-- MySQL dump 10.16  Distrib 10.2.36-MariaDB, for Linux (x86_64)
--
-- Host: localhost    Database: mariuspe_groparu
-- ------------------------------------------------------
-- Server version	10.2.36-MariaDB

/*!40101 SET @OLD_CHARACTER_SET_CLIENT=@@CHARACTER_SET_CLIENT */;
/*!40101 SET @OLD_CHARACTER_SET_RESULTS=@@CHARACTER_SET_RESULTS */;
/*!40101 SET @OLD_COLLATION_CONNECTION=@@COLLATION_CONNECTION */;
/*!40101 SET NAMES utf8 */;
/*!40103 SET @OLD_TIME_ZONE=@@TIME_ZONE */;
/*!40103 SET TIME_ZONE='+00:00' */;
/*!40014 SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0 */;
/*!40014 SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0 */;
/*!40101 SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='NO_AUTO_VALUE_ON_ZERO' */;
/*!40111 SET @OLD_SQL_NOTES=@@SQL_NOTES, SQL_NOTES=0 */;

--
-- Table structure for table `wp_comments`
--

DROP TABLE IF EXISTS `wp_comments`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `wp_comments` (
  `comment_ID` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `comment_post_ID` int(11) NOT NULL DEFAULT 0,
  `comment_author` tinytext NOT NULL,
  `comment_author_email` varchar(100) NOT NULL DEFAULT '',
  `comment_author_url` varchar(200) NOT NULL DEFAULT '',
  `comment_author_IP` varchar(100) NOT NULL DEFAULT '',
  `comment_date` datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  `comment_date_gmt` datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  `comment_content` text NOT NULL,
  `comment_karma` int(11) NOT NULL DEFAULT 0,
  `comment_approved` varchar(20) NOT NULL DEFAULT '1',
  `comment_agent` varchar(255) NOT NULL DEFAULT '',
  `comment_type` varchar(20) NOT NULL DEFAULT '',
  `comment_parent` bigint(20) NOT NULL DEFAULT 0,
  `user_id` bigint(20) NOT NULL DEFAULT 0,
  PRIMARY KEY (`comment_ID`),
  KEY `comment_approved` (`comment_approved`(1)),
  KEY `comment_post_ID` (`comment_post_ID`),
  KEY `comment_approved_date_gmt` (`comment_approved`,`comment_date_gmt`),
  KEY `comment_date_gmt` (`comment_date_gmt`)
) ENGINE=MyISAM AUTO_INCREMENT=34483 DEFAULT CHARSET=latin1;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `wp_comments`
--

LOCK TABLES `wp_comments` WRITE;
/*!40000 ALTER TABLE `wp_comments` DISABLE KEYS */;
INSERT INTO `wp_comments` VALUES (52,291,'Ayra','ayra_black@yahoo.com','http://bitterbluechronicles.wordpress.com','86.121.83.255','2007-04-01 01:59:52','2007-03-31 23:59:52','Of, pentru numele lui D-zeu, chiar trebuia sa stim asta? :)) Sau sa devenim constienti? :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(51,290,'celtic_bhoy','nemessys_gate@yahoo.com','','80.96.31.71','2007-03-31 19:44:32','2007-03-31 17:44:32','era o singura problema numa: era decembrie!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(48,290,'Andre MKT','','','86.106.55.69','2007-03-31 08:15:57','2007-03-31 06:15:57','Foarte vulgar, radu, Foarte vulgar!\r\nCred ca soarele de la karting te-o lovit in moalele capului.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(49,288,'corino','','http://vreauiosasetipareascapewebsite','66.176.74.8','2007-03-31 16:06:27','2007-03-31 14:06:27','Ma copii atentie ca asta cu site-ul vrea sa va innebuneasca de ris..dupa principiul mare e gradina lui D-zeu si multi o sarit gardu cind poarta era deschisa. Gropare (ce nume fatidic ai) sa ne traiesti la multi ani (cu visele tale \"eroice\" cu tot) si sa ne mai scrii cit de multe...\r\nAi putea sa ne scrii si tu cite un newsletter ....\r\n\r\n Te groparesc \r\n             Corino',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(9,145,'pepi','roman.petre@gmail.com','','82.77.126.134','2007-03-16 10:05:43','2007-03-16 08:05:43','Am vazut ca ai si rss, dar nu si link :). Poate ajuta pe cineva, ca pe mine stiu :P.\r\nhttp://www.groparu.ro/?feed=rss2',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727)','',0,0),(10,145,'tiboras','tibor_vamos@yahoo.com','','86.127.119.35','2007-03-16 13:21:14','2007-03-16 11:21:14','mai stii tu ceva de femei, ai putea scrie lejer  o carte cu atitea informatii e misto tine o asa',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(11,145,'','','','82.76.88.37','2007-03-16 14:30:38','2007-03-16 12:30:38','pot sa atest ca faza cu \"de ce ma pupi nebarbierit?\" e perfect adevarata!!! :))) e una din preferatele mele, spuse prietenului :P.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.2) Gecko/20070219 Firefox/2.0.0.2','',0,0),(12,145,'Andre','supergirgir@yahoo.com','http://marlahermina.deviantart.com/gallery/','82.77.126.254','2007-03-16 15:23:10','2007-03-16 13:23:10','Tu esti tahui, sa mor io!\r\nPostul asta nu este despre barbatul care o trait 116 ani\r\nci despre femeia balcanica in carne si oase si grasime.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(13,40,'Andre','supergirgir@yahoo.com','http://marlahermina.deviantart.com/gallery/','82.77.126.254','2007-03-16 15:35:18','2007-03-16 13:35:18','stii de unde vine Blea?\r\nam intrebat un bassarabean si mi-o zis ca e o derivare de la cuvantul BLEAD care inseamna prostituata. ma gandeam ca te-am loat la faza asta.\r\ncu drag eu, din biroul vecin:)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(14,40,'Andre','supergirgir@yahoo.com','http://marlahermina.deviantart.com/gallery/','82.77.126.254','2007-03-16 15:43:37','2007-03-16 13:43:37','a, stiu de tipu ala cu surubu prin nas, era ras in cap si statea imbracat numai in geaca de piele (pe pielea goala) la coada la cantina la minus 15 grade si se juca cu un cutzit. ala e!\r\nauzisem ceva de Legion, dar nu sunt singura!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(15,79,'Andrei','cipcirip@yahoo.com','http://n-am,ba,ok?','72.181.106.183','2007-03-16 17:08:35','2007-03-16 15:08:35','bine ca n-ai copiat si comentariile :)))))',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.0.3705; .NET CLR 1.1.4322; Media Center PC 4.0; .NET CLR 2.0.50727; ImageShack Toolbar 3.0.6)','',0,0),(16,94,'ardeiash','mamanandu@yahoo.co.uk','','87.65.155.164','2007-03-17 20:15:20','2007-03-17 18:15:20','c\'est vrai!  c\'est la belgique...',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1)','',0,0),(17,16,'anne oprea','anneoprea@yahoo.fr','','62.205.117.229','2007-03-18 00:38:21','2007-03-17 22:38:21','dragut stilul',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(18,151,'pepi','roman.petre@gmail.com','','82.77.126.134','2007-03-20 17:57:49','2007-03-20 15:57:49','La faza cu printzoru, jos palaria, dar ala ii dintr-o alta speta de englezi, nu ca restu politicienilor. Sa nu uitam ca prin 2003 cand pornea razboiu din Irak, si ai lor politichisti au fost acuzati de plagiat http://news.bbc.co.uk/2/hi/uk_news/politics/2736149.stm.\r\n\r\nTot o apa si un pamant.\r\n\r\nDar jos palaria, pentru a doua oara, pentru  romancele noastre :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.2) Gecko/20070219 Firefox/2.0.0.2','',0,0),(19,145,'Nascut din spermatozoizi campioni &raquo; Blog Archive &raquo; Cum se manipuleaza un gardian pudic','','http://www.groparu.ro/?p=153','69.16.239.16','2007-03-20 22:45:56','2007-03-20 20:45:56','[...] ÅŸi el a cedat, mai ales cÄƒ tanti nu Ã®l bÄƒtea la cap sa ducÄƒ gunoiul, sÄƒ repare uÅŸa sau sÄƒ cureÅ£e usturoi pentru chiftele. AÅŸa cÄƒ s-a hotÄƒrÃ¢t sÄƒ o reguleze, dar fÄƒrÄƒ ÅŸa, ÅŸi fÄƒrÄƒ sÄƒ se mai oboseascÄƒ sÄƒ o [...]',0,'1','Incutio XML-RPC -- WordPress/2.1.2','pingback',0,0),(20,153,'Andre MKT','','','86.106.55.69','2007-03-20 23:38:07','2007-03-20 21:38:07','I have a dream from the Rocky Mountains of Mississippi....\r\n\r\nEu mereu am vrut sa ma fac vanzatoare. \r\nSau derulatoare de casete in discoteci.\r\nSau detzinuta aia ne-lesbiana shi sa imi plimb\r\nlipsa de forme prin fatza colegelor mele lesbiene.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(21,153,'Nobody','stvali@personal.ro','','89.137.115.5','2007-03-21 01:30:35','2007-03-20 23:30:35','Cata vreme nu te faci homosexuala... e ok sa nu fii lesbiana',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(22,154,'pepi','roman.petre@gmail.com','','82.77.126.134','2007-03-22 13:34:54','2007-03-22 11:34:54','La multi ani, Andreea ;)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(23,164,'RM','','','194.117.242.3','2007-03-22 16:09:16','2007-03-22 14:09:16','Ma tem ca nu esti foarte informat in acesta directie. Tariceanu a argmentat destul de bine acesta decizie: \r\n\"Romania nu-si permite sa nu aiba reprezentare de nivel pe plan extern [...] Din pacate, in acest moment MAE se afla intr-o stare de blocaj cauzata de faptul ca presedintele Traian Basescu a refuzat propunerea de numire a ministrului de Externe pe care i-am facut-o. Acestea sunt motivele pentru care astazi am decis sa preiau pentru un timp limitat, cu titlu interimar, responsabilitatile ministrului de Externe pana cand acest blocaj se va rezolva. Pana la formularea unui raspuns din partea Curtii Constitutionale voi asigura interimatul la Ministerul Afacerilor Externe\"\r\n\r\nAi vreo alta solutie in aceasta situatie?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1; .NET CLR 2.0.50727)','',0,0),(24,47,'christine','','','82.76.88.37','2007-03-22 16:25:20','2007-03-22 14:25:20','dementiale poze, ce sa zic... ma pufneste rasul de la meclele voastre tiganizate :)). asteptam cu interes cel de-al nspelea succes!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(25,164,'Groparu','groparu.ro@gmail.com','http://','82.77.126.254','2007-03-22 17:11:18','2007-03-22 15:11:18','Hmmm. Ditamai coalitia de guvernare, si nu reusesc sa gaseasca un catindat pentru postul de ministru de externe care sÄƒ fie tÃ¢nÄƒr, Ã®n putere, ÅŸcolit ÅŸi erudit asupra cÄƒruia sÄƒ cadÄƒ ÅŸi alfa ÅŸi beta (recte, BÄƒse\' ÅŸi TÄƒri\') de acord? Greu de crezut...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,2),(26,151,'Groparu','groparu.ro@gmail.com','http://','82.77.126.254','2007-03-22 17:14:00','2007-03-22 15:14:00','Jos palaria, da\' ÅŸi pantalonii!!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,2),(27,147,'Andre','supergirgir@yahoo.com','http://marlahermina.deviantart.com/gallery/','82.77.126.254','2007-03-26 08:47:26','2007-03-26 06:47:26','crede-ma ca shi animalele se inghesuie in autobuz,\r\nmai ales in autobuzele de tzara, cand nea Fanel intra cu capra\r\nsi o pune pe scaunul ghidului.\r\nde asemenea, exista si o lele Victorie care vine cu o lada \r\nplina cu pui shi closhca overall shi ii aseaza pe scaunul din fatza.\r\n\r\nevident ca peizanii stau in picioare\r\n\r\nco-co-co-co-co',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(28,147,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-03-26 11:29:48','2007-03-26 09:29:48','Si lui nea Fanel ii putem intelege afinitatea pentru capra - animal sau pozitie, si lui tanti Victoria ii comprehensizam nevoia de exprimare cu \"ce puii mei!\"',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(29,267,'tiboras','tibor_vamos@yahoo.com','','86.127.119.35','2007-03-26 12:56:36','2007-03-26 10:56:36','mai e tara noastrab draga si frumoasa o permanenta tranzitie, ce zici tu acolo si asta e nasol ca tre sa te comporti ca si cum ar fi normal, sau sa te multumesti cu comportamentu oieresc de a te lamenta tot timpu, io am o stare de scirba permanenta. odata o sa vomit si o sa ma simt mai bine probabil.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(30,267,'nana (o mioara)','razornana@yahoo.com','','194.102.215.91','2007-03-26 13:22:30','2007-03-26 11:22:30','beeeeeehhheeeeiiii... Rapidul nu retrogradeaza :p',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1)','',0,0),(31,267,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-03-26 16:00:23','2007-03-26 14:00:23','@tiboras - io nu ma lamentez, io am inceput sa latru si sa musc, stai numa pana scriu intrarea din seara asta :D\r\n\r\n@nana - si io zic la fel, nici o ekipa nu retrogradeaza niciodata decat daca mere cu spatele!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(32,280,'Fascista','luminitadanciu@yahoo.com','','209.221.168.249','2007-03-28 00:08:21','2007-03-27 22:08:21','Mai toate ca toate, da\' tu nu porti si sutien la slipi? Next time display a bra or a bro on that rack!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; InfoPath.1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(33,280,'Groparu','groparu.ro@gmail.com','http://www.groparu.ro','89.137.115.5','2007-03-28 00:28:27','2007-03-27 22:28:27','Hmmm. Port sutien, dar numai pe podea, langa pat. Uneori mai ajunge si pe lampa si in oala cu macaroane cu soia.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(34,280,'marcu\'','','','192.35.17.15','2007-03-28 12:17:11','2007-03-28 10:17:11','deci sa reluam:\r\n- incapere goala\r\n- la un moment dat un rucsac cu \"prosop si slipi\" este lasat in incapere, nepazit\r\n- niste tipi intra sa discute afaceri\r\n- \"prosopul si slipii\" sunt etalati \r\n- tipii vorbesc doua ore, dupa care pleaca\r\n- rucsacul este recuperat...\r\n\r\ntoo many movies ? :))',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; InfoPath.1; .NET CLR 2.0.50727)','',0,0),(35,79,'Fascista','luminitadanciu@yahoo.com','','71.112.150.74','2007-03-29 03:40:15','2007-03-29 01:40:15','Cine e far\' de pacat sa arunce prima piatra. Uite ma ca pot cita/ parafraza din Biblie! Who knew I was a Bible thumper? \r\nN-o sper ca n-u ma-m facut de rusine cu cum a-m scris? Me count on you to tell if so! :)\r\nPicky, picky, picky!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; Sgrunt|V109|29|S-996046478|dial; snprtz|T05036630770176; .NET CLR 1.1.4322)','',0,0),(36,280,'sajata','a@a.com','','82.77.126.254','2007-03-29 15:43:27','2007-03-29 13:43:27','daca va aduceti aminte, marin preda, victor petrini, cel mai iubit dintre pamanteni, etc... \"uite un barbat cu coaie pe piept\" ii zise dracu\' al mic lui scaraotchi. si dup-aia o fost trimis sa slujasca pe pamant drept pedeapsa. noah, mirarea e ca nu aveti voi chilotzi la sutien, nu noi sutien la chilotzi',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(37,280,'Groparu','groparu.ro@gmail.com','http://www.groparu.ro','82.77.126.254','2007-03-29 15:47:11','2007-03-29 13:47:11','@marcu: Yes. Too many movies, not enough action.\r\n\r\n@sajata: de ce nu pot barbatii sa poarte costumu\' lu Eva? De zbracat, mon cher, de zbracat.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(38,79,'admin','groparu_ro@yahoo.com','http://','82.77.126.254','2007-03-29 15:56:21','2007-03-29 13:56:21','Eu sunt prima piatra.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,1),(165,326,'Greuceanu','fm77roen@yahoo.com','','195.149.72.124','2007-04-13 19:27:20','2007-04-13 17:27:20','Asha e mo....\r\ndar nu ma mai provoka mah!  \"Io nu mai pacatuiesc, ... Da\' nici Tu nu ma mai ispiti!\" nu se cade mah sa propui divinitatii astfel de troace..... trocuri....',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(40,285,'Greuceanu','','','195.149.72.124','2007-03-29 23:49:37','2007-03-29 21:49:37','Bazavane..... sa mor ieu daca imi pot imajina de unde dreaku\'tzi mai tragi sevele! De cate ori citesc cate ceva d\'ale Groparului.... imi zic: \"Mah! asta da! sa-mi bag! cum citesc printre lacrimi!  Asta chiar ca e cea mai tare din toate.... sigur nu va mai scrie... sau dak-o mai scrie, sigur\'or hi rasuflate fata de asta.... si asta se intampla de vreo 2-3 ani....\"  da-i \'nente!  ieu abia astept!!!!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(41,285,'Groparu','groparu.ro@gmail.com','http://www.groparu.ro','89.137.115.5','2007-03-30 00:30:04','2007-03-29 22:30:04','Esti un nesimtit mincinos. Sau vrei bani imprumut. OK, cati?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(42,285,'Andreea MKT','supergirgir@yahoo.com','http://marlahermina.deviantart.com/gallery/','82.77.126.254','2007-03-30 11:12:38','2007-03-30 09:12:38','Vreau bani!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(43,285,'Groparu','groparu.ro@gmail.com','http://www.groparu.ro','82.77.126.254','2007-03-30 11:34:13','2007-03-30 09:34:13','Lauda-ma.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(44,288,'sabina','','','81.12.163.178','2007-03-30 13:24:06','2007-03-30 11:24:06',':))',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1)','',0,0),(45,288,'pepi','roman.petre@gmail.com','','82.77.126.134','2007-03-30 15:34:42','2007-03-30 13:34:42','seminÅ£ie = s.f., cÃ¢nd te apuci sÄƒ mÄƒnÃ¢nci seminÅ£e :-))\r\n\r\nCum se numeste persoana care mananca alune? A Lunatic :P ?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727)','',0,0),(46,288,'Groparu','groparu.ro@gmail.com','http://www.groparu.ro','82.77.126.254','2007-03-30 15:55:51','2007-03-30 13:55:51','...alunelu\'...?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(47,285,'mumuland','','','85.204.38.37','2007-03-30 19:42:25','2007-03-30 17:42:25','.......ca si la femei .....intai platesti si apoi (o) servesti.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(449,358,'Groparu','groparu.ro@gmail.com','http://www.groparu.ro','82.77.126.254','2007-05-01 09:03:00','2007-05-01 07:03:00','@Andrei, deci io chiar ca pot fi asemuit cu un magar, si cu orice alt animal cu scula mare.  \r\n\r\nOrganizatorilor le doresc numa\' si numa\' la fel de mult bine (finca merita) cate shute in posterior or loatara de la toti frustratii, care or tot facut \"ga-ga-ga\", asa or tot facut!!! Veti nimeri in rai, baieti (si fetitze), in partea cu bloguri! Daca eram Andi Moisescu, ma-nchinam, asa, finca is Groparu, ma-nchin de 2 ori ;) Respect! Good job, cu prima ocazie va maresc salaru\'!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(450,355,'Sorinelu\'','sorinelm@gmail.com','','82.77.126.35','2007-05-01 10:10:32','2007-05-01 08:10:32','gropare sa ne traiesti si la anu tot cel mai prost blog sa iesi :D',0,'1','Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.0.11) Gecko/20070327 Ubuntu/dapper-security Firefox/1.5.0.11','',0,0),(451,354,'Bogi','bic_player@yahoo.com','','86.125.169.80','2007-05-01 11:17:53','2007-05-01 09:17:53','pfff saraca....defapt cred k e obijnuita la ora aia...\r\nda cum se face k defiecare data cand sun la orinj in miezu noptzii knd is rupt d bat nu\'i nime acol sa raspunda...si tu suni la o banca, sau la call centeru lor, si ii cineva acol si ai p cin sa iei la mishto :(',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(452,346,'Bogi','bic_player@yahoo.com','','86.125.169.80','2007-05-01 11:19:30','2007-05-01 09:19:30','poi tot zici p-aici k esti paralel cu fizica nucleara...de ce nu il pui sa te invetze si deaia...:P :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(453,328,'Bogi','bic_player@yahoo.com','','86.125.169.80','2007-05-01 11:26:21','2007-05-01 09:26:21','mno imi pare rau k nu am dat d blogu tau mai devreme sa te votez!! :( k il meritzi... si acuma dak tot ai luat premiu o sa pui in aplicare toate promisiunile...k poate mai dau si o raita prin cluj  k stau aproape :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(454,355,'Groparu','groparu.ro@gmail.com','http://www.groparu.ro','82.77.126.254','2007-05-01 11:26:39','2007-05-01 09:26:39','Man, mersi, daca nu ies, apai tot fac io cumva sa intru!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(455,354,'admin','groparu_ro@yahoo.com','http://','82.77.126.254','2007-05-01 11:31:06','2007-05-01 09:31:06','...sa fie din cauza ca is etichetat acolo in baza de date cu \"client problema\" din cauza ca le-am amentintat ca il aduc pe Fidel Castro in locu\' lu Vacaroiu din cauza ca l-or demis pe prezident din cauza ca nu-l plac din cauza ca numa da din gura din cauza ca el asa se gandeshte ca se face treaba? Probabil...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,1),(72,293,'marz','marz@clicknet.ro','','89.123.79.39','2007-04-01 09:27:41','2007-04-01 07:27:41','si tu ai afisat aici intrebarile puse intr-o luna si ceva ? :| ca-s 48 in total... da, gropare, ma plictisesc :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(172,326,'Greuceanu','fm77roen@yahoo.com','','195.149.72.124','2007-04-16 22:06:16','2007-04-16 20:06:16','da .... daka tu zici...\r\n\r\nda\'daka tat le jti tu pe toate.... ia zi-mi de unde jtiam io ca Camus sau Jung o zis?! ca... fara fum nu iese foc, sauuu... fara foc nu iese fum... Pasca ei de treaba...',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(3238,477,'Rottencabbage - Romanu e roman si-n Congo','','http://rottencabbage.haipa.ro/2007/06/16/romanu-e-roman-si-n-congo/','193.203.204.226','2007-06-16 02:00:00','2007-06-16 00:00:00','[...] ca pur si simplu nu am putut sa ii sparg figura in fata sefului si a celorlalti colegi. Tzucu-te! Fi-ti-as oedipu familiei tale sa-ti fiu! (in gand ziceam asta, da cred ca mi se vedea pe fatza, ca ii zice seful la ala, sa-l scoata [...]',0,'1','Incutio XML-RPC -- WordPress/supermoded by haipa v5.6','pingback',0,0),(3229,481,'Adi','acalarasu@gmail.com','http://adriancalarasu.wordpress.com','89.32.19.126','2007-06-15 22:48:35','2007-06-15 20:48:35','ÅŸ-anume ce trebi importante avea Groparu prin Sibiu, era ceva targ p-acolo? \r\nam eu o neliniste...\r\n:)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(3231,482,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.112.22','2007-06-15 22:53:26','2007-06-15 20:53:26','Mah, tu esti? Sau e frate-tu?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(3232,481,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.112.22','2007-06-15 22:56:43','2007-06-15 20:56:43','@Baghy: mah, am uitat sa mai pun neshte zerouri, da\' nush daca in fatza sau in spatele cifrei!\r\n\r\n@Adi: nu, mah, ma duc la munte. Un munte de gratare! :D (pffuaaai, fuame mi-i...)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(3233,481,'baghy','baghy83@lycos.it','http://baghy.wordpress.com/','78.12.5.241','2007-06-15 23:29:13','2007-06-15 21:29:13','in spate ca in fata le pui degeaba',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(3234,483,'oedip','oedip74@gmail.com','http://oedip.blogspot.com','89.137.104.170','2007-06-15 23:52:09','2007-06-15 21:52:09','n-ai fÄƒcut nimic, n-ai cu ce nÄƒ ne Ã®ncÃ¢nÅ£i\r\nhihihihihi...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(79,293,'Groparu','groparu.ro@gmail.com','http://','89.137.115.5','2007-04-02 22:57:39','2007-04-02 20:57:39','Nu am avut cum sa pun si zambetul perfid cu care mi se capteaza atentia. Oare d-aia nu mai am incredere in oameni?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,2),(80,304,'Andreea MKT','supergirgir@yahoo.com','http://marlahermina.deviantart.com/gallery/','82.77.126.254','2007-04-03 14:58:41','2007-04-03 12:58:41','nu-mi place coltarul, e prea bordelistic.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(81,304,'anonymous','fdvne@yahoo.com','','24.17.110.178','2007-04-03 16:43:17','2007-04-03 14:43:17','oribil coltzar...arata ca luat din piatza, de la tipii aia care vand mobila ieftina...',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(82,306,'Razvan Antonescu','razvan.antonescu@gmail.com','http://idei-locale.blogspot.com','82.137.30.96','2007-04-03 22:35:46','2007-04-03 20:35:46','Io l-am vazt pa unu si mai smecher. Vine controlu\', ala ca n-are belet, face gat pana ii enerveaza pe aia de numa. La prima statie RTUCii sa il dea jos. Ala scoate biletu\' si incepe sa ranjeasca. Oameni mai daramati ca aia n-am vazt',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.0.11) Gecko/20070321 Firefox/1.5.0.11 Flock/0.7.12','',0,0),(83,124,'alex trusca','alex_trusca@yahoo.fr','','86.126.98.36','2007-04-03 22:45:15','2007-04-03 20:45:15','radu...bravo. poate ca ma mai tii minte...mi-am facut un pic de lucru prin caminul nr. 6 de la litere din hasdeu...:)\r\nacum vreo 6 ani...eram student la teologie\r\nmersi de textuil asta. am ras copios. nu neaparat pt ca am treaba cu cele sfinte, ci pt ca nu suport manipularile lui dan brown. si...nu ma pot dumiri cat de multi imbecili si creduli se lasa dusi de nas.poate ca asa se vor mai trezi, prin textul tau.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1)','',0,0),(84,124,'alex trusca','alex_trusca@yahoo.fr','','86.126.98.36','2007-04-03 22:46:15','2007-04-03 20:46:15','PS cei care au urechi de auzit si nu aud, sa mearga la orl:))',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1)','',0,0),(85,304,'Groparu','groparu.ro@gmail.com','http://www.groparu.ro','89.137.115.5','2007-04-04 00:30:11','2007-04-03 22:30:11','@ Andreea: fiecare modul are lada lui de lenjerie =&gt; in fiecare pot baga cate o gajica, daca ma insor si vine nevasta mai repede acasa.\r\n\r\n@ anonymous: si normal ca e oribil, dar asta e numa modelu\', al meu are o combinatie de culori mai reusita (verde aprins cu portocaliu fosforescent)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(86,304,'sabina','','','81.12.163.178','2007-04-04 09:16:03','2007-04-04 07:16:03','gajici contorsioniste tre\' sa ai!!!',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1)','',0,0),(87,304,'Groparu','groparu.ro@gmail.com','http://www.groparu.ro','82.77.126.254','2007-04-04 11:08:31','2007-04-04 09:08:31','Nu-i stress, ca daca nu intra il kem pe Jack Spintecatoru\', si le inghesuie el cumva.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(91,265,'Placerea nu se refuza &raquo; PERICOL DE MOARTE: Cu bicicleta prin Cluj','','http://groller.info/geza/2007/03/29/pericol-de-moarte-cu-bicicleta-prin-cluj.html','193.203.204.226','2007-04-04 23:17:20','2007-04-04 21:17:20','[...] fiu in Piata Unirii la servici. Cu RATUC faci cam 30 de minute (nu mai zic de conditii&#8230; a zis Groparu), cu masina mica lejer 20. Asta dimineata intre 8 si 10 cand e traficul ala mai [...]',0,'1','Incutio XML-RPC -- WordPress/2.1.2','pingback',0,0),(104,319,'krigton','','','81.196.150.96','2007-04-05 14:30:03','2007-04-05 12:30:03','beton, sper ca aceste caracatie in jurul credintei numite religii sau mai bine zis biserici vor disparea in cateva zeci de ani. numai ne incurca viata.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(105,319,'Groparu','groparu.ro@gmail.com','http://','82.77.126.254','2007-04-05 15:00:14','2007-04-05 13:00:14','Nu, man, nu, ca io am stat si m-am gandit. Io stiu ca daca s-ar duce toti fariseii de pe lumea asta, as ramane singur, si m-as plictisi teribil (observi lipsa crasa de modestie); plus ca nu mai is sigur ca s-ar implini ce zicea Ildiko a mea cand o imploram cu lacrimi in ochi sa nu-mi dea papucii, si ea zicea \"noi doi? impreuna din nou? numai daca ai ramane ultimul mascul de pe lumea asta!\" - si sincer sa fiu nici nu as mai vrea sa se intample asta, ca s-o ingrasat.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,2),(106,319,'krigton','','','81.196.150.96','2007-04-05 15:38:37','2007-04-05 13:38:37','apoi nu toti cred in biserica :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(107,319,'Groparu','groparu.ro@gmail.com','http://www.groparu.ro','82.77.126.254','2007-04-05 16:11:22','2007-04-05 14:11:22','Corect, is si unii care cred in Dumnezau :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(108,319,'pepi','roman.petre@gmail.com','','82.77.126.134','2007-04-05 16:14:55','2007-04-05 14:14:55','Da tu tii cu Dinamo :)? Circula un zvon, ca Dumnezeu va tine cu Steaua sambata :P, sau asa zicea Jiji.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727)','',0,0),(109,319,'Groparu','groparu.ro@gmail.com','http://','82.77.126.254','2007-04-05 16:20:04','2007-04-05 14:20:04','Apai io atata stiu: indiferent cine joaca, io tin cu Dumnezeu, ca macar nu face blat!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,2),(110,321,'Sorinelu\'','sorinelm@gmail.com','','82.77.126.35','2007-04-05 16:24:27','2007-04-05 14:24:27','Ce e Gropare cu Ildiko asta dupa care regreti atata? Ii curgea bere din sfarcuri?',0,'1','Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.0.10) Gecko/20070302 Ubuntu/dapper-security Firefox/1.5.0.10','',0,0),(111,321,'Groparu','groparu.ro@gmail.com','http://www.groparu.ro','82.77.126.254','2007-04-05 16:33:10','2007-04-05 14:33:10','Hmmm... nu, ca daca ii curgea ma faceam Hannibal the Cannibal, o ascundeam in kimnitza, o puneam la imbuteliat si deskideam o noua fabrica de bere, Ildikoiana :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(3207,480,'ss','criss_team@yahoo.com','','81.196.150.198','2007-06-15 10:11:51','2007-06-15 08:11:51','au inceput sa piarda noptile prin baruri si cluburi  -&gt; lipsa cronica de somn -&gt; maladii cardiace =&gt; asa au murit dinozaurii',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7','',0,0),(3208,480,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-06-15 10:32:12','2007-06-15 08:32:12','@Baghy: am skimbat tigarile. facusera pe ele\r\n\r\n@ss: apai... io practic sportu\' asta de ceva vreme, sh inke n-am murit! :|',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(223,328,'Denisa','denisalala@gmail.com','http://www.denisuca.ro/blog','86.123.36.173','2007-04-23 16:16:49','2007-04-23 14:16:49','Pentru toate motivele ÅŸi promisiunile astea, ai votul meu. Groparu iz zÄƒ best of zÄƒ uorst!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(222,338,'Groparu','groparu.ro@gmail.com','http://www.groparu.ro','82.77.126.254','2007-04-23 14:41:19','2007-04-23 12:41:19','Hmmm... a treia dorintza nu vrei sa fie un stomac care sa poa\' sa dijere pkita aia cu slana care nu se topeshte? Ca daca ai avea asa ceva, ai putea sa bei ghi tatie, inclusiv alcool din termometru, lichid de frana si lapte demachiant cu alcool, ca efectul de afumare e garantat, si nij nu simti a doua zi ca daca faci pipi la coltz de strada, gaureshti gardu\'.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(220,335,'sorella','n.szoke@drago.net.pl','','84.40.204.174','2007-04-23 08:46:27','2007-04-23 06:46:27','no hat bine te-am gasit :P, da cum m-ai depistat? :))), macar mi-ai raspuns la tag ca restu nu se obosesc sa ma bage in seama, buna lojica :))))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(229,329,'Kissu','npacurar@gmail.com','http://www.pacurar.net','82.77.126.254','2007-04-24 09:52:19','2007-04-24 07:52:19','Confirmare!... http://www.youtube.com/watch?v=jGr969Wsn6U :D\r\nSi apoi: http://www.youtube.com/watch?v=FBO8GlROE2A&amp;mode=related&amp;search= da\' asta e calitate mai proasta (inregistrarea) dar piesa e MULT mai tare. :)\r\nSi am mai dat de una: http://www.youtube.com/watch?v=rtdyzXs3s7Y&amp;mode=related&amp;search= ;)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; InfoPath.1; .NET CLR 2.0.50727)','',0,0),(142,314,'krossfire','profesornukem@yahoo.com','http://krossfire.wordpress.com','86.123.207.153','2007-04-09 10:21:04','2007-04-09 08:21:04','Te-ai spovedit ? Te-ai impartasit ? Ai luat Luminaaaa ? Te simti mai curat si mai usor, cu asa un ajutor ?\r\n\r\nCred ca la urmatoarele sarbatori pascale o sa fac o campanie \'\'Tineti post pentru copii de Etiopia !\'\'',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(237,343,'cititoare','karianopol@yahoo.com','','195.225.64.98','2007-04-25 09:57:39','2007-04-25 07:57:39','trebuie sa recunosc ca ai stil. unul aparte! rad in mine de fiecare data cand citesc povestioarele tale. un ras sanatos. plin. dulce+amar. Dumnezeu sa-i odihneasca pe totii bunicii! unchii si matusile si toate neamurile mele, ale tale si ale tuturor!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; SU 2.010)','',0,0),(238,343,'Groparu','groparu.ro@gmail.com','http://www.groparu.ro','82.77.126.254','2007-04-25 10:06:08','2007-04-25 08:06:08','Mersi, adevaru\' e ca io mi-as dori mult sa ne hodineasca D-zeu si pe noi, ca bun ii somnu de dimineatza! Oioioi...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(239,343,'cititoare','karianopol@yahoo.com','','195.225.64.98','2007-04-25 10:14:42','2007-04-25 08:14:42','mie-mi spui!!!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; SU 2.010)','',0,0),(240,343,'sorella','n.szoke@drago.net.pl','','84.40.204.174','2007-04-25 11:42:52','2007-04-25 09:42:52','=))) o noua viziune asupra mortii :)))))\r\nfoarte pozitiv gandit :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(242,343,'Groparu','groparu.ro@gmail.com','http://www.groparu.ro','82.77.126.254','2007-04-25 15:04:34','2007-04-25 13:04:34','Ba man,... na, am coborat si io pe pamant tocma\' cand facea o nimfa baie in lac, cand il suspendau astia pe Basescu si mie imi murea cate o nevasta de verishor. Phuuula me!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(3187,480,'baghy','baghy83@lycos.it','http://baghy.wordpress.com/','78.12.5.241','2007-06-15 01:14:15','2007-06-14 23:14:15','tot mai bine scri.ai patit ceva in ultima perioada?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(247,345,'Marius','pop.marius@gmail.com','http://lityx.blogspot.com','86.35.157.42','2007-04-25 15:41:20','2007-04-25 13:41:20','No ashe! LOL',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(248,345,'Groparu','groparu.ro@gmail.com','http://www.groparu.ro','82.77.126.254','2007-04-25 15:52:37','2007-04-25 13:52:37',':D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(3173,477,'katmai','katmai@keptprivate.com','http://www.512kbps.com','195.212.29.187','2007-06-14 18:16:01','2007-06-14 16:16:01','sa mor daca mai stiu cine era oedip ... :((( si mie lene sa dau pe gugle :(((',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7 (CK-IBM)','',0,0),(241,343,'Marius','pop.marius@gmail.com','http://lityx.blogspot.com','86.35.157.42','2007-04-25 14:33:58','2007-04-25 12:33:58','Adica ba Gropare, io te citesc frecvent. Si-mi place de scrisul tau, sa mor io. Ca ai vana, stil si atitudine, in ordine inversa, normal. Si-mi place stii ce? Ca ai haz. Da\' asa nu-mi place cand ii zici tu de alea de dulce, adeca sentimente si tot felu\', de te crede lumea om, si om normal. Hai serios acuma - dumnezau sa-i odihneasca, da\' mai zi si \'mata de alea sa ne radem curat, fara amar. Sa ne radem ca la banc, nu ca la Charlie Chaplin, cu lacrima in coltul gurii si saliva pe spranceana. No, multam.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(149,324,'Gez','geza@dvis.info','http://groller.info/geza','89.137.114.63','2007-04-11 17:06:02','2007-04-11 15:06:02','Foarte tare frate... \r\n\r\nMai ales daca alt nene era insarcinat cu altcineva decat sofer beat :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(150,324,'luci','lucianticrea@yahoo.com','','89.123.75.76','2007-04-11 18:27:58','2007-04-11 16:27:58','pot sa zic ca spermatozoizii lu ALT NENE erau putin cam prea campioni',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(151,52,'Nascut din spermatozoizi campioni &raquo; Blog Archive &raquo; Cat de dobitoc poti sa fii ca sa minti un popa?','','http://www.groparu.ro/?p=326','69.16.239.16','2007-04-11 19:35:32','2007-04-11 17:35:32','[...] nu e nimic pe langa ce o facut Mitroa. Eram acolo. Eram chiar acolo - acolo unde anu&#8217; trecut pupasem candelabru, din greseala. Ne inviam, aÅŸteptam cu nerÄƒbdare sÄƒ se termene slujba, sÄƒ fumam ÅŸi sÄƒ mÃ¢ncÄƒm carne. La un [...]',0,'1','Incutio XML-RPC -- WordPress/2.1.2','pingback',0,0),(152,82,'Marius','pop.marius@gmail.com','http://lityx.blogspot.com','85.186.51.206','2007-04-11 20:08:15','2007-04-11 18:08:15','LOL cu font de 46. Excelent scris.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(153,70,'Tetea','n-are','http://nicid-asta','82.77.202.17','2007-04-11 20:28:16','2007-04-11 18:28:16','MÃ£ doare-n bascÃ£ de \"Richard Wumbrandt\", da\' numele to\'ashului e de fapt Richard Wurmbrand... FYI :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(3826,504,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.123.105.230','2007-07-05 11:15:17','2007-07-05 09:15:17','@Cornelia: io as prefera sa razi de cate ori nu ma ceteshti, ca bag sama ca a fi mai ghes ;)\r\n@Kissu: Ba Kissu, cu fatza asta m-as face avocat, mah, termopane termopane\r\n@Emaginatoru: deci io zic ca daca o aluzie nu are tenta sexoala, nij nu are rost sa o mai aluzionezi',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(3827,505,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.123.105.230','2007-07-05 11:18:36','2007-07-05 09:18:36','@All: Deci ba, mersi fain de urari, va asigur ca am o gruaza de povestit, ca nij in concediu\' asta Dumnezeu nu o avut kef sa ma plictisesc! Numa atata va dau de preludiu, ca atata fusai cuprins de evlavie ca era cat p-aci sa imi fac cruce in moscheea din Constantza, phuii mei...\r\n@C|neva: Ba, ultima data cand am verificat eu eram in spatele mousului. Da\' sa stii ca io joc nasol numa ca sa nu va fac pe voi sa va simtiti prost :d',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(155,326,'Andreea MKT','supergirgir@yahoo.com','http://marlahermina.deviantart.com/gallery/','82.77.126.254','2007-04-12 09:56:03','2007-04-12 07:56:03','Oki, la mine, in jumatea de familie olteneasca se practica mintirea popilor...\r\n\r\nDeci, bunica-miu Costica murise in \'89, D-zo sa il hodine si rubedeniile oltenesti evident ca o intarziat la inmormantare, printre care si matusa-mea, fiica raposatului. Deci intra ajtia in beserica, tzipa niste curci si popa ii ia la rost:\r\n-Nu va e rusine, la ora asa se vine la prohod?\r\n \r\nLa care matusa-mea:\r\n-Lasa-ne, parinte, ca abia acuma am venit de la Bucuresti!\r\n\r\nFaza este pe bune, deci da, la noi se mint popii.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(156,70,'Groparu','groparu.ro@gmail.com','http://','82.77.126.254','2007-04-12 11:33:51','2007-04-12 09:33:51','E, mah! Vroiam sa vad daca te prinzi.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,2),(157,314,'Groparu','groparu.ro@gmail.com','http://www.groparu.ro','89.137.115.5','2007-04-12 17:28:13','2007-04-12 15:28:13','Da mo, am loat! sh o fo gratisa. \r\n\r\nSh cu etiopiencele nu ar fi rau, ca daca s-ar vindeca toate femeile de-acolo de fuame si ar veni in Europa in cautarea fericirii, ar fi nuuuumaaaa ghiniiii...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(279,353,'Sorinelu\'','so@mo.ro','','89.32.204.225','2007-04-27 20:13:22','2007-04-27 18:13:22','N-am stiut ca am avut o sora geamana de care am fost despartit la nastere... :)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; SIMBAR={1D9E109F-E241-4fbe-8286-1439153C02D2}; .NET CLR 1.1.4322)','',0,0),(280,353,'admin','groparu_ro@yahoo.com','http://','89.137.112.22','2007-04-27 20:14:40','2007-04-27 18:14:40','Da mah, mai ales ca Diana si-o tinut ziua azi, da\' de fapt e nascuta in 1 Mai muncitoresc.\r\n\r\nPS: Iti urez si tie sa nu ai par in nara! ;)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,1),(159,326,'Greuceanu','fm77roen@yahoo.com','','195.149.72.124','2007-04-12 22:33:49','2007-04-12 20:33:49','aka Mitroa!\r\nmah! io n-am vrut , jur! sa-l mint! jur inca o data! jur! mah... da\' e nedreprt mo! e singura pasa crestineasca de care-mi pasa, si asta s-o intamplat de prin clasa a XI-a, cand incercam sa-l conving pe Inu, mai frumos, mai mare, mai frumos, mai cu succes la fete, mai apreciat de mama decat io insumi, sa-l conving cu tot ce stiam eu de la Nitzche sh Cioran, sa devina ateu... ca n-are rost, ca hai sa bem in noaptea sfanta etc.  Shi el mi-a zis.... \"da\' mah! asha-i! ai dreptate! asha e, cum zici tu! da\' io la beserica, la inviere tot ma duc! ca asha e shi mama, shi bunica-mea shi toata familia mea, n-or fi toti projti shi io dejtept\".... apoi am mai citit ceva de .... de... no\' ni mah... cum i-i zice... Camus cre\'ca... sau Jung, oricum cred ca era tot unu... care zicea asha... \"mah ! mah Gigi!te duci la inviere shi el nu exista...... ce-ai mah de pierdut!? nimik mah! Dar de nu te duci sh el exista?! ai cam belit-o!...\" si ui\' asha, amu vreo ... vreeeeoooo 12 ani, am inceput sa merg la inviere.... sa ma spovedesc..... sa nu scuip sau sa pup in ziua aia, sa nu injur in post, sh toate alea ce-am mai auzit shi eu de la ala ce videa lumanari... un fel de secretara a bisericii, a lacashului, ala face programari, la ala platejti, ala trage clopotele sh tot zice ce vrea atuncea... etc.... mo, sh de atunci tot incerc sa invataz sh io cateva chestii care nu imi ies niciodata... ceva de genu\':\"am vin\'t sa ma ..... spovedesc... \"....dar te-ai cuminecat?! nu..... ma duc amu... unde?! ui\' acolo unde stau aia 8 oameni! stau acolo la coada.... cand ajung... ma bata baba pe umar shi zice...\"aici stau numai femeile, barbatii au fost inainte... haidetz maine! maine, stau la cuminecat! \"ati mancat ceva az\' dimineata?! nu! dar pe dinti, v-ati spalat?! ... errrrr.. mdaa... haidetz maine, fara spalat! viu iara maine.... nespalat, nemancat, la cuminecat cu barbatii.... ajung primu\', zice popa...da\' v-atz impartashit?!... eerrrrrr.. nuuu chiar.... ei! pai dvs ati ajuns la varsta asta shi nu jtiti randuiala bisericeasca?! trebe sa va impartashiti intaihaidetz maine la 7! .... no, viu maine la 7, stau la coada (credeam ca-i coada...).. domne\' stai domne la rand zic eu atacat de babu cesh razamase umbrela de mine... ne-spalat, ne-pupat de vreo 8 zile, nemancat, .... etc, stai domne, ca aici nu-i coada, amu domn\' parinte zice evanghelia... ioi zic! tzujti in jenunchi! VAI! dumneata nu jti ca tot anu se injencheaza la evanghelie, dar in noaptea asta nu?!.... no.... ideea e ca nici amu o saptamana, shi nici amu\' habar nu am cam care-i treaba cu randuiala..... si merg cam \"random\", iar ca l-am mintit.... e vina popului uman! imajineaza-ti! beserika plina, 2 oameni la coada laaaa.... nujtiu cum ii zice, cand iti da popa .... un fel de pajte, da-i altfel pita sau vinu\', cu cana sh cu lingurita si cu prosopu\'.... no stau io la coadaaaaaa..... stratejik pozitionat ultimu\' (al doilea) ca sa vad ce trebe sa fac..... ashaaaa... deci cu dreapta servetzelu sub barbie, zic cum ma cheama, amin......iau o data doau trei, asha, ma jterg NUMAI pe buze... cruce sh plec, ok, inmcep si eu ritualul, shi popu\' se oprejte.... \"da\' tu te-ai.... hritonozamislit?!\".....mah calce-l!: \"de zic:nu! e adevaru\'! e ok religios! dar asta imi ia jervetzelu, nu-mi mai da prescura de aia in forma de pajte.... shi ma vede tata beserika pe mine mah.... shi parca vedeam corul ala ghimpe prelungind la nesfarshiiit....\"cu moooooooooooooaaaaaaaarrrrteeeeeeeaaaaaaa pe moarteeeeeeeeeeeee calcand......\", scrajnind printre masele, sau zic da! iau chestia shi io ca ala dinaintea mea.... totu-i ok.... slujba continua sh.....   no... inca un pacat... \"imi pare rau no... n-am jtiut...\"  Tu ce alegere ai fi facut mo in locu\' meu, hugh?!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(160,326,'Groparu','groparu.ro@gmail.com','http://www.groparu.ro','89.137.115.5','2007-04-13 01:52:37','2007-04-12 23:52:37','Dar... recunosti ca ai loat cuminecatura aia, sau pkita aia cu vin, ca un batlan, intre mAndibla si nas? Si ai icnit cand ai bagat-o la duoden? Z mah! Z MAH! AMU!!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(301,354,'Razvan Antonescu','razvan.antonescu@gmail.com','http://idei-locale.blogspot.com','86.122.71.124','2007-04-28 09:11:10','2007-04-28 07:11:10','Dude, that\'s evil...like it :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.0.11) Gecko/20070321 Firefox/1.5.0.11 Flock/0.7.12','',0,0),(302,354,'Groparu','groparu.ro@gmail.com','http://www.groparu.ro','89.137.112.22','2007-04-28 11:27:12','2007-04-28 09:27:12','@ Denisa: M-o sunat Andrei Crivat, sa imi zica ca musai sa ajung... oare are de gand sa ma demaste public ca fiind ala care lasa chinezoaice gravide?\r\n\r\n@Razvan: Ye, mah... gajica-mea mi-o tinut o teorie foarte alambicata in dimineata aia despre etica trezirii din somn a unei call center operator din Bucuresti, de m-am si simtit exact asa cum sunt: un betiv trist si plin de frustrari legate de transportul in comun. I-am zis ca nu se va mai repeta pana data viitoare.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(303,353,'roxana padure','roxana_padure@yahoo.com','','86.107.113.33','2007-04-28 11:27:16','2007-04-28 09:27:16','Saut Radu!\r\n\r\n  Imi place ce scrii si vreau adresa ta de mail....Trimite-mi-o! Mi-i dor sa vb cu tine....Oare am scris corect gramatical....OAre imi vede cineva mesajul?\r\nSi totusi parca te-am mai citit si in alta viata!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(304,353,'roxana padure','roxana_padure@yahoo.com','','86.107.113.33','2007-04-28 11:28:41','2007-04-28 09:28:41','Salut Radu!\r\n\r\n  Imi place ce scrii si vreau adresa ta de mail....Trimite-mi-o! Mi-i dor sa vb cu tine....Oare am scris corect gramatical....OAre imi vede cineva mesajul?\r\nSi totusi, parca te-am mai citit si in alta viata!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(305,82,'roxana padure','roxana_padure@yahoo.com','','86.107.113.33','2007-04-28 11:51:27','2007-04-28 09:51:27','Totusi eu nu am fost indragostita de Duclos niciodata, mi-a dat 5 la examen....nu-l uit nici cand mor.Asa ca nu ne baga pe toate in aceeasi oala! lol!\r\n  Doamne cine te-a pus sa-l inviti la camin!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(162,326,'sabina','','','81.12.163.178','2007-04-13 08:37:17','2007-04-13 06:37:17','Daca pana acum aveam vreo indoiala, s-a sfarsit cu ele! Declar cu mana pe inima ca NU SE EXISTA altii ca voi doi pe lumea asta!',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1)','',0,0),(163,326,'sajata','a@a.com','','82.77.126.254','2007-04-13 12:27:45','2007-04-13 10:27:45','sabinuca, se egzista, se egzita. crede si nu cerceta!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(164,326,'Groparu','groparu.ro@gmail.com','http://','82.77.126.254','2007-04-13 14:05:17','2007-04-13 12:05:17','Mo: nu e vb de mai tare sau mai moale, mai lung sau mai scurt. Ci EXACT ca noi. Asa ca in afara de ce iese din OZN-ul ala care m-o furat si o zis ca ma va clona, nu SE exista alt Groparu!!!! Si daca SE exista, sa nu-l prind pe la gajica-mea, ca ii rup picioarele.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,2),(166,326,'Fascista','luminitadanciu@yahoo.com','','71.112.159.78','2007-04-14 20:46:01','2007-04-14 18:46:01','Flaviu,\r\nsa te luminez :)\r\n\r\nPariul lui Pascal\r\n\r\nDaca crezi Ã®n Dumnezeu si se dovedeste ca el nu exista,\r\nnu vei fi pierdut nimic, dar daca nu crezi si se dovedeste ca\r\nexista, vei merge Ã®n Iad. Asadar, este iresponsabil sa\r\nfii ateu.\r\n\r\nDe unde Camus sau Jung....',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; Sgrunt|V109|29|S-996046478|dial; snprtz|T05036630770176; .NET CLR 1.1.4322)','',0,0),(422,355,'Groparu','groparu.ro@gmail.com','http://www.groparu.ro','89.137.112.22','2007-04-29 23:55:22','2007-04-29 21:55:22','Sunt flatat! Justice hath spoken... ca de obicei, statuia e legata la ochi, da\' a judecat drept si are si tzatze mari.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(424,356,'Denisa','denisalala@gmail.com','http://www.denisuca.ro/blog','86.123.36.173','2007-04-30 00:44:39','2007-04-29 22:44:39','Sincere felicitÄƒri! :D\r\nIo-s cÄƒzutÄƒ Ã®n cap dacÄƒ te cetesc ÅŸi-mi mai ÅŸi place? Ups...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(168,333,'Denisa','denisalala@gmail.com','http://www.denisuca.ro/blog','86.123.36.173','2007-04-15 01:01:04','2007-04-14 23:01:04','Te-am descoperit pe ClujBlogFest ÅŸi mÄƒ bucur cÄƒ ai fost nominalizat, chiar dacÄƒ la \"Cel mai prost blog\", cÄƒ altfel nu te descopeream, logic.\r\nDe azi, eÅŸti pe <a href=\"http://www.denisuca.ro/blog/index.php/devazut\" rel=\"nofollow\">Panoul de onoare</a>. Bun venit Ã®n readerul meu! :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(169,52,'Denisa','denisalala@gmail.com','http://www.denisuca.ro/blog','86.123.36.173','2007-04-15 01:08:47','2007-04-14 23:08:47','BestialÄƒ poveste! =))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(437,356,'Groparu','groparu.ro@gmail.com','http://www.groparu.ro','89.137.112.22','2007-04-30 21:45:22','2007-04-30 19:45:22','Denisuca, poti cadea in cap si sa-ti placa si sa fie OK, mai ales daca (virgula) ca si mine incredintezi procesul anevoios al gandirii altor organe, cel putin la fel de vitale.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(3819,504,'Emaginatoru','e_magist@yahoo.com','','86.122.12.12','2007-07-04 22:53:10','2007-07-04 20:53:10','Nea Groparnicule, ia explica matale espresia cu privire la rolul femeii:\r\n\"roluâ€™ femeii e la (...) supt barbat\", ca e cu doo taiÅŸe si nu mi clar la ce te referi.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1)','',0,0),(180,333,'Alex','alex@wip.ro','http://www.fenomental.com','86.105.254.172','2007-04-17 12:24:01','2007-04-17 10:24:01','Dar tot nu te lasi, si insisti zilnic la radio chiar si in concediu. :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(3220,483,'baghy','baghy83@lycos.it','http://baghy.wordpress.com/','78.12.5.241','2007-06-15 19:26:36','2007-06-15 17:26:36',':)))))))))))).ce bine ca ai blog',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(3221,481,'baghy','baghy83@lycos.it','http://baghy.wordpress.com/','78.12.5.241','2007-06-15 19:30:48','2007-06-15 17:30:48','nu te cred ca ai 2 vizitatori pe zi',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(187,326,'Fascista','sweetperfum16@yahoo.com','','209.221.168.249','2007-04-17 23:48:42','2007-04-17 21:48:42','Io nu stiu de unde, ca de la seminaru de psihologie nu poate fi ca nu te-am prea vazut.... ma gandesc ca poate oi fi auzit-o prin music pub de la betivii-genii pustii de pe acolo....:)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(188,333,'Fascista','sweetperfum16@yahoo.com','','209.221.168.249','2007-04-17 23:51:08','2007-04-17 21:51:08','Naspa kebabi pe bat.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(3144,478,'baghy','baghy83@lycos.it','http://baghy.wordpress.com/','78.12.6.4','2007-06-14 01:57:55','2007-06-13 23:57:55','nota 10 pentru postul asta.mergea si un triferment',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(3804,504,'Kissu','tot.aia@groparu.ro','http://www.pacurar.net','82.77.126.254','2007-07-03 16:30:35','2007-07-03 14:30:35','Ma Bazsa... am ras de m-am cacat pe mine!... Hai ca esti tare!! ;)))))) Da-le-n masa de usergaiduri si fa-te... fa-te... asa cum esti! ;)\r\n\r\nSa traiesti!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1)','',0,0),(3887,504,'De aialalta','pagin@yahoo.com','http://de-aia.blogspot.com','193.239.252.199','2007-07-08 18:29:07','2007-07-08 16:29:07','lasa ma ca ii bine. nemtii zic prost. putza putza suna bine ;)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(3890,505,'Sorinelu\'','sorinelm@gmail.com','','210.150.186.60','2007-07-09 04:48:26','2007-07-09 02:48:26','mnoah, iti doresc sa te frigi la soare ca un mic, asa sfaraind... si sa surfezi pe valuri de bere cu spuma de 2 dejete. hai concediu placut si sa-ti retraiesti tineretzea la maxim.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727)','',0,0),(3891,504,'Sorinelu\'','sorinelm@gmail.com','','210.150.186.60','2007-07-09 04:53:39','2007-07-09 02:53:39','ye ma gropare... da la care tenta sexoala faci aluzie? :D',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727)','',0,0),(3893,423,'serea','serealucianyahoocom','','217.200.200.54','2007-07-09 21:47:31','2007-07-09 19:47:31','ar fi ceva foarte .nasol.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Media Center PC 3.0; .NET CLR 1.0.3705; .NET CLR 1.1.4322)','',0,0),(3894,423,'serealucian','','','217.200.200.54','2007-07-09 21:50:04','2007-07-09 19:50:04','ce ati face daca nevasta ta ,o prinzi cu altu .ai omorao .sati muldaresti mainele de sange.sau ai lasao .cu divort.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Media Center PC 3.0; .NET CLR 1.0.3705; .NET CLR 1.1.4322)','',0,0),(3800,505,'katmai','katmai@keptprivate.com','http://www.512kbps.com','195.212.29.179','2007-07-03 10:57:15','2007-07-03 08:57:15','ui uill miss iu beibi',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7 (CK-IBM)','',0,0),(3801,505,'Adi Calarasu','acalarasu@gmail.com','http://adriancalarasu.wordpress.com','82.76.75.99','2007-07-03 11:25:16','2007-07-03 09:25:16','haidi breeee, tocmai vroiam sa te provoc la o leapsa, ca-i genu\' matale\r\n:(',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(3127,476,'sb_p','','','192.129.3.14','2007-06-13 17:11:48','2007-06-13 15:11:48','23 si 24. Foarte de acord. :)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.0.3705; .NET CLR 1.1.4322; Media Center PC 4.0; .NET CLR 2.0.50727)','',0,0),(3128,474,'katmai','katmai@keptprivate.com','http://www.512kbps.com','195.212.29.171','2007-06-13 17:52:59','2007-06-13 15:52:59','yahu futal .... moama si eu ma chinuiam amp...lea cu gmail',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7 (CK-IBM)','',0,0),(198,326,'Greuceanu','fm77roen@yahoo.com','','195.149.72.124','2007-04-19 02:25:27','2007-04-19 00:25:27','Asha-i ca ma deghizez bine?!\r\n\r\nEu te-am vazut! de fapt ti-am shi zambit..... tu nu m-ai prea vazut.... sau poate te ajteptam in pub...',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(199,333,'Marius','pop.marius@gmail.com','http://lityx.blogspot.com','86.35.157.42','2007-04-19 09:29:10','2007-04-19 07:29:10','Eu unul am votat de zor (adica o singura data, da\' grabit) la cel mai prost blog, ca intelesei ca asta ar fi obiectivul... Desi sincer, cred ca locul e la cel mai bun blog. Nu-i (prea) tarziu, desigur.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(3121,477,'oedip','oedip74@gmail.com','http://oedip.blogspot.com','89.137.104.170','2007-06-13 12:25:05','2007-06-13 10:25:05','api tuh sabina ce savoare mai mare vrei? :DDD',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(3123,477,'sabina','','','81.12.163.178','2007-06-13 13:38:10','2007-06-13 11:38:10','pe cea primara, oiedipule',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1)','',0,0),(3597,503,'Andrei Crivat','andrei@andreicrivat.ro','http://www.andreicrivat.ro','83.103.128.106','2007-06-27 09:17:13','2007-06-27 07:17:13','cum, magare, da\' de mesajele telefonice repetate pana la obsesie, de incurajarile mess-ianice, nu spui ?\r\nSi apropo, felicitari, ai scris cea mai lunga fraza pe care am citit-o eu (pana la capat) in ultimii 2 ani, 3 luni, 15 zile si doo ore',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727)','',0,0),(3110,476,'Razvan Antonescu','razvan.antonescu@gmail.com','http://idei-locale.blogspot.com','81.196.150.96','2007-06-13 11:38:50','2007-06-13 09:38:50','\"Ce carte nu ai citi niciodata?\r\nProfessional Search Engine Optimization with PHP: A Developerâ€™s Guide to SEO.\"\r\n\r\nDie bitch. Is an interesting book :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.0; en-US; rv:1.8.1.4) Gecko/20070607 Firefox/2.0.0.4 Flock/0.8.99','',0,0),(3111,476,'Razvan Antonescu','razvan.antonescu@gmail.com','http://idei-locale.blogspot.com','81.196.150.96','2007-06-13 11:47:15','2007-06-13 09:47:15','Ah da si Sven Hassel rulz :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.0; en-US; rv:1.8.1.4) Gecko/20070607 Firefox/2.0.0.4 Flock/0.8.99','',0,0),(3112,477,'sabina','','','81.12.163.178','2007-06-13 11:55:59','2007-06-13 09:55:59',':)) haios!!! numa\' ca mie zilele astea imi TREBUIE savoarea vulgaritatii injuraturii, altfel... hmmm...',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1)','',0,0),(3113,477,'oedip','oedip74@gmail.com','http://oedip.blogspot.com','89.137.104.170','2007-06-13 11:59:00','2007-06-13 09:59:00','pt asta trebe sa platesti... coirait... sa-ti trimit ibanul?\r\n:DD',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(3608,503,'IepurasulAtomic','praetorian21uk@yahoo.com','','192.100.130.8','2007-06-27 12:18:58','2007-06-27 10:18:58','Da Gropare, ai grija ce-ti doresti, Doamne Fereste sa nu ti se intample :)). Nu de alta, da\' mori dracu\' asfixiat. O fi frumos, nu spun ca nu, da\' tot mort ramai. Mai bine in orgasm la nush cat peste 100 de ani cu fo bunoaca de pana in 25, cum ziceai alta data ;). Bine-ai revenit!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(3607,503,'sabina','','','81.12.163.178','2007-06-27 12:15:19','2007-06-27 10:15:19','eu zic sa ai grija ce-ti doresti',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1)','',0,0),(3605,503,'Mary','zeitza_venus@yahoo.com','http://360.yahoo.com/zeitza_venus','193.22.173.10','2007-06-27 11:14:39','2007-06-27 09:14:39','mai gropare.. dak n\'ai crapat inca, eu zic ca mai ai sanse sa suprvietuiesti (d)racelii ce\'ti chinuie minte si\'ti innegureaza simtirea gnostica, si\'ti trezeste fantezii (ind)racite, :p',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(3602,502,'Mary','zeitza_venus@yahoo.com','http://360.yahoo.com/zeitza_venus','193.22.173.10','2007-06-27 11:08:17','2007-06-27 09:08:17','..eu zic sa te\'apuci sa\'ti sapi groapa.. cat inca mai poti... ca nu se stie dupa aia, :p',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(984,383,'katmai','katmai@keptprivate.com','http://www.512kbps.com','195.212.29.163','2007-05-10 18:04:03','2007-05-10 16:04:03','baie cu vegeta ???? what the fuck dude? ai facut supa ? :)))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7 (CK-IBM)','',0,0),(985,388,'mea','totmea@yahoo.com','','86.106.49.143','2007-05-10 18:10:41','2007-05-10 16:10:41','Hi,hi. Mi-a adus aminte de bancul cu Cum sa vorbeste nemteasca?.- Tot ca romana numa\' mai rar.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1)','',0,0),(3085,356,'andrei','alexei','','193.231.18.10','2007-06-13 00:46:05','2007-06-12 22:46:05','esti un bosketar',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; SIMBAR={7242A12F-1FBD-4d27-8936-C02B6C387BD0})','',0,0),(1914,411,'Greuceanu','fm77roen@yahoo.com','','195.149.72.124','2007-05-22 22:28:24','2007-05-22 20:28:24','MO!\r\n\r\nToo much love will kill u! cei ce au urechi de auzit... sa auda... etc.... \r\n\r\n faptul ca vine timpul in care doo zile de Coltz de rai...... ioi, de unde a disparut intristarea si suspinarea, in loc cu verdeatza fara nici o creatza, fara blonda sau bruneta, fara proiecte, fara impliniri sau ne-impliniri, fara limita, fara educatie, fara  bun simtz, fara frica ecsact ce zum zic aia jmekeri... FREE FOR ALL!!!!!!!!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(1201,389,'Sorinelu\'','sorinelm@gmail.com','','82.77.126.35','2007-05-14 11:25:55','2007-05-14 09:25:55','no, da\' mare diaria, nici n-ai apucat sa-ti dai jos nadragii...',0,'1','Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.0.11) Gecko/20070327 Ubuntu/dapper-security Firefox/1.5.0.11','',0,0),(2707,465,'cR','radu.guest@gmail.com','http://review.haipa.ro','82.137.53.82','2007-06-05 18:04:16','2007-06-05 16:04:16','Asa ii sta bine unui gropar, sa mearga la nunta in trening si pantofi.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(208,330,'varzastricata','tudor.maris@gmail.com','http://rottencabbage.ablog.ro','124.181.71.223','2007-04-20 13:32:06','2007-04-20 11:32:06','daca punem si servicii de \"ascultat motive nesex\" si \"scarpinat subrat\" intru si io. iti dai seama, multinationala......',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(3588,503,'oedip','oedip74@gmail.com','http://oedip.blogspot.com','89.137.99.163','2007-06-27 03:38:50','2007-06-27 01:38:50','Auzi mah! Cum n-ai tu 8 vizitatori?! Adica io vin sa te incurajez si tu-mi dizolvi indivisualul in general? Cata nesimtire!! :DDDDD\r\nDar voi pune asta pe seama boalei!\r\nNa, ca sa vezi ca suntem persoane diferite, toti cei care o sa intre pe aceasta sectiune de comment sa-i ureze lui raducu mamii \"tzatzobalaceala la mare dar numa pe langa celulitoase\"!!! :DDDDDD\r\n\r\nps.\r\nCa sa stie toti de te citesc, aia care sunt numa unu, si anume tu, de cand nu mai poate bee, groparu ii vede pe cei multi ca unu, si pe ala unu ca multi... are o problema... se numeste H2O-ita, ca nu mai putu bee si o trebuit sa-si ia pilulele cu apa!!! :PP\r\n\r\nhihihihihihihihihi\r\nhhahahahahaha',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(3212,480,'ss','criss_team@yahoo.com','','81.196.150.198','2007-06-15 11:41:45','2007-06-15 09:41:45','inche n-ai murit pt ca inche n-ai trait cat dinozaurii. da probleme cu inima ai. poti sa scrii intr-un blog urmator despre ele.\r\n\r\ncat despre dinozauri...se pare ca az is laitmotivu zilei: \r\nThe night sky looked very different when the dinosaurs roamed the earth - lots of light we now see as stars would not have yet reached earth and constellations would not have aligned.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7','',0,0),(3216,480,'Groparu','groparu.ro@gmail.com','http://www.groparu.ro','82.77.126.254','2007-06-15 12:42:01','2007-06-15 10:42:01','Ba nu, ca pe inima am berarit-o asar\', suficent kiar, dupa cum se poate vedea in ce scrie sub \"Nascut din spermatozoizi campioni\"',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(3217,482,'oedip','oedip74@gmail.com','http://oedip.blogspot.com','89.137.104.170','2007-06-15 14:06:22','2007-06-15 12:06:22','I\'m the man!!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(969,387,'marzazel','mariusrott@yahoo.com','','81.12.163.178','2007-05-10 08:09:45','2007-05-10 06:09:45','avem voie slogane in alte limbi romanice? ca vreau sa ii scriu si eu la Claudia Schiffer expirat asta (pentru cine nu stie, Taricelu fuse model), ca cica stie franceza: sii-trroo-ieeeeeen, repetee silvuple: sii-trroo-ieeeeeen, la tachse de inmatriculeer. \r\n\r\nDeci, ca sa nu imi uit vorba, ca azi e 10 mai: La republique est mort, Vive le roi !',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.2) Gecko/20070219 Firefox/2.0.0.2','',0,0),(3953,423,'Groparu','groparu.ro@gmail.com','http://','86.105.72.125','2007-07-15 20:24:48','2007-07-15 18:24:48','Io in primu rand as incerca sa invatz sa scriu bine romaneste si apoi as anihila-o cu ortografia!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,2),(221,338,'Marius','pop.marius@gmail.com','http://lityx.blogspot.com','86.35.157.42','2007-04-23 12:43:54','2007-04-23 10:43:54','Apai no, daca are 3 si mi le face de-a gata l-as pune in ordine: sa faca una bucata slanina ce nu se topeste niciodata si una bucata foc ce topeste tot. Ultima ar fi sa stea cu painea la picurat untura de pa slana pana se topeste de tot slana.\r\nNa, fir-ar al dracului de pestalan, ca l-am rezolvat. Deci pestisoru cu pricina va suna ocupat. Mirific.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(225,328,'Fascista','luminitadanciu@yahoo.com','','209.221.168.249','2007-04-23 20:24:13','2007-04-23 18:24:13','Discoteca studentelor! Congregatia virginelor! PARTIDUL LEZBIENELOR!!! Ma votati?\r\n\r\nAm sa dau cate o chinezoaica la fiecare! \r\n\r\nTe-am votat ma. Cine nu vrea o chinezoaica si o virgina? O sa ma imbogatesc de pe harnicia lor. Domestic servitude anyone? Macar ca daca ma gandesc mai bine tot mai bine l-as vrea pe Bratt Pitt cu Angelica lui sau fara.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; InfoPath.1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(3783,82,'Florina','florina_hica@yahoo.com','','86.127.77.37','2007-07-01 23:20:33','2007-07-01 21:20:33','Foarte misto! Desi am febra musculara la... hmm... tot, am facut maretul efort de a rade si chiar a rade pe bune. Sincer, imi face o placere mai mare sa stau sa-ti citesc chestiunile decat sa citesc Pirandello... :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(901,376,'catalin','solo@xsolo.biz','http://xsolo.biz','201.231.176.35','2007-05-08 20:25:21','2007-05-08 18:25:21','\"VA PLAC STRAINII!!!\" asta e valabila in toata lumea, in orice tara ai merge, ca strain ai o imagine relativ exotica. Poate mai putin ca roman in europa de vest, desi nu se stie niciodata. In plus la telefonul mobil, vine si compul si orice scula ;-) mai mult sau mai putin complicata etc.....',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(903,376,'Groparu','groparu.ro@gmail.com','http://www.groparu.ro','89.137.112.22','2007-05-08 20:32:35','2007-05-08 18:32:35','True! Io ma mir ca nu ni se cer sfaturi de cum sa le facem sa mearga vibratoru :|',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(3014,473,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.112.22','2007-06-11 17:24:54','2007-06-11 15:24:54','Da, ba Crivatz, da recunosti ca ai falsificat Gugal ca sa dea numa\' rezultate pro-cumparat vin?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(3013,474,'baghy','baghy83@lycos.it','http://baghy.wordpress.com/','78.12.15.10','2007-06-11 16:17:20','2007-06-11 14:17:20','ai dreptate.fiecare cu p.... masii',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(2891,471,'Andrei Crivat','andrei@andreicrivat.ro','http://www.andreicrivat.ro','89.137.98.13','2007-06-08 13:31:58','2007-06-08 11:31:58','ce poveste palpitanta, nemernice... ca un film bun, ca o carte interesanta. Mno, io ma bucur ca n-a murit Ana, sa-i dea Dumnezeu sanatate si sa fie fericita, si Calin la fel.\r\n\r\nDa\' pana la urma, Ana era insarcinata au ba ? si ce s-a intamplat cu copilu\' ?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727)','',0,0),(2743,465,'macabroo','raduccc@yahoo.com','http://rezistenta.blogspot.com','80.96.196.2','2007-06-06 09:01:17','2007-06-06 07:01:17','Dupa ce bei horinca nu faci pipi. Ti in tine ca altfel e blasfemie.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(2745,462,'Shadow','ahimi2001@yahoo.com','','193.231.20.2','2007-06-06 09:50:57','2007-06-06 07:50:57','IO zic ma grupule ca daca pe tine te pun in borhot si te distileaza dupa o sa avem de beut vinars.... la ce rezerva de jin ai prin ficatzii aia greu incercatzi:P',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(2746,462,'Shadow','ahimi2001@yahoo.com','','193.231.20.2','2007-06-06 09:51:15','2007-06-06 07:51:15','scuze... gropule',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(2894,471,'baghy','baghy83@lycos.it','http://baghy.wordpress.com/','78.12.15.10','2007-06-08 16:04:52','2007-06-08 14:04:52','eu vreau filmul cand ai cumparat tu un kil de lapte si te-ai filmat :))))',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(2895,472,'Andreea MKT','supergirgir@yahoo.com','http://marlahermina.deviantart.com/gallery/','82.77.126.254','2007-06-08 16:31:46','2007-06-08 14:31:46','carcalac=ceva mare.\r\n\r\nchichiric=ceva mic.\r\n\r\nzgubilitic=nebun.\r\n\r\nticsit=dus cu sorcova.\r\n\r\nbambilic=nu stiu ce inseamna.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(2897,472,'oedip','oedip74@gmail.com','http://oedip.blogspot.com/','89.137.104.170','2007-06-08 16:39:44','2007-06-08 14:39:44','gogele - io stiu ca la astea le zice tÄƒrzÄƒnei\r\n\r\niar zgubilitic - ÅŸtiu cÄƒ Ã®nseamnÄƒ slab, foarte firav, slabÄƒnog ÅŸi mic, insignifiant (sau mai frumos - insignifiabil)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(2898,472,'tzo','','','82.77.126.254','2007-06-08 17:08:27','2007-06-08 15:08:27','ba gropi.\r\no sugestie : scrie romaneste, fara kk si shsh si tiganisme.\r\nmerci\r\nesti un domn\r\ndaca pui si anunturile alea...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12','',0,0),(2899,471,'IepurasulAtomic','praetorian21uk@yahoo.com','','192.100.130.8','2007-06-08 17:24:13','2007-06-08 15:24:13','Ma gandeam io ca nu poate sa fie Groparu\' atata de insensibil incat sa vorbeasca asha lesne de moartea saracei fete :). Asha m-am bucurat la final ca-i bine fata (mai ales ca-i si ne-insarcinata, ca asta era mai grav), mai ceva ca un film de Lemnu\' Sfant(aka Hollywood). Da\' oricum, privind partea buna a lucrurilor, ma gandeam ca de e asha de insensibil precum pare, atunci clar el tre\' sa-mi tina \"discursu\' \" la inmormantare, ca io vreau sa rada lumea, nu sa planga de doru\' meu(ca nu-mi plac oamenii mincinosi, stiu io sigur ca de fapt s-ar bucura de n-as mai fi :). \r\n\r\nHai, sa va iubiti ca iepurii! Gropare, spune-i lu\' Calin sa ajute fata sa se insarcineze, sau macar s-o pacaleasca purtand prezervativ(ca cica in cazu\' sarcinii, incercarea ii mai placuta decat reusita :D)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(944,381,'varzastricata','tudor.maris@gmail.com','http://rottencabbage.ablog.ro','58.165.33.71','2007-05-09 10:16:44','2007-05-09 08:16:44','No pai stai linistit ca si de tine zicem de rau cand te duci dupa colt :D',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(947,381,'katmai','katmai@keptprivate.com','http://www.512kbps.com','195.212.29.179','2007-05-09 11:59:40','2007-05-09 09:59:40','un lucru ar fi tare ... atunci cand dai coltu sa continui sa bloggaresti ... maam ce cool ar fi ...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.8) Gecko/20050511 Firefox/1.0.4 (CK-IBM)','',0,0),(948,381,'admin','groparu_ro@yahoo.com','http://','89.137.112.22','2007-05-09 12:12:39','2007-05-09 10:12:39','=))\r\n\r\nSunt Groparu Catalin Radu Lemn Tanase, Andreea, se pare ca am murit si ma aflu in partea romaneasca a iadului... aud? Nu sunt in iad, mi se sopteste, ma aflu in Romania anului 2007...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,1),(951,383,'sabina','','','81.12.163.178','2007-05-09 14:48:32','2007-05-09 12:48:32','un lighean plin??? bleeeeaaaaak... \r\nimi pare rau de tine. hai, fa-te bine!!!',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1)','',0,0),(952,381,'sageata2002','','','82.77.126.254','2007-05-09 15:01:51','2007-05-09 13:01:51','io m-am kkt pe mine sa citesc scrisorile alea imaginare. dejaba. da\' aia nu inseamna ca mortu\' nu era erudit. era. erudit de stanga. in care stanga, pozau si comunistii, care isi ziceau de fapt socialisti. got the point?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(953,376,'catalin','solo@xsolo.biz','http://xsolo.biz','201.231.176.35','2007-05-09 15:02:13','2007-05-09 13:02:13','Kelly Bundy la concurs tv si avea un stick in mina pe care trebuia sa apese insa ea il freca :D si se mira de ce nu functioneza.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(955,383,'mea','totmea@yahoo.com','','86.106.49.143','2007-05-09 16:47:12','2007-05-09 14:47:12','Oooooo. Saracutul! Agresat cand ti-e mai greu. Raceala trece... Caleste-te.\r\nSi Vegeta nu-i buna. Are E-uri.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1)','',0,0),(957,386,'Gez','geza@dvis.info','http://groller.info/geza','89.137.114.63','2007-05-09 17:37:36','2007-05-09 15:37:36','Imi fac poster :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(958,373,'Gez','geza@dvis.info','http://groller.info/geza','89.137.114.63','2007-05-09 17:50:06','2007-05-09 15:50:06','Da-i in pula bre` ca-s niste gushteri si jumate :) \r\n\r\nThank god ca am bicicleta si ma beshesc pe ei de controlori din mers :)\r\n\r\nDa fii atent ce tzughi bugi is unii... e unu asa mai molau, 2 metrii, fatza de killer, ala ii pasionat de mica-mare ... si cand lucram in nera era abonat acolo.  Si-o investit ala banii acolo ... zilnic. Si cand ramanea fara, mai avea broderu` (ca totdeauna-s 2) si ii zicea hai sa mai dam o tura ca poate prindem pe careva... si dupa o ora erau inapoi cu bani de aparate in nera :)\r\n\r\nSi alta faza e ca ar trebui organizate neste flagrante, ca sa vezi ce futalai is astia, \"iti iau buletinu, si ne intalnim la mama dracu la ora 4 sa-mi dai XX RON si iti iei buletinu inapoi\" ... \r\n\r\nO sa le si scriu la baieti pe site-ul RATUC ca eu m-am saturat de dat shpaga la controlori, si ca de fiecare data tre` sa le dau lor banii de amenda si sa-i mai verifice sa mai dea si amenzi :)) \r\n\r\nSa vezi ce futai iau aia apoi =))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(2636,461,'zgura','vine@vine.ro','','193.230.205.140','2007-06-03 12:48:01','2007-06-03 10:48:01','Mei, d-apai credeam ca blogu asta e pentru omeni dejtepti asa ca noi doi impreuna si cu mine amandoi, ce draku? Pana cand? Deci astia cu cont pe hi5 si etc cum au ajuns aici? Cine nu-i in stare sa traiasca =&gt; sa moara sau sa intre in coma (da nu pe banii mei).',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(882,379,'Groparu','groparu.ro@gmail.com','http://www.groparu.ro','82.77.126.254','2007-05-08 15:57:04','2007-05-08 13:57:04','=)) Corec, da\' vinu roshu nu mai ajunge pana-n ficatzei, sireacu! Ca il haleshte pe tot stim-noi-ce-alt-organ, si nu vorbesc de organ d-ala care taie amenzi!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(2905,472,'baghy','baghy83@lycos.it','http://baghy.wordpress.com/','78.12.15.10','2007-06-08 20:12:56','2007-06-08 18:12:56','esti sigur ca doar cu foarfeca?cu flama oxiacetilenica nu merge?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(2908,471,'Andre MKT','','','86.106.55.69','2007-06-08 21:11:41','2007-06-08 19:11:41','duamne ma ce frica mi-o fost',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(2909,471,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.112.22','2007-06-08 21:24:08','2007-06-08 19:24:08','@ Ioi, ba Iepurila... da\' intre timp sh Calin s-o insurat, sh daca ii zic asha ceva ii taie nevasta-sa mandretze de putzulica!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(251,346,'mea','totmea@yahoo.com','','86.35.232.96','2007-04-26 13:17:39','2007-04-26 11:17:39','uuaaaaauuuuuu!!!!! Parca-ti si vad copiii!\r\nMultamesc pt. delectarea ce mi-o pricinuiesti exprimindu-te pe aici prin blogul tau.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(252,346,'Groparu','groparu.ro@gmail.com','http://www.groparu.ro','82.77.126.254','2007-04-26 14:08:12','2007-04-26 12:08:12','Mersi pentru delectarea pe care mi-o iscati, mai ales cand vad ca mai is si alti cetitori, nu doar bunica-mea si nepotu-mio!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(253,349,'Marius','pop.marius@gmail.com','http://lityx.blogspot.com','86.35.157.42','2007-04-26 14:50:29','2007-04-26 12:50:29','Poti sa-l abonezi si la blogul meu. Asta le va intrece pe toate.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(254,346,'Marius','pop.marius@gmail.com','http://lityx.blogspot.com','86.35.157.42','2007-04-26 14:58:17','2007-04-26 12:58:17','Apropo, nu nepotu\' scrie blogu\'?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(2912,471,'IepurasulAtomic','praetorian21uk@yahoo.com','','62.217.245.97','2007-06-08 21:47:29','2007-06-08 19:47:29','Zici tu ceva...acuma mi-am amintit ca baiatu\' asta are scama groasa, din aia de nici un aspirator n-o trage...da\' mai conteaza? Imagineaza-ti tu ma...dragostea vietii tale, s-o crezi moarta pe ANA si pe urma sa afli ca de fapt ii verisoara ai\' batrana de era clar pe lista de RIP-uri din start, nu ti-ai baga organu\' macar un pic (daca nu ai inca plozi in actuala casatorie...ca daca vine vb de plozi, io nu mai cred in a-ti insela nevasta...stiu, stupid me :))!!!), carevasazica, nu ti-ai baga organu\' in fosta ta dragoste...daca mai ii dragoste..bineinteles. Io cre\' ca da...nu stiu altii cum is. No, io ma duc in Obsession, ne videm pe acolo? ;) Pace p\'afara! \r\n\r\nPeSeu\': Da\' nevasta-sa tre\' sa afle? ;))',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(3069,474,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.112.22','2007-06-12 15:56:59','2007-06-12 13:56:59','Da\' ma, nu ti-l pot da, ca mi-i propitate, da\' ia d-aci: groparu_ro (a) yahoo.com.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(3063,474,'katmai','katmai@keptprivate.com','http://www.512kbps.com','195.212.29.179','2007-06-12 15:21:15','2007-06-12 13:21:15','baaa. da un mail ca nu reusesc sa iti dau treaba care am facut-o',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7 (CK-IBM)','',0,0),(2983,472,'Andreea MKT','','','86.122.68.169','2007-06-10 10:02:47','2007-06-10 08:02:47','riki kokosh=ungurism. cocos de talie pitica.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(3060,474,'katmai','katmai@keptprivate.com','http://www.512kbps.com','195.212.29.179','2007-06-12 14:06:55','2007-06-12 12:06:55','ai ceva pe mail. sper sa iti placa :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7 (CK-IBM)','',0,0),(3059,474,'katmai','katmai@keptprivate.com','http://www.512kbps.com','195.212.29.163','2007-06-12 13:59:48','2007-06-12 11:59:48','politica sucks, dar ... din pacate trebe ... sau nu ?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7 (CK-IBM)','',0,0),(3001,67,'ulrich','christian23bj','','89.38.252.172','2007-06-10 23:42:50','2007-06-10 21:42:50','ce pot sa zic.. \'deosebit\' cred ca e cuvantul! chiar m-ai facut sa rad! talentat baiet, ce pot sa zic.. keep up the good work ;)',0,'1','Opera/9.20 (Windows NT 5.1; U; en)','',0,0),(3003,473,'Andrei Crivat','andrei@andreicrivat.ro','http://www.andreicrivat.ro','89.137.98.13','2007-06-11 06:16:18','2007-06-11 04:16:18','dincolo de faptu\' ca esti inexact... pentru ca esti inexact, iti spui io ca esti, deci sa vedem:\r\n1) deci io n-am asteptat deloc sa te parfumezi, dat fiind ca, vorba aia, ma parfumam cot la cot cu tine, cam din aceleasi 14 doze de parfum, daca nu ma-nsel, parerea mea... \r\n2) deci pariu\' asta l-as fi pus si vorba aia, neparfumat, dat fiind ca asa o fu, si nu cum spui tu: base-iz-cool n-a vorbit veci pururi in Duma de Stat, cum n-a vorbit niciodata vreun presedinte roman acolo (zic de dupa opsnoa, ca de ceasca nu-s sigur)\r\n3) deci sticla aia nici macar nu-i 150 de euro, fraere, care-i numa\' un 80 de euro, cu toate taxele incluse, si nici nu-i firma base-iz-cool-ului, dat fiind ca alea numa\' zama de plosna bea\r\n\r\nce se intampla, asta-i parerea mea.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727)','',0,0),(848,376,'MÃ¢tza','ana.man.fox@gmail.com','','81.180.173.61','2007-05-08 08:43:45','2007-05-08 06:43:45','bruna ai?... :-?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.0.11) Gecko/20070312 Firefox/1.5.0.11','',0,0),(3005,472,'adi','adyrotaru@yahoo.com','','86.34.227.117','2007-06-11 09:32:07','2007-06-11 07:32:07','tiribombina = maÅŸinÄƒ de flacÅŸurat cichindrele',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(3006,473,'Andreea MKT','supergirgir@yahoo.com','http://marlahermina.deviantart.com/gallery/','82.77.126.254','2007-06-11 09:34:45','2007-06-11 07:34:45','zicea fizz: azi vom vorbi despre bani: cum se fac ei, cine ii fac. ii facem noi, baietii destepti.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(3007,471,'adi','adyrotaru@yahoo.com','','86.34.227.117','2007-06-11 10:28:56','2007-06-11 08:28:56','Pooola me\r\nAlta melodrama, fara sÃ¢nge si lacrimi, numai un pic de suparare ca sa poti zÃ¢mbi la final. YEAK!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(3008,472,'Groparu','groparu.ro@gmail.com','http://www.groparu.ro','82.77.126.254','2007-06-11 10:44:40','2007-06-11 08:44:40','...si sa nu uitam un all time classic: manioc = planta din care se face tapioca.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(855,378,'Marius','pop.marius@gmail.com','http://lityx.blogspot.com','86.35.157.42','2007-05-08 09:37:20','2007-05-08 07:37:20',':))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(3009,473,'baghy','baghy83@lycos.it','http://baghy.wordpress.com/','78.12.15.10','2007-06-11 11:03:07','2007-06-11 09:03:07','multumesc pentru pont.acum ma duc sa-i fac',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(3010,469,'katmai','katmai@keptprivate.com','http://www.512kbps.com','195.212.29.171','2007-06-11 14:14:53','2007-06-11 12:14:53','sa ti se tripleze salaru`... fara sa meriti.. doamne ajuta :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7 (CK-IBM)','',0,0),(3011,472,'sabina','','','81.12.163.178','2007-06-11 16:11:27','2007-06-11 14:11:27','profa mea de romana din generala avea un liliputi (=cocos de talie mica) pe care-l botezase Gadafi',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1)','',0,0),(3012,474,'Razvan Antonescu','razvan.antonescu@gmail.com','http://idei-locale.blogspot.com','81.196.150.96','2007-06-11 16:13:54','2007-06-11 14:13:54','Mda...la fel de oripilata era lumea pin 2000 cand ziceam ca m-am bagat in PD ca e partid de curve. Ce nu stiam atunci ca de curve proaste nu de lux ca subsemnatu',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.0; en-US; rv:1.8.1.4) Gecko/20070607 Firefox/2.0.0.4 Flock/0.8.99','',0,0),(2953,472,'bicplayer','bic_player@yahoo.com','','86.125.169.80','2007-06-09 14:33:07','2007-06-09 12:33:07','deci puteam sa traiesc si fara sa stiu astea.... :-&amp; defapt cred k mi-a scurtat viatza mai mult k un pachet d tzigari',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(3539,502,'IepurasulAtomic','praetorian21uk@yahoo.com','','192.100.130.8','2007-06-26 11:29:06','2007-06-26 09:29:06','Gropare, zic si io aproape cum zice \"katmai\", numa\' ca io spun \"cum\" bec fast :D....he he. Daca tu te imbolnavesti si nu mai scrii, si io ma imbolnavesc, ca am atata treaba de nu-mi vad capu\' si tu-mi mai descretzeai fruncea de dimineata, sau la amiaza, sau cand apucam sa te citesc. Asha, \"lumea fara tine e pustiu\".  Facem un targ, da-mi mie raceala si tu pune-te de scrie in continuare :). Hai, sa te faci bine...',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(870,379,'ss','criss_team@yahoo.com','','81.196.150.198','2007-05-08 12:33:27','2007-05-08 10:33:27','apai parerea mea care este i ca alcoolu micsoreaza creieru dom\'ne, da numa la cei care are (adica creier).\r\nadevaru adevarat i ca in prezenta lu nea alcoolu creieru chiar devine artist top class, da esplicatia nu-i ca din cauza ca se mareste.. esplicatia se afla in \'teoria avantajului consumului de bere (sau vodca...sau tzuica...etc etc)\' si pe care o reproduc pt cei care nu o aplica inca:\r\n\r\n  \"O turma de bivoli se poate deplasa atat de repede ca si cel mai lent bivol din turma. Cand turma este vinata, de obicei este ucis cel mai slab si mai din urma bivol. Aceasta selectie naturala este benefica turmei, pentru ca astfel, prin eliminarea celor mai slabi membri, se imbunatatesc viteza si sanatatea turmei.\r\n\r\nCam in acelasi mod, creierul uman poate opera doar atat de repede cat ii permite cea mai slaba celula cerebrala. Consumul excesiv de alcool, dupa cum se stie, omoara celulele creierului, dar in mod normal prima data omoara celulele cele mai slabe. In acest mod, consumul regulat de bere distruge cele mai slabe celule cerebrale, facand creierul o masina mult mai rapida si mai eficienta. Acesta este si motivul pentru care intotdeauna te simti mai destept dupa cateva beri..\"\r\n\r\nPS- alcoolul dauneaza grav sanatatii*\r\n\r\n*sponsored by CNA',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7','',0,0),(872,379,'Groparu','groparu.ro@gmail.com','http://www.groparu.ro','82.77.126.254','2007-05-08 13:46:06','2007-05-08 11:46:06','CNA, nu ne sponsorizezi sh noo niscai berule? Plsssss',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(2810,466,'cetitoare','totmea@yahoo.com','','86.35.232.96','2007-06-07 10:48:00','2007-06-07 08:48:00','dupa .14 te-ai apucat de lucru la tastatura ta?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(2727,35,'baghy','baghy83@lycos.it','http://baghy.wordpress.com/','78.12.7.161','2007-06-06 01:12:00','2007-06-05 23:12:00','e ora 1.11 si am terminat de citti postul asta.foarte.... nu am adjctive',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(878,379,'marzazel','mariusrott@yahoo.com','','81.12.163.178','2007-05-08 15:49:44','2007-05-08 13:49:44','gropare, dar io stiam ca oricum nu folosim 100% din creiri, deci, chiar in cazul in care este, exista, se afla asa o schimbare, numita redimensionare este chiar binevenita: se numeste optimizare. ramane mai mult sange pentru altele organele, stie ele fetele... adica ficat, ca acolo se strange alcoalele.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.2) Gecko/20070219 Firefox/2.0.0.2','',0,0),(256,346,'Groparu','groparu.ro@gmail.com','http://www.groparu.ro','89.137.112.22','2007-04-26 18:37:04','2007-04-26 16:37:04','Well... nu, ca nepotu\' e ocupat acuma sa redacteze \"Invatati sanscrita fara profesor\", editia a doua, revizuita si adaugita.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(257,349,'Raz','razvar@gmail.com','http://raz-soft.com','89.123.26.235','2007-04-26 21:23:33','2007-04-26 19:23:33','Bine ai facut! :lol:',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 ImageShackToolbar/3.0.4 Firefox/2.0.0.3','',0,0),(2651,461,'Andre MKT','','','86.106.55.69','2007-06-03 18:29:58','2007-06-03 16:29:58','mah, \'ai projti suntetz!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(2878,461,'sageata2002','a@a.com','','82.77.126.254','2007-06-08 09:30:46','2007-06-08 07:30:46','all: am scris commentul asta in aceeasi linie agresiva adoptata de multi de aici. se pare ca ni se pare normal sa injuram, da\' sa fim injurati...\r\npentru aia mica: fato, io macar incerc ca un prost sa atrag atentia ca ceva nu e in regula. si nu de 1000 de ori, ci de un milion. lasa-ma sa fiu don quijote daca atata ma duce minte. si da, cat depinde de mine fac sa fie ceva mai bine.\r\nsajata dixit',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(1829,423,'cetitoare','totmea@yahoo.com','','86.106.49.143','2007-05-21 21:25:18','2007-05-21 19:25:18','AI DREPTATE Gropare! sau Groparule?....nuuuu Gropare-i mai fain.\r\nNu stiu alte esemple ca nu urmaresc curvele politice. dar sint convinsa ca mai sint de-astia. artistii de balacaresc, sportivii se ciomagesc(in afara concursului) sa scada concurenta, uite ce fac microbistii in arene...nu mai stiu sa se bucure de meciul in sine...totu-i cu curu\'n sus.\r\nAm o nedumerire. Nu-i diplomat deloc deloc, da\' daca tot l-o luat, de ce draq n-o sters inregistrarea? ce-o gandit?????? bine ca scrii tu acilea fain, sa-mi mai descretesti fruncea, ca lumea-ntreaga se cam face de cacat. sintem neste degenerati majoritatea......ne ducem pe p...\r\nsi DA. am zas tate aste dupa ce-am baut neste beri. no si ce. ca tot asa gandesc si fara beri.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1)','',0,0),(2661,461,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.112.22','2007-06-04 00:14:23','2007-06-03 22:14:23','...si acu\', finca avem mai mult timp la dispozitie:\r\n\r\n@been there done that: Apropos de limba lu \"sulitza scuturata\", recomand www.groparu.ro/?p=79 \r\nPS: Kiar nu scriu ca sa fac cuiva - nici tie - pe plac. Finca inca nu mi-o oferit nimeni atatia bani.\r\n\r\n@yo: De acord, Dumnezeu nu prea face nani. Apropos, cat de des mergi tu la beserica? Lasa-ma sa reformulez, ca nicio nu pre merg: ce pacat nu iarta Dumnezeu niciodata? Hai, ca nu e greu. Meri la o turlÄƒ cu cruce-n varf, si intreaba-l pe nenea cu fusta lunga, neagra si barba daca nu stii. Si vei fi refelat.\r\n\r\n@Me: Adevarat, stau toata ziua calare pe calc. Shtii de ce? Ä‚sta mi-i jobu\'. Sh-mi place de si mor, da\' nesinucis. Sh prekini kiar am o droaie. Ceteshte Tiganiada, ca sa ii cunosti numa pe cativa dintre cei mai meseriashi adumbritori de planeta. Si nu am grija, finca stiu ce se poate intampla: nimic.\r\n\r\n@eu: ILIESCULEEEE!!! Nu cred in destine tragice, numa\' tragi-comice. \r\n\r\n@tot eu: M-am dus la dreq, m-o refuzat la export.\r\n\r\n@X: IO NU-S BOLNAV CU CAPU\'! Aud numa neshte voci, da\' numa cand imi pun castile pe urechi.\r\n\r\n@eu, tot eu si celelalte personalitati ale sale: Da, corect, posibil, probabil. Da\' argumenteaza, sa vad daca bat motivele tale cu ale mele.\r\n\r\n@tudor: Kiar mi-as dori sa stii cine mi-s:D da\' nu meritzi sa-mi f** timpu\'.\r\n\r\n@johan: Nu, chiar nu mi-i frica ca pot ajunge si eu ca el. Eu m-as sinucide mai igienic :D\r\n\r\n@Tuturor: Nush cum se face, da\' ma copii, numa\' pro-groparii de pe saitu\' asta stie sa scrie corect romaneshte??? (BTW, a big 10q) Non-groparilor: sinucideti-va prostia! Si de mai prind injuraturi neargumentate numa\' de dragu\' de a va simti voi cool, va sterg. Sus cenzura!\r\n\r\nGata, ma bag in pat ca e un film cu Clint Eastwood pe MGM.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(770,378,'katmai','katmai@keptprivate.com','http://www.512kbps.com','195.212.29.187','2007-05-07 18:36:11','2007-05-07 16:36:11','oh ... deci nu sunt singurul caruia ii e lene azi, doamne, credeam ca o iau razna !',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.8) Gecko/20050511 Firefox/1.0.4 (CK-IBM)','',0,0),(2806,466,'Hellene','helene_a21@yahoo.com','http://hellene-a-piece-of-me.blogspot.com/','86.34.4.4','2007-06-07 09:06:11','2007-06-07 07:06:11','E cam aiurea cand stropii de pipi s-au uscat si nu poti sa ii stergi. De scarba tre sa fugi la alta buda de pe etaj, unde bineinteles e ocupat. Te inrosesti de nevoie si sari de pe un picior pe altu si il injuri pe sef ca din cauza lui a trebuit sa te tii atat. Afurisita treaba.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(778,378,'Andre MKT','','','86.106.55.69','2007-05-07 19:40:01','2007-05-07 17:40:01','radu, nu imi place cand aberezi\r\nserios ca nu imi place\r\ntu esti prea destept, prea fain, prea cool',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(2724,465,'baghy','baghy83@lycos.it','http://baghy.wordpress.com/','78.12.7.161','2007-06-06 00:43:03','2007-06-05 22:43:03','ultimul sfat le intrece pe toate',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(2722,465,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-06-05 23:16:41','2007-06-05 21:16:41','Ca taci ma! N-ai inteles ca eram in trening si pantofi??? La altii am vÄƒst...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(2721,465,'Greuceanu','fm77roen@yahoo.com','','195.149.72.124','2007-06-05 23:12:32','2007-06-05 21:12:32','mo..... cum dreaku\' se vad stropii?!  Cum draku de poti fi asha de habauk sa atragi atentia atenti asupra ta cand jti ca ejti \"patat\'?! io nu pot sa cred ca s-au vazut stropiii umai de la primul pipi.... si nici ca ai facut o noapte intreaga doar un pipi..... vreau sa ne zici cum aratau in ochiii tai pantalonii a doa zi dimineata- amiaza! sau ai dat sh pe sa-cou (cou= singularul de la coi)?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(2632,461,'baghy','baghy83@lycos.it','http://baghy.wordpress.com/','78.12.3.208','2007-06-03 11:53:35','2007-06-03 09:53:35','gropare ce de comentarii ai adunat cu postul asta.vezi daca esti impotriva curentului.trebuia sa intri si tu pe hi5 ca e acolo un grup cu solidarietate si tampenii dinastea',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(2923,471,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.112.22','2007-06-09 03:13:40','2007-06-09 01:13:40','Tre\', c-asha zice Biblia. Sh in sara asta bÄƒui Ã®n... Ã®n... ye. Avenue.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(3777,505,'c|neva','cineva_df@yahoo.com','http://www.diaconuflorin.ro/blog','89.33.215.59','2007-06-30 23:46:37','2007-06-30 21:46:37','Tu esti tipu care joaca counter pe maxnet?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(2836,469,'baghy','baghy83@lycos.it','http://baghy.wordpress.com/','78.12.15.10','2007-06-07 18:23:14','2007-06-07 16:23:14','du-te naibii gropare :)))))))))))))))))',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(2839,469,'sabina','','','86.105.121.103','2007-06-07 19:29:22','2007-06-07 17:29:22','sa mananci o kila jumate de capsuni (azi la 18:30) fara sa-i impart(i) cu nimeni... oops',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(2842,469,'Andre MKT','','','86.106.55.69','2007-06-07 21:03:50','2007-06-07 19:03:50','1.sa mananci seminte de dovleac singura-singurica si sa citesti alexandru vakulovski, da nu cartea aia cu nume obscen, ci aia noua, BONG.\r\n\r\n2.sa te epilezi pe picioare cu lama \r\n\r\n3.sa te bucuri ca proasta ca amu iti permiti lac de unghii cu 200 000 si sa intrebi \"se accepta cardurile?\"\r\n\r\n4.sa te dai cu parfum masculin, ba chiar s aiti cumperi asa ceva\r\n\r\n5.sa te scoli odihnita\r\n\r\n6.sa bei si sa fumezi\r\n\r\n7.sa ai inima impacata\r\n\r\n8.sa dai inapoi briketa groparului dupa ce ai dohanit singura in spatele firmei.\r\n\r\n9.sa asculti dresden dolls \r\n\r\n10.sa iti juri ca daca viitoare cand gatlif mai face un film cu tzigani in romania, te duci si nu pleci fara un autograf de la asia argento.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(798,378,'Groparu','groparu.ro@gmail.com','http://www.groparu.ro','89.137.112.22','2007-05-07 23:48:06','2007-05-07 21:48:06','@Andreea: as vrea sa raspund, da\' mi-i lene.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(800,358,'lovingvama','admin@lovingvama.eu','http://lovingvama.eu','85.204.158.149','2007-05-08 00:05:54','2007-05-07 22:05:54','Pai se pare ca el ti-a luat tie interviul :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(2850,468,'Emaginatoru','e_magist@yahoo.com','','86.122.12.12','2007-06-07 22:13:59','2007-06-07 20:13:59','Noroc ca nu mai sunt elev sau student !',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(2851,461,'Andre MKT','','','86.106.55.69','2007-06-07 22:31:47','2007-06-07 20:31:47','Io daca il mai prind pe Oprea ca se leaga de societate (marea lui obsesie) pana si pe blogul lui Radu Gro, eu fac urat! Ce pielea mea, frate-miu sageata2002? Cred ca ai spus de 1000 de ori peste tot ca: societatea e de cacao, reguli stupide, lipsa de libertate, gresie si faiantza, rate la alfa bank, marmote auditori, gata maaaa! Am inteles. Shi am mai inteles ca ai un ghimpe in fund, dar nush ce se insisti sa il lashi acolo. \r\n\r\nCu drag, aia mica de la mkt',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(808,378,'katmai','katmai@keptprivate.com','http://www.512kbps.com','89.176.173.78','2007-05-08 00:31:39','2007-05-07 22:31:39','ma duc la somn :))) da mie lene sa ma ridic de pe scaun tulai` doamne',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(259,349,'Glogovetan Tudor','tudor_glogovetan@yahoo.co.uk','http://photography2012.blogspot.com/','89.136.23.215','2007-04-26 23:32:17','2007-04-26 21:32:17','Poti sa il inscrii unde vrei ca aia nu e adresa lui adevarata. Se pot face programe care sa trimita mailuri cu orice adresa din partea oricui. Daca vrei poti sa iti trimiti chiar si tie mail de pe propria casuta de mail. Da ar fii interesant sa prinzi o adresa adevarata ;)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(260,296,'Eddy','lee_samurai_e@yahoo.com','','86.34.232.210','2007-04-26 23:47:46','2007-04-26 21:47:46','Parerea mea este: din punctul tau de vedere, daca ti-e prieten adevarat sa nu incerci sa i faci probleme, dar daca stilul tau shmeker* iti impune si iti dicteaza sa faci gluma asta trecand peste faptul ca ii faci probleme, FA-O ! FA-O FA-OOOOOO ! \r\nDar din punctul meu de vedere, e prea putin ce ii faci, fa-l sa sufere, provoaca-i necazuri, dureri de pe urma caruia ne putem delecta mult timp p blog\'ul tau :D parerea mea sincera:D\r\n\r\nAsa cum au barbatii spor de sex, asa iti doresc si tie spor la caterinca! Traiasca Vadim cel intelept, stiutor de toate, si zeul frumusetii venusiace ! ii dorim sa traiasca, dar DOAR IN AMINTIREA NOASTRA! nu in prezent.\r\n\r\n* shmeker = nascut din sperma de campion :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(261,349,'Groparu','groparu.ro@gmail.com','http://www.groparu.ro','89.137.112.22','2007-04-27 02:05:54','2007-04-27 00:05:54','Ashea e, Tudor, ideia e caaaa... eu stiam de faza asta (vezi blog.pacurar.net, care trimite spamuri fest - adeca non-stop - deshi omu e fff bine intentionat, doara e shafu\' meu!) Daaaar... am primit mai multe mesaje de pe acelasi server, numa\' ca cu ID-uri diferite. Which rings a bell... shit, it rings it loud!!!!\r\n\r\nSi daca aia cu serveru\' cu pricina (foreve punct com) nu au bani sa ishi ieie un sysadmin cumsecade, cu atata mai rau pt. ei. Macar vor sti cum sa-si upgradeze \'cel penis, bata-l vina!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(262,296,'admin','groparu_ro@yahoo.com','http://','89.137.112.22','2007-04-27 02:13:21','2007-04-27 00:13:21','Ideia e caaa... dincolo de Vadimi, Becali si Vangheli: nu m-am putut aptine. Deloc. Da\' deloc-deloc. \r\n\r\nDoamneeee, iearta-ma!!!\r\n\r\nPS: Iar faptul ca i-s prekin... deja ii e suficient amar! Vai ghe amaru\' lui... Tupac  Amaru\' Sha-cur...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,1),(2710,465,'Groparu','groparu.ro@gmail.com','http://www.groparu.ro','82.77.126.254','2007-06-05 18:12:46','2007-06-05 16:12:46','...pantofi cu toc, te rog!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(1825,413,'Groparu','groparu.ro@gmail.com','http://','89.137.112.22','2007-05-21 20:01:58','2007-05-21 18:01:58','Da, ne-ai prins. E gay fest, no doubt about it. Dar in semnificatia aia veche a cuvantului \"gay\", aia de care zicea Wordsworth in \"Ode to the Daffodils\" (esti de acord cu mine ca e cel mai poet romantic din istoria literaturii engleze), si anume \"a poet could not but be gay/In such a jocund company\".\r\n\r\nDa-mi voie sa invoc dictionaru\' care se lafaie la mine pe calc, ca sa ma iesplic mai pe larg: gay (gÂ³) adj. gayÂ·er, gayÂ·est. 1. Showing or characterized by cheerfulness and lighthearted excitement; merry. 2. Bright or lively, especially in color: a gay, sunny room.\r\n\r\nAdeca vesel, mo. Vesel. Happy ;)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,2),(2775,466,'Emaginatoru','e_magist@yahoo.com','','86.122.12.12','2007-06-06 21:46:18','2007-06-06 19:46:18','Yo, Gro!\r\nMaestre, pot avea permisiunea dvs. s-o printez si sa o afisez pe usa la WC-ul de la lucru, asa pentru unele sugestii ?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(1834,423,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.112.22','2007-05-21 23:33:26','2007-05-21 21:33:26','Ce beri?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(1814,413,'Gez','geza@dvis.info','http://groller.info/geza','89.137.114.63','2007-05-21 17:40:24','2007-05-21 15:40:24','Mie imi seamana cu ceva gayfest :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(2129,441,'cetitoare','totmea@yahoo.com','','86.35.232.96','2007-05-25 11:11:00','2007-05-25 09:11:00','Faceti tot ceea ce n-as face eu! Nebunie dulce (si safe) s-aveti, (efemer)tiganilor!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(2832,466,'mishu','mishu@doingtheartwork.com','http://www.doingtheartwork.com','82.77.126.254','2007-06-07 15:13:03','2007-06-07 13:13:03','mai asteapta pana mai dau eu mana cu tine...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(2834,468,'baghy','baghy83@lycos.it','http://baghy.wordpress.com/','78.12.15.10','2007-06-07 16:11:15','2007-06-07 14:11:15','Gropare fiecare cu ce-l doare :))',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(2780,466,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-06-06 23:31:20','2007-06-06 21:31:20','Da! Si eu vreau sa stiu! Varzaaaa, eshi la raport!!!! Da-te prins!!! Ca ne-ai parfumat vietile!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(2779,466,'oedip','oedip74@gmail.com','http://oedip.blogspot.com/','89.137.104.170','2007-06-06 23:13:55','2007-06-06 21:13:55','ma frate vezi ca-i faci pa copchii astia sa urnieze, apoi om serios esti tuh\r\n\r\n:D\r\n\r\nps. ma taica ma, cine-i varza ca el ma stie si io nu, si ma oftic, ca nu e cu putinta una ca aiasta! ;)\r\ncum sa nu-l stiu io pa om, daca el ma stie, da\' totusi io nu\'l stiu... deci HEEEEELLLLPPPP ;)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(2702,462,'oedip','oedip74@gmail.com','http://oedip.blogspot.com/','89.137.104.170','2007-06-05 10:52:47','2007-06-05 08:52:47','\"Nu traje dom semaca\"!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(3537,502,'katmai','katmai@keptprivate.com','http://www.512kbps.com','195.212.29.171','2007-06-26 10:41:30','2007-06-26 08:41:30','cam bec fast ca o sa ni se faca dor di tini way',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7 (CK-IBM)','',0,0),(2825,468,'ss','criss_team@yahoo.com','','81.196.150.198','2007-06-07 14:12:03','2007-06-07 12:12:03','astia...probabil c-o fost programati. sau auto-programati. nu, nu la nenea ala functionar ceresc de la ghiseu, de care zicea groparu. la minte. treaba aia care nu-i chiar ashe SeFe, cu tehnicile de control al mintii.\r\n...no, amu ashe-i ca si voi sinteti confuzi?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7','',0,0),(2777,466,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-06-06 21:49:29','2007-06-06 19:49:29','Cum nu! Numa\' sa n-o vaza antipaticu\'. Nu al vostru, al meu:D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(2579,461,'Bogdan','blu3pc@yahoo.com','http://www.bogdan-pantoc.com','89.41.236.129','2007-06-02 11:13:04','2007-06-02 09:13:04','Hai domle ca esti tare, daca iti reuseste faza cu moartea in semn de solidaritate, cu siguranta ca o sa vina si altii dupa tine, ce atata pierdere de vreme, hai sa ne sinucidem cate unul la 5 minute, iar restul care raman sa beneficieze de mult trafic si bani din AdSense :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(2752,465,'Luna Betiluna','mihdana@yahoo.com','','82.76.46.190','2007-06-06 11:34:05','2007-06-06 09:34:05','sper ca n-ai asortat, Doamne feri, treningu` cu pantofii, poate doar cu mobilu` (sau -lele, ca groparu daca e sa fie sunat e musai sa fie gasit)...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.0.10) Gecko/20070216 Firefox/1.5.0.10','',0,0),(1576,413,'Fascista','','','209.221.168.249','2007-05-19 01:11:20','2007-05-18 23:11:20','MI -a rupt inima! Valeu!Cine vrea sa facem cheta sa ii luam  lu Mitrea macar un slip ca a lu\' Borat, ca saracii tidy-whitey\'s aia or vazut zile mai bune.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; InfoPath.1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(2605,461,'tudor','priculina@yahoo.com','','62.1.137.247','2007-06-02 19:56:56','2007-06-02 17:56:56','\"Mama mi-a spus sa imi fac numai prieteni mai inteligenti decat mine. Pe cine, mama, pe cine?\"\r\nasemenea ne-au zis si noua mamele noastre...daca nu ai prieteni e din cauza k toti sunt mult mai destepti ca si tine...nu prea se coboara lumea la nivelul tau...si cei care te sustin in ideile tale de om retardat sunt probabil de acelasi nivel cu tine...ce sa faci...mai exista si specimene ca tine...macar putin respect pt un om care nu mai e printre noi...',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(2604,461,'Teteanu :D','','','82.77.202.17','2007-06-02 19:54:18','2007-06-02 17:54:18','bÃ£ Gropare, tu-mni pari ficior de trabÃ£, norocu\' tÃ£u c-ai prins la borcanu cu miere la timpu\' potrivit... \r\nProblema-i a copchilului c-o trecut prea iute de la laba la pchizdÃ£... si dup-un futai o crezut cÃ£ aia-i dragoste mare! \r\nLÃƒSATZ\' BÃƒ FATA-N PACE!!! \r\nEa-i de vinÃ£ cÃ£ i-o arÃ£tat marmota lu\' ficioru\'? Problema e la ficioru\' \"psychically challenged\" (hmmm... era... :D )\r\n\r\nMOTORHEAD - We Are The Road Crew\r\n\"Another town another place,\r\nAnother girl, another face,\r\n......................................\r\nAnother hotel we can burn,\r\nAnother screw, another turn\r\n......................................\"\r\n\r\n\\m/',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(2603,461,'tot eu','aliceioana1988@yahoo.com','','86.122.24.34','2007-06-02 19:21:26','2007-06-02 17:21:26','esti sustinut de toti pup\'in\'curistii mai sus RATATILOR',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 2.0.50727)','',0,0),(2600,461,'Me','','','85.121.26.23','2007-06-02 19:18:23','2007-06-02 17:18:23','Jegosule',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 2.0.50727; .NET CLR 1.1.4322; MEGAUPLOAD 1.0)','',0,0),(2601,461,'tot eu','aliceioana1988@yahoo.com','','86.122.24.34','2007-06-02 19:19:20','2007-06-02 17:19:20','tampitule',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 2.0.50727)','',0,0),(2602,461,'tot eu','aliceioana1988@yahoo.com','','86.122.24.34','2007-06-02 19:20:02','2007-06-02 17:20:02','cel mai mare cretin in viata nu? oo da !!! mare tampit',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 2.0.50727)','',0,0),(2599,461,'tot eu','aliceioana1988@yahoo.com','','86.122.24.34','2007-06-02 19:17:29','2007-06-02 17:17:29','nenorocitule',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 2.0.50727)','',0,0),(2598,461,'tot eu','aliceioana1988@yahoo.com','','86.122.24.34','2007-06-02 19:17:09','2007-06-02 17:17:09','cretinule',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 2.0.50727)','',0,0),(2596,461,'tot eu','aliceioana1988@yahoo.com','','86.122.24.34','2007-06-02 19:16:08','2007-06-02 17:16:08','sa te duci dracu\' animalule',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 2.0.50727)','',0,0),(2597,461,'tot eu','aliceioana1988@yahoo.com','','86.122.24.34','2007-06-02 19:16:41','2007-06-02 17:16:41','animalule',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 2.0.50727)','',0,0),(2595,461,'X(','','','89.136.168.5','2007-06-02 19:13:49','2007-06-02 17:13:49','doamne....tu esti bolnav cu capu?chiar k nu te duce mult mintea aia....ce om nebun...doamne...',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; FunWebProducts; SIMBAR={B9508AEA-E018-4164-86C0-F676BD31A3B1})','',0,0),(2594,461,'eu','marius_cojocaru80@yahoo.com','','86.122.24.34','2007-06-02 19:13:08','2007-06-02 17:13:08','ANIMALULE!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!! sa ai un sfarsit mai tragic decat cel al lu Bogdan! esti cel mai mare cretin in viata serios ! MORI!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 2.0.50727)','',0,0),(2593,461,'Me','','','85.121.26.23','2007-06-02 19:06:38','2007-06-02 17:06:38','Groparu\' . . .  un lake ce sta all day long pe net. .  pentru ca daca iese afara sperie lumea, un om izolat un retardat :). N-am cuvinte nu stiu cum te-as putea descrie. . . . impertinent ce esti :) \r\n\r\nAi grija de tine. . . . nu se stie ce se poate intammpla',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 2.0.50727; .NET CLR 1.1.4322; MEGAUPLOAD 1.0)','',0,0),(2592,461,'dan','tot_io_ba','','86.127.137.155','2007-06-02 19:02:29','2007-06-02 17:02:29','tu probabil ai cazut in cap la nastere;nu e necesar sa te arunci pentru nicio profesoara..',0,'1','Opera/9.10 (Windows NT 5.1; U; en)','',0,0),(2591,461,'yo','','','89.136.97.231','2007-06-02 19:00:44','2007-06-02 17:00:44','ua zdrentzelor cum ati putut scrie asa cv ua ..nebunilor ...voi nu ganditi deloc ....mah ...Dumnezeu nu doarme niciodata j cel carea a scris asa cv ...o sa ..aiba numai bucurii ...ua ....taranilor.........baiatu ala sa sinucis pt ca a iubit o zdreantza asa ca asa care a scris;) ... asa ca ....taceti din gura ...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(2590,461,'sb_p','','','192.129.3.14','2007-06-02 16:57:05','2007-06-02 14:57:05','p.s.2: make that 7 greseli de spelling... n-am fost atenta :P',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.0.3705; .NET CLR 1.1.4322; Media Center PC 4.0; .NET CLR 2.0.50727)','',0,0),(2829,468,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-06-07 14:35:36','2007-06-07 12:35:36','Io de 12 ani tat incerc sa imi controlez mintea sa imi controleze corpu\' sa imi controleze putzulica sa pot bea bere fara sa o pish dupe o ora. Sh nu-mi iese. Io creca KGB-ul e de vina! Sau dictonu\' ala cum ca berea nu se cumpara, berea se inkiriaza...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(2765,466,'koyrosh','a@a.com','','82.77.126.254','2007-06-06 15:42:25','2007-06-06 13:42:25','protestez; pe mine ma ploo in buda. si, buda antipatica momentan nu mai e:D',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(2764,465,'Groparu','groparu.ro@gmail.com','http://www.groparu.ro','82.77.126.254','2007-06-06 15:41:24','2007-06-06 13:41:24','Da!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(1605,385,'BREEETTA','zetta_gitta@yahoo.com','','82.78.223.106','2007-05-19 07:10:13','2007-05-19 05:10:13','Fuck the rest,I roll with the best.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; FunWebProducts)','',0,0),(2766,466,'pepi','roman.petre@gmail.com','','82.77.126.134','2007-06-06 16:51:16','2007-06-06 14:51:16','Pfuui ma, sa ma pis pe mine de ras, nu alta. \r\nAbia astept si povestea cum mergi acasa la buda cand ai musafiri antipatici sau nu :).',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727)','',0,0),(2589,461,'sb_p','','','192.129.3.14','2007-06-02 16:54:49','2007-06-02 14:54:49','\"genu\' feminin de moarte\" - :)) \r\n\r\nda\' eu ma intreb, Gropare, se poate practica bloggingu\' din afterlife? ca altfel... ramane bunatate de blog in paragina...\r\n\r\np.s.:\"been there done that\"- 6 greseli de spelling in treij\' de cuvinte?! ntz, ntz, ntz. english is not for everybody, mate...',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.0.3705; .NET CLR 1.1.4322; Media Center PC 4.0; .NET CLR 2.0.50727)','',0,0),(2521,461,'IepurasulAtomic','praetorian21uk@yahoo.com','','192.100.130.8','2007-06-01 14:03:08','2007-06-01 12:03:08','Asha sa-ti ajute Dumnezeu!!! :)))',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; N_O_K_I_A; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(2520,460,'sabina','','','81.12.163.178','2007-06-01 13:09:36','2007-06-01 11:09:36','poate un pic cam obscen',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1)','',0,0),(3015,473,'Andrei Crivat','andrei@andreicrivat.ro','http://www.andreicrivat.ro','89.137.98.13','2007-06-11 17:46:32','2007-06-11 15:46:32','dap ma, recunosc, ce dracu sa mai zic ?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727)','',0,0),(2518,461,'cetitoare','totmea@yahoo.com','','86.35.232.96','2007-06-01 11:50:18','2007-06-01 09:50:18','las\' ca te trezesti tu! las\' ca discuti tu acas\'!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(2753,465,'Luna Betiluna','mihdana@yahoo.com','','82.76.46.190','2007-06-06 11:37:03','2007-06-06 09:37:03','...si mai cer sa ne spuna groparu dac-a dansat mireasa focoasa olteanca de Baia Mare, ha?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.0.10) Gecko/20070216 Firefox/1.5.0.10','',0,0),(2511,74,'Nascut din spermatozoizi campioni &raquo; Blog Archive &raquo; Groparu se va sinucide in solidaritate pentru Bogdan Costache','','http://www.groparu.ro/?p=461','69.16.239.16','2007-06-01 10:57:36','2007-06-01 08:57:36','[...] o sa vreau sa mor din cauza unei profe de romana. Da. Sa ma indragostesc de ea, sa ii scriu poezele d-alea d-ale mele, stil Emil Brumaru, da&#8217; - firesc - oleaca mai najpa, sh sa o scot la kefane, sh toti sa se [...]',0,'1','Incutio XML-RPC -- WordPress/2.1.2','pingback',0,0),(1963,438,'christine','','','86.121.208.117','2007-05-23 10:37:36','2007-05-23 08:37:36','cred ca ai gasi voluntari pt varianta cu tnt-ul la parlament. :)) pana atunci, strangem din dinti si citim de zor dictionaru\' de argou, cum bine zici matale...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(746,376,'MÃ¢tza','ana.man.fox@gmail.com','','81.180.173.61','2007-05-07 10:33:37','2007-05-07 08:33:37','gropare-gropare, ... vreo frustrare mica, ceva? ca prea lunga ti-e lista. chiar asa.. de ce neaparat \"ziua barbatului\" ? pentru barbatii pe care ii iubim facem in asa fel incat fiecare zi sa fie ziua lor. sau macar una pe saptamana. daca sunt barbati care nu simt asta, .. atunci e nasol. ti-as raspunde la fiecare  motiv de mai sus, ... dar mi-ar lua prea mult si am de lucru :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.0.11) Gecko/20070312 Firefox/1.5.0.11','',0,0),(747,376,'Groparu','groparu.ro@gmail.com','http://www.groparu.ro','82.77.126.254','2007-05-07 10:37:25','2007-05-07 08:37:25','\"In fiecare zi il fac sa simta ca e ziua barbatului. Pana seara, pana vine si sotul acasa\"',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(748,376,'MÃ¢tza','ana.man.fox@gmail.com','','81.180.173.61','2007-05-07 10:40:27','2007-05-07 08:40:27','din seria: \"-tu ti-ai privit vreodata sotul in ochi cand faceai dragoste?\" raspuns: \"-da, statea in usa si se uita ca un bou...\" =))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.0.11) Gecko/20070312 Firefox/1.5.0.11','',0,0),(2676,462,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.112.22','2007-06-04 17:33:59','2007-06-04 15:33:59','...si toate astea in regia, costumele, scenariul si distributia lui Sergiu Nicolaescu :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(2139,441,'Luna Betiluna','mihdana@yahoo.com','','82.76.46.190','2007-05-25 13:44:24','2007-05-25 11:44:24','Io zic: faceti tot ce-as face io da` nu pot pentru ca sa plec sa fac, adica tot as face si-acu de-alea nefacute (demult).... na-ti-o franta ca ti-am dres-o !\r\nPe caiiiiiiiii !',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.0.10) Gecko/20070216 Firefox/1.5.0.10','',0,0),(751,376,'mea','totmea@yahoo.com','','86.35.232.96','2007-05-07 12:56:48','2007-05-07 10:56:48','Gropare, da\' eu te iubesc. Stii.Nu?\r\naaaaa..... LA MULTI ANI! (de la o \"blonda\")',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(754,377,'MÃ¢tza','ana.man.fox@gmail.com','','81.180.173.61','2007-05-07 14:50:47','2007-05-07 12:50:47','da\' sa injuri, sa betivesti si sa duhanesti nu ti-i lene?   asta ca o alternativa la faimoasa replica a unguroaicei din bancul cu the sex robot si cele 3 tanti cobai: \"da\'  sa fugi te mai tin bateriile?\"',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.0.11) Gecko/20070312 Firefox/1.5.0.11','',0,0),(755,376,'Groparu','groparu.ro@gmail.com','http://www.groparu.ro','82.77.126.254','2007-05-07 15:00:04','2007-05-07 13:00:04','Mi se pare normal sa ma iubesti! Cine poate sa nu iubeasca un butoiash de bere?\r\n\r\nFemei din toate tarile, iubiti-ma! Am bere pentru toate.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(756,377,'Groparu','groparu.ro@gmail.com','http://www.groparu.ro','82.77.126.254','2007-05-07 15:03:53','2007-05-07 13:03:53','Poi astea ie eforturi intelectoale! clar ca nu mi-i lene.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(284,354,'Denisa','denisalala@gmail.com','http://www.denisuca.ro/blog','86.123.36.173','2007-04-28 01:04:01','2007-04-27 23:04:01','Beton! Biata fÄƒtucÄƒ... da\' bine i-ai fÄƒcut! :D\r\nPÃ¢n\' la urmÄƒ, Ã®n loc sÄƒ-ÅŸi facÄƒ ei reclamÄƒ, Å£i-ai fÄƒcut tu. Pe banii lor.\r\nBaftÄƒ la RoBlogFest, io te-am votat! :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(285,354,'Denisa','denisalala@gmail.com','http://www.denisuca.ro/blog','86.123.36.173','2007-04-28 01:04:20','2007-04-27 23:04:20','No, ClujBlogFest, m-ai ameÅ£it.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(3535,502,'ion iopescu de la alba','mist_ab_2k@yahoo.com','','83.103.154.202','2007-06-26 08:03:11','2007-06-26 06:03:11','gropare. sa nu care cumva sa iei medicamente... Tzuicomicina, Usturoi si mult somn!\r\nAzi am facut ce am invatat de la tine... la faza cu controlorii... erau in statie, si inainte sa urce zic cu voce tare: \"No ca vin sa ne controleze de belete si abonamente!\" Nu m-o crezut nimeni... da io deja le-am bagat abonamentu sub nas la controlori... nici n-or apucat sa-si agate legitimatiile in kept...he he',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(2127,439,'Paszti','pasztorjozsef@yahoo.com','','81.12.230.166','2007-05-25 09:14:05','2007-05-25 07:14:05','Ce teapa!!! Imi pare rau de tine da\' la faza cu x frati ar fi trebuit sa se declaseze alarma :(\r\nIti dai seama daca tepe dinastea luam si noi care suntem antenati in balcani (am vazut multe, am auzit multe si am patit multe) ce tepe trag saracii occidentali. Pentru concetatenii nostri rrommi cred ca e raiul de pa pamant.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1)','',0,0),(2113,439,'cetitoare','totmea@yahoo.com','','86.106.49.143','2007-05-25 07:02:58','2007-05-25 05:02:58','ai nevoie urgenta de-un lob in plus......unul de veghe.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1)','',0,0),(1556,415,'groparu\' dixit &laquo; servicii secrete sau cultura paranoiei','','http://serviciisecrete.wordpress.com/2007/05/18/groparu-dixit/','72.233.2.32','2007-05-18 19:51:03','2007-05-18 17:51:03','[...] groparu&#8217;&nbsp;dixit  &#8220;no, meretzi la vot&#8220; [...]',0,'1','Incutio XML-RPC -- WordPress/MU','pingback',0,0),(2677,463,'Piticu21','piticu@piticu.ro','http://www.piticu.ro','89.165.215.227','2007-06-04 20:12:14','2007-06-04 18:12:14','ba ... sunteti rai ... rai rai rai :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(2678,462,'Cornelia G','','http://360.yahoo.com/corneliaguju','86.105.82.121','2007-06-04 20:59:21','2007-06-04 18:59:21','ce-mi place! :))))',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(2756,465,'Luna Betiluna','mihdana@yahoo.com','','82.76.46.190','2007-06-06 11:55:48','2007-06-06 09:55:48','bien, bien, da nu prea-nteleg, mama soacra s-a dat \'\'libera\'\' sau era din Philiashi via Belciugatele? Ori te-a-nnadit buricul cel prea zbantuit al doamnei?  (asta a propos de variantele tale justificative, of course...) :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.0.10) Gecko/20070216 Firefox/1.5.0.10','',0,0),(2664,461,'sageata2002','a@a.com','','82.77.126.254','2007-06-04 09:09:42','2007-06-04 07:09:42','nu vreau sa scriu inca un blog pe post de comment, da\' ma vad nevoit (is nartzoaga de care zicea bazavan)\r\nmi se pare ca aici s-or adunat sa comenteze cei mai preacuratzi si mustind de iubire si dreptate oameni. un fel de iisushi mai mititei, asa. cretinilooooor! idiotilooooor! voi l-ati omorat, bueeey! voi cu alinierea voastra la niste reguli sociale alienate. voi, ajtia care va erijatzi in cei mai puri de pe planeta. societatea aia de kkt pe care o propovaduitzi a facut-o pe marmota aia (de era auditor) sa moara de foame, desi intorcea banii cu lopata. societatea aia arata cu deshtu\' 2 oameni care se iubesc; pentru ca fac parte din paturi diferite, se numeste iubire interzisa. din cauza asta se ascundeau aia. din cazua barfelor unor cretinopatzi ca voi.\r\nva prevad un mare viitor: pentru ca nu mai puteti ordona cozile la lapte, ca pe vremea lui ceaschca, voi ordonatzi lumea. si voi sunteti aia care vor incalca primii regulile, vor bea de vor rupe, isi vor insela nevasta (sau isi vor blestema zilele noaptea - cazul fetelor); o sa va casatoriti la 45-50 de ani cu o fatuca de 20. daca va tine pozonaru\', ca pula oricum nu aveti nici acuma.\r\ncateva cuvinte despre groparu\': o gatat o faculta cu litere, deci daca scrie aiurea o face pentru ca vrea pula lui, nu ca nu are habar sa scrie, are o tona de preteni, e outspoken, solar si il urasc cu gramada cand ma dispera.\r\ncateva cuvinte despre voi: http://blog.360.yahoo.com/blog-e5fo8yAieqHQW4TAnaiR2OFfFQ--?cq=1&amp;p=26\r\no mica rectificare: nu am zis ca sa introducem vot universal, ci sa fie un fel de cens pe capacitate, ca pe vremea romanilor: daca esti in stare intelectual, votezi. daca nu, stai acasa, fa prunci pentru imperiu si imperiul te va tine cu papa si muieri. numa\' ca voi sunteti dejaba.\r\nam auzit de oameni care se masturbau pe freud. voi faceti din hustler cornete de castane.\r\nDuamne, cine pula o sa plateasca pensia groparului?',0,'1','Opera/9.10 (Windows NT 5.1; U; en)','',0,0),(2663,461,'scorojit','spyke_gg@yahoo.com','http://scorojit.wordpress.com/','89.36.35.53','2007-06-04 08:33:09','2007-06-04 06:33:09','De ce ai scos link-ul de la profilul lui de haifaiv?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12','',0,0),(2655,461,'johan','ppio_ioan@yahoo.com','','89.36.213.219','2007-06-03 22:45:20','2007-06-03 20:45:20','ba tata ba ce prost est!da cu P mare ma!nu ti-e frica ca te bate Dumnezeu?ce ti-a facut copilu ala ma?nu iti este frica ca ai fi putut fii si tu in cazul lui?ba dar nu am crezut ca poti fi asa de animal...ba tata ba dar esti prost rau ma nenorocitule1apropo esti .............................................................................................................................................un PROST mare cat un animal',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(2668,461,'J','','','82.77.126.254','2007-06-04 13:44:34','2007-06-04 11:44:34','Io cre\'ca groparu\' l-o impins pe amorez, ca sa aibe subiect de blog :D',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; FDM; .NET CLR 1.1.4322)','',0,0),(2755,465,'Groparu','groparu.ro@gmail.com','http://www.groparu.ro','82.77.126.254','2007-06-06 11:45:53','2007-06-06 09:45:53','Well,... nu am dansat cu mireasa, ca io nu ma dau la femei cu verighetzi, numa daca verighetzile is in buric sau in nas. Am dansat in schimb o sÃ¢rba focuasÄƒ prelungitÄƒ cu mama soacra de Filiashi :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(2750,465,'Frange Oase','radu.crisan@gmail.com','','82.77.126.254','2007-06-06 11:04:53','2007-06-06 09:04:53','Poi ba, io nu cred ca e problema cu flotoarele din BM; eu zic ca se trage de la horinca ma. Buey, stii care-i culmea betziei? Sa vezi ca te pishi pe langa poola....',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(2499,460,'Cristi Roman','cristi@roman.ro','http://www.cristiroman.ro','89.137.98.13','2007-06-01 08:04:35','2007-06-01 06:04:35','cool.ok. ce tare.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727)','',0,0),(1809,423,'Groparu','groparu.ro@gmail.com','http://','82.77.126.254','2007-05-21 13:44:32','2007-05-21 11:44:32','...daca si-o sunat varu\' din Spania, oare sa il rog pe prezident sa imi rezolve de un concediu acolo, cu cazare moca?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,2),(2915,472,'Luna Betiluna','mihdana@yahoo.com','','89.123.8.94','2007-06-08 23:45:52','2007-06-08 21:45:52','mai tza tze tzi tzo tzu,\r\ncum sa se tiganeasca un gropar fara tiganisme, ha? aud? cu DEXu si DOOMu?\r\nhai, un sinonim/antonim ici colo, o metafora parfumata via buda, da chiar ashe, fara ardei iute la ciorba? e nashpa\r\nand btw, nashpa e in DEX :) si e de la ei :)\r\ncele bune',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(2760,466,'sabina','','','81.12.163.178','2007-06-06 14:30:15','2007-06-06 12:30:15','mai am putin si ma pis pe mine de ras',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1)','',0,0),(2761,466,'sabina','','','81.12.163.178','2007-06-06 14:30:53','2007-06-06 12:30:53','...dar e buda ocupata...',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1)','',0,0),(2762,466,'Andreea MKT','supergirgir@yahoo.com','http://marlahermina.deviantart.com/gallery/','82.77.126.254','2007-06-06 15:09:10','2007-06-06 13:09:10','eu nu te mai citesc ca mor de ras si afara ploua',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(1808,423,'Groparu','groparu.ro@gmail.com','http://','82.77.126.254','2007-05-21 13:43:42','2007-05-21 11:43:42','E! Greu\'! \r\n\r\nDaca Baseâ€™ isi pierde firea tocmaâ€™ cand discuta cu Putin? Sau cu Barroso? Sau cu Ahmadinejad? Si le fura telefoanele, sau pixurile de aur? Sau dÄƒ, ca Nikita Hrusciov, cu pantofuâ€™ in masa? Sau lasa un pÃ¢rtz la o intrunire, de nervi, de ii inerveaza pe ailanti potentati, care nu are crieri mai mari decat un marinel? Atunci ce se intampla? Vine atentatuâ€™ de la iranieni? Vine! Se taie gazuâ€™ de la rushi? Se taie! Se pierde clauza? Se!\r\n\r\nTanti aia nu putea filma cu camera profi din dotare in Selgros finca magazinele are regulamente: vrei sa filmezi, trebe aprobare. Fiind dumineca, tanti nu avea cum sa ceara aprobare de la shafii selgroshi. Daca nenea Baselu (care exploiteaza cu nerusinare presa, ca doara de-aia il iubim - apropos, stiai ca nu da curs invitatiilor la toc-shouri decat daca moderatorii sunt pro-basestieni?) nu avea chef de mediatizare, pur si simplu loa doi sepepei d-aia cu Kalashuri care se pierd la manifestatii, si tineau baetii lumia departe: â€œNava amiral cumpara bere, nu va apropiati!â€ Lumea ar fi inteles. Daâ€™ sa confisti in haluâ€™ asta un terminal mobil numa finca poti (Hristoaseeee!!!) mi se pare o defulare penala. Pedepsibila.\r\n\r\nDaca gajica aia era prekina-mea, as fi avut sange de marinel pe capota. Seros! Si daca imi mai puteti da in istoria moderna a tarilor nordice (care e exemple si modele pt noi, orice s-ar zice!) un exemplu similar, io inkid blogu si ma apuc sa scriu cronica literala. Ptiu, literara. Ca si asa scriu anagramat. Ptiu, agramat.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,2),(2048,437,'cetitoare','totmea@yahoo.com','','86.35.232.96','2007-05-24 13:06:37','2007-05-24 11:06:37','SI EU!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(2820,468,'oedip','oedip74@gmail.com','http://oedip.blogspot.com/','89.137.104.170','2007-06-07 13:36:41','2007-06-07 11:36:41','nu e confuza mah, citeste biblia kant si heideger (cu un singur g, evident ca asta e heidegger pt jurnalisti - http://www.jurnalul.ro/articole/94192/cluj-%E2%80%93-gemenele-kinga-si-andrea-bodis-spre-moarte-imbratisate ) in maghiara si germana... sau, conform cu asta (http://bastrix.wordpress.com/2007/06/05/de-unde-tentatia-sinuciderii-la-tineri/) se uita prea mult la tv si la calculator...\r\n\r\n:DDD',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(2430,442,'been there done that','lisca.ana@gmail.com','','82.208.154.111','2007-05-30 20:12:42','2007-05-30 18:12:42','pe bune asa, e fie\'tu? ca asa nu semanati.\r\nda fie. rupe-l de la inima si da-l rapid pina nu se strica, ca-l vreau rau de tot.\r\nps: n-am zestre... crezi ca e vreo problema? \r\nadica daca dragoste nu e, nimic nu e.\r\nio zic ca aici e dragoste. ;)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(2653,461,'Emaginatoru','e_magist@yahoo.com','','86.122.12.12','2007-06-03 21:10:35','2007-06-03 19:10:35','Yo, Gro!\r\nEsti chiar optemist sa zici matale ca la nouajpatru de ani o sa dai coltzu. Si si atuncilea numa volontir, ca ti s-o fi urat de Tiganiade si alte cele.\r\nPrecum vaz acilea e multzi care vrea sa mori, incat ma gandesc la o zicala cu caii care nu moare cand vrea cainii. Shi i-otz doresc ashijderea sa groparesti pe net pana la vrasta \'naintata de care ziciai.',0,'1','Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.1.1) Gecko/20061208 Firefox/2.0.0.1','',0,0),(2046,412,'Groparu','groparu.ro@gmail.com','http://www.groparu.ro','82.77.126.254','2007-05-24 12:23:04','2007-05-24 10:23:04','@been there done: piranda o zis: \"discutam acasa\". Io zic ca-i ghe ghini...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(2662,461,'doroti','adela_maria7@yahoo.com','','86.121.178.203','2007-06-04 03:05:21','2007-06-04 01:05:21','ma dar tu esti chiar prot tu nu te uiti la tv sa vezi si tu k saracu Ralph nu sa aruncat singur pt k ii era frik de inaltime si a fost batut in garsonira si dupa aceea aruncat de la 9 mai uitativa si voi fratilor la tv',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(2652,461,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.112.22','2007-06-03 19:48:09','2007-06-03 17:48:09','Wooow, ce m-am distrat cetind comentariile unora! :D Ca sa le raspund in stilu\' lor, \"nu v-Äƒ aÅŸtept s-Äƒ reveniÅ£!\"\r\n\r\nÃŽmi pare rÄƒu ca media IQ-ului vizitatorilor groparului a facut un nose-dive weekendul asta din pricina unui pamflet. Tind sa-l aprob pe NÃ¢rÅ£oagÄƒ, ca zice bine cand zice: \"Vezi, monÅŸer? D-aia votul nu ar trebui sa fie universal! Parol...\"',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(2539,461,'zgura','ummm@ok.ro','','193.230.205.140','2007-06-02 00:03:26','2007-06-01 22:03:26','Gropare daca te ucizi, te omor cu mana me (de la maus). Sunt fanu tau numaru 1, ca formula .... aa .. cu flor, la mine pe scara. Atata imi place cum bloguiesti ca o sa fac un blog despre blogu tau cand vorbesti tu despre alte bloguri. Deci Groparu nu muri cacatine n-om gasi, parca....',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(2420,445,'Greuceanu','fm77roen@yahoo.com','','195.149.72.124','2007-05-30 13:58:43','2007-05-30 11:58:43','BAH!\r\n\r\nPielea mea!\r\n\r\ndesi este singura bautura alcoolika care nu-mi place nic o culoare..... jur ca de la anu trebe sa bem acolo numai ROM!!!!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(2530,461,'been there done that','lisca.ana@gmail.com','','82.208.154.111','2007-06-01 20:03:14','2007-06-01 18:03:14','utterly dissapointed.\r\nblogging is free, aparently for everybody. every single pesant out-there.\r\nyou are grose, and unbelivebly discusting. nothing sacred.\r\nce varsta ai? oricum pt varsta ta esti incredibil de imatur and worst than that, stupid.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(2083,439,'baghy','baghy83@lycos.it','','78.12.19.236','2007-05-24 21:52:22','2007-05-24 19:52:22','nasol.nasol.ai muncit mult la cartea aia?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(1921,411,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.112.22','2007-05-23 00:27:56','2007-05-22 22:27:56','Io numa atata stiu: ca too much luv will kill me, da\' o sa ma si resurrect! Parol...\r\n\r\nDeci o sa fie free for all? Nu melee?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(2322,439,'mishu','mishu@doingtheartwork.com','http://www.doingtheartwork.com','82.77.126.254','2007-05-28 10:55:00','2007-05-28 08:55:00','Ahaha, am si uitat de camera aia man. Da\' era profi, ai uitat sa le zici ca era cu film si tot tacamul :D Zi daca reusesti sa o vinzi:)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(2673,461,'oedip','oedip74@gmail.com','http://oedip.blogspot.com/','89.137.104.170','2007-06-04 16:05:47','2007-06-04 14:05:47','mah gropare mah, nu dai coltu... dai unghiu drept mah, prishepi? - haha\r\nhai noroc batrane!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(2093,412,'Greuceanu','fm77roen@yahoo.com','','195.149.72.124','2007-05-24 23:56:23','2007-05-24 21:56:23','Ori e aia nesimtzitzi ori e putzulika ta mika',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(2039,412,'eu','','','86.34.227.117','2007-05-24 10:19:35','2007-05-24 08:19:35','poate nu-l impungeai (numai) cu burta ta inexistenta, si atunci incepuse sa-i placa',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(1311,400,'Fana','stefana_catinas@yahoo.co.uk','http://mirandolina.wordpress.com','217.156.11.130','2007-05-15 18:02:52','2007-05-15 16:02:52','hahahahahahahahha, noroc ca e fecior de treaba, asta-i tare!',0,'1','Mozilla/5.0 (Macintosh; U; PPC Mac OS X Mach-O; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(2038,412,'moi','andreea_molocea@yahoo.com','','89.38.254.3','2007-05-24 10:19:21','2007-05-24 08:19:21','e mai nasol sa simti tu \"putulica\" cuiva. oricum, ai fost original. Nu se poate spune ca nu ai facut tot posibilul. am ras. o zi faina',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1)','',0,0),(2315,439,'katmai','katmai@keptprivate.com','http://www.512kbps.com','195.212.29.163','2007-05-28 09:48:10','2007-05-28 07:48:10','tare :))))) mai era Mintea Creata care se bucura acu fo doo` zile de faptul ca mie imi merge nasol :))) acu-i randu` meu .. ce tare-i :D hihihiihihhih',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7 (CK-IBM)','',0,0),(2082,439,'Marius','','','85.186.51.206','2007-05-24 21:15:07','2007-05-24 19:15:07','Ai o camera Olympia? Ma, ce misto, o cumpar io.\r\nFii atent, ca mi-a placut asta, stiu ca il stii, da-mi place mie sa-l scriu:\r\nItic si Strul se vad pe strada, Strul amarat de nu vedea bine si Itic vesel ca un mare patron. \"Ce-i cu tine mai Strul?\" zice Itic c-un zambet de 24 de karate. \"Lasa-ma mai, ca-s amarat, nevasta nu-mi da pace cu gradina aia care trebuie s-o sap, copiii plang toata ziua sa ma joc cu ei, casa mi se usca tot timpul si trebuie s-o ud sa nu crape si alte cate mai cate.\" \"Mai Strul tie iti trebuie un elefant, mai. Uite, io mi-am luat unu si e laser, frate: imi sapa in gradina, se joaca cu copii, imi stropeste casuta cu trompa si nici nu ocupa mult loc... doarme pe pres, in fata casei ca un catelus.\" \"Ia zi ma, nu-l vinzi?\" \"Nu pot Strul, ca ma paraseste nevasta, imi plang copii, mi se darama casa.\" \"Hai mai, iti dau dublu pe el fata de cat ai dat tu!\" \"Nu pot mai\" Pana la urma Itic ii vinde elefantul cu triplu suma. Dupa o saptamana, Itic vesel, Strul tot fript si amarat. \"Ce-i mai Strul?\" \"bai, elefantu asta mi-a daramat casa, mi-a scurmat toata gradina, copii se ascund si plang cand il vad, nevasta pleaca...\"Mai Strul, tu ai o problema, mai. Cu atitudinea asta tu n-o sa vinzi elefantul ala, mai.\" \r\nSpor la Tiganiada, sa ne dai poze.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(2080,439,'Glogovetan Tudor','tudor_glogovetan@yahoo.co.uk','http://photography2012.blogspot.com/','89.136.23.215','2007-05-24 21:10:53','2007-05-24 19:10:53','Ceapa ei de treaba mah gropare ! da la mine o vint un tzagan mai negru ca noaptea cu o camera foto  \'manglita dintr-un Metro sau ce mai este prin sibiu... si io tampu\' nu i-am dat nici 50 de lei pe ea. Si era camera buna.. pe eticheta (aia care o uitat so deie jos) scria 1799.99 :| .. Sony era.. mai zi ceva..',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(354,355,'Bogdan','publog.ltd@gmail.com','http://laschimb.blogspot.com','193.231.18.12','2007-04-28 23:03:41','2007-04-28 21:03:41','No, bun!\r\n\r\nDe la nunta direct la blogfest! \r\n\r\nNu stiu daca sa te felicit sau nu pt ca \"ai castigat\". Oricum, considerand  valoarea premiului, cred ca mai degraba tre sa te felicitam.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(357,355,'Denisa','denisalala@gmail.com','http://www.denisuca.ro/blog','86.123.36.173','2007-04-29 00:44:37','2007-04-28 22:44:37','Vreau sÄƒ fiu prima care te felicitÄƒ pentru cÃ¢ÅŸtigarea premiului pentru cel mai prost blog din Cluj. Acum rÄƒmÃ¢ne sÄƒ-Å£i Ã®ndeplineÅŸti - sau nu, cÄƒ tot e la modÄƒ - promisiunile din campanie. :)\r\nFelicitÄƒri, la anul te nominalizez EU unde meriÅ£i!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(1300,398,'Mihai','mhangansv@yahoo.com','','81.196.150.96','2007-05-15 14:41:33','2007-05-15 12:41:33','Vodcaroiu... :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(2313,441,'katmai','katmai@keptprivate.com','http://www.512kbps.com','195.212.29.163','2007-05-28 09:45:36','2007-05-28 07:45:36','ce dracu e tiganiada aia totusi???',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7 (CK-IBM)','',0,0),(2480,460,'baghy','baghy83@lycos.it','','78.12.3.208','2007-05-31 23:58:40','2007-05-31 21:58:40','tare articol',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(2481,460,'ale','muketza88@yahoo.com','','86.120.20.35','2007-06-01 00:01:27','2007-05-31 22:01:27','nmk de comentat',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; FunWebProducts; SIMBAR={6896AD17-AAEC-4d20-A0BE-40BE0035E8E4})','',0,0),(1912,419,'Greuceanu','fm77roen@yahoo.com','','195.149.72.124','2007-05-22 22:16:34','2007-05-22 20:16:34','MO,\r\n e 100% adevarat! Nu e multi cei ce traiesc cu adevarat aceste senzatii!  imi aduce aminte faptul ca tu ejti unul dintre cei ce aplauda.... imi aduce aminte de un \"proverb\" american.... -\" Stii de ce nu suntem toti eroi?! ca doar noi, oamenii, am nascut notiunea de \"erou\".  Pentru ca avem din cand in cand nevoia sa stam la coltz de stradutza shi sa aplaudam atunci cand trec eroi adevarati...\".',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(2534,461,'baghy','baghy83@lycos.it','','78.12.3.208','2007-06-01 20:50:15','2007-06-01 18:50:15','nu stiu de unde le mai scoti.ai imaginatie.oricum pentru mine esti cel mai tare blogger.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(2079,412,'alex-glock18','alex_glock18@yahoo.com','','80.97.50.2','2007-05-24 20:49:41','2007-05-24 18:49:41','in iasi am trait sa vad cum un sofer de autobuz a oprit harabaua ca sa dea jos un asemenea specimen dupa ce oamenii incepusera sa faca scandal ca le cade nasul. si asta dupa o statie :D.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.0.11) Gecko/20070312 Firefox/1.5.0.11','',0,0),(1211,389,'Groparu','groparu.ro@gmail.com','http://','82.77.126.254','2007-05-14 15:19:34','2007-05-14 13:19:34','Da, sh d-ai s-o tot revarsat pi blog, tuata...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,2),(1210,390,'gyozo23','','','85.55.160.24','2007-05-14 14:53:57','2007-05-14 12:53:57','hat drega io nu superman, dar trebuie sa spun ca e un pic fals. Suntem muuuuuuuuuuuuuuuuulti rumanashi prin epania (con accento andaluz) si intradevar suntem varza la epanyol. da nici multi colegi epanyoli nu am avut care sa invete argyeleneasca noasta.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(1882,411,'Groparu','groparu.ro@gmail.com','http://www.groparu.ro','82.77.126.254','2007-05-22 10:46:24','2007-05-22 08:46:24','Crezi ca e usor sa faci o insula de tiganie intr-o mare de latinitate dintr-o mare de slavi?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(1209,396,'Sorinelu\'','sorinelm@gmail.com','','82.77.126.35','2007-05-14 14:13:03','2007-05-14 12:13:03','VOTAT',0,'1','Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.0.11) Gecko/20070327 Ubuntu/dapper-security Firefox/1.5.0.11','',0,0),(1913,423,'Greuceanu','fm77roen@yahoo.com','','195.149.72.124','2007-05-22 22:20:54','2007-05-22 20:20:54','Hi! ai\'m back! \r\n\r\nca-n poker, ca jtiu ca altfel nu gatam niciodata.... pulsez cu sec sh gata!   Arghezi parca o fost primu care a zis public ca Regele se besheshte... shi a azis-o in publik (in versuri0!   te deranjeaza sa jti ca presedintele tau nu e Super-super man, ca vomita, cadumnezeieshte shi-shi baga pola?! sincer, macar presedintele meu o recunoaste si-si cere scuze! cel fara de pacat sa arunxce piatra! Hrusciov si-a pus o lume la picioare! fa-mi moftul si lasa-ma sa cred in el! Baga-mi-ash!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(1293,396,'katmai','katmai@keptprivate.com','http://www.512kbps.com','195.212.29.187','2007-05-15 12:34:00','2007-05-15 10:34:00','gud. ala e buletin de vot pe placu` meu',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7 (CK-IBM)','',0,0),(1204,390,'katmai','katmai@keptprivate.com','http://www.512kbps.com','195.212.29.163','2007-05-14 12:46:28','2007-05-14 10:46:28',':))))))))))))))))))))))))))))))))))))))))))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7 (CK-IBM)','',0,0),(1205,390,'katmai','katmai@keptprivate.com','http://www.512kbps.com','195.212.29.163','2007-05-14 12:46:55','2007-05-14 10:46:55','a am uitat sa adaug . suntem 4 romani in team, si au venit 2 indieni. :))) le-am explicat gingas ca trebe sa invete romana :)))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7 (CK-IBM)','',0,0),(2377,442,'Groparu','groparu.ro@gmail.com','http://','89.137.112.22','2007-05-29 23:00:44','2007-05-29 21:00:44','Auzi, tu aici crezi ca ai dat de tigani care-sh vinde fiiii?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,2),(1437,406,'Paszti','pasztorjozsef@yahoo.com','','81.12.230.166','2007-05-17 10:54:48','2007-05-17 08:54:48','Cauta o lama buna;)\r\nDa adresa mosului sa nu mai puna nimeni piciorul acolo.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1)','',0,0),(1289,396,'Marius','','http://lityx.blogspot.com','86.35.157.42','2007-05-15 09:12:34','2007-05-15 07:12:34','Votat. Ma ofer sa facem o campanie. Agri culturala.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(2376,445,'Groparu','groparu.ro@gmail.com','http://','89.137.112.22','2007-05-29 22:55:40','2007-05-29 20:55:40','Io-s tigan clujean arian sibian betzivan.\r\n\r\nSh paru meu are sh o pata blonda, nu-tz zÃ¢c unde.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,2),(1436,396,'Groparu','groparu.ro@gmail.com','http://','82.77.126.254','2007-05-17 10:35:07','2007-05-17 08:35:07','Da-mi-o inapoi!!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,2),(2378,445,'Crang','remusmitroi@yahoo.com','','86.122.53.26','2007-05-29 23:05:08','2007-05-29 21:05:08','amu puteti cu toti zari ca de cand cu tiganiada s-o cam terminat cu discriminarile romului de catre rom. Amu doar s-a descoperit ca doar romul il poate exploata pe rom si doar in interesul comun al amanduora.Noi am demonstrat ca in aceasta excursie timp de trei zile am trai, ne-am vestimentat, si ne-am hranit tiganeste (sau romeste ), si nu am fost supusi nici unei discriminari oricat de nesemnificative ar fi fost ea, mai putin cele atrase de propriul comportament.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; .NET CLR 1.1.4322)','',0,0),(1881,411,'been there done that','lisca.ana@gmail.com','','82.208.154.111','2007-05-22 09:49:18','2007-05-22 07:49:18','mai lasa remniscentele..... ur gettin\' softy.. :D\r\nastept cu nerabdare review-ul acestui week-end. \r\nsau nu?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(2077,439,'alex-glock18','alex_glock18@yahoo.com','','80.97.50.2','2007-05-24 20:43:40','2007-05-24 18:43:40','naspa combinatie, am ramas fara cuvinte :x',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.0.11) Gecko/20070312 Firefox/1.5.0.11','',0,0),(1193,388,'Andreea MKT','supergirgir@yahoo.com','http://marlahermina.deviantart.com/gallery/','82.77.126.254','2007-05-14 09:05:06','2007-05-14 07:05:06','Faza reala: \r\n2001\r\nrestaurantu din NY (unde varu-miu e manager)\r\no organizat ceva Revelion\r\nceva party\r\nceva panarama de chef multinational\r\nsi la 12 noaptea s-o suit pe scena un negru si o cantat la microfon\r\n\"M-a facut mama oltean\"',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(1877,411,'cetitoare','totmea@yahoo.com','','86.35.232.96','2007-05-22 08:35:38','2007-05-22 06:35:38','Hiiii! ce-am uitat?! riuard: multe multe molecule de alcool.\r\n\r\nSherifa.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(2359,445,'Greuceanu','fm77roen@yahoo.com','','195.149.72.124','2007-05-29 12:16:58','2007-05-29 10:16:58',':))))\r\n\r\nMah tu nu iejti normal! trebe sa va zic io ceea ce s-o predat la jkoala Tziganilor cand asta, adika, Ielvis \"era dupa creta\" adika in zioa de sambata a reusit sa se imbete de 3 ori. enumar orarul sau de  \"semi - meta- trezie\": 08.32 - 11.18; 13.02 - 15.41; 20.01 - 24.12; ceea ce relateaza Ielvis este o amestecatura din cele trei mari ere bazavaniene, marcate fiecare de cateva faze: perioada I: nasterea, ascensiunea, punctul culminant si apusul; faza II: nasterea si punctul culminant; faza III:ascensiunea - stingerea.\r\n\r\nBatalia cu urzici:  Nu am cuvinte in aceasta limba romaneasca sa va descriu senzatia ce te incearca cand o intreaga tufa, cu radacina cu tot, de urzici inalta cam cat Suciu, incep dansul lor tumultuos intre triceps si marele dorsal!  Nu va pot relata cum poate o fiinta umana ne-posesoare de labii, sa opreasca jetul de bere distilata cand incerci sa te aperi de atacul urzicilor ucigase, nemiloase, saltarete si fara de epuizare, cu mainele goale!\r\nDar poate Ielvis va poate esplika ce inseamna sa maturi cu aceeasi tufa locul cel mai putin vazut de lumina..... adika acolo unde se incheie barbatu cand e gata crosetat! adika intre anus sh scrot!!!  Dupa aceste altercatii, a urmat o repriza de decathlon printre munti, pietre balegari rauri etc.\r\n\r\nDe moment cred ca am fost cam imreuna dupa creta......',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(2336,442,'baghy','baghy83@lycos.it','','78.12.12.143','2007-05-28 21:43:23','2007-05-28 19:43:23','gropare hai si cu urmatoarele episoade',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(2674,462,'oedip','oedip74@gmail.com','http://oedip.blogspot.com/','89.137.104.170','2007-06-04 16:07:22','2007-06-04 14:07:22','merci mah ca l-ai preluat ca ramanem io cu el in brate :)))\r\nsi ma trezeam ca-s ca la fotbalu de la noi - io centrez, io sar la cap, io ratez :DDD',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(1373,47,'Nascut din spermatozoizi campioni &raquo; Blog Archive &raquo; Tiganiada 2007 - the final countdown','','http://www.groparu.ro/?p=405','69.16.239.16','2007-05-16 16:26:15','2007-05-16 14:26:15','[...] Mai pe romaneshte: AMR-ul descreste. Read last year&#8217;s story here. [...]',0,'1','Incutio XML-RPC -- WordPress/2.1.2','pingback',0,0),(1372,402,'Groparu','groparu.ro@gmail.com','http://www.groparu.ro','82.77.126.254','2007-05-16 11:16:50','2007-05-16 09:16:50','@ Varza: da-mi trimetz un cangur? sa fac sarmale din carne de cangur? Si da, da. Am influenta. Influentez mustele care se pune la mine pe gura si in nari, ca la copiii aia gravizi din Etiopia.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(2522,461,'NRGY','nrgy@idilis.ro','http://nrgy.xhost.ro','86.121.178.154','2007-06-01 17:07:06','2007-06-01 15:07:06','Ietate ca ai desenat ici taman doleantele mele. Si daca mii de pizde o sa`mi lase si mie, dupa ce voi bate cuba cu eternitatea, comentarii extatice pe al meu hi5 profil atunci o sa fie absolut sublima ducerea`mi pe lumea ailalta.\r\n\r\nHowgh!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(2371,442,'been there done that','lisca.ana@gmail.com','','82.208.154.111','2007-05-29 21:46:43','2007-05-29 19:46:43','auzi gropare? m-am inamorat profund de prietenul tau ala cu multe ghiuluri, chimesa alba si un lant gros de aur la gat, si pantaloni negri, si haina neagra de piele.\r\nne faci lipeala?\r\n:D',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(2328,442,'Ascunsu','pagini_ueb@yahoo.com','http://special-emoticons.blogspot.com/','86.122.8.62','2007-05-28 16:11:15','2007-05-28 14:11:15','pa tu amu zici ca ai fo unde ai fo? t-o fo frica sa nu vinim si noi? :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(2022,412,'been there done that','lisca.ana@gmail.com','','82.208.154.111','2007-05-24 06:48:54','2007-05-24 04:48:54','omg. asa ai ajuns? te dai prin troleuri la barbati? ce zice piranda ta? :P',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(1122,392,'Groparu','groparu.ro@gmail.com','http://www.groparu.ro','89.137.112.22','2007-05-13 02:35:17','2007-05-13 00:35:17','...more on ze Jermanz: http://uk.reuters.com/article/oddlyEnoughNews/idUKL1160419820070511?rpc=92',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(565,374,'Gez','geza@dvis.info','http://groller.info/geza','89.137.114.63','2007-05-04 12:12:47','2007-05-04 10:12:47','Pacat ca nu pot da edit... sa completez, o facu tu pt mine:\r\n\r\nTin minte la alimentara cand stateam la coada sa cumpar paine, trebuia musai sa iau si un kil de peste puturos din cale-afara\r\n\r\nMai tin minte ca trebuia sa stau la coada la butelii cu schimburi, de pe la 2-3 dimineata pana pe la amiaza (toata familia ajungea sa stea la coada prin rotatie)... cand sosea camionul (am crescut in Simleu Silvaniei si abia acu 2 ani a ajus gazul acolo ... ) astia de prin Cluj nu cred ca stiu de faza cu coada de la butelii :) \r\n\r\nSi luam cate 2 ca aveam o butelie mare ruseasca rosie, in care incapeau doua din astealalte mai mici, si o umpleam pe balcon ... durere!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(510,360,'Groparu','groparu.ro@gmail.com','http://www.groparu.ro','89.137.112.22','2007-05-02 19:51:52','2007-05-02 17:51:52','Hmmm... oare sa fie Vacaroiu singurelu\' care le gusta? Nu cred',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(511,357,'Groparu','groparu.ro@gmail.com','http://www.groparu.ro','89.137.112.22','2007-05-02 20:06:18','2007-05-02 18:06:18','Mie-mi spui! Numa sa stii cum sa-l gasesti, mai ales daca-l cheama G. Nice story, BTW... :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(509,368,'Groparu','groparu.ro@gmail.com','http://www.groparu.ro','89.137.112.22','2007-05-02 19:50:23','2007-05-02 17:50:23','Te-nteleg... io azi n-am condus deloc, si tot pic de somn.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(1977,438,'m0Fo','sourcer@gmail.com','http://google.jp','86.55.227.69','2007-05-23 16:33:04','2007-05-23 14:33:04','... il recitam :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(1755,423,'Greuceanu','fm77roen@yahoo.com','','195.149.72.124','2007-05-20 22:45:06','2007-05-20 20:45:06','Gropare....\r\nTu jti de ce i-o loat Base telefonula fufulika aia?! stai sa-tz zic io in doo vorbe: imagineaza-ti situatia: ejtiin mijlokul ticalosilor aliati tatzi impotriva ta, ticalos si tu, dar parca aia e mai ticalosi ca tine... te freaca de te indoaie, iti demit toti consilierii si toata oligarhiutza ... perzi bani, pueter, nu dormi noaptea, te freaca mitingurile, drumuri, pervershi de ziarishti ce abia asteapta sa gaseasca ceva de interpretat ca sa te beleaska.... sh, asha futut din toate partile, \"sustinut\" numai de un boc caruia-i clantane dintii in tot timpul in ceafa ta, stresat de de PR-ul tau, cu emotia cat caru\' in timpul referendumului, apare o gasculitza de asta care i se pare ca-i mare paparazzi si te fute cu intrebari la care ai raspuns deja de 1000 de ori cand tu, de fapt vrei sa te decizi daca iti iei Borsec sau Vatra Dornei.  te cicaleshte asha cum numai o muiere shtie sa faca, ii presara un pic din tupeul tipic bucurestean, si pur si simplu iti sare mujtaru\' si-tzi scapa un sincer:\"auzi tu?! bagami-aj\'..... ce pilelea mea vrei?! tz-am zis de 10 ori lasa-ma in kilu\' meu in pace?! ia mai da-te\'n cacatu meu de... pasarika...\", mo, nu0tz gati vorba de zis sh vezi ca muierea cicalitoare zambejte satisfacuta cu telefonul in mana ca le va rupe ea gura colegilor de redactie cu story-ul ei&gt;  Ce dreaku faci?! de la telefoanele astea nu prea jti ce sa te ajtepti.... de da habauka pe post treaba, ai chert 12 %, de te bagi pe la spate sa nudea.... trebe sa te pui bine cu PC-ul.... shi, prin urmare, hatz! apuci telefonul si vezi tu cum rezolvi... apoi zici ca-mi pare rau.... ca mi-am pierdut cumpatul ca eram agitat etc sh aia ma stresa... sh gata!\r\n\r\nPoatae o fi sunat la vreun var din spania de pe telefonu ei, mai jti?!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(1368,400,'Groparu','groparu.ro@gmail.com','http://www.groparu.ro','82.77.126.254','2007-05-16 09:09:39','2007-05-16 07:09:39','There you go, I look like Anus :|',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(564,374,'Gez','geza@dvis.info','http://groller.info/geza','89.137.114.63','2007-05-04 12:08:14','2007-05-04 10:08:14','Vezi ca ai la linkul fenomental http://http:// ... sa corectezi :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(506,368,'katmai','katmai@keptprivate.com','http://www.512kbps.com','195.212.29.187','2007-05-02 18:56:37','2007-05-02 16:56:37','mie mie somn... am condus azi.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.8) Gecko/20050511 Firefox/1.0.4 (CK-IBM)','',0,0),(507,360,'katmai','katmai@keptprivate.com','http://www.512kbps.com','195.212.29.187','2007-05-02 18:58:20','2007-05-02 16:58:20','cineva e beat in mailu ala?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.8) Gecko/20050511 Firefox/1.0.4 (CK-IBM)','',0,0),(557,373,'Groparu','groparu.ro@gmail.com','http://www.groparu.ro','82.77.126.254','2007-05-04 09:10:12','2007-05-04 07:10:12','True! Vroiam sa vad daca te prinzi, ma Ionutz.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(558,373,'phoenix','','','89.121.185.108','2007-05-04 09:55:03','2007-05-04 07:55:03','mai degraba RATUC - regia absoluta de tocat unii calatori',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(2416,441,'Diana','blue10ro@yahoo.com','','193.0.225.44','2007-05-30 12:41:28','2007-05-30 10:41:28','Pe cand un dans a la Chocolat? :)) Ma bucur ca te-am revazut, Radule, ai adresa mea de mail, poate ne vedem la o bere, ca tot m-am mutat la Cluj... Si trebuie sa ne intalnim, sa sarbatorim n ani de cand am terminat faculta ... By the way, Sasa iti trimite salutari! Pupaturi tuturor!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(502,357,'catalin','solo@xsolo.biz','http://xsolo.biz','201.231.176.35','2007-05-02 17:13:03','2007-05-02 15:13:03','Eram in India cu 2 prieteni si unu din ei era cu prietena dupa el, ea mai mica, bruneta si par negru. Cam toti indienii se luau de ea, crezind ca ar fi localnica care umbla cu straini. Multe discutiiiii ...etc...Pina la urma si-a pus un punct in frunte si gata! Nimeni nu i-a mai zis nimic. Asa ca un punct bine plasat face cit o gramada de cuvinte :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(524,368,'c.c.','aa@aa.com','','89.120.198.224','2007-05-03 09:56:35','2007-05-03 07:56:35','Fa-i o rama de icoana...  eu zic ca da mai bine, ce spui? :p',0,'1','Mozilla/5.0 (Macintosh; U; PPC Mac OS X Mach-O; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(1261,396,'Bogdan','bogdancri@gmail.com','http://www.telepedia.ro','86.126.172.71','2007-05-15 02:49:11','2007-05-15 00:49:11','Vreau si eu...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(526,368,'Groparu','groparu.ro@gmail.com','http://www.groparu.ro','82.77.126.254','2007-05-03 10:35:14','2007-05-03 08:35:14','Nu, ca n-am ce prunc sa-i pun in bratze :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(2375,445,'been there done that','lisca.ana@gmail.com','','82.208.154.111','2007-05-29 22:05:18','2007-05-29 20:05:18','nu prea aveti sanse.\r\nsunteti clujeni 100% din nefericire. aveti si accent de clujeni. iar tu gropare, ai par roscatel, tigan, n-ai sa ajungi never. unfortunatelly.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(1864,411,'cetitoare','totmea@yahoo.com','','86.106.49.143','2007-05-22 07:04:03','2007-05-22 05:04:03','WANTED!',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1)','',0,0),(1117,392,'me','','http://mymosh.blogspot.com','81.181.174.112','2007-05-13 00:31:54','2007-05-12 22:31:54',':)))) foarte tare articolu\'...no servus mah...vin\'ncoace sa te pup',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(1029,378,'madfox70','ritmic.club@gmail.com','http://www.ritmic.lx.ro','84.232.158.6','2007-05-11 08:10:03','2007-05-11 06:10:03','Mi-a fost lene sa citesc tot ... despre ce era vb?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(1362,402,'cetitoare','totmea@yahoo.com','','86.35.232.96','2007-05-16 08:30:51','2007-05-16 06:30:51','Hahahaha! Unde dai si unde crapa!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(1361,400,'','','','86.122.68.189','2007-05-16 07:22:40','2007-05-16 05:22:40','Coprea nu e Fecior, in primul rand, Coprea e un original dus cu pluta pe Somesh, am vrut sa ii iau cadou dar m-am razgandit, nu ii gasesc nimic, dar no....32 de ani e o varsta. Cat despre tine Radu, aratzi ca McManus din OZ- Inchisoarea Federala. Gata, am gasit personaju!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.0.11) Gecko/20070312 Firefox/1.5.0.11','',0,0),(1113,392,'Glogovetan Tudor','tudor_glogovetan@yahoo.co.uk','http://photography2012.blogspot.com/','89.136.23.215','2007-05-12 22:47:14','2007-05-12 20:47:14','no si ziceai ca la bolta aia nemtzasca scria in romaneste sa nu fure lumea ( care e romani). Pai stai linistit ca asa e peste tot in tarile estea \"civilizate\". in italia de ex.. intr-on bar.. sau crajma.. era pus un abtzibild pe care scria, tot in cea mai pura romana: \"ca sa nu va pishati pe langa buda, ca sa nu luati (toata) hartia igienica acasa, ca sa va spalati si uscati pe maini, ca sa folositi sapunul, ca sa , ca sa si asa mai departe. deci.. io zic sa ne apucam sa blindam usile de la buzile din romania cu un strat gros de instructiuni de folosire a toaletei in tate limbile civilizate. ca no.. numa neamtzu sa aiba?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(462,355,'sageata2002','','','89.137.104.156','2007-05-01 20:39:28','2007-05-01 18:39:28','tre\' sa zic ca sunt interesanti dentistii astia de se impreuneaza; stiu ei de ce si nu vreau sa-i porcaiesc la tine pe sait. as prefera laiv',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(556,373,'Ionut','ionutzstroe@yahoo.com','','89.121.185.108','2007-05-04 08:49:36','2007-05-04 06:49:36','RATUC - Regia Autonoma de Transport Urban de Calatori.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(1360,402,'varzastricata','tudor.maris@gmail.com','http://rottencabbage.ablog.ro','58.170.195.152','2007-05-16 07:20:04','2007-05-16 05:20:04','Maaama, te-am prins. Deci imi trebuie asa: masina cu 4 usi, bicicleta mov, salar de 4000 de euro fara loc de munca, 7 bisexuale deschise la minte si cu fizic de penthouse, un porc, 140 de ani de noroc (sa ramana si la copii, saracii), un cal cat mai mare cu putinta - pe GPL ca n-am fan, o borseta cu www.groparu.ro, inca un porc. \r\nAvand in vedere ca esti persoana cu cea mai multa influenta pe care am cunoscut-o in viata mea, te rog sa ai in vedere cele de mai sus.\r\nPS: Serios vorbind - super tare frate!',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(2356,442,'Greuceanu','fm77roen@yahoo.com','','195.149.72.124','2007-05-29 11:39:05','2007-05-29 09:39:05','Treaba e ca atuncea cand dai in ceva.... habar nu ai ce se va intampla... io mi-am facut mashina cu cu My Troy SRL, sa se citeasca sh de pe luna daca se vede mashina, ca sa vada lumea frumusetxe de brand.... sh taman unde cautai tu, ma vako, in gunoi, cu toate mashinile parkate, taman s-o nimerit sa fie in fata la jkoala unde taicami-o e dirig si prof de romana-engleza..... iar ieri....\" pai mai copii mai.... cum dreaku ati ajuns in valea aurie sa ma faceti de rusine sh acolo mah?! ca cand ztii ieshit de la mine din curte mi-o fost rusine sa ies din curte sa ma vad cu vreun vecin, ca trebuia sa ii esplik ce-i cu atatia tigani la mine, sau ce dreaku de preteni are fiu-mio ca la 40 de ani az maine mere la bal maskat pe strada.... dar v-ati dus si ati bagat manele sh ati cautat prin gunoaie in fata jkolii.... sa-mi zica copiii si colegii a doa zi....dom\' profesor! dom\' profesor! va-m vazut masinile de la firma pline de tzigani care ascultau manele!!!! beac! v-au furat  mashinile?!\"',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(2362,445,'koyrosh','a@a.com','','82.77.126.254','2007-05-29 14:50:26','2007-05-29 12:50:26','tin sa protestez! am fost cel mai ostracizat personaj din toata tziganiada: am patimit cel mai mult in si intre erele lui ielvis. am fost lovit, schinguit, scuturat, trantit, inghetzat bocna in vale si, capac la toate, astea s-au petrecut pe un soare ucigash, fara sa se interpuna nimic intre mine si el. ielvis jtie de ce!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(2361,445,'Andreea MKT','supergirgir@yahoo.com','http://marlahermina.deviantart.com/gallery/','82.77.126.254','2007-05-29 13:55:57','2007-05-29 11:55:57','ma declar complet satisfacuta de tziganiada de anul asta',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(1471,405,'varzastricata','tudor.maris@gmail.com','http://rottencabbage.ablog.ro','124.180.217.164','2007-05-17 23:58:00','2007-05-17 21:58:00','Fain filmu. Ce tril are dom\'le ala cu palarie, ceva de vis :D Nu voi comenta prin acest post baia la comun pe acordurile \"Candy Shop\"......',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(1383,405,'Andre MKT','','','86.106.55.69','2007-05-16 20:11:59','2007-05-16 18:11:59','io va iubesc, mah!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(1011,387,'Kissu','','http://www.pacurar.net','82.208.134.29','2007-05-10 23:34:55','2007-05-10 21:34:55','Bah Baza... daca tot nu vii la serviciu ca esti bolnav, cu muci verzi... culca-te bah tata, sa te hodinesti si sa te insanatosesti, ca de luni avem de lucru cacalau! Asa ca nu mai scrie bloage la tri noaptea si pune mana si te culca mai devreme... ;)\r\n\r\n:p\r\nAl\' din stanga ta...',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1)','',0,0),(2337,442,'mistra','','','86.126.12.179','2007-05-28 22:12:45','2007-05-28 20:12:45',':))))))))))))))))))))))))))...nu am mai ras de mult asa de tare.....',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(1250,396,'Groparu','groparu.ro@gmail.com','http://www.groparu.ro','89.137.112.22','2007-05-15 01:26:56','2007-05-14 23:26:56','Is puse bine acolo unde scrie CNP-ul de pe buletin(ul de vot).',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(2360,445,'Luna Betiluna','mihdana@yahoo.com','','82.76.46.190','2007-05-29 13:08:03','2007-05-29 11:08:03','Nene Greucene, am dat si io ochii roata dupa Troia voastra, da` un alt nene mare, negru si urat zicea ca s-a suspendat, taman cand voia si mandea sa vaza cu ce-i aburiti p-ailalti in timpu` liber (ca timpu` ocupat mi se pare clar ala din Vale). So, se mai egzista au ba? Au e doar suspendata? :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.0.10) Gecko/20070216 Firefox/1.5.0.10','',0,0),(1064,388,'Groparu','groparu.ro@gmail.com','http://www.groparu.ro','89.137.112.22','2007-05-12 02:14:34','2007-05-12 00:14:34','...cum zice Margi\': \"ma cinsteshteee timishorenceleeee...\"\r\n\r\nSi acolo la restaurant avetz si tiganci cu Bindi in frunte?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(1248,396,'De aia','sdeew@yahoo.com','http://de-aia.blogspot.com','89.137.116.226','2007-05-15 01:07:18','2007-05-14 23:07:18','bag si eu tot ce trebe. de unde iau stampila? :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.2) Gecko/20070219 Firefox/2.0.0.2','',0,0),(1016,387,'Groparu','groparu.ro@gmail.com','http://www.groparu.ro','89.137.112.22','2007-05-11 00:26:04','2007-05-10 22:26:04','Ba Kissu, inciarca tu, ba, sa dormi cand te scoli la 1 jumate nuaptea ca nu poti respira ca nu ai picaturi de infipt in nas si iti sta mucii ca stalactitii in nari, si nu se da scoshi, si ti se intzapa ganglionii in beregata ca cuiele in Iisusi, ba... \r\n\r\nMai am otzara si regret zilele cand meream la serviciu!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(1017,387,'Groparu','groparu.ro@gmail.com','http://www.groparu.ro','89.137.112.22','2007-05-11 00:31:27','2007-05-10 22:31:27','....si stai, ca nu am apucat sa iti zic nimic de curva aia de masea de minte careia fix amu i-o trebuit sa imi aduca aminte ca o am! Am fo\' la stomat-oloaga si mi-o bagat vreo tri siringi inuntru cu apa oxigenata... cica sa spele! Macar daca avea lenjerie de piele, ma-ntelegi?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(2059,411,'Carlanu`','','','86.122.54.78','2007-05-24 16:57:09','2007-05-24 14:57:09','RRRRRRRRRRRaaaaa!!!!!',0,'1','Mozilla/5.0 (Windows; U; Win98; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(1986,412,'cetitoare','totmea@yahoo.com','','86.106.49.143','2007-05-23 19:17:44','2007-05-23 17:17:44','poate ca era deja decedat, daca putzea, nu misca si nu se impresiona de...putulica ta!',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1)','',0,0),(4016,526,'Groparu','groparu_ro@gmail.ro','http://www.groparu.ro','82.77.126.254','2007-07-19 11:05:59','2007-07-19 09:05:59','Ba, deci lipovecii e cumva persoanele alea din spatele sfarcelor lor? Sau aia din fatza sfarcelor mele, aia pe care i-am vazut acolo? Cum poate exista aceeasi forma fizica in doo coordonate complet diferite? Phuii mei! Ca io nu stiu...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(1058,389,'o oitza','fenhuvc@yahoo.com','','24.17.110.178','2007-05-11 21:00:11','2007-05-11 19:00:11','and we should care because...??',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(548,374,'Razvan Antonescu','razvan.antonescu@gmail.com','http://idei-locale.blogspot.com','86.122.70.242','2007-05-03 22:22:04','2007-05-03 20:22:04','Mi lene si mi somn da mai erau bananele verzi si oraselul copiilor cu mos gerila. \r\nManifestatii pompoase de 23 august (sa il fut in gura pa bou care o pus ziua nationala in mijlocu iernii sa mancam fasole cu carnati la popota armatei). \r\n\"Dnul Antonescu haideti la scoala ca plodu o gasit manifeste legionare la tara si o aflat ala de la judet care are plodu la noi in clasa\"\r\nSoimii patriei si pionierii si cutezatorii samd\r\nCasa pionierilor \r\nCiresarii\r\nHerpesu pizdii masii care m-o impiedicat sa pup conducatorii iubiti ca mandru si vajnic comandant de departament\r\nTelecoloru \r\nSeriile Delfin/Enigma/Jules Verne\r\nToate Panzele Sus\r\nCenaclu Flacara pe care il ragneam de frica cand ma lasau barbarii acasa si se lua curentu\r\nEuropa Libera. Palme dupa cap pentru spus bancuri de la Europa Libera la scoala\r\nConcediile sindicaliste la mare.\r\nDa maaaaaaaaaaaaa is multe ;)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.0.11) Gecko/20070321 Firefox/1.5.0.11 Flock/0.7.12','',0,0),(1214,396,'sabina','','','89.137.112.22','2007-05-14 16:30:54','2007-05-14 14:30:54','votat',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(544,371,'mea','totmea@yahoo.com','','86.106.49.143','2007-05-03 18:23:03','2007-05-03 16:23:03','Pardon! M-a luat.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1)','',0,0),(545,371,'Piticu21','piticu@piticu.ro','http://www.piticu.ro','89.165.215.227','2007-05-03 20:22:25','2007-05-03 18:22:25','vaai ... rau ai facut :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(2056,437,'Andreea MKT','supergirgir@yahoo.com','http://marlahermina.deviantart.com/gallery/','82.77.126.254','2007-05-24 15:10:04','2007-05-24 13:10:04','barba aia ma face si pe mine sa cad in pacat:)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(2054,412,'katmai','katmai@keptprivate.com','http://www.512kbps.com','195.212.29.187','2007-05-24 14:22:48','2007-05-24 12:22:48','tebea sa ii futi una si sa il inviti sa mearga in pizda masii sa moara acasa. sau macar sa se spele cand pleaca in oras. bleah. la chestia asta sunt total agresiv. nu ma intereseaza ca au 60 ani, chiar deloc. dar atunci cand ies in oras si scot sconcsu` din vizuina si merg pe mijloacele de transport in comun ca si cum nimic nu s-ar intampla. da-o in ma-sa de treaba, si de cele mai multe ori motivul pt care ii vezi pe autobuze si tramvaie e ca sa isi termine bilelele moka, ce plm sa se plimbe macar de ele. gura',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7 (CK-IBM)','',0,0),(2057,437,'Groparu','groparu.ro@gmail.com','http://www.groparu.ro','82.77.126.254','2007-05-24 15:26:33','2007-05-24 13:26:33','Da, da\' barba mea e mai faina!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(1892,411,'carlanu`','','','193.151.30.56','2007-05-22 13:50:55','2007-05-22 11:50:55','sper sa faci indigestie mancandu-mi poya\r\nterorist de guerilla din industria soft',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(1042,387,'Kissu','','http://www.pacurar.net','82.77.126.254','2007-05-11 13:46:52','2007-05-11 11:46:52','No bine mah Bazaaaa....! Hai, treaca mearga... numa\' sa nu mori, ca dup-aia cine dreq mai scrie bullshituri comerciale pentru fraieri?!... ;))\r\n\r\nHai sa fii sanatos! Si vezi, imbraca-te bine ca in zilele urmatoare se anunta la Cluj canicula de 31 grade Celsius, sa nu cumva sa racesti si mai tare decat esti deja! ;))))\r\n\r\n:-h\r\nKissu',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(538,371,'Groparu','groparu.ro@gmail.com','http://www.groparu.ro','82.77.126.254','2007-05-03 16:06:20','2007-05-03 14:06:20','Da.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(2063,423,'Razvan Nation','bluedeathgraz@yahoo.com','','69.114.43.133','2007-05-24 18:33:25','2007-05-24 16:33:25','Daca si cu Parca se plimbau intr\'o barca..',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(1004,381,'Mimoza','qurli19@yahoo.com','','89.38.91.7','2007-05-10 22:15:24','2007-05-10 20:15:24','iti aduci aminte de reclama knd Dumnezeu sta pe un puf de norisor si sta in acelasi timp p net (k doar le poate p toate).... eu te rog, personal, sa`i spui sa`ti traga si tie un fir, sa continui blogul. da` acum ce nume v`a avea blogul: .... in cautarea taramului de nicaieri?... povestiri de departe?... ei kkt, t las p tine la nume.... â€œDe la Nistru panâ€™ la Tisa, toata MISA pishu-mi-s-aâ€...=))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(2051,437,'Luna Betiluna','mihdana@yahoo.com','','82.76.46.190','2007-05-24 13:46:59','2007-05-24 11:46:59','Ioi, Domne, inca unu ! Groparule, nu manca tortu` singurel, ca te strici la matze (alea de ghioraie, nu alea de miorlaie) si n-o sa te mai placi, finca o sa te cazezi in buda si-o sa putzi :))) ...... si pe cine-o sa mai dragaleshti tu cu-atata pasiune? vai, vai.......',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.0.10) Gecko/20070216 Firefox/1.5.0.10','',0,0),(536,371,'mea','totmea@yahoo.com','','86.35.232.96','2007-05-03 15:37:55','2007-05-03 13:37:55','Uauuu! Ai gasit un sofer RATUC simpatic????? Cu simtul umorului? Si mai si frina decent? Sau inventezi? Nu ma bulversa, te rog.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(2052,437,'Groparu','groparu.ro@gmail.com','http://','82.77.126.254','2007-05-24 13:48:20','2007-05-24 11:48:20','Nu-i stress, ca daca ma stric la burta mai fac un gropar mic, in budescu.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,2),(1002,387,'Mimoza','qurli19@yahoo.com','','89.38.91.7','2007-05-10 22:03:32','2007-05-10 20:03:32','no, eu nu`l vad ink pe vacaroiu, da` astept cu sufletu la gura (da` nu`l las sa scape, fi pe pace, mai intai sa citesc)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(532,368,'Groparu','groparu.ro@gmail.com','http://www.groparu.ro','82.77.126.254','2007-05-03 13:25:25','2007-05-03 11:25:25','Nu pot pe boc, ca e prea mic, nu se vede. Ar trebui sa pun si o lupa langa, sh mi-i lene',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(1387,396,'MaTr3o','matr3o@yahoo.com','http://www.matr3o.blogspot.com','86.34.239.197','2007-05-16 21:00:26','2007-05-16 19:00:26','am furat poza',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(1053,381,'admin','groparu_ro@yahoo.com','http://','89.137.112.22','2007-05-11 20:09:23','2007-05-11 18:09:23','Adevaru\' e caaaa... la toti ni\'i greu:|',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,1),(1224,396,'Saptamana Fierbinte &raquo; piticu.ro','','http://www.piticu.ro/2007/05/14/saptamana-fierbinte/','81.196.154.80','2007-05-14 19:02:54','2007-05-14 17:02:54','[...] ca eu manipulez? Unii se oftica ca &#8220;n-are&#8221; camasa de 200 de euro. Au aparut niste variante de buletine de vot. Cred ca astea le vom avea in sectii, daca nu le desenam. Si vodafone isi concediaza [...]',0,'1','Incutio XML-RPC -- WordPress/2.1.3','pingback',0,0),(1446,408,'.marius','marius@wirelessisfun.com','http://marius.wirelessisfun.com','89.137.107.129','2007-05-17 13:22:22','2007-05-17 11:22:22','mwhahahahahahaha geniala ;-)',0,'1','Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.1.3) Gecko/20061201 Firefox/2.0.0.3 (Ubuntu-feisty)','',0,0),(2053,437,'katmai','katmai@keptprivate.com','http://www.512kbps.com','195.212.29.187','2007-05-24 14:19:38','2007-05-24 12:19:38','uel sed',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7 (CK-IBM)','',0,0),(495,356,'Fascista','luminitadanciu@yahoo.com','','71.112.150.30','2007-05-02 05:59:43','2007-05-02 03:59:43','berea mea unde-i?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; Sgrunt|V109|29|S-996046478|dial; snprtz|T05036630770176; .NET CLR 1.1.4322)','',0,0),(496,365,'mishu','mishu@i2xm.com','http://www.n-am.com','82.77.126.254','2007-05-02 09:14:17','2007-05-02 07:14:17','Mai is, n-ai zis ce le putem face decat pentru 14 din cei 322. Sau ii punem cate 2? Si atunci is 28? Sau cate 3 la fiecare tura... Aiaiaiaiiiii... ar fi dreams can come true land! Oricum, mai trebuie gasite pedepse! :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(497,359,'varzastricata','tudor.maris@gmail.com','http://rottencabbage.ablog.ro','124.181.83.230','2007-05-02 10:55:44','2007-05-02 08:55:44','ba, io nici macar cu putza n-am putut. Nu mere. Mi-o iesit candva un gand din cur, da cam atat :D',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(499,365,'Groparu','groparu.ro@gmail.com','http://www.groparu.ro','82.77.126.254','2007-05-02 11:43:04','2007-05-02 09:43:04','Da, da\' e ca e pacat sa ii killareshti pe toti deodata, cand ii poti chinui pe ailanti cu agonia asteptarii...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(1043,388,'Dee','aeriana80@yahoo.com','','192.229.17.103','2007-05-11 16:47:54','2007-05-11 14:47:54','pot sa confirm :D \r\nFrumos oras...\r\nDaca treci pe la noi, te duc a restaurant Bollywood :)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(1448,406,'pepi','roman.petre@gmail.com','','82.77.126.134','2007-05-17 16:05:00','2007-05-17 14:05:00','Cand am fost si io la domnu cu Ursus, cu un Canon imprumutat (da - eu eram unul din \"altora\" :P), a incercat sa ma jecmaneasca si pe mine. Problema era tot la fel: obiectivus captivus. Pana la urma nu m-am indurat sa-i las aparatu, si l-am reparat to asa cum l-am stricat: a mai luat inca o tranta :D',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727)','',0,0),(528,368,'Sorinelu\'','sorinelm@gmail.com','','82.77.126.35','2007-05-03 12:09:15','2007-05-03 10:09:15','pe boc',0,'1','Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.0.11) Gecko/20070327 Ubuntu/dapper-security Firefox/1.5.0.11','',0,0),(1044,381,'Mimoza','qurli19@yahoo.com','','89.38.91.7','2007-05-11 16:56:22','2007-05-11 14:56:22','ce desteapta sunt... \"v`a avea\".....=))   v`ai, v`ai mie.....',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(1995,412,'varzastricata','tudor.maris@gmail.com','http://rottencabbage.ablog.ro','124.180.214.244','2007-05-23 21:51:41','2007-05-23 19:51:41','Dumnezeu sa-l ierte! \r\nHai ca daca era baba se impresiona cumva, nu te deprima acuma :D',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(1742,423,'baghy','baghy83@lycos.it','','78.12.16.198','2007-05-20 17:49:21','2007-05-20 15:49:21','bine spui',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(1443,406,'Luci','lucianticrea@yahoo.com','','81.196.150.76','2007-05-17 12:21:49','2007-05-17 10:21:49','Am fo si eu cu camera lu patronu meu americanu\' al de ii zice jose campos si am patit ficz la fel. Da macar face mosu camera ca noua.\r\naaa.apropos: Ar fi o faza sa te duci la mos imbracat ca tzigan si sa vezi daca nu lasa la pretz(asa pentru minoritatzi...).',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.0.11) Gecko/20070312 Firefox/1.5.0.11','',0,0),(1638,405,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.112.22','2007-05-19 15:49:54','2007-05-19 13:49:54','Da, ba, ala ii niebun, pe bune.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(1035,388,'Gez','geza@dvis.info','http://groller.info/geza','89.137.114.63','2007-05-11 09:38:37','2007-05-11 07:38:37','O stiut ala ce manca :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(571,374,'katmai','katmai@keptprivate.com','http://www.512kbps.com','195.212.29.179','2007-05-04 14:49:11','2007-05-04 12:49:11','inghetata aia buna care era la caserola si care avea o tona de straturi.\r\nfaptul ca \"pititea\" era cel mai tare joc, sau tara tara vrem ostasi\r\nfaptul ca ciordeam tevi de pvc ca sa ne impuscam cu cornete.\r\nfuratul de smochine\r\no tona de shits ...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.8) Gecko/20050511 Firefox/1.0.4 (CK-IBM)','',0,0),(441,155,'Denisa','denisalala@gmail.com','http://www.denisuca.ro/blog','86.123.36.173','2007-05-01 00:03:31','2007-04-30 22:03:31','Superb. =D&gt;',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(2329,442,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-05-28 16:38:33','2007-05-28 14:38:33','Ba nu, ca si daca veneati, va trebia un aerostat sa ajungeti acolo sus, pe unde pluteam noi, in cele sfere stratosfere... Si la plecare, un batiscaf ca sa ajungeti acolo, la noi, in Groapa aia a Marianelor unde ne scufundase cea mai crunta mahmureala de la orgiile romane incoace...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(1893,411,'carlanu`','','','193.151.30.56','2007-05-22 13:52:47','2007-05-22 11:52:47','shi sa-mi schimbi poza ma!!!!!!!!!! Da` numa dupa anu` asta.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(460,82,'harry plotter','conionel@yahoo.com','','89.41.216.55','2007-05-01 15:40:28','2007-05-01 13:40:28','hai roxana nu baga vrajeala, ca se stie ca te masturbai gandind-u-te la el',0,'1','Opera/9.01 (Windows NT 5.1; U; en)','',0,0),(459,359,'Groparu','groparu.ro@gmail.com','http://www.groparu.ro','82.77.126.254','2007-05-01 13:06:13','2007-05-01 11:06:13','Mie-mi spui! Pai io gandesc cu capu\' numa cand pleaca crierii din putza in sus.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(458,354,'katmai','katmai@keptprivate.com','http://www.512kbps.com','195.212.29.171','2007-05-01 12:46:55','2007-05-01 10:46:55','totusi .. ai primit vot ? :D de la ea? anyway faina povestea si e bine rau de tot de retinut. avem inspiratie next time :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.8) Gecko/20050511 Firefox/1.0.4 (CK-IBM)','',0,0),(457,359,'katmai','katmai@keptprivate.com','http://www.512kbps.com','195.212.29.171','2007-05-01 12:43:55','2007-05-01 10:43:55','pentru ca uneori e bine si profitabil sa gandesti cu putza mai ! pentru ca putem, si pentru ca suntem mandri de-asta :) de-aia !',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.8) Gecko/20050511 Firefox/1.0.4 (CK-IBM)','',0,0),(448,358,'Andrei Crivat','andrei@andreicrivat.ro','http://www.andreicrivat.ro','89.137.98.13','2007-05-01 08:11:22','2007-05-01 06:11:22','bine, magare! si de organizatori, care s-au spetit si au transpirat indelung numa\' si numa\' ca sa ai tu ocazia sa te lafai cu premiu\' tau.... nici o vorba ??',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727)','',0,0),(456,346,'admin','groparu_ro@yahoo.com','http://','82.77.126.254','2007-05-01 11:32:57','2007-05-01 09:32:57','Nuuu, ca daca imi descopar cernobilu\' din burta si mi-l sting astia, nu o sa mai pot bea berea cu aceeasi sete :|',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,1),(4011,526,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','86.105.72.125','2007-07-18 18:16:07','2007-07-18 16:16:07','Yo, Geza man: http://www.groparu.ro/?p=67 :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(4014,526,'Greuceanu','','','195.149.72.124','2007-07-18 22:52:36','2007-07-18 20:52:36','MO!\r\n\r\nIo de mult am vrut sa merg in Delta da\' n-am ajuns niciodata pana acolo.... satisfa-mi sh mie o curiozitate... ai vazut \"- stÃ¢rc de baltÄƒ, stÃ¢rc cenuÅŸiu, stÃ¢rc de noapte, stÃ¢rc galben;\", mo, da\' sfarc lipovean ai vast\'?! sh daca da....umbla tot cate 2?! cum arata?! se enerveaza repede?! zi-mi sh mieeeee..... pls.....\"',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(3752,503,'Busuioc','busuioc.constantin@gmail.com','http://deleted','86.122.36.17','2007-06-30 14:04:03','2007-06-30 12:04:03','Cum ai pus Ã® din a? Stie cineva cum se face? Ziceti si mie, va rog.',0,'1','Opera/9.01 (Windows NT 5.1; U; en)','',0,0),(4008,526,'Gez','geza@dvis.info','http://groller.info/geza','89.137.99.19','2007-07-18 17:45:33','2007-07-18 15:45:33','Ba frate, nu-i de bine! Am o foame de-un kil in mine ... \r\n\r\nTrebe sa ne punem odata si sa ne luam cortu si sa merem la pescuit. (nuj dak esti amator) \r\n\r\nSi cu pestii aia sa punem pe cineva sa ne faca zama din asta, de peste.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(3524,502,'baghy','baghy83@lycos.it','http://baghy.wordpress.com/','78.12.5.204','2007-06-25 22:36:11','2007-06-25 20:36:11','Gropare insanatosire grabnica si sa ne povestesti cum a fost la nunta',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(4009,525,'Gez','geza@dvis.info','http://groller.info/geza','89.137.99.19','2007-07-18 17:55:45','2007-07-18 15:55:45','=)) \r\n\r\nam vazut si postere prin centru ... \"m-am urat de atata urat\"',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(3255,482,'oedip','oedip74@gmail.com','http://oedip.blogspot.com','89.137.104.170','2007-06-16 10:54:04','2007-06-16 08:54:04','SMB!\r\n\r\nSper ca sti ce e asta :P\r\n\r\ndaca nu o sa-ti comunic privat... la privata, daca ma-ntelegi ;)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(4005,528,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-07-18 14:26:18','2007-07-18 12:26:18','Da mo! urmeaza :) urmatoarea postare',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(3519,502,'Adi','acalarasu@gmail.com','http://adriancalarasu.wordpress.com','89.32.19.126','2007-06-25 21:54:15','2007-06-25 19:54:15','si eu il stiu pe unu\' care tuseste toata vara pen\'ca bea numai de la congelator...\r\nuf, ce nu face omu\' sa se raceasca un pic \r\nda\' un pic numa\' :)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(4003,528,'alexier','alexier_90@YAHOO.COM','','89.35.116.70','2007-07-18 11:24:31','2007-07-18 09:24:31','nEATZA, explica odata cum fu in deltoce ca si io vreau sa ma duc la un peste stricat sapoi sa tsiu la ce sa ma astept',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; DigExt)','',0,0),(4004,528,'alexier','alexier_90@YAHOO.COM','','89.35.116.70','2007-07-18 11:25:18','2007-07-18 09:25:18','nEATZA, explica odata cum fu in deltoce ca si io vreau sa ma duc la un peste stricat sapoi sa stiu la ce sa ma astept',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; DigExt)','',0,0),(3265,483,'Greuceanu','fm77roen@yahoo.com','','195.149.72.124','2007-06-16 16:48:22','2007-06-16 14:48:22','da mo! a fost suuuuper..... Blogu\' poate numai sa aminteasca de faptele marete ce au avut loc! Iar Nartzoaga ar face bine sa nu mai dea mediei acet tip de detalii... dupa ce ca i-am permis sa-shi asheze curu\' ala paros si plat ca un fier de calcat taman hapt in prelungirea protapului, la fel ca un arbitru de volei ce nu-shi dezlipejte uochii de la fileu sh de la minge sh comenta fiecare mijkare sacra a marelui protap mejterit de Faurul Pamantului jtiut numai de Greuceanu, si lipit cu apa de foc shi curatat cu iarba fiarelor!!!.  Sh de acolo, ametit de propriile simturi, nu mai avea cum fi obiectiv!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(3266,480,'Greuceanu','fm77roen@yahoo.com','','195.149.72.124','2007-06-16 16:54:22','2007-06-16 14:54:22','Teoria 11\r\n\r\nN-au murit dinozaurii - sunt doar ascunsi! Foarte bine ascunsi!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(3268,481,'veriga lipsa','primordiall@yahoo.com','','81.181.42.248','2007-06-16 18:34:39','2007-06-16 16:34:39','mestere, mai traieste emericu ori o zburat in alte loace?\r\nda\' cum frantz si-o putut da ala foc pa mecla ashe cu repeziciune? :D\r\nastept un autograf de la mnetale cand ii avea vreme',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(3509,502,'andreanum','andreanum@yahoo.com','http://andreanum.wordpress.com','89.40.135.250','2007-06-25 19:53:40','2007-06-25 17:53:40','aoleo, gropare, ia cu lamiie si scapa repede ca e naspa rau sa ai muci cind altii fac baie in mari. insanatosire degrabnica iti urez.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(3714,97,'Nascut din spermatozoizi campioni &raquo; Blog Archive &raquo; De ce plec in concediu','','http://www.groparu.ro/?p=505','69.16.239.16','2007-06-29 14:45:42','2007-06-29 12:45:42','[...] nu se prea compara cu asta, traducerea asta nu fu singulara; finca am mai avut [...]',0,'1','Incutio XML-RPC -- WordPress/2.1.2','pingback',0,0),(3715,505,'IepurasulAtomic','praetorian21uk@yahoo.com','','192.100.130.7','2007-06-29 15:41:40','2007-06-29 13:41:40','Concediu fain ma Groapare, sa-ti fie burta plina cu mici, gatu\' inundat cu bere si fatza infipt adanc intr-o pereche de sani voluptosi...cel putin o pereche :D. Sa ne auzim cu bine...io o sa sufar fara articolele tale, asha ca sper sa ai si-o mana libera pentru tastatura, da\' numa\' daca se poate. Hai noroc.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(3736,505,'Luna Betiluna','mihdana@yahoo.com','','89.123.2.198','2007-06-30 00:13:00','2007-06-29 22:13:00','hai c-am beut io-naintea ta si n-am vazut c-ai scris 2 saptamani .... imi trebe tare concediuuuuu',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(3712,504,'bicplayer','bic_player@yahoo.com','','86.125.169.80','2007-06-29 14:19:02','2007-06-29 12:19:02',':)) faina treaba =))\r\nde beut k un porc n-ai zis nimica....sau n-ai beut :O',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(3713,504,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-06-29 14:33:27','2007-06-29 12:33:27','@ Mary: Apai nu i-i frica lu Groparu, ca daca vin cu manajturenii mei... pfuai, o incaseaza japonejimea ca in Guadalcanal! Basca ca vin cu ciobaneii din Sibiu, sh atata mi ti-i mulg pana fac urda de japoneji!\r\n@ rux: Tulai, noa, cate PULE mai sunt pe lumea asta! Apropos, cineva care e nascut in asemenea orash cum se cheama, o PULA de om?\r\n@baghy: Cin Cin!\r\n@ Hammer: Apai daca il furam, unu dintre noi era violat, sh io stiu care, ca la mine pe cur scrie: EXIT ONLY\r\n@ bicplayer: ma, nu am beut ca un porc, am beut ca un burete, sh buretzii nu vorbeshte!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(3505,502,'pepi','roman.petre@gmail.com','','82.77.126.134','2007-06-25 15:33:03','2007-06-25 13:33:03','Adevaru\' e ca numa oamenii destepti racesc vara ;).',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727)','',0,0),(3506,502,'sabina','','','81.12.163.178','2007-06-25 15:57:42','2007-06-25 13:57:42','sa recunosti e primul pas spre vindecare',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1)','',0,0),(3716,504,'Cornelia G','corneliaguju@yahoo.com','http://360.yahoo.com/corneliaguju','86.105.81.102','2007-06-29 15:58:08','2007-06-29 13:58:08','...mai gropare!...\r\nde cate ori te citesc rad in hohote. pana si de comentariile la comentarii..!\r\n\r\n...sa traiesti!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(3730,505,'Luna Betiluna','mihdana@yahoo.com','','89.123.2.198','2007-06-29 22:02:21','2007-06-29 20:02:21','dom`le, io zic ca distractie neplacuta n-are cum sa-ti iasa, desi la cum te prezinti in ultima vreme...(cin-cin, s.a.)...nu se mai stie ... still, iti urez sa fii in forma buna, sa faci fata provocarilor din onor statiunea tineretului care este',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(3731,505,'Luna Betiluna','mihdana@yahoo.com','','89.123.2.198','2007-06-29 22:03:05','2007-06-29 20:03:05','da` cand te-ntorci?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(3697,476,'Marius','pop.marius@gmail.com','http://lityx.blogspot.com','86.35.157.42','2007-06-29 09:53:39','2007-06-29 07:53:39','No, cu parere de rau gropare, pas, ca n-am blog de actualitate. Adeca, io il fac, dar o sa fie citit peste vreo trizaci de anisori. Bun asa? Asa ma gandeam si io...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(3700,504,'Hammer','pontos.alin@gmail.com','','86.120.55.79','2007-06-29 11:04:37','2007-06-29 09:04:37','No hai ca am ras cu lacrimi. Cin Cin\'stie ce pateai daca il mai si furai pe japonezu\'!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(4029,530,'Groparu','groparu_ro@gmail.ro','http://www.groparu.ro','82.77.126.254','2007-07-19 16:58:23','2007-07-19 14:58:23','Ye, mah man, da\' io ce sa fac daca prekinii mei is retarzi? :( ca io le tat zic ca cu Dumnezeu nu e de joaca, ca nu ne-o trimis El in Romania dijaba in loc sa ne trimita in Pigmeia sau Lalaland... sh noi mai sh comentam... ca buoii (asta chiar e comentariu serios)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(3970,506,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-07-16 10:53:26','2007-07-16 08:53:26','Da mo, bine v-am gasit, ma duc sa fac cerere sa ma scoata permanent in concediu platit.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(3971,507,'IepurasulAtomic','praetorian21uk@yahoo.com','','192.100.130.7','2007-07-16 11:34:08','2007-07-16 09:34:08','Bine (v-)ati revenit domnu\' Groparu\', desi vad ca nu-i cazu\', ceea ce ma bucura :). Auzi, da\' neste trufandale mai octogenare n-ai gasit pe plaja aia? Adica deh, is bune si astea de pana in 60 de ani de tre\' sa-ti feresti copiii cand se intorc de pe-o parte pe alta. Adica mie mi-ar fi placut sa vad un ranjet printre proteza de la o bunicutza sexi de minim 75...cu pensia pe terminate. Da\' nah, aparatu\' a fost in mana ta, acuma ce sa mai zic. Numa\' ca-s dezamagit, data viitoare sa faci poze si pentru gusturile mele. Ne-am inteles? Dau o bere! Hai, spor la aberat si incearca sa nu-ti manifesti prea des greata revenirii la servici. Nu de alta, da\' vomatu\' excesiv duce la dezhidratare...si-i si pacat de berile alea ;).',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(3959,506,'baghy','baghy83@lycos.it','http://baghy.info/','78.12.19.170','2007-07-15 23:41:21','2007-07-15 21:41:21','salutare gropare.a fost trista blogosfera fara tine.tot pus pe glume esti.foarte bine.nu ti-a daunat soarele ala',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(3962,507,'baghy','baghy83@lycos.it','http://baghy.info/','78.12.12.248','2007-07-16 00:16:41','2007-07-15 22:16:41','Voulez vous coucher avec moi? Notres poules dans votre cour? :))))))))).Ai stat sa faci poze la toate fainele:)))Ce tinerel pari fara barba si cu parul scurt.Acum din nou la munca',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(3963,507,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','86.105.72.125','2007-07-16 00:22:28','2007-07-15 22:22:28','Ye mah, bag p***ula.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(3986,525,'marcu\'','','','192.35.17.10','2007-07-17 09:11:46','2007-07-17 07:11:46','sa bem pentru a 69\'a abereatiune ! :D',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; InfoPath.1; .NET CLR 2.0.50727)','',0,0),(3988,525,'IepurasulAtomic','praetorian21uk@yahoo.com','','192.100.130.7','2007-07-17 10:50:23','2007-07-17 08:50:23','Ieri am vazut si io posteru\' asta din autobuz si nu intelegeam care-i faza. Deci asha zici, ca nu mai are loc lumea de statuia lu\' Iancu. Mie mi-o trecut o gramada de idei constructive prin bila cand am vazut afisu\', nicidecum asta. Cum ar fi spre exemplu sa se repare fantana aia arteziana ca incepe sa se degradeze. Si asta-i grav, pentru ca daca intr-o zi vrea Iancu sa faca o \"randunica\" sau un \"echer\" (pozitii de plonjat ma, nu pasare si nici figura geometrica) in apa de la picioarele sale, o sa-si crape bostanu\'. Si poate sa mai amenajam pe ici pe colo cate un boschet, un petec de iarba, sa reparam si sa nivelam pavaju\' ala, ca asha fac oamenii gospodari. Da\' nu-i rau nici asha, hai sa daramam, ca s-avem ocupatie. Mersi ca m-ai lamurit? N-ai un baros, ca ma bag si io daca-i de stricat?...',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(3991,525,'bicplayer','bic_player@yahoo.com','','86.125.169.80','2007-07-17 13:52:28','2007-07-17 11:52:28','frate io nu-s din cluj...da is total impotriva...\r\npoi cum ma si apoi sa numai mearga versurile astea:\r\n\"[...]Sus in dealu Clujului sta statuia Iancului,\r\nDoamne ocrotestei pe romani\r\nSi cum sta Iancu p statuie, si le da la unguri mu*e\r\nDoamne ocrotestei pe romani[...]\"\r\n\r\nda halo in niciun caz',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(3975,507,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-07-16 14:05:06','2007-07-16 12:05:06','@ Epurila si muove: am una apsolut dementiala, da\' nush unde phuii mei s-o pitit, ca am pozele puse in vreo 6 locatii.\r\n\r\n@ All: niciodata nu am stiut cum sa fac fatza unor asemenea manifestari de afectiune masculina. Noroc ca nu e cazul sa ma ingrijorez pentru gaoz daca naufragiem toti pe o insula pustie.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(3972,507,'katmai','katmai@keptprivate.com','http://www.512kbps.com','195.212.29.179','2007-07-16 12:17:33','2007-07-16 10:17:33','uelcam bec. inima mea era franta fara tine, si albastrul cerului nu mai era atat de albastru. au au au ce ma fac ziceam in fiecare dimineata cand ma trezeam. acum stiu ca viata are sens. senc iu pentru dizainar. vorbesc diseara cu el beteue.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7 (CK-IBM)','',0,0),(3678,503,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.112.22','2007-06-29 00:48:15','2007-06-28 22:48:15','Na, mah, d-aia is buni programecii la casa romanului!!! Baghy, mersi fain, mai ales ca tot ce-i acolo e natural sh ecolojic ;;)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(3677,503,'baghy','baghy83@lycos.it','http://baghy.info/','78.12.9.211','2007-06-28 23:36:44','2007-06-28 21:36:44','uite aici se gasesc sani http://www.realdoll.com/accessories.asp :))))))))',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(3676,504,'baghy','baghy83@lycos.it','http://baghy.info/','78.12.19.144','2007-06-28 22:50:22','2007-06-28 20:50:22','no Cin cin Gropare',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(3671,296,'halogen','halogen_x@yahoo.com','http://www.sri.ro','89.136.28.25','2007-06-28 21:34:08','2007-06-28 19:34:08','faceam un test sorry nu se adreseaza nimanui:))',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1)','',0,0),(3672,296,'halogen','halogen_x@yahoo.com','http://www.sri.ro','89.136.28.25','2007-06-28 21:34:26','2007-06-28 19:34:26','tare nnu..',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1)','',0,0),(3670,296,'halogen','halogen_x@yahoo.com','http://www.sri.ro','89.136.28.25','2007-06-28 21:32:14','2007-06-28 19:32:14','esti un bou',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1)','',0,0),(3999,528,'Andrei Crivat','andrei@andreicrivat.ro','http://www.andreicrivat.ro','89.137.98.13','2007-07-18 07:40:22','2007-07-18 05:40:22','bine ma... si delta ?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727)','',0,0),(3666,503,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.112.22','2007-06-28 20:09:20','2007-06-28 18:09:20','Da, da, stiu, ai crescut un serpe la sani! Stiu cum e, ca si io tot cresc unu\', da\' in pantaloni, sa imi iertatz porcairea gandului asternuta electronic!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(4043,526,'alexier','alexier_90@YAHOO.COM','','89.35.116.70','2007-07-20 10:11:06','2007-07-20 08:11:06','hai sa zicem ca bei vere si faci sex nu prea mere bha decat daca iti tragi un furtun in gura direct din doza dar atuncia ii destul de grei cand dai limbi noo... plm. da aia cu toate trei nu prea mere',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; DigExt)','',0,0),(4072,536,'IepurasulAtomic','praetorian21uk@yahoo.com','','62.217.245.97','2007-07-21 20:27:26','2007-07-21 18:27:26','Gropare, io-s baiet bombon si-mi place de tine(nu-mi cere perversitati ca nu-s din ala....stii tu...) si bombon fiind am intrat pe saitu\' ala sa dau cu leapsa in Silvan. Da\' problema e ca boii zice: \"ati mai votat odata!\"(daca ziceau \"A-TI mai votat odata\" chiar ca-mi sarea mustaru\' pe pereti). Asta in conditiile in care io m-am conectat prin telefon(si la bruma mea de tehnica pare-mi-se ca am IP propriu si de nereprodus). Io nush cine tine saitu\' ala, da\' io zic sa investigati o tzara problema, sa nu fie vreo manarie p\'acolo, c\'ar fi pacat.\r\n\r\nOff topic, azi  bag sama ca te-am vazut in strand! Tu erai? Nu spui unde, ca nu vreu sa te caute lunetistii! Spun doar atat: itzi ajunjea apa pana la umeri si inca n-ai burta de bere...pronuntata :D. Mnoa...io-s iepure simtit si n-am intrat peste tine sa-ti strang mana. Esti in timpu\' liber si-ar fi total neplacut sa fii asaltat de fani...mai ales de acelasi sex cu tine :). Asha ca te-am admirat de la distanta si m-am multumit cu atat. Hai s-avem de tate...si vezi cum faci cu berile alea, ca mi-i ca faci risipa, nu se vede pe tine...prea tare :). Spor la treaba asta...ca \"arbitriiiiiiii rai e multi\". Noroc...desi mie imi place becks! :)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(3663,504,'rux','ruxxandra86@yahoo.it','','84.220.142.186','2007-06-28 17:52:56','2007-06-28 15:52:56','mi se intamplase si mie o chestie de genul asta cu italieni, japonezi si cin cin...dar atunci erau mai multi japonezi(2):D\r\nca sa raman in tema stii unde si-au facut vacanta cativa fotbalisti italieni vara asta?....in PULA(localitate balneara ffff cunoscuta si apreciata in Sardinia)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(3660,504,'Mary','zeitza_venus@yahoo.com','http://360.yahoo.com/zeitza_venus','193.22.173.10','2007-06-28 16:23:28','2007-06-28 14:23:28','amu\' chiar zic sa te apuci sa\'ti sapi gruapa.. ca poate vine za japo-guy cu tot neamul lui cel razboinic... si\'ti arata el cin cin..',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(3661,503,'andreanum','andreanum@yahoo.com','http://andreanum.wordpress.com','194.30.177.1','2007-06-28 16:40:27','2007-06-28 14:40:27','ti i-am sters pe aia pe care i-ai avut. pe astia de acuma sa ti-i stergi singur, caci vaz ca daca iti fac altii treaba te blegesti. hai, copacel-copacel, ia somoiogu de stergare si frashsht cu el pe la nas. care am fost ca o mama si te-am iubit ca pe copchilu mieu...',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1)','',0,0),(3319,480,'admin','groparu_ro@yahoo.com','http://','89.137.112.22','2007-06-17 21:36:36','2007-06-17 19:36:36','Ba Greucica, tu iara scrii numa ca sa ne faci sa radem?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,1),(3658,503,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-06-28 15:39:32','2007-06-28 13:39:32','@ andreanum, ce muci mi-ai sters, ca uite la ei cum atarna!!!\r\n@ Luna, am vorbit cu Dumnezeu si o zis sa iti indeplinesc rugamintea. Iat-o! E sus ;)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(3321,480,'Greuceanu','fm77roen@yahoo.com','','195.149.72.124','2007-06-17 23:25:42','2007-06-17 21:25:42','Poate cineva sa zica ca nu-s ffff bine ascunshi?! Ce?! i-a gasit careva sh io n-am auzit?! Mnoa! deci sunt fff bine ascunshi!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(3875,505,'VIP','dea0a@yahoo.com','http://vipuri.blogspot.com','86.122.8.62','2007-07-06 09:19:23','2007-07-06 07:19:23','pa\' tu meri la costinesti sa cauti internetu cand ii plin de tzatze goale pe acolo? slab om!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(4074,536,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','86.105.72.125','2007-07-21 21:16:31','2007-07-21 19:16:31','Epurilaaaa!!! Nu mai fa din iestea mo, \'aide de saluta Groparu\' sh bucura-i inimioara batrana! Sh apai - esti de acelashi sex cu mine DEOCAMDATA! ca cine stie ce ne rezerva viitoru\' sh noru\' ala fosforos din Ucraina, ca poate se mai inventeaza vreun sex pe planeta, cum ar fi, de exemplu, un sex feminin care sa nu comenteze orice faci!!!! (utopie, nu?)\r\n\r\nNajpa cu votu\' lu pejte. Sper sa ii deie Silvan in judecata sh sa ii trimeata la Canal, sa se sepe intre ei, nu pe noi, care suntem mai inteligenti decat ai lor!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4066,536,'Glogovetan Tudor','tudor_glogovetan@yahoo.co.uk','http://dingrajd.blogspot.com/','89.136.23.215','2007-07-21 13:48:31','2007-07-21 11:48:31','Dapai mah gropare, te\'ntreb pe tine ca pe el mai rar il gasesc, ce draci so \'plÃ¢ntat acolo? cÄƒ cine o loat locu\'ntÃ¢i? cine io spart chitara? cine io taiat coardele? cine io pus piuneze pe scaun? cum dreaq numa 1 mah?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4047,534,'toma','','','81.1.83.171','2007-07-20 15:37:14','2007-07-20 13:37:14','planeta ciudatilor plina de habauci ca tine ... oricum f. nostima welldone!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; xHollywood Media Bar)','',0,0),(3653,503,'Luna Betiluna','mihdana@yahoo.com','','82.76.46.190','2007-06-28 10:59:33','2007-06-28 08:59:33','Mai, domnule mucosule (daca-mi permiti, ca esti mai tanar, nu de alta :) ), tu vrei sa ne numeri cati ne milostivim de tine ori vrei sa vezi de suntem deja in conced si tu nu? uite-aici caractere mari de-ti scriu la mesaje de dez-racire, asta dupa ce tu te-ai dansat pana la udare la nunta .... si-oi fi adormit la umbra vreunui aier de-ala conditionat..... si nici nu ne pove, de pierim de curiozitate, groparule ce esti, atata astepti :) ....',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.0.10) Gecko/20070216 Firefox/1.5.0.10','',0,0),(3655,496,'Hammer','pontos.alin@gmail.com','','86.120.55.79','2007-06-28 12:37:36','2007-06-28 10:37:36','Lista cu ce li se reproseaza masculilor tatici e shi mai plina de sos :-D',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(4121,537,'mishu','mishu@doingtheartwork.com','http://www.doingtheartwork.com','82.77.126.254','2007-07-24 09:39:54','2007-07-24 07:39:54','Din care s-ar putea intelege ca americanii nu sunt in irak pentru petrol... da\' eu zic ca a fost doar de diversiune, ca Pearl Harbor sau 9-11... :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4120,540,'Femei','asdw@yahoo.com','http://de-aia.blogspot.com','86.122.8.62','2007-07-24 09:34:58','2007-07-24 07:34:58','@ groparu:\r\n\r\nma, daca nu ti-o iesit din spate numa din fatza... nici nu ii asa de rau. cand nu mai iasa nici din fatza atunci ii nasol ca ajungi sa te lauzi ca atarna frumos...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4023,534,'L3ST','callmel3st@gmail.com','http://l3st.nimic.org/','89.34.244.21','2007-07-19 14:35:07','2007-07-19 12:35:07','Esti un adevarat salvator al planetei! :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 ImageShackToolbar/4.2.1','',0,0),(4024,526,'Sibianca','alexa_g48@yahoo.com','','62.23.212.160','2007-07-19 15:52:20','2007-07-19 13:52:20','Superb! Modul in care ganditi, modul in care gustati viata (atat la propriu cat si la figurat)... Ca intotdeauna, m-ati lasat cu rasuflarea usor taiata',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(4025,526,'Groparu','groparu_ro@gmail.ro','http://www.groparu.ro','82.77.126.254','2007-07-19 16:11:29','2007-07-19 14:11:29','Sighiencele rulllzzzz!!! \r\n\r\nAm mai intalnit fenomenul asta cu respiratia taiata intr-un film in care o gajica \"dormea\" cu prekinu eroului in scutece, sh asta avea mainile bine infipte in gatleju\' ei. Tare film... oare eu eram ala din pat, sau ala din spatele mainilor? Phuii mei, ca nu mai stiu',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4026,534,'Denisa Lala','denisalala@gmail.com','http://www.denisuca.ro/blog','86.123.36.173','2007-07-19 16:31:49','2007-07-19 14:31:49','Go Planet! You da man!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4027,530,'Adi Calarasu','acalarasu@gmail.com','http://adriancalarasu.wordpress.com','89.32.19.126','2007-07-19 16:44:34','2007-07-19 14:44:34','\'ai ma Gropare, penticostal?\r\nnu-i frumos...',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(4028,526,'Sibianca','alexa_g48@yahoo.com','','64.208.49.108','2007-07-19 16:48:51','2007-07-19 14:48:51','Depinde de jumatatea paharului de mai sus;)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(4068,536,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','86.105.72.125','2007-07-21 17:10:53','2007-07-21 15:10:53','Mo Todor, amu kiar n-am cu cine vorbi, ca sireacu\' e negru de furie, sh pe buna dreptate! Da\' aflu io...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(3348,484,'pierdut in spatiu','acalarasu@gmail.com','http://adriancalarasu.wordpress.com','82.76.75.99','2007-06-18 13:08:09','2007-06-18 11:08:09','Nu stiu exact in ce sat din Australia se duce sa traiasca prietenarul dvs dar va rog sa-i transmiteti ca am si eu un amic p\'acolo. Sa-l strige pe nume indata ce ajunge, ca lumea-i mica, nu se poate sa nu se gaseasca.\r\nSi s-ar putea sa-i fie de ajutor ca el e de mult p\'acolo si stie toate carciumile. Gigi il cheama, ca mi-am adus aminte.\r\n\r\nofftopic:\r\nDomnu Groparu,\r\ndati-mi si mie va rog cu batu\' pe ultimil meu blog, ca sa nu se prinda lumea ca vorbesc singur.\r\nsa scrieti acolo 10 (zece), daca se poate... multumesc!\r\nCu deosebit respect!\r\n \r\nps: ai dreaq trolii astia... :D',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(3349,470,'aprozarnet','luc_rockit@yahoo.com','http://aprozarnet.wordpress.com/','89.35.158.151','2007-06-19 00:35:11','2007-06-18 22:35:11','salut\r\nde ce iti cenzurezi cuvintele? \r\nadica folosesti cuvantul, da nu il lasi sa se vada clar, pui stelute, ca si cum ai pune beep pe ceva audio. d c?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(4017,526,'alexier','alexier_90@YAHOO.COM','','89.35.116.70','2007-07-19 11:34:59','2007-07-19 09:34:59','nO gropare sa fi sanatos gropare si nu in ultimu rand iubit de toate gakicele bune cu titi mare din romania cat de curand ma sui si io in car si moi duce si io sa vad mandretea sudului(delta). pov',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; DigExt)','',0,0),(4018,526,'cetitoare','totmea@yahoo.com','','86.35.232.96','2007-07-19 11:56:19','2007-07-19 09:56:19','Pentru asa o descriere a ciorbei de peste de la mama ei de-acasa, cu siguranta ca Radu Anton Roman te-ar invidia.\r\nEu iti spun doar atit: Sar\'mina pentru masa!\r\nIar eu te invidiez ca stii sa degusti si sa gusti cu atita nesat totul in lumea asta, de la bere la orice declanseaza betii, de la tztite pietonale la ale de le iubesti, de la natura moarta a biroului la frumusetea naturii vii de pe alocurile pe unde haladuiesti si altele si altele mai culte si mai si. Ptiu! Norocosule! Bine-ai revenit!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(3651,503,'andreanum','andreanum@yahoo.com','http://andreanum.wordpress.com','194.30.177.1','2007-06-28 09:45:10','2007-06-28 07:45:10','adica cum ba, io intru, sunt aici sa-ti sterg mucii virtuali de boala si tu imi spui ca sunt una cu kati, sabina, adi mary, katmai si iepurasu atomic? tu esti mai grav bolnav decit credeam, fratioare :D \r\nAcu mai vrei si tite gigant in gura...vrei o pila la un psihanalist? :)))))',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1)','',0,0),(3420,496,'mishu','mishu@doingtheartwork.com','http://www.doingtheartwork.com','82.77.126.254','2007-06-22 09:25:50','2007-06-22 07:25:50','Mai barbati... sa-mi bag p*** ce probleme-avem :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(3353,470,'Paszti','pasztorjozsef@yahoo.com','','81.12.230.166','2007-06-19 08:45:49','2007-06-19 06:45:49','Clar ca popor homosexual, ca toti istoricii spun ca ne tragem din Decebal si Traian.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1)','',0,0),(3354,470,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-06-19 10:02:45','2007-06-19 08:02:45','@aprozarnet: mo, daca maica-mea, care e computer illiterate, se apuca sa se dea pe net pe groparu.ro? Iti dai seama ca ma dezmosteneste? Ca ea numa atata asteapta! \r\n\r\n@Paszti: apai cica nu tÄƒÅ£i istoricii; ÅŸi oricum, dacÄƒ ar fi sÄƒ credem ce zice istoricii maghiari... oioioi! Deci io nu mai cred decÃ¢t Ã®n istoricii care Ã®mi dÄƒ mie subiecte de scris pe blog.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(3355,485,'baghy','baghy83@lycos.it','http://baghy.wordpress.com/','78.12.5.241','2007-06-19 12:32:13','2007-06-19 10:32:13','si tu cat concediu ai Gropare?:)))',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(3621,503,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.112.22','2007-06-27 16:36:49','2007-06-27 14:36:49','@Korova: @-) carne de femeie, cu pasarica sh peshte in acelasi timp??? Woooowww...\r\n@ Adi Calarashi: e, mah, ca no, uitai sa vreu sa ma fac binie, no...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(3358,485,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-06-19 14:37:58','2007-06-19 12:37:58','Apai nush, ca in loc sa plec in concediu io stau sh scriu bluage!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(3359,485,'oedip','oedip74@gmail.com','http://oedip.blogspot.com','89.137.104.170','2007-06-19 15:23:08','2007-06-19 13:23:08','da, da lasÄƒ cÄƒ jtiu io... Å£iganiadÄƒ, friptane, Å£uici, etc... ÅŸi se mai ÅŸi plÃ¢nje...\r\n\r\n:PPPPP\r\n:DDDD',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(3360,485,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-06-19 15:49:58','2007-06-19 13:49:58','Da, ma, da... mnoa, io am propus sa facem in fiecare zi la serviciu o Tiganiada miculutza, da\' or bagat nush ce scuza lamentabila ca nu se poate, din cauza la... munca parca ii zicea, da\' nu-s sigur',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(3361,485,'pierdut in spatiu','acalarasu@gmail.com','http://adriancalarasu.wordpress.com','82.76.75.99','2007-06-19 16:20:59','2007-06-19 14:20:59','da\' chiar, voi astia din Cj unde mergeti in concediu?\r\nca eu asta din Baragan unde-i pamantu\' ca-n palma si fara pic de haz merg de vreo doi ani in BH si-acuma parca as veni prin CJ, ca n-am mai fost de cand eram tinerel, cand am venit  cu primul marfar ca sa beau o bere cu piticu\' ala de la Altar ca-mi placea mie cum canta.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(3362,485,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-06-19 16:23:29','2007-06-19 14:23:29','Cum unde sa venim!!! In Baragan, mo! Da\' acolo un\' se gata in litoral, inca nush daca in ala bulgaresc sau romanesc, ca mai am cel putin 8 zile sa ma hotarasc.\r\n\r\nSh dupe aia o tura de munte, ca sa fixam bronzu\' pana ne poleim de aur :D, si ca sa ne fure si muntenii, nu numa\' litoralii.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(3620,503,'Adrian Calarasu','acalarasu@gmail.com','http://adriancalarasu.wordpress.com','82.76.75.99','2007-06-27 16:23:08','2007-06-27 14:23:08','of, greu domn profesor, pana acum trebuia sa fi fost ca nou.\r\ndar e explicabil, probabil si metabolismul asta e dupa cum e omul, iar mata esti ardelean :D',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(3436,496,'andreanum','andreanum@yahoo.com','http://andreanum.wordpress.com','89.40.135.133','2007-06-23 10:17:10','2007-06-23 08:17:10','gropare, io miss de sex femenin si nu-mi plac femeile oricum, nu e nici un pericol sa mi le trimiti si pe ale tale :D',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(3437,500,'Busuioc','busuioc.constantin@gmail.com','','84.232.157.99','2007-06-23 14:47:15','2007-06-23 12:47:15','No, apa sa nu-i bagi in pizda muma-sa?',0,'1','Opera/9.01 (Windows NT 5.1; U; en)','',0,0),(3438,498,'Adi','acalarasu@gmail.com','http://adriancalarasu.wordpress.com','89.32.19.126','2007-06-23 16:13:19','2007-06-23 14:13:19','La ultima intrebare am sa-ncerc sa iti raspund eu, cu o <a><strong>POVESTE</strong></a>',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(3439,498,'Adi','acalarasu@gmail.com','http://adriancalarasu.wordpress.com','89.32.19.126','2007-06-23 16:16:46','2007-06-23 14:16:46',':))\r\nce destept sunt\r\nnormal ca nu merge ce-am vrut eu sa fac :D\r\nlas\' ca-ti zic eu...',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(4431,565,'ania','soredarkshines@gmail.com','http://aniakhaki.blogspot.com/','89.123.122.39','2007-08-04 01:09:19','2007-08-03 23:09:19','deci...nu cred!!! :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4118,537,'mumuland','','','80.97.64.199','2007-07-24 07:23:20','2007-07-24 05:23:20','Or bolunzat americanii si (o)  fura sau rapesc ca si harabii.....de la irakieni li se trage(dak te caci pre des in casa vecinului ii iei mirosurile)..........campania anti terorism cu terorism pentru teorism si in numele terorismului............\r\n\r\niz io? care ? asta: ;)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12','',0,0),(3364,484,'varza','tudor.maris@gmail.com','http://rottencabbage.haipa.ro','124.181.15.31','2007-06-19 21:30:17','2007-06-19 19:30:17','Corect. Trimite-l la mine, ca-i esplic io de restu 437 de puncte.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(3365,485,'macabroo','raduccc@yahoo.com','http://rezistenta.blogspot.com','82.76.52.94','2007-06-19 22:42:50','2007-06-19 20:42:50','Cele 2 luni se compun din, 1 luna spitalizare dupa incasat taxator in muian (sa mearga din mana in mana pana\'n spate la taxatoare=pateu), 1 cautat camasa, itzari si ciucati lacatzi sa se asorteze cu colejii.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(3366,485,'Greuceanu','fm77roen@yahoo.com','','195.149.72.124','2007-06-20 00:04:37','2007-06-19 22:04:37','da!\r\nthat\'s me again!\r\nmah! la cate blesteme sh la cate injuraturi incaseaza ominii ajtiaaaaa... 2 luni e putin mo! io le-j da sh 45% din puctu\' de pensie! apoi tu cu concediu\' tau..... mah! da\' banca jtie mah ce faci?! jtie mah cum te destrabalezi?!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(3368,486,'cetitoare','totmea@yahoo.com','','86.35.232.96','2007-06-20 09:02:37','2007-06-20 07:02:37','da\' tu de unde stii?????',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(3369,486,'The Original Yankee','crisan_emil@yahoo.com','','83.103.133.151','2007-06-20 09:20:41','2007-06-20 07:20:41','de fapt Groparu\' a fost din ala cu bun simtz si a zis \"f***\", nu \"fute\", ca doara el este trecut prin stadii pedagogice si nu trebe stricata inochentzia tinerei jeneratzii...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(3370,486,'pierdut in spatiu','acalarasu@gmail.com','http://adriancalarasu.wordpress.com','82.76.75.99','2007-06-20 10:01:20','2007-06-20 08:01:20','pai in cazu-asta trebuie sa aveti ca fratii, ca sa zic asa...',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(3371,485,'ot','','','86.34.3.100','2007-06-20 10:03:10','2007-06-20 08:03:10','radule, dar pe jos ai incercat sa mergi? ca la traficul care este in centru mai repede il strabati pe jos si de la periferie poti lua iar autobuzul spre destinatie si mergi mai linistit. \r\ne putin efort fizic (care da, nu cred ca e prea bun la cei care stau toata ziua pe scaun la pc :-) si nici nu te scuteste de mirosuri, atingeri lipicioase, discutii inutile si placerea de a sta la coclit in asteptarea culorii verzi.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Media Center PC 3.0; .NET CLR 1.0.3705)','',0,0),(3372,486,'baghy','baghy83@lycos.it','http://baghy.wordpress.com/','78.12.5.241','2007-06-20 10:22:41','2007-06-20 08:22:41','atunci il cunosteai pe pusti',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(3373,486,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-06-20 10:45:32','2007-06-20 08:45:32','@cetitoare: pai foloseam timpul prezent cu sens de viitor, ca in fraza: maine merg la mare :D\r\n\r\n@Yankee: U were there ;)\r\n\r\n@Gasit in spatiu: Da, sh el trebe sa-mi zica nenea, ca bag sama ca i-s frate mai mare...\r\n\r\n@Baghy: I-am cunoscut numa sanjele care i se prelingea pe tzeava pushtii :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(3374,485,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-06-20 10:47:17','2007-06-20 08:47:17','@ot: Asa-i, da\' mergand pe jos nu-si striveste nici o studenta pieptii in bratele tale, cand pune autobuzu\' frana brusca!\r\n\r\nDa, zici bine, ar cam trebui sa ma apuc de ceva miscare. Da\' nu de azi. De maine...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(3375,487,'cetitoare','totmea@yahoo.com','','86.35.232.96','2007-06-20 11:13:46','2007-06-20 09:13:46','hahahhaha! deci tu niciodata nu dai unde te uiti.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(3376,487,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-06-20 11:25:14','2007-06-20 09:25:14','...pai nu, ca cine o zis ca 7 ani ca maine trec bag sama ca era Highlander d-ala care traieste forever.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(3377,485,'katmai','katmai@keptprivate.com','http://www.512kbps.com','195.212.29.163','2007-06-20 12:01:21','2007-06-20 10:01:21','e timpul sa imi schimb meseria :((((( sau sa ne ...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7 (CK-IBM)','',0,0),(3378,486,'katmai','katmai@keptprivate.com','http://www.512kbps.com','195.212.29.163','2007-06-20 12:02:06','2007-06-20 10:02:06','gud uan gropare.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7 (CK-IBM)','',0,0),(3379,487,'baghy','baghy83@lycos.it','http://baghy.wordpress.com/','78.12.5.241','2007-06-20 12:29:52','2007-06-20 10:29:52','era culmea sa fi ajuns chiar in decolteu.Si mai sunt lucruri care iti apartin si pot sa ajunga acolo.Sau nu?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(3980,525,'the blind pazvante','versiunea2@yahoo.com','http://ochiiluipazvante.wordpress.com/','194.102.61.162','2007-07-16 23:43:47','2007-07-16 21:43:47','Eu stiam ca Iancu suie pe statuie, in nici un caz nu se da jos...',0,'1','Opera/9.20 (Windows NT 5.1; U; en)','',0,0),(3637,503,'the blind pazvante','versiunea2@yahoo.com','http://ochiiluipazvante.wordpress.com','194.102.61.162','2007-06-27 23:47:53','2007-06-27 21:47:53','Lasa tzÃ¢tzobsesia in pace ca n-a facut rau nimanui! Fa niste poze \r\nla balanganitoare si sa vezi cati tzÃ¢tzobsedati o sa dea pe-aici.\r\n\r\nPS: \"Acest blog nu se adreseaza minorilor decat insotiti de tata alcoolic sau (de preferintza) de mama\"\r\n\r\nMama natura? Totul se leaga atunci...',0,'1','Opera/9.20 (Windows NT 5.1; U; en)','',0,0),(4019,526,'Groparu','groparu_ro@gmail.ro','http://www.groparu.ro','82.77.126.254','2007-07-19 12:04:30','2007-07-19 10:04:30','@ alexier: du-te, fiul omului, sh pacatuieshte! :D sh daca descoperi o solutie sa bei bere, sa faci sex sh sa pescuieshti in acelasi timp, pls da-mi sh mie reteta,... ca de cand o tot caut!\r\n\r\n@ cetitoare: am avut o adolescentza foarte traumatizanta, in care intra sh neshte prietene de-ale surorii mele, mai mari ca mine cu cel putin 6 ani :| si cum zicea pÃ¢rÅ£oagÄƒ: ma tot uit la jumatea aia goala a paharului, ca aia plina e plina cu rahat!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4020,525,'Groparu','groparu_ro@gmail.ro','http://www.groparu.ro','82.77.126.254','2007-07-19 12:05:31','2007-07-19 10:05:31','Ye mah, alea se refereau la faptu\' ca io umblu prin centru Clujului, si-s urat ca dreq. Io ce sa le fac, no? Ce sa le fac?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(3631,503,'baghy','baghy83@lycos.it','http://baghy.wordpress.com/','78.12.1.241','2007-06-27 21:52:16','2007-06-27 19:52:16','ia vezi poate gasesti o pereche de sani in leasing ca nu ar trebui sa ai probleme cu leasingul doar muncesti la firma mare',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(3431,496,'andreanum','andreanum@yahoo.com','http://andreanum.wordpress.com','80.97.184.198','2007-06-22 19:41:06','2007-06-22 17:41:06','gropare si astilantii: io cred ca voi vorbiti asa pentru ca nu aveti treaba. Ia ziceti la doamnele sa-mi dea cite un mail :D \r\nSa vad io daca in doua saptamini mai zdreliti caldarimu a paguba.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(3381,485,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-06-20 15:11:31','2007-06-20 13:11:31','Ye mah. M-as face tÃ¢rf, da\' mi-i ca as fi singuru\' giggolo care da EL bani clientelor ca sa-si faca portofoliu...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(3382,488,'andreanum','andreanum@yahoo.com','http://andreanum.wordpress.com','194.30.177.1','2007-06-20 16:23:11','2007-06-20 14:23:11','Gropare, trai-ti-ar famelia, mi-ai adus aminte de un prieten care a zis ca se va razbuna pe un altu pentru oaresce gresale de tinerete si ii va seduce fata. Fata aluia avea, pe vremea amenintarii, cam 6 primaveri implinite :D\r\n\r\nAcu are vreo 16 copila, dar i-a trecut si astuia de razbunare :))))',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1)','',0,0),(3610,502,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.112.22','2007-06-27 13:51:14','2007-06-27 11:51:14','@ pepi: da, io-s esceptia ce intareshte regula\r\n@ sabina: io recunosc ca aud voci, da m-am vindecat? canci!!!\r\n@ andreanum: mersi de urale, am s ama gandesc la ele cand am sa imi bag lamaie prin cavitatzi\r\n@ Adi: si eu il stiu pe unuâ€™ care se tat kinuie sa omoare otzara de ficat, dar ficatul rezista!\r\n@ baghy: Baghy, always a pleasurr ;;) nunta vine imidiat, numa sa descarc cele poz(n)e\r\n@ ion iopescu de la alba: cred ca ti-ai dat seama ca asemenea activitati subversive sunt deopotriva anarhiste si iredentiste!!! Good boy ;)\r\n@ katmai: man, deci daca nu m-o rapus pe mine prostia, apai nu m-o rapune oleaca de muci!!! (da\' sa nu-mi faci portret cu mine curgandu-mi nasu\' la vale pls)\r\n@ Iepurasul Atomic: sa nu te puie cucu\' sa te imbonavesti! si daca te pune, da-o mai departe, da\' la lupi\r\n@ Mary: o zic ca inca nu am bani de suficienta bere ca sa imi umplu gruapa ca sa mi se pare o alternativa viabila la ceea ce am amu!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(3611,503,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.112.22','2007-06-27 14:24:47','2007-06-27 12:24:47','@ oedip: Daaa, maa, stiu, da\' asa o zis doftoru ala de genialitate la care ma tot duc, ca cica da bine sa faci pe modestu, ca nu mai stiu din ce cauza. SI DACA VREAU FEMEI CU CELULITA, MA DUC LA MAMELE DUJMANILOR!!!\r\n@ Andrei Crivat: daaa, moo, stiu, da\' urarile erau de la vocea aia care imi tot repeta opsesiv ca vom cuceri lumea, sh nenea doftoru\' de voci in cap la care ma tot duc o zis ca sa nu mai zic la nimeni de ea, chiar daca suna la telefon!!! Apropos de fraza, asa-i ca e uimitor ce poate face o fraza despre perechi de sani? :D\r\n@ Mary: Nu moare groparii, asa o zis nenea doftoru\' ala care diseca gropari, ca cica a\' dreq ficat mai vre bere!!!\r\n@ sabina: da, am foarte mare grija, mai ales ca nenea doftoru\' ala care indeplineste dorinte la gropari o zis ca nu se poate sani fara femeie atasata, si io am zis ca ok, asta e\r\n@ IepurasulAtomic: Nu, ca o zis nenea doftoru ala care dezasfixiaza gropari inecati in sfarce ca asa ceva nu e literalmente posibil, chiar daca sanii sunt, cum sa zic io mai plastic, moartea mea, frate!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(3409,496,'varza','tudor.maris@gmail.com','http://rottencabbage.haipa.ro','58.165.5.126','2007-06-21 21:52:50','2007-06-21 19:52:50','-daca-i pe jos, e montat\r\n-colacul e de surprinzator de multe ori JOS\r\n-Poseidon statea cu ea sub apa si cred ca si lui ii zicea nevasta-sa ca nu-i spalata (furculita...)\r\n-nu trebe, ca-i balcon inchis\r\n-e bine si de 2 ori pe an, economisim curent electric\r\n-yeah, right!\r\n-daca nu-i rece frigideru, nu-i rece berea\r\n-pana la un anumit nivel de gri merge\r\n-niciodata nu am reusit, cand am incercat arata ca un parbriz de dacie din \'78\r\n-nu, e drept\r\n-pentru ce sunt Sfintele Sarbatori Pascale???\r\n-ne e mila de flori, de fapt......\r\n-Camembert?\r\n-la ce bun, daca nu ne spalam si pe noi? si cat timp mai e marmelada in casa....\r\n-intru incaltat cand ma grabesc, normal ca nu stau sa matur\r\n-dezordinea ta e ordinea altuia..\r\n-hahaha\r\n-presul e curat, ca doar nu ne stergem...',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(3954,506,'Adi Calarasu','acalarasu@gmail.com','http://adriancalarasu.wordpress.com','89.32.21.164','2007-07-15 21:12:44','2007-07-15 19:12:44',':)\r\nBine-ai venit inapoi acasa, oriunde-oi fii tu acolo pe Feleacu sau mai la vale.\r\nHai ca ai de dat socoteala! Si nu ma refer la socoteala aia de care ziceai matale mai devreme!\r\nRaportu tata!!\r\n:))\r\n;)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(3956,504,'Placerea nu se refuza &raquo; ä»Šä¸€ç•ªç¾Žå‘³ã—ã„ã®ã¯ï¼ï¼ï¼','','http://groller.info/geza/2007/07/15/%e4%bb%8a%e4%b8%80%e7%95%aa%e7%be%8e%e5%91%b3%e3%81%97%e3%81%84%e3%81%ae%e3%81%af%ef%bc%81%ef%bc%81%ef%bc%81.html','193.203.205.12','2007-07-15 21:58:14','2007-07-15 19:58:14','[...] ma ajuta Groparu sa traduc [...]',0,'1','Incutio XML-RPC -- WordPress/2.1.2','pingback',0,0),(3432,497,'Adi','acalarasu@gmail.com','http://adriancalarasu.wordpress.com','89.32.19.126','2007-06-22 19:42:50','2007-06-22 17:42:50','ma Gropare,\r\ndeci te duci frumos la geaponezu-ala, ii bagi o mana in gat si-i zici:\r\nCE CAUTI BAH IN MUNTII NOSTRI?!\r\nsau\r\nUAT AR IU LUCHIN FOR BAH IN AUR MAUNTAINS, biaci?!\r\nsi-atat, ca banui ca nu stii tu si japonieza d\'aia.\r\nca s-arati cine-i stapanu!\r\ndupe aia (sau inainte?) te gandesti la planu\' be, ca poate-i f\'un ninja sau samurai ceva, si-atunci se-nvarte situatiunea...',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(3433,496,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.112.22','2007-06-22 21:45:07','2007-06-22 19:45:07','Ba man, le-as zice, da\' duamnele is dame bine, care or cam trecut de varsta aia la care cautau amanti pe net :D plus ca prea tare m-am kinuit sa strang ceva rest de harem in juru meu, sh nu prea mi-i lesne sa dau share full access',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(3434,497,'Adi','acalarasu@gmail.com','http://adriancalarasu.wordpress.com','89.32.19.126','2007-06-23 00:08:57','2007-06-22 22:08:57','aa, si sa-mi dai si mie poze d\'alea cu japonezi care fac poze, ca fac un studiu.\r\neu ar trebui sa cochetez (adica sa joc cricket japonez, cu croseuri) cu japonezii pen\'ca si eu am ochii mici si putin oblici, nu stiu de ce, d\'aia sap sa vad, ca trebuie sa fi fost un tatar sau hai, un hun la mine in copacul ala cu gene, ma gandesc eu, si si poze-mi place sa fac...',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(3384,488,'baghy','baghy83@lycos.it','http://baghy.wordpress.com/','78.12.5.241','2007-06-20 19:58:35','2007-06-20 17:58:35','interesanta injuratura',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(3405,496,'Adrian','acalarasu@gmail.com','http://adriancalarasu.wordpress.com','82.76.75.99','2007-06-21 17:07:47','2007-06-21 15:07:47','@Groparu\r\np\'asta n-am vrut s-o zic ca cica nu-i frumos sa te iei de parametrii fizici ale celor mai defavorizati.\r\nce, crezi ca eu am vrut sa ma opresc din creascut la unu sais\'sase? :D',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(3406,496,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.112.22','2007-06-21 17:31:03','2007-06-21 15:31:03','Da, mo, da\' pun pariu ca matale ai p*** mare!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(3407,496,'baghy','baghy83@lycos.it','http://baghy.wordpress.com/','78.12.8.157','2007-06-21 17:48:36','2007-06-21 15:48:36','Gropare vezi ca ai un video cu dedicatie la mine pe blog',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(3386,488,'laura','','','71.203.145.21','2007-06-21 00:25:28','2007-06-20 22:25:28','nea gropare,\r\ndeloc legat de subiect, uite un link fain http://thura.newsvine.com/_news/2007/06/16/785044-must-we-offend-large-women-to-sell-them-yogurt\r\nenjoy :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(3422,497,'Razvan','razvan.antonescu@gmail.com','http://idei-locale.blogspot.com','81.196.150.96','2007-06-22 11:53:52','2007-06-22 09:53:52','Apai bre...bed niuz....ca de vreo 2 ani am vazt trendu hasta original cu furatu mirelui :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.0; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(3423,497,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-06-22 12:44:05','2007-06-22 10:44:05','Miri japonezi??? Si astia vin in tzara sa ne ia femeile, locurile de munca sh sa se lase furati la nunte???',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(3424,497,'katmai','katmai@keptprivate.com','http://www.512kbps.com','195.212.29.163','2007-06-22 14:10:08','2007-06-22 12:10:08','... fura-i masina si banii ... asa o sa fie o nunta de neuitat :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7 (CK-IBM)','',0,0),(3425,496,'katmai','katmai@keptprivate.com','http://www.512kbps.com','195.212.29.163','2007-06-22 14:12:22','2007-06-22 12:12:22','si timp gramada la dispozitie :)))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7 (CK-IBM)','',0,0),(3404,496,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-06-21 16:50:18','2007-06-21 14:50:18','@Adrian: si pe langa toate astea e si pitic de un metru 50! Si pun pariu ca ii puneau aia mai mari chilotii in cap cand era la scoala, ipochimenu\'!\r\n\r\n@Andreanum: imi inghit avalansa de ganduri misogine care se kinuie sa demonteze ce scrisashi, da\' cum puii mei nu e aia exploatare cand esti legat la ochi, incatushat de pat si abuzat cu marmelÄƒzi de prune turnate pe trup, linse pÃ¢na la subtierea pielii de o gura flamanda si niciodata sÄƒturatÄƒ, si sufocat de tÄƒt felu de fumuri Ã®necÄƒcioase de la lumÃ¢nÄƒri aromate, \"ca asa-i romantic, am vazut la TV!\"? Si dupa aia tot tu esti de vina cÄƒ o Ã®ntrebi dacÄƒ mai are, cÄƒ Ã®ncepe etapa la 9!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(3426,497,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-06-22 15:28:15','2007-06-22 13:28:15',':))\r\n\r\nCumnatu-meu, care e coios si neamtz in acelasi timp, vine cu sor-mea in patrie. Sh la vama, vameshii  - clar, sushanele, momele, doar-doar o pica ceva de la mashina cu numere germane. Sh unu zice: trebuie sa dati 200 euro. Cumnatu-meu, desi e coios si neamtz, se cam caca pe el, sh umbla in portofel; da\' nu se rabda sh intreaba: da\' di ce? \"Taxa finca ne loatz fetele din tzara!\"\r\n\r\nBanc cu vameshi. Cumatu-meu o ras numa\' finca nu o trebuit sa mai deie bani, nu finca ar avea simtzul umorului foarte dezvoltat :D Da\' e ficior cumsecade.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(3427,497,'baghy','baghy83@lycos.it','http://baghy.wordpress.com/','78.12.13.222','2007-06-22 16:35:44','2007-06-22 14:35:44','important ca-i ficior cumsecade.fura si tu o japoneza si pune-o pe blog in lenjerie intima',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(3613,502,'katmai','katmai@keptprivate.com','http://www.512kbps.com','195.212.29.171','2007-06-27 14:36:04','2007-06-27 12:36:04','waaaaa ce tare gropareeeeee :))) iti fac portret ... moaaaama mersy pt idee moshule :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7 (CK-IBM)','',0,0),(3719,505,'baghy','baghy83@lycos.it','http://baghy.info/','78.12.11.69','2007-06-29 16:25:07','2007-06-29 14:25:07','Distractie placuta.Meriti o pauza dupa tampenile astea',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(3993,525,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-07-17 14:48:14','2007-07-17 12:48:14','@ Pazvante: ca de obicei, esti un clarvazator; da io zic ca cum in univers nu exista nici sus nici jos, o statuie poate foarte usor sa coboare in sus!\r\n\r\n@ Marcu: bag pixu ca saptamana asta am cate o serie de beri programate zilnic, si toate culmineaza cu alta nunta - dumineca; mersi ca mi-ai dat subect de umezit gatu! Ca nij nu stiam pentru ce sa mai beu ;)\r\n\r\n@ Epurila: :)) io cand am cetit echer si pasarica m-am gandit instant la kamasutra...\r\n\r\n@ bicplayer: Mo! Nu prea le da Iancu nimic, ca o primit el destul de la ei... sh saitu\' asta e chiar super pro intelegere dintre romani si unguri, casatorii inter-rasiale cu negrese, recunoasterea drepturilor lesbienelor de a infia adulti ca mine, si cu ocrotitu\' - NICI MACAR DUMNEZEU NU NE POATE PAZI PE NOI, PE ROMANI, DE NOI INSHINE! :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(3720,505,'sabina','','','86.105.121.103','2007-06-29 16:31:50','2007-06-29 14:31:50','chiar asa, distractie placuta!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(3617,502,'katmai','katmai@keptprivate.com','http://www.512kbps.com','195.212.29.171','2007-06-27 14:42:32','2007-06-27 12:42:32','http://512kbps.com/wp-pics/mucilavale.JPG nu am putut rezista dawg :D sorry. this was fast :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7 (CK-IBM)','',0,0),(3618,502,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.112.22','2007-06-27 15:22:22','2007-06-27 13:22:22','Pfuaaai de minee, cat curge din capu\' meeeeu!!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(3619,503,'Korova','korova_seven@yahoo.com','http://andreanum.wordpress.com','86.106.20.58','2007-06-27 16:03:55','2007-06-27 14:03:55','Ca tot te duci la mare in curand... va dedicam acest wallpaper cu proprietati curative miraculoase, dorindu-va sa vi se arate aievea cand veti pasi \"pe malu apii\" :d (da, ma, click, are niste Å£Ã®Å£e, sa te saturi, nu alta:))\r\nhttp://art.milt.eu.org/Art-Gallery/Free-Wallpapers/mermaid.painting.jpg',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(3401,496,'Adrian','acalarasu@gmail.com','http://adriancalarasu.wordpress.com','82.76.75.99','2007-06-21 14:44:11','2007-06-21 12:44:11','da fetelor!\r\nsi sa stiti ca brad pitt are oameni care-i calca blugii la dunga, ii fac frenci manichiur, ii sterg lentilele de contact alea albastre, ii fac suvite frumoase la par si patratele pe burta, mah!\r\nasa ca degeaba va uitati voi cu admiratie la el, ca nu-i meritul lui, na!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(3402,496,'andreanum','andreanum@yahoo.com','http://andreanum.wordpress.com','194.30.177.1','2007-06-21 15:01:34','2007-06-21 13:01:34','da, napoleon isi facea singur cizmele cu crema! orice barbat isi da singur botinele cu crema. ba unu le da si pe ale mele :D\r\nnu mai zbierati, ca nu sunteti asa de exploatati. potential exista, vad io bine. cred ca inca nu v-ati gasit zabala potrivita, cum mah sa pui barbatu sa spele asternuturile?? :)))',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1)','',0,0),(3391,485,'Emaginatoru','e_magist@yahoo.com','','86.122.12.12','2007-06-21 08:59:06','2007-06-21 06:59:06','Bei, ratucii eshtia precis e cu studii. Precis ca angajatoriu i-o shcolit ce trebe sa se face daca pica tanti grasa pe podiaua RATUCului.\r\nSh e sh stresatz tata zua ca lucreaza si ei cu uamini nervosh. Tre sa aibe musai spor de stres. Io ma intreb cat e norma de lucru per zi... ca io stiu ezact la care ore nu-i de umblat fara belet, ca intra manelistii de serviciu. Si nu e decat v-o 4 ore pus cap la cap.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1)','',0,0),(3392,486,'Andreea MKT','supergirgir@yahoo.com','http://marlahermina.deviantart.com/gallery/','82.77.126.254','2007-06-21 09:29:53','2007-06-21 07:29:53','Fire in the hole!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(3400,494,'Adrian','acalarasu@gmail.com','http://adriancalarasu.wordpress.com','82.76.75.99','2007-06-21 14:22:01','2007-06-21 12:22:01','pai asta cam asa e, ca la anu\' nou, cum te prinde asa o tii tot anul.\r\nsi ce zici, n-as fii preferat sa ma prinda si pe mine treaz, satul, ftut si plin de bani? \r\nda\' a fost cam invers...',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(3399,488,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-06-21 14:05:17','2007-06-21 12:05:17','Deci singura problema cu fete mai durdulii e ca trebe crescuta cantitatea de iubire acordata, ca ai mai multe kile de iubit!!!\r\n\r\nNeserioshii sa se abtina.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(3398,494,'oedip','oedip74@gmail.com','http://oedip.blogspot.com','89.137.104.170','2007-06-21 12:43:27','2007-06-21 10:43:27','apoi io zic sa nu te chinui asa de tare ca esti p\'aproape :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(4115,537,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','86.105.72.125','2007-07-24 00:05:53','2007-07-23 22:05:53','E mah, da\' planu meu nu era sa pun doi nashi romani sa plateasca, din moment de aveam americanu\' bun de plata pt hotia aia josnica! Inke nu i-am facut fucktura, da\' nuuu-l ieeeert...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7','',0,0),(4166,316,'ania','soredarkshines@gmail.com','http://aniakhaki.blogspot.com/','89.123.85.116','2007-07-26 18:14:35','2007-07-26 16:14:35','si sa inteleg ca numa\' acum l-ai vazut? :&gt;',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4167,316,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','86.105.72.125','2007-07-26 19:32:58','2007-07-26 17:32:58','Nu, da\' iz in criza de subecte, ca io is omu\' predicaturilor',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4168,544,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','86.105.72.125','2007-07-26 19:40:05','2007-07-26 17:40:05','Asha le zic sh io de vreo 20 de ani, sh ma mir ca inca n-or bagat la cap...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4428,565,'Adi Calarasu','acalarasu@gmail.com','http://adriancalarasu.wordpress.com','89.32.19.126','2007-08-03 21:29:42','2007-08-03 19:29:42','cine-a pus anuntul asta?\r\nTetelu?\r\n:))',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(4170,316,'ania','soredarkshines@gmail.com','http://aniakhaki.blogspot.com/','89.123.85.116','2007-07-26 20:37:02','2007-07-26 18:37:02','a aparut o inghetata noua de la napolact...mousse ii zice. e in 3 variante :) scrie despre asta :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4171,316,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','86.105.72.125','2007-07-26 21:17:17','2007-07-26 19:17:17','Apoi... e mousse cu scroll, optica sh cu bluetooth? Astea is sortimentele?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4173,316,'ania','soredarkshines@gmail.com','http://aniakhaki.blogspot.com/','89.123.85.116','2007-07-26 21:37:36','2007-07-26 19:37:36','putem s-o luam si asa. hai sa vedem: pt mouse cu scroll avem inghetata cu praline...sau cum naiba era...ceva cu ciocolata; optic...capsuni si vata de zahar si pt bluetooth ramane cafea :) se potriveste...ca si mouse-ul meu bea des cafea :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4130,542,'mumuland','','','85.204.38.37','2007-07-24 22:17:43','2007-07-24 20:17:43','Minunata incursiune in vremurile cand......o carte de Jhules Vhernes mancatzas  se vindea numa musai dak luai si AGRICULTURA SOCIALISTA....ioar despre beutura cum ii zici matale ..Frate :  Vizitati cu incredere cooperativele noastre de consum ! ioi si asta e tare PROLETARI DIN TOATE TARILE MUITI-VA !.........ZAC BINIE? ;)\r\n\r\nIZ IO MA ...CUM CARE IO? ASTA :   ;)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(4425,559,'Calarasu','acalarasu@gmail.com','http://adriancalarasu.wordpress.com','89.32.19.126','2007-08-03 20:19:35','2007-08-03 18:19:35','Intrebarea e usor tendentioasa dar DA! :D',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(4217,547,'ania','soredarkshines@gmail.com','http://aniakhaki.blogspot.com/','89.123.127.250','2007-07-28 00:53:52','2007-07-27 22:53:52','nais la belis. saptamana trecuta se putea face baie :) poate ai noroc ;) \r\ndoar sa nu te pape viperele in cariera :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4218,546,'dadatroll','crayclant@yahoo.com','http://dadatroll.wordpress.com','67.161.47.114','2007-07-28 01:19:58','2007-07-27 23:19:58','Am o intrebare, pot sa ti-o pun?',0,'1','Mozilla/5.0 (Macintosh; U; Intel Mac OS X; en) AppleWebKit/419.2.1 (KHTML, like Gecko) Safari/419.3','',0,0),(4114,540,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','86.105.72.125','2007-07-23 23:42:50','2007-07-23 21:42:50','@g: nu te-ai prostit tu, nij gand, \"!\" era un pic cam obosit sh s-o incovoieat oleaca sa ishi traga sufletzelu\' lui de semn ortoepic, sireacu\'...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4123,507,'Femei','asdw@yahoo.com','http://de-aia.blogspot.com','86.122.8.62','2007-07-24 13:21:43','2007-07-24 11:21:43','foarte sexy femeile ma!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4125,540,'ss','criss_team@yahoo.com','','81.196.150.198','2007-07-24 15:02:10','2007-07-24 13:02:10','no, apai nu ca mi-s io avocatu ghiavolului....si nici macar n-am primit bani de la partea acuzata, da finca am un suflet absolut mare si bun le mai usurez (no liquids involved..ca doar i canicula si nu facem risipa) soarta aia a lor de violatori de limba comoara cum i romaneasca noastra si zic ca nu tre sa se scoata decat din kkoa a doo lufturi. adica: \"organizatia a carei activitate devine rutina se ofi\". eeee? merje?\r\n\r\n+\r\n\r\ndomnu groparu, io zic sa nu ratezi ocazia sa faci un ban de neste berici si sa le prezinti planu de prespalare a rusinicii, ca doar zice ei ca is \"deschisi la orice\". ashe ca ajtept sa incasezi comisionu ala gras si sa ma omenesti si pe mine cu o berica.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7','',0,0),(4126,540,'dadatroll','crayclant@yahoo.com','http://dadatroll.wordpress.com','67.161.47.114','2007-07-24 17:41:49','2007-07-24 15:41:49','Iliescu a avut 4 mandate. 1990-1990, 1990-1992, 1992-1996, 2000-2004.',0,'1','Mozilla/5.0 (Macintosh; U; Intel Mac OS X; en) AppleWebKit/419.2.1 (KHTML, like Gecko) Safari/419.3','',0,0),(4106,540,'g','licuricel@yahoo.com','','86.121.202.171','2007-07-23 22:52:59','2007-07-23 20:52:59','In afara greselilor....suna ca naiba. Cine a fost inspiratia autorului, Adrian Paunescu si Cenaclul Flacara!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.2; en-US; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4418,559,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-08-03 15:24:33','2007-08-03 13:24:33','@ ss: da, mo, Dumnezau nu-si uita locotenentii, asa ca iata-ma-s!\r\n\r\n@ Epurila: mo, te iau! te iau. Serios. Fii joi, 2 august, in fatza la Matthias. Vezi ca am ziarul Piatza in mana. Neserioasele sa se aptina! \r\n\r\n@ Mile kilometrice: deci daca ai avut shansa sa bei cu Gropan, deja esti mult deasupra tuturor cartierelor muncitoresti in patriea mea muma, care ea m-o ales pe mine, ca de alegeam io, alegeam clar insula Lesbos! Sau Heterosexoalos.\r\n\r\n@ \'mnu Neanderthal: Da, mo, da eia nu canta manele goraniceshti! Ca m-am interesat, am gugalit. \r\n\r\n@ CÄƒlÄƒ: Nij nu stii cat rezon ai! Da, Goranica e modest, sh asha is si io, sh io, fiind modest, nu am cum sa fiu deasupra ta mah, sh sh daca ash fi, tat n-as recunoaste, ca-mi scade traficu\' daca te superi sh nu mai vii. Corec?\r\n\r\n@ mumuland: da, mo, sibienii are sh ei tiganii lor, sh unii vin la Cluj sa fure malaiu\' din capitala Transilvaniei? Cine vine? Cum cine! Io, mah, asta, care altu\'?\r\n\r\n@ ania: imi fac unu cu girl power outage. Mere?\r\n\r\n@ mumuland: imi fac unu cu girl power failure. Mere? \r\n\r\n@ vedete: mo, ash fi putut veni, dar cred ca am avut chestii mai interesante de facut, gen sa studiez analele lenii mele ancestrale, sau sa studiez cum dreq se duc banii astia, mah, din buzunar, de parca nij n-or fo acol\' niciodat\'!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4108,540,'g','licuricel@yahoo.com','','86.121.202.171','2007-07-23 22:53:46','2007-07-23 20:53:46','pardon, m-am prostit si eu. ? in loc de !',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.2; en-US; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4109,540,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','86.105.72.125','2007-07-23 23:23:32','2007-07-23 21:23:32','@ Dadatroll + Oitza = corect: Organizatia ale carei activitati devin rutina (fara virgula intre subect sh predicat decat daca virgulele delimiteaza o constructie incidenta) se ofi\'. True. True. Sh da, ie fraza, ca are doi predicatzi! :D\r\n\r\n@ Femei: Poza am facut-o exact din zona dinaintea ei. Am incercat sa ii fac sh din spate, da\' nu mi-o ieshit, mi-am facut sh cucui. In Cluj mi-o ieshit.\r\n\r\n@ Troznea: Daca descoperi a cui e logo-ul, Groparu.ro sponsorizeaza un All-you-can-eat romantic la \"impinge-tava\" unde am facut poza. Tu sh prekina/prekinul/cutzu\' matale. \r\n\r\n@ Epurila din uraniu: Lasand la o parte placerea repetitiva provocata de comentariile ne-zgarcite ale matale, cand mai vezi gropar belind ochii dupa decoltee te plantezi in fatza domniei mele, sh glasui: Gropare, ej bou! You will have my full undivided attention ;) Cat despre bac - io in Delta am intalnit oameni care iau bacul zilnic. Ii si costa vreo 6 lei sau ceva de genu\'. Meditatii contra bere? Yyyyesss... Io zic sa incercam sa dam de MISA, eia te invatza sa meditezi gratis, sh banii astfel economisiti ii prapadim pe bere!\r\n\r\n@ All: Io n-am nemica cu agramatii sh anagramatii, finca limba e facuta sa fie violata; sh un gand dajtept eclipseaza o gramatica de caporal. Da\' cand o firma cheltuie neshte banutzi serioshi pt reclama, sh primeshte o fraza (ptiu, propozitie) cu un record de trei gafe gramatical greshite incorect de la Itzy Bitzy Media, care este, nu merita ei asha, putin, un mic sex oral?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4110,534,'Femei','pas@yhaoo.com','http://de-aia.blogspot.com','89.137.117.237','2007-07-23 23:26:06','2007-07-23 21:26:06','fac dragoste cu lumina stinsa \r\n\r\npare mai mare pe intuneric? sau prinzi curaj? :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.2) Gecko/20070219 Firefox/2.0.0.2','',0,0),(4642,588,'Adi','acalarasu@gmail.com','http://adriancalarasu.wordpress.com','89.32.19.126','2007-08-10 23:59:40','2007-08-10 21:59:40','@Calarasu\r\nHehe, aista-i buna de \"Intrebarea zilei\", ia ca t-o iau io cu \"cut\"...',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(4779,589,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','86.105.72.125','2007-08-15 00:41:19','2007-08-14 22:41:19','@ octaaaaaaa!!!!!! we missed uuuuuuuuuuu\r\n\r\n@ radu m: man, rahat in straitza! daca nu aghetzi nimica, ori stai pana vin studentele, ori da o tura pan\' la Costineshti, ca e var-mio acolo, sh zice ca e femeile... ptiu, conditiile faine!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4417,559,'Vedete','asdw@yahoo.com','http://vipuri.blogspot.com','213.157.188.71','2007-08-03 14:38:44','2007-08-03 12:38:44','da n-ai putut mere cand o cantat la cluj, ma?!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4112,530,'Femei','pas@yhaoo.com','http://de-aia.blogspot.com','89.137.117.237','2007-07-23 23:30:01','2007-07-23 21:30:01','as arde si eu ceva in noaptea asta si nu raspunde pe messenger... nu ai nr lui de tel? :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.2) Gecko/20070219 Firefox/2.0.0.2','',0,0),(4113,540,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','86.105.72.125','2007-07-23 23:41:20','2007-07-23 21:41:20','...sh daca suntetz cuminti, am sa va zic ce plan de scoatere din kko le-as propune firmei care o loat tzapa cu reclama: in stanga, vechea reclama, langa care sa scrie: \"asa arata fosta noastra reclama\"; in dreapta, textul revizuit, adaugit, etc. Sh mesajul: \"NOI nu pierdem nici o ocazie sa ne dezvoltam pentru dvs\", sau o cacatura de genu\' asta. \r\n\r\nSh m-as scoate bazma corata, ca corporatie! Ca doara nu exista publicitate negativa care sa nu fie benefica, ca d-aia o castigat Iliescu tri mandate!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4122,536,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-07-24 11:10:55','2007-07-24 09:10:55','Amu io nu-ntzaleg: daca noi avem vadimii, funarii sh falitii nostri, de ce nu i-ar avea sh ei p-ai lor? Sh inca ceva: io am tot auzit bancuri cu romani sh unguri; da\' bance cu unguri sh romani nu e? Ca is sigur ca sh ei are! Sh-s curios...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4091,540,'dadatroll','crayclant@yahoo.com','http://dadatroll.wordpress.com','171.64.233.22','2007-07-23 18:33:08','2007-07-23 16:33:08','- Ai\r\n- Devin\r\n- Fara virgula intre subiect si predicat',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(4092,536,'dadatroll','crayclant@yahoo.com','http://dadatroll.wordpress.com','171.64.233.22','2007-07-23 18:35:11','2007-07-23 16:35:11','alexier suge in toate limbile. \r\n\r\nVezi limba cailor cu un experiment care demonteaza tampenia asta cu ungurii care nu vorbesc romana cu tine ca nu vor.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(4587,583,'Radu M.','radu_muri@yahoo.com','http://theblacklight.wordpress.com/','79.113.139.242','2007-08-09 07:19:31','2007-08-09 05:19:31','-&gt;nu imi bag pluginu de melodii ca m-as da de gol cu ce prostii ascult\r\n-&gt;Life is full of shit,and i can see you are full of life\r\n-&gt;',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7','',0,0),(4094,540,'oitza','oitza@yahoo.com','','24.17.110.178','2007-07-23 19:25:01','2007-07-23 17:25:01','ale...',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(4095,540,'Femei','pas@yhaoo.com','http://de-aia.blogspot.com','89.137.117.237','2007-07-23 19:26:29','2007-07-23 17:26:29','da in ce zona-i facuta poza? :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.2) Gecko/20070219 Firefox/2.0.0.2','',0,0),(4096,537,'Femei','pas@yhaoo.com','http://de-aia.blogspot.com','89.137.117.237','2007-07-23 19:30:14','2007-07-23 17:30:14','Sa traiasca Tibilica, ma!\r\n\r\nSlab ai fost ma de americanu o fost in stare sa iti fure mireasa de sub nas!\r\n\r\nHai sa traiesti si tu!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.2) Gecko/20070219 Firefox/2.0.0.2','',0,0),(4097,540,'dadatroll','crayclant@yahoo.com','http://dadatroll.wordpress.com','171.64.233.22','2007-07-23 19:35:55','2007-07-23 17:35:55','Da, ale, am gresit si eu. \r\n\r\nDar e fraza sau propozitie? Care e a doua propozitie?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4098,525,'dadatroll','crayclant@yahoo.com','http://dadatroll.wordpress.com','171.64.233.22','2007-07-23 19:40:22','2007-07-23 17:40:22','Statuia E statuia Caritasului. Din banii Caritasului s-a facut. Si cum Caritasul s-a oprit \"in 5\" (adica li s-a dat ultima data banii inapoi celor care i-au depus pe 5), s-a spus ca o sa le dea banii inapoi celor care au depus pe 6 cand o sa arate Iancu 6 degete. Muhahahahhhhahahahahhahhhhahhhhhahhhhahha Ha ahahh ahhh ahhhh hhaaa hahha.\r\n\r\nHei, daca tot vrem o statuie cu perioada funariota, de ce nu facem una cu un veceu vopsit in tricolor?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4099,540,'Troznea','','','81.181.119.76','2007-07-23 20:23:42','2007-07-23 18:23:42','Ai sters numele. Dar ai lasat logo-ul. Promisiunea a fost respectata doar pe jumatate. :)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(4588,583,'Radu M.','radu_muri@yahoo.com','http://theblacklight.wordpress.com/','79.113.139.242','2007-08-09 07:20:36','2007-08-09 05:20:36','Apoi Gropare tata tu stii ca iengleza ie limba universala...asa ca tre` frate sa ne adaptam la schimbarile acestea cie au loc in sotzietatea noastre care este....',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7','',0,0),(4101,540,'IepurasulAtomic','praetorian21uk@yahoo.com','','62.217.245.97','2007-07-23 20:53:29','2007-07-23 18:53:29','Gropareee...ce-mi facusi ma? Io de obicei pic de bou, da\' nu la gramatica! Bine, n-oi fi io AS(S) ca doar nu-s carte de joc, da\' parca aveam undeva intre 5 si 10 la gramatica. Tu-i mama ma-sii, io sunt sigur ca cre\' ca profa de romana o acceptat spaga aia de la mama :((. Mno, zi tu, ce fac io acuma? Cum mai dau ochii cu tine data viitoare? Cine stie cate greseli gramaticale, ortoepice(sau ortopedice, de ce nu?!) si de punctuatie oi face(mai cu seama de punctuatie atuncia cand vorbesc)?! Fara (lipsa de) respect pentru cei care si-o dat cu presupusu\' mai sus, io vreau sa le aud din gura ta(greselile, care este)! Numa\' asha de test, ca prea te-ai dat ciumeg. Si sa mor io de nu ma rad cand o vini alt intelijent p\'aci si ti-o zice ca de fapt nu-i asha...sa vezi tu ce creste traficu\' atuncea...mai ceva ca cand ala de s-o aruncat pentru profa de gramatica(sau de romana, ca-i tot una, nu?). Mno, deci io astept, sa nu ma dezamagesti ca am bacu\' la anu\'...bine, io il dau cam a 6-7a oara(ca nici nu mai stiu), da\' mama mi-o zis sa nu ma dau niciodata batut(sau baut?nush, ma rog, irelevant). Io te rog sa ma ajuti...ce zici de programu\' asta: \"Meditatii pentru bere!\"? Eh, acuma mai vezi vreo greseala gramaticala? Pai asha....',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(4174,316,'mumuland','','','85.204.38.37','2007-07-26 22:07:01','2007-07-26 20:07:01','hm ........... o zo pun shi eu deo firma de asta da ashtetpt studentele alea din anu intai  cu tatele pe afara dhin nu mai stiu care epopeeum deliurim de a ta din oaresce zi........ cu alea as fura sio io statu roman si dupe aia leas condamna la trajere in teapa....\r\nbuna treaba cu inghetaat da stii proverbul ala care nici nu se epsista? ...............  asta e :  cine  stie sa linje klar ca cunoaste toate sortimentele de inghetata....\r\n\r\n\r\n  iz io ma.care io? asta: ;)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(4128,540,'IepurasulAtomic','praetorian21uk@yahoo.com','','62.217.245.97','2007-07-24 20:32:28','2007-07-24 18:32:28','No ce ti-am zis io ca tot nu scapi si sare p\'aci unu\' mai destebt ca tine?! He he, ce ma rad! Auzi, io am o confesiune din aia de spun ce-am pe suflet. Io nu mi-am dat seama ma de duma cu bacu\'...in primu\' rand c-am fo\' prea flatat de faptu\' ca tu esti in mod repetat satisfacut(daca-mi permiti asemenea cuvant) de comentariile mele...deci carevasazica, nu m-am prins de duma ta decat acuma. No zi tu, nu mai bine dau dracu\' 6 lei si trec bacu\', ca p\'aci prin Cluj am auzit c-ar costa sute de iepuroi :)?! Salutari cu respect...vedeti ca ati ramas restant cu articolu\' pe azi...nici acum nu-mi pot opri suspinele de fata mare :)...',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(4084,536,'alexier','alexier_90@YAHOO.COM','','89.35.116.70','2007-07-23 09:31:21','2007-07-23 07:31:21','hai gropare ca mai trimet si io pin lista mea de mess un mass ca sa il voteze tati romaniii pe Silvan pretenu tau',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; DigExt)','',0,0),(4085,536,'alexier','alexier_90@YAHOO.COM','','89.35.116.70','2007-07-23 09:42:47','2007-07-23 07:42:47','bha fratiilor, uitati abstract de povestea cu SIlvan. Ieri  fusai cu preten de a meu in Targu Mures trebuia sa mereem mai multi la binoclat si agatat de femeiii da so tras restu pe cur si no.... Bha apai io am fost in toata eurpo vorbesc bine engleza si foarte bene germana si ma a desxcurcat peste tot. Pana am ajuns in mures no sa vezxi tu acolo ca romana pula engleza pula germana pula sa vezi tu acolo maghiari ioi... Tg mures ii un oras frumos da io imi bag pula sa ma dcu la magazin sa cer un pachet de tzigari si pizda aia imi zice ca ia nu intelege romaneste da de aia ssta la noi in tara mancamiar toata pula no bine ka akuma macara cat de cat m-am descarcat',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; DigExt)','',0,0),(4086,270,'gigig','budau_claudiu@yahoo.uk','','89.38.65.11','2007-07-23 11:16:16','2007-07-23 09:16:16','ce muie are baaaa\r\n:))) muieee:)) \r\noiare stie sa faca muie?:)))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(4087,536,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-07-23 11:19:53','2007-07-23 09:19:53','Deci mo, adevaru\' e ca daca ash fi vanzator, sh mie mi-ar placea sa fufu neshte tinerele la icre cu \"non comprende\"!!! :D daca tanti vroia sex sh tu nu te-ai prins?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4089,525,'ot','','','86.34.3.100','2007-07-23 15:36:34','2007-07-23 13:36:34','se poate schimba linistit statuia cu iacu, pentru ca nici chiar in perioada comunista nu s-au realizat astfel de statui hidoase. la fel este si cu crucea de pe cetatuie si cu monumentul rezistentei comuniste de langa facultatea de chimie. \r\nstiti cate sute de milioane a luat realizatorii pentru lucrarile acestea? bineinteles ca s-a dat si putina mita si s-a mers pe interese (poate ca la festivalul de folk la care a fost vasilica nedreptatit). ati vazut ce alte proiecte au fost propuse cand s-a luat decizia de a se realiza? ceva popular, traditional, facut cu gust poate sa inlocuiasca cate o astfel de monstruozitate. \r\nproblema e ca trebuie privite lucrurile in esenta si nu superficial. \r\nnu trebuie facute statui aurite si cu imparati pe care nu i-am avut, dar ce se face se poate face cu cap si cu gust. asta doar daca nu va incasa si nenea boc niste bani cum a facut si tatucul funar (de pe acuma bunic la cati ani ne-a scolit), cand s-a decis ce proiect va fi acceptat. \r\ncred ca toate aceste monumente se potrivesc foarte bine cu imaginea lui funar din ultima campanie. cand pe strazile din manastur circula un camion vechi de prin 80 plin cu oameni care fluturau drapele si se canta Legenda lui Kashay (c-asa-i romanul cand se-ntinereste).\r\nno, si amu la incheiere va urez sa cascatii ochii si sa nu vedeti pana in primul perete si sa lasati pita si circul pentru cei care o fac sa se infrupte ei din ele si sa nu le dam noi apa la moara.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Media Center PC 3.0; .NET CLR 1.0.3705)','',0,0),(4175,316,'IepurasulAtomic','praetorian21uk@yahoo.com','','62.217.245.97','2007-07-26 23:52:14','2007-07-26 21:52:14','Gropare...am io un subiect mult prea tare pentru tine...ce merita mentionat si vreau...pentru prima data de cand muma\' me m-o facut...sa-i dau cat mai multa publicitate. Numa\' asha...ca stiu io de ce :). Cand vin luni de unde plec(numa\' ashe sa te bag in ceata), itzi spun ce si cum. Nu zic mai multe, sa ramai curios si tu peste vickend. Ma pun la somn sa hodin berule ce le-am servit in seara asta, ca io-s ciumeg si maine nu servesc servici(adica azi...vineri, nu stiu cat iulie 200...si ceva). Ne auzim, sper sa ma ajuti cu treaba mai sus NEmentionata, ca-i de belea :D.Ceau!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(4133,544,'Adi Calarasu','acalarasu@gmail.com','http://adriancalarasu.wordpress.com','89.32.19.126','2007-07-25 13:08:05','2007-07-25 11:08:05','Ma voi sigur n-ati facut zama din animalutul ala dragut de companie, din poza, nu?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(4421,560,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-08-03 15:48:14','2007-08-03 13:48:14','@ vedete: nu-i adevarat! e o minciuna! nu-i adevarat! incerci sa te legi de goranu\' meu!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4137,544,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-07-25 14:08:53','2007-07-25 12:08:53','Mo, nu, ca io de cand cu sherpii din pantaloni cam am grija ghe tatie alte asemenea taratoare!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4138,542,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-07-25 14:09:40','2007-07-25 12:09:40','Da mah, zici bine, da io as zice \"Proletare din toate tarile\", stii, ca sa pastram totusi un minim de monosexualitate apsoluta!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4185,544,'angel','','http://leoaica.wordpress.com','82.77.83.83','2007-07-27 11:47:48','2007-07-27 09:47:48','Am ras cu lacrimi citind faza cu salvatorul Luci.:))) Atat eu cat si o duzina din colegii de serviciu. Felicitari pentru blog, este medicament pentru zilele de luni. si nu numai!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(4186,540,'angel','','http://leoaica.wordpress.com','82.77.83.83','2007-07-27 12:04:09','2007-07-27 10:04:09','la o parte politica vrem sa aflam continuarea. a corectat cucoana greselile au ba?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(4140,544,'Femei','asdw@yahoo.com','http://de-aia.blogspot.com','86.122.8.62','2007-07-25 14:40:40','2007-07-25 12:40:40','ai ma! si in delta te-ai pierdut?! :P \r\n\r\nii mai greu ca in mijloc de cluj-napuci? :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4141,544,'Vedete','asdw@yahoo.com','http://vipuri.blogspot.com','86.122.8.62','2007-07-25 14:41:25','2007-07-25 12:41:25','trabuia sa intrebi o pasarica care-i drumu spre casa.\r\n\r\n(t-o placut cacafonia? :P )',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4142,544,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-07-25 14:54:40','2007-07-25 12:54:40','@ Femei: nu m-am pierdut, ca am stat agatzat de picioru\' lui Luci mai tare decat daca ar fi fost fusta de brazilianca!\r\n\r\n@ Vedete: Cacafonia, sau cacofobia? A doa oare e sinonima cu constipatia? Amu... din cate stiu io, pasaricile nu vorbeshte... am gresit?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4143,544,'mumuland','','','80.97.64.199','2007-07-25 15:10:23','2007-07-25 13:10:23','ioi se selpisol dulse.....hanacoanda de romania care se ineaca drecu si cu o boaba de mazare:)\r\n\r\n\r\nis io ma.care io ? asta: ;)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12','',0,0),(4144,544,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-07-25 15:13:36','2007-07-25 13:13:36','@ mumuland: ma mumuland, tu esti, sau frate-tu geaman???',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4145,540,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-07-25 15:39:19','2007-07-25 13:39:19','@ dadatroll: Iliescu o avut 4 mandate DEOCAMDATA! (this really worries me)\r\n\r\n@ Epurila: da, mo, ma cam oboseste atata genialitate, sh d-aia mai fac greshale intentionat!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4187,316,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-07-27 12:08:04','2007-07-27 10:08:04','You ppl don\'t wanna mess with my Engrish. It\'s a mess already.\r\n\r\nEpilat Gropari? Saptamana viitoare ma tund chel, ca deja nu mai suport sa gandesc de sub capitza!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4188,544,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-07-27 12:10:00','2007-07-27 10:10:00','Man, mersi, normal ca e medicament, doara scriu numa\' cand iau codeina cu bitter suedez!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4189,540,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-07-27 12:11:41','2007-07-27 10:11:41','Nush, ca n-am mai mers sa pap in crajmoteca aia, finca numa marti iau banetu\', sh pun pariu ca nij dupa marti nu o sa mananc, ca daca o sa am bani o sa merg la beute, nu la papica!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4190,316,'cetitoare','totmea@yahoo.com','','86.35.232.96','2007-07-27 12:14:46','2007-07-27 10:14:46','no sa-mi retii si mie un post caldut (ori de incalzit)  in SC GROPARU Corporate, ca pin\'atunci ma reincarnez intr-o bunoaca (sigur. ca mi-o zis mie un tibetan).\r\ninghetata mousse...ce combinatie! oare ingheata (impietreste) si si fixeaza???? ohohooooo, de te tine turul Europei?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(4191,546,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-07-27 12:15:05','2007-07-27 10:15:05','OK, domnu\' Groparu, pot incepe eu?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4192,544,'alexier','alexier_90@YAHOO.COM','','89.35.116.70','2007-07-27 12:17:40','2007-07-27 10:17:40','no ma fusai si io in delta cu un amic care are o chestie dinaaia la care el ii zice iaht de 4 pers ma rog masina mea ii mai mare da in fine am stat aproape o sapt mo intepat tantarii de ma scarpin preste tot desi am folosit sg 4 tuburi dealea de autan care nici nu ii ieftin no.. si delta ii faina mancarea nustyu ca numai pe apa am stat ce o gatit fetele am mancat da in total va recomand sa mereti in delta ca merita chiar si aia ca mine care nustyu sa tina nici un bat de peste in mana asa k mine. \r\nBha fie ca avti jeepuri sa orice masina am luato pe un drum nhational cu tot cu jeep care ei zic ca cu ala nu poti sa ramai nicaieri mah io mam dus pe un drum national(ziceau astia pe pancarda) si am ramas cu toyota Landcruiser acolo de l-am sunat pe un amic din Ct sa vie sa ma scoata de acolo si tapa el o ramas cu Toaregu tot acolo pan la urma o vin un nene cu tracoru si ca sa scoata amandoua masini o cerut 100 lei :=(( bagamias in tractorul lui. deci nu va aventurati indiferent de masina... ca dor ii DN',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; DigExt)','',0,0),(4193,316,'ania','soredarkshines@gmail.com','http://aniakhaki.blogspot.com/','89.123.79.141','2007-07-27 12:26:39','2007-07-27 10:26:39',':)) e ca si cum te-as duce la epilat :)) (apoi la o inghetata in prima cripta pe stanga)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4194,546,'bicplayer','bic_player@yahoo.com','','86.125.169.80','2007-07-27 12:28:22','2007-07-27 10:28:22','ba ma durea capu si inainte sa citesc asta si acuma ma dore si mai tare :-s',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4195,544,'angel','','http://leoaica.wordpress.com','82.77.83.83','2007-07-27 12:46:06','2007-07-27 10:46:06','injectabil sau clisma?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(4196,546,'cetitoare','totmea@yahoo.com','','86.35.232.96','2007-07-27 13:00:04','2007-07-27 11:00:04','pretiosule...adoratule...ca si de nimicul tau ma incint si ma-nfior.\r\nce ti-as face de te-as prinde!\r\nce te-as face de ti-as prinde!\r\njoc de pronume.....deh, inteligentza decadenta.\r\n(ai zis orice)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(4197,546,'Marius','pop.marius@gmail.com','http://lityx.blogspot.com','86.35.157.42','2007-07-27 13:08:25','2007-07-27 11:08:25','Mie nu-mi convine, deci nu sunt de acord, in consecinta ma impotrivesc, prin urmare comentez.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4198,316,'sajata','a@a.com','','82.77.126.254','2007-07-27 13:24:19','2007-07-27 11:24:19','mo, tot am promis si io blogu\' ala, da\' numa\' nu am vreme (si kef) de el. da\' las\' ca o sa scriu cum m-am pisat intr-o corporatie unde nu se trage apa :D',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(4199,546,'J','','','89.136.54.155','2007-07-27 13:43:46','2007-07-27 11:43:46','Tzi-o adormit neuronu\' Dnu Groparu\' ? :)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1)','',0,0),(4200,546,'ania','soredarkshines@gmail.com','http://aniakhaki.blogspot.com/','89.123.76.238','2007-07-27 13:43:56','2007-07-27 11:43:56','nah bine! eu chiar nu am vrut sa vorbesc de inghetata peste idea ta de corporatie...da daca ai zis ca nu mai ai ce posta :)) daca vrei iti dau un tag ca si asa aia la care le-am dat leapsa is plecati...atata doar ca subiectul e idiot rau :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4201,546,'mumuland','','','80.97.64.199','2007-07-27 13:49:13','2007-07-27 11:49:13','mnoa cand sa ceteasca mumuland haberatiunea ta de azi.....mumu haberatiune....ce Mnezo ai facut in Delta...to papat stiuca inspiratia ?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12','',0,0),(4202,546,'scenarista','scena@yahoo.com','http://www.scenarista.wordpress.com','89.33.187.138','2007-07-27 14:02:25','2007-07-27 12:02:25','nu am rezisat niciodata la \"va rog frumos\". ce mai face clujul?\r\nfelicitari pentru blog.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4203,546,'Adi Calarasu','acalarasu@gmail.com','http://adriancalarasu.wordpress.com','89.32.19.126','2007-07-27 15:01:26','2007-07-27 13:01:26','Cand eram mic ardeam furnici cu lupa. Acum imi pare rau... :(',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(4147,544,'mumuland','','','85.204.38.37','2007-07-25 18:39:31','2007-07-25 16:39:31','trea asta cu iz io sau fratemio jeaman e legata de ce o patit chuk noris ala: sio peirdut virjinitatea inaintea lui tataso\r\noricum teio citi num a pacasa ca daca o fuck la job de festecare data safu se uita lung la minie si io ii zac foarte tandru: ce vrei ma pola?...daia nu creste remuneratia la mine.\r\n\r\n\r\niz io ma.care io? asta: ;)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(4159,544,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-07-26 12:48:37','2007-07-26 10:48:37','Geez, man, what kind of \'pasarici\' have you been having???',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4161,544,'Vedete','asdw@yahoo.com','http://vipuri.blogspot.com','86.122.8.62','2007-07-26 13:54:51','2007-07-26 11:54:51','tat felu man... sa stiu sa fac comparatie care ciguleste mai cu folos :P s-apoi cand o gasesc pe ai mai priceputa o bag la mine in cotetz ;)\r\n\r\ntu ai luat-o pe prima care o iesit in cale? :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4162,544,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-07-26 14:38:33','2007-07-26 12:38:33','Nu, numa\' pe prima care o acceptat, mah :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4163,540,'dadatroll','crayclant@yahoo.com','http://dadatroll.wordpress.com','67.161.47.114','2007-07-26 16:55:15','2007-07-26 14:55:15','Si Nastase are 4 case, deocamdata. In viitor o sa aiba una mica de tot, sau 10.',0,'1','Mozilla/5.0 (Macintosh; U; Intel Mac OS X; en) AppleWebKit/419.2.1 (KHTML, like Gecko) Safari/419.3','',0,0),(4164,544,'Vedete','asdw@yahoo.com','http://vipuri.blogspot.com','86.122.8.62','2007-07-26 17:00:37','2007-07-26 15:00:37','hai ma ca la valoarea ta tre sa accepte toate :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4204,546,'Vedete','asdw@yahoo.com','http://vipuri.blogspot.com','213.157.188.71','2007-07-27 15:24:40','2007-07-27 13:24:40','ma, las ca ii bine!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4205,544,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-07-27 15:30:01','2007-07-27 13:30:01','@ alexier: stii bancu ala cu groapa pe care o umplea tzaranu\' ala cu apa ca sa pice domnii de la orash in ea ca sa ii poata scoate cu tractoru\' sa faca un banutz?\r\n\r\n@ angel: da.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4206,534,'sktes','sktes_2002@yahoo.com','http://sktes.wordpress.com/','79.113.136.236','2007-07-27 15:57:06','2007-07-27 13:57:06','Tanti Gaia ar trebui sa ia notite :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4207,546,'ania','soredarkshines@gmail.com','http://aniakhaki.blogspot.com/','89.123.76.238','2007-07-27 17:11:17','2007-07-27 15:11:17','numa 10 commenturi? slab :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4209,546,'Denisa Lala','denisalala@gmail.com','http://www.denisuca.ro/blog','86.123.36.173','2007-07-27 18:35:43','2007-07-27 16:35:43','SÄƒ trÄƒiascÄƒ Dom\' Groparu! :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4423,565,'Paszti','pasztorjozsef@yahoo.com','http://www.groparu.ro/?p=565','81.12.230.166','2007-08-03 16:37:33','2007-08-03 14:37:33','priceless =))',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727)','',0,0),(4149,544,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','86.105.72.125','2007-07-25 23:16:30','2007-07-25 21:16:30','Ma, zi lu shafu\' tau (cum care al tau? ala!) sa criasca dreq liafa, sh sa zica sh la al meu sa creasca leafa; astfel vom aviea mai multi bani de bere, sh firma va prospera!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4634,588,'mumuland','','','85.204.38.37','2007-08-10 18:35:51','2007-08-10 16:35:51','ma gropare am vaz io ca alalalt deliratzie da ta ai avut 2 scomentarii si zac ca no e mai slabutz.... si se ia aia de mine ca cica lasa frate ca te inteleje aia care e ardelenii si si aia care is mitici mai molcomi.da io nu tie criticam si oricum recunoaste ca iti place sa fi creticat .mai ales ca ai candidat la cel mai prost blog al anului .......tu ai vrut ..........io am votat ......\r\nsamu pt miticu ala mai molcom sai moara tatzi dusmanii.... :  mititci molcomi nu is....si nu is....klar miticii is mitici  si le dau la tati ce le da galeria lu u  l tatzi  din galeria cfr-ului.....nu de alta da in armata tazi mor facut ungur si tazi miticii si moldovenii(alta specie care zper io e pe cale de diosparitzie) za amuzam cum zaceam ioioioioi,si ii ora doi si deastea deale mele din ardeal....deci sa nu se ia miticii de minie pe panmant ardelenesc......mheretzi ma in caca-pitala voastra si nu ne mai infectatzi si pa noi......\r\n\r\npz. nu is rasist da dacai om sa hie alb........:))\r\n\r\n\r\nis io ma.care io? asta: ;)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(4602,579,'Andreea MKT','supergirgir@yahoo.com','http://marlahermina.deviantart.com/gallery/','82.77.126.254','2007-08-09 16:18:13','2007-08-09 14:18:13','doar in poza nu ejti tu ala mic\r\nsi tanti aia seamana la ochi cu tine deci banuiesc ca e...bunica-ta',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(4603,585,'ania','soredarkshines@gmail.com','http://aniakhaki.blogspot.com/','89.123.111.149','2007-08-09 16:36:51','2007-08-09 14:36:51','groparu e vedeta...pe-o treapta cu \'u\' :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4604,587,'ania','soredarkshines@gmail.com','http://aniakhaki.blogspot.com/','89.123.111.149','2007-08-09 17:18:36','2007-08-09 15:18:36',':))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) no lol!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4606,587,'Gez','geza@dvis.info','http://groller.info/geza','89.137.120.175','2007-08-09 17:46:28','2007-08-09 15:46:28','Facem bre!\r\n\r\nAltceva mai vrei?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4572,583,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','86.105.72.125','2007-08-08 21:07:37','2007-08-08 19:07:37','@ Radu M: lol, gimme more! da\' sh in graiu\' aiesta romanesc, ca engleza nu are atatea injuraturi in ea :D\r\n\r\n@ Ralu: da, e super fain designu\', pacat ca e plin de scriitura :(',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(4573,582,'IepurasulAtomic','praetorian21uk@yahoo.com','','62.217.245.97','2007-08-08 21:09:16','2007-08-08 19:09:16','Din cuvintele unui celebru cineva: \"Sh l-o impersonat sh pe Groparu (pentru cei care nu il cunoasteti, il gasiti pe www.groparu.ro)\"...pai asta face parte din categoria non-Sensului(ah...pardon, Ad-Sensului) din articolu\' anterior. In alta ordine de idei, daca sfarsitu\' lumii nu vine de la meteoriti, incalzire globala, malarie, ciuma bubonica, lepra, beshini de vaca si alte metane, atunci clar vine de la imbulzeala asta pentru locu\' intai. Ma, io m-am scarpinat aseara in timp ce faceam o rotatie de 360+ de grade cu dublu tulup si echer din randunica de sobolan...si toate astea in timp ce inganam o rugaciune. Deci gata, am brevetat-o, ati pus-o. Si nu uitati ca ati auzit-o aici prima data! Asadar Groparu\' are jumatate din ceea ce iau io! Cine vrea s-o foloseasca, la mine cu bericica, ca io nu impart cu nimeni locu\' intai! Clar? \r\n\r\nSi pana la urma, cine pana cocosului brazilian a scos duma de mai sus? Oricum, n-aveti voi grija ca vine sfarsitu\' lumii si fara sa dea blogosfera ultimu\' cuvant.\r\n\r\nPeSeu: Inca un gand pentru eternitate- Da\' daca murim cu totii, atunci la ce cucurigu\' meu sa mai lasam ultimu\' cuvant? Pentru gandacii de bucatarie care raman in viata? Zic si io asha...ca mine!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(4574,583,'IepurasulAtomic','praetorian21uk@yahoo.com','','62.217.245.97','2007-08-08 21:15:33','2007-08-08 19:15:33','Am si io unu\', daca va tot zbateti in IQ p\'aci. Da\' sa nu va aud ca seamana, ca nu-i asha: \"Stau cu susul in jos, ca sa nu mai vad lumea pe dos!\"',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(4651,588,'Femei','pas@yhaoo.com','http://de-aia.blogspot.com','89.137.117.237','2007-08-11 08:57:14','2007-08-11 06:57:14','ma, tu tata sambata esti la munte. di ce nu te faci cioban si ai scapat de grija bagajelor si a transportului :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.2) Gecko/20070219 Firefox/2.0.0.2','',0,0),(4577,583,'mumuland','','','85.204.38.37','2007-08-08 22:44:54','2007-08-08 20:44:54','unu din lista me de mess ave statusu:  iesit cu vaca... io cre ca nu lo vaz fomeia lui....important e ca vaca era fericita...\r\n\r\niz io ma.care io?asta: ;)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(4579,583,'Calarasu','acalarasu@gmail.com','http://adriancalarasu.wordpress.com','89.32.19.126','2007-08-09 00:13:38','2007-08-08 22:13:38','\'ai ma Gropare ca aia cu puiu\' porcos e chiar misto, cred eu. E genu\' meu asa, zic, gen \"Intrebarea zilei\" cand am eu probleme existentiale.\r\n\r\nNo hai cu povesti din putu\' matale de gandire pana atunci, lasa pustiiii sa se afirme.\r\nSi daca n-ai povesti noi, ce puii mei eufemistici, inventeaza cateva!!!\r\nIo asa fac ;)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(4776,594,'ania','soredarkshines@gmail.com','http://aniakhaki.blogspot.com/','89.123.76.91','2007-08-15 00:35:00','2007-08-14 22:35:00',':( go go go!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4406,559,'mumuland','','','80.97.64.199','2007-08-03 06:39:40','2007-08-03 04:39:40','apoi sa te duci ca mie numi place taganii........si in doi la mina  ca Sibiu e chapitala Heuropeana sa ma lese in pace ca e abureala..............au si ei taganii lor...\r\n\r\niz io ma.care io? asta: ;)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12','',0,0),(4156,544,'Vedete','asdw@yahoo.com','http://vipuri.blogspot.com','86.122.8.62','2007-07-26 11:32:21','2007-07-26 09:32:21','pasaricile numa fac ceva zgomote... un fel de bashini... asta in cazu in care is prea uzate... \r\n\r\nscuzati vocabularele...\r\n\r\nnuma bine!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4211,547,'Femei','pas@yhaoo.com','http://de-aia.blogspot.com','89.137.117.237','2007-07-27 19:54:50','2007-07-27 17:54:50','ai grija la shtiucile din lac :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.2) Gecko/20070219 Firefox/2.0.0.2','',0,0),(4212,547,'Adi Calarasu','acalarasu@gmail.com','http://adriancalarasu.wordpress.com','89.32.19.126','2007-07-27 20:32:25','2007-07-27 18:32:25','Gropare, hai la BÃ¢lea, facem o orgie cu bere :)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(4420,560,'Vedete','asdw@yahoo.com','http://vipuri.blogspot.com','213.157.188.71','2007-08-03 15:44:36','2007-08-03 13:44:36','zice fata: \"fii atent ma ca nu se termina\"\r\n\r\nsi inca o observatie ma gropare: \r\n\r\n\"noi cantam la nunti sh inmormantari; daâ€™ sa nu ne kemati la mormantari, ca zice noi suntem foarte expensivi! ASA CA PLEASE DONâ€™T DIE!!!\"\r\n\r\ndupa asta de obicei la orice concert zice ca la nunti iau numa jumatate pretu cat la inmormantari si apoi incep sa cante o cantare de nunta. nu mai rade si tu la poante pe care le spune la mii de concerte, la sute de mii de oameni!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4214,546,'Troznea','','','86.127.22.102','2007-07-27 21:51:10','2007-07-27 19:51:10','Ma doare in fund de: primarul localitatii, aia care ma intreaba daca m-am tuns, cetatenii care se uita la OTV, politaiul de aseara, aia care construiesc blocuri pe la 5 dimineta in fata geamului meu, ala care ma-njura pe YM, vecina de la trei, evaluarea de pe 31, piersicile de import, domn\' presedinte (ala de la club), sefa, sefu\' lu sefa, aia care s-au crestat caca rnatii cu sisurile aseara in Mamaia, ala care umbla cu Maria, Maria, jocu\' ala de logica, ce-mi reproseaza Adrian.\r\nMa dore-n fund de toate astea si am vrut sa stii si tu.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(4177,316,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','86.105.72.125','2007-07-27 01:42:18','2007-07-26 23:42:18','Pfuaaay, trei comentarii in vo 4 ore!!! Iz tare. Deci:\r\n\r\n@ ania: nu e otzara prea mult dulce inghetzatzile alea? ...ceva mai acru, asha, ca gustu\' de dimineatza de dupa o noapte intreaga de bericizare, nu egzsita la Napolact? Ashea... sh... m-asteptam sa imi dai peste nas cu limba frantzuzita, cum cÄƒ \'mouse\' sh \'mousse\' e doo kestii diferite, sh io urma sa iti zic de Vauvenargues, pe care l-am cetit in orijinal..., da\' no, nerÃ¢zÃ¢nd de francieaza me, nu mi-o eshit faza. Da\' data viitoare,... \r\n\r\n@ mumuland, MI-I FRICA DE MA C** PE MINE ca m-ai detronat big time ca opsedat sexoal no. 1. Daca e ashea, pt asta am numa 2 cuvinte: res-pect! Nu, nu respect, scris cu literi mici, ci ashea: RES-PECT!!! PS: Mah, da\' SIGUR-SIGUR TU ESTI???\r\n\r\n@ Epurila pogonici - una la manutza: io credeam ca esti ficior de dat bacu\', underaged, but as smart as me; sh amu aflu ca ai serviciu? pfuaaay... A doa la manutza: mo, maine (sau azi, vinere) ma duc la munte, ca e ziua unui prekin mai kitarist ca mine, sh pfuaaaay, ce kef va ieshi! Ruaga-te sa fac baie noaptea in lacu\' ala de munte, anesteziat de palinca d-aia de la socru\', ca o sa mushc din lostritze! A, sh sa-mi amintesti sa ma kinui sa ma perpelesc pentru \"oare unie mere epurila de-i ashea sicret? OARE PLEACA-N AMSTERDAM, LA HASH LEGAL???\"',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4180,316,'ania','soredarkshines@gmail.com','http://aniakhaki.blogspot.com/','89.123.79.141','2007-07-27 09:17:41','2007-07-27 07:17:41',':)) cum sa ma leg de franceza ta...cand puteam sa ma leg direct de engleza ta :&gt; \r\nvoiai sa ajungem la discutii despre cosmetice si alte alea? :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4181,316,'Vedete','asdw@yahoo.com','http://vipuri.blogspot.com','86.122.8.62','2007-07-27 09:29:21','2007-07-27 07:29:21','e inghetata nascuta din prafuri campioane? :P\r\n\r\n@ania... numa sa nu-l duci pe groparu la epilat :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4182,316,'ania','soredarkshines@gmail.com','http://aniakhaki.blogspot.com/','89.123.79.141','2007-07-27 09:50:29','2007-07-27 07:50:29','apai daca-l duc la epilat nu o sa-si mai poata aranja parul cu mousse si nu-i bine...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4409,559,'ania','soredarkshines@gmail.com','http://aniakhaki.blogspot.com/','89.123.93.118','2007-08-03 09:26:29','2007-08-03 07:26:29','sugerez sa-ti iei un tricou pe care scrie girl power :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4411,559,'mumuland','','','80.97.64.199','2007-08-03 11:24:54','2007-08-03 09:24:54','auzi gropare ? sa iti ei tricou cu  girl power...\r\n\r\nis io ma.care io?asta: ;)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12','',0,0),(4640,588,'Calarasu','acalarasu@gmail.com','http://adriancalarasu.wordpress.com','89.32.19.126','2007-08-10 21:44:31','2007-08-10 19:44:31','Daca americanii spun ca mananca \"ciainiz\" (cand se refera la mancarea chinezeasca) chinezii cum zic, ca mananca \"caucazian\"?!?!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(4595,583,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-08-09 11:20:48','2007-08-09 09:20:48','@ ania: tu inca NU AI FACUT NICIODATA FEBRA MUSCULARA DE LA SEX???? :O',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4591,583,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-08-09 10:02:52','2007-08-09 08:02:52','@ Epurila: errr... cum il kema p-ala... Raj Kapuur? Mi se pare ca tz-o plagiat statusu\'!\r\n\r\n@ mumuland: da\' daca omu\' era kiar fermier de vaci?\r\n\r\n@ CÄƒlÄƒ: mo, asa oi face, da\' stai sa mai am sh ceva vreme, ca ma copleseste trebile... sh nu alea care se rezolva la buda!\r\n\r\n@ Radu M: mo, daca tu faci statuse din melodii de winamp... e gros! Io, ca prostu\', le scot din preputzul gandirii proprii. Io-te cum iese: zbor pe luna cu o naveta. Naveta de bere. PS: Sh cu engleza, limba universala... io as zice ca limba universala e aia pe care-o aplici shafului, ca toti facem asa, si engleza mai e ce mai e pana vine chineza puternic din spate...\r\n\r\n@ Andre: daca as pune d-ale matale, n-ar mai fi groparu.ro...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4592,578,'andreanum','andreanum@yahoo.com','http://andreanum.wordpress.com','194.30.177.1','2007-08-09 10:08:27','2007-08-09 08:08:27','ba cea-ve-ti cu omu? e super conpentent, a crescut si vizarile de la supermarchetu cel mai mare selgros care este in lume. sunt-eti indivi-osi.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1)','',0,0),(4593,583,'ania','soredarkshines@gmail.com','http://aniakhaki.blogspot.com/','89.123.111.149','2007-08-09 11:04:46','2007-08-09 09:04:46','acum mi-am amintit ceva apropo de statusuri...dupa 20 de abdomene pentru un 10 la educatie fizica am lasat status pe YM ceva in gen \'febra musculara de la 20 de abdomene...de la sex de ce nu face nimeni febra musculara?!?\' si in 2 ore jumatate din lista de mess s-a simtit sa-mi spuna cate ceva :)) jumatate din jumatate facuse si febra musculara...:&gt;',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4590,583,'Andreea MKT','supergirgir@yahoo.com','http://marlahermina.deviantart.com/gallery/','82.77.126.254','2007-08-09 09:49:19','2007-08-09 07:49:19','de ce nu pui si de ale mele?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(4381,558,'mumuland','','','80.97.64.199','2007-08-02 14:14:58','2007-08-02 12:14:58','taci ma gropare.nu tie lua die injinierii de la noi.ca tatzi care o gatat poli stie bine sa face ceo or invatat.practic tati gata cu 5 ani experientza ca tati se angajeaza din primu an ca nu le ajung banii de acasa sa beie.............\r\n\r\niz io ma.care io?asta: ;)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12','',0,0),(4221,341,'','fi5ds3op@gmail.com','','87.248.164.204','2007-07-28 04:22:22','2007-07-28 02:22:22','~',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1)','',0,0),(4380,558,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-08-02 14:00:48','2007-08-02 12:00:48','@ curioasa: mersi, sa va traiesc, da\' tot io sa mor primu\', ca alfel scriu numa-n gol sh nu mai ceteshte nime\'!\r\n\r\n@ ania: am vazut filmu\', varianta mea se termina mereu - partea I - cu o bere, sh partea a doa - cu o fomeie. These are the final destinations of my life!\r\n\r\n@ mumuland (mumuland who?): ma, inginerii romani poa\' sa faca poduri, da\' numa d-alea de gimnastica!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4397,559,'Calarasu','acalarasu@gmail.com','http://adriancalarasu.wordpress.com','89.32.19.126','2007-08-02 23:29:12','2007-08-02 21:29:12','Gropare, pa mine sa ma ierti ca-s cam ca tine asea, adicaca mi-i cam lene sa pun caciulite si codite da literele romanesti , nu-s nici prof de matematici(?), ca bag sama ca d\'aia-ti place matale (espresie sudista) sa scriiiii ase frumos, ordonat si cu litere - da\' cred ca tat sunt mai tare ca tine, s-aci vin cu cel putin trei argumente care sa ateste factu\' aista, ca cica-i numar majic:\r\n\r\nCel putin trei argumente care atesta faptul cacalarasu e mai smecher decat Groparu:\r\n\r\n1. Calarasu a vazut Cluju\' (cat se vede din el, ca nu mai tin io prea bine minte, prea tare-i apa-n Ardeal...) de pe dealul Feleacului (ca la Holiud), Groparu nu a vazut Bucurestiul de pe vreun deal, ca noi nu avem dealuri;\r\n2. Calarasu a avut gagica-n Manastur (superocazie, la un concert, iar nu mai imi amintesc esact...), Groparu nu a avut gajica-n Berceni;\r\n3. Calarasu a baut Ursus cu un australian la Balcic(true story!), Groparu a baut bere Rahova cu un kenian la Ulan Bator?!?!?!  Nu prea cred!...\r\n\r\nAcuma ca s-o dreg c-am fo pe langa subect, na: iti doresc sa pui si tu mana pe o camera foto, vezi tu a cui, si sa-l faci pe iugoslavianul ala de Bregovic - orez sarbesc - cum l-am facut eu cand n-a vrut sa-mi dea autograful lui pe tricoul cu meu cu steagu\' americii:\r\n\r\nhttp://adriancalarasu.wordpress.com/2007/03/21/paparazzo-cu-goran-bregovic-la-lansare-carmen-with-a-happy-end-bucuresti-14-octombrie-2006\r\n\r\nBAFTA!!!!!!!!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(4357,556,'IepurasulAtomic','praetorian21uk@yahoo.com','','62.217.245.97','2007-08-01 22:42:42','2007-08-01 20:42:42','Auzi Gropare, vezi ca stricam targu\'! Pai baaaaaaa...cum sufletu\' meu divortat de corpu\' asta de iepure badaran(in care de fapt zace incatusata o iepuroaica, da\' io cica n-ar trebui sa ma prind), carevasazica cum lasi ma \"bruneta crocanta\" fara cap?! Pai buey, da\' io daca vreu sa fac cu bruneta asta croisant ce-o facut Billu\' de n-o fost sex(zicea el, ca s-o trezit mai depstept ca altii), unde fac? Ha, zi tu?! Scoate-te, scoate-te! Si daca io cand is deasupra vreu sa ma uit intr-o pereche de ochi frumosi ce fac ma? Imi cumpar din piatza? Da\' daca vreu sa-i dau la falci (nu aia de mai sus, ailalta activitate atata de placuta barbatului viril de la tzara) sau s-o trag de par...de unde? Io zic sa-i pui croisantului capu\' inapoi pe umeri si las-o dracu\' muta in cel mai rau caz! Ca sa stii tu de la mine ca o femeie daca vre sa-ti phoota moralu\' si sa-ti comenteze(desi nu mai are voce de 3 zile ca ii racita bocna si abia poate respira) gesticuleaza si tot itzi strica ziua :))). Pace p\'afara si sa nu se mai intample! :)\r\n\r\nPeSeu: As zice s-o lasam fara maini, da\' parca nici de alea nu m-as putea desparti :))...',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(4358,556,'ania','soredarkshines@gmail.com','http://aniakhaki.blogspot.com/','89.123.72.198','2007-08-01 23:23:59','2007-08-01 21:23:59','lol',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4359,556,'Femei','pas@yhaoo.com','http://de-aia.blogspot.com','89.137.117.237','2007-08-01 23:30:50','2007-08-01 21:30:50','poate acolo dormea crocanta ma gropare',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.2) Gecko/20070219 Firefox/2.0.0.2','',0,0),(4360,551,'Femei','pas@yhaoo.com','http://de-aia.blogspot.com','89.137.117.237','2007-08-01 23:32:03','2007-08-01 21:32:03','une-i chefu ca viu pe blat?!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.2) Gecko/20070219 Firefox/2.0.0.2','',0,0),(4362,556,'IepurasulAtomic','praetorian21uk@yahoo.com','','62.217.245.97','2007-08-02 03:53:44','2007-08-02 01:53:44','Gropare, \'tziar croisantu\' a dracu\' ca acuma ti-am visat-o. Inalta, svelta, par lung brunet si intins,cu un cur de sa mori da\' cu tzatze mai mici un pic(ca deh, o fo\' visu\' meu :)). Si ma, numa\' asha pentru ca o fo\' visu\' meu, croisantu\' nici macar n-o comentat ma. Ca sa vezi :))! Si-o fo\' si buna de numa\' in pat(sau ma rog, in bucatarie, ca acolo am servit-o). Si tocmai cand ma simteam io mai barbat ca \"Moammaaa, fii atent ce-am reusit sa iubesc!\", aflu ca-i aproape prostituata. Pfiuuu, \'tu-i mama ma-sii. Da\' tot nu-i bai. Mersi ma ca mi-ai manipulat subconstientu\' si mi-ai oferit un vis asha placut. Numa\' vezi sa nu care cumva sa scrii de vreun negru chel de 2m cu un obiect contondent ce se loveste de genunchi...SHIIIIT! Am pomenit io! Baaaa si mai voiam sa dorm :((. Ma phut, mai bine citesc ceva, ca nu vreu sa mai visez Doamne fereste vreo ceva sa raman fara tat tubu\' digestiv!\r\n\r\nPeSeu: Gropare, nu-mi dai o carte buna? Ca sa mor daca mai dorm! Si vezi cat ii ceasu\'? :(( Wish me luck!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(4394,559,'Domnu\' Nderthal','','','86.122.53.218','2007-08-02 22:02:28','2007-08-02 20:02:28','Gropare, Justin Timberlake, Beyonce sh Britney e nejte ce-are ursu\'-n loc de mÃ¢nÃ£...  LasÃ£-l pe Bregoran Govici... TzigÃ£nie faci (aproape) an de an! Ce-tz trÃ£bÃ£ de import!? Meri bÃ£ la Sibiu la Jetro Tal! Te-a hi ajteptÃ¢nd ceva acolo...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.4;MEGAUPLOAD 1.0','',0,0),(4367,556,'Radu M.','radu_muri@yahoo.com','http://theblacklight.wordpress.com/','79.113.137.12','2007-08-02 09:48:03','2007-08-02 07:48:03','Mah gropar shÃ£f, tirul ala era ceva joc...pe cum inaintai si toroshteai comunitari castiga in tonaj?? De la 22 la 39 de tone....Ciudat tiru Sandelului..:]',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7','',0,0),(4533,568,'Vedete','asdw@yahoo.com','http://vipuri.blogspot.com','213.157.188.71','2007-08-08 09:28:12','2007-08-08 07:28:12','pulalela ma groparu. unde ii traducerea? :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4534,569,'Vedete','asdw@yahoo.com','http://vipuri.blogspot.com','213.157.188.71','2007-08-08 09:29:12','2007-08-08 07:29:12','ma gropare. superba cantarea de pe autocar. ma lasi sa o bag si la mine pe blog?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4597,578,'mistral','corina_m_ch@yahoo.com','','86.126.12.179','2007-08-09 13:07:07','2007-08-09 11:07:07','foarte tare....io l-as chema la interviu sa ma distrez :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4508,569,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-08-07 14:27:00','2007-08-07 12:27:00','@ Piticu: da, atata numa ca stilul meu nu e chiar asa dulce, finca are mai degraba gust de bere strong, sh nu e chiar asa de clasic, finca inca nu o fost inventat! A, si nici macar nu se poate numi stil...\r\n\r\n@ curioasa: apai or tot oprit vreo 6 mashini pline ochi cu fete de la durex, da\' le-am expediat dintr-un gest scurt, iugoslav; finca daca mergeam cu ele pierdeam ocazia de a afla cum se joaca \"Nu te supara, frate!\" cu orci sh orcitze!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4370,556,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-08-02 11:22:47','2007-08-02 09:22:47','@ mumuland: da, mah, noroc ca am supravietuit, ca alfel cine devenea viitoru\' Hitler???\r\n\r\n@ Epurila: mah, corect, capu\' are rostu\' lui, mai ales cu guritza aia din dotare, ca io prea m-am lasat dus de imaginea aia secsi a lu Buffalo Bill din Silentzium Mieilor care le lega de lanturi sh le kinuia taindu-le capu\' de tot!\r\n\r\n@ Femei: unie era fomeia crocanta? la beserica? nu, ca alea nu-s ale mele, is a lu\' Shafu\'... ala cel mai de sus...\r\n\r\n@ Epurila: mo, apropos de somn, singura mea carte buna e o carte de joc cu femei goale. Stiu ca ma repet, da\' mi-i greu sa fiu genial zilnic, anual sau decenial.\r\n\r\n@ Radu M: Mo, respect! Ej singuru care sh-o dat seama ca mah, tonele astea de pe TIR tat cresc precum kilele la o femeie maritata!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4371,556,'curioasa','totmea@yahoo.com','','86.35.232.96','2007-08-02 11:40:52','2007-08-02 09:40:52','cind o sa circuli cu masina ta o sa-ti iei crocante cu tine? cu sau fara cap?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(4372,551,'Livia','sos_livia@yahoo.fr','','193.231.20.2','2007-08-02 12:07:57','2007-08-02 10:07:57','imi place...grozava poezie...grozav baiat',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 1.1.4322)','',0,0),(4373,558,'curioasa','totmea@yahoo.com','','86.35.232.96','2007-08-02 12:16:25','2007-08-02 10:16:25','http://www.youtube.com/watch?v=u5ZWEOE8toQ\r\nde-asta bere bei? ca, ia, tine moartea ocupata\r\nSa ne traiesti, ca trebuiesti!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(4374,556,'curioasa','totmea@yahoo.com','','86.35.232.96','2007-08-02 12:24:26','2007-08-02 10:24:26','si cum o sa te prezinti?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(4375,556,'katmai','katmai@keptprivate.com','http://www.512kbps.com','193.86.73.13','2007-08-02 12:49:33','2007-08-02 10:49:33','houli cau ... si daca murea groparu` au doamneeee ce faceam ce faceam :((( vezi cand iei parashute la autostop tre sa fii porc, nu baetas, ca te fac fetitele de numa :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4376,558,'ania','soredarkshines@gmail.com','http://aniakhaki.blogspot.com/','89.123.72.198','2007-08-02 12:58:38','2007-08-02 10:58:38','ati vazut final destination?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4377,558,'mumuland','','','80.97.64.199','2007-08-02 13:12:36','2007-08-02 11:12:36','eeee.tata viatza ta si a celor din juru tau e o adevarata telenovela......pa cand aparae si zavoranka in povestile tale? in rest ii minunat...la americani le plac prabusirile si daca amu de atatia anii arabii lu ala mic cu nume de deterjent benladen nu mai fac ninimk si is in somaj...prabusesc ei oarece ca doar stii ce bine le place sa trimita repede 3546475465654 de masini de la tat atatea canale tv sa transmita live ca vb aia.... i am john ......si nu stiu cum si is .......live for .... daten pola me .......chanel.......sapoi dai si lacrimi si solidaritate americana si albii si negrii sa imbratoseaza ca fratii ...si e o mare inima acolo....si pe noi ne doare undeva...............noi ar trebui sa detonam podu die la cernavoda ezact cant trec 10000 de trenuri pe el si milioane de autoturisme cu milioane de oameni si nu pridem stirile din seara ai de la americani..........io atata le zac la americani da pe vb noastra ...mai calci si in cacat.......si duceti ma injineri romanii acolo sa va faca podeturi.nu ii bagati pa tati numa la mc donald sau kfc...\r\n\r\nis io ma.care io? asta: ;)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12','',0,0),(4556,583,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','86.105.72.125','2007-08-08 17:30:18','2007-08-08 15:30:18','Daaa!!! Are doo cifre IQ-ul Groparului, atata numa ca amandoo cifrele is cu minus, da\' minus cu minus da plus!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(4552,582,'Denisa Lala','denisalala@gmail.com','http://www.denisuca.ro/blog','79.118.51.107','2007-08-08 16:51:23','2007-08-08 14:51:23','Bueeei, aia o fost ideea mea, am pus-o CA COmentariu pe blogu lu OrÄƒdeanu, ÅŸi el o preluat-o... deci io te-am ghicit, da? :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4553,583,'Denisa Lala','denisalala@gmail.com','http://www.denisuca.ro/blog','79.118.51.107','2007-08-08 16:54:33','2007-08-08 14:54:33','Zuper, au \"iz\" de IQ mÄƒricel. Nu cÄƒ m-aÅŸ fi Ã®ndoit vreo clipÄƒ...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4379,556,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-08-02 13:53:31','2007-08-02 11:53:31','@ curioasa: nush, ma mai gandesc, ca pe bara de la bicicleta nu pot sa iau decat 2 deodata :D Sh de prezentat, o sa fie simplu: Romaniafilm prezinta Groparu Nemerniq!\r\n\r\n@ katmai: mo, deci mersi de gand, da\' tot va bantuiam io daca muream, sh scriam mesaje cu sanje pe buzile de la tzara! Sh-apa puneam vacile sa beie bere, sh io le furam laptele, ca orice strigoi beraros!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4224,546,'Sibianca','alexa_g48@yahoo.com','','81.181.70.9','2007-07-28 12:39:10','2007-07-28 10:39:10','Cand am vazut postul asta, m-am gandit ca e scris special pentru timizii care nu reusesc sa reuseasca sa submituie cate-un comment la a-berea-tiunile tale, asa ca iacata-ma-s!\r\n:P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4545,582,'vasile','reallyinsane@gmail.com','','193.138.195.202','2007-08-08 14:28:44','2007-08-08 12:28:44','Taci ca muri masamare...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4547,582,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-08-08 16:04:57','2007-08-08 14:04:57','Ye, mah, najpa chestie! :| Dumnezau s-o ierte sh s-o hodineasca, sh s-o duca exact in partea romaneasca a raiului.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4512,579,'ania','soredarkshines@gmail.com','http://aniakhaki.blogspot.com/','89.123.67.128','2007-08-07 19:00:25','2007-08-07 17:00:25','hai ma gropare...ca nu tati is mai shafi ca tini...numa gropareasa ;)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4350,556,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','86.105.72.125','2007-08-01 20:07:38','2007-08-01 18:07:38','...pai e un fel de pereche de sani care stau drepti ca la armata, de poti sa aghetzi umerashu\' in ei, picioare lungi care se infig cu furie intr-un curuletz rotunjor, asa mai implinit, burtica sexy, sh fara cap: ca daca are cap are sh gura, cu care comenteaza tot ce faci; sh comentatu\' eclipseaza toate beneficiile pe care ti le poate face cu gura aia.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4535,569,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-08-08 10:05:48','2007-08-08 08:05:48','Mo, deci daca-ti place muzica de betivit, go for it! Sh nij nu e nevoie sa pomeneshti sursa. Ca nu contieaza ;)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4766,593,'Radu Iliescu','riliescu2000@yahoo.com','http://careeste.blogspot.com','89.121.187.24','2007-08-14 18:44:20','2007-08-14 16:44:20','Pentru un tip care scrie asa de zgubilitic cum o faci tu, ai sesizat o chestie esentiala: aceea ca nimic nu vine cu adevarat mokka. Pana si paralele gasite pe strata (au prin conturi) costa ceva. \r\n\r\nUn tip care a priceput asta nu-si mai poate permite luxul sa se bucure de o pleasca.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0)','',0,0),(4767,593,'Adi Calarasu','acalarasu@gmail.com','http://adriancalarasu.wordpress.com','62.217.241.242','2007-08-14 18:49:13','2007-08-14 16:49:13','Aia cu PIN-urile false e de retinut :))',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(4769,594,'ania','soredarkshines@gmail.com','http://aniakhaki.blogspot.com/','89.123.109.12','2007-08-14 21:04:56','2007-08-14 19:04:56','saracu gropar :(',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4771,594,'IepurasulAtomic','praetorian21uk@yahoo.com','','62.217.245.97','2007-08-14 21:44:49','2007-08-14 19:44:49','Gropare nu mai pomeni de munca ca ma crispez....da\' mah, \r\n\"munca ca\"calau. Pe bune ca daca tre\' sa mai muncesc inca vreo 2-3 zile asha cum am facut-o zilele ce-or trecut, imi dau dreq demisia. Pai io credeam ca salariu vine pentru prezenta, nu si pentru munca, cum ar veni un fel de chirie pentru prezenta mea cat se poate de exclusiv fizica la servici. Daca am vazut ca astia nu-mi maresc salaru\', am spus: \"Clar, n-avem de lucru nici anu\' asta!\". Si-acu\'...io-te ce-mi fac astia! Pfiuuuu...deci da! da? nu mai pomenim de munca, bine? Hai respect si pace p\'afara ;)!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(4773,594,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','86.105.72.125','2007-08-15 00:18:11','2007-08-14 22:18:11','@ CÄƒlÄƒ: pfuaaay, mÄƒ, da\' asa-i ca aia is nemiscati tot timpu\'? Ma, zi sincer: tu nu esti cumva o fresca, mah???\r\n\r\n@ ania: da :| sireacu gropar, amu se kinuie pentru a doua rezidentza.\r\n\r\n@ Epurila: ba epu\', deci io numa atata sper, sa fii tu primu\' om de pe lumea asta care se-mbogateste de la munca mah! Io numa atata sper. Da\' fara becalizme!!! (corect faza cu pace p-afara, numa\' in pantece de femei sa fie razboi!)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4775,593,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','86.105.72.125','2007-08-15 00:29:11','2007-08-14 22:29:11','@ ania: ezac!\r\n\r\n@ adi: am incercat sa ti-i retrimit, sh s-or dublat!!!\r\n\r\n@ marzazel: mo, hai sa facem supermarket lifting, sau, ce pana me... liqor store lifting si sex shop lifting!\r\n\r\n@ mumulan\': daca stii o cutie d-aia cu banet, spune-i sh lu\' groapÄƒ! Plsssss\r\n\r\n@ oedip: mo, deocamdata chief operations manager la trajnete sh ploi ii Ilie; daca ii iei locu\', pune-ma sh pe mine secretara, sa trajnim neshte becali!\r\n\r\n@ andreea mkt: andreea, tu bag sama ca musay esti mama lu\' oedip! a, stai, ca uitai ca asta nu-i ala cu ma-sa...\r\n\r\n@ de aia: fix asta voi sh face. Oricum ajung in iad, partea aia fara bloage :(\r\n\r\n@ pliscu: alo! alo! nu te mai aud!!! cine e acolo?\r\n\r\n@ Radu Basescu... ÄƒÄƒÄƒ, Iliescu: da, mo, da\' am zis sa ii mai tin oleaca pana scriu blogu\'!\r\n\r\n@ CÄƒlÄƒ: e, mah, da nu credea ala ca fura de la romani!!! hotului i-e frica de furat ;)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4531,581,'Radu M.','radu_muri@yahoo.com','http://theblacklight.wordpress.com/','79.113.139.133','2007-08-08 08:36:38','2007-08-08 06:36:38','Super..!..:]',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7','',0,0),(4541,578,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-08-08 13:51:43','2007-08-08 11:51:43','Man, io tot nu am prea inteles, bine ca o subliniat ce???',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4627,587,'VIP','dwee@yahoo.com','http://vipuri.blogspot.com/','213.157.188.71','2007-08-10 16:02:47','2007-08-10 14:02:47','ma gropare, tu pe lumea ailalta cu ce o sa te ocupi daca amu esti gropar? cu dezgropatu?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4628,587,'VIP','dwee@yahoo.com','http://vipuri.blogspot.com/','213.157.188.71','2007-08-10 16:04:02','2007-08-10 14:04:02','adi, n-ai inteles. asta e blog scris in ardeleneste. cine intelege citeste, citeste. cine nu intelege sare mai departe sau cere traducere... \r\n\r\nde exemplu eu nu pot citi bloguri in ungureste :((',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4629,568,'Paszti','pasztorjozsef@yahoo.com','','81.12.230.166','2007-08-10 16:05:44','2007-08-10 14:05:44','bozmeg = baszd meg = fute-l\r\nmenihozo = menj haza = du-te acasa (pentru destinatie mai demult aveai nevoi de pasaport, amu numa cu buletinu ca creditele)\r\nastea trebe stiute musai, ca niciodata nu stii cand it trebe\r\n\r\nio inteleg ce scrie da nivelul de alcohol ii asa gye mic gye nu pot sa traduc numai cateva cuvinte: se deschide, despre Cluju nostru drag si scump, la Sibiu, la Bruckenthal, aurarii de langa Central, nenea preot cu ceasca de aur.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727)','',0,0),(4630,581,'De aia','dwee@yahoo.com','http://de-aia.blogspot.com/','213.157.188.71','2007-08-10 16:06:07','2007-08-10 14:06:07','ma gropare, sa nu te legi de google ca iasa scandal ma!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4631,568,'admin','groparu_ro@yahoo.com','http://','82.77.126.254','2007-08-10 16:40:03','2007-08-10 14:40:03','E, da\' nu zice cumva sh ceva de onor traducatoriu?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,1),(4355,556,'mumuland','','','85.204.38.37','2007-08-01 21:18:27','2007-08-01 19:18:27','hmmmmmmmmmmmmm....eternu foimeile un rau necesar........amu oricum mai bine k bancu ala sec....el pe ia se gandeste: ce tapa tai luat ca nam bani si ea de dedesupt se gandeste : nai prezervativ ce sida tai luat....deci e de bine si e de ok ca vb aia daca io traji lu nevatsa ai tanara a lui irinel columbeanu ce insamna?  inseamana va faci bine la un milionar si  nu vrei asta......................dar oricum acu ca tot vb de studentele de anu intai sa stii ca multe din ele isi platesc soferii de taxii cu ashe ceva...cu ce?cu chestiile care i leai scris mai sus ...chestiii de,, bunesa corcanta,,...\r\n\r\n\r\nkl(ca urasc sa scriu ps)\r\nnorok ka ai supravietutit ma ca altfel ce mai ceteam noi?\r\n\r\n\r\niz io ma.care io? asta:;)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(4226,546,'Emaginatoru','e_magist@yahoo.com','','86.122.12.12','2007-07-28 21:18:36','2007-07-28 19:18:36','Io zic \"pas\" si nu comentez nimic. Na!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1)','',0,0),(4598,585,'sabina','','','81.12.163.178','2007-08-09 13:37:39','2007-08-09 11:37:39',':))',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(4228,124,'stella_dark_angel','stella_dark_angel@yahoo.com','http://thismakesmegreen.blogspot.com','193.239.247.224','2007-07-29 01:00:24','2007-07-28 23:00:24','OO..da am ras cum n-am mai raas de mult...bun articoluu..bun mi-a placut...cat despre manipularile lui Brown..e ..buna cartea doar poate pentru copiii sub 5 ani..basme taica..basme fictiune bolnava...si informatiile despre care se zice ca sunt adevarate...sunt de fapt..rastalamcite...rusine..sa afci avere pe o acrte ca asta...',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SIMBAR={B393C74F-E8EF-4b95-81E6-CA2EFC1DFA1E}; SV1; Seekmo 10.0.314.0)','',0,0),(4229,125,'stella_dark_angel','stella_dark_angel@yahoo.com','http://thismakesmegreen.blogspot.com','193.239.247.224','2007-07-29 01:04:39','2007-07-28 23:04:39','punct ochit..punct lovit...place blogu...',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SIMBAR={B393C74F-E8EF-4b95-81E6-CA2EFC1DFA1E}; SV1; Seekmo 10.0.314.0)','',0,0),(4385,559,'IepurasulAtomic','praetorian21uk@yahoo.com','','192.100.130.8','2007-08-02 17:06:41','2007-08-02 15:06:41','Pai de ce sa nu supravietuiesti ma rog? Conduce cumva vreuna din gajici? :)) (oai, ce misogin am fo\')! Pai mai Gropare, noi stim ce vrei sa-ti scrie pe cruce, asha ca meri cu Domnu\', da\' sa nu uiti sa ne bantui p\'aci. Ca noi te-am iubit si-o facem in continuare ma, doar stii asta.\r\n\r\nPeSeu: Si-acuma ca te-am periat bine...Baaaa, ia-ma si pe mine la concert! De fapt io nu de concert sufar ma, mi-i de alea patru gagici. Ma, platesc io tata benzina, numa\' lasa-ma sa tin una din nimfele alea in brate. Sa mor io, uite, daca ne opreste politia ca suntem 6 in masina platesc io amenda si-i dau permisu\' meu sa borasca punctele acolo. Gropare, ne stim de-o viata! Ce zici? Ha? Facem o triaba? Hai ca stiu ca vrei...Si daca nu vrei te mituiesc...cu bere, multa bere, un ocean de bere...Nu? Nici acuma? Al dracu\' Groparu asta, n-ar imparti fericirea si cu noi. Eh, lasa ca ne-o fi si noua ghine! Io astept totusi sa te razgandesti...Hev fan!!! ;)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(4386,559,'Mile','','http://milecarpenisan.wordpress.com','86.123.246.164','2007-08-02 17:29:35','2007-08-02 15:29:35','Frate vezi ca (a nu se citi vezica) ala bea mult inainte in timpul si dupa concert. Asa ca trebuie sa faci mega antrenament daca vrei sa te pui la baut cu Bregovici. Eu am incercat o singura data. Pana am pupat paharul de tuica scotiana asta o ras toata sticla. Dar e beton daca se trosneste...canta intr-un mare fel. Oricum la concertele lui trebuie sa mergi usor puscat intr-o aripa. Srecan put (drum bun). \r\nP.S. Te compatimesc pentru faza cu gagicile. E misto primele 15 minute dupa care o sa inebunesti de la atatea discutii despre farduri ciorapi freze si Rici Martini.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(4540,578,'Hammer','hammer@alpinet.org','','86.120.55.79','2007-08-08 13:13:20','2007-08-08 11:13:20','Amu ai comentarii, m-am imbulzit bine de tot. Iarta-ma:-)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(4509,579,'ania','soredarkshines@gmail.com','http://aniakhaki.blogspot.com/','89.123.67.128','2007-08-07 16:36:00','2007-08-07 14:36:00','iar tre sa zic la multi ani?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4510,579,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','86.105.72.125','2007-08-07 17:06:47','2007-08-07 15:06:47','Pai io ce sa fac daca toti is mai shafi ca mine?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4332,552,'mumuland','','','80.97.64.199','2007-08-01 07:17:46','2007-08-01 05:17:46','faina retzeta...io recomanda: se ia phorthofelul si she mere unde vre i sa   mananci,platesti, vine si apoi bagi...\r\n\r\n\r\niz io ma.care io?asta: ;)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12','',0,0),(4333,552,'ss','criss_team@yahoo.com','','81.196.150.198','2007-08-01 10:04:01','2007-08-01 08:04:01','pestii, si chiar si unii copii, fac sex in apa... sper ca nu cu femeia aia eviscerata  :-S\r\n\r\nmulta treaba dom\'ne cu pestii astia..dupa ce te chinui atata pana ajungi sa-i trantesti pe foc, dupa aia tre sa-ti mai manci nervii ca sa-i scoti (pestii, desigur!) de printre oasele alea osoase si cartilaginoase care este. \r\nprobabil ca de aia is si asa buni (pestii, desigur!) de sa-ti bati copii de la ei.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7','',0,0),(4334,546,'Hammer','hammer@alpinet.org','','86.120.55.79','2007-08-01 10:37:50','2007-08-01 08:37:50','Multzam fain! Impartasim aceeasi pasiune pentru primarii:-)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(4335,552,'Adi Calarasu','acalarasu@gmail.com','http://adriancalarasu.wordpress.com','62.217.241.242','2007-08-01 11:09:56','2007-08-01 09:09:56','# Its okay to eat fish cause they dont have any feelings # - Kurt Cobain :D',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(4336,65,'stella_dark_angel','stella_dark_angel@yahoo.com','http://thismakesmegreen.blogspot.com','193.239.247.224','2007-08-01 11:32:26','2007-08-01 09:32:26','mortal..absolut mortal...mai ales aia cu jacheta...:=)))',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SIMBAR={B393C74F-E8EF-4b95-81E6-CA2EFC1DFA1E}; SV1; Seekmo 10.0.314.0)','',0,0),(4337,552,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-08-01 11:58:13','2007-08-01 09:58:13','@ ania: io stiu ca is oameni care fac sex chiar sh in shampanie!\r\n\r\n@ mumuland: da, numa ca pretul poate include sh o mica flegma-medalion de la chelner.\r\n\r\n@ ss: peshtii rule! am uitat sa precizez ca reteta se refera numa\' la pestii din neamu\' \"Ychtios\" (daca asa se scrie), nu din cei de neamul \"Proxenetus\"\r\n\r\n@ CÄƒlÄƒ: \"It\'s also OK to speak about Kurt, \'cause he don\'t have no feelings no more!\" (Groparu)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4339,445,'Canistra','froadi@yahoo.com','','81.181.184.248','2007-08-01 14:15:31','2007-08-01 12:15:31','Sunt de acord cu romul. dar din ala de care este la Nelu si Klein, la sticla de juma verde.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727)','',0,0),(4340,552,'macabroo','raduccc@yahoo.com','http://rezistenta.blogspot.com','80.96.196.2','2007-08-01 14:41:12','2007-08-01 12:41:12','Just. Dar ce te faci cu pestii care au fost porci in timpul vietii?  Se mai aplica reteta?',0,'1','Opera/9.20 (Windows NT 5.1; U; en)','',0,0),(4341,552,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-08-01 14:57:55','2007-08-01 12:57:55','@ macabroo: fiind o tzara cu muhuulta experientza in domeniu, retzeta e simpla: ii imbraci in pantofi, ii incalti in costume sh ii trimiti - ai ghicit! - in bufetul Parlamentului.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4765,594,'Adi Calarasu','acalarasu@gmail.com','http://adriancalarasu.wordpress.com','62.217.241.242','2007-08-14 18:42:49','2007-08-14 16:42:49','Eu muncesc mai mult decat toate astea ce zici matale plus toti omuletii aia cu lopata de pe insemnele de semnalizare a lucrului de pe strazile din Bucale si decat  Videanu la un loc.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(4624,587,'mumuland','','','80.97.64.199','2007-08-10 13:28:05','2007-08-10 11:28:05','gropare...ase scris atatea comentarii............viatza nu tie iarta...\r\n\r\niz io ma.care io?asta:  ;)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12','',0,0),(4625,548,'M.I.S.H.U. &raquo; Blog Archive &raquo; Back from/to the loop','','http://www.doingtheartwork.com/?p=125','66.199.252.66','2007-08-10 15:20:51','2007-08-10 13:20:51','[...] o tura buna unde mi-am baut adica sarbatorit ziua de nashtere. Mai multe detalii puteti gasi la aceasta minunata adresa care apartine domniei sale groparulpunctro si care are minunatul talent de a pune faptele in varful [...]',0,'1','Incutio XML-RPC -- WordPress/2.2','pingback',0,0),(4626,587,'Adi Calarasu','acalarasu@gmail.com','http://adriancalarasu.wordpress.com','62.217.241.242','2007-08-10 15:27:07','2007-08-10 13:27:07',':))\r\nGropare, scrie tu tat asa si-ti garantez eu ca o sa te citeasca tati ardelenii aia seriosi si cu capii pa umeri si chiar si cativa mitici asea ca mine, mai molcomi.\r\nMoldovenii nu ca aia sunt pre repeziti si nici nu intelege dialectu\' :))',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(4620,585,'pepi','roman.petre@gmail.com','','82.77.126.134','2007-08-10 10:36:06','2007-08-10 08:36:06','Da sapca rosie ai? ;)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727)','',0,0),(4348,556,'ania','soredarkshines@gmail.com','http://aniakhaki.blogspot.com/','89.123.72.198','2007-08-01 19:29:34','2007-08-01 17:29:34','auzi, cum arata o \'bunesa crocanta\'?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4636,588,'ania','soredarkshines@gmail.com','http://aniakhaki.blogspot.com/','89.123.111.149','2007-08-10 19:55:33','2007-08-10 17:55:33','no nashpa! lasa...eu am fost azi la tarnitza si am vazut un copil facand caca pe saltea...\r\nweekend placut...daca apuci sa mai pleci :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4762,589,'Radu M.','radu_muri@yahoo.com','http://theblacklight.wordpress.com/','79.113.137.196','2007-08-14 17:16:19','2007-08-14 15:16:19','@groparu Multam fain, `oi merge si io saptamana asta sa le dau in gura aia mare si shtirba..:]...numa` ca io-s pescar profesionist si s-ar pute` sa nu prind..:)..',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7','',0,0),(4459,567,'Ionut','ionut_alin03@yahoo.com','http://www.aidphoto.blogspot.com','89.123.176.46','2007-08-05 14:32:08','2007-08-05 12:32:08','Salutare ! Am si eu un blog foto si as vrea sa facem schimb de linkuri. www.aidphoto.blogspot.com Daca esti de acord lasa-mi un comentariu pe blog. Numai bine',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(4460,567,'ania','soredarkshines@gmail.com','http://aniakhaki.blogspot.com/','89.123.122.167','2007-08-05 16:23:18','2007-08-05 14:23:18','la multi ani! si sper ca pan\' la urma nu i-ai dus jinars',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4565,582,'Denisa Lala','denisalala@gmail.com','http://www.denisuca.ro/blog','79.118.51.107','2007-08-08 19:06:50','2007-08-08 17:06:50','SÄƒru\'mÃ¢na, mulÅ£Äƒmesc!\r\nNu vreau ce-i a Cezarului, nici a Gro... de fapt... ba nu, lasÄƒ! :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4566,582,'Denisa Lala','denisalala@gmail.com','http://www.denisuca.ro/blog','79.118.51.107','2007-08-08 19:08:39','2007-08-08 17:08:39','Nu, mÄƒ, stai, cÄƒ acu\' cetii cu ambii ochi, zice bine Arhi, deci OrÄƒdeanu\' a fost cu ideea, DeCe a preluat-o ÅŸi Ã®mbunÄƒtÄƒÅ£it-o, ÅŸi io am gÄƒsit replica TA! AÅŸa, sÄƒ fie clar! :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4567,582,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','86.105.72.125','2007-08-08 19:13:25','2007-08-08 17:13:25','Deci iarashi o situatie in care toata lumea a luat locul I!!! :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(4544,578,'Hammer','hammer@alpinet.org','','86.120.55.79','2007-08-08 14:24:29','2007-08-08 12:24:29','pag 4, paragraful Aptitudini, al doisprezecelea rand',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(4506,569,'curioasa','totmea@yahoo.com','','86.35.232.96','2007-08-07 13:38:47','2007-08-07 11:38:47','Mah, ca n-ai si tu noroc o data de o crocanta fara cap da\' cu masina bengoasa si suflet marinimos...... offff. cata mai ghinionu\'',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(4504,569,'Piticu21','piticu@piticu.ro','http://www.piticu.ro','89.165.215.227','2007-08-07 11:59:18','2007-08-07 09:59:18','Dulcele stil clasic ;)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4596,583,'IepurasulAtomic','praetorian21uk@yahoo.com','','192.100.130.7','2007-08-09 11:57:46','2007-08-09 09:57:46','Pai ma Gropare, ma gandesc ca daca stai pe spate si primesti nu prea poti sa faci febra musculara. Poate doar de la faptu\' ca respiri mai greu. Si mai poti sa mai faci febra musculara incercand sa nu versi cafeaua :))....hai ca ne-am frigizit in dimineata asta! Buna treaba! ;)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(4501,568,'albanezu','mist_ab_2k@yahoo.com','','83.103.154.202','2007-08-07 07:54:40','2007-08-07 05:54:40','cuvintele estea le-am invatat de la miklos, colegu meu de facultate, care cand vorbea cu neamurile lui din Reghin, mai zicea si cuvintelel estea 2.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4502,568,'albanezu','mist_ab_2k@yahoo.com','','83.103.154.202','2007-08-07 07:55:36','2007-08-07 05:55:36','draci ca-s mahmur... nu mai scribilesc bine...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4518,579,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','86.105.72.125','2007-08-07 23:10:49','2007-08-07 21:10:49','Au\' acilea ce dzice shafu\': blog.pacurar.net',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4517,579,'mumuland','','','85.204.38.37','2007-08-07 22:02:25','2007-08-07 20:02:25','aaaaaaaa   hokk banu e ochiu drecului desi sa curga beutura si sa vina fomeile...alea despuiate........deci la tine va fi.aaaaaaaaaa a venit firma de catiering.avem pire cu pulpe de pui si fasole cu carnat si.........un  69 cu misionar asortat cu  linguritza si stropit cu sex oral pe final.....asta e pt groparu :))........\r\n\r\niz io ma.care io? asta : ;)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(4500,568,'albanezu','mist_ab_2k@yahoo.com','http://deci!','83.103.154.202','2007-08-07 07:53:53','2007-08-07 05:53:53','deoarece tara asta multilateral dezvoltata sub nivelu marii are populatia formata din neamuri vecine si prekine, bozd mec = fute-o iar menihozo, care nu creca ii scrisa corect, inseamna \"pkizda masii\"',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4538,578,'Hammer','hammer@alpinet.org','','86.120.55.79','2007-08-08 13:11:35','2007-08-08 11:11:35','bine ca a subliniat ca nu a facut parte an grupuri de bagabontzi shi derbedei',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(4539,578,'Hammer','hammer@alpinet.org','','86.120.55.79','2007-08-08 13:12:20','2007-08-08 11:12:20','bine ca a subliniat faptul ca nu a facut parte an grupuri de bagabontzi si derbedei',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(4289,548,'Radu M.','radu_muri@yahoo.com','http://theblacklight.wordpress.com/','79.113.139.52','2007-07-31 09:30:51','2007-07-31 07:30:51','Faina poveste, apoi bagsama ca esti pescar ca si mine...ceea ce-i muy bine...fire intinse...:D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7','',0,0),(4290,550,'katmai','katmai@keptprivate.com','http://www.512kbps.com','193.86.73.13','2007-07-31 10:06:31','2007-07-31 08:06:31','wooo groparu iz bec :D mai diar :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(4295,550,'ania','soredarkshines@gmail.com','http://aniakhaki.blogspot.com/','89.123.99.243','2007-07-31 11:01:45','2007-07-31 09:01:45','@mumuland :)) apai sa stii ca inghetata cu sunca chiar nu vreau :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4296,550,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-07-31 11:15:42','2007-07-31 09:15:42','@ Epurila: mesu\' meu de gropar e (care altu\'?) groparu_ro @ yahu.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4761,593,'pliscu','adigherla@yahoo.com','http://pliscu.blogspot.com','86.105.73.121','2007-08-14 16:16:51','2007-08-14 14:16:51','da` ti`am spus ca ti`am virat 2000 de lei in cont, ce te tot prefaci ca nu stii?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4537,578,'Hammer','hammer@alpinet.org','','86.120.55.79','2007-08-08 13:11:35','2007-08-08 11:11:35','bina ca a subliniat ca nu a facut parte an grupuri de bagabontzi shi derbedei',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(4324,546,'pliscu','adigherla@yahoo.com','http://pliscu.blogspot.com','193.226.6.226','2007-07-31 23:02:11','2007-07-31 21:02:11','curiozitate: iti place sa joci fotbal?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(4309,551,'pepi','roman.petre@gmail.com','','82.77.126.134','2007-07-31 16:15:19','2007-07-31 14:15:19','Multam frumos de urare\r\nSa traiasca groparu al mare ! ;)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727)','',0,0),(4310,551,'sabina','','','81.12.163.178','2007-07-31 16:22:07','2007-07-31 14:22:07','tare... la multi ani, Petre! Sa fii iubit, copile!',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(4311,548,'Vlad','dez_legat@yahoo.com','','79.113.139.74','2007-07-31 16:23:03','2007-07-31 14:23:03','/whois sabina.....resolving DNS sabina to: DUMNEZO!.irod.teohtist.pittis\r\nCine face o alianta cu mine? cetatenilooooooor aveti incredere!\r\nPS: daca poate face cineva un studiu referitor la cat damage pot face 53 de litri de bere asupra neuronilor, sa-mi trimita un mesaj morse ca altceva nu mai poci descifra',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4312,548,'Radu M.','radu_muri@yahoo.com','http://theblacklight.wordpress.com/','79.113.136.89','2007-07-31 16:29:23','2007-07-31 14:29:23','RÃ£gÃ£....nickul tau imi sugereaza ca stai pe undeva pe Buzaului....Grigorescu..:D asa e?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7','',0,0),(4303,550,'Andreea MKT','supergirgir@yahoo.com','http://marlahermina.deviantart.com/gallery/','82.77.126.254','2007-07-31 14:44:20','2007-07-31 12:44:20','nici pe mine nu ma intereseaza daca te insori cu alta si nu ma iei pe mine, fiinca sunt inginer.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(4272,550,'Alexandra','alex.groza@gmail.com','http://alexis-design.info','89.34.72.14','2007-07-30 19:36:35','2007-07-30 17:36:35','Si asta cica ii adevarat ?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4273,550,'ania','soredarkshines@gmail.com','http://aniakhaki.blogspot.com/','89.123.124.209','2007-07-30 19:57:12','2007-07-30 17:57:12','good! e bine de stiut ce a fost prin olimpic.\r\npoate de aia l-au inchis si tre\' sa mergem la aquina...sa stam inchisi acolo cu toti fanii solar :&gt;\r\nsi...daca e pe bune povestea...saracul om :(',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4274,550,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','86.105.72.125','2007-07-30 20:30:02','2007-07-30 18:30:02','@ SS: apai io nu le imPUT faptu\' ca ei PUT (ba da!), ci faptu\' ca de frica unei chestii de care s-ar putea sa le placa (recte: putzulica la dush in cur de mascul) isi refuza aceasta placere (?); ca io is de parere ca fiecare mascul in afara de mine sh inca cativa prekini cu care ma rad io ar trebui sa aiba macar o incercare homo, sa vaza dreq, le place, sau ba? ca io de ce vreau chestia asta: cu cat is mai multi homo, cu atat ramane mai multe gajici pt mine, care-s cam avid.\r\n\r\n@ Alexandra: apai daca injineru\' ma minte, mint sh io; da\' io numa atata zic: io am renuntat sa ma mai gandesc la cat caca de peshte ne vine noo la Cluj din Tarnitza pe tzava. \r\n\r\n@ ania: da, poate d-aia l-au inchis, sau poate din cauza ca li se pishca ca presteaza un serviciu public sh ar cam trebui sa steie dreq deschisi sa ne satisfaca! Aud? Nu l-au inchis, auzi, ca cica un alt injiner o fo vinerea sau joia trecuta acolo, de s-o balacit.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4275,550,'ania','soredarkshines@gmail.com','http://aniakhaki.blogspot.com/','89.123.87.85','2007-07-30 20:36:10','2007-07-30 18:36:10','poate inginerii din jurul meu m-au dezinformat...da eu asa am auzit...ca olimpicul de afara e inchis pentru renovare...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4482,567,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-08-06 14:58:07','2007-08-06 12:58:07','Ioai, pepi, mersi mah, mersi fain ;)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4483,568,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-08-06 17:04:52','2007-08-06 15:04:52','Deci mo, scuza-ma, da\' io nu prea stiu mai multa maghiara decat stiu coreeana!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4484,568,'ania','soredarkshines@gmail.com','http://aniakhaki.blogspot.com/','89.123.82.34','2007-08-06 17:16:05','2007-08-06 15:16:05','te-a injurat...:))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4554,582,'Arhi','arhi@arhiblog.com','','81.181.174.115','2007-08-08 17:17:01','2007-08-08 15:17:01','a se remarca ca ideea e a lui Oradeanul.com, nu a lui dan',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4277,550,'mumuland','','','85.204.38.37','2007-07-30 21:26:48','2007-07-30 19:26:48','pfuiai frateeee ce phoveste ...ce nharatiune .....ceee lostrita me tat zici?pe ala lo prins infractu la inima in hapa si aasta sa scuza ca lo zgariat cu unghia?ba ....ba ...ba ?,... io nu mai zac nimik ca mai spariet cu mortzii tai......auzi ?co phovestirea hasta iai thaiat hapetiitu de inghe la donsoara care te dorea pa blog ....rece...\r\n\r\niz io ma.care io?asta : ;)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(4278,550,'ania','soredarkshines@gmail.com','http://aniakhaki.blogspot.com/','89.123.122.100','2007-07-30 21:40:46','2007-07-30 19:40:46',':)) apetitul de inghetata...niciodata ;)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4561,583,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','86.105.72.125','2007-08-08 18:26:19','2007-08-08 16:26:19','@ Ralu: Da, numa\' ca atunci nu ar mai fi al meu statusu\' :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(4562,583,'Radu M.','radu_muri@yahoo.com','http://theblacklight.wordpress.com/','79.113.137.49','2007-08-08 18:46:02','2007-08-08 16:46:02','Chiar ca au un IQ ridicat dar sunt cam seci...da` merg la tzara...:]',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7','',0,0),(4560,583,'Ralu','obviously_strange@yahoo.com','','79.113.139.214','2007-08-08 18:04:24','2007-08-08 16:04:24','Sau: `If you tied buttered toast to the back of a cat and dropped it from a\r\nheight, what would happen?` :-?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4280,550,'mumuland','','','85.204.38.37','2007-07-30 22:39:22','2007-07-30 20:39:22','haoleu ! nu! pentru nhumele lui dionisos nu? nu ca ar fi un cadavru plutind intro piscina................ dar tapanu respectic mai este si crestat de o unghie....parca te si vad  cum spui: aha omeni morti scufundati putreziti....da sigur o sa iau o inghe de fructe de padure....cu extra sirop de zmeura...minunat...si vreau si smochine..si mortii aia tu cum nu pluteau?de ce erau scufundati? da eu am comandat si extra sirop................bai gropare la ase blog ashe comentatori.....vb aia: cei ce se samana ..se inmultesc..(da la atata samanat)\r\n\r\niz io ma.care io? asta: ;)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(4281,550,'ania','soredarkshines@gmail.com','http://aniakhaki.blogspot.com/','89.123.94.206','2007-07-30 22:52:07','2007-07-30 20:52:07','inghetata de fructe sa mananci tu. si smochine...yuck',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4282,550,'stella_dark_angel','stella_dark_angel@yahoo.com','http://thismakesmegreen.blogspot.com','193.239.247.224','2007-07-31 00:07:42','2007-07-30 22:07:42','sa..mor..am ras de n-ammai putut..acuma imi pun yo intrebarea retorika ce-i drept, dak toti din familia mea sunt injineri..  ei..ce cadavre or mai fi zgariat la viata lor...:=))) secrete de fam parea I:=))',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SIMBAR={B393C74F-E8EF-4b95-81E6-CA2EFC1DFA1E}; SV1; Seekmo 10.0.314.0)','',0,0),(4283,550,'ania','soredarkshines@gmail.com','http://aniakhaki.blogspot.com/','89.123.113.126','2007-07-31 00:23:49','2007-07-30 22:23:49','ce zici de un leapsa \'my desktop\'...ca-s curioasa cum arata un desktop de gropar...si macar asa nu mai scrii de \'injineri\' si cadavre ;)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4383,559,'ss','criss_team@yahoo.com','','81.196.150.198','2007-08-02 15:52:51','2007-08-02 13:52:51','aoleu, domnu groparu, nici nu stiu daca sa ma bucur sau sa ma ingrijorez pt tine... totusi am sentimentu ca iti cam trebe niste bafta la tine asa ca itz urez sa n-o uiti cumva p-acas.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7','',0,0),(4326,552,'ania','soredarkshines@gmail.com','http://aniakhaki.blogspot.com/','89.123.99.243','2007-07-31 23:32:56','2007-07-31 21:32:56','pestii si copiii fac pipi in apa :&gt;',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4475,567,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-08-06 10:40:55','2007-08-06 08:40:55','@ Femei: ioi, mersi la fel :)\r\n\r\n@ Ionut: mersi frumos de urarile de bine facute amei mele, care de fapt i-o doamna, sh te intreb: pozele de pe saitu matale is cu femei goale? c-alfel...\r\n\r\n@ ania: mersi la fel ;) nu i-am dus, ca daca ii duc, il arde\r\n\r\n@ angel: promiteam, da\' nu prea m-am tinut de cuvant! mersi la fel de urari ;)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4476,557,'sabina','','','81.12.163.178','2007-08-06 11:14:32','2007-08-06 09:14:32','isi construise si dush, bag sama, tot din cartoane...',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(4477,568,'albanezu','mist_ab_2k@yahoo.com','','83.103.154.202','2007-08-06 11:17:54','2007-08-06 09:17:54',': bozd mec, menihozo.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4478,551,'Corina','','','64.236.208.25','2007-08-06 12:57:03','2007-08-06 10:57:03','Asteptam sa o puna cineva pe niste acorduri .... La multi ani, Petre!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(4314,548,'RÃ£gÃ£','jnitzal@yahoo.com','','89.123.91.12','2007-07-31 17:05:32','2007-07-31 15:05:32','Da..da .. sau prin BuzÃ£u, satu Grigorescu. Bine m-ai ginit. Ce faci RÃ£ducule? Ce de radu pe blog pÃ£trat.. devil inside..',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4548,578,'admin','groparu_ro@yahoo.com','http://','82.77.126.254','2007-08-08 16:08:29','2007-08-08 14:08:29','Da, mah, fraza aia e apsolut geniala, desi io unu n-as angaja p-unu caruia nu i-o placut BUG Mafia in tineretza...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,1),(4304,550,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-07-31 14:56:56','2007-07-31 12:56:56','Tu pe langa faptu ca nu ej nici macar inginer, ej sh foarte loata! Yankee, wespekt...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4513,579,'mumuland','','','85.204.38.37','2007-08-07 19:28:53','2007-08-07 17:28:53','sa zaci si la mine dacva pica ceva marire de salar de leafa de remuneratie ......hok? ca daca e pozitiva treaba atunci sa bag si io la inaintare o oda ...vb proverbului:  pana trec puntea ma fak frate si cu......cine trebe...\r\n\r\niz io ma?care io? asta: ;)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(4316,548,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-07-31 17:38:18','2007-07-31 15:38:18','Deci nu poci decat a ma foarte bucura ca VlÄƒdilÄƒ sh RÄƒgÄƒ (care rule, BTW) apÄƒrurÄƒ din ceÅ£e, numa atata voi a va ruga pi toÅ£i: numa sa nu faceÅ£ din bunÄƒtate de sait portal de racolari gay onlain!!!! Mai ales dacÄƒ e fÄƒrÄƒ comision la gropar.\r\n\r\nÅž tÄƒt pt toÅ£i: Dumnezo!!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4288,550,'mumuland','','','80.97.64.199','2007-07-31 08:04:52','2007-07-31 06:04:52','pantru ania shpecial:  aici nu esti in reklama la hohland sa zaci ca o vrei pa aia cu sunca....am zas inghetata de fructe apai de aia tre sa mananci...hai ca las smochinele  afara sa nu zaci ca nu las de la mine ....',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12','',0,0),(4266,548,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-07-30 16:17:15','2007-07-30 14:17:15','Gresit! Cu atata alcool abia am reusi sa le imbatam bine, ca sa parem sh noi mai sexy in ochii lor! Ca daca a doua zi le vine sa vomite cand ne vad cu ele in pat, asta e partea a doa.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4267,548,'ania','soredarkshines@gmail.com','http://aniakhaki.blogspot.com/','89.123.124.209','2007-07-30 17:17:06','2007-07-30 15:17:06',':))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4268,550,'ss','criss_team@yahoo.com','','81.196.150.198','2007-07-30 17:29:44','2007-07-30 15:29:44','no bhola...de nu s-ar fi dus prekinu la baia anuala, cine stie, poate si in ziua de az ar mai fi facut nenea ala scuba diving in olimpic..of of.. sa-l ierte Dumnezeu (si pe nenea si pe salvamar).\r\n\r\nin alta ordine de idei: domnu groparu, dupa postarea asta nu pre o sa mai ai spor la combatut indivizi certati cu apa si sapunu, ca o sa-ti zica_ca ei este precauti, ca adica cum sa aiba ei contact cu dushu si sa riste sa se bolnaveasca cu cine stie ce maladie... s-apai vorba aia, la dush nici nu poti ca sa-i pui prezervativ..',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7','',0,0),(4249,548,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-07-30 11:12:21','2007-07-30 09:12:21','@ ania: ba nu, ca eream undeva in dreapta lacului, gheparte de lumea dezlantuita, gheparte pana sh de viperi, soacre sau alte taratoare!\r\n\r\n@ mumuland: deci in primu\' rand ca amu is mai sigur ca oricand ca tu esti; da\' is si mai sigur ca nu acasa am dezghiocat votcile, ci acolo, intre munti, daca nu ma crezi intreaba-i p-aia de or fost sh ei acolo, intreaba-i de ce zambeau furios cand am monopolizat io discutia la foc, sh am glasuit ceva articulat de genu\' \"eerrddhhjskeeeee... djjsjkakkkkk!!!\" Sh ei or zis \"Ce???\" sh io am zis \"Nu pot sa cred ca ma puneti sa repet asa o fraza complicata!\"',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4244,548,'ania','soredarkshines@gmail.com','http://aniakhaki.blogspot.com/','89.123.87.11','2007-07-30 00:00:23','2007-07-29 22:00:23','good...ma bucur ca te-ai distrat si ca nu te-a papat vreo vipera :) da vad ca poza e facuta de pe terasa cabanei...deci imi imaginez ca ai avut ca limite barajul si hotelul :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4262,548,'Adi Calarasu','acalarasu@gmail.com','http://adriancalarasu.wordpress.com','82.76.75.99','2007-07-30 15:50:37','2007-07-30 13:50:37','no, am inteles si stiu si io ce-i aia zaraza c-am beut si io una d\'aia mica, ca prea faina era reclama. deci doar reclama mi-o placut.\r\nda\' dupe aia nu stinjai cu berule?\r\n:)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(4294,550,'IepurasulAtomic','praetorian21uk@yahoo.com','','192.100.130.7','2007-07-31 10:57:19','2007-07-31 08:57:19','Uai, io atata am de zis despre patania pretinului tau: buey frate, mai taie-ti unghiile de la picioare ca omori omini si nu-i frumos :D. Mno, dau acuma si condoleantze pentru saracu\' om, ca-i pacat de viata lui, da\' ce sa-i faci!? \r\n\r\nSi acuma Gropare, cinstita si mandra fie familia ta care te-o facut, da-mi si mie te rog o adresa de contact(messenger si/sau mail) sa povestim de trebushoara ceia de-am pomenit-o io vineri(sau joi), ca nici nu mai stiu. Nu ca n-ar fi important, da\' mi-o mai murit cativa neuroni de la bautura in vickend...si bineinteles ca pe urma am cinstit in memoria lor si-am mai omorat o tura. Mno, astept :D. Multam fain!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(4257,548,'mumuland','','','80.97.64.199','2007-07-30 14:21:22','2007-07-30 12:21:22','moldovencele e nhaspa.tu auzi cum vorbiesc?pai daca ashe vorbiesc tuzi dai szama atunci cand  lie tavalaiesti cum jiem? \r\n\r\nis io ma.care io? asta; ;)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12','',0,0),(4258,548,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-07-30 14:51:58','2007-07-30 12:51:58','Depinde cat de bine le tavaleshti, mah, ca poate nu gem, ci numa fluiera sh bat din picioare!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4260,548,'Adi Calarasu','acalarasu@gmail.com','http://adriancalarasu.wordpress.com','82.76.75.99','2007-07-30 15:39:29','2007-07-30 13:39:29','zmeura cu berule zici? nu-mi miroase bine...',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(4261,548,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-07-30 15:40:58','2007-07-30 13:40:58','Da, mah, zmeura cu berule, atata numa ca nu era berule, era ceva distilat din vin, de-i zice Zaraza, dupa numele unei tiganoase care nush ce lautar o inspirat ea prin mahahalalerele Bucurestilor interbelici!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4558,582,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','86.105.72.125','2007-08-08 17:50:31','2007-08-08 15:50:31','@ Denisa la-la-la: corectat! ;)\r\n\r\n@ Arhi: deci Oradeanul e dedublatzi?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(4557,583,'ania','soredarkshines@gmail.com','http://aniakhaki.blogspot.com/','89.123.66.255','2007-08-08 17:44:22','2007-08-08 15:44:22','de acu cred ca o sa fiu mai atenta la statusurile tale :&gt;',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4255,548,'ania','soredarkshines@gmail.com','http://aniakhaki.blogspot.com/','89.123.124.19','2007-07-30 13:39:10','2007-07-30 11:39:10','yuck...! poate daca le spalati inainte...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4256,548,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-07-30 14:10:57','2007-07-30 12:10:57','Nu, ca dupe aia se plictiseshte anticorpii sh se pensioneaza, sh moare Groparu\', infectu\'.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4248,548,'mumuland','','','80.97.64.199','2007-07-30 07:04:00','2007-07-30 05:04:00','cel mai begos lucru e ala care suna ashe:  omu merje la lac belish sau nebelish ma rogh si isi ea pentru orjie o sticla de fanta si una de sprite ca lu jumatatea lui  nui place cola ca diszolva ficatu(o vaz pe discovery)...sara face plimabri in padurice sa aculte pasarici (care este  si care canta cica mai frumos decat alea de pe turzii).... tat sara foc de tabara da el sta si sa uita si face poze ca botezatu ...nu papa slanina pa pita ca jumatatea zace ca ingrasa ...sa nu mai vb de votca sau bere sau alte bucurii ale vietzii care nu e bune si e si periculoase pe deasupra ..sau pe dedesupt........pescuit? pola pescuit ca langa lac traje curentu si pola si baie in lac ca vine lostrita si iti papa ananasu.......si .....si .duminica sara omu ajunje acasa isi ia un r 26 la care aduna matematic un v 33 si apoi dupe ce efectu apare  scrieo poveste cum ai scris tu asara .......adevarul e dincolo de noi.....\r\n\r\niz io ma.care io? asta: ;)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12','',0,0),(4298,548,'RÃ£gÃ£','jnitzal@yahoo.com','','89.123.91.12','2007-07-31 11:50:24','2007-07-31 09:50:24','groasa treaba.. tre sa mai organizam o manevra de asta daca ne-or mai primi gazdele.. \'mniezooooo..\r\n\r\n\r\nDRACU!!!!!!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4293,546,'dsgfrtghjn','elenepascariu@yahoo.com','','82.76.225.56','2007-07-31 10:42:37','2007-07-31 08:42:37','la la ce commmmmmment misto mi se rupe de tot',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(4264,548,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-07-30 16:03:50','2007-07-30 14:03:50','E, pai tocma\' acilea e shparla, ca de fapt cu coniacu stingi berile! Cu sucu\' stingi votca, sh cea mai meserie e palinca, cu care stingi ginu\'!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4265,548,'ania','soredarkshines@gmail.com','http://aniakhaki.blogspot.com/','89.123.72.125','2007-07-30 16:13:38','2007-07-30 14:13:38','cu atata alcool ati reusi sa dezinfectati si moldovence :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4250,546,'AndRei','oioioi','http://simaisi','98.195.82.119','2007-07-30 11:50:22','2007-07-30 09:50:22','diiiiiiiiiiispaaaaaaari',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4251,548,'AndRei','palamnaeus','http://360.yahoo.com/cipcirip','98.195.82.119','2007-07-30 11:55:19','2007-07-30 09:55:19','\"e gross\" mai degraba. deci iara atz cantat gros scrumul de tzigara. imi amintesc de o anumita sceneta in care povesteai cu ceva pretenar pretentzios (si, imi parea mie, gay sau macar efeminat) \"il stii pe S...?\" \"nu\" \"apoi n-atzi pierdut nici unul nici celalalt nimic\"...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4252,548,'mumuland','','','80.97.64.199','2007-07-30 12:11:56','2007-07-30 10:11:56','io ti cred frati......cum sa nu ti cried....da ase imi placie miii sa ma las grieu sconvins...i zac  minunat ca mierjeti la munti si cantati nu di alta da iar inciepe anu universitaro moldovinesc di la cluj...........stii aia care vin din moldova lui stiefan ...sa care tatzi au pis(z)te 9,99 la bac si numa medii die 10 in liceu si hocupa 98% din locurili di la cluj si nom ave ce face numa sa ne mutam in munti.......sa imi tii si mie un loc bun langa lac...sa plantez si  carutza me cu puradei acolo....\r\n\r\n\r\niz io ma.care io?asta: ;)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12','',0,0),(4253,548,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-07-30 12:27:35','2007-07-30 10:27:35','@ AndRei, nu iereau nici unu efeminat, iereau numa pretzioshi; ridicol de pretzioshi; sh nu am cantat fumul de tigara, ci scrumul de tigara, care e doo cantice diferite unu de cealalta, scrise de doi artisti diferite unu de cealalta. Oricum, tz-ar fi placut ;) (acum poti ofta de dor)\r\n\r\n@ mumuland: io numa atata dzic, cum ca IO, marele gropar, am picat de doo ori la facultate. De 2 ori. Sh abia in al treilea an am intrat. Sh nu-i stress, ca daca vin moldoveni, vine sh multe moldovence!!! Ceea ce e de bine, zic io. Cum care io? Tot asta: ;)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4299,548,'sabina','','','81.12.163.178','2007-07-31 12:16:03','2007-07-31 10:16:03','Sa scrie si Dezlegatu\'! Am zisara!',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(4519,579,'ania','soredarkshines@gmail.com','http://aniakhaki.blogspot.com/','89.123.69.241','2007-08-07 23:28:07','2007-08-07 21:28:07','bai nu ziua groparesei a fost sambata?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5','',0,0),(4516,579,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','86.105.72.125','2007-08-07 21:36:09','2007-08-07 19:36:09','@ ania: gropareasa, sau groparitza? ca e doo entitati diferite...\r\n\r\n@ mumuland: mo, nush, io tot astept sa fiu platit direct in fomei sh bere! Se-aude, firma???',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4520,579,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','86.105.72.125','2007-08-07 23:41:03','2007-08-07 21:41:03','Apai ba da, da\' amandoo mi-s shefe :|',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4521,578,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','86.105.72.125','2007-08-07 23:49:44','2007-08-07 21:49:44','Deci finca nimeni nu se invreniceshte sa comenteasca aceasta sublima mostra de intelect probabil finca lor li se pare ca CV-ul e super corect, dati-mi voie sa va zic ca nu e, sh postarea asta chiar merita macar un comment, pentru ca sivi-ul asta e super najpa, desi voo vi se pare ca e super corect!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4760,593,'De aia','dwee@yahoo.com','http://de-aia.blogspot.com/','213.157.188.71','2007-08-14 16:09:09','2007-08-14 14:09:09','gropare, meri si zi ca dai banii inapoi. cine stie ce functionara nacajita de la banca tre sa lucre o luna doua pentru banii aia ca o gresit contu... fii om bun ma sa nu se greseasca si la tine candva :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4493,568,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','86.105.72.125','2007-08-06 23:24:06','2007-08-06 21:24:06','@ ania: m-o injurat? No fii atent ce i-o zic: albanezule, mosteni-mi-ai imperiu\'!\r\n\r\n@ adi: ezac! nici mai mult nici mai putin!\r\n\r\n@ Epurila: ma, sh io fac parte din noi astia care inca nu stie maghiara! Sh tot sper sa imi zica sh mie unu macar ce insamna macar cuvintele alea de mi le-o scris albanezu\', ca creca alea is mai picante decat articolu in care cica e vorba de mine... desi, daca insamna ce cred sh stiu io ca-nsamna (si chiar stiu, ca asa mi-or zis toti vamesii din tzara vecina sh prekina!), mai degraba i-as zice sa caute altu\' sa si-l f***, ca pe curu\' meu, dupa cate am mai zis, scrie foarte clar \"EXIT ONLY\"!!! (ii traduceti careva lu albanezu\' ce insamna asta pls?)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4525,578,'Florina','florina_hica@yahoo.com','','79.113.129.28','2007-08-08 03:01:29','2007-08-08 01:01:29','Mda... e super corect dar mai trist ar fii daca cineva chiar la-r angaja an functie de cea cea scris in sivi...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4473,567,'angel','elena.siriteanu@yahoo.com','','86.127.26.22','2007-08-06 09:49:22','2007-08-06 07:49:22','promiteai de mic.:))\r\nLa Multi Ani mamei tale!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; iOpus-I-M; .NET CLR 1.1.4322)','',0,0),(4563,583,'Radu M.','radu_muri@yahoo.com','http://theblacklight.wordpress.com/','79.113.137.49','2007-08-08 18:48:42','2007-08-08 16:48:42','Uite cateva statusuri... \r\n-&gt;\"Nu lua in desert numele Domnului ....du-te singur\"\r\n-&gt;\"Suicide is man\'s way of telling God \"You can\'t fire me! I quit!!!\"\"\r\n-&gt;',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7','',0,0),(4564,583,'Ralu','obviously_strange@yahoo.com','','79.113.139.214','2007-08-08 18:58:01','2007-08-08 16:58:01','Da, da` asta nu inseamna ca nu-mi pot etala eu minunatia de IQ pe bloguri la necunoscuti :D Fain blog, bai dÃ£ uei :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4486,568,'adi','adyrotaru@yahoo.com','','86.34.227.117','2007-08-06 17:31:53','2007-08-06 15:31:53','aha, deci asa...',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(4487,568,'IepurasulAtomic','praetorian21uk@yahoo.com','','192.100.130.8','2007-08-06 17:42:28','2007-08-06 15:42:28','Da\' uai Gropare, noi astia mai putin vorbitori de limba maghiara de nu prea stim nici intelege limba mai la stanga mentionata...ce ne facem? Ii frumos asha sa ma lasi sa mor aci curios c-ai dat in vant cu vorba si io n-o pricep? Io maine imi iau un translator ungur si de nu-i stire buna, ai pus-o cu mine. Scuza-ma ca-s asha suparat, am avut o zi lunga :). Salut Groparu\' cu respect ;).',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(4447,560,'Femei','pas@yhaoo.com','http://de-aia.blogspot.com','89.137.117.237','2007-08-04 15:55:30','2007-08-04 13:55:30','zeu pe dracu! vine pentru bani, canta plictisit, cearta publicul cand aplauda si bea ca porcu tot spectacolu. in plus nici nu prea are chef sa vina la bis... decat dupa mult chin. asta ii ceva pui de zmau!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.2) Gecko/20070219 Firefox/2.0.0.2','',0,0),(4448,560,'macabroo','raduccc@yahoo.com','http://rezistenta.blogspot.com','82.76.52.94','2007-08-04 16:16:37','2007-08-04 14:16:37','Deci se integreaza perfect in peisaj. Nu cred ca te duci la Bregovici asteptand sa vezi Celine Dione. Atata timp cat face ce face, si o face bine, nu vad unde  e problema... Cat despre partea cu aplaudatul, unii merita sa moara',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4437,565,'mmm','','','89.122.251.212','2007-08-04 09:09:19','2007-08-04 07:09:19','wow!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4438,565,'bicplayer','bic_player@yahoo.com','','86.125.169.80','2007-08-04 09:45:20','2007-08-04 07:45:20','poftim cultutra, la anu recolta :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4439,560,'macabroo','raduccc@yahoo.com','http://rezistenta.blogspot.com','82.76.52.94','2007-08-04 09:45:45','2007-08-04 07:45:45','Bai Goran e zeu. Si daca ar fi doar o leak mai sclabutz tot ar fi semizeu.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4440,560,'bicplayer','bic_player@yahoo.com','','86.125.169.80','2007-08-04 09:56:19','2007-08-04 07:56:19','\"Groparu is always wright\" :-)))))) hahahahaa\r\nof coursea ;-) Groparu for President :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4446,567,'Femei','pas@yhaoo.com','http://de-aia.blogspot.com','89.137.117.237','2007-08-04 15:53:25','2007-08-04 13:53:25','La Multi Ani!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.2) Gecko/20070219 Firefox/2.0.0.2','',0,0),(4442,565,'macabroo','raduccc@yahoo.com','http://rezistenta.blogspot.com','82.76.52.94','2007-08-04 11:43:20','2007-08-04 09:43:20','La mijloc nu e un lucur curat.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4480,567,'pepi333','','http://roman.petregmail.com','82.77.126.134','2007-08-06 14:07:54','2007-08-06 12:07:54','La multi ani doamna mama lui groparu :) !',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4481,551,'pepi333','roman.petre@gmail.com','','82.77.126.134','2007-08-06 14:12:09','2007-08-06 12:12:09','Amu multam tuturor de urari:\r\n\r\n@sabina - eu zic ca sunt deja iubit :)\r\n@femei - anu asta fara chef, doar pe acasa cu vargalebes \"home-made\" :D\r\n@livia - unde e baiatu ala grozav... sa-l stiu si eu :P\r\n@corina - abia astept sa canti piesa (ma uit mereu pe taraf tv, asa ca sigur nu o sa ratez hitul daca apare) :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4444,565,'ubu','manu@seanet.ro','http://manusart.wordpress.com','89.42.142.197','2007-08-04 14:01:28','2007-08-04 12:01:28','mai baietzi ia mai intratzi si p\'aici&gt;\r\nwww.ebuchete.ro\r\ncica e blog de opinii ushoare\r\nCat de ushoare?\r\n\r\nmanuX',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(4758,593,'Andreea MKT','supergirgir@yahoo.com','http://marlahermina.deviantart.com/gallery/','82.77.126.254','2007-08-14 15:25:20','2007-08-14 13:25:20','mie oedip (nu ala cu ma-sa) mi se pare atragator:))',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(4755,589,'octa','octaviatarnita@yahoo.com','','86.132.126.149','2007-08-14 14:30:55','2007-08-14 12:30:55','serus, \r\nnumai am vrut sa va zic ca mi-i ciuda ca nu am participat la smida, editia 2007',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; YPC 3.2.0; SV1)','',0,0),(4756,592,'oedip','oedip74@gmail.com','http://oedip.blogspot.com','89.137.99.163','2007-08-14 14:42:14','2007-08-14 12:42:14','da, da... de aia te-o bagat silvan in piesa ca-i tat dai buzz :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4757,593,'oedip','oedip74@gmail.com','http://oedip.blogspot.com','89.137.99.163','2007-08-14 15:02:32','2007-08-14 13:02:32','io zic sa nu mai ploaie!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4754,593,'mumuland','','','80.97.64.199','2007-08-14 14:17:57','2007-08-14 12:17:57','mnie imi plac aia care merg cu fomeile lor la bag in comat si alea nu stie ce si  cum ...si el.omu...caPU LA famile ii explica ei ca ce si cum e  cu banii dhin cutiile alea...........\r\n\r\n\r\niz io ma.care io? asta:;)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12','',0,0),(4752,593,'marzazel','mariusrott@yahoo.com','','81.12.163.178','2007-08-14 13:46:25','2007-08-14 11:46:25','adica noi toti ceilalti care in continuare ne mai intitulam romani suntem hoti ?!? gata, nu mai vii sambata cu mine la shoplifting... aaa, adica shopping.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.2) Gecko/20070219 Firefox/2.0.0.2','',0,0),(4751,593,'adi','adyrotaru@yahoo.com','','86.34.227.117','2007-08-14 13:17:48','2007-08-14 11:17:48','ioi, nu stiam unde s-au dus banii pe care am incercat sa-i transfer la mine-n cont!!!\r\nfii bun si trimite-mi-i indarat :D',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(4750,593,'ania','soredarkshines@gmail.com','http://aniakhaki.blogspot.com/','89.123.109.12','2007-08-14 12:53:39','2007-08-14 10:53:39','good choice :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4741,593,'albanezu','mist_ab_2k@yahoo.com','','83.103.154.202','2007-08-14 08:06:59','2007-08-14 06:06:59','gropare, te deghizezi cat mai naspa sa nu te cunoasca camerele video, bagi cardu, scoti banii, si dup-aia meri si suni la banca cum ca ti-o furat cardu. Si te-ai scos.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4742,593,'sabina','','','81.12.163.178','2007-08-14 09:07:03','2007-08-14 07:07:03','da-mi-i mie, ca asa nu se cheama ca i-ai furat tu',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(4745,593,'ania','soredarkshines@gmail.com','http://aniakhaki.blogspot.com/','89.123.67.10','2007-08-14 10:41:39','2007-08-14 08:41:39','eu zic ca esti francez :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4747,593,'Andreea MKT','supergirgir@yahoo.com','http://marlahermina.deviantart.com/gallery/','82.77.126.254','2007-08-14 11:18:55','2007-08-14 09:18:55','deci radu\r\n\r\ncand eram studenta, ma dadeam mare la fetele din camin ca io fraieresc vanzatorii de pe Piezisha cu 10 000/pe punga de alimente. si da, asa faceam. acuma mi-ar fi rusine. si daca gasesc un portofel, evident ca o sa dau banii inapoi la destinatar sau cel putzin la Politie. daca banii aia is pentru un copil sau operatzie sau mai stiu eu ce? da-i dracu de bani, sunt happy ca am ajuns la nivelul profesional la care IMI PERMIT sa fiu corecta.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(4748,593,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-08-14 12:05:19','2007-08-14 10:05:19','@ albanezu: ar trebui sa se inventeze o deghizeala pentru anti-Dumnezeu, sa nu te recunoasca, sh sa poti fura cat ai kef; stii pe cineva care vinde?\r\n\r\n@ sabina: aha! tu vrei sa furi de la hotz???\r\n\r\n@ ania: io zic ca vreau sa fiu evreu bogat sh tanar\r\n\r\n@ andreea: da, si eu daca am sa gasesc o geanta plina de bani, am sa-i dedic pierzatorului o melodie la Radio Erevan! Ba chiar am sa si platesc dedicatia.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4729,593,'raluca','ralucaghervan@yahoo.com','http://360.yahoo.com/ralucaghervan','89.137.11.203','2007-08-13 22:47:18','2007-08-13 20:47:18','fii linistit ca si mie mi s-a intamplat si s-au prins destul de repede. :( nu stii ca bancile nu pierd niciodata? \r\nuai, si cate planuri imi facusem..',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 2.0.50727)','',0,0),(4730,589,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','86.105.72.125','2007-08-14 00:12:55','2007-08-13 22:12:55','@ mumu: nu, mah, nu e vrajeala, ca ala asa o zis, ca nu e\r\n\r\n@ sabina: da! sh urmeaza o noapte la fel de normala!\r\n\r\n@ ania: da, le-or pus extraterestrii!!!\r\n\r\n@ vlad: da, mo, oare n-am putea bea derect pastila aia?\r\n\r\n@ Radu M: mo, tat lacu\' e plin! da\' plin-plin! numa\' daca esti gajica si iti cauti peste io zic ca nu ai nimerit bine, asa ca da mai departe vorba, ca daca le trebe, sa ne caute pe noi',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4731,593,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','86.105.72.125','2007-08-14 00:40:29','2007-08-13 22:40:29','@ ralu: da, da\' faza e ca oricum o sa ma ploaie...\r\n\r\n@ ralu: asa e, bancile nu pierd niciodata, mai ales Banca Dacia Felix, CreditBank, Banca Internationala a Religiilor, BankCoop...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4726,593,'Ralu','obviously_strange@yahoo.com','','79.113.138.136','2007-08-13 22:12:09','2007-08-13 20:12:09','Pai ai putea sa te faci ca nu stii si sa iei banii, da` cikakarma o sa-si intre in atributiuni dup`aia si-o sa te roada constiinta c-ai luat croaziera-n grecia de la gura bine`mbracatului. Si daca ti se mai si intampla sa dea o ploaie cand vrei sa mergi la munte, ii zice ca-i pedeapsa divina :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4724,589,'Radu M.','radu_muri@yahoo.com','http://theblacklight.wordpress.com/','79.113.137.131','2007-08-13 19:34:44','2007-08-13 17:34:44','Gropare tu unde pescui cleni la Belis??? Zi si mie ca sa prinda si carligu meu cativa...:D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7','',0,0),(4718,536,'Nascut din spermatozoizi campioni &raquo; Blog Archive &raquo; Cantecacii care place Groparului','','http://www.groparu.ro/?p=592','69.16.239.16','2007-08-13 14:11:23','2007-08-13 12:11:23','[...] Ziceam acilea de Silvan, albanez de felu mariei sale, care ma cam enerveaza finca daca s-ar enerva, ar canta la [...]',0,'1','Incutio XML-RPC -- WordPress/2.1.2','pingback',0,0),(4703,589,'DÃ£nilÃ£','','','82.77.202.17','2007-08-13 10:07:44','2007-08-13 08:07:44','BÃƒÃƒÃƒÃƒÃƒÃƒÃƒÃƒÃƒÃƒÃƒ, cea mai tare fazÃ£ de weekendu\' Ã£sta a fost concertu\' lu\' UDO !!!!!!!!!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4700,589,'De aia','dwee@yahoo.com','http://de-aia.blogspot.com/','213.157.188.71','2007-08-13 09:21:03','2007-08-13 07:21:03','BAAAAAAAAAAA, II FOARTE TARE CEA MAI TARE FAZA DE WEEKENDU ASTA!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4701,589,'De aia','dwee@yahoo.com','http://de-aia.blogspot.com/','213.157.188.71','2007-08-13 09:21:51','2007-08-13 07:21:51','BAAAA, A CUI II PAPUCU ALA DE NU-I EPILAT PE PICIOR MA?! SCARBOSU\'!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4709,589,'ania','soredarkshines@gmail.com','http://aniakhaki.blogspot.com/','89.123.101.56','2007-08-13 11:52:21','2007-08-13 09:52:21','ce ma...sunt microfoane in autobuze?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4683,588,'bicplayer','bic_player@yahoo.com','','86.125.169.80','2007-08-12 15:55:34','2007-08-12 13:55:34','nasol moment :p\r\neh da sincer si mie asa mi se intampla knd beau cam mult :|\r\ncred k asta e modu lu d-zeu sa ne spuna k am exagerat :-s  da trece ;)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4711,544,'alexier','alexier_90@YAHOO.COM','','89.35.116.70','2007-08-13 12:18:10','2007-08-13 10:18:10','revenit tineti aproape\r\n?\r\nbha nu styu bancu da lam aflat:D\r\ndin pacate l-am si simtit...... fusai in deutsch la un seminar pe tema uniunii pulii mele cu europa in fine am aflat altceva mai imp la seminar intro pauza de cafea imi zice un sasalau ca ios roman si iam zis ca da si ca is roman nu tigan !!!! si mio zis ca o vast de curand la tv (cand am auzirt asta deja mi so ridicat paru ope picioare) in fine asta o vast ca filme porno rom is cele mai bune din europa.... macar suntem si noi la cv buni\r\n!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; DigExt)','',0,0),(4712,589,'De aia','dwee@yahoo.com','http://de-aia.blogspot.com/','213.157.188.71','2007-08-13 12:22:03','2007-08-13 10:22:03','no atunci ii bine ma gropare. da adevarata valoare ii epilata?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4713,589,'Vlad','dez_legat@yahoo.com','','79.113.139.197','2007-08-13 12:25:42','2007-08-13 10:25:42','mumuland : io-l cred pÃ£ Faur!\r\nde aia: ala-i papucu meu...si peru ala ii mandria Tarnita ca-i cu pedegree.\r\nnoa in rest o fo numa bine la weekend....respect pt pastila din babanu ca n-are efecte secundare gen durere de cap si alte dume',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4708,589,'sabina','','','81.12.163.178','2007-08-13 11:49:26','2007-08-13 09:49:26','dupa week-end-ul asta ziua de luni pare mult mai umana',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(4694,589,'raluca','ralucaghervan@yahoo.com','http://360.yahoo,com/ralucaghervan','89.137.11.203','2007-08-13 00:12:42','2007-08-12 22:12:42','mah, deci nu in tura in care ai fost tu mafiot ai castigat, ca in tura in care am fost eu mafiot. ca eu am dus greul. a se mentiona pentru precizia cartilor de istorie care urmeaza a fi scrise',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.0.3705; .NET CLR 1.1.4322)','',0,0),(4704,568,'Paszti','pasztorjozsef@yahoo.com','','81.12.230.166','2007-08-13 10:40:58','2007-08-13 08:40:58','Ba da, a doua parte a textului ii numa multumiri traducatorului, tzucui mana cu care o batut tastatura, ca fara el de rapa s-o fi dus toata expozitia.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727)','',0,0),(4705,589,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-08-13 10:53:13','2007-08-13 08:53:13','@ raluca: da\' tu crezi ca e usor sa fii barbatul din spatele geniei?\r\n\r\n@ de aia: sh io am vrut sa intreb ca de ce nu-i papucu\' epilat! Noroc ca adevarata valoare nu zace in picioare, ci intre. Parerea me.\r\n\r\n@ Danila: da, ma, io as fi preferat sa fie Uscato, da\' tat weekendu\' numa o plouat, bag p***',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4706,589,'mumuland','','','80.97.64.199','2007-08-13 11:01:38','2007-08-13 09:01:38','trea  cu soferu e vrajeala.. in rest bravo tie ca........ ai ce ai cu lacu ala...\r\n\r\niz io ma.care io? asta : ;)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12','',0,0),(4689,588,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','86.105.72.125','2007-08-12 21:09:34','2007-08-12 19:09:34','@ mumuland: mo, io tat zic ca e mult mai sexy sa urasti de exemplu francezii, sh nimeni nu m-asculta! ce pana me, doar impartim aceeasi tzara sh aceleasi femei!\r\n\r\n@ ania: apucai sa plec, sh fu sooper :D\r\n\r\n@ cÄƒlÄƒ: :)) io tot zic ca cea mai nasoala razbunare cross-cultural ii expresia aia englezeasca \"the French are coming\" (in traducere: vine ciclu)\r\n\r\n@ Adi: bine zis, tocma\' ce-o loai sh io! (Chinese mom to her baby girl: today we\'re eating round-eye!)\r\n\r\n@ femei: mo, deci m-as face, da\' care ar fi farmecu daca nu ai shafi care sa te fitileasca?\r\n\r\n@ bicplayer: mah, sh mie mi se-ntampla tot felu\' de kestii ciudate cand ma imbat!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4691,588,'mishu','mishu@doingtheartwork.com','http://www.doingtheartwork.com','89.123.118.178','2007-08-12 22:17:55','2007-08-12 20:17:55','Hatz! Nici n-am stiut prin ce peripetii a trecut ceainiza de vineri. Sper doar ca portia mea ti s-a varsat in geanta pe husa de la aparat, far de la bicicleta si ce \'mniezo mai era prin BLbuda vineri dupa amiaza.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(5386,623,'sktes','sktes_2002@yahoo.com','http://sktes.wordpress.com/','79.113.137.88','2007-09-02 13:27:29','2007-09-02 11:27:29','Pufaletzi! =P~ (felicitari si la cat mai multe pungi de pufaletzi)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5385,607,'zgribulica','sorina_zgribulica@yahoo.com','http://criticalmassploiesti.weblog.ro/','89.38.51.49','2007-09-02 13:11:45','2007-09-02 11:11:45','http://criticalmassploiesti.weblog.ro/     asta e critical mass',0,'1','Opera/9.22 (Windows NT 5.1; U; en)','',0,0),(5384,618,'baghy','baghy83@lycos.it','http://baghy.info/','78.12.19.252','2007-09-02 10:48:18','2007-09-02 08:48:18','cata imaginatie',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(4787,594,'Hammer','pontos_a@yahoo.com','','86.120.55.79','2007-08-15 07:56:56','2007-08-15 05:56:56','Faza cu bocancii de munte e chiar trista:-(',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(4789,595,'De aia','dwee@yahoo.com','http://de-aia.blogspot.com/','213.157.188.71','2007-08-15 08:50:25','2007-08-15 06:50:25','ma, ta~te ca ta~te, da unde ii piscina aia?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4792,589,'Emaginatoru','e_magist@yahoo.com','','86.122.12.12','2007-08-15 09:51:49','2007-08-15 07:51:49','Hai bey ca de faza cu patrushtriu treia sa scrie in ziar si deci as fi auzit si io ca am cativa pretini care citesc. Da uaricum ii fain. Si de nu-i adevarat.\r\nIn schimb adevarat e ca tenecu ala e mishto.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; en-GB; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4793,57,'Emaginatoru','e_magist@yahoo.com','','86.122.12.12','2007-08-15 10:06:14','2007-08-15 08:06:14','Voi acei ce stati pe vine\r\nSi alene va cacati\r\nStergeti degetele bine\r\nPe pereti sa nu mai dati\r\n\r\nTot intr-o toaleta in Targu Mures prin anii \'50',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; en-GB; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4794,595,'Calarasu','acalarasu@gmail.com','http://adriancalarasu.wordpress.com','89.32.19.126','2007-08-15 10:13:04','2007-08-15 08:13:04','Normal ca nu se deosebesc intre ei, fac un copil, il ratacesc in multime si-apoi se oftica si fac altul si tot asa. D\'aia-s asa multi!\r\n\r\nCe plictisitoare trebuie sa fie viata chinejilor. Nu poa\' sa faca si ei misto unu\' de altu\' in baza caracteristicilor fizionomice definitorii, sa-si zica si ei \"bah tzigane\", \"bah nasosule\" \'au \"mah uratule/fromosule\".\r\nCred ca n-au nici proverbe d\'alea gen \"ochii albastrii ca curu\' broastii\"\r\n\r\nAuzi, da\' este ca atunci cand te-au vazut au escxclamat \"Brad Pitt!!!\" ? Ca mie asa mi-or zis...',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(4795,594,'curioasa','totmea@yahoo.com','','86.35.232.96','2007-08-15 10:29:31','2007-08-15 08:29:31','auzi? da\' te si spetesti?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(4796,595,'curioasa','totmea@yahoo.com','','86.35.232.96','2007-08-15 10:34:40','2007-08-15 08:34:40','asa-i ca erau surdo-muti?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(4798,585,'Vlad','dez_legat@yahoo.com','','79.113.137.8','2007-08-15 12:54:34','2007-08-15 10:54:34','din ciclu : Te iubesc mama dar nu ca pe U!\r\nPS : Imi curgi prin vene Ioana!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4800,595,'mumuland','','','80.97.64.199','2007-08-15 13:47:02','2007-08-15 11:47:02','rasism pa fatza frate .......rasism pur........mama lor de oblici.....:)\r\n\r\niz io ma.care io?asta: ;)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12','',0,0),(4805,595,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','86.105.72.125','2007-08-15 17:36:09','2007-08-15 15:36:09','@ de aia: piscina aia e in Cluj. -Napoca.\r\n\r\n@ CÄƒlÄƒ: ba, mie nush de ce, da or exclamat \"Marla!!!\"\r\n\r\n@ curioasa: asa e, sh sh chineji pe deasupra!\r\n\r\n@ mumulan\': da, mah, cum sa nu fii rasist daca astia vin la baie fara chinezoaicele din dotare?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4806,595,'ania','soredarkshines@gmail.com','http://aniakhaki.blogspot.com/','89.123.76.91','2007-08-15 17:42:37','2007-08-15 15:42:37','ai auzit noua reteta?...chinezi bine transati portionati la valiza :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4807,595,'Radu M.','radu_muri@yahoo.com','http://theblacklight.wordpress.com/','79.113.137.61','2007-08-15 18:03:59','2007-08-15 16:03:59','Cel mai tare post....Vivat orezu`..:]',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7','',0,0),(4813,596,'mumuland','','','85.204.38.37','2007-08-15 22:46:51','2007-08-15 20:46:51','deci musai... da musai sa meri cu oarece  ofranda la zeitza aceea a cantinei...io la cantina hobservatorului ham papat odata un snitel de porcule.si ashe mam bucurat ca era mare si  no promitea mult...da cand mam apucat de halit avea carne ase de putina mai ceva k si ciocolata in oualele kindzder :)...no da sa i dai ceva la tanti...ca esti om bun si nu ii mumos sa hi om rhe....\r\n\r\niz io ma.care io? asta : ;)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(4814,596,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','86.105.72.125','2007-08-15 22:49:14','2007-08-15 20:49:14','Ba, sincer ma gandeam de mult sa merg la ea, desi nu am mai vazut-o niciodata de atunci, da\' mi-era jena sa ii zic \"sar\'na, tanti, is io! Cum care io? asta: ;)\"',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4818,595,'Mile','','http://milecarpenisan.wordpress.com','86.125.49.216','2007-08-16 01:22:20','2007-08-15 23:22:20','Nu pot sa cred ca riscam un razboi cu chinezii din cauza ta. Tu esti mai tzaka decat mine. Unde pu*a me ii ingropam pe toti dupa ce ii cotropim? In sacose?\r\nPS Incearca si tu sa te iei de neamuri din astea mai putin numeroase sa ii batem repede...sa ocupam Parisul si sa stam sa bem la fel ca si tata Hemingway. Oricum textul a fost bestial.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(4825,596,'Hammer','pontos_a@yahoo.com','','86.120.55.79','2007-08-16 07:03:49','2007-08-16 05:03:49','Am stat acolo in anul I. De treaba cantina :-)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(4826,595,'Radu M.','radu_muri@yahoo.com','http://theblacklight.wordpress.com/','79.113.138.215','2007-08-16 07:52:57','2007-08-16 05:52:57','@ Mile.....ii ingropam in valize...oricum, incap cam 2/valiza poate chiar si 3-4 daca-s mai micutzi...:D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7','',0,0),(4829,596,'cip','cip@blogul.ro','http://blogul.ro','193.138.195.202','2007-08-16 09:58:37','2007-08-16 07:58:37','Offtopic:\r\n\r\n\"Rod Stewart a fost gropar.\"\r\nSursa: http://www.hotnews.ro/articol_81405-Ce-munceau-vedetele-inainte-sa-devina-personaje-celebre.htm\r\n\r\nIntrebare: ce a fost Groparu inainte sa fie gropar?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4830,596,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-08-16 10:39:54','2007-08-16 08:39:54','@ cip: da, mah, deci v-atz prins: inainte de a fi gropar, am fost Rod Stewart.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4831,596,'ania','soredarkshines@gmail.com','http://aniakhaki.blogspot.com/','89.123.76.91','2007-08-16 11:08:13','2007-08-16 09:08:13','ai avut o viata palpitanta...poate iti face cineva o statuie in centru :D langa avram iancu :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4834,596,'Adi Calarasu','acalarasu@gmail.com','http://adriancalarasu.wordpress.com','62.217.241.242','2007-08-16 13:51:31','2007-08-16 11:51:31','acuma ca sÄƒ-Å£ speli pÄƒcatele, Ã®n viaÅ£a urmatoare e musai sÄƒ te faci moaÅŸÄƒ, zic...',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(4836,596,'IepurasulAtomic','praetorian21uk@yahoo.com','','82.77.123.71','2007-08-16 15:36:31','2007-08-16 13:36:31','Intamplarea asta imi aduce aminte de-o duma pe care am auzit-o de la un prieten. Nu stiu cat o fi de-adevarata, da\' nu m-as mira. Cica sa face ca castiga (caca) marele, Deosebitu\', NEMAIPOMENITU\' si inegalabilu\'(aici mi-ar fi trebuit niste caractere mai mici) de Doroftei un meci. Stiu, si eu m-am mirat cand am auzit c-a castigat Doro (ca asha il alint io, ca ne stim de cand m-am nascut...eu, ca el fura de mult mere din piatza). Asha, dara castiga si el un meci, toata lumea stupefiata: \"oai, o castigat Doro! Nu cred, mortii ma-sii ca pariasem pe alalalt!!! Acu\' i-o trebuit si lui sa castige?!\". Si vine una, cica reporterizda (de-al de aia de-l molesteaza pe Basexu in mall si i-o trage la \"poPULAritate\"-n-am inventat io cuvantu\', nu ma urati) si-l intreaba pe Doro: \"Bah fraiere....adica ma scuzati, domnule Cum-Te-Cheama(ca fata chiar nu stia), da\' cum de v-ati apucat de box?!\". La care Doro o privesti senin (si putin crucish, asha cum il stim cu totii) in ochi si-i spune vesel: \"Foamea doamna, foamea!\". \r\n\r\nMno, io vad ca tie ti-o priit foamea si nu te-ai tampit si d-aia imi esti tu drag. Uai, none of that gay shit, s-onteles?! Ca desi ai fo\' privat, creieru\' tau n-o incetat sa functioneze, motiv pentru care acuma incerci sa-l ineci(cu un sigur n) :). Pace p\'afara!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(4837,596,'IepurasulAtomic','praetorian21uk@yahoo.com','','82.77.123.71','2007-08-16 15:38:38','2007-08-16 13:38:38','@Ania, n-ai auzit c-or facut astia campanie: \"Mi s-o urat de atata urat!\"? In cazu\' asta, cum sa-i puna statuia lu\' Groparu\'?! Adica, no offense, da\' mai bine Iancu! Gropare, cand ma prinzi dau o bere....hehehe :D!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(4840,597,'ania','soredarkshines@gmail.com','http://aniakhaki.blogspot.com/','89.123.101.160','2007-08-16 17:27:13','2007-08-16 15:27:13','deci nu l-ai platit sa-ti faca reclama? :))\r\nsi tu ramai fara cuvinte? :(',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4841,597,'pliscu','pliscu@gmail.com','http://pliscu.blogspot.com','86.105.73.121','2007-08-16 17:31:41','2007-08-16 15:31:41','ooo, cati fani! cum stai cu \"groupie-girls\"?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4842,597,'','','','85.204.38.37','2007-08-16 18:38:12','2007-08-16 16:38:12','ma vezi ce patzesti de la spermatozoizii aia campioni?...io teas trimite la nationala die folbal  sa   ii ajutzi cu o calificare ma campionule ca vb aia is sponzorizatii de   bere.si tu cu berea esti mai frate decat e ea cu romanu.... :))\r\n\r\niz io ma.care io? asta: ;)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(4844,596,'dudu','wlaal888@yahoo.com','','88.158.197.199','2007-08-16 18:43:38','2007-08-16 16:43:38','tata lor treaba....amu e altfel....la cantina babes,din hasdeu chiar langa kminele de fete se poate manca moca chiar regulat...k e impinje tava (autoservire) si poti sa alegi si sa nu stai la rand sa platesti mancare ... ci sa meri direct la masa....bine....cu privirile de rigoare....de sperat sa fie ale celorlalti si nu a caseritzei sau bucatareselor:P aveam un prieten care ... k in povestioara (amintire) cam facea elefantzelul cu buzunarele si mai testa vigilenta caseritzei:))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4850,597,'IepurasulAtomic','praetorian21uk@yahoo.com','','62.217.245.97','2007-08-16 22:10:57','2007-08-16 20:10:57','Mo, am cetit si zic asha. C-o pupat ca n-o pupat, te-o atins unde tz-o placut. Si d-aci pana la orgasm ii doar un pas! Este? Oricum, mi-o placut cum o scris: frumos, direct, incisiv! Da\' is o tzara gelos, ca voiam si io sa te laud. Numa\' ca daca blogu\' mi-i pe butuci, n-am avut unde si cand. Asha ca, fac si io o semnatura langa a lor: \"Sunt Fan Groparu\"...adeca SFG, prescurtare care mai poate tine loc si de o alta activitate atat de placuta: \"Sa F$% Gagici\"! Da\' nu se compara cu a fi fan Groaparu\', aia-i clar! :) Si atata, ca parca vad ca tz-o iei in cap cu atatea laude si te dedai la beutura si minore care te vor pentru faima si nu mai scrii p\'aci ani intregi.\r\n\r\nDeci restu\', gata cu laudele ca si-o ia in cap! Io v-am spus...Pace p\'afara! ;)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(4860,592,'Vlad','dez_legat@yahoo.com','','79.113.137.121','2007-08-17 13:46:28','2007-08-17 11:46:28','mie nu-mi place de silvan cum canta.....si se si prea ataca ca o mironosita , oricum asta-i decat flashu meu propriu si personal.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4864,597,'Radu M.','radu_muri@yahoo.com','http://theblacklight.wordpress.com/','79.113.137.31','2007-08-17 16:12:35','2007-08-17 14:12:35','Respecte A tot ingropatorule...Sunt mandru ca te-am pus colea-sha in dreapta la blogul meu unde scrie Groparu',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7','',0,0),(4867,596,'alexier_90','alexier_90@yahoo.com','','89.43.250.189','2007-08-17 17:49:46','2007-08-17 15:49:46','neatza, bha daevaru ca ca nustiu un student mnacar care sa zica bha ca in faculta nu am suferit foame/..../ aja cv nu exista numai eu stiu cate foamete am rabdat in faculta ca doara numai de pipe si alcool aveam $ bha si zilele astea trec cu soaramea pin Tirgu Mures si ni se facura noua foame... am duso la o cantina infecta dupa ce am intrebato daca are increedere in mine. mia zis ca da si ma intrebat ca dc am aduso la aja o cantina si atuncia iam zis ca aicia mancam in faculta cand aveam bani ceea ce se inbtampla o data la 2 sapt !!!! oricum aniii de lic is frumopsi dar cei de facultyate in camine is futere',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; .NET CLR 1.0.3705; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(4870,597,'macabroo','raduccc@yahoo.com','http://rezistenta.blogspot.com','82.76.52.94','2007-08-17 21:07:21','2007-08-17 19:07:21','Imi cer scuze pentru manifestarea barbara de prost gust anterioara, doream sa comunic doar ca \"Groparu\' he\'s our man if he can\'t do it, no one can\" si acum sa redevenim circumspecti si critici cu lumea.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4873,598,'ania','soredarkshines@gmail.com','http://aniakhaki.blogspot.com/','89.123.107.45','2007-08-17 22:42:22','2007-08-17 20:42:22','frumosi nepoti :)  gropari in devenire...ce mai!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4874,598,'Domnu\' Nderthal','','','86.122.33.213','2007-08-17 23:35:56','2007-08-17 21:35:56','UrÃ¢te broajte... copchiii devin oameni de la paijpe ani in sus...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.4;MEGAUPLOAD 1.0','',0,0),(4875,598,'ania','soredarkshines@gmail.com','http://aniakhaki.blogspot.com/','89.123.73.79','2007-08-17 23:47:54','2007-08-17 21:47:54','bai porcule...is chiar draguti aia mici...broasca esti tu!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4891,598,'pliscu','adigherla@yahoo.com','http://pliscu.blogspot.com','89.137.98.84','2007-08-18 12:53:15','2007-08-18 10:53:15','cel mare iti poarta numele? :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(5349,624,'DÃ£nilÃ£','','','86.122.33.214','2007-08-31 21:26:22','2007-08-31 19:26:22','Te prind io bÃ£ jmekere si-ti dau la gioale... CÃ£-tz\' jtiu moaca si jtiu unde e nunta bÃ£ dejteptule... Shi lu\' vÃ£r-to... VÃ£ prind io... la Kor**a!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.4','',0,0),(5346,624,'ss','criss_team@yahoo.com','','81.196.150.198','2007-08-31 17:01:33','2007-08-31 15:01:33','cand bagi un ciardash din ala asa cu patima sa pui pe varu\' sa te filmeze, sa putem ca sa ne radem si noi un pic.\r\ndistractie!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7','',0,0),(5838,645,'katmai','katmai@keptprivate.com','http://512kbps.com','195.212.29.163','2007-09-20 09:25:34','2007-09-20 07:25:34','de fiecare data cand vin in ro, trebe sa stau in arad 1 2 ore. nam ce zice nimic . e cam scary. In turda am stat de la 4 la 7 ani. era frumos si quiet. era revolutia and stuff. Dupa parerea mea, un oras frumos o sa fie intotdeauna Alba-Iulia. 4 ani de liceu acolo, a fost chiar ... awesome. E mic el, dar are farmec, si te indragostesti',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7 (CK-IBM)','',0,0),(5831,644,'conia','','','194.153.242.9','2007-09-19 19:30:01','2007-09-19 17:30:01','@ Andreea :pe toti ii opresc cei de la Glamour Models, dupa parerea mea se ocupa cu altceva :)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(5780,637,'zahir9','','','89.137.116.186','2007-09-16 12:24:31','2007-09-16 10:24:31','foarte tare postul asta. multe din chestiile scrise aici imi amintesc de felul in care ma simteam acum ceva vreme cu un personaj  ince drag mie',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5832,644,'ss','criss_team@yahoo.com','','89.32.145.81','2007-09-19 19:42:40','2007-09-19 17:42:40','clar. se ocupa cu facut bani de la fraieri.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7','',0,0),(5837,645,'xxx','laaprozar@gmail.com','http://aprozar.blogspot.com/','86.34.251.238','2007-09-20 09:24:10','2007-09-20 07:24:10','parca ar fi un studio cinematografic unde s-a turnat raboiul stelelor',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; Alexa Toolbar; .NET CLR 2.0.50727; .NET CLR 1.1.4322; FDM)','',0,0),(5836,645,'tetelu2','tetelu2@personal.ro','','81.196.150.85','2007-09-20 07:34:39','2007-09-20 05:34:39','Despre  Arad au perfecta dreptate neamurile tale din \"jermanica\".\r\nAm fost si eu recent prin zona de vreo 3 saptamani, iar povestea ta mi-a dat o senzatie de deja vu. Totusi orasul are ceva ce la Cluj lipseste : un strand mare si frumos.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.0; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(5839,645,'andreanum','andreanum@yahoo.com','http://andreanum.wordpress.com','194.30.177.1','2007-09-20 09:50:34','2007-09-20 07:50:34','Acum 2 saptamini, mergind spre tara aia din vest cu granita de est spre Arad, a trebuit sa o luam si noi pe centura acestui minunat oras. Din cele 5 intersectii cu calea ferata am prins 3, dintre care una de doua ori. Asta se-ntimpla intr-o simbata. Cineva ne zicea ca mai bine o luam prin oras, ca econimiseam vreo 25 de minute, numai ca noi nu stim drumul prin oras, iar blocurile aradene nu ni se par cu nimic mai presus decit orice alt bloc comunist din tara noastra. Evident, ne-am minunat ca intre o comuna pe care nu mai stiu cum o cheama si Arad exista tramvai :D',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1)','',0,0),(5840,645,'Hammer','hammer@alpinet.org','','86.120.55.79','2007-09-20 11:29:55','2007-09-20 09:29:55','Apai s-o mai schimbat cate ceva in Copsha...or mai picat din hardugiile celea...unele singure, altele demolate, or mai crescut balarii mutante pe dealuri...puteai sa bagi in cadru si sula aia de horn (era elocvent) de polueaza cu plumb, cadmiu si alte kestii din tabloul marelui artist Mendeleev.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(5792,640,'Greuceanu','','','89.21.118.141','2007-09-17 05:55:31','2007-09-17 03:55:31','n-apoi la firma me\' se face numa\' building.... fara team.....',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(5793,105,'lilith','marcu_luiza@yahoo.com','http://www.aberatiunti.blogspot.com','82.77.126.148','2007-09-17 11:38:44','2007-09-17 09:38:44','mai, daca tu ai putut insamna ca si io pot!! nu tre sa fie sarbaUtoare ca sa tziu post, vreau numa sa vad daca pot! problema e cu tigarile... pot sa tin post si sa fumez? ca parca e prea naspa cafeaua de dimineata fara tigara! :(( \r\nasa, si chipsuri am voie? ca sunt un pic cam dependenta de ele. \r\nsa-mi raspunzi, auzi? si daca suna bine ma apuc si io sa vad cum e!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5794,640,'nenea cosmos','','http://www.nenea.wordpress.com','193.231.82.119','2007-09-17 16:42:27','2007-09-17 14:42:27','asta-i rau, nici macar odata pe an?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 2.0.50727)','',0,0),(5797,105,'admin','groparu_ro@yahoo.com','http://','86.105.72.125','2007-09-17 23:34:17','2007-09-17 21:34:17','No cigarettes, no nothing! Incearca sa renunti la orice te face sa te simti bine, ca io creca asta-i idea.\r\n\r\nCipsuri is out of the question, ca fac sete de bere. E simbioza naturala intre ele.\r\n\r\nLa sex in schimb iti da dezlegare Groparu. Kiar el.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,1),(4905,596,'Greuceanu','','','89.21.118.210','2007-08-19 00:40:28','2007-08-18 22:40:28','mo!\r\nsincer nu-mi aduc aminte sa-mi fost foame in faculta.... devenise doar o obijnuintza.... un sandvish?! sau doua beri?! ce alegi?! niciodata n-am ales sandvishul! culmea, gropule, o fost on costinejti, cand doo sapt n-am loat nik de mancare, doar slana sh biscuitii de acas.... si mi-ai zis.:\" bag pola mah! amu ni imi iau o gogoasha cu branza de la GOGOASA INFURIATA! nu mai pot de foame!\" si eu am zis.....\' no bine mah! io te ajtept vis-a-vis la terasa cu silva!\", mnoa! ghici! nici macar nu ai gustat=-o! o gogoasa era = cu 1,2 bere rece blonda la 400 ml...',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(4913,597,'Femei','pas@yhaoo.com','http://de-aia.blogspot.com','89.137.117.237','2007-08-19 11:50:10','2007-08-19 09:50:10','pa ma gropare, tu esti vedeta! pot sa iti zic \"dom profesar\" de acum?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.2) Gecko/20070219 Firefox/2.0.0.2','',0,0),(4921,594,'Replicile sÄƒptÄƒmÃ¢nii 11 at Jurnal de noapte','','http://www.andreicrivat.ro/2007/08/19/replicile-saptamanii-11/','212.227.64.193','2007-08-19 21:19:16','2007-08-19 19:19:16','[...] ÃŽntr-o bunÄƒ zi voi munci mai mult chiar decÃ¢t mine! (Groparu) [...]',0,'1','Incutio XML-RPC -- WordPress/2.2','pingback',0,0),(5546,632,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','86.105.72.125','2007-09-06 22:58:35','2007-09-06 20:58:35','Deci mo, io pe Anto\', Darius sh Baza ii pot tine-n frau, da\' nu-s prea sigur de omu cu idei locale, jegu\' sh groaprele. De astia kiar nu-s sigur de ce va ieshi!\r\n\r\nSh tu n-ai voie sa iti bei mintile, ca cica urmeaza cea mai frumoasa noapte din vieatza ta, sh trebe sa poti vedea toate stelele sh satelitii care se promeneaza prin bolta!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5547,632,'Miruna','mirunavasilescu@yahoo.com','','86.106.59.163','2007-09-06 23:31:54','2007-09-06 21:31:54','@ Andrei Crivat: Auauau, deci de aia mi se tot zicea mie ca asa-i obiceiul local...la o nunta am fost in viata mea, si cu aia sper sa raman ca si acum incerc sa uit. In alta ordine de idei, la mai mare, sa fie-ntr-un ceas bun si toate cele corespunzatoare momentului! :)\r\n\r\n@ Groparu: tu ai un fetish cu nuntile, cu furatu\' miresei sau pur si simplu iti place sa te invarti in cercuri elegant imbracate? :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5548,631,'sktes','sktes_2002@yahoo.com','http://sktes.wordpress.com/','79.113.137.88','2007-09-07 03:10:57','2007-09-07 01:10:57','Bre\'. d\'aia nu gasii tu azi drumu spre otograph? Ca nu te vazui prin zona zonala a zonei. Pacat .. fu\'tare :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5721,637,'DÃ£nilÃ£','','','84.232.159.225','2007-09-14 00:26:50','2007-09-13 22:26:50','Fain, da\' la aia cu coperta de revistÄƒ ai supralicitat! Acum tÄƒte o sÄƒ se creadÄƒ dimineaÅ£a cel puÅ£Ã¢n la fel arÄƒtoase ca Cindy Crawford... Nici vorbÄƒ sÄƒ fie aÅŸa...  Nu le mai bÄƒga prostii Ã®n cap!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.4','',0,0),(5634,633,'Greuceanu','','','89.21.118.42','2007-09-11 14:31:19','2007-09-11 12:31:19','mah... apropos de mirese..... cica daca visezi mireasaaaa...... ai parte de moarte.... sa jtiti ca sunt vreo 2 ani de cand m-am visat mireasa.... da\' sa nu ziceti la nimeni.... ca s-ar putea sa-mi interpreteze visul in fel sh chip! parol! fara interpretari!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(5708,637,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','86.105.72.125','2007-09-13 19:48:25','2007-09-13 17:48:25','Geez, numa de asta-mi vorbeste, io cred ca i s-o stricat placa de pick-up!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5709,637,'Miruna','mirunavasilescu@yahoo.com','','86.106.59.163','2007-09-13 19:53:11','2007-09-13 17:53:11','Maica-mea de la o vreme a trecut la artileria grea, gen \"maine poimaine mor si nu apuc sa ma vad bunica\"...ehee, ce stii tu...santaj sentimental profesionist.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5710,637,'laurie','','','69.131.175.190','2007-09-13 20:13:13','2007-09-13 18:13:13','nea gropare, cine canta melodia aia faina dedicata tziganiazilor la radio cj?\r\nfain scris-ai de muieri, btw',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5711,637,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','86.105.72.125','2007-09-13 20:18:13','2007-09-13 18:18:13','Ternipe, Nelu, Ternipe :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5712,639,'oitza','oitza@yahoo.com','','24.17.110.178','2007-09-13 20:23:10','2007-09-13 18:23:10','\"hai s-o luam asha\" : alina radea tot aiurea...cam enervant',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(5713,637,'laurie','','','69.131.175.190','2007-09-13 20:33:40','2007-09-13 18:33:40','nelu? anyway, thanx gropare. \r\nps e o placere sa te-ascult (no acuma poti roshi un pic)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5714,637,'baghy','baghy83@lycos.it','http://www.baghy.info','78.12.5.205','2007-09-13 21:22:11','2007-09-13 19:22:11','Gropare ai spart topurile cu postul asta.iti dai seama ca trebuie sa-i dau linkul prietenei mele ca sa o impresionez?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; it; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.6','',0,0),(5586,630,'nenea cosmos','','http://neneacosmos.wordpress.com/','86.35.29.2','2007-09-09 23:37:50','2007-09-09 21:37:50','vericule, se putea mai rau decit sa o zici pe aia cu canceru. te consolez eu. pai erai pe scari, da? pai daca erai cu ea in lift si dadeai o basina? atunci sa te vad ce mai ziceai. se poate si mai rau. zi mersi ca erai pe scari... nu tre sa folosesti armamentu, stai cuminte. fa 5 flotari daca ti-a venit chefu de penitenta. uite la ciutacu, bine ca avea gura plina si nu l-a injurat pe tinu...',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(5585,631,'nenea cosmos','','http://neneacosmos.wordpress.com/','86.35.29.2','2007-09-09 23:25:32','2007-09-09 21:25:32','mi-a zis mie una andreea ca esti de belea si sa intru pe blogu tau ca astia la cluj sint altfel. nu sint altfel ca am fost eu la cluj si erau tot de astia ca la bucuresti, cu miini, picioare si haine pe ei. uite imi luasem cratita cu fasole in fata la monitor ca acuma am de la plat si incape si cratita in fata tastaturii, scriu asa, cu cratita intre miini, ma-ntelegi, uite acuma mai bag stinga la fasole, e buna, are si niste carne, si cum iti zic eu, asa aflu ca ai alunecat pe sapun. ca faci dush dimineata e clar ca esti nitel ciudat, eu doar ma spal la cur dupa ce ma cac, nu pricep ce motiv ai tu de te speli tot, cumva te caci in sus? nu cred, ca ne-ai fi zis. Bine ma, da sa dai cu sapun e deja exces. daca pui poze atunci sa le pui pe rotten.com. sa ii zici lu andreea sa nu imi mai dea adrese de astia ca tine ca sinteti prea dilii. auzi, sapun dimineata... pai tu pina la virsta asta n-ai mai alunecat niciodata pe sapun? imposibil. Da sa nu elimini tu cauza ma? iti zice ingineru ce sa faci daca tot insisti cu fitze de astea, baga cu sapun lichid nenicule, e de mare viitor, eu inca n-am alunecat pe sapun lichid, ma rog, cind il folosesc, la ocazii, ia citeste ca sa faci in felul urmator: umpli cada, pui niste sapun lichid, agiti nitel cu mina si te bagi inauntru in apa. fumezi o tigara, te scarpini la coaie si iesi. treaba buna.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(5553,628,'ania','soredarkshines@gmail.com','http://aniakhaki.blogspot.com/','89.123.99.138','2007-09-07 07:45:11','2007-09-07 05:45:11','asa asa...de-a lungul! remember kids, down the road...not across the road! :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5554,632,'Sa vina Robbie Williams','robilica@yahoo.com','http://robbie-williams.blogspot.com','213.157.188.71','2007-09-07 09:29:17','2007-09-07 07:29:17','sa se imbrace ciutacu in portocaliu si sa pupe poza cu basexu daca vrea mireasa inapoi!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5555,628,'Sa vina Robbie Williams','robilica@yahoo.com','http://robbie-williams.blogspot.com','213.157.188.71','2007-09-07 09:30:40','2007-09-07 07:30:40','acum depinde... daca nu o tai la timp cand ii vine barbatu acasa.... taie el ce vrea... si nu cred ca ii maioneza',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5556,631,'VIPu','robilica@yahoo.com','http://vipuri.blogspot.com','213.157.188.71','2007-09-07 09:35:38','2007-09-07 07:35:38','ei ma! nu puteai face si tu un rezumat: \"am facut dush, am cazut, am dat cu capu si am fost la spital. nu am nimic.\"\r\n\r\ntrebuia sa scrii 5 ecrane sa imi chiunui eu ochii... ce om, ma! da la tat rau si-un bine... am ras cu lacrimi :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5557,632,'Alexandra','alex.groza@gmail.com','http://alexis-design.info','82.77.126.90','2007-09-07 10:12:41','2007-09-07 08:12:41','Eu sper sa nu fie cu multe \"furturi\", in rest... i`m sure ca o sa ne bem mintile ;)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5665,638,'De aia','ww@yhaoo.com','http://de-aia.blogspot.com','89.137.116.8','2007-09-12 18:07:55','2007-09-12 16:07:55','o sa rupi gura targului. creste audienta cu 500% ma :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.2) Gecko/20070219 Firefox/2.0.0.2','',0,0),(5695,639,'Miruna','mirunavasilescu@yahoo.com','','86.106.59.163','2007-09-13 18:28:49','2007-09-13 16:28:49','Tipa are voce misto dar pare cam de plastic asa (mai putin cand se detensioneaza brusc si zice \"aoleuuu\") insa e fata buna :))... si domnu\' Radu care n-a facut cursuri de dictie cu creionul in dinti pare pe alocuri cam self-conscious dar de pe la minutul 40 a fost mai ok, iar pentru un first-timer la radio s-a descurcat admirabil.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5696,637,'tedynecula','masterdirectortedy@yahoo.com','http://tedynecula.arhi.tv','86.120.95.75','2007-09-13 18:52:27','2007-09-13 16:52:27','GG!!  foarte marfa, l-ai luat :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5697,637,'De aia','assw@yahoo.com','http://de-aia.blogspot.com','89.137.122.75','2007-09-13 18:53:43','2007-09-13 16:53:43','ma, io presimt ca tu vrei sa te insori!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.2) Gecko/20070219 Firefox/2.0.0.2','',0,0),(5698,639,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','86.105.72.125','2007-09-13 18:54:10','2007-09-13 16:54:10','@ irina: da, mai mult os decat hai\r\n\r\n@ miruna: fata de la radio lucreaza la radio public, sh bag sama ca nu putea sa vorbeasca cu tulai sh ioi prea mult :D sh mai ie o faza: io am emisiune zilnica la radio, deci iti dai seama ce sanse are cariera mea mediatica sa o depaseasca pe a lu\' Andrei Gheo\' :((',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5667,638,'Tetelu','fds@yahoo.con','http://www.google.com','89.37.75.46','2007-09-12 22:27:46','2007-09-12 20:27:46','gropare te-am ascultat la radio si ai fost demential. cred ca ar trebui sa iti faci emisiune propie la radio.\r\nPS: ascultatorul ala maghiar a fost tare haios',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5732,637,'Andreea MKT','supergirgir@yahoo.com','http://marlahermina.deviantart.com/gallery/','82.77.126.254','2007-09-14 11:06:00','2007-09-14 09:06:00','de il iubesc pe radu:))\r\n\r\n1.ca ii vad spatele din birou de la mine cum se incovoaie cand acceseaza site-uri de alea ruisinoase.\r\n2.pt ca are shivite blonde naturale anapoda (!!!)\r\n3.pt ca stie ca nu il pup in fund\r\n4.pt ca trebe sa ii dau 200 000 \r\n5.pt ca imi dadea tigari si ma intreba daca nu imi trebe si bricheta.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(5694,639,'irina','irinamimoza@yahoo.com','','86.121.19.18','2007-09-13 18:19:51','2007-09-13 16:19:51','cred ca lu tanti aia care ti-a luat interviu i-a placut de tine. nu-i nimic, oricum esti haios.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5669,638,'that is me...','cinderellafla_tab@yahoo.com','','89.123.205.213','2007-09-12 22:58:05','2007-09-12 20:58:05','a fost super emisiunea!!!!!!  \r\nimi place gandirea ta... si esti funny!\r\n   bye',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; FunWebProducts; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) )','',0,0),(5670,638,'Adi Calarasu','acalarasu@gmail.com','http://adriancalarasu.wordpress.com','89.32.19.126','2007-09-12 23:03:03','2007-09-12 21:03:03','Am inregistrat emisiunea.\r\nDaca vrei o urc maine pe ueb ca sa o iei, Gropule ;)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(5691,639,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','86.105.72.125','2007-09-13 17:14:54','2007-09-13 15:14:54','Da! Sh faza e ca la faza asta nu pot da vina pe nimeni, asa cum fac eu de obicei cand ceva nu merge bine :|',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5730,637,'ARHI &raquo; De ce iubim femeile','','http://www.arhiblog.com/de-ce-iubim-femeile','208.116.62.218','2007-09-14 10:08:54','2007-09-14 08:08:54','[...] ce le iubim, Groparu style. Dude, la primul paragraf eam de facut un comentariu. Staim ca palmele lor reci au nevoie de caldura [...]',0,'1','Incutio XML-RPC -- WordPress/2.2.3','pingback',0,0),(5731,637,'Ostrogotul','a.patru@gmail.com','http://ostrogotul.deviantart.com','194.102.180.216','2007-09-14 10:51:47','2007-09-14 08:51:47','ioi...gropare...e grav! Mey, tu esti indragostit rau!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5672,638,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','86.105.72.125','2007-09-12 23:40:06','2007-09-12 21:40:06','@ all: deci ba, io apreciez foarte mult ca incurajati in halu\' asta un crier care sireacu\' se tat chinuie, mah, sa faca gimnastica! CÄƒlÄƒ\', vreau mah, vreau! :D vezi ca iti las comentariu cu ID-ul lu Groparu (pe care-l cunosc foarte bine) pe saitu\' tau, care de fapt ruleaza.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5690,639,'conia','','','193.226.17.210','2007-09-13 16:33:58','2007-09-13 14:33:58','Un pic balbait...dar merge...',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(5684,638,'Marius','pop.marius@gmail.com','http://Lityx.blogspot.com','89.123.117.188','2007-09-13 12:07:23','2007-09-13 10:07:23','Deci... emisiunea la download? Unde? Cand?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5686,638,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-09-13 14:23:15','2007-09-13 12:23:15','Deci ba, sper ca azi sa rezo\' :) Si va inteleg nerabdarea sa ascultati un Gropar care se da in stamba pe FM, ca mie deja mi-i frica ca o sa ajung la Carcotashi, noroc ca nu-s celebru, ca alfel aveau aia material de 4 emisiuni...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5715,639,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','86.105.72.125','2007-09-13 21:33:26','2007-09-13 19:33:26','@ oitza: deci nu ea radea asa, io radeam. Da, asa e rÃ¢su\' meu.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5716,637,'Emaginatoru','e_magist@yahoo.com','','79.113.140.89','2007-09-13 22:49:45','2007-09-13 20:49:45','Sublim.\r\nTrebuia sa nu permiti comentarii la postarea asta.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1)','',0,0),(5717,637,'ania','soredarkshines@gmail.com','http://aniakhaki.blogspot.com/','89.123.64.19','2007-09-13 23:20:06','2007-09-13 21:20:06','apai... daca de regula am ochii mari... la postul asta s-au facut si mai mari :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5718,639,'milanesta','ana_stefanaaa@yahoo.com','','89.34.180.55','2007-09-14 00:09:47','2007-09-13 22:09:47','Mie mi-a placut :D . Eu de obicei butonez radioul non-stop , fiindca niciodata nu e nimic interesant pe nici un canal, dar aseara m-am oprit pe Radio Cluj  ( desi nu stiam cine esti :D ) si am rezistat sa nu schimb frecventa pana la capat :D ..... A fost interesant sa te ascult :) ....m-au binedispus povestile tale ....ar trebui sa te auzim mai des pe la radio :)',0,'1','Opera/9.10 (Windows NT 5.1; U; en)','',0,0),(5719,639,'milanesta','ana_stefanaaa@yahoo.com','','89.34.180.55','2007-09-14 00:11:05','2007-09-13 22:11:05','Si acuma bineinteles ca m-am apucat sa iti citesc tot ce ai scris pe blog :D ....si rad non-stop :D',0,'1','Opera/9.10 (Windows NT 5.1; U; en)','',0,0),(5700,637,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','86.105.72.125','2007-09-13 19:01:37','2007-09-13 17:01:37','@ omu cu nume de suc pentru copii: l-am loat, da era prea greu sh m-o strivit\r\n\r\n@ de ailanta: deci ne potolim, da?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5701,639,'Miruna','mirunavasilescu@yahoo.com','','86.106.59.163','2007-09-13 19:07:35','2007-09-13 17:07:35','=))=)) hai c-am facut-o de oaie =))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5702,637,'De aia','assw@yahoo.com','http://de-aia.blogspot.com','89.137.122.75','2007-09-13 19:24:43','2007-09-13 17:24:43','asa credem... ca ne insuram si ne potolim... cand colo ne potolim pe dracu! putem de muiere?! aia di ce ii acolo, plasa di ce ii pe cuier, hainele de ce ti-s aruncate pe pat? etc etc etc\r\n\r\nam vre noi sa ne potolim... las ca vezi tu gropare... da macar io iti spui ca sa stii de acum sa nu fii dezamagit dupa insuratoare :P de nu ma crezi intreaba pe altii pe la care ai mai fo\' la nunti.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.2) Gecko/20070219 Firefox/2.0.0.2','',0,0),(5703,637,'De aia','assw@yahoo.com','http://de-aia.blogspot.com','89.137.122.75','2007-09-13 19:26:04','2007-09-13 17:26:04','si mie stii numa di ce mi-a parea rau?!... ca s-a alege prafu de campionii astia  de care zici in titlu blogului...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.2) Gecko/20070219 Firefox/2.0.0.2','',0,0),(5704,637,'Miruna','mirunavasilescu@yahoo.com','','86.106.59.163','2007-09-13 19:31:04','2007-09-13 17:31:04','Deci \"iubim femeile numa\' nu dam cu subsemnatu\' la starea civila\"? :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5705,637,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','86.105.72.125','2007-09-13 19:33:14','2007-09-13 17:33:14','@ de aia: =)) deci mo, io de fiecare data cand ii intreb p-astia insurati daca is fericiti, ori imi evita privirea si schimba subectu\', ori ii dau un bip la nevasta sa ii sune ea (ca el are prepay, ea are abonament), si o intreaba: \"draga mea, ma intreaba groparu daca suntem fericiti, ce am voie sa declar?\"',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5706,637,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','86.105.72.125','2007-09-13 19:38:04','2007-09-13 17:38:04','@ Miruna: Geez, what is wrong with you people? V-o mituit maica-mea sa ma batetz la cap?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5707,637,'Miruna','mirunavasilescu@yahoo.com','','86.106.59.163','2007-09-13 19:42:22','2007-09-13 17:42:22','A, nu nu, dimpotriva, ca si eu, vorba aia, incerc sa aman momentul cat mai mult, mie imi convine asta cu iubitul de la distanta. Si mama ta face presiuni? :(',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5338,623,'angel','elena.siriteanu@yahoo.com','http://leoaica.wordpress.com','82.77.83.83','2007-08-31 13:03:07','2007-08-31 11:03:07','sa-i traiasca! cat anisori are Medeea?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(5339,623,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-08-31 13:29:51','2007-08-31 11:29:51','Mo, sa le! Medeea are 2 anishoare, sh uit-o cat e de frumoasa, ii aia din dreapta, ca ailanti doi din stanga is nepotii lu unchiu\', care unchi e io: http://www.groparu.ro/wp-content/uploads/2007/08/untitled.JPG',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5340,623,'Skinner','chiujdea@gmail.com','http://ask.com','79.113.133.16','2007-08-31 13:43:57','2007-08-31 11:43:57','felicitari lui greuceanu!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5342,623,'sabina','','','81.12.163.178','2007-08-31 14:33:50','2007-08-31 12:33:50','mama-Doamne cat sunteti de unul al altuia!!! n-am mai vazut asa ceva in viata mea! :) fainilor! pup greuceanu si famelia.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(5539,628,'Miruna','mirunavasilescu@yahoo.com','','86.106.59.163','2007-09-06 19:53:02','2007-09-06 17:53:02','La maioneza merge tot de-a lungul?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5674,638,'macabroo','raduccc@yahoo.com','http://rezistenta.blogspot.com','82.76.52.94','2007-09-13 00:25:20','2007-09-12 22:25:20','Bai deci cu tristetete in suflet declar ca aici la Bucuresti nu s-a prins Radio Cluj din cauza de.... intereferente. De fapt mint si am fost sa beau ca porcu. Doresc reluare, ofer interes.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5682,638,'10MBC','alin.banc@gmail.com','http://www.maestral.ro','217.156.21.3','2007-09-13 11:08:38','2007-09-13 09:08:38','si eu vreau emisiunea. adi calarasu, o pui pe un ftp sau ceva sa o iau?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5584,632,'nenea cosmos','','http://neneacosmos.wordpress.com/','86.35.29.2','2007-09-09 21:06:44','2007-09-09 19:06:44','acu\' daca jolicu e nasic ma vad nevoit sa il invat o treaba buna. Tre sa aiba in buzunaru din stinga snopu de bancnote de 1 leut si in ala din dreapta cascavalul ala bunu\'. asta ca sa nu ajunga ca mine sa bata tiganii in fata bisericii ca n-are schimbat si e prea chitros ca sa le dea melioane. in plus, indiferent ca nunta e nordista sau sudista formatia de rithm&amp;pupu care o sa va enterteimenteze acolea o sa zica la un moment bine definit un slagar de mare angajament numit nuneasca. acolo stie aia o meserie de se opreste hora exact cu ciutacu linga gurist(a). e momentu cind nasu scoate mormanu de bancnote de 1 leu, se uita in ochii intregii formatii, e psihologic, ma-ntelegi, baga la loc si scoate de aia de 100. ii disciplineaza instantaneu.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(5541,628,'Mana','mariana.ciutacu@gmail.com','','81.12.224.196','2007-09-06 20:28:22','2007-09-06 18:28:22','Cred ca tu ai plecat de la dilema: \"Sa-mi tai venele sau sa mi le las lungi?\"...',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 2.0.50727; InfoPath.1)','',0,0),(5542,631,'baghy','baghy83@lycos.it','http://baghy.info/','78.12.19.252','2007-09-06 21:24:30','2007-09-06 19:24:30','Insanatosire grabnica.Si hai cu pozele:)))',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(5543,628,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','86.105.72.125','2007-09-06 22:09:12','2007-09-06 20:09:12','@ Miruna: mere de-a adancu\'.\r\n\r\n@ WoMana: apai daca pe bigudie nu mere...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5544,631,'InSiDeR','johndoe13.2004@gmail.com','','82.78.113.28','2007-09-06 22:20:09','2007-09-06 20:20:09','=)) sanatate',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5545,632,'Andrei Crivat','andrei@andreicrivat.ro','http://www.andreicrivat.ro','89.137.98.13','2007-09-06 22:38:04','2007-09-06 20:38:04','sa-ti explic, ma: daca IO vin la nunta, pica toate traditiile, ideea fiind asa: cand sudistii nu pricep nimic, le zicem c-asai obiceiu\' la noi, in Ardial. Cand ardelenii nosti nu pricep nimic, le zicem ca deh, asa-i la miticii aia... si ii pacalim pe toti, si n-o sa fie nici o traditie si noi ne dicstram si ne bem mintile, ma\r\nmno, ashe de marfa, moshule',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727)','',0,0),(5726,637,'macabroo','raduccc@yahoo.com','http://rezistenta.blogspot.com','80.96.196.2','2007-09-14 08:39:51','2007-09-14 06:39:51','Miroase a post cu dedicatie si iz de cenusa in cap pnetru ca Groparu a facut ceva rau. Daca ma insel, gg.',0,'1','Opera/9.23 (Windows NT 5.1; U; en)','',0,0),(5727,637,'Cristina','csoric_cristina@yahoo.com','http://www.eco-montan.info','86.107.116.11','2007-09-14 08:41:12','2007-09-14 06:41:12','Dupa lecturarea cuvintelor si afirmatiilor tale de mai sus, am ajus la concluzia ca trebuie sa fii intalnit numai femei extraordinare in cursul vietii tale, iar iubita ta este cu adevarat Speciala !\r\n Eu personal, m-am regasit in fiecare paragraf al tau. Bravo',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(5492,630,'Victor Ciutacu','victor@ciutacu.ro','http://www.ciutacu.ro','86.35.134.106','2007-09-05 22:58:25','2007-09-05 20:58:25','Ia d\'aci:\r\n- Sprit in asa-zisa lume oarecum buna, de obicei nu merg, la asta am zis ca merita sa pierd doua ceasuri dupa emisiune.\r\n- Ajung acolo, lumea era deja rezolvata, ma asez rupt de foame langa niste cunoscuti; in dreapta mea, o femeie ce-mi parea cunoscuta.\r\n- Halesc niste mici, execut bere &amp; whisky, imi iau moaca uman-satisfacuta, ne dam la barfa.\r\n- Intrebare de baraj: Ciutacule, de ce-ai plecat de la Adevarul (preistorie)? Ca m-a curatat Tinu, raspund candid. Omu\' din fatza mea izbucneste intr-un ras aproape isteric, eu ma uit lung, el se opreste si-mi explica: eu sunt gineri-sau, iar duduia de langa tine e fix Ana Maria, fie-sa si nevasta-mea.\r\nTe-am umilit?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; FunWebProducts; SIMBAR={3D633094-9EA0-411c-9B30-8FEB3C2546B8}; .NET CLR 1.1.4322)','',0,0),(5493,622,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','86.105.72.125','2007-09-05 23:22:32','2007-09-05 21:22:32','Mo, nuz din Ciznadie, is din Poplaca (Turnisor) + Dragasani (Madulari) = Sibiu (Vasile Aaron).\r\n\r\nAm zis tat?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5200,613,'Lumi','luminicoara@yahoo.com','','89.123.98.14','2007-08-27 21:11:52','2007-08-27 19:11:52','Iti multumim din suflet pentru urari . Ne-a distrat pe cinste  ceea ce ai povestit .Suntem flatati ca te cunoastem si ca te-am avut nuntas. Sa nu te lase inspiratia niciodata!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows 98; t20010828)','',0,0),(5630,633,'sweeper','ak70g2@gmail.com','','86.104.255.87','2007-09-11 06:46:33','2007-09-11 04:46:33','Groparu = Ebola, Anthrax &amp; Margburg virus combined. Tre\' sa-mi schimb dracu\' biroul...',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; .NET CLR 2.0.50727)','',0,0),(5631,633,'mumuland','','','80.97.64.199','2007-09-11 07:23:53','2007-09-11 05:23:53','faina remarca die la final....sa nu uiti Darie sa nu uiti....pientru cine mai deschidie chito cartie si nu asteapta cu sufletul la gura nou episod dhin iubirea nu stiu cui si neveste ne-cococsite :))\r\n...binie ca te-ai distrat   la nunta...io nu iubesc nuntile.\r\n\r\niz io ma.care io? asta :  ;)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12','',0,0),(5632,633,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-09-11 10:09:40','2007-09-11 08:09:40','@ Robbie Williams Renault: nasu\' o cinstit cu o punga de fulgi de porumb, un abonament pe viata la Jurnalul National, un post de parlamentar european pt. Crivatz sh o imprimerie de bani. Atata am vazut io.\r\n\r\n@ Da aia: mo, deci taiai paragrafe, si cand colo, ce sa vezi! pana dimineatza, paragrafele ramase s-or combinat si le-or nascut la loc pe alea taiate!\r\n\r\n@ Miruna: nush daca nu cunva n-avea si ceva guma de mestecat prin scuipatu\' ala.\r\n\r\n@ Sweeper: tot, plus virus de calculator!\r\n\r\n@ mumuland: nicio nu iubesc nuntile, ca Groparii nu are ce face la nunti, da\' intr-o buna zi am sa iubesc o mireasa! (sper)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5624,633,'De aia','ww@yhaoo.com','http://de-aia.blogspot.com','89.137.116.8','2007-09-10 22:31:40','2007-09-10 20:31:40','miruna, nu ai consistentza ca sa zic asa... :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.2) Gecko/20070219 Firefox/2.0.0.2','',0,0),(5689,638,'mishu','mishu@doingtheartwork.com','http://www.doingtheartwork.com','82.77.126.254','2007-09-13 15:31:38','2007-09-13 13:31:38','Quote: \r\n\"ss Says: \r\n\r\napai uite ca incet-incet tot cresti in celebritate. si in curand o sa ajungi atata de celebru ca o sa trebuiasca sa vorbesti numa frumos, ca la emisiune, si o sa trebuiasca sa renunti la betii si alte cele ca or fi toti cu ochii pe tine.\"\r\n\r\nDumnezeu e sus si bun si vede si o sa ne ramana numai noua de baut ca L-a ajuta pe-aiest minunat groparucu mamii sa se lase de vicii... sau sa le lase altora.\r\n\r\nIo-ti tin pumnii ma, s-ajungi celebru. De cand caut pe cineva pe spatele cui sa imi fac cariera :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5679,638,'mumuland','','','80.97.64.199','2007-09-13 07:46:47','2007-09-13 05:46:47','bine ma si tu cu emisiunea ta ...sh io care ti credeam serios .  :))...evident can nu te-am ascultat ca erau 2 meciuri la tv da lasa ma ca ai fo tare...........\r\n\r\n\r\niz io ma.care io asta :  ;)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12','',0,0),(5688,638,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-09-13 15:30:45','2007-09-13 13:30:45','Deci io fug de celebritate ca de spovedanie!\r\n\r\nNa, uite, prima bucata e sus.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5681,638,'Adi Calarasu','acalarasu@gmail.com','http://adriancalarasu.wordpress.com/','62.217.241.242','2007-09-13 10:21:03','2007-09-13 08:21:03','@Gropu\r\nNormal ca pagina mea ruleaza, doar ma invart zilnic pe acolo!\r\nHai ca vedem cum facem, am o fila.aac de 50mb si cu durata de 115 minute, cat a tinut emisiunea. De o calitate exceptionala, am ripuit stream cu stream, ma.\r\nSi stii ce-i senzational? Trebuie sa te auzi asta, ma, stii ce voce tanara ai ?!?!  :))',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(5675,635,'baghy','baghy83@lycos.it','http://www.baghy.info','78.12.5.205','2007-09-13 00:55:23','2007-09-12 22:55:23','si nu are poze de la nunta? :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; it; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.6','',0,0),(5621,633,'Robbie Williams','asdwww@yhaoo.com','http://robbie-williams.blogspot.com','89.137.116.8','2007-09-10 19:09:17','2007-09-10 17:09:17','da ma, zi-ne cat o cinstit ciutacu sa vedem cum sta psd-u cu fondurile. daca-i in revenire sau ii tot la fund :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.2) Gecko/20070219 Firefox/2.0.0.2','',0,0),(5488,630,'mumuland','','','85.204.38.37','2007-09-05 19:47:51','2007-09-05 17:47:51','puteai sa ii spui bietei femei bolnave si cuvintele : zi sa mori tu ca ii ase... era si mai rau...\r\nda ce ai facut tu e foarte greu de iertat fiule ase ca sa iti scriu un nr de cont unde sa depui fo 10000 de parai americani europeni  ce vrei...k sa fii iertat ?hai nu te traje pe cur ca vb aia tai batut joc de un bolnav pe patu de moarte............\r\n\r\niz io ma .care io? asta : ;)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(5622,633,'De aia','ww@yhaoo.com','http://de-aia.blogspot.com','89.137.116.8','2007-09-10 19:12:13','2007-09-10 17:12:13','gropare, mai taie niste paragrafe ca ii pre mult de citit. scrii tu fain... da ii pre mult.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.2) Gecko/20070219 Firefox/2.0.0.2','',0,0),(5623,633,'Miruna','mirunavasilescu@yahoo.com','','86.106.59.163','2007-09-10 22:15:51','2007-09-10 20:15:51','Eu un singur lucru n-am inteles: cum sa lipesti margelele cu scuipat? Ca si eu am incercat intr-o noapte si nu mi-a iesit, doar cu guma de mestecat am izbutit.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5728,639,'Hammer','hammer@alpinet.org','','86.120.55.79','2007-09-14 09:50:41','2007-09-14 07:50:41','Multumesc pt postare, le-am ascultat, chit ca a trebuit sa imi fac un cont si acolo;)\r\nMi-a placut emisiunea!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(5645,636,'mumuland','','','80.97.64.199','2007-09-12 09:43:17','2007-09-12 07:43:17','io nyus cu politica da va zac mai ales lu: de aia... :) punete ma tu de prezedinte sau dak nu adul pa tatatau.ce naiba.? vi dor de iliescu?..basescu e excelent.e mitocan.habar nu are pe ce lume e.ase ca lumea nu se asteapta la multe de la el.... si mai lasatima ma cu udrea .ce tata tzara asta are fantezii sexuale cu ea ? si li ciuda ca basescu ii da ...ce ii da ca nu stiu dastiu ca incepe cu   m... :))\r\nno ase.si mie mi ciuda .pa  keo ala.de ce? ca io traje lu andreea balan...............no ase.\r\n\r\n\r\niz io ma .care io?  asta:  ;)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12','',0,0),(5687,638,'ss','criss_team@yahoo.com','','81.196.150.198','2007-09-13 14:57:56','2007-09-13 12:57:56','apai uite ca incet-incet tot cresti in celebritate. si in curand o sa ajungi atata de celebru ca o sa trebuiasca sa vorbesti numa frumos, ca la emisiune, si o sa trebuiasca sa renunti la betii si alte cele ca or fi toti cu ochii pe tine.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7','',0,0),(5477,630,'Miruna','mirunavasilescu@yahoo.com','','86.106.59.163','2007-09-05 14:24:56','2007-09-05 12:24:56','Esti odios!  Numa\' ce te-ai facut cu un cititor in plus. La blogroll te bag, pe onoarea mea!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5479,630,'Sa vina Robbie Williams','robilica@yahoo.com','http://robbie-williams.blogspot.com','213.157.188.71','2007-09-05 15:15:25','2007-09-05 13:15:25','lasa ma ca ii ok. toata lumea stie despre ce ii vorba. la fel o stiut si fata. is sigur ca nu s-o suparat :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5480,629,'Sa vina Robbie Williams','robilica@yahoo.com','http://robbie-williams.blogspot.com','213.157.188.71','2007-09-05 15:17:49','2007-09-05 13:17:49','sa ne zici si noua unde putem vedea filmu cu groparu starlet :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5482,630,'ania','soredarkshines@gmail.com','http://aniakhaki.blogspot.com/','89.123.77.130','2007-09-05 15:58:48','2007-09-05 13:58:48','las ca se mai intampla...nu te impusca...ca raman eu fara material de lecturat :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5209,613,'mishu','mishu@doingtheartwork.com','http://www.doingtheartwork.com','82.77.126.254','2007-08-28 09:03:38','2007-08-28 07:03:38','Lumi di ce te-ai fo maritataraaaaaaaaaaaaaaaaaaaa?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5494,630,'Anton','ovidiusimuvoina@yahoo.com','','83.103.132.201','2007-09-05 23:24:15','2007-09-05 21:24:15','ooo, crede-ma, nu doar tu ai putea sa faci asa ceva... mai sunt si altii...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(5654,638,'Hammer','hammer@alpinet.org','','86.120.55.79','2007-09-12 14:31:18','2007-09-12 12:31:18','Brava , faina treaba. Da\'... di ce?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(5655,638,'ss','criss_team@yahoo.com','','81.196.150.198','2007-09-12 14:35:24','2007-09-12 12:35:24','ca sa comentezi germania-romania?\r\nhai ca te ascultam, sa dai numa o dedicatie pentru toti 3 cititorii tai de pe blog, fara numar! fara numar!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7','',0,0),(5650,634,'ania','soredarkshines@gmail.com','http://aniakhaki.blogspot.com/','89.123.65.233','2007-09-12 11:45:36','2007-09-12 09:45:36','=))))))))))))))))))))))))))))))))))))))))))))))))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5649,634,'macabroo','raduccc@yahoo.com','http://rezistenta.blogspot.com','80.96.196.2','2007-09-12 10:44:54','2007-09-12 08:44:54','Errgh....Imi cer scuze gen... ar trebui sa-mi fac blog sau ceva...gen',0,'1','Opera/9.23 (Windows NT 5.1; U; en)','',0,0),(5729,637,'mishu','mishu@doingtheartwork.com','http://www.doingtheartwork.com','82.77.126.254','2007-09-14 10:06:15','2007-09-14 08:06:15','Cristina, atunci trebuie sa ne cunoashtem!!! Eu vreau sa va spun ca sunt un magar insensibil la posturi din astea siropoase dar sa stiti ca si mie imi sta bine cu parul ud :))\r\n\r\nPS: Va dau o informatie neoficiala dar aflata din surse sigure: Groparul se insoara maine, cununia civila va avea loc cu incepere de la ora 12 la Casa de Cultura A Shtudentilor din Cluj. Be there!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5725,637,'sweeper','ak70g2@gmail.com','','86.104.255.87','2007-09-14 06:52:52','2007-09-14 04:52:52','Bai nene: \r\n\r\n1. Casa de piatra in caz de vrei sa te insori.\r\n\r\n2. Ia vitamine, presimt c-or sa te tabare femeile...',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; .NET CLR 2.0.50727)','',0,0),(5648,634,'admin','groparu_ro@yahoo.com','http://','82.77.126.254','2007-09-12 10:42:02','2007-09-12 08:42:02','Deci ba, tu iara scrii in comentariu mai fain decat scriu io in postare?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,1),(5646,634,'macabroo','raduccc@yahoo.com','http://rezistenta.blogspot.com','80.96.196.2','2007-09-12 10:40:25','2007-09-12 08:40:25','Eu ii propun in ordinea numerelor de pe tricou pe: Catalin Botezatu la dush (eu pup poala popii popa....),  Adrian Paunescu ( are barba, profil si stie cu Secu), Nicu Gheara ( se descurca si are agentie de fotomodele divine), Traian Basexu ( o functie in plus nu strica niciodata si este un pas inainte spre dominatia mondiala) si nu in ultimul rand Gigi Becali (\"pentru ca e om bun maica\")',0,'1','Opera/9.23 (Windows NT 5.1; U; en)','',0,0),(5592,632,'Victor Ciutacu','victor@ciutacu.ro','http://www.jurnalul.ro','82.76.75.160','2007-09-10 12:22:57','2007-09-10 10:22:57','Am luat act:)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(5659,638,'Adi Calarasu','acalarasu@gmail.com','http://adriancalarasu.wordpress.com','89.32.19.126','2007-09-12 16:40:33','2007-09-12 14:40:33','oook!\r\nbine ca se poate asculta Radio Cj pe internet, ca altfel ma duceam sa cumpar din targ un radio d-ala Gloria, care numai el prindea undele alea lungi, tocmai hat, din Ardeal ;)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(5660,638,'ss','criss_team@yahoo.com','','81.196.150.198','2007-09-12 16:46:29','2007-09-12 14:46:29','nici o problema, formularea \"pentru toti cititorii mei de pe blog\" o sa fie suficienta, ca o sa sune ca la premiile mtv si o sa te simti si mai mare vedeta. si noi o sa ne ecstaziem: \"esteee! despre mine o zis groparu acuma!\"\r\nsi cand o vezi pe alina ca da disperata din maini din cauza ca nu mai reusesti sa te comporti ca un gentleman, trage aer in pept si gandeste-te ca esti fiu\' lu mama (care de fapt e-o doamna).',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7','',0,0),(5652,634,'sweeper','ak70g2@gmail.com','','86.104.255.87','2007-09-12 14:02:05','2007-09-12 12:02:05','Bre nene, io nu pot sa ma ecsprim. Dupa cum zice in Coranu\' meu din biblioteca, n-am treaba cu asta... Biblia n-am gasit-o, cred c-am uitat s-o cumpar....',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; .NET CLR 2.0.50727)','',0,0),(5653,634,'ss','criss_team@yahoo.com','','81.196.150.198','2007-09-12 14:29:27','2007-09-12 12:29:27','io o propun pe uana zavoranu pentru ca din 2 motive: \r\n1- ca numa atata i mai lipseste ei din CV (Tudor) si, de altfel, numa atata ne-ar mai lipsi si noua;\r\n2- ca-i cea mai completa: canta ca o privighetoare, n-are probleme in a se face simpatica, ruju i tine loc de barba, statuie si-ar face - n-ar zice nu, si nici n-o facut parte din securitate.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7','',0,0),(5562,626,'Andreea MKT','supergirgir@yahoo.com','http://marlahermina.deviantart.com/gallery/','82.77.126.254','2007-09-07 15:30:18','2007-09-07 13:30:18','deci in canada\r\n\r\ncum pumnul consortului atinge obrazul consoartei, consoarta face tzrrr la politie si in 4 minute, nenorocitul este legat fedelesh si dus la bulau.\r\n\r\npe mine ma bate barbatu in fiecare zi dar de fiecare data cand sun la politie la 112 ....e ocupat.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(5561,631,'Greuceanu','','','89.21.118.94','2007-09-07 14:38:01','2007-09-07 12:38:01','MO, mare vaka ejti!  tu ce dreq ajteptai?! hugh?! sa te bage tat de la centura in sus in gips cu mainile departate de corp in forma de cruce nemtzeasca? sa-tz infoaie capu\' cu fasha medicala sh sa-tz lase numa loc de privit sh buzele afara?! sa te duci la lucru\' sh sa zica sef\': ioi saracu\' tu\'! ui\' ni\' la iel ca sh asha rupt vine la treabaaaa..... iar toata suflarea feminina ..... care... (nu jtiu\' cum dreaqu fac mo, au un truc ele cred... adika io n-am pretentia mah sa miroase frumos dupa mine, dupa ce ies io din bae dupa ce-am dat afara tot ce-o ramas mai toxic din carne sh cognac.... ca n-are cum dreaku\' sa miroase frumos.... dar macar doresc mo sa ... nu mai miroase chiar asha tare ... ... noa... shapoi iele cum dreaku fac mah de dupa ce dau sh ele afar\' rau\', intri dupe ele in bae sh .... miroase a ... ambipur! sh te uiti in jur sh nu-i decat facaletzu\' ala de periat buda pe dinauntru\' sh un pic de hartie ijienika....numik! cum fac mo?!) iar suflarea aceea feminina sa vie la tine sh sa te mangaie pe gips, sa te pupe pe buzele alea rosii, sa te intrebe...\"da\' ce-ai patit?! ioi, saracu\' de tine.... sa vin pe la tine sa iti tiu\' de urat?!\", sa te dai jmeker cu colegii asha cum facea var\'mio intr-a treia cand sh-o rupt mana sh la toti le zicea:\"ci-i mah! ci-i! iejti jmeker?! tu vrei sa te bat cu ghipsu\'?! cand tz-oi trage un gips in cap......\", de fapt cand var,mio o ajuns intr-a shasea, mi-am rupt sh io mana.... sh jur ca a fost cea mai frumoasa zi din viata mea pana atuncea.....\"las\' mah, las\', ui\' acuma ma duc la mama sh merem la spital sa-mi puna mana in gips, aopi tz-arat io  tzieeee.....\". dar se pare ca nu prea ai avut noroc mah..... sh chestia cu gatu\' sa jti ca nu e un avantaj!  femeile cred despre ea, la fel ca sh mine, ca numa sashii aia obeji sh galbeni-albiciosi isi pot suci gatu\' intorcandu-se sa se uite in oglindaaa....',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(5656,638,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-09-12 15:09:43','2007-09-12 13:09:43','@ Hammer: Pentru a vorbi despre chestia care mie imi place cel mai mult si mai mult pe lumea asta: despre mine :D\r\n\r\n@ SS: Mo, am sa va dedic tat felu\', da\' nu o sa poci zice explicit ca ii dedic sh lui SS una-alta, ca astia or sa zica ca is nostalgic WWII, sh nu ca n-as fi! Da\' m-o rugat Alina sa ma comport ca un gentleman, si am zis ca voi face eforturi uriase.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5565,632,'baghy','baghy83@lycos.it','http://baghy.info/','78.12.19.252','2007-09-08 00:40:50','2007-09-07 22:40:50','cam asa-i la noi in Ardeal.Poarta in sat,pantof la mireasa furat si mireasa furata.Si plateste Nasu ca e din Bucuresti.Mare jurnalist si blogger',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(5591,632,'admin','groparu_ro@yahoo.com','http://','82.77.126.254','2007-09-10 11:27:59','2007-09-10 09:27:59','Da!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,1),(5590,632,'Victor Ciutacu','victor@ciutacu.ro','http://www.jurnalul.ro','82.76.75.160','2007-09-10 10:29:17','2007-09-10 08:29:17','Gropare, scrii tu primul cum e sa te-nsori in ploaie si sa ucizi DJ-ul la unspe noaptea sau o fac eu?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(5570,631,'varza','tudor.maris@gmail.com','http://rottencabbage.haipa.ro','58.106.98.229','2007-09-08 12:22:04','2007-09-08 10:22:04','Deci sa ma lamuresc: tu ai bicicleta?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5571,631,'Dany','D@yahoo.com','','86.125.118.58','2007-09-08 15:44:55','2007-09-08 13:44:55','G. Ca sa vezi ce aproape este lumea ...cealalta!!!!\r\n\r\nIo zic sa-ti scimbi numele din groparu in mansarda!\r\n\r\n nu ti juca cu predestinarea ! de fapt n-ai zis ingropatu , ii ok daca vrei tu !',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7','',0,0),(5512,630,'curioasa','totmea@yahoo.com','','86.35.232.96','2007-09-06 09:13:19','2007-09-06 07:13:19','Pai ai vorbit precum Groparu\',nu? Ai fo\' natural.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(5513,630,'angel','elena.siriteanu@yahoo.com','http://angel.saltwaterc.net','82.77.83.83','2007-09-06 09:23:58','2007-09-06 07:23:58','esti simpatic si cand ti-o ia gura pe dinainte. :)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(5514,630,'sepukku','dinamoenr1@yahoo.com','','85.120.159.10','2007-09-06 09:24:05','2007-09-06 07:24:05','aaaaaaahahahahahahahahahhah....si care a fost primu lucru pe care l-a zis femeia?trebuie sa stiu...',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0)','',0,0),(5515,630,'macchiavelli','mlkoby@yahoo.com','','87.234.61.50','2007-09-06 10:16:47','2007-09-06 08:16:47','nu meriti impuscat inca! ca sa iti castigi onoarea asta trebuie sa fie si mama fetei de fatza!\r\n\r\nKeep up the good work :)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(5516,625,'octa','octaviatarnita@yahoo.com','','86.141.44.65','2007-09-06 10:23:17','2007-09-06 08:23:17','ahahahahahahahahahahahahaha',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; YPC 3.2.0; SV1)','',0,0),(5517,630,'Victor Ciutacu','victor@ciutacu.ro','http://www.jurnalul.ro','82.76.75.160','2007-09-06 10:58:31','2007-09-06 08:58:31','@sepukku: sa nu ma formalizez, ca n-o sa ma impace ea cu tac\'su dupa moarte daca n-am reusit s-o facem in viata.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(4931,598,'Paszti','pasztorjozsef@yahoo.com','','81.12.230.166','2007-08-20 11:28:07','2007-08-20 09:28:07','Aoleu! Ala ii ceas pe care scrie care te poti scufunda pana la 200 metri? Si io am avut unul autentic chinez cu 7 melodii, si cand l-am pus in chiuveta n-o mai cantat veci.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727)','',0,0),(5657,638,'adi','adyrotaru@yahoo.com','','89.123.88.112','2007-09-12 15:49:32','2007-09-12 13:49:32','...care tu de fapt esti un gentleman...',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(5658,638,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-09-12 16:24:07','2007-09-12 14:24:07','@ adi: Nuz! Numa atata sper, sa nu iasa o emisiune din aia in care is f*** mai ceva ca un caine in picior. Picioru\' meu.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5640,636,'Miruna','mirunavasilescu@yahoo.com','','86.106.59.163','2007-09-11 22:45:55','2007-09-11 20:45:55','Afirmatia asta cu armeanu\' bun e epocala, o sa mi-o scriu in carnetelu\' ala al meu auriu cu lacatel, de notez eu expresii frumoase in el.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5637,635,'ania','soredarkshines@gmail.com','http://aniakhaki.blogspot.com/','89.123.81.65','2007-09-11 20:33:15','2007-09-11 18:33:15','iti dam dreptate :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5638,636,'De aia','ww@yhaoo.com','http://de-aia.blogspot.com','89.137.116.8','2007-09-11 21:35:15','2007-09-11 19:35:15','si o sa mai asteptam mult si bine.\r\n\r\nstii care e cel mai bun lucru pe care l-a facut basexu pana acum? a facut-o pe elena udrea din c#$*a vedeta',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.2) Gecko/20070219 Firefox/2.0.0.2','',0,0),(5520,630,'sepukku','dinamoenr1@yahoo.com','','85.120.159.10','2007-09-06 13:14:29','2007-09-06 11:14:29','nici nu mai ai cum...xD',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0)','',0,0),(5521,630,'Darius','ibrahim_rom@yahoo.com','http://jeg.ro','82.77.126.159','2007-09-06 13:20:34','2007-09-06 11:20:34','IntrÄƒ-mi pe messenger.',0,'1','Mozilla/5.0 (Macintosh; U; Intel Mac OS X; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5522,630,'Dany','D@yahoo.com','','86.125.118.67','2007-09-06 13:30:34','2007-09-06 11:30:34','Frate, \r\nnu te impusca , te rooog! mai ai o sansa, nimic nu-i pierdut, sau n-ai kert nimic.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7','',0,0),(5523,631,'sabina','','','81.12.163.178','2007-09-06 13:32:51','2007-09-06 11:32:51',':))',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(5525,629,'10MBC','alin.banc@gmail.com','','217.156.21.3','2007-09-06 13:45:03','2007-09-06 11:45:03','concluzia: Use condoms.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5526,631,'10MBC','alin.banc@gmail.com','','217.156.21.3','2007-09-06 13:47:35','2007-09-06 11:47:35','Gropare, o portie dubla de berica tripla si te-ai rezolvat.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5527,630,'10MBC','alin.banc@gmail.com','','217.156.21.3','2007-09-06 13:49:28','2007-09-06 11:49:28','Stati calmi oameni buni ca groparu nu se impusca asa usor. insa cu siguranta data viitoare nu ratez.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5528,631,'sweeper','ak70g2@gmail.com','','86.107.192.53','2007-09-06 14:10:15','2007-09-06 12:10:15','Tu vad ca ai ceva cu dezbracatu\'... O bere mare pt Groparu, fratele meu de obiceiuri!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; .NET CLR 2.0.50727)','',0,0),(5529,631,'Miruna','mirunavasilescu@yahoo.com','','86.106.59.163','2007-09-06 14:35:59','2007-09-06 12:35:59','Ma, eu cand aveam vreo 10 ani am dat cu capu\' de cada atat de tare ca am avut in locu ala o buba pana la 16 ani. Trebuia sa ma duc la doctor? Si daca ma puneau sa ma dezbrac??',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5530,631,'macabroo','raduccc@yahoo.com','http://rezistenta.blogspot.com','80.96.196.2','2007-09-06 15:26:45','2007-09-06 13:26:45','Patria vrea poze!',0,'1','Opera/9.23 (Windows NT 5.1; U; en)','',0,0),(5532,631,'ss','criss_team@yahoo.com','','81.196.150.198','2007-09-06 16:57:23','2007-09-06 14:57:23','aoleu!! vezi ce se intampla daca te arde sa te deosebesti de ceilalti si faci dush? dimineata!?!\r\n\r\n..s-apoi daca nici la raze xxx nu te-o lasat sa te despuiezi..insamna ca cu siguranta aia/alea aveau ceva cu tine impotriva.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7','',0,0),(5533,631,'ss','criss_team@yahoo.com','','81.196.150.198','2007-09-06 17:01:18','2007-09-06 15:01:18','@ miruna: de te punea sa te dezbraci clar ca era un doctor pedofil. bine ca nu te-ai dus.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7','',0,0),(5534,631,'Miruna','mirunavasilescu@yahoo.com','','86.106.59.163','2007-09-06 17:13:02','2007-09-06 15:13:02','Da, asa zic si eu. Oricum a trecut de la sine. Da\' stau prost de tot cu matematica...ma intreb daca n-o fi de atunci.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5535,631,'DÃ£nilÃ£','','','82.77.202.17','2007-09-06 17:34:36','2007-09-06 15:34:36','vez\' dacÃ£ te-ai lÃ£sat de beut si de pipat !? buba...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5536,631,'ss','criss_team@yahoo.com','','81.196.150.198','2007-09-06 17:44:04','2007-09-06 15:44:04','pai io zic asa: daca o trebuit 6 ani ca sa se vindece buba la exterior, mai trebe inca vro 6 sa se vindece si pe interior...si dupa aia creca o sa incepi sa rezolvi integrale simple. acuma ramane sa faci o diferenta intre varsta actuala si varsta de 16 ani, faci o derivata de ordinu 2 si din grafic o sa iti dai seama unde te situezi.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7','',0,0),(5558,632,'andreanum','andreanum@yahoo.com','http://andreanum.wordpress.com','194.30.177.1','2007-09-07 11:58:02','2007-09-07 09:58:02','Deci io sa stiti ca voi fi aproape de mneavuastra, in capitala Ardealului stramosesc: Budapesta. \r\nIn timp ce voi servi niscai gulash cu Tokay, am sa ma gindesc la tristetea care tre sa va cuprinda fiind nevoiti sa beti cu jegh (asta pare fraged, dar duce mult si costisitor) si mai ales cu nenea victoire, care se da genial, dar nush cit ii va prii la genoi palinca de zalau de la antementionat. Trist. De toamna. :D\r\nCasa de peatra, tizule si pupaturi viitoarei doamne. Tranzmite mata, gropare, rogu-te, ca io ma rusinez fata cu uamenii cu care nu m-am pupat in veata mea. :p',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1)','',0,0),(5538,631,'Miruna','mirunavasilescu@yahoo.com','','86.106.59.163','2007-09-06 19:51:37','2007-09-06 17:51:37','Bai deci io ma situez unde am chef, da? Si nu-mi zici tu mie cu intergale, cu derivate, cu de-alea, ca n-am ciocnit valizele in tren, da? Incredibil, unii n-au nicio limita. La munca, baa, nu la tocit scaunele in bibleoteci! Huo!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5176,610,'albanezu','mist_ab_2k@yahoo.com','','83.103.154.202','2007-08-27 09:19:29','2007-08-27 07:19:29','ma, io-s curios scaunu in varianta pentru femeei cum o fi!?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5177,612,'Adi Calarasu','acalarasu@gmail.com','http://adriancalarasu.wordpress.com','62.217.241.242','2007-08-27 09:32:43','2007-08-27 07:32:43','No, sax, ma Gropule, ca si io am fost sambata la Sibiu, ba s-un pic din duminica. Daca stiam veneam paste tine la nunta ca sa-ti demonstrez ce mica-i lumea :P',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(5110,610,'nevazatoru','versiunea2@yahoo.com','','194.102.61.162','2007-08-25 00:07:35','2007-08-24 22:07:35','Mai grav era daca aveai 3 coaie, ceea ce nu dorim nimanui...',0,'1','Opera/9.20 (Windows NT 5.1; U; en)','',0,0),(5111,608,'ania','soredarkshines@gmail.com','http://aniakhaki.blogspot.com/','89.123.74.2','2007-08-25 00:20:58','2007-08-24 22:20:58','@katmai vad ca nu te poti abtine :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5181,613,'Tudor','','http://dingrajd.blogspot.com/','89.136.23.215','2007-08-27 10:13:46','2007-08-27 08:13:46','PÄƒ mÄƒ gropare.. priveÅŸte-te la partea bunÄƒ: ai fost tÄƒt Ã®n centru atenÅ£iei! CÃ¢t despre ploaie... Ã®i mai fain sÄƒ te prinzÄƒ Ã®n vÃ¢rfu\' muntelui. Acolo sÄƒ vezi frustrare.. numa cÄƒ pe mine nu mo vÄƒst nime.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4939,597,'varza','tudor.maris@gmail.com','http://rottencabbage.haipa.ro','89.37.116.108','2007-08-20 18:41:22','2007-08-20 16:41:22','Felicitari la domnu\' gropar care e-n gura lumii in modul \"de bine\". Da am vazut in corespondenta de acolo ca esti cam ocupat.... Joi ce faci? Ca si noi astia mai ocupati am vrea sa te cunoastem, sa ii facem in ciuda lui Carpenisan dup\'aia :D Mai ales ca am auzit ca faci cinste la oameni cand te vezi cu ei..',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1)','',0,0),(5188,612,'Vlad','dez_legat@yahoo.com','','79.113.138.44','2007-08-27 12:26:34','2007-08-27 10:26:34','nu fi asa radical cu beutura si fumatu ca nu-i bine sa le lasi dintr-o data.\r\nweekendu asta si io ma duc la Ghiocelu creca....poate ne vedem prin zona',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5306,620,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-08-30 14:33:33','2007-08-30 12:33:33','@ macabroo: da, moh, da\' ui ca una dintre ele duce o viatza paralela, fara mine!\r\n\r\n@ VIPU: mo, daca dau iama prin femei iara... vezi tu numa cati razi or sa iasa!!!\r\n\r\n@ pt Robbie Williams: mo, ti-i clar ca nu am kef sa ma deconspir, da\' faza asta cu altu cu acelasi nume cu mine chiar merita sa o pun!!! C-asa mi-or zis vocile.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5253,618,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-08-29 10:23:12','2007-08-29 08:23:12','@ macabroo: da, bah, fix asta l-am intrebat si io pe fostu\' prof de romana Florescu cand ii dadeam cashu\' pe o strada laturalnica, sh stii ce mi-o zis? Stimate fost elev, nici in ziua de azi nu stiti sa folositi bine desinentzele!!! \r\n\r\n@ Iepuru: Deci sa nu ne gandim ca Groparu face asemena chestii, da? Groparu nu e pejte. \r\n\r\nPS: Nu fara un comision suficient de stimulant!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5220,612,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-08-28 13:57:31','2007-08-28 11:57:31','@ Robbie fan: Era al meu!!!!\r\n\r\n@ CÄƒlÄƒ: Mo, io ma nunteam prin Cluj-Na-Boc-a :| Numa\' sambata asta ma duc la verishoara mea la Sibiu, la nunta de marginashi, unde voi muri de ras cu var-mio injineru\', ca o sa ne dam intelectoali, hihihi!\r\n\r\n@ Vladeasa: mo, am incercat cu puterea a doua, cu numere prime, cu ipotenuze... numa cu radicalu\' creca mai reusesc! Meri la Ghio? Super tareeee\r\n\r\n@ octa: ma las, da\' dupa aia cica urmeaza lasatu\' de fomei, sh acolo kiar ca n-am de gand!!! asa ca daca nu ma las de fumat mai am asa, un buffer zone...\r\n\r\n@ sktes: e mah! fusai, sh ma distrai! mai hai',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5221,610,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-08-28 14:08:25','2007-08-28 12:08:25','@ Ciutacu: pfuaaay, ciutacu viziteaza groparu.ro! sh sh comenteaza de rÃ¢s!\r\n\r\n@ Femei: sa nu uitam ca brishca este, ca orice alta spadÄƒ, simbol falic! :D\r\n\r\n@ VIPU: VIPUle, tz-as zice ca de la lins, da mi-i asha o jenaaa...\r\n\r\n@ Radu M: nici nu stii cata dreptate ai!!!\r\n\r\n@ albanezu: sh io ma intreb, oare proeminentza seamana a putza, limba sau deshti? Ca acilea fiecare cu ce poate! (da, da, stiu, e porno comentariu\', asta e, rugati-va sa ma coc la capatzana odata)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5222,610,'Victor Ciutacu','victor@ciutacu.ro','http://www.ciutacu.ro','82.76.75.160','2007-08-28 14:48:04','2007-08-28 12:48:04','@groparu: Nevasta-mea, nasha lu\' stim noi2 cine, e mare fan de-al tau. Ca si andreanum, care te descoperi si te introduse lumea buna din satu\' cu ministri. Ele m-au molipsit:)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(5099,610,'Radu M.','radu_muri@yahoo.com','http://theblacklight.wordpress.com/','79.113.138.96','2007-08-24 19:08:36','2007-08-24 17:08:36','Locul pentru coaeh e ala mare, Gropare si pentru obrajorii posteriori sunt locurile alea mici..',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7','',0,0),(5190,612,'octa','octaviatarnita@yahoo.com','','86.132.125.152','2007-08-27 13:47:50','2007-08-27 11:47:50','lasa-te de fumat cel putin ca si eu m-am lasat!\r\nse poate!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; YPC 3.2.0; .NET CLR 2.0.50727)','',0,0),(5191,608,'Sibianca','alexa_g48@yahoo.com','','81.181.70.9','2007-08-27 14:35:06','2007-08-27 12:35:06','Si uite-asa, ma numar printre domnisoarele care nu s\'or putut abtine sa citeasca o scriere marca Groparu....',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5192,608,'Sibianca','alexa_g48@yahoo.com','','81.181.70.9','2007-08-27 14:36:53','2007-08-27 12:36:53','errata: Si uite-asa, ma numar printre domnisoarele care nu sâ€™or putut abtine sa nu citeasca o scriere marca Groparuâ€¦.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5194,609,'mishu','mishu@doingtheartwork.com','http://www.doingtheartwork.com','82.77.126.254','2007-08-27 16:08:53','2007-08-27 14:08:53','Ma gropare, spermatozoidu\' campion era ala cu \"Tradare, suntem in cur!!!\" ? ;;)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5250,618,'macabroo','raduccc@yahoo.com','http://rezistenta.blogspot.com','80.96.196.2','2007-08-29 08:36:35','2007-08-29 06:36:35','Reversul medaliei e ca intr-o noapte ploioasa si fara luna, poate peste 10 ani, poate peste 9, cand toata lumea se va fi culcat, Lucian, prietenul gelos al bunaciunii, care a fost abandonat de parintii plecati in spania si crescut de jderi, te va urmarii pe stradutele laturalnice atat de aproape incat ii vei simti respiratia in ceafa. Dupa ce iti va rupe dintii cu telefonul mai putin meserias dar cu carcasa de titaniu te va scufunda incet cu capul in baitza pasarelelor tipand din toti rarunchii \"Who\'s fucking who right now!!!?? Ia piscina de la generatia noastra ratata.\"',0,'1','Opera/9.23 (Windows NT 5.1; U; en)','',0,0),(5093,601,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-08-24 15:05:51','2007-08-24 13:05:51','@ angel: mo, deci mie imi vine sa ii bag pe toti... da\' mai bine hai ca nu mai zic nimic.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5251,618,'IepurasulAtomic','praetorian21uk@yahoo.com','','82.77.123.114','2007-08-29 08:43:48','2007-08-29 06:43:48','Gropare...stii ce vreau, nu? Hai ca stii! Ia gandeste-te tu bine bine si zi-mi! De fapt, dracu\' sa-l ia de suspans, ca ma omoara. Ma, io vreau sa te ajut! Cum? Pai nu-i clar? Din moment ce insiruirea de mai sus nu ma ajuta sa-mi exprim ideea, fac prima data o manarie(cunoscuta in termeni de specialitate si ca \"rocada\"). Hai sa manarim sa fie punctu 3 in loc de punctu\' 6. Deci da, da? Buuuun! Eh, acuma io zic ca vreau sa te ajut cu punctele 6 si 9(nu fix pe tine ma hopsedatule, ca ti-am zis ca nu-s din ala). Eu stiu ca etica nu-ti permite sa te ajuti singur cu mai sus mentionatele puncte 6(care-i manarit) si 9(care-i fix cum trebe). Stii ce vreau io sa spun prin toate astea? Stii, normal ca stii, ca doar bolnavii se inteleg intre ei. Vreau numaru\' ma...numaru\' de telefon al trufandalei de 19 ani, ca n-am mai scos asha ceva la suc, prajitura si alte violente de vreo cateva luni. Si mi-i dor ma, intelegi? Io pe bune ca-s potrivit, is in mintea lor...deci poti avea incredere in mine. Nu te fac io tocmai pe tine de ras :)). Mno, astept sa-mi scrii. Vreau asha: numar de telefon, cea mai recenta poza(da\' daca nu se poate, de la 17 ani incoace ii bine), dimensiuni(la fel, cele mai recente ori +17) si niste bani de suc, prajituri si bere(in bancnote mici, ca doar itzi fac o favoare, ce dracu\' :D).Nu uiti, bine? Si cum ziceam si alta data...Pace p\'afara! ;)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(5092,604,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-08-24 15:04:58','2007-08-24 13:04:58','Mo, deci io pe Putin o sa-l respect numa\' in clipa in care o sa-mi deie o mie de miliarde de actiuni la Gazprom, ce pana me! Ca sh asa am potential sporit de gaze naturale. Eu, de mine zic.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5841,645,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-09-20 11:53:02','2007-09-20 09:53:02','@ tetelu2: ca sa nu mai povestim despre centura Aradului, pe care Cluju\' nu o are, loc de inalta densitate de personaje care mai de care mai feminine! (asta pentru connoisseuri)\r\n\r\n@ xxx: da, este un studio, dar nu puteau filma nimic despre stele: acolo soarele rasare decat daca-l platesti.\r\n\r\n@ katmai: io zic ca cel mai linistit oras din tzara este Machu Pichu - atata numa ca nu se prea afla in tzara. Deocamdata.\r\n\r\n@ andreanum: da, faza cu tramvaiu\' e chiar dementiala, apropos, ai vazut caii de la tramvai? Ca io sh amu ma mir cum de poa\' sa marga trasura aia fara nici un atelaj. Parol.\r\n\r\n@ Hammer: Io tat zic ca Copsa este varianta romaneasca a CernobÃ¢lului, finca Ceausescu sigur o zis \"Ceeee? Va aratam ca putem fi si mai poluati decat ucrainenii!!\" Si le-o aratat...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(5843,645,'Hammer','hammer@alpinet.org','','86.120.55.79','2007-09-20 13:42:28','2007-09-20 11:42:28','Mai poluatzi si mai virili, tinand cont de kestia aia erecta numita cosh de exhaustare si de nr de puradei pe metru patrat de Copsha',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(5844,645,'andreanum','andreanum@yahoo.com','http://andreanum.wordpress.com','194.30.177.1','2007-09-20 15:30:54','2007-09-20 13:30:54','ce tramvai? io am vazut doar sinele. Am crezut ca ie sine de tren, dar cineva ne-a zis ca nu, este de tram-vai. N-am stiut ca si trece tramvaiu pe acolo, credeam ca pt deplasari exista autobuze. Si zici ca are cai? Ba, da astia de la Arad is tare evoluati, bag sama... :D',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1)','',0,0),(6009,657,'catalin','solo@xsolo.biz','http://xsolo.biz','201.231.171.199','2007-09-26 19:29:51','2007-09-26 17:29:51','Grele probleme mai sint in Romania! Uneori ma pot bucura incredibil de mult, citind \"faimoasele evenimente\" la saptamini sau niciodata. Oau, ce \"pierdere\" pt mine. Curind o sa apara bancuri cu militienii de la Politia animalelor...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(5857,647,'PhenoBarbieDoll','poisongirl94@yahoo.com','http://360.yahoo.com/poisongirl94','193.230.230.101','2007-09-21 10:00:59','2007-09-21 08:00:59','Deci Groparu se ingroapa in datorii?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(5858,647,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','86.105.72.125','2007-09-21 10:09:51','2007-09-21 08:09:51','NU! In banet se-ngroapa :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(5955,656,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','86.105.72.125','2007-09-25 20:58:58','2007-09-25 18:58:58','@ Miruna: Nij mie! Sh atata am fugit de ia... oioioi!\r\n\r\n@ ss: mo, deci se poate; ca si io ma tot intreb, ce o fost la inceput, virgina, sau fomeia? daca fomeia, din ce virgina o devenit fomee? Si daca virgina, ce femeie a nascut-o?\r\n\r\n@ kalapkura: da, sh io ash arde niscai jolidoane, dar ce te faci cu alea care deja au flacari acolo la ele, in jolidon?\r\n\r\n@ baghy: man, mai treci p-acilea, intr-o buna zi am sa dezbat sh cum se gaseste clitorisu\', ca io mai am numa\' otzara sh il pipai sh strig: EXISTAAAA!!!\r\n\r\n@ kalapkura: ma, io le am cu violu\', da numa\' cand ma aflu in partea aceea a putzulicii, stii tu, aia cu bilutzele.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(5861,647,'adi','adyrotaru@yahoo.com','','89.120.56.7','2007-09-21 11:58:24','2007-09-21 09:58:24','http://forum.softpedia.com/index.php?showtopic=293831&amp;st=0',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(5862,647,'baghy','baghy83@lycos.it','http://baghy.info/','78.12.16.147','2007-09-21 13:23:03','2007-09-21 11:23:03','6 la suta si in plus mai e si dobanda?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(5863,648,'ania','soredarkshines@gmail.com','http://aniakhaki.blogspot.com/','89.123.105.78','2007-09-21 14:21:30','2007-09-21 12:21:30','tu esti deja nuntas profesionist :) dixtractie',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(5864,647,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-09-21 14:28:06','2007-09-21 12:28:06','Dap. Clar.\r\n\r\n\"Bancile nu sunt institutii de binefacere decat pentru ele insele!\"',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(5865,648,'pliscu','pliscu@gmail.com','http://pliscu.blogspot.com','86.105.73.121','2007-09-21 15:05:58','2007-09-21 13:05:58','nuntas pro, normal :P da` intrebarea e: daca ar veni la tine la nunta toti cei la care ai fost, unde i-ai ingramadi?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(5866,648,'WhiteWolf','laskmerge@gmail.com','http://whitewolf.1gb.at','89.39.81.200','2007-09-21 15:18:20','2007-09-21 13:18:20','Dubasul face galagia corespunzatoare pentru a se aduna lumea in fata la primarie\r\nLumea se aduna. Si apoi tace pentru a le intra, clar, in urechi, ce se da de stire, ca sa auda tot omu\':\r\n<b>Data viitoare, cand mai faci drum la Sibiu, lasa un semn pe mail cu vreo 2 zile inainte !</b>\r\nCheia (orasului, ca doar e si al meu) e la mine. \r\nStikloantzele nu le tin incuiate :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(5867,648,'lilith','marcu_luiza@yahoo.com','http://www.aberatiunti.blogspot.com','82.77.126.148','2007-09-21 15:19:10','2007-09-21 13:19:10','vaz ca-ti plac nuntile! dixtractie faina sa ai. poate ai sa ma \"nasesti\" si pe mine candva! :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(5868,534,'Nascut din spermatozoizi campioni &raquo; Blog Archive &raquo; Cica secs ecologic. Citez: hÄƒÄƒÄƒ, hÄƒÄƒÄƒ, hÄƒÄƒÄƒ!','','http://www.groparu.ro/?p=649','82.103.137.253','2007-09-21 15:21:23','2007-09-21 13:21:23','[...] de la Groparu, care de fapt iz io: creca am mai scris despre [...]',0,'1','Incutio XML-RPC -- WordPress/2.1.2','pingback',0,0),(5869,648,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-09-21 15:28:03','2007-09-21 13:28:03','@ ania: da, groparelui ii plac nuntile! finca e martor si la ingropaciuni de burlacii, si mi se rupe inimioara numa cand ma gandiesc...\r\n\r\n@ pliscu: mie nu de nunta mi-e frica, ci de vesnicia ei! Åži ÅŸi mai ÅŸi: mi-i fricÄƒ de Äƒia care ar veni sÄƒ mÄƒ vazÄƒ nu la nuntÄƒ, ci la la Ã®ngropÄƒciune, sÄƒ se rÃ¢dÄƒ ca pe groparu Ã®l Ã®ngroapÄƒ alÅ£ii, hihihi!\r\n\r\n@WhiteWolf: Deci ma, asemenea geniu legendar ca matale numa sighian putea fi! U got it. Vezi ca in octomvrie tre\' sa ne imprietenim cu Mile Carpenishan - ca i-am promis.\r\n\r\n@ lilith: vez\' ca-s un nas zgarcit zgarcit care cere sa i se pupe mana, vorbeste ragusit ca Marlon Brando si il intreaba pe popa la ce croitoreasa si-o facut fuztele, sau daca si le-o loat de la second de pe Motilor.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(5941,649,'WhiteWolf','laskmerge@gmail.com','http://whitewolf.1gb.at','89.39.82.133','2007-09-25 16:24:08','2007-09-25 14:24:08','Cozmose, Gropare, s-a auzit si acolo, in spate  ? :P\r\nTocmai am fost redusi la calitatea de numÃ£r !\r\nMiruna, sarutam dreapta; de la mine, cel putin.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(5926,650,'k','kosminbonea@yahoo.com','','89.122.171.87','2007-09-25 08:10:28','2007-09-25 06:10:28','8 nuntzÃ®? Fix-pix! un prekin o fo la 12 deja anu Äƒsta, din aprilie Ã®ncoa, ÅŸi mai are 2! Groaznic! TÄƒÅ£i banii Ã®i sparje pÄƒ nunÅ£i, de nu-i mai ajung de termopane, ÅŸi Ã®i stomatolog.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(5927,650,'.marius','marius@wirelessisfun.com','http://marius.wirelessisfun.com','89.137.107.129','2007-09-25 09:51:57','2007-09-25 07:51:57','omg... :))) gropare, fa rost de id\'ul meu... stiu ca poti am ceva pentru tine ;-)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(5928,650,'.marius','marius@wirelessisfun.com','http://marius.wirelessisfun.com','89.137.107.129','2007-09-25 09:52:15','2007-09-25 07:52:15','cu o virgula in plus acolo... :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6005,661,'ss','criss_team@yahoo.com','','81.196.150.198','2007-09-26 17:14:54','2007-09-26 15:14:54','...sa citeasca   \r\n\r\n (ca vad ca asta n-o mai incaput...o fi ceva semn)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7','',0,0),(6006,661,'ss','criss_team@yahoo.com','','81.196.150.198','2007-09-26 17:17:08','2007-09-26 15:17:08','hestraordinar. dupa sa citeasca urmeaza \"verbiaj &amp; co\", numa ca vad ca daca pui intre \'\' nu apare dom\'ne.\r\nhai ca poate de data asta.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7','',0,0),(5952,656,'kalapkura','kalapkura@yahoo.com','http://ciuciu','89.136.55.236','2007-09-25 20:23:20','2007-09-25 18:23:20','gropare s-o treci pa tanti P prin chinurile vrunor budigaiboxeri muieri cu cusatura aia exact pe mijloc sau sa nu zic buditanga ca imediat o ia madam P pa cararile hipiotismului si sparge jolidonu din unirii si le da foc la tatzi chiar sub nasu lu matyas',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(5953,656,'baghy','baghy83@lycos.it','http://baghy.info/','78.12.21.31','2007-09-25 20:24:50','2007-09-25 18:24:50','nu stiam pana acum',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(5954,656,'kalapkura','kalapkura@yahoo.com','http://ciuciu','89.136.55.236','2007-09-25 20:37:53','2007-09-25 18:37:53','piess: la atata succes la public gropare, io zic ca tre sa-ti faci canal irc, tot le ai matalutza cu violu',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; SIMBAR={A3537CF6-A147-4d04-BF49-D2D4C4B57435}; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(5871,648,'Miruna','mirunavasilescu@yahoo.com','http://potsafacsiasaceva.blogspot.com/','86.106.59.163','2007-09-21 15:38:37','2007-09-21 13:38:37','Clar, am zis eu demult, e ceva dubios cu toate nuntile astea. \r\nFor what it\'s worth, vazut filmul, placut. \r\nHai sa fie-ntr-un ceas bun.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(5872,649,'ss','criss_team@yahoo.com','','81.196.150.198','2007-09-21 15:43:31','2007-09-21 13:43:31','pai da, ca cica pana si brad si angelina fac sex ecologic (nu zice care cu cine/ce)...ca sa vezi..',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7','',0,0),(5873,648,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-09-21 15:59:36','2007-09-21 13:59:36','Luciano ruleaza :D sa vezi numa cum povesteste de cat de sgarcit de Puff. Diddi Puff.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(5874,645,'been there done that','lisca.ana@gmail.com','','82.208.154.111','2007-09-21 16:02:07','2007-09-21 14:02:07','mda! vezi bine, ca aradul(sau mica viena) meu e mai frumos ca si clujul tau!! dar ai mers pe centura si pe acolo e numa\' asa de fenta sa se sperie groparii si sa nu mai treaca pe aici.\r\nsi da exista tramvai intre arad si vladimirescu si cred ca merge si pina la lipova! parol! noroc ca avem tramvai intre arad si localitati si nu o sa mai avem in arad pt cateva luni..sau ani?!?!?\r\ncentura e sublima :P pina cand o sa se construiasca si la noi poade peste toate liniile de tren, mai este! te rog fa reclamatie la dl falca!!!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1)','',0,0),(5875,649,'been there done that','lisca.ana@gmail.com','','82.208.154.111','2007-09-21 16:09:18','2007-09-21 14:09:18','seios?? unde oi fi citit tu minunatia de articol despre brad??? da si mie ca eu il plac mult de tot!!\r\nsi gropare...zici ca nu is biodegradabile?? trist! trist!\r\ntre sa mai taiem niste caprette pentru gropar! \r\napropos.. eu mi-am cumparat o haina din piele de capra :D',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1)','',0,0),(5877,649,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-09-21 16:16:17','2007-09-21 14:16:17','@ been here done nothin\': scuza-ma ca nu ma pot aptinea, se stie doara ca ma stradui, ca asa mi-o recomandat doftorii: e haina de capra, sau haina de stat capra???\r\n\r\nNa, stiu ca am fost iara vulgar, nici macar io nu rad la comentariu\' asta, da\' m-o rugat injerashu de pe umaru drept, ala de supt cercel, sa il postez, sh am cedat, finca e de fapt injerasha. Sh e sexy.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(5878,649,'Adi Calarasu','acalarasu@gmail.com','http://adriancalarasu.wordpress.com/','62.217.241.242','2007-09-21 16:19:49','2007-09-21 14:19:49','scatlover =))',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(5879,649,'ss','criss_team@yahoo.com','','81.196.150.198','2007-09-21 16:29:47','2007-09-21 14:29:47','@ been that done there: poti sa salivezi aici: http://www.cancan.ro/2007-09-21/Brad-si-Angelina-fac-sex-ecologic.html\r\n\r\nps- recomand si masculior sa arunce o privire ca de fapt poza fotogenica-i cu anjelina, nu cu bred fitz.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7','',0,0),(5940,655,'WhiteWolf','laskmerge@gmail.com','http://whitewolf.1gb.at','89.39.82.133','2007-09-25 16:22:01','2007-09-25 14:22:01','Datz\' voi de dreaku\' daca apuca fimeea lui sa ceteasca p\'aici.\r\nNici prechin nu mai avetz , nici beroasele nu se mai impart cu el si posibl sa se porneasca si skandal plus tzirkus la domiciliu\' ala conjugal pe motiv de \"nu mai dormi, animalo ca te rad AZP-istii pe bloguri\".\r\nDanjeru\'i mare :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(5881,649,'mumuland','','','85.204.38.37','2007-09-21 18:48:32','2007-09-21 16:48:32','eu nu comentez dar astept cu nerabdare sa scrii despre Andreea Marin si Banica jr....io atata am avut die zas...\r\n\r\niz io ma.care io? asta :  ;)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(5882,649,'dark shines','soredarkshines@gmail.com','http://aniakhaki.blogspot.com/','86.105.126.89','2007-09-21 19:12:50','2007-09-21 17:12:50','cu toata trupa de medicina anul 1... sau numa cu partea feminina? mie nu mi se par atat de frumoase :&gt;',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(5883,649,'been nowhere\' done nothin\'','lisca.ana@gmail.com','','82.208.154.111','2007-09-21 19:19:18','2007-09-21 17:19:18','e evident ca nu te poti aptinea, dar e bine ca.. cel putin ai intentia de a respecta indicatiunea doftorilor\' ...\r\ne o haina din piele de capra :)) !! si a fo\' scumpa dom\'le!! \r\ndar ma bucur ca esti plin de imaginatiuni!! fara tine nu as fi putut sa am o viziune globala asupra tuturor sensurilor periorative ale fiecarei propozitii.\r\n@ss ms de link, dar nu am salivat, (not enough brad $me) iar angelika nu ma incanta.. :(',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1)','',0,0),(5884,648,'Veroshag','veronica.grecu@gmail.com','','89.137.40.151','2007-09-21 20:05:09','2007-09-21 18:05:09','Nuntzile din Fagarash rulz! Parol! \r\nDaca faceti brainstorming si va hotarati sa furati si mirele, atentie mare la domnu\' politist care obishnuieste a trece duios precum Anastasia prin tzentru, catre orele unsp\'ce din noapte. Si mai obisnuieste domnu\' politist sa opreasca masinile nuntasilor care se hotarasc sa execute manevre necuviincioase in mijloc de intersectie ... Na, ca m-am pierdut in detalii ... m-am induioshat la aflarea vestii ca vei onora cu prezenta urbea mea aproape natala! Sa ai fan!',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; MEGAUPLOAD 2.0; Hotbar 10.0.356.0)','',0,0),(5885,647,'varza','tudor.maris@gmail.com','http://rottencabbage.haipa.ro','58.106.98.229','2007-09-21 22:05:33','2007-09-21 20:05:33','Bine totusi ca-i vorba de banca, gandeste-te daca apelai la un camatar. Si nu \"citeai\" contractu\'. Nu era vorba ca nu aveai azi ce scrie, era vorba ca nu ai CU ce scrie. \r\nDeci jumatatea plina......',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(5886,649,'varza','tudor.maris@gmail.com','http://rottencabbage.haipa.ro','58.106.98.229','2007-09-22 02:40:49','2007-09-22 00:40:49','As putea completa prin combinarea punctelor 2 si 3: nu mai trageti apa la baie, culegeti si folositi in gradina.... apoi sex. \r\nCeva ii gresit rau aici.... Doamne fereste!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(5888,649,'Groparu','Groparu','http://Www.groparu.ro','62.217.247.246','2007-09-22 11:03:12','2007-09-22 09:03:12','Ba, io-z la nunta si fac laiv blogging!',0,'1','SonyEricssonK800i/R1JC Browser/NetFront/3.3 Profile/MIDP-2.0 Configuration/CLDC-1.1','',0,0),(5889,643,'Ionutz','ionut.diacu@gmail.com','http://www.desprecazare.ro','195.242.158.68','2007-09-22 12:44:54','2007-09-22 10:44:54','Sunteti in week-endul dvs liber ... sau in concediu ... Sau pur si simplu vreti sa evadati ...\r\nDar unde ?\r\nAici veti afla si veti vedea unde ...\r\nVeti afla daca merita ...\r\nFara sa mai incercati pe propria dvs piele ...\r\n\r\nwww.desprecazare.ro',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5890,647,'Daniel','danielracovitan@yahoo.com','http://www.ghidoo.ro','88.161.114.233','2007-09-22 12:53:19','2007-09-22 10:53:19','doar 6%?!\r\nin Franta este in jur de 16-18%',0,'1','Opera/9.23 (Windows NT 5.1; U; fr)','',0,0),(5939,656,'WhiteWolf','laskmerge@gmail.com','http://whitewolf.1gb.at','89.39.82.133','2007-09-25 16:19:30','2007-09-25 14:19:30','Asta-i cu zmecherie din aia huge ! - postarea, vrau sa zic :)\r\nIo cre\' ca Groparele si-o dat drumu\' : la sondaj :)) Si vrea sa bage sama ce parere are tot utillizatoru\'  si/sau (de ce nu?) Luzeru\' de ii ceteste blogu\' despre un eventual <b>Daca am focuri in AZP, inseamna ca mi se plimba ca bezmetica pe o comoara?\"</b>',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(5931,647,'Dorin','dorin5109@yahoo.com','','86.121.83.45','2007-09-25 12:56:52','2007-09-25 10:56:52','ai dat f mult. eu am dat 1000 comision pentru 45.000 credit imobiliar tot la alpha acum 2 luni',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(5932,650,'VIPu','robilica@yahoo.com','http://vipuri.blogspot.com','213.157.188.71','2007-09-25 13:29:58','2007-09-25 11:29:58','fain ai imbracat buda aia ma gropare! esti talentat!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(5895,645,'kalapkura','kalapkura@yahoo.com','http://ciuciu','89.136.55.236','2007-09-22 21:37:26','2007-09-22 19:37:26','strandul neptun e intr-adevar de vazut in arad, in august la amiaza poti avea probabil singura senzatie tare din zona : ca toti au murit si au lasat terasele goale cu muzicile date la maxim si cloru curgand in bazine...si iaca asa cel mai tare strand din sud estu europei e mai ceva ca marte ( d eunde se ghiceste mana ungurului ce dupa ce o vazut ca nu-i merge cu statuia libertatii din centruo misculat ce-o misculat si o tras cate un strand cu bazine calde/necalde cu valuri si potrivite spe-ci-al ca sa ne falimenteze ). norok cu italienii pensionari care ne mai iau de cate-o nevasta si renoveaza cate un apartament de bloc',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; SIMBAR={A3537CF6-A147-4d04-BF49-D2D4C4B57435}; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(5896,645,'kalapkura','kalapkura@yahoo.com','http://ciuciu','89.136.55.236','2007-09-22 21:40:57','2007-09-22 19:40:57','ioai da,unguru care ne falimenteaza e al de a tras stranduri dincolo d egranita . asa. a nu s epricepe ca are vreo legatura personaju nostru colectiv cu strandul neptun din mica viena',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; SIMBAR={A3537CF6-A147-4d04-BF49-D2D4C4B57435}; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(5933,650,'kalapkura','kalapkura@yahoo.com','http://ciuciu','89.136.55.236','2007-09-25 13:57:38','2007-09-25 11:57:38','groparu vreau sa fiu exact ca tine cand ma fac mare.de la buboaie incolo',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; SIMBAR={A3537CF6-A147-4d04-BF49-D2D4C4B57435}; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(5934,649,'Miruna','mirunavasilescu@yahoo.com','http://potsafacsiasaceva.blogspot.com/','86.106.59.163','2007-09-25 14:39:29','2007-09-25 12:39:29','io numa\' v-am numerotat, sa nu zica gura lumii ca ma scald in gloria voastra:)))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(5935,650,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-09-25 14:53:18','2007-09-25 12:53:18','@ Lupulaine: M-o pus sa ma descaltz, sh in toata ceatza aia din camera numa\' tablou ala se vedea OK! D-aia l-am sh pozat. \r\n\r\n@ K: your friend e o mama eroina! parol. Wespect ;)\r\n\r\n@ marius: rulezi :| punct\r\n\r\n@ VIPu: da, mo, ca asa ma imbrac sh pe mine zilnic, deci am iesperientza.\r\n\r\n@ kalapkura: deci mo, ca sa fii ca mine tre\' sa faci puscarie pentru viol.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(5898,643,'admin','groparu_ro@yahoo.com','http://','86.105.72.125','2007-09-23 02:36:58','2007-09-23 00:36:58','Deci ba Ionutz: io nu fac reclÄƒmi pe saitu\' meu. Nu ie sait comercial, sh asta nu se va schimba in viitorul pe care il poci io concepe cu mintea mea de copkil. Asa ca nij nu stiu de ce nu iti sterg comentariu\' tau off topic. Poate imi dai tu ceva raspuns (semn de intrebare d-asta: ?)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,1),(5936,655,'ss','criss_team@yahoo.com','','81.196.150.198','2007-09-25 15:12:00','2007-09-25 13:12:00','asta se cheama ca face sex foarte ecologic. \r\ndaca avem vrun reprezentant al vreunei organizatii ecologiste prin preajma, io zic sa ia in considerare acordarea unui premiu.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7','',0,0),(5937,656,'ss','criss_team@yahoo.com','','81.196.150.198','2007-09-25 15:16:55','2007-09-25 13:16:55','daca nu s-or inrosit fecioarele la citirea postarii anterioare..apai la asta sigur n-o mai facut fatza :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7','',0,0),(5938,655,'VIPu','robilica@yahoo.com','http://vipuri.blogspot.com','213.157.188.71','2007-09-25 15:46:03','2007-09-25 13:46:03','ie, asta cand nu adoarme dupa prima infigere.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(5942,655,'Miruna','mirunavasilescu@yahoo.com','http://potsafacsiasaceva.blogspot.com/','86.106.59.163','2007-09-25 16:28:18','2007-09-25 14:28:18','Hai ca, vorba lu\' ss, mai ecologic de atat nu se poate. Doar deloc, ca mine, da\' am inteles ca nu e pentru cardiaci. :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(5943,656,'Miruna','mirunavasilescu@yahoo.com','http://potsafacsiasaceva.blogspot.com/','86.106.59.163','2007-09-25 16:29:51','2007-09-25 14:29:51','Deci asta fac barbatii in armata???',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6309,671,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','82.77.126.148','2007-10-04 10:36:55','2007-10-04 08:36:55','lasa gropare... doar stii ca noi te iubim! n-ai de ce sa te simti incomplect :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(5945,655,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-09-25 16:47:25','2007-09-25 14:47:25','@ Lupulainu\' BÄƒlan: Da, da\' itz dai sama ce tare ar fi sa baje d-na lu Tibby comentariu \"Asta s-o crezi tu!;)\"',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(5906,648,'baghy','baghy83@lycos.it','http://www.baghy.info','78.12.18.173','2007-09-23 20:51:09','2007-09-23 18:51:09','daca stiam ca vi in Fagaras la nunta nu mai plecam de acolo',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; it; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.6','',0,0),(5907,647,'raluca','ralucaghervan@yahoo.com','http://360.yahoo,com/ralucaghervan','89.137.11.203','2007-09-23 23:08:26','2007-09-23 21:08:26','eu ti-am zis sa faci la Raiffeisen Banca pt Locuinte!! Inca nu e prea tarziu!',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.0.3705; .NET CLR 1.1.4322)','',0,0),(5909,649,'macabroo','raduccc@yahoo.com','http://rezistenta.blogspot.com','80.96.196.2','2007-09-24 08:45:34','2007-09-24 06:45:34','pateu',0,'1','Opera/9.23 (Windows NT 5.1; U; en)','',0,0),(5946,656,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-09-25 16:50:15','2007-09-25 14:50:15','@ ss: mai exista asa ceva, ca am vast pe saitu\' wwf ca categoria asta e inclusa la \"extinc animals\"?\r\n\r\n@ Lupulainu\' BÄƒlan: Da, mo, atata numa ca io nu port AZP decat pe podea, langa patu\' meu - care de fapt e-un coltzar.\r\n\r\n@ Miruna: sa vezi numa cand isi baga trupetzii deshtiu\' in cur, sh daca ala face pasi in fatza la disperare, toata trupa zice \"Eeeee, asta are avans!\"',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(5947,655,'WhiteWolf','laskmerge@gmail.com','http://whitewolf.1gb.at','89.39.82.133','2007-09-25 16:54:29','2007-09-25 14:54:29',':)) :))\r\nStop hurting me !!! :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(5948,649,'Miruna','mirunavasilescu@yahoo.com','http://potsafacsiasaceva.blogspot.com/','86.106.59.163','2007-09-25 17:02:10','2007-09-25 15:02:10','Domnilor, din cate am inteles eu, un numar e o calitate de admirat la un barbat. Deci hats off. :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(5949,656,'Miruna','mirunavasilescu@yahoo.com','http://potsafacsiasaceva.blogspot.com/','86.106.59.163','2007-09-25 17:04:09','2007-09-25 15:04:09','Ma, mie nu-mi place armata asta a voastra...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(5914,649,'WhiteWolf','laskmerge@gmail.com','http://whitewolf.1gb.at','89.39.81.92','2007-09-24 16:04:35','2007-09-24 14:04:35','Daca si numai daca ai reusit sa ramai jiu prin partile principale, afla ca nenea ala cu Cosmosul a pus la cale o dita marshavia si m-am alaturat cu tot dragul. :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(5950,656,'ss','criss_team@yahoo.com','','81.196.150.198','2007-09-25 17:19:36','2007-09-25 15:19:36','gropare, io cred ca mai egzista, numa ca, la fel ca dinozaurii, se ascund bine.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7','',0,0),(6024,659,'VIPu','robilica@yahoo.com','http://vipuri.blogspot.com','213.157.188.71','2007-09-27 08:18:15','2007-09-27 06:18:15','baaaaa!!!!!!!! ii gresita stema. in loc de castel medieval sau de care dracu o fi asta trebe pus castel tziganesc actualizat, trendy si cool. nu cred ca o sezut vun tzagan vreodata in castel d-asta ce aveti voi pe stema. scoate-o repede si refa-o!!!!\r\n\r\nNU ESTI DELOC ATENT, GROPARE!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(5917,649,'nenea cosmos','domnu_cosmos@yahoo.com','http://nenea.wordpress.com/','92.80.46.240','2007-09-24 19:49:53','2007-09-24 17:49:53','deci multumesc ocaziei care ca o oportunitate mi-a dat sansa sa fac un articol de blog cu care fac clickuri folosind numele groparelui, ca un furt de personalitate, ca da lumea search dupa groparu si gaseste cosmosu.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(5918,650,'Miruna','mirunavasilescu@yahoo.com','http://potsafacsiasaceva.blogspot.com/','86.106.59.163','2007-09-24 21:07:32','2007-09-24 19:07:32','Sa stii ca daca o fi, cand o fi, pe tine te pun sa-mi organizezi evenimentul, sa nu se iroseasca frumusete de experienta acumulata cu pretul atator cearcane. Numa\' don\'t hold your breath, cum zice francezu\', ca am zis daca.\r\nDeci te-ai lecuit de nunti pe anul asta?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(5919,650,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','86.105.72.125','2007-09-24 21:09:38','2007-09-24 19:09:38','Io atata sper! Sh mai sper sa nu apara mormantarile, desi am neshte indivizi la care le-as sapa cu drag groapa.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(5920,650,'ania','soredarkshines@gmail.com','http://aniakhaki.blogspot.com/','89.123.92.213','2007-09-24 21:13:34','2007-09-24 19:13:34','cand am vazut buba... am si uitat ce voiam sa comentez...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(5921,649,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','86.105.72.125','2007-09-24 21:57:01','2007-09-24 19:57:01','@ Coy-mos: Iti dai seama ce univers gaseste aia daca cauta Groparu?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(5922,650,'Miruna','mirunavasilescu@yahoo.com','http://potsafacsiasaceva.blogspot.com/','86.106.59.163','2007-09-24 22:30:36','2007-09-24 20:30:36','Pe mine tabloul ala m-a fermecat.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(5956,656,'nenea cosmos','domnu_cosmos@yahoo.com','http://nenea.wordpress.com/','92.80.2.48','2007-09-25 21:24:05','2007-09-25 19:24:05','azepeul e un instrument bleu cu care lustruiesti bocancii, pe urma te duci la dusuri si pe urma cind te intorci la dormitor il imbraci pentru ca locotenentul tocmai a aruncat pe geam orice imbracaminte civila.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(5958,656,'baghy','baghy83@lycos.it','http://baghy.info/','78.12.21.31','2007-09-25 22:46:23','2007-09-25 20:46:23','Gropare stai antena la ce iti zic.Vorbesc cu o fata pe mess si in loc sa ma ia cu ce mai faci imi zice:\r\nEa: iar cu ocazia asta voiam si sa iti multumesc ca mi-ai aratat blogul lui groparu\'. \r\nOmul este absolut fascinant\r\nEa: il devorez de fiecare data\r\nEa: deci la textul lui intotdeauna sunt asa \r\nEa: l-am si ascultat la radio \r\nEa: cand a fost la cluj acolo \r\nEa: super simpatic \r\nEa: si se vede ca a citit o gramada\r\nNo mai zi ceva.astept raspuns',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(5959,657,'baghy','baghy83@lycos.it','http://baghy.info/','78.12.21.31','2007-09-26 00:15:47','2007-09-25 22:15:47','cat adevar in aia cu italianul.parca la capitolul 5 e',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(5960,657,'WhiteWolf','laskmerge@gmail.com','http://whitewolf.1gb.at','89.39.81.107','2007-09-26 00:16:29','2007-09-25 22:16:29','1. Nu pot vota pe saitu\' de-l indici inainte sa se legifereze prostitutia. Ma tem ca voi fi acuzat ca umblu la prostituata ProMedia\r\n2. Da\' daca vrei, iti popularizez initiativa, asa, sa-ti ramana fomeile pe care le doresti ca heterosexual fomist ce iti place sa lasi impresia ca ai fi.\r\n3. Chiar nu cred ca demersu\' sa aiba cine stie ce ecou cata vreme nu ai inclus in el termenii oligarh, Becali, zoso si nici free porn.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(5961,649,':: WhiteWolf :: &raquo; Blog Archive &raquo; Impreuna Salvam Cu Avant','','http://whitewolf2.freehostia.com/archives/282','64.72.112.142','2007-09-26 00:20:59','2007-09-25 22:20:59','[...]  gaseste o super dileala pe HotzNiuz si pentru ca nu-i fire din aia de se abtine, improasca un post absolut corespunzator. Lumea, care plictisita, care curioasa sau, pur si simplu, care mimeaza ca lucreaza sarind (de [...]',0,'1','Incutio XML-RPC -- WordPress/2.2.1','pingback',0,0),(5962,656,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','86.105.72.125','2007-09-26 00:24:49','2007-09-25 22:24:49','Hai mo, deci ne potolim; Äƒsta nu are cum fi blog fain din moment ce am numa\' un singur articol despre iPhone, nu ma indur sa bag bance sau filme youtubizde in el, si nij nu-s chiar asa mare fan Basescu! Da\' mersi de feedback :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(5963,657,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','86.105.72.125','2007-09-26 00:28:46','2007-09-25 22:28:46','@ Baghy: E, mah, mie numa d-aia mi-i hazna, ca desi sorella are hazbÄƒnd neamt, asta e neamtu\' dracului, sh e super-romanizat, sa vezi numa ce romana stie: ii dau mesaj de Paste cu \"Hristos a-nviat!\", si el raspunde: \"Restul familiei sunt dorm; numai eu sunt amviat!\"\r\n\r\n@ Lupulaine: animalelele, conform dexului, presupune un organism pluricelular, ca m-am documentat; ori in afara de free porn (punctul tau 3), nici unu\' nu indeplineste criteriile! A, sh nuz hetero fomist, numa\' nesatul :D Parol!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(5964,657,'WhiteWolf','laskmerge@gmail.com','http://whitewolf.1gb.at','89.39.81.107','2007-09-26 00:42:34','2007-09-25 22:42:34','Da, recunosc, ej politically corect\r\nIntr-adevar, animalele nu asculta manele la telefon :)\r\nMa mai gandesc, da ?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(5965,656,'WhiteWolf','laskmerge@gmail.com','http://whitewolf.1gb.at','89.39.81.107','2007-09-26 00:43:45','2007-09-25 22:43:45','Taci si lasa-te devorat.\r\nS\'apÃ£i te potolesti. Da ? :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(5968,657,'ania','soredarkshines@gmail.com','http://aniakhaki.blogspot.com/','89.123.116.57','2007-09-26 02:51:13','2007-09-26 00:51:13','fara pui... ca dupa aia tre si aia protejati :D de ce-ul 2 suna bestial... :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(5987,656,'WhiteWolf','laskmerge@gmail.com','http://whitewolf.1gb.at','89.39.82.181','2007-09-26 14:16:07','2007-09-26 12:16:07','@lilith, daca se intampla cum zici \'mneata, asta tine de misterele eternului feminin si nicidecum de armata',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(5988,655,'WhiteWolf','laskmerge@gmail.com','http://whitewolf.1gb.at','89.39.82.181','2007-09-26 14:17:47','2007-09-26 12:17:47','Adi, chiar daca nu te ajuta organele (sper ca n-ai hiba din aia cu hernia :P ) poti incerca sa te maschezi in <b>lezbianc</b>\r\nDetalii si tot ce mai presupune asta, direct la Groparu',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6001,650,'admin','groparu_ro@yahoo.com','http://','82.77.126.254','2007-09-26 16:10:15','2007-09-26 14:10:15','Deci mai reea, ca sa zic asa, sa nu zic \"fÄƒ\": io, de la cei 1,85 metri pe care-i am (care, la capatu\' de sus, is goi-goluti!), pot poza orice din perspectiva unui avion de recunoastere U2, care si-o loat numele de la formatia aia gay irlangheza. Cat despre costumu\' ruinat la nuntile astea: ala de sambata l-am burdushit bine cu vin roshu, si p-ala de dumineca l-am frecat cu darnicie si cu polen, si am turnat - parca - bere. Si atunci intelegi cand zic ca in astea ultime 5 saptamani am platit o avere numai curatzatu\' costumelor? Da\' prefer sa le curatz pentru nunti, boteze sh cumetrii, decat pentru mormantari. Oare numai mie nu-mi plac mormantarile?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,1),(5990,657,'VIPu','robilica@yahoo.com','http://vipuri.blogspot.com','213.157.188.71','2007-09-26 14:49:32','2007-09-26 12:49:32','io militez pentru confratii mei ma. si pentru tine... chiar daca te dai lup alb... tot porc esti si tu :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(5991,657,'IepurasulAtomic','praetorian21uk@yahoo.com','','82.77.123.114','2007-09-26 14:52:04','2007-09-26 12:52:04','Mah Gropare, io nu-s cine stie ce mare iubitor de animale, c-as fi numit zoofil. Da\'s suficient de animal si om in acelasi timp si eu, incat sa nu-mi convina ca se suie unu\' cu picioarele pe-o pisica sh-o face snitzel. Da\' de aici si pana la o mare miscare nationala...care fie vorba intre noi nu vad sa aiba vreun viitor practic...e mare distanta de parcurs. Mie sincer mi se rupe ca unu\' a rupt in picioare o matza. E un suflet, e drept. Da\' pe de alta parte, ar mai fi probleme cu:\r\n\r\n1. EDUCATIA.\r\n2. SISTEMU\' SOCIAL(si aici ma refer in special la copiii orfani care sufera in lagarele de concentrare din Romania).\r\n\r\n....si multe altele, ca m-am saturat de enumerat. Si le stiti si voi f bine. Si-aci am pomenit doar de problemele sociale(care de fapt primeaza), far\'a mai zice nimic despre politica, justitie(care-i tot politica), biserica(care-i tot politica) si tat asha. \r\nAdica, in alta ordine de idei, spun pas(sper fara a mi se urca toata blogosfera si opinia PUbLICA in cap...nu de alta, da\' chiar nu merit atat atentie). Eh, la fel nu merita atata atentie nici o mana de retarzi care s-apuca sa chinuie animale. Fie vorba intre noi, majoritatea chiar is retarzi. La noi in Romanica, psihopatii care omoara oamenii scapa fara pushcarie, credeti ca vor face pushcarie pentru o biata pisica? Ia hai sa judecam...\r\n\r\nPentru cine a inteles: \"Respect!\". Pentru ceilalti:\"Heirup!\", ca asta va caracterizeaza cel mai bine.\r\n\r\nPace p\'afara!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(5992,650,'reea','andreea.iancu@apropo.ro','http://reea.netfun.ro','193.230.230.122','2007-09-26 14:57:14','2007-09-26 12:57:14','gropare da\' pretentios ejt mah!\r\n\r\nsa te vaz pe tine la un eveniment in costum pozand de la inaltimea nasului broastei (sa nu zic genunchi) cuplul extraordinar care are un metru juma\', eventual mirii  pusi unul peste altul. Si nu imi zice ca ti-ai distruge \"costumu\' ala bunu\'\" doar de dragul ...artei...zau!\r\n\r\nE adevarat ca daca mergi pe covorul rosu de la decernarea premiilor Oscar iti iei costum si te pui pe burta sa il pozezi pe Jack Nicolson... dar sa nu confundam evenimentele...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(5993,147,'Nascut din spermatozoizi campioni &raquo; Blog Archive &raquo; Ce s-o inteles din petitia pentru animale','','http://www.groparu.ro/?p=661','82.103.137.253','2007-09-26 14:57:20','2007-09-26 12:57:20','[...] Finca nu pot bea bere kiar zilnic!!! [...]',0,'1','Incutio XML-RPC -- WordPress/2.1.2','pingback',0,0),(5994,661,'Miruna','mirunavasilescu@yahoo.com','http://potsafacsiasaceva.blogspot.com/','86.106.59.163','2007-09-26 15:10:00','2007-09-26 13:10:00','Sa-i dam ce-i al lui. Stie cuvinte, spune \"verbiaj\" si foloseste \"luetic\". Si sa stii ca eu dorm mai linistita acum ca am vazut ca oameni vigilenti care sar de c*r in sus la fiecare postare care le pare suspecta. Asa e bine, sa mature blogosfera in cautare de \"teribilisti\" ca tine! Jos umorul, jos autoironia, jos sarcasmul!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(5995,657,'lilith','marcu_luiza@yahoo.com','http://www.aberatiunti.blogspot.com','82.77.126.148','2007-09-26 15:13:04','2007-09-26 13:13:04','da, groparule! acum serios vorbind, am acasa 2 pisici. si jur ca as fi in stare sa il omor pe ala de s-ar atinge de una din ele. \r\nam crescut printre animale, le cunosc, le inteleg, le iubesc mai mult decat iubesc oamenii. \r\ncat despre animalele de voi, as fi in stare de multe, dar depinde de situatie :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(5996,661,'WhiteWolf','laskmerge@gmail.com','http://whitewolf.1gb.at','89.39.82.181','2007-09-26 15:17:18','2007-09-26 13:17:18','Si ce mai punem, \"sus\", Miruna ?\r\nCa ce poate vedea tot omu ne da cu rest la semafor si putoare prin mijloacele de transport in comun.\r\nPlus ca-i mai plin netu\' de astia care\'s pus pe demolat din principiu. Si nu neaparat ca ar si avea ceva de pus in loc',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(5997,657,'WhiteWolf','laskmerge@gmail.com','http://whitewolf.1gb.at','89.39.82.181','2007-09-26 15:20:29','2007-09-26 13:20:29','VIPu, asadar nu vrei sa recunosti ca te extaziezi ori de cate ori auzi de juisarile porcilor care transpira de la 30 de minute in sus. Bineee......\r\nDaca tot ne-ai stabilit, definitiv, porci pe amandoi, astept cu doar in piept sa ne vorbesti si de scroafe.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(5998,661,'IepurasulAtomic','praetorian21uk@yahoo.com','','82.77.123.114','2007-09-26 15:25:32','2007-09-26 13:25:32','Uai....Groparu\'! Alooo! Auzi? Io te sustin ma...nu pen\'ca is groupy...numa\' ca am ciocnit o bere cu tine si-asha am fost de incantat incat s-or intamplat lucruri pe care mi-i jena sa le spun acilea. Daca tu nu esti tu, io cine dracu\' mai is(daca voi intelegeti ce-am vrut sa spun prin asta, sa-mi spuneti si mie, ca io nu m-am prins). Pace p\'afara.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(5999,661,'Miruna','mirunavasilescu@yahoo.com','http://potsafacsiasaceva.blogspot.com/','86.106.59.163','2007-09-26 15:28:36','2007-09-26 13:28:36','Sus-sus de tot sunt astia cu capu\' mare dar usor, care o ard pricinos si care probabil nici n-au stiut vreodata cum e sa-ti dai brusc seama ca daca nu razi, in secunda doi o sa-ti pocneasca o vena de nervi. Pentru ca mama lor i-a crescut in grijulie in beci, feriti de rele, si le-a dat o educatie aspra dar severa aplicandu-le in fiecare seara lovituri cu muchia riglei la palma daca nu rosteau rugaciunea frumos, cu intonatie. In curand se vor uni, se vor imperechea intre ei si vor deveni o comunitate independenta a carei emblema va fi un bat infipt fix unde-i place mai mult lui Botezatu.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6000,661,'rrsse','rrsse@yahoo.ro','','86.121.19.97','2007-09-26 15:55:13','2007-09-26 13:55:13','Daca ai scris despre beiat am si vrut sa vad ce scrie. Da, da, da.... Beiatu vede viata dintr-un clop de sticla, n-ar recunoaste realitatea nici daca l-ar calca in picioare. Snob, pretios, superficial... Tu scrie mai departe, imi place maxim',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1)','',0,0),(6002,661,'Arhi','arhi@arhiblog.com','http://arhiblog.com','82.78.209.81','2007-09-26 16:30:40','2007-09-26 14:30:40','dupa blocurirli gri, stam noi majoritatea, sunt mai inalte la sosea sa nu se vada foamea, sa nu se vada baietii, care luetic ii prostesc pe prosti, verbiind toata noaptea, c-o pizda la colt.\r\nda.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6004,661,'ss','criss_team@yahoo.com','','81.196.150.198','2007-09-26 17:11:28','2007-09-26 15:11:28','gropare, nu tre sa te justifici, lasa-i pe \'intelihentes\' astia dexteri cu capu mare crescuti in eprubeta, lasa-i sa-si expuna principiile de inalta tinuta morala, ca doar tre sa discute ceva si ei, prealuminatii, in clubul lor select. noroc ca mai exista cate un blog ca asta ca alfel ar duce mult-prea-circumvolutionatii lipsa de material pentru a-si etala sclipirile de rasa superioara.\r\n\r\nio un singur mesaj am pt ei: pe loc repaus, relaxati-va, da, stim ca sinteti inteligenti. pe cuvant.\r\n\r\nsi o sugestie pt tine gropare: fa o sectiune \'instructiuni de citire a blogului\' si la sfarsitu aberatiunilor baga si tu un \'acesta este un pamflet\', ca vezi si tu ca este unii care se prind mai greu.\r\nba chiar si un test \'cat sunt de frustrat\' poti sa bagi..si cine nu scoate puctaju sa primeasca recomandare cum ca ar fi mai bine pentru sanatatea lui sa citeasca ',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7','',0,0),(5971,657,'Radu Iliescu','riliescu2000@yahoo.com','http://careeste.blogspot.com','89.136.251.45','2007-09-26 09:10:33','2007-09-26 07:10:33','Stai, stai ashe, am ghicit. La tine pe blog se poate spune orice abe, numai sa fie cu haz nu? Adica, daca vreau si ma man\'ca, po\' sa te injur, da numai sa radem cu totii si sa ne batem pe burta, noa?\r\n\r\nVezi ca jtiu?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(5972,657,'Radu Iliescu','riliescu2000@yahoo.com','http://careeste.blogspot.com','89.136.251.45','2007-09-26 09:11:27','2007-09-26 07:11:27','Aaa, sa fiu mai explicit: \"abe\" nu vine de la Abe Lincoln (ala cu masina), ci de la A-B-E-R-A-T-I-E.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(5984,656,'lilith','marcu_luiza@yahoo.com','http://www.aberatiunti.blogspot.com','82.77.126.148','2007-09-26 13:48:11','2007-09-26 11:48:11','si daca femeile poarta azepeuri, ce se cheama ca este? spre exemplu, mie imi plac boxerii, is mai comozi. :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(5985,657,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-09-26 13:57:10','2007-09-26 11:57:10','@ lilith: chiar... esti in stare... de orice pentru animalutze? :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(5986,657,'WhiteWolf','laskmerge@gmail.com','http://whitewolf.1gb.at','89.39.82.181','2007-09-26 14:14:52','2007-09-26 12:14:52','@VIPu, tu militezi pentru porcu romanesc din cauza de prieteni, din cauza ca iti place sa mananci ekolojik sau pur si simplu pentru ca ti-ai ales, deja, in ce doresti sa te reincarnezi pe motive de orgasm prelungit ?\r\n@Groparu, de ce pui intrebari de-a dreptu\' ?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(5975,657,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-09-26 10:08:00','2007-09-26 08:08:00','@ Ilici: nu, ba, nu poti sa ma injuri, ca ma injur io suficient. Da\' esti invitat sa faci la fel cu dumneatale! Sh sa fii orijinal, c-asta e musaie.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(5983,657,'lilith','marcu_luiza@yahoo.com','http://www.aberatiunti.blogspot.com','82.77.126.148','2007-09-26 13:43:05','2007-09-26 11:43:05','am dat si eu cu subsemnata acolosha, da nu stiu daca o sa aiba vrun folos. petitiuni pe net is kakalau, dar niciuna nu a schimbat ceva vrodata.\r\n\r\noricum, de dragul animalelor sunt in stare de orice! chiar si de dragul animalelor de voi, care esteti!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(5977,657,'VIPu','robilica@yahoo.com','http://vipuri.blogspot.com','213.157.188.71','2007-09-26 12:51:58','2007-09-26 10:51:58','da ma, si sa protejeze si porcii ma!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(5978,657,'Miruna','mirunavasilescu@yahoo.com','http://potsafacsiasaceva.blogspot.com/','86.106.59.163','2007-09-26 13:03:30','2007-09-26 11:03:30','Fara legatura cu postul tau, ca am dat deja cu subsemnatul pe petitie long ago, da\' mneatale de ce nu binevoiesti a raspunde la lepse de la confrati? A?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(5979,656,'Adi Calarasu','acalarasu@gmail.com','http://adriancalarasu.wordpress.com/','62.217.241.242','2007-09-26 13:13:38','2007-09-26 11:13:38','La sudisti ii zicea \"aparat de zapacit p*zd*le, nush din ce motiv  :))',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(5980,655,'Adi Calarasu','acalarasu@gmail.com','http://adriancalarasu.wordpress.com/','62.217.241.242','2007-09-26 13:14:07','2007-09-26 11:14:07','acuma io nu-s feminista d\'aia ca nu ma ajuta organele (chiar, poti fii feminisT?!) dar ca sotie de tibby sigur s-ar gasi o mie si una de replici de dat la mojic, gen: tz place cum miroase ciorba asta de burta si cu fasolea cu ciolan, ma? Perfect, acuma mars si mananca la Gima de la prezentari de mezeluri\"\r\nsau \"ma, ti-am calcat calcat camasa asta, adica maneca dreapta, na!\"',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(5981,657,'Scirbitu\'','','','86.34.167.21','2007-09-26 13:14:31','2007-09-26 11:14:31','Sper sa fii si tu protejat prin Legea asta, mai animalule',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; InfoPath.1; omniasig s.a; omniasig s.a)','',0,0),(5982,657,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-09-26 13:29:36','2007-09-26 11:29:36','@ Miruna: de exempur, leapja aia cu desktopu\' e ciudata, finca pe desktop am o poza cu o mamaliga la ceaun de la Tiganiada - deci la asta am raspuns; da\' leapja cu scrinshotu\' din system tray, aia mi se pare mai penal chiar ca cea mai reusita postare gropareasca! Sper ca raspunsu\' are legatura cu comentariu\' tau.\r\n\r\n@ Scarbitu: io numa atata sper, sa ne protejeze pe toti!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6017,657,'nenea cosmos','domnu_cosmos@yahoo.com','http://nenea.wordpress.com/','92.80.28.109','2007-09-26 22:52:35','2007-09-26 20:52:35','cind eram mic da gras m-o dus ai mei la cursuri de vioara. acu vioara aia am vindut-o la un tigan in tirg pe mai nimica, ca incurca peisaju postrevolutionar de la mine din camera dupa 10 ani de stationare la cutie pe dulap. cind eram eu mic deci chestia e ca veneam eu de la locu unde un nene in virsta visa sa scoata din mine paganini, ma rog, pentru asta primea banii. era seara si aveam o geaca si un fes de ziceai ca-s cili uili, va jur. ma opresc golanii de 14 ani care erau fratii mai mari ai putoilor de vreo 10 cu care ma jucam eu. cica sa le cint ceva. ma pis pe mine de frica de doua ori ca sa se incalzeasca instrumentu, scot vioara si scirtii do sol mi do, do mi sol do. iau o palma dupa ceafa si o flegma pe ochi la foc automat. eram carnita proaspata pentru smecherii aia si cum se plictiseau ei ma baga dupa un colt (la noi in cartier exista colturi) si vad eu o pisica legata rascracit pe gard cu fata spre mine. mi se pune un cutit in mina si mi se da tema sa scot ochii la pisica ca daca nu o sa imi scoata ei ochii mie. ei suturi in cur, eu pasi inainte. ma buseste plinsul, scap cutitu pe jos, mai iau niste palme pe colo pe colo, nu, nu m-au violat, erau toti baieti de familii bune, si mi-am luat vioara si-am tulit-o home. nici in ziua de azi nu stiu ce sa intimplat cu pisica aia dar sint convins ca soacra-mea era ascunsa si vedea totul, desi eu eram mic si ea nu stia ca va fi mama lu mama lu cosmos junior. acu vreo 9 ani duc eu la tara un motan portocaliu care cistigase la bingo o excursie cu cosmosu. Acolo se executau cirnatii deci timpitu ala portocaliu sare pe cirnati si fuge prin curte cu vreo 2 metri. socrela il aresteaza dintr-o miscare, ii pune catusele si il duce in spatele curtii unde il leaga de un copac. asteptam sa imi dea un cutit sa ii scot ochii dar probabil ca a uitat toata scena. am eliberat motanu care a fugit in vecini unde ce credeti ca a facut? a mai furat un cirnat si de aici nu mai stiu ce i s-a mai intimplat recidivistului. in concluzie eu iubesc animalele dar la ele in mediul lor natural, nu ca pufi al meu care dimineata duminica dadea cu gheara la talpa si se distreaza cum misc eu picioarele pe sub plapuma. de aia nici nu o mai tin pe pufi, acest ciine de lupta cu operatie estetica, l-am mutat la mama unde o duce bine, ca si eu am dus-o bine in tinerete, ma rog, eu nu mincam wiscas.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(6029,657,'adi','adyrotaru@yahoo.com','','89.120.56.7','2007-09-27 10:16:20','2007-09-27 08:16:20','stii ce? ma fut in ea petitie!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(6030,659,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-09-27 10:28:30','2007-09-27 08:28:30','@ DÄƒnilÄƒ: urasc sa-ti dau dreptate, dar ai dreptate, dreptate, dreptate! \r\n\r\n@ VIPu: este o stema vadit grotesca vadit intentionata!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6305,671,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-10-04 09:14:11','2007-10-04 07:14:11','@ lilith: na, ca nijio n-am inca 43 sau 67, cat are Uri. Nasol. Ma simt incomplect.\r\n\r\n@ laurie: ba (Nelu), ce legatura are maritishu\' cu mine? Da\' sincer amu...\r\n\r\n@ Miruna: de ce crezi tu ca am cheltuit o avere ca sa imi cumpar .ro-ul? Finca aparusera impostori! There can be only one! And that very one is me. Ailanti is second henzi. (Pe DC, odata, apare altu cu nicku\' meu; il atentionez, si zice \"nu e adresa mea, dar proprietarul vinde numele cu 500.000, daca te intereseaza!\" Ii zic: \"Aflu adresa de la provider, ca my best friend lucreaza acolo, si iti fac o vizita cu basarabenii, nu ma intere\' ca esti tu sau e altu! Iti aduc io batista sa iti strangi dintii de jos, nu-i stress\" De atunci am ramas singurul Groparu din hub.)\r\n\r\n@ Andre: esti sigura ca jandarii veneau sa te controleze de flotant? Hmmm...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6022,661,'sktes','sktes_2002@yahoo.com','http://sktes.wordpress.com/','79.113.137.222','2007-09-27 01:03:04','2007-09-26 23:03:04','Stirea in sine a avut un efect constipator asupre mea. Randurile mai jos iscalite (adica \"Petitia protevista pentru salvat animalele\" sa fiu coherent), m-au luat pe sus, ca un laxativ. Rezultatul final l-ash fi pus pe blog-ul Verboidului, dar atat respect pentru (mult exagerata) inteligenta umana inca mai am.\r\n\r\nSubscriu la ideea \"jos sarcasmul\", pentru ca si deoarece nu poate fi digerat, interpretat si inteles in acelasi timp si concomitent cu sclipirile geniilor ce infunda buzile electronice.\r\n\r\n@WhiteWolf: tz permitzi sa-i jignesti, facandu-i genii? Pfff. :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(5160,613,'ania','soredarkshines@gmail.com','http://aniakhaki.blogspot.com/','89.123.81.233','2007-08-26 16:54:32','2007-08-26 14:54:32',':)) ploaia care v-a prins pe voi e aia pentru care m-am rugat eu cu o seara inainte cand nu mai suportam caldura si super nunta la care am fost prezenta :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5305,620,'Sa vina Robbie Williams','robilica@yahoo.com','http://robbie-williams.blogspot.com','213.157.188.71','2007-08-30 14:08:32','2007-08-30 12:08:32','io am crezut ca ai identitate ascunsa. cand colo esti la vedere... am crezut ca esti un fel de zorro sau zoso... m-ai dezamagit, gropare. mi-ai spulberat mitu\'!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5249,615,'sabina','','','81.12.163.178','2007-08-29 08:29:41','2007-08-29 06:29:41','errr... counter strike-ul nu e pentru cei care au trecut de 30 de ani?!!',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(5081,603,'angel','elena.siriteanu@yahoo.com','http://angel.saltwaterc.net','62.231.91.55','2007-08-24 13:39:54','2007-08-24 11:39:54','ati uitat vremurile cand Ceasca ne indopa numai cu parizer, huh? si ala din soia.\r\nGropare, cred ca ai sanse sa gasesti carne prin parizer doar daca atunci cand musti din felie iti nimeresti degetul. Cat despre aur.... cred ca poti considera ca ai gasit asa ceva daca ai reusi totusi sa dai de vreo bucata de carne prin parizer (nu degetul tau).',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; iOpus-I-M; .NET CLR 1.1.4322)','',0,0),(5082,601,'angel','elena.siriteanu@yahoo.com','http://angel.saltwaterc.net','62.231.91.55','2007-08-24 13:43:13','2007-08-24 11:43:13',':D baga-i numa`pe-aia din orasul tau. :))',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; iOpus-I-M; .NET CLR 1.1.4322)','',0,0),(5083,608,'angel','elena.siriteanu@yahoo.com','http://angel.saltwaterc.net','62.231.91.55','2007-08-24 13:46:31','2007-08-24 11:46:31','nu-i mai injurati atata ca mai tre si ei sa faca revizie ca dup-aia tipati ca nu aveti apa calda si caldura cand bate viforul la geam a tacere si pustiu ca a plesnit nu`sh ce teava. Si-asa bubuie de vechi ce sunt...\r\nCat despre restul, mai aminteste-ti si tu de-ale copilariei valuri :))))',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; iOpus-I-M; .NET CLR 1.1.4322)','',0,0),(5300,620,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-08-30 10:27:43','2007-08-30 08:27:43','@ curioasa: sa stii ca m-am verificat la pantaloni, sh miroseau a mine! deci eu is.\r\n\r\n@ VIPU: nu le mai zi sh la altii de google!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5301,620,'10MBC','alin.banc@gmail.com','','217.156.21.3','2007-08-30 10:35:21','2007-08-30 08:35:21','Radule, iti zic si eu trei lucruri: Tare\r\nCare o fost a treia chestie de care te-o ferit D-zeu?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5085,609,'macabroo','raduccc@yahoo.com','http://rezistenta.blogspot.com','80.96.196.2','2007-08-24 14:27:32','2007-08-24 12:27:32','Stie sa faca sarmale?',0,'1','Opera/9.23 (Windows NT 5.1; U; en)','',0,0),(5014,601,'pepi','roman.petre@gmail.com','','82.77.126.134','2007-08-23 08:39:01','2007-08-23 06:39:01','Apropo de kisda. Fii atent cu isi schimba numele Benq: http://www.theinquirer.net/default.aspx?article=40449 \r\n\r\nP.S O sa putem zice fara regrete, tocmai mi-am cumparat cea mai tare Qisda :))',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727)','',0,0),(5015,603,'VIPU','ase@yahoo.com','http://vipuri.blogspot.com','213.157.188.71','2007-08-23 09:02:23','2007-08-23 07:02:23','lasa ma parizerili. zaraza mere cu masline. cauta samburii :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5078,556,'RMils','rmils@google.com','http://bigmp3db.com/','202.143.112.252','2007-08-24 12:24:04','2007-08-24 10:24:04','How add your blog to google database?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1)','',0,0),(5079,536,'RMils','rmils@google.com','http://bigmp3db.com/','219.255.36.76','2007-08-24 12:24:55','2007-08-24 10:24:55','How add your blog to google database?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1)','',0,0),(5017,601,'albanezu','mist_ab_2k@yahoo.com','','83.103.154.202','2007-08-23 10:14:59','2007-08-23 08:14:59','pune-ti centrala gropare si da-i in qisda masii de termoficati. sh taie si tajile ce trec pe la tine prin apartament... elea de caldura si aia de apa calda ca oricum is inutile.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5018,601,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-08-23 10:15:02','2007-08-23 08:15:02','Deci mo pepi, tot mereu am zis io ca tu ej kisdos, serios sh frumos!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5019,601,'mishu','mishu@doingtheartwork.com','http://www.doingtheartwork.com','82.77.126.254','2007-08-23 10:15:23','2007-08-23 08:15:23','Ahahahaha, te-o spart decoltata maine-i gata! Vezi de ce nu ii bine sa te tina minte femeile? Ca tzin minte si caloriferu si puishoru\' :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5020,603,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-08-23 10:15:42','2007-08-23 08:15:42','Io creca e un sambure de adevar in ce zici tu!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5734,637,'untitled pe mnz | psihopatu&#8217; din &#8216;96','','http://mnz.balcescu.ro/2007/09/14/untitled-3.php','69.93.255.82','2007-09-14 12:00:11','2007-09-14 10:00:11','[...] nu in ultimul rand de ce iubeste groparu&#8217; femeile? - unele sunt chiar [...]',0,'1','Incutio XML-RPC -- WordPress/2.2','pingback',0,0),(5735,637,'Darius','ibrahim_rom@yahoo.com','http://jeg.ro','82.77.126.159','2007-09-14 12:05:43','2007-09-14 10:05:43','Vreau sÄƒ fiu femeie cu buric Ã®n braÅ£ele tale, Gropare...',0,'1','Mozilla/5.0 (Macintosh; U; Intel Mac OS X; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5023,601,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-08-23 10:55:19','2007-08-23 08:55:19','@ albanezu: mo, imi pun, da as vrea una din aia, CernobÃ¢liana, sa rulez!!!\r\n\r\n@ mishu: sa inteleg ca am un puisor memorabil...?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5024,402,'Nascut din spermatozoizi campioni &raquo; Blog Archive &raquo; Eu sh prietenul meu Vladimir Putin','','http://www.groparu.ro/?p=604','82.103.137.253','2007-08-23 11:43:37','2007-08-23 09:43:37','[...] ce am stabilit o Basescu o relatie sincera, de prietenie si reclama in sistem barter (dÄƒ click aci daca ej mai nou pe sait), m-am hotarat sa tintesc mai sus. Da, mult mai [...]',0,'1','Incutio XML-RPC -- WordPress/2.1.2','pingback',0,0),(5075,608,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-08-24 10:36:46','2007-08-24 08:36:46','Ba DÄƒnÄƒila, hai, ca o inceput sa curge o solutie ca cafiaua azi-dimineata pe robinete, da\' hai numa daca plecam sambata seara inapoi la sighie! ca io maine am nunta. Nu a mea, din cate am opservat',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5304,620,'VIPU','ase@yahoo.com','http://vipuri.blogspot.com','213.157.188.71','2007-08-30 14:07:34','2007-08-30 12:07:34','ma gropare, am vrut numa sa iti spun ce multi razi barzaveni is pe lumea ceasta :P\r\n\r\nca vipuri is putzine... :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5302,620,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-08-30 11:11:16','2007-08-30 09:11:16','@ 10MBC: pai e simplu, e ca cei patru apostoli care fura trei. Deci nu numa\' romanii fura!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5303,620,'macabroo','raduccc@yahoo.com','http://rezistenta.blogspot.com','80.96.196.2','2007-08-30 12:47:49','2007-08-30 10:47:49','Asta e ca aia cu... am dubla personalitate si-o dezvolt pe\'a treia',0,'1','Opera/9.23 (Windows NT 5.1; U; en)','',0,0),(5026,603,'ania','soredarkshines@gmail.com','http://aniakhaki.blogspot.com/','89.123.115.144','2007-08-23 13:07:07','2007-08-23 11:07:07','deci matza mea nu mananca parizer... asta insemna ca nu e comestibil. 0% carne si 100% gust de cauciuc',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5073,608,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-08-24 10:23:07','2007-08-24 08:23:07','@ katmai: mo, deci musai sa imi zici, da\' numa mie daca ti-i rushine de ania, scrie pe sait sa cetesc numa io, ce pm\r\n\r\n@ mishu: ba, ai prekini in sfere inalte? da\' in stratosfere nu ai? da\' in vid, ai?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5074,608,'DÃ£nilÃ£','','','82.77.202.17','2007-08-24 10:25:47','2007-08-24 08:25:47','BÃ£, aj fi vrut sÃ£ trec pe la tine sÃ¢mbÃ£tÃ£ - duminicÃ£... cunojti tu motivu\' ;)...\r\nda\' Ã®n asÃ© conditzii PAS!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5028,603,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-08-23 14:11:11','2007-08-23 12:11:11','@ ania: inteleg... da\' parizeru\' tau mananca pisici?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5029,604,'Andrei Crivat','andrei@andreicrivat.ro','http://www.andreicrivat.ro','89.137.98.13','2007-08-23 14:13:53','2007-08-23 12:13:53','ni ma, ce-n forma e prezidentele lor. se vede ca nu sta la sprituri cu jiji, ca al nost....',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727)','',0,0),(5030,606,'Andrei Crivat','andrei@andreicrivat.ro','http://www.andreicrivat.ro','89.137.98.13','2007-08-23 14:14:50','2007-08-23 12:14:50','ai furat ideea mea, de a inventa verbe ?  MAGARIULE ',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727)','',0,0),(5031,606,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-08-23 14:16:35','2007-08-23 12:16:35','@ Uragan: Hehe! Sa fii matale frumos, destept, ne-paduchios sh la lupta victorios numa\' cat am violat eu limba romana asta, care e sh patria voastra, de alfel...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5032,604,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-08-23 14:17:14','2007-08-23 12:17:14','Apai nu, ca e ocupat sa-i baje supt masa pe Sarkozy sh-alde shele...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5033,601,'The Original Yankee','crisan_emil@yahoo.com','','83.103.128.160','2007-08-23 14:36:10','2007-08-23 12:36:10','si despre cum te-o tzepuit quisdele de la Zapp nu povestesti? sau la recrutarile alora numa\' sa la bashcau te-ai prezentat?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5034,601,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-08-23 14:52:49','2007-08-23 12:52:49','@ Yankee: deci la zapp am fo la o prezentare in fatza la vreo 800 de studenti, sh dupa ce si-o turuit zappii discursele, l-am intrerupt pe vorbitoriu si am zis: de ce ati venit sa ne recrutati din moment ce v-am trimis de vreo 4 ori CV-ul pe sait si nici macar nu v-ati obosit sa imi confirmati primirea, desi va rugasem in acest sens? Moment in care tot auditoriu o inceput sa aplaude, sh eu am iesit de acolo, ca-mi atinsasem scopu\'. Parol c-asa o fost!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5071,599,'katmai','katmai@keptprivate.com','http://www.512kbps.com','195.212.29.187','2007-08-24 09:47:43','2007-08-24 07:47:43','nu te supara frate ... vai ce dor imi e de jocu ala. \r\n\r\nbtw daca stie careva .. aventurile lui habar n-am si-ale prietenilor sai .. format electronic.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7 (CK-IBM)','',0,0),(5072,608,'mishu','mishu@doingtheartwork.com','http://www.doingtheartwork.com','82.77.126.254','2007-08-24 09:59:49','2007-08-24 07:59:49','Imi pare rau gropare, eu nu te mai pot recomanda prietenilor mei culti din sfere inalte care nu poate sa citeasca asemenea monstruozitati de care ei nici macar nu a auzit. Adio!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5036,603,'macabroo','raduccc@yahoo.com','http://rezistenta.blogspot.com','80.96.196.2','2007-08-23 15:28:08','2007-08-23 13:28:08','Ai sanse sa gasesti o gheara sau un degetd e chinez in parizer. Sau o gheara de chinez daca chinezii ar avea gheare. Dar asta nu a fost niciodata dovedit de savanti. Poate si parizerul ar fi galben. Si totusi.',0,'1','Opera/9.23 (Windows NT 5.1; U; en)','',0,0),(5069,607,'katmai','katmai@keptprivate.com','http://www.512kbps.com','195.212.29.187','2007-08-24 09:44:14','2007-08-24 07:44:14','groparu` creativ :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7 (CK-IBM)','',0,0),(5070,604,'katmai','katmai@keptprivate.com','http://www.512kbps.com','195.212.29.187','2007-08-24 09:45:38','2007-08-24 07:45:38','gropare actually trebe sa il admiri pe putin, pentru ca putin, incearca sa scoata rusia din ... ce e acuma, si sa o aduca din nou la rangul de putere. rusia e o tara frumusica si e pacat sa nu fie exploatata. so putin e un om de admirat.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7 (CK-IBM)','',0,0),(5038,607,'Gez','geza@dvis.info','http://groller.info/geza','89.137.112.121','2007-08-23 17:09:05','2007-08-23 15:09:05','\"Sa vorbesti si de-a mea biclÄƒ\" - legat de bicla ta, sper sa participi si tu peste o luna la Critical Mass :)\r\n\r\nDa si tu sfoara-n tzara la cei cu biciclete sa ne adunam cat mai multi. \r\n\r\nSi la multi ani pentru Mile :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5039,602,'Something for my &#8220;apple fanboys&#8221; friends &laquo; Startupping echoes','','http://vladhorby.wordpress.com/2007/08/23/something-for-my-apple-fanboys-friends/','72.232.151.18','2007-08-23 17:21:34','2007-08-23 15:21:34','[...] by vladhorby on August 23rd, 2007   The reason for it here (Romanian). And something [...]',0,'1','Incutio XML-RPC -- WordPress/MU','pingback',0,0),(5066,603,'adi','adyrotaru@yahoo.com','','86.34.227.117','2007-08-24 09:29:12','2007-08-24 07:29:12','@ania\r\nParizerul nu se face din cauciuc, ci din MDM:\r\nDin carnea de pasare dezosata mecanic (gaturi, aripi si picioare tocate pana devin o pasta) se prepara parizerul, crenvurstii, carnatii si pastele de pateu.\r\nhttp://www.adevarul.ro/articole/carnea-mdm-un-produs-cu-risc-crescut-pentru-consumatori/19028',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(5067,608,'katmai','katmai@keptprivate.com','http://www.512kbps.com','195.212.29.187','2007-08-24 09:42:43','2007-08-24 07:42:43','deci lumea e interesata :))))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7 (CK-IBM)','',0,0),(5068,608,'katmai','katmai@keptprivate.com','http://www.512kbps.com','195.212.29.187','2007-08-24 09:43:36','2007-08-24 07:43:36','@ania as scrie ceva pentru tine referitor la dus rece, si sa fac o legatura intre groparu` -&gt; se face mica | ania -&gt; ? dar as fi un porc misogin :)) asa ca prinzi tu aluzia. sorry nu ma pot abtine',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7 (CK-IBM)','',0,0),(5041,607,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','86.105.72.125','2007-08-23 18:02:13','2007-08-23 16:02:13','Mo, da\' ce-i aia Critical Mass? Ii petrecerea aia cu lesbience goale pe biciclete, prin luncile patriei mele?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5086,603,'Femei','pas@yhaoo.com','http://de-aia.blogspot.com','89.137.117.237','2007-08-24 14:43:27','2007-08-24 12:43:27','gropare, dupa ce bei tata sticla samburele ala de adevar se transforma in adevar absolut ;)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.2) Gecko/20070219 Firefox/2.0.0.2','',0,0),(5242,612,'sktes','sktes_2002@yahoo.com','http://sktes.wordpress.com/','79.113.137.88','2007-08-29 02:39:08','2007-08-29 00:39:08','Cole\'s .. fiecare joi, pana joi. Mi se paru unu cunoscut pi\'colo, da nu stiam daca tu sau nu tu. Da pan\' la urma cre ca tu, ca prea semana cu tu. Acu ca ma gandesc mai bine, carnatu asta chiar ma indeamna la foame!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5733,637,'curioasa','totmea@yahoo.com','','86.35.232.96','2007-09-14 11:14:09','2007-09-14 09:14:09','Groparita stie toate astea?\r\n\r\nMultam Gropare ca mi-ai iscat fluturi in stomac. Prea mult de cind nu am mai simtit asta. Deci, Pretiosule, te voi iubi si dori vesnic, si faptul ca nu pot respira cuvintele astea in contact direct cu tine, va fi inca o neimplinire adaugata vietii mele ca femeie. Da\' mah, daca ii fii vreodata in pericol, sa ma strigi de ajutor, ca oi face tot ce trebe sa te salvez, ca esti cu siguranta un individ dintr-o specie pe cale de disparitie (io te-as ocroti prin lege, zau asa).',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(5298,616,'sajata','a@a.com','','82.77.126.254','2007-08-30 10:17:36','2007-08-30 08:17:36','franzela, da\' copirait ai pi puoza? ai pi pula :P!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(5299,616,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-08-30 10:26:58','2007-08-30 08:26:58','Da mo, n-am!\r\n\r\nAsta e de fapt poza cu familia lui MÃ¢rÅ£oagÄƒ zis PÃ¢rÅ£oagÄƒ, famelie din Turda. Mai zic?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5432,625,'mumuland','','','85.204.38.37','2007-09-03 19:11:52','2007-09-03 17:11:52','ba dac bati nevasta nu te mai trezesti a doua zi dimineata langa ea ...  din motivele aztea:\r\n- dimi la prima ora e pro tv care filmeiaza pt stirili di la ora tinti\r\n-mihalelea tatu de la de n ori femeie e acolo si zace deja la tata lumea ca ce de cacat esti\r\n-badea ala care este bre va aparea bre sa ii zice ca vre sa va puie fatza in fatza si sai zaci di cew iai dat borsu pe  nas bre\r\n-si curva stupizelor ce va aparea prin gaura de la poarta 5 de unde face posa....si iti va zice ca fata e sorsa lu smarandescu si ka smarandesku asta e chiar aci in studio si vre sa iti deie ceva.cam ce ai dat tu la neamuri cand teo intebat de maritis.....:))\r\n\r\ndeci de vrei femeie de nevasta faci ase : sfat de la mumuland :\r\n\r\niti aduni pretinii cei mai buni..dai de baut si ii intrebi daka e buna femeia asta.si aia kare stiu.....;)...o sa iti zica iao ba ca e buna nai vazut ce bine fhace hamor hamor hamor...la tazi in dormitorrrrrr..... han tatie pozitiile skarmasutriene...si atgunci o iei....si la propriu si la figurat ...si la metamorfozat\r\n  iz io ma.care io? asta : ;)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(5088,609,'Femei','pas@yhaoo.com','http://de-aia.blogspot.com','89.137.117.237','2007-08-24 14:44:58','2007-08-24 12:44:58','ma, io ma tata gandesc: di ce or fo campioni spermatozoizii aia? si daca aia or fo campioni tu di ce nu participi la turu frantei ma?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.2) Gecko/20070219 Firefox/2.0.0.2','',0,0),(5089,608,'octa','octaviatarnita@yahoo.com','','86.150.58.112','2007-08-24 14:52:03','2007-08-24 12:52:03','ahahahahahaha',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; YPC 3.2.0; .NET CLR 2.0.50727)','',0,0),(5090,609,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-08-24 14:59:48','2007-08-24 12:59:48','@ macabroo: mo, nu stie, dar il pot programa sa lase varza sa creasca\r\n\r\n@ femei: mo, deci spermatozoizii mei or fo campioni finca ala care s-o fecundat nu era cel mai rapid spermatozoid, dimpotriva, kiar putzea locu\' de supt el de putoare ce era; da\' era cel mai dejtept, sh i-o prostit pe ailalti spermatozoizi sa o ia in directia gresita, sh el o vint bine-mersi, sh si-o bagat capu\' in ovul, sau ovar, nu mai stiu, si-o kert coada, sh dupa ceva anishori si-o facut sait. Sh nu, nu poci concura la turu Franciei, finca daca as face sh io ca el, m-ar descalifica. Sh sh is prea putoare ca sa fac turu\' Franciei fara sa m opresc in fiecare podgorie!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5091,608,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-08-24 15:03:34','2007-08-24 13:03:34','@ Angel: mo, da\' mie niciodata nu mi-i frig iarna, finca beu palinca! Plus ca io n-am auzit in nici o tzara cu pretentii (ma refer la tarile alea ioropene care or tot invadat Africa) CA reparatiile LA TRI Å¢Ä‚VI sa dureze un catralion de zile, sh sh fara sa PUIE DREQ UN ANUNT, SA STIU SI IO SA NU MAI TRANSPIR!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5257,618,'10MBC','alin.banc@gmail.com','','217.156.21.3','2007-08-29 11:22:00','2007-08-29 09:22:00','Celor care pretindeti plata in natura de la elevele, studentele care, fortate de parinti, trebuie sa ia o nota mare am un singur mesaj pentru voi: daca ati fi in fata mea pe strada, va jur ca as testa acceleratia masinii mele pe loc (si va zic in avans ca nu am logan).',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5258,608,'angel','elena.siriteanu@yahoo.com','http://leoaica.wordpress.com','82.77.83.83','2007-08-29 11:26:37','2007-08-29 09:26:37','eu nu-s domnisoara. si tot nu m-am putut abtine.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(5259,618,'ss','criss_team@yahoo.com','','81.196.150.198','2007-08-29 11:38:22','2007-08-29 09:38:22','@10mbps: profi sariti de pe fix, neintelesi in imensa lor genialitate, am intalnit cu totii si se gasesc peste tot. da la partea cu hudrea tre sa spun ca ai luat-o pe aratura. io nu l-am cunoscut personal da stiu mai multi elevi (nu 1 sau 2) care s-o inteles chiar bine cu el. deci la faza asta n-ai ce face, esti frustrat si asa o sa ramai...de ce? pt ca \"nu ai stiut matematica deloc\". cand recunosti singur ca esti pe dinafara da totusi sari la gatu unuia numa pt ca nu ti-o facut pe plac..asta se numeste frustrare.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7','',0,0),(5260,618,'10MBC','alin.banc@gmail.com','','217.156.21.3','2007-08-29 11:44:39','2007-08-29 09:44:39','Ultimul comentariu pe tema asta: Nu stiam mate intr-a 12-a pentru ca hudrea m-a facut varza din a 9-a pana in a 11-a. Tot din vina lui a trebuit sa plec de la Li.CJ. Imi pastrez parerea. Eu m-am referit la el ca prof. Nu am reusit sa il inteleg niciodata. ULTIMUL COMENTARIU, nu mai am nimic de spus de el',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5261,618,'macabroo','raduccc@yahoo.com','http://rezistenta.blogspot.com','80.96.196.2','2007-08-29 11:59:10','2007-08-29 09:59:10','@10MBC - bag sama ca loganu a devenit un standard pentru siguranta si confort, gen. Aprige vremuri traim.',0,'1','Opera/9.23 (Windows NT 5.1; U; en)','',0,0),(5294,620,'VIPU','ase@yahoo.com','http://vipuri.blogspot.com','213.157.188.71','2007-08-30 09:34:13','2007-08-30 07:34:13','http://www.google.ro/search?num=100&amp;hl=ro&amp;client=firefox-a&amp;rls=org.mozilla:en-GB:official&amp;hs=UPe&amp;sa=X&amp;oi=spell&amp;resnum=1&amp;ct=result&amp;cd=1&amp;q=%22radu+bazavan%22&amp;spell=1',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5263,618,'10MBC','alin.banc@gmail.com','','217.156.21.3','2007-08-29 13:34:14','2007-08-29 11:34:14','@macabroo: vroiam sa subliniez ca am o masina mai rapida decat un logan. Asta era ideea. Adica mult mai eficienta in lovirea personajelor mai sus mentionate. Daca tot veni vorba: infinit mai confortabila, cu un nivel muult mai mare de siguranta. Ar trebui sa te chinui serios ca sa o rastorni (nu am vazut o astfel de masina rasturnata). Loganul mi se pare intruchiparea prostiei omenesti (sau romanesti?). Nu ma intrebati de ce. Slaba  calitate cumparata pe bani multi.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5264,618,'10MBC','alin.banc@gmail.com','','217.156.21.3','2007-08-29 13:35:46','2007-08-29 11:35:46','@ss sa stii ca 10mbc insemna ceva. 10 mbps inseamna altceva. Probabil dupa orele lui hudrea...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5276,619,'angel','elena.siriteanu@yahoo.com','http://angel.saltwaterc.net','86.127.9.212','2007-08-29 20:14:53','2007-08-29 18:14:53','care e intrebarea zilei? ca e doua!!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; iOpus-I-M; .NET CLR 1.1.4322)','',0,0),(5277,620,'Emaginatoru','e_magist@yahoo.com','','79.113.140.211','2007-08-29 21:35:58','2007-08-29 19:35:58','Tana na na! Tana na na! Parca ie Zona crepusculara.\r\nDoo lucruri ie clar:\r\n1.Dupa cum e scris articolul ( cum e in engleza: \"piece of blog\"?), eu sunt sigur ca tu esti, nu celalalt.\r\n2.Daca guglezi dupa \"radu bazavan\" nu o sa mai gasesti pagini cu beingapro ci te da direct pe groparu.ro si de-aci nu mai pupi tu nici un giob ca nime nu ar angaja asa diliu.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; en-GB; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5279,619,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','86.105.72.125','2007-08-29 23:05:23','2007-08-29 21:05:23','@ ss: deci de la Nistru pan\' la Tisa, toata MISA pishu-mi-s-a!\r\n\r\n@ angel: pai da mah, da-s mai multe zile!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5280,620,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','86.105.72.125','2007-08-29 23:12:27','2007-08-29 21:12:27','Mo, deci faza e pe bune: kiar am primit mail de la un ficior care e bucurestean, sh il kiama ca pe mine, un nume greu de retinut, da\' nume de care is foarte mandru finca rimeaza cu struna, manz, mistretz, viezure, varza, bazavan! Sh l-am sh sunat.\r\n\r\n1. Sh io is sigur ca io is, finca tocmai ce ma pipaii, sh-mi placu; \r\n2. Cu angajatu - nu-i stress, ca poate ma angajeaza o firma de bloguri care vrea sa deie faliment!!! :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5282,618,'ania','soredarkshines@gmail.com','http://aniakhaki.blogspot.com/','89.123.76.240','2007-08-29 23:25:44','2007-08-29 21:25:44','s-a trecut la struguri?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5441,626,'mumuland','','','80.97.64.199','2007-09-04 09:27:47','2007-09-04 07:27:47','zac ase...ca esti pa sama bolund...dai sfaturi de astea la fomei ....norok ka nai dat nr de telefon de la azociatzia aia nu die alta da cand nie mai intoarciem betzi ...di la sedintza,delegatzie.fiecare cu scuza lui....rizcam sa gasim akasa   ninjalai si samuraite...sau oarece luptatatoare de restling de ala ...si io prefer  o luptatoare reasling de jidvei...  :)...ca fiecare are un razboi die dus...vb aia a poetului pilosofului,matematicianului...sau ce o hi\r\n\r\ndeci inceteaza sa mai faci aci pe siteul tau training pt fomei cu barbatzi betzi  :)..mai bine punie de organizeaza un team beatu-ning cu baitezii ca sa nie cunoastem mai binie...\r\n\r\n\r\niz io ma.care io? asta :  ;)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12','',0,0),(5442,626,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-09-04 10:03:21','2007-09-04 08:03:21','@ 10mbc: ye, mah, da\' daca vor iubire? ce ne facem?\r\n\r\n@ mumuland: mo, n-are cum femeile noastre sa iasa din bucatarie sh sa ceteasca ce scriu io, sh sh daca cetesc, io am invatzat doo kestii de la onor prezident romanesc: iarna nu-i ca vara; sh Romunica nu e Danemarca! Cat despre rendezvuuri prelungite de berule sh alea... stai numa sa ma scutur de munca asta care ma sugruma ;) (ma, da\' sigur tu ej?)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5443,626,'10MBC','alin.banc@gmail.com','','217.156.21.3','2007-09-04 11:18:49','2007-09-04 09:18:49','Pai le fraierim ca le dam asta pana nu mai au de ales. prectic, nu?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5444,622,'alexier','alexier_90@YAHOO.COM','','89.35.116.70','2007-09-04 12:17:46','2007-09-04 10:17:46','gropare u ejty din cisnadie ca atuncia  sar puteam sa avem aceeasi origine? sii bha intereseazate cat ii un avion pana acolo sa merem sa vedem si noi alte nationalitati in plm',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; DigExt)','',0,0),(5761,639,'Luna Betiluna','mihdana@yahoo.com','','92.80.93.48','2007-09-15 13:07:49','2007-09-15 11:07:49','a, muzica a fost excelenta  !!! a bagat-o don`soara sau t-ai pus-o singurel?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5446,627,'ss','criss_team@yahoo.com','','81.196.150.198','2007-09-04 15:35:28','2007-09-04 13:35:28','si se sconcspromite in ochii sconcsatenilor sai.\r\n\r\n\r\nsi daca tot ne aflam la pagina cu intrebari: ce se intampla cu un magazin alimentar care da faliment?\r\n\r\ndevine magazin f-alimentar. \r\n\r\n..nici o legatura cu euromarketu din statie de pe memo unde de vro doua luni mai activeaza o vanzatoare care tine deschis pana se vand si ultimele 2 vopsele de par, 3 baterii, 2 conserve si 6 boabe de piper negru.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7','',0,0),(5762,640,'The Original Yankee','crisan_emil@yahoo.com','','89.43.186.64','2007-09-15 14:04:27','2007-09-15 12:04:27','auzi, cine is alea 6 colege lesbience ca io nu le jtiu?\r\nla mine te-ai gandit?\r\nL.O.L.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5763,640,'Arhi','cetin.ametcea@gmail.com','http://arhiblog.com','82.79.69.62','2007-09-15 16:30:37','2007-09-15 14:30:37','bade, tu lucri cumva la firma care incepe cu p si se termina cu ps si vinde electronice??',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5451,626,'baghy','baghy83@lycos.it','http://baghy.info/','78.12.19.252','2007-09-04 19:47:23','2007-09-04 17:47:23','tot timpul ma faci sa rad.chiar nu stiu de unde le mai scoti',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(5452,629,'Mocanu','asdwww@yhaoo.com','http://arieseni.blogspot.com','89.137.122.190','2007-09-04 20:50:00','2007-09-04 18:50:00','uita-te ma si tu la porno. lasa cacaturile astea!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.2) Gecko/20070219 Firefox/2.0.0.2','',0,0),(5453,627,'Mocanu','asdwww@yhaoo.com','http://arieseni.blogspot.com','89.137.122.190','2007-09-04 20:51:38','2007-09-04 18:51:38','gresit!\r\n\r\nraspunsul corect: \"pute\"',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.2) Gecko/20070219 Firefox/2.0.0.2','',0,0),(5454,629,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','86.105.72.125','2007-09-04 21:28:55','2007-09-04 19:28:55','Uita-te tu! Io prefer sa FAC porno.\r\n\r\nGropatsch. The others just watch.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(6008,405,'Nascut din spermatozoizi campioni &raquo; Blog Archive &raquo; Tiganiada - Memento','','http://www.groparu.ro/?p=659','82.103.137.253','2007-09-26 18:32:44','2007-09-26 16:32:44','[...] cei care nu stie: click acilea ca sa aflati despre cheful nostru in care ne imbracam in tigani sh ne doare la pedala de [...]',0,'1','Incutio XML-RPC -- WordPress/2.1.2','pingback',0,0),(5765,637,'Lexis','g_lexis2005@yahoo.com','http://www.alexandraghitalexis.blogspot.com','89.38.76.46','2007-09-15 19:43:06','2007-09-15 17:43:06','Aici a scris un om indragostit... de o femeie :)) zic eu :-B ha! fuarte interesant....',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.2) Gecko/20070219 Firefox/2.0.0.2','',0,0),(5766,640,'xxx','laaprozar@gmail.com','http://aprozar.blogspot.com/','80.96.133.209','2007-09-15 20:28:46','2007-09-15 18:28:46','asteptam poze cu cele 6 colege lesbinece. in excercitiul functiunii',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; SLCC1; .NET CLR 2.0.50727; Media Center PC 5.0; .NET CLR 3.0.04506; FDM)','',0,0),(5768,640,'nenea cosmos','','http://neneacosmos.wordpress.com/','92.80.13.105','2007-09-15 22:31:34','2007-09-15 20:31:34','la ora asta cind deja faci bildin de ala gretos cu minutzele pe lezbiste, mort de beat si cu 83 de pastravi deja pescuiti, sa multumesti lu Doamne Doamne care e sus si vede tot ca are conexiune buna ca nu joci la o pravalie cu santiere cum fac eu, unde la tim bildin ne uitam pe geam dupa pensionarele care trec prin preajma caci femei canci, iar in ceea ce priveste somnul de lunea m-am interesat, esti obscen rau, cica e interzis prin lege.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(5293,620,'curioasa','totmea@yahoo.com','','86.35.232.96','2007-08-30 09:07:03','2007-08-30 07:07:03','mno buuuun.. da\' din astia doi tu esti ala...UNICU. da?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(5158,612,'Vreau pe Robbie','robbie@yhaoo.com','http://robbie-williams.blogspot.com','89.137.117.237','2007-08-26 15:54:54','2007-08-26 13:54:54','misto carnatz :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.2) Gecko/20070219 Firefox/2.0.0.2','',0,0),(5467,629,'mishu','mishu@doingtheartwork.com','http://www.doingtheartwork.com','82.77.126.254','2007-09-05 10:01:52','2007-09-05 08:01:52','Eu sunt de parere ca sa isi dea foc toti romanii plecati in afara... In ultima vreme vad ca suntem intoxicati cu stiri de rau de cetatzenii care au luat drumul europei. Sunt sigur ca sunt si oameni care fac lucruri extraordinare in cercetare si stiinta sau pur si simplu isi vad de treaba. Dar aia nu sunt spectaculosi pentru jurnalistii de 2 lei romani (si nu numai). Pamant! Pe foc toata lumea!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5468,629,'Andreea MKT','supergirgir@yahoo.com','http://marlahermina.deviantart.com/gallery/','82.77.126.254','2007-09-05 10:13:58','2007-09-05 08:13:58','oki, pt mishu si radu si toti\r\n\r\ndar s-a gandit cineva dintre voi cetateni onorabili cu slujbe bune, s-a gandit careva in ce hal de disperare era omu ala de si-a dat foc?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(5469,629,'admin','groparu_ro@yahoo.com','http://','82.77.126.254','2007-09-05 10:29:17','2007-09-05 08:29:17','@ Andrea MKT: http://www.jurnalul.ro/articole/101530/se-cauta-150000-de-muncitori',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,1),(5470,629,'Andreea MKT','supergirgir@yahoo.com','http://marlahermina.deviantart.com/gallery/','82.77.126.254','2007-09-05 10:47:48','2007-09-05 08:47:48','@admin: mersi d site dar asta nu explica fapta omului. mai vinovata mi se pare marmota aia care si-a abandonat copilashul.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(5471,630,'baghy','baghy83@lycos.it','http://baghy.info/','78.12.19.252','2007-09-05 11:13:25','2007-09-05 09:13:25','se mai intampla.:))si eu sunt scorpion.vezi ca ai o leapsa de la mine.fa bine si fa ce zice acolo ca sunt curios',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(5472,630,'Sorinelu\'','sorinelm@gmail.com','','210.131.161.21','2007-09-05 12:15:27','2007-09-05 10:15:27','POC !! POC !! POC !! pfu!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) )','',0,0),(5473,630,'bicplayer','bic_player@yahoo.com','','86.125.169.80','2007-09-05 12:38:29','2007-09-05 10:38:29','da ce itzi mai place sa precizezi k \"locuiesc supt mine\" :-P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5437,626,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','86.105.72.125','2007-09-03 22:43:07','2007-09-03 20:43:07','Io numa atata zic:\r\n\r\nYou can be a king or a grim reaper,\r\nBut everybody dances with the sweeper!\r\n\r\nNuz, mah, is vai de natia mea, nu vezi ce fac astia cu noi?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5438,626,'10mbc','alin.banc@gmail.com','','89.137.122.141','2007-09-03 23:02:04','2007-09-03 21:02:04','Poate practicau putin SM, ce stiti voi... Tanti nu a fost satisfacuta de situatie. Tipul era prea egoist, astfel tanti si-o bagat .... semnatura in divort. Cu alte cuvinte, daca femeile vor bataie, dati-le oameni buni!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5394,624,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','86.105.72.125','2007-09-02 21:30:19','2007-09-02 19:30:19','@ss: n-am bagat ciardashe, ca or fo numa\' neamuri d-alea care m-or piscat de obrajori, ca ui ce mare m-am facut...\r\n\r\n@danila: Ce mah??? Las\' ca ne intalnim noi sh vez tu numa cum iti rup io tie mana sh te bat cu ea!!! Sh-apa tz-o infig in anus sh iti dau sa miroshi!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5050,608,'The Original Yankee','crisan_emil@yahoo.com','','85.186.13.34','2007-08-23 21:08:56','2007-08-23 19:08:56','daca mai tine chestia asa vro saptamana, io zic ca linistit poti sa meri la ei si sa te-asezi in fata la regizor (directorul regiei adeca), sa ridici elegant bratele sa te scarpini antiorar la ceafa, si sa zici noah, fraere, asa-i ca n-ai primit in vieata vietii tale reclamatie mai imputita?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5466,629,'Andreea MKT','supergirgir@yahoo.com','http://marlahermina.deviantart.com/gallery/','82.77.126.254','2007-09-05 09:55:49','2007-09-05 07:55:49','1. eu nu mi-as da foc niciodata si daca ma dai afara de la servici, tu, radule, ca te-ai saturat sa ne vezi pe mine si pe jojo cum iti batem in geam\r\n\r\n2. dru a mea (care mai nou se numeste minerva) nu va avea veci o punga in cap, eventual tu ca nash si o casa faina si 2 parintzi iubitori:)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(5052,608,'ania','soredarkshines@gmail.com','http://aniakhaki.blogspot.com/','89.123.72.21','2007-08-23 21:39:31','2007-08-23 19:39:31','si eu am facut dus cu apa rece. aia de la distrigaz au inchis conducta de la 9-16 pe hartie si acum e aproape 23 si inca nu avem gaz :(',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5465,629,'albanezu','mist_ab_2k@yahoo.com','','83.103.154.202','2007-09-05 09:31:05','2007-09-05 07:31:05','No ni ma gropare stire: http://www.romanialibera.ro/a105300/sindicalistii-din-rat-cluj-cer-demisia-conducerii.html\r\nVezi, bine ca nu te-ai angajat acolo!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5054,603,'MaTr3o','matr3o@gmail.com','http://matr3o.com','89.122.243.97','2007-08-23 23:57:46','2007-08-23 21:57:46','parizer, noua promotie pufuleti cu surprize.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5463,629,'Hammer','pontos_a@yahoo.com','','86.120.55.79','2007-09-05 09:14:33','2007-09-05 07:14:33','Stiri date la diversiune...crumpene date porcului ca sa nu simta cum ii taie stapanu\' din shorici.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(5464,629,'angel','elena.siriteanu@yahoo.com','http://angel.saltwaterc.net','82.77.83.83','2007-09-05 09:18:41','2007-09-05 07:18:41','inainte, pe vremea lui Ceasca, cu greu faceai rost de un film de groaza ca sa ai parte de senzatii tari :D. Acum e de ajuns sa te uiti la stiri si ti se face rau. Eu nu inteleg de ce se dau pe post asemenea grozavii. Oare romanul este chiar atat de ahtiat dupa stiri de genul asta?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(4998,599,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','86.105.72.125','2007-08-22 18:37:15','2007-08-22 16:37:15','@ all: mersi de urari, ashijderea sa avetz sh voi parte de niepotz sh niepoate gropareshti, sh tu, bÄƒ CÄƒlÄƒ\', nu mai vorbi ca maica-mea!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4999,597,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','86.105.72.125','2007-08-22 18:49:23','2007-08-22 16:49:23','@ all: DECI BA, IO NU PRE-S OBIJNUIT CU OSANALE, FINCA STIU MAI BINE DECAT TOTI CA NU VALOREZ NICI MACAR DOI LEO VECHI, SH SCUZE DE CAPS, CA NUMA AMU AM VAST, SH VA MAI ZIC CA MI-I TARE FRICA CA GLORIA ASTA SUBITA SA NU-MI SUBMINEZE BRUMA AIA DE INSPIRATIE CARE POPOSI PE LA MINE! Ca fiind de gen feminin, pun pariu ca e la fel de nestatornica ca pfuaaay, cate fomei!\r\n\r\n@ varzaru\': Deci mo, e clara treaba la fel pe cat e de oabla: joi e seara de autograf, pe memorandumului, ca se canta laiv melodii d-alea bashite de folk, cu isvoarem frunze sh iubiri cand itz clantzane dintii in gura in cort, la munte! Ia legaturile cu Oedip, ca asta deja stie, ca l-am tribalizat.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5315,622,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','86.105.72.125','2007-08-30 16:44:25','2007-08-30 14:44:25','@ macabroo: mo, deci io nu cred ca stie careva ce fac alea cu papurile alea, ca nij dreq nu se uita la trestii!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5316,621,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','86.105.72.125','2007-08-30 17:07:02','2007-08-30 15:07:02','Nu e mah svreaj!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5317,620,'Adi Calarasu','acalarasu@gmail.com','http://adriancalarasu.wordpress.com/','89.32.19.126','2007-08-30 20:46:34','2007-08-30 18:46:34','Uite-l pe Gropu la bureau.\r\nHaidi maaa, ca nu esti ase batran! Sau, de cand e poza aia? :)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(5065,608,'sabina','','','81.12.163.178','2007-08-24 08:47:33','2007-08-24 06:47:33','e chiar asa de mica? ;;)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(5804,637,'Ionut','stiegroparu@yahoo.com','','82.77.126.254','2007-09-18 12:28:28','2007-09-18 10:28:28','Ma bag sama ca tu vrei si sa te insori si sa faci copii....nostalgiile astea numai atunci te apuca ... da ar trebui sa scrii odata si reversul ...de ce urim femeile ..asta asa ca sa-ti treaca criza',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727)','',0,0),(5802,105,'lilith','marcu_luiza@yahoo.com','http://www.aberatiunti.blogspot.com','82.77.126.148','2007-09-18 10:09:08','2007-09-18 08:09:08','pfiu!!! m-am scos! macar la sex sa am dezlegare... :)) da sa stii ca nu imi place soia... exista inlocuitori? brrr',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5308,56,'anonim','','','82.76.17.224','2007-08-30 14:54:29','2007-08-30 12:54:29','Ce frumos!\r\n\r\nCe credeti, ce sanse are o relatie intre doi colegi programatori (de sex opus, bineinteles)?\r\nAr fi oare prea de tot? Sau poate sa mearga...?\r\nIntreb si eu....sunt curioasa si de parerile altora, mai ales a celor in cauza, dar nu numai.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(5309,622,'10MBC','alin.banc@gmail.com','','217.156.21.3','2007-08-30 15:46:11','2007-08-30 13:46:11','Virgine = fara experienta.. Ce-or fi vazand astia in virgine?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5310,622,'pepi','roman.petre@gmail.com','','82.77.126.134','2007-08-30 16:04:17','2007-08-30 14:04:17','Tot ce-i bun are si partea lui proasta:\r\n- 13 sotii: pai noi nu putem duce nici una, daramite atatatea (si e si cu ghinion pare-se)\r\n- Fiica sa cea mare, prinÅ£esa Sikhanyiso, Ã®n vÃ¢rstÃ£ de 17 ani, va conduce anul acest â€ždansul trestiilorâ€. Aici nici nu stiu ce e mai rau: sa-ti fie fata vazut-o cu tot ce are ea mai scump, sau sa te bucuri ca inca se incadreaza la dans ;).\r\n\r\nP.S. Unde ziceai ca-s tipele alea cu sloganu?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727)','',0,0),(5311,622,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-08-30 16:14:00','2007-08-30 14:14:00','@ 10 MBC: man, amu... nu poci a-ti explica, ca e public saitu\', sh ma leaga astia!\r\n\r\n@ Pepe: http://mituriurbane.vira.ro/mituri-urbane/94/sloganul-muncitoarelor-de-la-apaca/',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5312,621,'macabroo','raduccc@yahoo.com','http://rezistenta.blogspot.com','82.76.52.94','2007-08-30 16:27:18','2007-08-30 14:27:18','Clar sevraj.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5313,622,'macabroo','raduccc@yahoo.com','http://rezistenta.blogspot.com','82.76.52.94','2007-08-30 16:34:12','2007-08-30 14:34:12','Deci fain, dar:\r\n\r\n1. ce fac pana la urma cu trestiile?\r\n2. pun pariu ca n-ai loc sa arunci ochiul de cati scout-eri de la echipe mari sunt\r\n3. ce faci cu virginele care au SIDA virgina?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5774,640,'IepurasulAtomic','praetorian21uk@yahoo.com','','62.217.245.97','2007-09-16 09:29:42','2007-09-16 07:29:42','Bah Gropare, vezi ca bag sama ca ti-o fujit 2 lezbiene din alea de le ai tu acolo(care este), ca io le-am vazut aseara in club(nu spui care, ca cica fac reclama). Si am si-o intrebare, care de fapt vor fi 2(adica doua, nu doi): la ce mama curului de firma lucrezi tu ma de aveti atatea zile de tim bilding? Si 2(adica doi): cum facem sa ma angajez si io acolo, ca la firma mea tim bildingu\' o tinut fix o zi si cea mai mare atractie(pe langa painball) o fost c-am facut io striptease si-o incercat sa ma violeze o fana. N-o reusit, da\' cre\' ca inca n-o renuntat la idee....',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(5141,609,'VIPU','pas@yhaoo.com','http://vipuri.blogspot.com','89.137.117.237','2007-08-26 02:02:37','2007-08-26 00:02:37','da tu de unde stii sub cine o murit ecaterina ma?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.2) Gecko/20070219 Firefox/2.0.0.2','',0,0),(5475,630,'ss','criss_team@yahoo.com','','81.196.150.198','2007-09-05 13:38:18','2007-09-05 11:38:18','da, esti un animal insensibil. meriti sa arzi in focurile iadului tanjind la canceru ce va sa vie odata cu glaciatiunea planificata dupa incalzirea asta globala (oare chiar i globala sau numa pe alocuri?..)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7','',0,0),(5459,629,'mumuland','','','80.97.64.199','2007-09-05 07:48:57','2007-09-05 05:48:57','mie cand sa incendiaza oamenii imi plac scenele cu aia care baga fitile:\r\n\r\nsuparatu zace:  hai ma da cu benzina k lume pe tine nu te face ce drecu hii barbat\r\n\r\n baba zace:  hai maica datzi foc ca di la 4 ne tii aci pa tati..suntem batrani dati foc ca ne dor piciorele de atata stat\r\n\r\ntanaru liceean smecher zace:   lasa baba ca dak nu isi da foc in zece minyte iii dam noi ce pola me..\r\n\r\nsasa mai diparte...\r\n\r\niara cu mama aia cu coptilul ase zac si io.de gat stransa pina more..si dat la centru de ekariszaj .sa faca pedigree din ea:)\r\n\r\n\r\niz io ma.care io? asta:  ;)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12','',0,0),(5318,622,'ania','soredarkshines@gmail.com','http://aniakhaki.blogspot.com/','89.123.88.33','2007-08-30 21:28:06','2007-08-30 19:28:06','si eu vreau o virgina :) sa fac baie in sangele ei :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5125,610,'Femei','pas@yhaoo.com','http://de-aia.blogspot.com','89.137.117.237','2007-08-25 17:31:09','2007-08-25 15:31:09','lasa ma gropare ca cioplesti tu cu brishca ;)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.2) Gecko/20070219 Firefox/2.0.0.2','',0,0),(5126,609,'Femei','pas@yhaoo.com','http://de-aia.blogspot.com','89.137.117.237','2007-08-25 17:32:35','2007-08-25 15:32:35','no bine ma gropare. is dezamagit. ramai tu la turu pietei mihai viteazu in juru fastfudului chinezesc... mediocrule :(',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.2) Gecko/20070219 Firefox/2.0.0.2','',0,0),(5127,608,'VIPU','pas@yhaoo.com','http://vipuri.blogspot.com','89.137.117.237','2007-08-25 17:33:25','2007-08-25 15:33:25','ce pula mea vorbesti asa urat ma? :(',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.2) Gecko/20070219 Firefox/2.0.0.2','',0,0),(5128,607,'VIPU','pas@yhaoo.com','http://vipuri.blogspot.com','89.137.117.237','2007-08-25 17:34:43','2007-08-25 15:34:43','paunescule!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.2) Gecko/20070219 Firefox/2.0.0.2','',0,0),(5129,610,'VIPU','pas@yhaoo.com','http://vipuri.blogspot.com','89.137.117.237','2007-08-25 17:35:56','2007-08-25 15:35:56','coaiele ca coaiele, da locu pentru putza di ce ii asa subtire?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.2) Gecko/20070219 Firefox/2.0.0.2','',0,0),(5256,618,'10MBC','alin.banc@gmail.com','','217.156.21.3','2007-08-29 11:17:12','2007-08-29 09:17:12','Daca esti un prof care, prin exigenta lui, mai face victime e ok. Dar daca fiecare zi este un nou inceput pentru a tortura saracii elevi care nici nu mai stiu bine pe ce lume is sau cum se agatza o tipa pentru ca tot liceul au invatzat la mate, atunci urarile mele va sunt adresate: Ma fut in voi retardati ordinari care va descarcati toate frustrarile pe elevi.  Prima data urarile de \"bine\", dupa aceea urarile de bine.\r\nDomnule Hudrea care ai terorizat generatii intregi de elevi, iti doresc sa nu te odihnesti in pace acolo unde esti, ci sa faci probleme imposibile la matematica si sa te gandesti de ce nu te place nici un elev.\r\nDoamna profesoara de istorie, care ati incercat din rasputeri sa ma lasati corijent pentru a nu imi da bacul de la CTTT (nu va stiu numele) va dati seama ca sunteti atat de proasta incat nici un tip nu s-a complicat cu dvoastra. Poate daca nu va rasturnam bancile de nervi ca mi-ati dat 4 la o lucrare de nota 9 (reverificata de alt prof), nu ati fi incercat asta. mi-a placut fatza dumneavoastra cand directoarea v-a spus clar: \"Domnul Banc trebuie sa promoveze acum\". Ce pula mea... daca dumneavoastra credeti ca faceti ce vreti, eu v-am aratat ca pot sa fac mai multe decat dumneavoastra. \r\nCam aici se termina clasamentul \"futezi mintile copiilor\".\r\n\r\nUrmeaza clasamentul \"profi adevarati\"\r\nGropare, te-as pune pe tine aici, dar nu pot, pentru ca nu te-ai comportat ca un prof ordinar niciodata. (a propos, ti-s dator cu o cafea de aia la care te fura vanzatoarea)\r\nProfa de mate, care desi nu am stiut matematica deloc, mi-a dat 7 pe al doile semestru ca sa imi iasa 5 dupa 3-ul pe primul. - Mare doamna\r\nProful de fizica din Li.CJ care, desi mai are scapari cand il calci pe coada, il respect intr-un mod deosebit. (la TOATE tezele la fizica am luat 3, dar nu conteaza).\r\n\r\nGropare, scuze de postul asta asa mare, dar a trebuit... asta e.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5131,609,'Groparu','Groparu','http://Www.groparu.ro','62.217.247.247','2007-08-25 19:14:59','2007-08-25 17:14:59','Gresit! Se zice \'subtalentato\', la fel cu Ecaterina Teodoroiu, care o murit sublocotenent',0,'1','SonyEricssonK800i/R1JC Browser/NetFront/3.3 Profile/MIDP-2.0 Configuration/CLDC-1.1','',0,0),(5254,618,'katmai','katmai@keptprivate.com','http://www.512kbps.com','195.212.29.163','2007-08-29 10:34:25','2007-08-29 08:34:25','vreau sa fiu prof :))))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7 (CK-IBM)','',0,0),(5228,615,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-08-28 16:39:04','2007-08-28 14:39:04','Mo, ziceau ceva de o chestie mica si dotata, cu ceva creier prin ea. \r\n\r\nPS: Nu pot sa nu opserv cum imi fortzatzi mana sa scriu numai continut de adulti pe acest site! Ntz ntz ntz...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5229,615,'ss','criss_team@yahoo.com','','81.196.150.198','2007-08-28 17:39:47','2007-08-28 15:39:47','nici o problema, it\'s safe, ca minorii is ocupati cu counter strike-u si cu pornosagurile..',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7','',0,0),(5134,610,'Radu M.','radu_muri@yahoo.com','http://theblacklight.wordpress.com/','79.113.139.151','2007-08-25 20:51:56','2007-08-25 18:51:56','Locul pt putzishca e asa subtire pt ca e facut pt Herr Gropar dupa ce i-au taiatu` aia apa calda..:]',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7','',0,0),(5739,639,'lilith','marcu_luiza@yahoo.com','http://www.aberatiunti.blogspot.com','82.77.126.148','2007-09-14 15:29:56','2007-09-14 13:29:56','hai ca esti simpatic! am ras cu lacrimi! cu siguranta te voi mai citi, ca e tare funny! :D ;)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5235,615,'macabroo','raduccc@yahoo.com','http://rezistenta.blogspot.com','82.76.52.94','2007-08-28 20:46:20','2007-08-28 18:46:20','Deci au trebuit sa \"intre\" in egztraterestra ca sa decrete ceva. :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5414,624,'galatzi','road2h3ll@yahoo.com','http://galatzy.nabelea.com','82.78.82.95','2007-09-03 09:24:30','2007-09-03 07:24:30','Cu sau fara voia ta gropare, eu te bag in ... blogroll ... \r\n\r\nS-or mai vazut ardeleni in blogroll la moldoveni ??? \r\n\r\nSemnat, Blogarul cu numi di orash',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5751,637,'Nea Gogu','','','84.232.145.219','2007-09-14 23:38:11','2007-09-14 21:38:11','- mÃ¢inile sunt totdeauna reci, cÃ¢teodatÄƒ catifelate. Au nevoie de cÄƒldura palmei tale (masculine, bÄƒtÄƒtorite)... hmmm...\r\n- ar mai fi modalitÄƒÅ£i ÅŸi unelte de mÃ¢ngÃ¢iat... cu sprÃ¢ncenele!? ai timp de pierdut?!\r\n- sigur ai timp de pierdut!\r\n- fiind tot timpul rÄƒcite (vezi punctul urmÄƒtor) poÅ£i respira aerul din bornÄƒul lor, mirosind a Oly**h sau altele asemenea\r\n- le e frig tot timpul. punct.\r\n- sÃ¢mbure de pepene-buric = prefectura-... era ceva...\r\n- dacÄƒ nu au o coroniÅ£Äƒ de pÄƒr aspru!\r\n- dacÄƒ sughiÅ£i Ã®Å£i revine gustul berii de dinainte de a pupa arÄƒtarea.\r\n- Ã®Å£i oferÄƒ fruntea, cÄƒ restul le-o pupÄƒ celÄƒlalt\r\n- ÅŸi singura. restul... dÄƒ doamne sÄƒ fie epilatÄƒ!\r\n- ÅŸogore :)\r\n- paparudÄƒ? parcÄƒ aÅŸa-i zice!\r\n- hmmmm... nu! pentru cÄƒ sunt vulgare cÃ¢nd Ã®ncearcÄƒ sÄƒ fie sexy.\r\n- gem tot timpul. ÅŸi tot timpul le doare ceva!\r\n- dacÄƒ-ÅŸi aduc aminte ÅŸi nu sunt obosite... si nu le doare nimic..\r\n- \"azi n-am chef... mai bine cuibÄƒresc!\"\r\n- tocmai! ÅŸi tot n-au chef!\r\n- dar se simt vreodatÄƒ bine!?!? ÅŸi mai fac ÅŸi scandal...\r\n- nu, dar merg Ã®n gaÅŸcÄƒ la WC ÅŸi subiectul \"tampoane aromate\" se poate discuta chiar ÅŸi la masÄƒ...\r\n- cu altul\r\n- n-ai vÄƒzut pÄƒruialÄƒ Ã®ntre douÄƒ harpii! s-ar ruÅŸina ÅŸi tiriÅŸtii!\r\n- mai bine le laÅŸi Ã®n pace. orice ai face tot nu e bine. bea o bere. o sÄƒ-i treacÄƒ.\r\n- \"profesionistele\". restul pun cartofi!\r\n- dacÄƒ-i poala vecinului aproape. dacÄƒ nu, vÃ¢nturÄƒ din aripi ÅŸi-ÅŸi expun unghiile vopsite Ã®n culorile rÄƒzboiului.\r\n- \"cÄƒ cÃ¢ntÄƒ\" dacÄƒ iau la cÄƒiÅ£Äƒ. dacÄƒ nu, te toacÄƒ la cap ca sunt obosite ÅŸi n-au chef de karaoke.\r\n- corect. neuron la neuron nu-ÅŸi rupe sinapsa.\r\n- dacÄƒ faci abstracÅ£ie de \"adiposu\'\"...\r\n- niÅŸte pÄƒr te zgÃ¢rie pe faÅ£Äƒ! bad bush!!!\r\n- nu te lasÄƒ sÄƒ plateÅŸti dar te obligÄƒ sÄƒ le cumperi toate prostiile\r\n- asta e distracÅ£ia lor\r\n- uneori, rareori, foarte rareori cu valenÅ£e de nicodatÄƒ (ia-Å£i de la MAC)\r\n- berg**bier\r\n- da, dacÄƒ e vecina din blocul celÄƒlalt\r\n- \"n-am chef, mÄƒ doare capul\"\r\n- pÄƒcat cÄƒ n-au acelaÅŸi ritual ÅŸi dimineaÅ£a! \"ajutoooor.... Gorgona...\"\r\n- asta le mai lipsea...\r\n- ooops!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.4','',0,0),(5806,637,'g ogoreanu','bogumir13@yahoo.com','','81.181.93.19','2007-09-18 14:22:49','2007-09-18 12:22:49','deaorece asa ne-a spus Dumnezeu ,  dar din fericire nu ne-a dat un nume',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(5799,640,'nenea cosmos','domnu_cosmos@yahoo.com','http://nenea.wordpress.com/','92.80.57.23','2007-09-18 00:08:04','2007-09-17 22:08:04','tati, merci de linkuÅ£ dar s-a schimbat adresa, futui, e http://nenea.wordpress.com/\r\n\r\nonoare muncii',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(5807,641,'Miruna','mirunavasilescu@yahoo.com','http://potsafacsiasaceva.blogspot.com/','86.106.59.163','2007-09-18 15:43:11','2007-09-18 13:43:11','E, sa-ti fie de bine! :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5754,631,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','85.186.77.129','2007-09-15 10:20:21','2007-09-15 08:20:21',':)) aoleu mama ce-am mai ras! vrei sa-ti zic o adresa de spital la care te lasa sa te dezbraci? am pile acolo, numa ca-s putine doftorite si mai multi doftori... da te lasa sa te dezbraci... eh? ce zici?\r\n\r\nsi io fac dush dimineata, si eu am alunecat pe sapun in cada, si am dat cu fundu de suportul de sapun, din ala de fainta (suportul, nu sapunul)... continuarea nu o mai zic... ca da, am o cicatrice pe fund. da e sexy, sa stii! :P',0,'1','Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.0.12) Gecko/20070731 Ubuntu/dapper-security Firefox/1.5.0.12','',0,0),(4991,599,'alexier','alexier_90@YAHOO.COM','','89.35.116.70','2007-08-22 13:27:06','2007-08-22 11:27:06','sa iti traiasca nepotii cati ei avea p[oate odatasi odata si copii si mai nou zici ca sprechen deutsch ha?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; DigExt)','',0,0),(5750,637,'nenea cosmos','','http://neneacosmos.wordpress.com/','92.80.27.10','2007-09-14 23:35:31','2007-09-14 21:35:31','e de bine. de la bucuresti se vede in felul urmator: groparul este hetero. spermatozozoii aia campioni vor avea urmasi. patria are viitor.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(5747,637,'caminu paishpe','fdorefn@yahoo.com','','24.17.110.178','2007-09-14 20:05:07','2007-09-14 18:05:07','hmmm...oare ce parere ar avea o anume mioritsa de toate motivele astea?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(5217,612,'sktes','sktes_2002@yahoo.com','http://sktes.wordpress.com/','79.113.137.88','2007-08-28 13:35:24','2007-08-28 11:35:24','Fusai joi la cantarea hiper-patriotica care este si se datora lu\' douashtri ogust? Ca fu tare cantarea, nu di\'alta :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5218,613,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-08-28 13:52:23','2007-08-28 11:52:23','@ ania: nu te mai ruga de ploaie cand io tre sa merg la nunta, decat dupa ce am ajuns la nunta!\r\n\r\n@ macabroo: oare si-or dat seama ca ugly people shouldn\'t have babies?\r\n\r\n@ Tudor: adeveru\' e ca in varfu muntelui nu e buda de femei, unde ele sa se schimbe de hainele ude departe de ochii tai FLAMANZI!!!\r\n\r\n@ Lumi: Deci io v-am mai scris ce trebia la voi pe plic, sh sa bagatz la cap!!! Ca restu\' numa de voi depinde! A, sh de oleaca de bafta de la Dumniezau. \r\n\r\n@ Mihaitza: Ca i-o vint vremia, mah! Sh ca sh-o gast un ficior cumsecade, nu vo baragladina ca noi!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5162,613,'macabroo','raduccc@yahoo.com','http://rezistenta.blogspot.com','82.76.52.94','2007-08-26 19:00:45','2007-08-26 17:00:45','Dilema: daca numarul de nunti e obscen de mare dupa cum se poate observa, numai io am fazut vo mie anul asta, de ce numarul de prunci e in continua scadere. Oamenii astia nu stiu care e menirea lor pe lume?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5226,615,'ss','criss_team@yahoo.com','','81.196.150.198','2007-08-28 16:16:54','2007-08-28 14:16:54','cand o zis \"ala mic si destept\" esti sigur ca se refereau la telefon? :-\"',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7','',0,0),(5740,94,'lilith','marcu_luiza@yahoo.com','http://www.aberatiunti.blogspot.com','82.77.126.148','2007-09-14 15:38:33','2007-09-14 13:38:33','am fost si eu pe-acolo vara asta, dar nu m-a impresionat cu nimic. Amsterdam e adevaratu\'! :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5741,637,'ina','ina@oricum.ro','http://www.oricum.ro','86.55.143.58','2007-09-14 15:41:38','2007-09-14 13:41:38',':) \r\n\r\nmotivele tale sunt foarte dragute\r\n\r\niar comentatorii foarte faini. am un zambet mare pe fata acuma dupa ce s-au mai linistit hohotele:)\r\n\r\nnoroc bun',0,'1','Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.1.6) Gecko/20061201 Firefox/2.0.0.6 (Ubuntu-feisty)','',0,0),(5742,594,'lilith','marcu_luiza@yahoo.com','http://www.aberatiunti.blogspot.com','82.77.126.148','2007-09-14 15:46:54','2007-09-14 13:46:54','salutare ca de la clujanca la clujan. prea multa munca o sa te omoare, asculta-ma pe mine! :((',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5755,630,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','85.186.77.129','2007-09-15 10:23:21','2007-09-15 08:23:21','si daca tu te-mpusti, pe mine cine ma mai face sa rad cand sunt suparata? :((',0,'1','Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.0.12) Gecko/20070731 Ubuntu/dapper-security Firefox/1.5.0.12','',0,0),(5756,640,'ania','soredarkshines@gmail.com','http://aniakhaki.blogspot.com/','89.123.92.141','2007-09-15 10:33:11','2007-09-15 08:33:11','dixtractie :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5225,610,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-08-28 16:15:54','2007-08-28 14:15:54','@ Ciutacu: Deci mo, io d-abia ajtept momentu\' in care m-oi pravali d-acol\' de sus sh voi face buf, ca o lespede de piatra in baltoaca cu broajte!!! Heheee... sh-atunci am sa va zic vorba mea favorita: IO V-AM ZÃ‚S! V-AM ZÃ‚S??? V-AM ZÃ‚S CÄ‚-Z ZERO! DA\' N-AÅ¢ VRUT SÄ‚ M-ASCULTAÅ¢I!!!...\r\n\r\nIubesc cand apar eu ca filozoful de final, pseudo-mintea cea de pe urma...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5267,618,'ss','criss_team@yahoo.com','','81.196.150.198','2007-08-29 15:51:00','2007-08-29 13:51:00','@10kbph: sa ai noroc de masina, si sa nu lovesti muste nevinovate cu ea!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7','',0,0),(5427,622,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-09-03 15:58:15','2007-09-03 13:58:15','@ Hammer: mo, deci e ok, da\' sa nu-ti doresti sa fii nimic in Danemarca! Decat daca ai fi o plaja in Spania. \r\n\r\nDanemarca e boring.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5736,637,'luminita','lummi31@gmail.com','','81.196.54.24','2007-09-14 12:57:15','2007-09-14 10:57:15','Gropare, felicitari pentru...spiritul fin de observatie!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(5271,619,'ss','criss_team@yahoo.com','','81.196.150.198','2007-08-29 17:39:39','2007-08-29 15:39:39','asta-i ciclu apei in natura in viziunea MISA? ;))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7','',0,0),(5272,618,'Radu M.','radu_muri@yahoo.com','http://theblacklight.wordpress.com/','79.113.136.164','2007-08-29 17:42:10','2007-08-29 15:42:10','Si eu voi fi prof...deci aveti grija unde va trimiteti copiii si mai ales cum ii veti boteza..&gt;:)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7','',0,0),(5737,637,'ania','soredarkshines@gmail.com','http://aniakhaki.blogspot.com/','89.123.120.120','2007-09-14 13:04:23','2007-09-14 11:04:23','@darius da ce, nu esti deja femeie?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5738,637,'M.I.S.H.U. &raquo; Blog Archive &raquo; Iubita mea!','','http://www.doingtheartwork.com/?p=177','66.199.252.66','2007-09-14 13:17:28','2007-09-14 11:17:28','[...] Ca un raspuns la postul Groparului [...]',0,'1','Incutio XML-RPC -- WordPress/2.2','pingback',0,0),(5424,625,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-09-03 15:39:07','2007-09-03 13:39:07','@ pliscu: mo, deci am revenit la kipa, da\' numa juma\' de paket de nicotina pe zi; sh cochetez din ce in ce mai serios cu clipele cand mai trag o paoza d-aia lunga! (mi-am recapatat mirosul, bueeeey!!!)\r\n\r\n@ baghy: mo, deci sfatu\' ala cu batut nevasta, io le-am tot zis: nu mai dati in ele ca prostii, ca LASATI URME!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5421,625,'pliscu','pliscu@gmail.com','http://pliscu.blogspot.com','86.105.73.121','2007-09-03 13:11:11','2007-09-03 11:11:11','apucatu`te`ai de beut si fumat, sau ai prelungit pauza?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5422,622,'Hammer','pontos_a@yahoo.com','','86.120.55.79','2007-09-03 13:52:25','2007-09-03 11:52:25','Nush sa-tz dau raspuns, da\' uite un motiv sa itz doresti sa fii sofer in Danemarca :-)  http://razvan.exarhu.ro/preventie-la-bustul-gol/',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(5423,625,'baghy','baghy83@lycos.it','http://baghy.info/','78.12.19.252','2007-09-03 14:02:31','2007-09-03 12:02:31','numa sfaturi dastepte dai Gropare',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(5416,624,'Sa vina Robbie Williams','robilica@yahoo.com','http://robbie-williams.blogspot.com','213.157.188.71','2007-09-03 09:49:52','2007-09-03 07:49:52','iar ai furat mireasa?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5417,624,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-09-03 11:14:59','2007-09-03 09:14:59','@ Galatzi: mo, am fo bagat in tot felu de chestii la vieatza mea, sh in blogroale e super sa hii bagat!\r\n\r\n@ Robert: nu o furai, ca nu avusai loc de bizoni! Sh mama o zis ca ma dezmosteneste daca spurc sh nunta aia.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5418,624,'Victor Ciutacu','victor@ciutacu.ro','http://www.ciutacu.ro','82.76.75.160','2007-09-03 12:24:36','2007-09-03 10:24:36','La nunta de saptamana viitoare, e nevoie sa-mi iau hainele de friptura? N-as vrea sa te fac de ras:)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(5419,624,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-09-03 13:00:01','2007-09-03 11:00:01','@ Ciutacu: mai bine imbraca-te in muzica de friptura! parerea mea...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5436,626,'sweeper','ak70g2@gmail.com','','86.107.192.53','2007-09-03 22:36:34','2007-09-03 20:36:34','Nene Radule, imi povestise Andre de tine, Da\' vaz ca esti mai ucigator ca antraxu\'... Acu\' nu te supara ca nu-s coerent, da\' ma recuperez de sub birou, unde am ajuns de ras!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; .NET CLR 2.0.50727)','',0,0),(4988,599,'octa','octaviatarnita@yahoo.com','','86.136.18.157','2007-08-22 12:42:49','2007-08-22 10:42:49','f frumosi',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; YPC 3.2.0; SV1)','',0,0),(4989,598,'octa','octaviatarnita@yahoo.com','','86.136.18.157','2007-08-22 12:46:04','2007-08-22 10:46:04','spune-i la domnu ala sa isi schimbe slipu',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; YPC 3.2.0; SV1)','',0,0),(4984,599,'Hammer','pontos_a@yahoo.com','','86.120.55.79','2007-08-22 06:47:48','2007-08-22 04:47:48','Aspri nepotzi, sa-tz traiasca. Daca le plac pufuletzii insamna ca \"puii de neamtz\" is romani bine de tot ... pe jumatate :-)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(4985,599,'Sorinelu\'','sorinelm@gmail.com','','210.150.186.60','2007-08-22 08:59:34','2007-08-22 06:59:34','gropare le doresc si nepotilor tai egzact ce ii doresc si copilului meu care mai are un pic si o sa inceapa sa-ti citeasca posturile.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727)','',0,0),(4986,599,'VIP','sdww@asdsa.de','http://vipuri.blogspot.com','213.157.188.71','2007-08-22 09:18:44','2007-08-22 07:18:44','sa-ti traiasca nepotii! \r\n\r\nde-ai fi si tu asa fain ca ei...',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; InfoPath.2)','',0,0),(5759,640,'','','','86.106.59.163','2007-09-15 11:57:07','2007-09-15 09:57:07','Pot sa te detest nitel?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5760,639,'Luna Betiluna','mihdana@yahoo.com','','92.80.93.48','2007-09-15 12:51:38','2007-09-15 10:51:38','no, dupa ce ca i-am umplut de muzici si poze (ca cu fazele-i altu`) si-am mai multe favorite decat bagate, acu s-ascult si emisiuni de radio pe trilulilu (ca-n america s-o asculta, da` la capiteala nu :( )\r\n@oitza - ai dreptate, alina, de stres, probabil, ca Groparu-i stresant rau (!!), a ras intr-una .....\r\n@Groparu - asa repede gandesti pe cat de repede vorbesti? ca de altele nu te mai intreb..... :))))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5120,610,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','86.105.72.125','2007-08-25 12:42:41','2007-08-25 10:42:41','Da! adica NU!!! mai ales daca al treilea o crescut in talpa... brrrrrrr!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5210,609,'adi','adyrotaru@yahoo.com','','86.34.227.117','2007-08-28 09:16:41','2007-08-28 07:16:41','sau: TRADARE! Am fost dati in gÃ¢t!!!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(5748,637,'mumuland','','','85.204.38.37','2007-09-14 20:13:26','2007-09-14 18:13:26','ma... mai ai pana la Cartarescu  .....esti super ok da mai ai.....oricum e bine ca macar te compari cu varfurili di lance sinu cu tatzi manelistii...oricum io to zac direct... treaba de mai sus ai scriso ... pientru ca ....:\r\n1. sa impresionezi pe cine trebe ....pientru ca :\r\n2.te-ai saturat de masturbat si ai mai face si tu sex...pientru ca:\r\n3. intr adievar  pielea acolo e fina sub san nu la tine  in palma....pentru ca :\r\n CLAR CATZ STA MINTEA LA MARITIS.. alfe; nai scrie bolunzaniile alea :))\r\n\r\niz io ma.care io? asta  :  ;)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(5122,610,'Victor Ciutacu','victor@ciutacu.ro','http://www.ciutacu.ro','86.35.134.106','2007-08-25 14:07:46','2007-08-25 12:07:46','Se cheama spatiu pentru amigdale:)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; FunWebProducts; SIMBAR={3D633094-9EA0-411c-9B30-8FEB3C2546B8}; .NET CLR 1.1.4322)','',0,0),(5043,596,'Gez','geza@dvis.info','http://groller.info/geza','89.137.112.121','2007-08-23 18:17:00','2007-08-23 16:17:00','Io si amu rabd foame :) \r\n\r\nRau ii sa n-ai un coltz de pita\'n casa ... tin minte cand stateam in Transporturi, si am fost nevoit sa mananc slana cu gem ... ca altceva nu era. \r\n\r\nFaine vremuri! \r\n\r\nGropare, trebe sa le povestim odata la un pescuit, si stiu ca ai agenda full da poate pe la anu il programezi tu si pe campionu judetean pe Salaj  la prins caras, intr-un weekend vre-o 2 ceasuri la o pescuiala :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5044,607,'sabina','','','86.105.121.103','2007-08-23 18:22:31','2007-08-23 16:22:31','omg... deviati de la subiect, baieti!!!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.2)','',0,0),(5045,607,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','86.105.72.125','2007-08-23 18:23:47','2007-08-23 16:23:47','Dimpotriva, vorbim despre el pana ajunge predicat!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5232,616,'Calarasu','acalarasu@gmail.com','http://adriancalarasu.wordpress.com','89.32.19.126','2007-08-28 19:24:25','2007-08-28 17:24:25','asta, de-ti incurci familea, e unul dintre efectele sevrajului, cum s-ar zice? :)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(5233,616,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','86.105.72.125','2007-08-28 19:28:54','2007-08-28 17:28:54','Nu, mah, ca dac-as fi in sevrj, mi-ar termrua mainlie pe tatsaruta!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5757,640,'feelbasil','feelbasil@gmail.com','http://lecluj.blogspot.com/','85.204.111.165','2007-09-15 10:54:00','2007-09-15 08:54:00','Gropare, cum te afirmi ca sa te vada lumea si pe tine la campionatul de facut mancare (sau cum i-a zice si la ala) ?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5798,640,'WhiteWolf','laskmerge@gmail.com','http://whitewolf.1gb.at','89.32.115.3','2007-09-18 00:03:37','2007-09-17 22:03:37','Da-te kult, abureste tot ce prinzi; zi-le ca faci a mai stiitzifica chestioaie pentru National Geographic, sectiunea de dezastre.\r\nCu navete, cum ar veni :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(4995,599,'Adi Calarasu','acalarasu@gmail.com','http://adriancalarasu.wordpress.com','62.217.241.242','2007-08-22 17:02:27','2007-08-22 15:02:27','Gropare, ia colea si tuarna si matale fo doi-trei, ca-t trece vremea, si-i pacat...\r\nHai ca nu-i treaba grea, zic.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(4978,599,'ania','soredarkshines@gmail.com','http://aniakhaki.blogspot.com/','89.123.79.242','2007-08-22 02:03:55','2007-08-22 00:03:55','somn usor :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5743,595,'lilith','marcu_luiza@yahoo.com','http://www.aberatiunti.blogspot.com','82.77.126.148','2007-09-14 15:53:05','2007-09-14 13:53:05','in cluj napoca, da unde ii piscina aia? :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5744,639,'oana','oana05odo@yahoo.com','','79.113.139.189','2007-09-14 16:33:14','2007-09-14 14:33:14','no mai intai blog, apoi radio, dar pe cand televiziune?',0,'1','Opera/9.21 (Windows NT 5.1; U; en)','',0,0),(5808,641,'Andreea MKT','supergirgir@yahoo.com','http://marlahermina.deviantart.com/gallery/','82.77.126.254','2007-09-18 16:27:33','2007-09-18 14:27:33','cum adika loat 40 de injineri?\r\ntrebuia sa scrii \"luat 38 de injineri plus andre si ioana, care sunt doua fecioare de la marketing, sfioase si blande ca o dimineatza de mai\"',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(5809,641,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-09-18 16:48:51','2007-09-18 14:48:51','@ Miruna: Mi-i :D\r\n\r\n@ Andreea: la voi inginerizarea inca nu are efecte ireversibile, dar avanseaza drastic.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5810,643,'Miruna','mirunavasilescu@yahoo.com','http://potsafacsiasaceva.blogspot.com/','86.106.59.163','2007-09-18 17:23:45','2007-09-18 15:23:45','Toate ca toate, da\' Fuego...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5829,644,'ania','soredarkshines@gmail.com','http://aniakhaki.blogspot.com/','89.123.93.248','2007-09-19 17:30:40','2007-09-19 15:30:40','am facut si eu o scurta analiza si am ajuns la concluzia ta... doar ca... la mine  intra in calcul si cearcanele :(',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(5813,641,'ania','soredarkshines@gmail.com','http://aniakhaki.blogspot.com/','89.123.98.227','2007-09-18 23:57:22','2007-09-18 21:57:22',':( si eu vreau la belish... ACUM!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5814,643,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','86.105.72.125','2007-09-19 00:28:57','2007-09-18 22:28:57','Oare muzica lu\' Fuego o fi inecat (opservati ca am scris cu un singur \"n\", nu cu trei!) tatie muzculitele alea? Sh daca erau ele mujtele ase destepte, di ce nu s-or sinucis in bere? Si - mai ales - di ce nu s-or sinucis cand erau deja muzcoaie d-alea mari, verzi si pensionate, care numa\' papa dijaba bugetul de pensii si calatoresc gratis prin autobuze, c-asa le lasa primaria?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5815,641,'Miruna','mirunavasilescu@yahoo.com','http://potsafacsiasaceva.blogspot.com/','86.106.59.163','2007-09-19 00:31:29','2007-09-18 22:31:29','Auyi, da\' nu cumva belish asta al tau e si el un fel de gura portitei, in felul lui? :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5816,641,'Miruna','mirunavasilescu@yahoo.com','http://potsafacsiasaceva.blogspot.com/','86.106.59.163','2007-09-19 00:32:33','2007-09-18 22:32:33','Am vrut sa scriu \"auzi\" da\' m-a luat de cap inversarea aia cand scrii cu diacritice...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5817,643,'Kissu','','http://www.pacurar.net','85.186.50.152','2007-09-19 00:58:36','2007-09-18 22:58:36','Da\' ce ma p...? :))) Tu meri la munte sa te dai pe Net?!?!.... :p Si ce vrei sa zici? Ca nu ti-o placut acolo la Belish? Da\' cu urmele alea de gheare de om din iarba de langa foisoru\' cu pricina ce erau?! :))))\r\n\r\nMnoah... pa si pusi! Io ma\'c in Halchidichi... :p',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1)','',0,0),(5818,641,'Kissu','@Mirunasiania','http://www.pacurar.net','85.186.50.152','2007-09-19 01:02:01','2007-09-18 23:02:01','Iaca aici: http://picasaweb.google.com/npacurar/BLSTeamBuildingLaBelis - meserie locsoru\', nu?\r\n\r\n\"Enjoin\"... sau Engage! ;)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1)','',0,0),(5819,643,'WhiteWolf','laskmerge@gmail.com','http://whitewolf.1gb.at','89.39.82.251','2007-09-19 03:11:23','2007-09-19 01:11:23','\"Balmos aveti? Da, zice. Ma satur cu o portie? intreb. Atunci va recomand sa mancati si supa, zice d-ra aia\"\r\nM-am rupt de rÃ£s. :)))\r\nDaca mai ai mai vreau',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5820,641,'WhiteWolf','laskmerge@gmail.com','http://whitewolf.1gb.at','89.39.82.251','2007-09-19 03:15:27','2007-09-19 01:15:27','Bag sama ca s-au pertrecut ceva activitati haotice pe acolo.\r\nDe ce n-ai contorizat, corect, pe fata, sa stie tot lecturaciu\' , victimele colaterale ? De ce o dai la deruta?\r\nImposibil sa fie tot 40 si numai niste ochi umflati.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5821,643,'Andreea MKT','supergirgir@yahoo.com','http://marlahermina.deviantart.com/gallery/','82.77.126.254','2007-09-19 09:22:20','2007-09-19 07:22:20','Io am o slabiciune pentru barbatii cu 3 crete pe frunte si pentru farfuriile alea de la restaurantul din Belish pe care scria\" Bine ati venit la Poiana Brasov!\"',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(5822,643,'mumuland','','','80.97.64.199','2007-09-19 10:03:44','2007-09-19 08:03:44','no vezi ...? daia tre mers cu cortu......si de aci  ai cate stele vrei frate...daca nu e innorat afara :)\r\n\r\n\r\niz io ma care io? asta :  ;)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12','',0,0),(5823,643,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-09-19 10:27:59','2007-09-19 08:27:59','@ Kissu: clar ca merg pe munte sa ma dau pe net! Alfel cum as fi vazut ce faine is crestele, daca nu pe google maps?\r\n\r\n@ Whitewolf: Mo, deci mie abia mi-o ajuns balmoshu\' ala, cum sa mai dau sh la altii? Ce crezi tu, ca io vreu sa ajung in rai, la sectkia \"Darnici\", ca sa mor de plictiseala?\r\n\r\n@ Andre: io creca sh pe kelneri scria d-alea cu Poiana. Najpa.\r\n\r\n@ mumuland: da! sh daca ai noroc poti avea sh o stea de cinema in asternut langa tine, in cort. Io nu am avut pana amu noroc d-asta.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5824,641,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-09-19 11:27:31','2007-09-19 09:27:31','@ Miruna: Belish e un fel de gradina unie o fomee nu s-o rapdat sh o papat un mar. Io asa cred, dupa cat e de fain.\r\n\r\n@ WhiteWolf: Deci in primu\' rand ca is mandru ca cetejti saitu\' aiesta de tÄƒtÄƒ jena, ÅŸi-n al doilea rÃ¢nd nu am putut contoriza ce ÅŸi cum: vedeam numa\' dublu si nu mai stiam sa impart la doi.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5825,637,'Botache','nasturei_verzi@yahoo.com','http://www.nasturei.wordpress.com','82.77.126.148','2007-09-19 12:26:50','2007-09-19 10:26:50','\"Pentru ca si cand injura, o fac fara vulgaritate.\r\n\r\nPentru ca sunt sexy cand incearca sa fie vulgare.\"\r\n\r\nSa le vad eu pe alea care sunt sexy cand sunt vulgare, ca le manc! :)) Intr-adevar, f*tu-i mortii ma-sii si p*zda ma-sii suna extrem de gratios in gura unei femei. :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.0; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(5826,643,'nenea','','http://www.nenea.wordpress.com','193.231.82.119','2007-09-19 12:56:05','2007-09-19 10:56:05','eu am avut noroc ca era si stea, era si de cinema, aveam si cort, numa ca era barbat si ne-a fost scirba.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 2.0.50727)','',0,0),(5827,644,'ss','criss_team@yahoo.com','','81.196.150.198','2007-09-19 14:56:31','2007-09-19 12:56:31','ohoo..pai sa zici mersi si sa-i porti sanatos.\r\ntate bune si frumoase, da amu alarmarea ta ma alarmeaza si pe mine, ca la mine i ca la tine, numa cu o singura diferenta: io cam am probleme la ochi.\r\nda pt incurajat din priviri domnisoare cu decoltee generoase tat is buni. pfiu.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7','',0,0),(5828,644,'Andreea MKT','supergirgir@yahoo.com','http://marlahermina.deviantart.com/gallery/','82.77.126.254','2007-09-19 15:11:37','2007-09-19 13:11:37','Gro, uite: m-o agatat azi de la Glamour Models langa faculta de arte ca daca nu vreau sa fiu modelu lor. Io ma gandeam sa te ieu si pe tine  si pe Simina si pe Coprea si pe Cindre si pe Ioana, ca suntem frumosi de murim. mai ales okii.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(5849,645,'c|neva','cineva_df@yahoo.com','http://www.diaconuflorin.ro/blog','89.33.215.60','2007-09-20 22:37:59','2007-09-20 20:37:59','Nu cred ca traieste cineva p\'acolo. Poate doar cei homeless.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(5850,645,'nenea cosmos','domnu_cosmos@yahoo.com','http://nenea.wordpress.com/','92.80.37.37','2007-09-20 23:06:12','2007-09-20 21:06:12','copsa mica arata bine in filmul ala. zau asa. ii pun gard, repar curentu electric, ii pun la intrare reclama ca e studio de film si turnez acolo la low cost: terminator 4, anal rape 22, madmax 6, plus un film cu margelatu batrin batrin batrin, nu se prinde lumea de silozuri daca e praf mult si gloantele fac piuuun, cum numai in filemele romanesti le puteai auzi. cu lumini bune scoti si un film sf cu bruce willis salvind planeta pluto de teroristii galactici.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(6007,661,'WhiteWolf','laskmergeGmail.com','http://whitewolf2.freehostia.com','89.39.82.181','2007-09-26 17:28:23','2007-09-26 15:28:23','Subscriu la chestia aia cu instructiunile de folosire a blogului groparesc.\r\nTre\' sa existe o linie de demarcatie cat mai clar stabilita intre prostii ca noi si sifiliticii de geniu.\r\nSubliniez; nu incerc sa jignesc pe nimeni. Asa ne invata DEX-ul :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(5923,650,'WhiteWolf','laskmerge@gmail.com','http://whitewolf.1gb.at','89.39.83.33','2007-09-25 00:43:58','2007-09-24 22:43:58','Miruna, era cat pe aci sa ma exprim in aceeasi nota. Si poate chiar o fac.\r\nTotush, ej subversiv rau, gropare !\r\nTe cheama omu\' in casa, te lasa sa-i calci preshurile fara sa te puie sa-tz aretzi ciorapii de duminica descaltzandu-te si tu ii dai cu okiu magic pa paretzi\r\nScarry.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(5848,644,'WhiteWolf','laskmerge@gmail.com','http://whitewolf2.freehostia.com','89.39.82.212','2007-09-20 20:50:33','2007-09-20 18:50:33','<b>Importanta stiintifica a acestei descoperiri este foarte mare !</b>\r\nSunt convins ca nu mai dureaza mult si cercetatorii arondati ziarului Libertatea vor confirma studiul :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6012,659,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','86.105.121.103','2007-09-26 22:11:39','2007-09-26 20:11:39','Deci Huby (autoriul) ii un perfect, da\' nu Perfect Lemon!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6383,675,'Arhi','arhi@arhiblog.com','http://arhiblog.com','81.181.175.76','2007-10-05 16:45:40','2007-10-05 14:45:40','deci tu nu esti de acord ca stramosii nostri au fost cei mai tari, si ca romania e cea mai frumoasa si mai bogata tara, cu cei mai valorosi conducatori?\r\nBlasfemie...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6307,664,'','','','89.123.71.104','2007-10-04 09:53:03','2007-10-04 07:53:03','c fraier ai fost!!!\r\nc crezi? k asistentele s cele mai sfinte femei!!!\r\nt inseli!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6015,659,'DÃ£nilÃ£','','','84.232.159.250','2007-09-26 22:40:00','2007-09-26 20:40:00','TzÃ¢ganilor (a nu se confunda \"tzÃ¢ganii\" cu stimabilii cetÃ£teni romÃ¢ni de etnie rromÃ£, persoane de un deosebit calibru social si intelectual, nu oameni ai muncii de la orashe si sate, profesori si ingineri ca mai sus numitzii TZÃ‚GANI)... deci, tzÃ¢ganilor... fain o fo\' la TZÃ‚GÃƒNIE (termen peiorativ pentru o adunare tovÃ£rÃ£sehascÃ£ dedicatÃ£ analizei unor probleme de maximÃ£ importantzÃ£ pentru societatea contemporanÃ£ romÃ¢neascÃ£, aflatÃ£ Ã®ntr-un moment crucial al confluentzei mentalitatilor oriental-balcanice cu cele occidental-tehnocrate)... deci, tzÃ¢ganilor (non-cioril*r, sau \"non-melanin-excess-challenged people ce sÃ¢ntez\' voi) da\' fain o fost la mai sus pomenita adunare, chiar daca am stat numa\' f\'un ceas! SÃ£ mai hie si la anu\'! Tzucu-v-ash pe boticu\' sticlelor din dotarea fostÃ£ si viitoare!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.4','',0,0),(6011,659,'Miruna','mirunavasilescu@yahoo.com','http://potsafacsiasaceva.blogspot.com/','86.106.59.163','2007-09-26 21:46:30','2007-09-26 19:46:30','Maxim mi-a placut \"Ea cuprinde semne de patronaj istoric, fiind totusi o asumptiune.\" \r\nCineva a fost ghid turistic....:))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6025,659,'VIPu','robilica@yahoo.com','http://vipuri.blogspot.com','213.157.188.71','2007-09-27 08:19:07','2007-09-27 06:19:07','BAAAAAAAAAAA!!!!\r\n\r\nSI CORTU! ASTA NU II CORT DE CORTORARI! ASTA II CORT DE BOLUNZI CE SE DUC PE MUNTE!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6026,661,'VIPu','robilica@yahoo.com','http://vipuri.blogspot.com','213.157.188.71','2007-09-27 08:22:25','2007-09-27 06:22:25','ma, io n-am treaba cu ale voastre. cu cearta, cu matzele cu alea alea.... da di ce nu poti sa bei bere zilnic?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6330,672,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-10-04 16:11:36','2007-10-04 14:11:36','@ Oedip: da, mah, io caut o chestie care sa faca intrepicioarele sa fie frumos.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6324,672,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-10-04 15:32:58','2007-10-04 13:32:58','@ PhenoBarbie: Da, adevaru\' e ca omu ii un ficior super de treaba, sh p-astia am inteles ca ii mai ajuta Dumnezeu; numa cu scarnaviile ca mine are El ce are!!! PS: De-abia astept sa imi deie o litra de horinca ca multumire ca i-am pupat masina!\r\n\r\n@ DD: Da Doamne pe lume o ploaie cu spume! Spume de bere, binenteles.\r\n\r\n@ Razvan: deci mah, sper ca te referi la \"intrat in spate de masina\". Io numa atata mai sper. Nu supt spatele tau. Ca asta ar fi chiar crud.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6325,672,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','82.77.126.148','2007-10-04 15:33:42','2007-10-04 13:33:42','uite de-aia ma tem de biciclisti :(',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6326,672,'Razvan','razvan.antonescu@gmail.com','http://idei-locale.blogspot.com','81.196.150.96','2007-10-04 15:34:51','2007-10-04 13:34:51','Spate de masina mah. Rosie si Fabia pentru amatori. Da numa sa fiu si io in ea ca sa iti vaz fata',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6327,671,'andreanum','andreanum@yahoo.com','http://andreanum.wordpress.com','194.30.177.1','2007-10-04 15:39:21','2007-10-04 13:39:21','ian sa-l sun io pe vasile alu ernu sa-i spun ca fanii lui au invadat groparimea :D',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1)','',0,0),(6331,672,'ss','criss_team@yahoo.com','','81.196.150.198','2007-10-04 16:33:35','2007-10-04 14:33:35','aoleu gropare, ce beteshig ai lucrat iara?...la ce pagube ai produs, i clar ca rulai ca descreieratu, muult peste viteza legala a sunetului. bine ca nu tz-o dat puncte.\r\n\r\nda si aia ma, 13 milioane?? ocoli-ar falimentu!...\r\n\r\nsi bitza, in ce stare-i bitza? mai traieste..i in coma..isi revine?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7','',0,0),(6329,672,'oedip','oedip74@gmail.com','http://oedip.blogspot.com','139.18.194.141','2007-10-04 15:58:00','2007-10-04 13:58:00','buie frate, cum s-ar zice, iar futushi calu!!!\r\n\r\n:))\r\n\r\nmno, sorry de incident, dar asa ma gandeam si io si speram sa nu-l accidentezi prea tare pa shofer ca te stiu impulsiv :P\r\n\r\nsfat: mersul pa gios face picioru frumos!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6332,672,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-10-04 16:38:41','2007-10-04 14:38:41','Bitza e in aceeasi stare ca si ieri, deci recte asadar neatinsa. Si nu-i pasa de nimic, ca nu ea trebe sa plateasca paguba, nemernica!!! (draga mea bitza...)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6333,672,'Doamne-Doamne','criss_team@yahoo.com','','81.196.150.198','2007-10-04 16:41:49','2007-10-04 14:41:49','Gropare, fiule, mai vino pe la Biserica. Hai de te roaga si te spovedeste. Cu loteria nu pot sa promit nimic, ca e plin de smecheri p-acolo. Da in cazu in care castigi, nu uita sa imparti si cu alti amarati care au de indreptat table la masini, cum i ss, de exemplu.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7','',0,0),(6334,672,'evilpenguin','evilpenguin666@gmail.com','','89.114.108.212','2007-10-04 16:59:14','2007-10-04 14:59:14','Asta pentru ca voi pe-acolo n-aveti bande pentru biciclete d-astea jmechere cum avem noi in Buciurejti.  Daca mergi pe banda de biciclete fie-ti iei monster bike, fie te proptesti in 15 portbagajuri pana sa ajungi unde vrei. Ca nesimtitii numa pe liniilea alea portocalii parcheaza, de zici ca le-a luat ma-sa strada.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6338,672,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2007-10-04 18:02:03','2007-10-04 16:02:03','@ Doamne-Doamne: Doamne-Doamne, io zic ca beserica cea mai meseriasha e insusi trupul meu adolescentin, pe care - drept sa fiu - se cam pisha cainii la colturi; sh nu prea poci intra cu inima curata intr-un stabiliment de-al matale, ca tot timpu ma pufneste rÃ¢su\' si ma uit dupa decoltee. Decat asa, mai bine ma duc la crajma!\r\n\r\n@ evilpenguin: mo, e vina mea ca UE ne-o alocat numa\' cativa kilometri de piste pentru biciclisti, si aia s-or oprit la Bucuresti? Da\' nu-i stress, ca daca fiecare biciclist ar face ca mine, i-am dezvatza noi curand pe soferi de soferit!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6337,671,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2007-10-04 17:51:59','2007-10-04 15:51:59','Ioai, tu andreanum... in primu\' rand ca vaz ca matale ii cam stii pe toti (pe Greuceanu aka Rramon il stii? tigan d-al meu...), si-n al doilea rand: tot respectu\' pentru cetitorii mei, da io creca ni nu trebe sa sape prea adanc in blogosfera ca sa descopere ceva de un miliard de ori mai groparesc decat insusi Groparu!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6339,672,'Pegas vs Octavia','','http://www.arhiblog.com/pegas-vs-octavia','208.116.62.218','2007-10-04 18:49:04','2007-10-04 16:49:04','[...] Si castigatorul este&#8230;ati ghicit, pegasul. Continuarea la groparul pe blog. [...]',0,'1','Incutio XML-RPC -- WordPress/2.2.3','pingback',0,0),(6340,672,'oitza','oitza@yahoo.com','','24.17.110.178','2007-10-04 19:17:13','2007-10-04 17:17:13','ce stil sa te bagi in seama...uitati-va la mine, ascultati-ma, etc, etc, ce important sunt eu!',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727)','',0,0),(9552,859,'sabina','','','81.12.163.178','2007-12-11 11:04:37','2007-12-11 09:04:37','=))',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648)','',0,0),(6343,672,'moroseanca','morosenii@mail.com','','62.224.221.155','2007-10-04 19:41:39','2007-10-04 17:41:39','ioi ioi ioi mi s-o oprit inima-n loc cÃ¢nd am vazut ca victima avea numar de maramu\' dar am citit in continuare si m-am linistit. bine ca v-ati inteles si nu ti-o infipt fr-un cutzÃ¢t in cap ca i-ai sifonat frumusete de masinuca morosanului.\r\ncreca ii place usturoiu, in sinea lui, ca alta explicatie nu exista de ce mai esti in viata si tastezi cu doua jejite intregi :D',0,'1','Mozilla/5.0 (Macintosh; U; PPC Mac OS X Mach-O; de; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6344,672,'macabroo','raduccc@yahoo.com','http://rezistenta.blogspot.com','82.76.52.94','2007-10-04 20:12:42','2007-10-04 18:12:42','Jumatatea plina de octavia, e ca nu i-ai dat (ma scuzati doamnelor) la bot. Deoarece, bara plus capota plus un far insumeaza suma rotunda de 45 mil in cap. Sau asa am auzit...de la cineva...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6529,676,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','82.77.126.148','2007-10-09 10:18:22','2007-10-09 08:18:22','bai, daca te legi de indieni te legi de stra-strabunicu! :P\r\napropo, numele meu de indianca e whispering black fether, desi prietenii mei mai vechi m-au poreclit dansul norilor (dupa personajul din doctor quinn)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6530,683,'VIP','ps@yahoo.com','http://vipuri.blogspot.com','213.157.188.71','2007-10-09 10:21:02','2007-10-09 08:21:02','asa rau o duceau aia ma? sa mance la pranz gropari? naspaaaaa',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6531,646,'koyrosh','a@a.com','','82.77.126.254','2007-10-09 10:22:37','2007-10-09 08:22:37','franzela, mai tzii minte revoltele mele de acu\' un an? si ce itz zisasam atuncia? noah, itz mai dau o veste proasta: resemnarea oilor te pashte. am mai ramas din toate visele mele cu pasiunea fumatului in balcon, cu ochii in gol...',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(6488,677,'ss','criss_team@yahoo.com','','81.196.150.198','2007-10-08 16:48:10','2007-10-08 14:48:10','sa vorbesti cu colegu sa-ti aduca si vro 3 tiriboantze de testicoaie.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7','',0,0),(6489,677,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2007-10-08 17:22:07','2007-10-08 15:22:07','@ macabroo: nu-i stress, ca oricum tat la femei la buda meream!\r\n\r\n@ ss: hmmm, acilea e mai greu: iti dai sama de cate Parlamente e nevoie ca sa strangi o pereche mica-mica?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6490,677,'andreanum','andreanum@yahoo.com','http://andreanum.wordpress.com','89.40.132.127','2007-10-08 17:34:47','2007-10-08 15:34:47','fratioare da ce prosper arati pe pulile alea ale tale... sunt realmente inpresionata. :D',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(6609,685,'MaTr3o','matr3o@yahoo.com','http://matr3o.com','92.80.213.155','2007-10-10 16:49:18','2007-10-10 14:49:18','macar eu sunt mai destept decat telefonul meu ;;) evil one.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6493,330,'Nascut din spermatozoizi campioni &raquo; Blog Archive &raquo; Draga Banca!','','http://www.groparu.ro/?p=646','82.103.137.253','2007-10-08 18:41:29','2007-10-08 16:41:29','[...] Cand eram paduche, mi-ai zambit condescendent si m-ai refuzat cand ti-am prezentat planul meu imbatabil de afaceri: un bordel numa&#8217; de mamelit. [...]',0,'1','Incutio XML-RPC -- WordPress/2.1.2','pingback',0,0),(6494,677,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2007-10-08 18:52:50','2007-10-08 16:52:50','@ andreanum: 21... batute pe muchie!!! :D:D:D nij dac-aveam 21 de ani nu eram mai mandru. Iti dai seama, 20 de backupuri!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6415,675,'Arhi','arhi@arhiblog.com','http://arhiblog.com','81.181.175.76','2007-10-06 12:38:13','2007-10-06 10:38:13','miezure, viezure, opinci, mirc, blog',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6417,675,'nenea cosmos','domnu_cosmos@yahoo.com','http://nenea.wordpress.com/','92.80.26.189','2007-10-06 14:28:12','2007-10-06 12:28:12','cu permisiunea dumneavoastra voi face pe blogul meu o introspectie (ce naiba o fi aia?) la mine pe blog cu referire la ginditorul de hamangia. la mine pe blog mi se pare un subiect plin de nuante in blog la mine. voi pune aici linkul cind pe blogul meu introspectia (repet, ce e aia?) va fi gata la mine in blog.\r\n\r\nce de reclama am bagat... m-as scos....\r\n\r\nsa ma anuntati daca deja va ustura de atita teasing.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(6418,675,'nenea cosmos','domnu_cosmos@yahoo.com','http://nenea.wordpress.com/','92.80.26.189','2007-10-06 14:29:35','2007-10-06 12:29:35','m-am scos, nu ma-s scos, butoane tradatoare!\r\n\r\ndeci la mine pe blog in curind acusica la blogul meu, la mine da?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(6420,675,'nenea cosmos','domnu_cosmos@yahoo.com','http://nenea.wordpress.com/','92.80.26.189','2007-10-06 16:08:50','2007-10-06 14:08:50','deci acum la mine pe blog exista introspectia (totusi, ce e aia?) scrisa in blogul meu la mine pe blogul care imi apartine mie deoarece este blogul meu facut de mine care am blog.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(6421,675,'nenea cosmos','domnu_cosmos@yahoo.com','http://nenea.wordpress.com/','92.80.26.189','2007-10-06 16:09:23','2007-10-06 14:09:23','si apropo, voi ati mai pomenit varza in salata de peste?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(6541,685,'Mihai','mhangansv@yahoo.com','','81.196.150.96','2007-10-09 12:40:55','2007-10-09 10:40:55','Esti zulu :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6542,685,'csaba','krigton@yahoo.com','','213.86.197.188','2007-10-09 12:41:29','2007-10-09 10:41:29','cu ajutorul indicatorului, parca si vad cum te scoate unul afara pe usa si iti arata semnul. \"si acum directia Ursus\"',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; InfoPath.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.590; .NET CLR 3.5.20706)','',0,0),(6543,685,'Dexter','dextertag@gmail.coi','','82.76.65.140','2007-10-09 12:52:51','2007-10-09 10:52:51','Trebuia sa pui eticheta de la Tu-borg, eu-borg, el-borg...Sau cum ii mai spune mamai-mea...TURBO! Oricum...Apreciez gestul...',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; t20010828)','',0,0),(6544,685,'ania','soredarkshines@gmail.com','http://aniakhaki.blogspot.com/','89.123.98.28','2007-10-09 12:53:19','2007-10-09 10:53:19','ce tare :D lipseste sa provoci un incendiu :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6545,685,'PhenoBarbieDoll','poisongirl94@yahoo.com','http://360.yahoo.com/poisongirl94','193.230.230.101','2007-10-09 13:03:33','2007-10-09 11:03:33','Io am alte preocupari la cooperativa, cum ar fi de exemplu sa-l incui pe business unit manager in borcanul ala de-i zice birou si sa-i las si cheile in usa pe dinafara ca sa nu poata folosi al doilea set de chei :) Pai daca m-o inervat...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(7740,761,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','82.77.126.148','2007-11-06 10:14:53','2007-11-06 08:14:53','nu asa mai gropare! intai le iei pe moldovence...iti zic eu ca nu o sa te uiti dupa italience never ever!\r\nsau uite, cehoaicele is iara geniale!! am fost az-vara prin cehia, si io ca femeie le-as fi luat pe toate si tot acolo am suferit o criza de identitate. ma tot duceam la buda sa ma uit daca nu mi-a crescut si mie ceva in pantaloni, ca prea faine femei au cehii! deci io iti propun sa te sacrifici pentru ele, nu pentru italiencele cu fundu mare si buricu sub genunchi!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(6547,685,'ss','criss_team@yahoo.com','','81.196.150.198','2007-10-09 14:17:20','2007-10-09 12:17:20','viva la revolucion! traiasca regele (berii in romania)!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7','',0,0),(9184,841,'.marius','marius@perijoc.com','http://marius.wirelessisfun.com','89.36.21.108','2007-12-04 17:31:03','2007-12-04 15:31:03','Daca reusesti, promit sa nu te mai imbiu cu tigarile mele de foi... ;-)\r\n\r\nPS: mi-ai ars polarul in Le General... :((',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9185,841,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2007-12-04 18:03:51','2007-12-04 16:03:51','Da mah, pe tine cine te-o invatzat sa vii in polar in orash? Ntz ntz...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9186,842,'irina','irinamimoza@yahoo.com','','86.121.22.228','2007-12-04 18:14:44','2007-12-04 16:14:44','ca mare dreptate ai. instructoru meu cred ca si-o trage cu cel putin din juma de cursante. stia el ce stia cand si-a luat matiz, ca acolo trag gagicile.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9187,842,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','85.186.77.129','2007-12-04 18:29:52','2007-12-04 16:29:52','gropare, cand ai urmatoarea ora de condus?? ca sa stiu sa nu ies din casa! :D',0,'1','Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.1.10) Gecko/20060601 Firefox/2.0.0.10 (Ubuntu-edgy)','',0,0),(9188,842,'manole','redtailanda@yahoo.com','http://www.mesterulmanole.wordpress.com','89.32.123.108','2007-12-04 18:34:26','2007-12-04 16:34:26','Cum stai cu tzigÄƒrile? Acum te-ai gÄƒsit sÄƒ te leÅŸi?\r\nSincer nici Ã®n BucureÅŸti nu mÄƒ prea simÅ£ Ã®n siguranÅ£Äƒ!\r\nHai bafta! - nu Å£ie, instructorului.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(9189,842,'Random links at Jurnal de noapte','','http://www.andreicrivat.ro/2007/12/04/random-links/','212.227.64.193','2007-12-04 19:46:22','2007-12-04 17:46:22','[...] Groparu&#8216; Ã®nvaÈ›Äƒ sÄƒ È™ofeze. Doamneeeee&#8230; [...]',0,'1','Incutio XML-RPC -- WordPress/2.2','pingback',0,0),(9190,842,'andreanum','andreanum@yahoo.com','http://andreanum.wordpress.com','89.40.186.94','2007-12-04 22:18:04','2007-12-04 20:18:04','gropare, pe la primavara ma apuc si io de scuala de-asta si ii prindem pe astia ca in cleste: tu dinspre nord vest, io dinspre sud est... poate rezolvam traficul din zonele noastre de influenta :D',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(6453,676,'oedip','oedip74@gmail.com','http://oedip.blogspot.com','139.18.194.141','2007-10-07 18:37:40','2007-10-07 16:37:40','shiting cow more likely :)))))))))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6454,676,'Andrei Crivat','andrei@andreicrivat.ro','http://www.andreicrivat.ro','89.137.83.141','2007-10-07 19:28:35','2007-10-07 17:28:35','io vreau ca pe nevasta-mea s-o cheme Apa care Rade, adica Minehaha, sotia lu\' Haiawatta. deci asta NU implica ca io sa fiu haiawatta, doar pe nevasta-mea am decis c-asa o cheama, Apa care Rade',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; SLCC1; .NET CLR 2.0.50727; Media Center PC 5.0; .NET CLR 3.0.04506)','',0,0),(6455,676,'Radu Iliescu','riliescu2000@yahoo.com','http://careeste.blogspot.com','89.123.118.13','2007-10-07 19:32:32','2007-10-07 17:32:32','Radu Iliescu. Radu, din tribul Iliescu, pentru prieteni. E bine?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0)','',0,0),(6556,689,'zgura','','','79.113.128.240','2007-10-09 21:57:13','2007-10-09 19:57:13','Mai zi-ne cu banci, fa niste sectiuni speciale: de banci, de notari si de agenti imobiliari. Si numa de bine si de mame daca se poate',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6557,689,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2007-10-09 21:58:47','2007-10-09 19:58:47','AAAaaarrrghhhhh, si pe tine te-or prins? Bastards... bastards!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6558,689,'bicplayer','bic_player@yahoo.com','','86.125.169.80','2007-10-09 22:22:47','2007-10-09 20:22:47','poi catzeaua ii bitch din nashtere asa k nu prea ai nimerit-o :P\r\n\r\nda oricum...itzi mai fata mintea nishte chestii super funnea :))\r\n\r\nsi stii cum e vorba aia....bucurate de ziua de azi maine va fi mai rau ;)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6560,646,'WhiteWolf','laskmerge@gmail.com','','89.32.115.197','2007-10-09 23:55:50','2007-10-09 21:55:50','Gropare, nu te lua dupa anarhistu\' de moj cosmos.\r\nUita-te mai bine (si mai apasat) spre urarile mustind de optimism ale lui koyrosh.\r\nChiar zace inzelepciune mioritica in ele :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6561,689,'WhiteWolf','laskmerge@gmail.com','','89.32.115.197','2007-10-10 00:00:02','2007-10-09 22:00:02','Cin\' drak o taiet deja -scuzatz, o kurentat pana la anestezierea letala- porku\' de mÃ nci tu slanÃ£ pe vremea asta ?!? - ca doar nu-mi vei zice ca-i din aia rancezita de mai acu\' un an sau stransa-n matz de plastice vidate de pe la hipermarkete &amp; alte platzuri.\r\nCiapa stiu c\'or pus-o, deja, turdenii pe taraba. Da slanina ?\r\n@bicplayer, <b>cine-iala (sau aia)  bucurate ?</b>',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6562,689,'Adi Calarasu','acalarasu@gmail.com','http://adriancalarasu.wordpress.com/','89.32.19.126','2007-10-10 00:00:16','2007-10-09 22:00:16','Azi am mancat slana cu ceapa, semn ca se apropie salariu.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(6587,690,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-10-10 11:17:08','2007-10-10 09:17:08','Mah, pare rau la mine ca nu suntem noi cea mai mare companie americana! Rau-rau pare... da\' totusi pare bine ca nu ne-or borbandat ca sa ne aduca democratia finca, asa cum zicea o protestatara, \"bombing for peace is like fucking for virginity!\" (parerea ei)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6599,691,'ss','criss_team@yahoo.com','','81.196.150.198','2007-10-10 14:12:10','2007-10-10 12:12:10','apai britney....\r\nnu poti s-o compari cu \'corleone\'.. chiar si cu jiji ar fi fost exagerata comparatia (big breakthrough: se poate si mai rau decat jiji :D )',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7','',0,0),(6539,685,'Andrei Crivat','andrei@andreicrivat.ro','http://www.andreicrivat.ro','89.137.83.141','2007-10-09 12:20:18','2007-10-09 10:20:18','io cre ca te da afara.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; SLCC1; .NET CLR 2.0.50727; Media Center PC 5.0; .NET CLR 3.0.04506)','',0,0),(6540,646,'baghy','baghy83@lycos.it','http://baghy.info/','78.12.8.67','2007-10-09 12:21:14','2007-10-09 10:21:14','niste hoti',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(6263,670,'macabroo','raduccc@yahoo.com','http://rezistenta.blogspot.com','80.96.196.2','2007-10-03 13:32:47','2007-10-03 11:32:47','Sh\' care\'i numele tau de elf Gropare? Ai clan?',0,'1','Opera/9.23 (Windows NT 5.1; U; en)','',0,0),(6267,662,'octa','octaviatarnita@yahoo.com','','86.132.126.127','2007-10-03 16:33:21','2007-10-03 14:33:21','subsemnez la toate',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; YPC 3.2.0; .NET CLR 2.0.50727)','',0,0),(6268,666,'octa','octaviatarnita@yahoo.com','','86.132.126.127','2007-10-03 16:40:55','2007-10-03 14:40:55','iti recomand pelicula : \"My penis and I\"\r\no sa te ajute cu mai multe issues:))',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; YPC 3.2.0; .NET CLR 2.0.50727)','',0,0),(7855,772,'UnCopiluty','uncopilutz@yahoo.com','http://www.uncopilutz.haipa.ro','79.113.139.206','2007-11-09 17:20:35','2007-11-09 15:20:35','Tipele Ã®n pungi Ã®s mai drÄƒguÅ£e, totuÅŸi...',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 2.0.50727)','',0,0),(6382,675,'Doamne-Doamne','criss_team@yahoo.com','','81.196.150.198','2007-10-05 16:29:50','2007-10-05 14:29:50','deci nenea Ganditoru: cel mai probabil ca medita la quintesenta ideologiei suprarealiste in discrepanta cu sinergia translucida a afinitatilor afective ale eului interior. sau poate ca numa statea ca ion in bota, numa ca cu capu\'n palme (ce faci ioane, shezi si cujeti?..nu, numa shed.)\r\nperfect plauzibila si varianta individului in care se regaseste fiecare dintre noi, shezand in pozitie regala pe o toaleta din portelan fin si punand tzara la cale (in absenta ziarului). la urma urmei se stie ca cele mai bune idei asa prind viata, deci numele Ganditorul e de actualitate desi are radacini stravechi.\r\n\r\ncat despre pictorasii cei viteji care decorau peretii pesterilor, aia-s precusorii conceptului de galerie de arta.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7','',0,0),(6380,675,'sabina','','','81.12.163.178','2007-10-05 15:50:50','2007-10-05 13:50:50',':)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(6271,671,'Miruna','mirunavasilescu@yahoo.com','http://potsafacsiasaceva.blogspot.com/','86.106.59.163','2007-10-03 17:12:57','2007-10-03 15:12:57','Slabut...slab de tot. Sa vezi cum e cand iti pierzi toate actele, inclusiv certificatul de nastere. Ala da balci!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6273,671,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','83.103.133.158','2007-10-03 18:22:33','2007-10-03 16:22:33','eu nu mi-am pierdut niciodata actele :P\r\npentru buletinul de cluj mai tre\' sa astept muuult si bine...mai am o speranta: poate ma marit cu un clujean get-beget, care sa aiba casa lui. pana una alta, io tre sa ma duc tomna in vaslui sa-mi schimb buletinu, la anu mai ezact! damn it, am o oroare!!!',0,'1','Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.0.12) Gecko/20070731 Ubuntu/dapper-security Firefox/1.5.0.12','',0,0),(6379,672,'adi','adyrotaru@yahoo.com','','89.120.56.7','2007-10-05 14:35:32','2007-10-05 12:35:32','ma tot uit la poza... parca-ti vad mucii pe portbagaj\r\n...sau Ã®i shi fosta avuta orgasm in secunda in care ai plesnit octavia? :O\r\nno, nu ma lasa sa ma chinuie prea mult intrebarea',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(6276,671,'baghy','baghy83@lycos.it','http://baghy.info/','78.12.14.243','2007-10-03 20:25:11','2007-10-03 18:25:11','Si zici ca esti din Sibiu de loc?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(6378,675,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-10-05 14:24:11','2007-10-05 12:24:11','Nu zic UNDE mai sus, asta va descifra posterioritatea!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6377,675,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-10-05 14:23:46','2007-10-05 12:23:46','Completare: am mintit mai sus.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6279,670,'b36','bogg_306@yahoo.com','','89.123.161.57','2007-10-03 21:26:04','2007-10-03 19:26:04','...chipul de elf ....nu-ti stiu fatza....da` e amuzant .',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Media Center PC 3.0; .NET CLR 1.0.3705; .NET CLR 2.0.50727; .NET CLR 1.1.4322)','',0,0),(6280,671,'laurie','','','69.131.168.85','2007-10-03 21:36:57','2007-10-03 19:36:57','damn it, gropare, cred ca ti se-nmultesc cetitorii',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6281,671,'Miruna','mirunavasilescu@yahoo.com','http://potsafacsiasaceva.blogspot.com/','86.106.59.163','2007-10-03 21:53:02','2007-10-03 19:53:02','intre ei.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6282,671,'nenea cosmos','domnu_cosmos@yahoo.com','http://nenea.wordpress.com/','92.80.34.90','2007-10-03 21:54:17','2007-10-03 19:54:17','tot e bine cÄƒ pe mine m-a gasit cu niste ani multi in urma sa imi fac buletinul pe noua adresa ca tocmai ma mutasem la proprietate noua exact inainte de alegeri fara sa ma gindesc ca toti aia cu buletine expirate care doresc sa voteze vor dori sa isi preschimbe buletinu. am intrat in joc, am facut cea mai lunga coada din istoria cosmica si la sfirsit am descoperit ca imi gresisera aia adresa in actul de vinzare dar nu doar o litera ci un cuvint intreg din numele strazii, caz in care pe numele gresit al strazii eram din alt sector, problema mare. cu ocazia aia am aflat si eu pe ce strada stau. tanti a fost draguta (trecuse de stadiul la care se mai putea enerva) si dupa numele blocului mi-a facut buletinu pe strada reala. am jurat ca a doua zi voi modifica actul de proprietate, caz in care dupa niste ani buni am rezolvat problema pentru ca nu puteau specialistii sa imi faca cadastrul. cu ocazia schimbarii multa lume a fost mirata ca aveam buletin pe adresa corecta, au crezut ca sint vreun smecher si s-au miscat actele rapid deci eu acum am un act de proprietate care zice ca am un apartament pe strada cucu in supraf, la etaju, schita, alea alea, 3 pagini de povesti, plus o foaie unde scrie scurt ca cucu este cici. eu daca vad la altcineva asemenea act de proprietate imi miroase a escrocherie dar las ca merge si asa.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(6283,671,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2007-10-03 22:28:01','2007-10-03 20:28:01','Miruna, printre soapte: urmeaza o postare despre taica-mio sh cum o ramas el, om batran la 60 de ani, fara TOATE actele posibile care atestau cine, ce, unde si cat timp este el! Da\' mai incolo.\r\n\r\n@ lilith: uimitor cate Monici Gabor se exista! Din pacate, nu-s kiar asa urat ca Urniel, ca te infiam io. Sper ca esti minora sexy. \r\n\r\n@ baghy: e, mah, nu numa\' de loc, ci si de gÃ¢nd, da\' maica-mea stii de unde e, mah? din POPLACA. Da. Se exista asemenea localitate, pe bune.\r\n\r\n@ Laurie: Da, mah Nelu, si-or dat seama si ei, sireacii, ca prea mare lucru nu gasashti acilea! Ca io tat asta va dzic.\r\n\r\n@ Miruna, intre soapte: nu intre ei, ci intre PICIOARELE ei. Parerea mea.\r\n\r\n@ Cozmose, daca imi spuneai ca toate ti-or mers ca unse la cumparare, as fi zis ca esti ficior de Belzebut! Nici asa nuz sigur ca nu esti, da\' daca esti, sigur suntem frati. Ca si io am o coada. E drept ca nu in spate, ci in fatza.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6284,670,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2007-10-03 22:31:12','2007-10-03 20:31:12','@ Cosmos: da, si Gates da vina pe razboiu cu arabocii, care araboci invatza bine mersi prin Romania, da\' fara camile. Deci tot tzara mea e de vina, tzuca-o-ash rece!\r\n\r\n@ macabroo: non me gustas WOW-uri, da nicku\' meu pe orice gamereala jucata onlain este - ai ghicit - Groparu. Cu www in fatza sh .ro in spate.\r\n\r\n@ b36: bah, deci daca nu-mi stii fatza - JUR! jur jur jur - nu ai ABSOLUT nimic ce pierde. Finca daca te uiti atent in ochii mei imi vezi fundu\' capului.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6376,675,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-10-05 14:23:14','2007-10-05 12:23:14','Sincer? Nici eu. Da\' trebuia sa scriu ceva azi, ca alfel scade traficu\'.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6287,671,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','83.103.133.158','2007-10-03 23:02:26','2007-10-03 21:02:26','nenea gropare, ma flatezi! recunosc, sunt o minora de 23 de ani... :))',0,'1','Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.0.12) Gecko/20070731 Ubuntu/dapper-security Firefox/1.5.0.12','',0,0),(7852,772,'nenea cosmos','domnu_cosmos@yahoo.com','http://www.nenea.wordpress.com','193.231.82.119','2007-11-09 16:06:08','2007-11-09 14:06:08','ba ce melodie ti-ai bagat, m-ai spart. vorbeam eu serios cu un subaltern cind deodata s-a stricat toata vraja ca a inceput gaina sa cinte.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 2.0.50727)','',0,0),(7853,772,'cronicaru\'','tzone_a@yahoo.com','http://cronicaru.blogspot.com/','193.230.230.101','2007-11-09 16:37:53','2007-11-09 14:37:53','ce sa zic, tare slogan si-a gasit iulica mol asta. daca gasesti la el numai cadouri pentru soacre putea sa-i zica magazin pompe funebre',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(8870,815,'cosmin','cosmin@binarycrafts.com','http://binarycrafts.com','89.34.72.34','2007-11-27 11:37:54','2007-11-27 09:37:54','Pun pariu ca Steve Irwin se\'ntoarce pe ailalta parte de ciuda. Fauna de asta de troleibuz nu gasesti acolo la antiplozi. Periculos da merita adrenalina.\r\nUrmatoru ar fi rromu tanar, calator fara bilet din printzip etnic, cuceritor din priviri intre statzii. Da ai grija ca astia is agili si cu etilu AXE hiperinflamabil. Si vezi ca daca-ti zice ca discriminarea se invatza de acasa tu sa-i zici ca nu esti din Cluj. Sau ca casa de copii nu e acasa. Ceva adanc.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en; rv:1.8.1.10) Gecko/20071115 Firefox/2.0.0.10','',0,0),(8063,788,'oedip','oedip74@gmail.com','http://oedip.blogspot.com','139.18.194.141','2007-11-15 13:09:55','2007-11-15 11:09:55','mah da ce paros esjti... ce sexy de paros esjti!!! asta ai vrut sa scoti (sau sa bagi) in evidentza?\r\n\r\n:))))))))))))))))))))))))))))))))))))))))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(6366,672,'pitiuska','dora.bacanu@yahoo.com','','86.122.94.196','2007-10-05 08:35:20','2007-10-05 06:35:20','io zic sa nu stam cu mainile in san si sa deschidem un cont de intr-ajutorare pt gropar! ;))',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(6367,672,'InnOcente*','innocente@innocente.ro','http://www.innocente.ro','89.165.215.227','2007-10-05 08:50:08','2007-10-05 06:50:08',':)) Mai miroÅŸi a usturoi :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(7781,760,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','82.77.126.148','2007-11-07 11:38:33','2007-11-07 09:38:33','si ai lasat tu fetele alea la greu!! urat din partea ta gropare! pai tu crezi ca te-or luat in masina numa ashe... de dragu soarelui? n-au capatat si ele o atentie, o maslina, ceva?? rusine! si au mai si avut incredere in tine... inseamna ca areti bine si nebarbierit, si cu tina si mirosind a palinca! iuui',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7782,760,'Groparu','groparu_ro@gmail.ro','http://www.groparu.ro','82.77.126.254','2007-11-07 12:45:48','2007-11-07 10:45:48','Deci ori m-or loat pentru alte talente de-ale mele pe care le-or ginit in ciuda moacei, ori finca trebuiau sa auza de groparu.ro, sait pe care, de alfel, nu il cunosteau, si nici nu aveau de gand pentru a-l vizita!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7541,742,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','85.186.77.129','2007-10-30 07:52:46','2007-10-30 05:52:46','vrajeala! io am fost in amsterdam, si nu am capu plin cu heliu... si totusi nu mi-i greu! :P',0,'1','Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.0.12) Gecko/20070731 Ubuntu/dapper-security Firefox/1.5.0.12','',0,0),(6371,671,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-10-05 11:02:18','2007-10-05 09:02:18','Avea Shakespeare o replica dementiala... I am not what I am, cica tradusa cu Nu sunt ce par a fi. Oare se aplica sh la nasterea ta? Oare vis al mortii eterne e viatza lumii-ntregi?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(7779,760,'darius f','darius2u@yahoo.com','http://desprepsd.wordpress.com/','82.79.52.137','2007-11-07 09:08:47','2007-11-07 07:08:47','Doamne feri sa te lasi de sait. Noi ce draku citim dupa aia?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7780,760,'Groparu','groparu_ro@gmail.ro','http://www.groparu.ro','82.77.126.254','2007-11-07 10:30:45','2007-11-07 08:30:45','@ nana, Usim: deci io zisai ca rÃ¢cÃ¢ii o brumÄƒ de bun simptz ÅŸi astfel nu fusÄƒi nevoit sÄƒ le cer nimica! :D\r\n\r\n@ clarvazatoarea: te rog frumos sa-mi citezi cand am zis io altminteri!\r\n\r\n@ Lupulainu: exact d-alea erau! circustante circumstantiale!!!\r\n\r\n@ dariusf: apai puteti, de exemplu, citi http://desprepsd.wordpress.com/',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(6374,675,'Andrei Crivat','andrei@andreicrivat.ro','http://www.andreicrivat.ro','83.103.128.106','2007-10-05 14:22:26','2007-10-05 12:22:26','eu nu sunt de-acord',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; SLCC1; .NET CLR 2.0.50727; Media Center PC 5.0; .NET CLR 3.0.04506)','',0,0),(6375,675,'Andrei Crivat','andrei@andreicrivat.ro','http://www.andreicrivat.ro','83.103.128.106','2007-10-05 14:22:52','2007-10-05 12:22:52','completare: eu nu sunt de acord, da ?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; SLCC1; .NET CLR 2.0.50727; Media Center PC 5.0; .NET CLR 3.0.04506)','',0,0),(6289,671,'laurie','','','69.131.168.85','2007-10-03 23:12:59','2007-10-03 21:12:59','enough about this nelu guy already. ugh:( sa te-ntreb cand faci fomeie cinstita din groparitza? ;) mai bine nu? thought so.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6357,672,'nenea cosmos','domnu_cosmos@yahoo.com','http://nenea.wordpress.com/','92.80.16.195','2007-10-05 00:47:19','2007-10-04 22:47:19','voi in ardeal oricum sinteti disperati dupa masini nemtesti si germane iar octavia tot din sectorul ala e, deci ai palit un monument, ma. ca si cum te-ai fi proptit in poarta sarutului cu ranga, pricepi?\r\n\r\ndeci eu eram kinder de ala mai maricel si intru eu cu pegasu in autobuz din laterala ca ma uitam dupa pamela anderson (pe vremea aia angela similea, de unde atitea pamele). urla lumea la sofer, opreste ala ikarusu, se da jos, ma ridica, ma pupa, ma iubeste, ma scutura, ma sterge, se convinge ca sint intreg, iar ma pupa, vrea sa ma duca la spital, isi pierde piinea, e disperat, intra la puscarie, se uita pe sub roti sa se asigure ca nu e o bucata din mine pe acolo, se linisteste, se calmeaza, isi da seama ca e totul ok si sa vezi pe urma cum ma apuca de ceafa si incepe sa imi care suturi in cur si capace pe circa, noroc cu lumea din autobuz ca ma zapacea. bicicleta avea numai ghidonu\' dereglat dar a luat-o el de pe jos si a aruncat-o cit colo de a cazut pe pedala si s-a futat. eu si azi ma mai uit prin cabinele de autobuz, poate dau de el... poate poate',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(6294,671,'Miruna','mirunavasilescu@yahoo.com','http://potsafacsiasaceva.blogspot.com/','86.106.59.163','2007-10-04 02:43:59','2007-10-04 00:43:59','UITE CE AM GASIIIT!!!!!! \r\nhttp://moldova.net/member.php?find=lastposter&amp;t=3281',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6356,672,'Mile','','http://milecarpenisan.wordpress.com','62.217.245.97','2007-10-05 00:42:34','2007-10-04 22:42:34','Dupa pui de morosan sa nu dai cu bolovan....da si tu cu bitigla...bine ca nu o fo ala bat ca vai ce te rupea . Pina la urma bine ca nu ai patit nica...las-o in pu*a de Octavia toagla e de baza.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(6354,672,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2007-10-04 23:51:27','2007-10-04 21:51:27','@ oitza: asa-i ca-i najpa saitu\'? io nu l-aj mai revizita...\r\n\r\n@ morojranca: vuoi, morojenii, nij habar n-avetz ce mitologie avem noi, ne-morojenii, fatza de tÄƒrÃ¢mu\' Äƒla binecuvÃ¢ntat dintre Ucraina ÅŸi RomÃ¢nia! Daca era sa aleg in cine sa ma infig, alegeam moroshan, ca sibiain cu moroshan dÄƒ binie!\r\n\r\n@ macabroo: bÄƒ, tu Å£ii cu el?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6300,670,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','83.103.133.158','2007-10-04 07:12:18','2007-10-04 05:12:18','mai gropare, atata mai sper: ca nu e sti un elf blond imbracat in rochie medievala! :/',0,'1','Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.0.12) Gecko/20070731 Ubuntu/dapper-security Firefox/1.5.0.12','',0,0),(6304,671,'Andreea MKT','supergirgir@yahoo.com','http://marlahermina.deviantart.com/gallery/','82.77.126.254','2007-10-04 08:51:07','2007-10-04 06:51:07','deci eu sunt dezamagita de administratia pudica financiara. in 2005, \r\nam fost cu baba mea (am avut o baba acuma 2 ani care mi-o dat garsoniera in kirie pe o gramada de bani \"daca vretzi, bine, daca nu, o dau la italian\"- care italian cred ca era fictional, da\' ma rog)...deci merg cu baba mea la finante si era asa coada ca saraca nu se putea tine pe picioare, deci am plecat acasa si 6 luni am stins becurile cand bateau jandarmii la usha sa imi dea amenda de flotant si eu ma ascundeam in baie.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(6213,662,'lilith','marcu_luiza@yahoo.com','http://www.aberatiunti.blogspot.com','82.77.126.148','2007-10-02 08:40:18','2007-10-02 06:40:18','aoleooo, ce-mi facusi gropare! m-ai lepjuit si pe mine, deci si in concluzie tre sa scriu si io de administratia pudica locala?? \r\nai de capu meu, tre sa ma gandesc bine, ca am asa, pe limba, niste spurcaciuni care trebe scuipate, ca de mult le tin in mine....',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(7956,784,'bicplayer','bic_player@yahoo.com','','86.125.169.80','2007-11-13 19:59:43','2007-11-13 17:59:43','la multzi ani!! sa traiesti o mie de ani ca un copac ;)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(6215,665,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','82.77.126.148','2007-10-02 09:48:24','2007-10-02 07:48:24','mie mi-e frica de ce ar putea iesi daca v-as spune ce pozitie am pe scara ierarhica a firmei.. :\"&gt; dar cred ca nici io nu stiu prea bine',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6578,689,'koyrosh','a@a.com','','82.77.126.254','2007-10-10 10:15:43','2007-10-10 08:15:43','mo prala, da\' vaz ca acoperi o plaja larga de lecturaci (lectura, lecturac); pe langa ca se prinde bicplayer de rupe malu\', scrie foarte noanshalant \"bucurate\". ma enerveaza si pe mine letrinele, da\' vaz ca nici cratimele nu mai is ce-or fost.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(6579,689,'mishu','mishu@doingtheartwork.com','http://www.doingtheartwork.com','82.77.126.254','2007-10-10 10:17:30','2007-10-10 08:17:30','nu se mai face scoala ca pe vremea ta... =))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6580,646,'darius f','darius2u@yahoo.com','http://desprepsd.wordpress.com/','82.79.52.137','2007-10-10 10:33:29','2007-10-10 08:33:29','Hai ca acuma ca stiu ca mai e unu care o luat m..e de la ING parca ma simt mai bine. Nu sunt de acord totusi cu partea de final. Io cand ma duc sa platesc ma pun la un ING Selfâ€™Bank si nu tre sa vorbesc cu nici o tanti si nici nu tre sa scriu nici un formular, aparatu imi ia banii, mii numara si dupa aia mai apesi doua tri taste sa zici ce vrei sa faci cu banii aia si gata.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6581,689,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-10-10 10:44:52','2007-10-10 08:44:52','@ koyrosh: bine ca esti tu destept!!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6582,646,'Arhi','arhi@arhiblog.com','http://arhiblog.com','82.79.189.58','2007-10-10 10:55:19','2007-10-10 08:55:19','Gropare, ING?:))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6583,690,'Basty','basty@canvas.ro','http://www.canvas.ro','82.77.126.21','2007-10-10 10:56:05','2007-10-10 08:56:05','Sssssh ! You shouldn\'t say that ! Sssssh ! Ce-s cu ideile astea revolutionare ? Nu stiai ca nu ai voie ?',0,'1','Mozilla/5.0 (Macintosh; U; Intel Mac OS X; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6584,646,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-10-10 11:09:37','2007-10-10 09:09:37','@ Arhi: am zis eu asta? am zis fuck-ING.\r\n\r\n@ darius f: asa ie, la platile in lei. Dar la platile in euro bancomatu\' scuipa afara hartiile si cheama politia. Nu am avut nciodata curaj sa incerc sa bag sute de euroi in aparat! (da, sunt un fricos congenital vaginal)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(7807,769,'Groparu','groparu_ro@gmail.ro','http://www.groparu.ro','82.77.126.254','2007-11-08 11:13:48','2007-11-08 09:13:48','@ lilith: sa stii ca tzara intreaga se mandreste cu moldovencele!\r\n\r\n@ un copilutz: \"a frige grataru\" e un eufemism, din cate stiu io.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7808,769,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','82.77.126.148','2007-11-08 11:42:22','2007-11-08 09:42:22','.marius, apai si io mi-s napoceanca napoceanca... numa buletinu trebe schimbat :P oi fi io moldoveanca moldoveanca, si m-oi fi mandrind io cu asta, da acolo nu mai am de gand sa ma intorc! \r\n:(( asta inseamna ca napocenii napocenii nu vor sa ma adopte in sanul lor? ce dezamagire! :((',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7809,769,'Groparu','groparu_ro@gmail.ro','http://www.groparu.ro','82.77.126.254','2007-11-08 11:50:56','2007-11-08 09:50:56','Cica pe olteni ii boteaza cu \"In numele tatalui si-ai fiului, ia drumu\' Sibiului!\" Pe moldoveni cum ii boteaza, \"CÃ¢t Ã®i roÅŸu rujului, dute-n dealu\' Clujului!\"?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7978,785,'Razvan Antonescu','razvan.antonescu@gmail.com','http://idei-locale.blogspot.com','81.196.150.96','2007-11-14 12:54:03','2007-11-14 10:54:03','Ingineri my ass. Ca din comentarii eu nu vad decat inginere',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7979,785,'curioasa','totmea@yahoo.com','','89.123.87.205','2007-11-14 13:14:27','2007-11-14 11:14:27','musai sa ne zici ce s-a mai intimplat dupa \"- Da, zice el, mersi frumos. E localul meu.\" groparu o-nvatat ce-i aia \"liniste mormintala\"?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(7946,784,'niciodata','niciodata@wordpress','http://niciodata.wordpress.com','217.10.215.6','2007-11-13 16:43:03','2007-11-13 14:43:03','Acest Gropar va fi aici si maine! Dar tu?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7980,785,'baghy','baghy83@lycos.it','http://baghy.info/','78.12.13.1','2007-11-14 13:33:30','2007-11-14 11:33:30',':)))) :))))))))) si chiar ca te dau inginerele de gol. nu mai modela povestile',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(7981,785,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-11-14 14:17:59','2007-11-14 12:17:59','Deci da, recunosc ca erau si multe injinere, da\' io ce sa fac daca in tot regnu\' animal orice mascul are un ciopor intreg de fomele?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7949,784,'NRGY','','','86.121.181.94','2007-11-13 17:08:54','2007-11-13 15:08:54','La multi ani! Sa ai parte de toate cele bune si sa ne traiesti 100 de ani fara reparatii capitale.\r\n\r\nDÄƒ sa te pup!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7950,784,'Victor Ciutacu','victor@ciutacu.ro','http://www.ciutacu.ro','82.76.75.160','2007-11-13 17:11:25','2007-11-13 15:11:25','Un sincer si calduros sa ai presiune, ca-n rest se rezolva toate:)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(7951,784,'oedip','oedip74@gmail.com','http://oedip.blogspot.com','139.18.194.141','2007-11-13 18:34:41','2007-11-13 16:34:41','sa cresti mare si voinic ca mine mah!!! potentule :P\r\nla multi ani, si btw, vin acasa pe 3, deci sa ma astepti cu bere in aeroport :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7952,784,'.cris','','','193.67.235.58','2007-11-13 18:35:44','2007-11-13 16:35:44','LA MULTI ANI !! \r\n\r\nsa ti se inmulteasca vizitatorii pe pagina ca lateii din partile tale cu care te mandresti!!\r\nsa ti se umple pestera de puradei frumosi si grasi ! \r\nsa stea muierile coada la usa pesterii sa faca plozi cu tine!\r\nsi tu sa fii virtuos sa le multumesti pe toate !',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(7983,785,'baghy','baghy83@lycos.it','http://baghy.info/','78.12.13.1','2007-11-14 15:01:36','2007-11-14 13:01:36','tu nu ai nici o vina. vina intotdeauna apartine femeilor :))',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(7971,785,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','82.77.126.148','2007-11-14 10:47:52','2007-11-14 08:47:52','si io zic ca \"ce vor muierile\" adica sigur ti-o stuchit in supa! sau daca nu ti-a stuchit, atunci io zic sa nu mai mergi pe la el, ca te tine minte!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7973,785,'Andreea MKT','','','89.43.186.64','2007-11-14 11:26:11','2007-11-14 09:26:11','numa tu puteai patzi faze din astea.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7974,785,'sabina','','','81.12.163.178','2007-11-14 11:53:37','2007-11-14 09:53:37','daca au scuipat in zama, scuipatul ala avea un gust demential...',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(7975,784,'si mester','','','89.137.120.50','2007-11-14 12:26:09','2007-11-14 10:26:09','nu mai stiu pe unde mi-am plasat (m)uraturile de LMA dar ... le gasesti tu',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7976,785,'Bernadette','briqo_o@yahoo.com','','82.77.126.254','2007-11-14 12:35:34','2007-11-14 10:35:34','mai mai cum modelezi tu toata povestea :)) nu l-ai tras deoparte..i-ai zis de fata cu toata lumea..si da da..era misto omuletzu',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; FDM; .NET CLR 1.1.4322)','',0,0),(7977,784,'oedip','oedip74@gmail.com','http://oedip.blogspot.com','139.18.194.141','2007-11-14 12:43:59','2007-11-14 10:43:59','oedip ala care o scris a 2-a oara n-am fost io... o fost aia mica... dar tot a mea! :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7954,38,'dana','dannelly13@yahoo.com','','212.0.201.165','2007-11-13 19:21:07','2007-11-13 17:21:07','salut ce mai faci',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1) Gecko/20061010 Firefox/2.0','',0,0),(7955,784,'conia','','','193.226.17.210','2007-11-13 19:58:09','2007-11-13 17:58:09','Eu zic ca mai bine sarbatoreai ieri cand inca mai erai tanar, astazi iti amintesti de toate lucrurile pe care le puteai face si nu ai reusit.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(7805,769,'zau asa!','totmea@yahoo.com','','89.123.116.181','2007-11-08 09:56:24','2007-11-08 07:56:24','Faget?.....Faget.....Faget..... Aaaa! Io am fost o data. Da\' era ocupat.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(7806,769,'.marius','marius@perijoc.com','http://marius.wirelessisfun.com','89.137.107.129','2007-11-08 10:14:46','2007-11-08 08:14:46','@lilith pai groparele vorbea de napocence napocence... sarumana...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8997,831,'sabina','','','81.12.163.178','2007-11-29 16:23:38','2007-11-29 14:23:38','=))',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(8998,831,'Botache','nasturei_verzi@yahoo.com','http://www.nasturei.wordpress.com','82.77.126.148','2007-11-29 16:28:16','2007-11-29 14:28:16','Valoarea artistica n-o fi mare, dar adevar graieste gura ta!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.0; en-US; rv:1.8.1.10) Gecko/20071115 Firefox/2.0.0.10','',0,0),(8999,832,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-11-29 16:46:55','2007-11-29 14:46:55','...finca nu vroi sa ma vedetz kiar asa de bat!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.10) Gecko/20071115 Firefox/2.0.0.10','',0,0),(9033,831,'WhiteWolf','contact@white-wolf.ro','http://white-wolf.ro','89.32.115.34','2007-11-30 05:05:00','2007-11-30 03:05:00','baghy, ca patzit te intreb :)\r\nDa\' mai ai blog ?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.10) Gecko/20071115 Firefox/2.0.0.10','',0,0),(9034,830,'WhiteWolf','contact@white-wolf.ro','http://white-wolf.ro','89.32.115.34','2007-11-30 05:10:21','2007-11-30 03:10:21','Ma scuzat\' ca ma insinuez atat de tardiv dar mi-a intarziat Asimetricu\' marinaros cu puantele. Zilele asthea, cica a gandit.\r\nMno.\r\n<b>Deci, ori ca se ard ori ca nu , io vreau sa stiu daca se ard pasiv or activ ?</b>\r\nCa sa nu o mai dea ,fenicshii, la intors cum ca ce-au votat; stim imediat daca-s din alea 4 miliuane de-au rupt stampila ( in valoare de vrio 13 MIL eoroi) de tre\' sa se tina musai sama',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.10) Gecko/20071115 Firefox/2.0.0.10','',0,0),(9001,831,'mirra','','','83.103.137.234','2007-11-29 16:54:48','2007-11-29 14:54:48','N-ai valoare,n-ai valoare?/Dara ai o gura tare! ...Iata ca facui si eu versuri:))\r\nMult adevar graiesti!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.10) Gecko/20071115 Firefox/2.0.0.10','',0,0),(9002,831,'eu,Miruna','mirunavasilescu@yahoo.com','http://potsafacsiasaceva.blogspot.com/','86.106.59.163','2007-11-29 17:00:23','2007-11-29 15:00:23','Eu nu pot decat sa remarc ca saptamana asta ai avut trei posturi care au continut caca.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.10) Gecko/20071115 Firefox/2.0.0.10','',0,0),(9003,832,'mirra','','','83.103.137.234','2007-11-29 17:04:14','2007-11-29 15:04:14','am auzit ca e carciuma cu balcon,e musai sa trec maine s-o vad!Si cica se dau si halbe gratis!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.10) Gecko/20071115 Firefox/2.0.0.10','',0,0),(9371,850,'WhiteWolf','contact@white-wolf.ro','http://white-wolf.ro','81.181.106.106','2007-12-08 19:27:03','2007-12-08 17:27:03','@vizionarul, teoretizam si eu. In plus, eram complet treaz. Da ? :)\r\nDe obicei nu ma arat interesat de respectivul ritual inainte de 3-4 paharele de rachiu. Dupa care, crede-ma, ma doare la baska de teoriile europene\r\n@andreanum, alea\'s fatalisme literar-ceausiste :P\r\nDupa 1989, cand vine vorba de Mioritsa si ciobanas , <b>naratorul</b> vrea sa credem ca a exprimat altceva. :)\r\nGropare, da-ne un semn ! convinge-ne ca ai scapat in viata si dupa acest ultim asalt',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; IEMB3; IEMB3)','',0,0),(9114,838,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2007-12-03 02:12:00','2007-12-03 00:12:00','Stai, no, ca fibrilez amu!!! Stai sÄƒ scap de demonii ÄƒÅŸtia care Ã®mi danseazÄƒ Ã®n faÅ£a spatelui ochilor...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9005,831,'nenea cosmos','domnu_cosmos@yahoo.com','http://www.nenea.wordpress.com','193.231.82.119','2007-11-29 17:59:07','2007-11-29 15:59:07','tara mea e mare ca un brustur\r\nsi multi prosti se sterg cu ea la spate...\r\ndar se razbuna si ea cum poate,\r\nse rupe de le intra destu-n cur.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 2.0.50727)','',0,0),(9162,841,'Lucian','lucian_udrescu@yahoo.com','','82.77.126.134','2007-12-03 22:37:45','2007-12-03 20:37:45','Succes la lasat de fumat. Acum am descoperit blogul tau si recunosc ca m-am prapadit \"usor\" de ras citind cateva posturi. Eu inca mai stau in 14 si te-am si prins un an. Te stiu din vedere (asta daca erai in gasca cu Ciura si Bolbos), tu sigur nu ma stii nici macar din vedere - inca nu s-au facut vederi cu mine.\r\n\r\nLa cat mai multe posturi!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 2.0.50727; MAXTHON 2.0)','',0,0),(9309,847,'Hammer','hammer@alpinet.org','http://www.alpontos.wordpress.com','86.120.55.79','2007-12-07 14:27:09','2007-12-07 12:27:09','Am primit doo litre de cola. Te-am batut:-))',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(9310,763,'Hammer','hammer@alpinet.org','http://www.alpontos.wordpress.com','86.120.55.79','2007-12-07 14:30:44','2007-12-07 12:30:44','No ashe...dar daca nu ai fotografii...dejaba!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(9031,832,'zulea','zulea1@gmail.com','','89.137.121.165','2007-11-30 03:52:50','2007-11-30 01:52:50','@ Miruna:\r\nUn tip face autostopul, Ã®l vede pe un bade cu o cÄƒruta venind pe sosea si Ã®l Ã®ntreabÄƒ:\r\n-No bade departe-i Clujul?\r\n-D\'apoi nu-i departe!\r\nUrca tipul Ã®n cÄƒruta, merge, merge, trece o ora, doua ore ...\r\n-No bade, da departe-i Clujul?\r\n-No amu-i tare departe!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.10) Gecko/20071115 Firefox/2.0.0.10','',0,0),(6033,661,'Hammer','hammer@alpinet.org','','86.120.55.79','2007-09-27 11:36:14','2007-09-27 09:36:14','Mah, bag de sama ca astia-s ca socru-meu...chiar daca suntem de acord, tzine in mod neaparat sa imi arate ca el are dreptate. Despre spectatorii stirilor proTV aveam o parere proasta de mult...orishikat.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(6034,659,'energy','','','82.76.131.10','2007-09-27 11:46:25','2007-09-27 09:46:25','Pt aia mai stup...efiati de latina (me), care-i dextra si care-i sinistra?\r\nDextra nu-i dreapta? Sinistra nu-i stanga? Sau vitavercea?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6035,658,'WhiteWolf','laskmerge@gmail.com','http://whitewolf.1gb.at','89.32.115.74','2007-09-27 13:01:08','2007-09-27 11:01:08','<b>Unfuckinbelievable !!!</b> :P\r\nSo, imediat ce ai aflat te-ai si vindecat de ce gandeai visi-a-vis de a o invita la un sukalÃ£u, da ?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6037,658,'Miruna','mirunavasilescu@yahoo.com','http://potsafacsiasaceva.blogspot.com/','86.106.59.163','2007-09-27 13:34:39','2007-09-27 11:34:39','Caci imi place tanti asta.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6038,658,'','','','82.77.126.254','2007-09-27 15:00:49','2007-09-27 13:00:49','@ WhiteWolf: Nu, mo, ca nici in ziua de azi nu m-am vindecat de viziuni cu femei cu bice in mana. Faza e ca acolo kiar se respecta faza aia cu profii care n-are voie sa se combine cu studentii, ca daca era invers, as fi fost primul student roman care calarea profa vikinga daneza! \r\n\r\n@ Miruna: I believe you :| she ruled',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6039,659,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-09-27 15:01:52','2007-09-27 13:01:52','Io stiu ca e sinistra lui sotie si odiosul dictator. Restu\' e can-can.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6040,657,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-09-27 15:05:23','2007-09-27 13:05:23','Deci ba, is unii carora ar trebui sa le interzic sa mai bage comentarii la mine pe sait, ca scriu colosal mai fain ca je si imi fura sh bruma de vizitatoare care mai intra acilea (in marea lor majoritate is oameni care spera sa le mai dau bani imprumut). Cozmose, uai, sa ni traiajti mo!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6041,658,'ss','criss_team@yahoo.com','','81.196.150.198','2007-09-27 15:26:32','2007-09-27 13:26:32','apai fa bine si baga si o poza...ce ej egoist? ;))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7','',0,0),(6042,663,'ss','criss_team@yahoo.com','','81.196.150.198','2007-09-27 15:31:34','2007-09-27 13:31:34','o ras, o ras...da era rasu lui?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7','',0,0),(6043,663,'Florina','florina_hica@yahoo.com','','79.113.130.50','2007-09-27 17:00:47','2007-09-27 15:00:47','Pai si daca urci intr-o masina care sta/merge agale in/pe panta, atunci nu inseamna ca urci in jos? Si la fel si invers: daca cobori dintr-o masina care sta/merge agale in/pe rampa, nu se numeste ca cobori in sus???',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6349,671,'Emaginatoru','e_magist@yahoo.com','','79.113.140.5','2007-10-04 20:30:49','2007-10-04 18:30:49','O tzara ofoftopic. \r\n\r\nAmu si io mi-am bagat acturile sa ma scriu sa ma fac iara student. Ceea ce inca nuj daca ie bine au ba. Da tat nu pricep di ce le tre la aia \"copie legalizata dupa certificatul de nastere\", asta pe langa tate diplomile care oricum tat de la iei le-am luat tat di la iei si unde scrie clar ca am fost student la aceeasi Univ.\r\n\r\nOare nu-s convinj ca m-am nascut ?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6314,670,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-10-04 14:03:04','2007-10-04 12:03:04','Nu, nu e medievala.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6386,672,'Groparu','groparu_ro@gmail.ro','http://www.groparu.ro','82.77.126.254','2007-10-05 17:16:14','2007-10-05 15:16:14','@ adi: mucii mei is acolo unde le e locu\', recte pe maneca.\r\n\r\n@ Noi: mo, se pare ca rezolvam la juma de pretz, sh fara rent-a-carutza. Finca omu\' ie un meseriash. Moroshan cumsecade, as mai zice io.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6317,671,'mioritsa','mioritsa@yahoo.com','','83.131.14.11','2007-10-04 15:03:58','2007-10-04 13:03:58','independent si fara legatura cu postul asta, voiam sa iti recomand blogul unui scriitor moldovean cred, vasile ernu se numeste, multi-premiat in romania pentru \"Nascut in URSS\" (probabil tot din ceva spermatozoizi campioni), unde poti gasi chestii interesante despre cultura noastra, cea ruso-romana si mama Rusie; vezi ca eu nu stiu sa fac link catre pagina, dar sigur gasesti tu singur...\r\n\r\n... plus muzica ruseasca patriotica, filmuletul lui Cobileanski daca forezi pe blogul lui, si inca alte bunatati pe care nu am avut timp sa le descopar, dar cu care ma voi delecta pana cand voi avea ocazia sa vin in romania sa cumpar cartea.\r\n\r\n... si mai voiam sa te felicit pentru blog, il citesc de mult si cu mare placere :-)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1)','',0,0),(6387,672,'Noi','ionut_i_garbea@yahoo.com','','86.124.24.142','2007-10-05 17:27:03','2007-10-05 15:27:03','felicitari.\r\nsuper cumsecade.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3 webaroo/1.2','',0,0),(6388,675,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-10-05 17:56:28','2007-10-05 15:56:28','@ Doamne-Doamne: da\' di ce desenele care rupestre gura targului nu iz porno?\r\n\r\n@ Arhi: despre cat de viteji sh de strabuni or fost bunicii bunicilor nostri voi dezbatea in alta postare, daca Doamne-Doamne ma mai lasa sa scriu acilea bloage sh nu acasa la el, in cer.\r\n\r\n@ ss: si mie mi le-o cetit, da\' s-o cam rusinat, ca erau pornografice.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6319,672,'PhenoBarbieDoll','poisongirl94@yahoo.com','http://360.yahoo.com/poisongirl94','193.230.230.101','2007-10-04 15:20:22','2007-10-04 13:20:22','Bine ca n-a patit nimic soferul, ca ramaneai si fara boi la bicicleta.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6320,672,'Doamne-Doamne','','','81.12.163.178','2007-10-04 15:22:37','2007-10-04 13:22:37','da. e posibil sa fi intrat in anul mortii lui Iorgovan. te-am ferit de felceri de data asta, dar de-acuma sa fii cuminte, ja? ridica-te si umbla!',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(6384,672,'Noi','ionut_i_garbea@yahoo.com','','86.124.24.142','2007-10-05 16:53:12','2007-10-05 14:53:12','nasoala patanie.\r\nda\' chestia cu 1300 de lei ...\r\nnu esti obligat sa platesti banii astia doar pentru ca asa a vrut muschiul lui, la acea unitate de reparatii.\r\nesti obligat sa-i repari masina la o unitate de reparatii auto AUTORIZATA.\r\nnu obligatoriu la dealerul/reprezentanta Skoda(daca acolo ati fost).\r\n\r\npovestea cu inchiriatul masinii este o marlanie.\r\nnu exista asa ceva (exceptand cazul in care ai lovit vreun recuperator feroce care te-a amenintat :D )\r\n\r\nparerea mea.\r\ndau detalii si raspund la intrebari pe email.\r\nbafta multa.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3 webaroo/1.2','',0,0),(6385,675,'ss','criss_team@yahoo.com','','81.196.150.198','2007-10-05 17:02:02','2007-10-05 15:02:02','deci Doamne-Doamne mi-o citit gandurile si o postat comentu pe care de fapt vroiam sa-l bag io.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7','',0,0),(8799,813,'CÄƒlÄƒ','acalarasu@gmail.com','http://adriancalarasu.wordpress.com/','62.217.241.242','2007-11-26 11:44:43','2007-11-26 09:44:43','Visez la o Romanie in care se AM CU CINE SI PENTRU CE - VOTA!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(8131,777,'nana','razornana@yahoo.com','','86.34.163.6','2007-11-16 08:16:18','2007-11-16 06:16:18','hahahahaha cristina e vara-mea :)) mnoah ca mi-ai adus zambetul pe buze de dimineata.. mutumesc',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(6667,697,'irina','irinamimoza@yahoo.com','','86.121.18.73','2007-10-12 17:35:19','2007-10-12 15:35:19','e o doamna.\r\n\r\nprimesc vreun premiu?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6668,414,'nenea cosmos','domnu_cosmos@yahoo.com','http://nenea.wordpress.com/','92.80.13.12','2007-10-12 19:37:12','2007-10-12 17:37:12','deci aÅŸa se agaÅ£Äƒ cu blogul... aahhaaaa...',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(9196,842,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2007-12-05 00:57:06','2007-12-04 22:57:06','Bascula aia de la reclama la Urinea... ptiu... Unirea?\r\n\r\nMi-s ONORAT!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9197,16,'admin','groparu_ro@yahoo.com','http://','89.137.109.142','2007-12-05 01:40:19','2007-12-04 23:40:19','EJ BAT! recunojti?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,1),(8090,789,'WhiteWolf','contact@white-wolf.ro','http://white-wolf.ro','89.32.115.161','2007-11-15 18:18:33','2007-11-15 16:18:33','Gropare, io cred ca , din pacate, chiar au treaba ... \"aceeia\" :P\r\nFac pe sustinatorii enuturilor prezidential-victoriene.\r\nDaca zice Asimetricu\' ca exista listaci, ei de ce sa-l contrazica ? - si uite asa ai ajuns , la randul tau, <b>listac</b>\r\nNimic in plus.\r\nCin\' draq, sa-ti mai dea, in ziua de azi, o rozetÃ£ de calitate si inca pe de-a moaca. Nu ? :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8091,786,'WhiteWolf','contact@white-wolf.ro','http://white-wolf.ro','89.32.115.161','2007-11-15 18:20:56','2007-11-15 16:20:56','Citez: <i>\"DeÅŸtiuâ€™ meu, Ã®nvÄƒÅ£at de o Ã®ndelungatÄƒ experienÅ£Äƒ, cÃ¢nd o vÄƒzut locuâ€™ liber, s-o strecurat instinctiv, aÅŸa cum l-am Ã®nvÄƒÅ£at eu, Ã®n despicÄƒturÄƒ.\"</i>\r\nIo zic sa faci un chestionar, sa intrebi si sa lamuresti  - doua intr-una - lumea\r\nIi vorba de un desth\' super educat sau ii vorba numa\' de un rebel care se ghideaza numa\' dupa ce-i comanda prea cinstita sulitzÃ£, cea far\' de minte ?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8092,788,'WhiteWolf','contact@white-wolf.ro','http://white-wolf.ro','89.32.115.161','2007-11-15 18:23:35','2007-11-15 16:23:35','Aha :)\r\nSi ziceati ca aveti familii, inginere, ... cutare-una-alta ? \r\nCa de aprins vad, va aprindeti de intra in faliment toti aia de se ocupeaza de disfunctiile erectile sau femeile ciapÃ£.\r\nBre, de cias e vorba.... de leapsÃ£ e vorba.....',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(9551,856,'manole','redtailanda@yahoo.com','http://www.mesterulmanole.wordpress.com','81.181.92.157','2007-12-11 10:26:00','2007-12-11 08:26:00','1. sa se faca ziua de lucru 6 ore in saptamana de 3 zile lucratoare; \r\n2. sa se mai opreasa circulatie cind apar pe strada (posesoare 9o C) - am multe regrete prea putine remuscari...;\r\n3.sa se condeseze astia 17 ani si inca urmatorii 17 in doua zile, de-ale mele, s-apuc si eu, maica!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows 98)','',0,0),(9168,841,'The Original Yankee','crisan_emil@yahoo.com','','89.43.186.64','2007-12-04 00:17:36','2007-12-03 22:17:36','buey gropi...\r\nbuey frate buey...\r\nsa-ti dau bricheta inapoi? daca stiam ca-i asa grav nu as fi acceptat, sa mor io',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9124,840,'manole','redtailanda@yahoo.com','http://www.mesterulmanole.wordpress.com','81.181.92.157','2007-12-03 08:40:51','2007-12-03 06:40:51','ase de, mironica este iara liber.\r\namu, intreb si eu ca prostu\', da\' pentru cat timp, di data aista?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows 98)','',0,0),(9125,840,'manole','redtailanda@yahoo.com','http://www.mesterulmanole.wordpress.com','81.181.92.157','2007-12-03 08:42:23','2007-12-03 06:42:23','imi plaÅŸe di tine.ai recuperiat.\r\nmecxi.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows 98)','',0,0),(9126,839,'manole','redtailanda@yahoo.com','http://www.mesterulmanole.wordpress.com','81.181.92.157','2007-12-03 08:50:29','2007-12-03 06:50:29','ti Ã®nÅ£eleg foarce bine.fumÄƒreÅ£ ca ÅŸi tine am avut ÅŸi eu oareÅŸce Ã®ncercÄƒri da\' mi-o trecut.\r\ndac am fost Ã®n stare sÄƒ mÄƒ Ã®mpac cu Å£ara mia, aÅŸa cum e ea, ca-n poezia ta, atunÅŸe m-oi Ã®mpaca ÅŸi cu pacatu\' aista.\r\nam zÃ¢s.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows 98)','',0,0),(8094,786,'andreanum','andreanum@yahoo.com','http://andreanum.wordpress.com','89.40.131.51','2007-11-15 18:55:28','2007-11-15 16:55:28','eu am fost odata la pizzeria asta gente, pe undeva pe linga piata cipariu, nush daca e aceeasi. Urit, mincare multa si proasta si servicii rapide ardelenesti. E drept ca mie imi era foame si secundele erau deja minute, dar nici sa stau o ora dupa un pizzoi pe care au turnat checiap (care eu nu maninc pizza cu checiap). Deci flit gente, nu mi-a placut, nu m-am mai dus. Poate m-au ginit ca sunt miticutsa si de-aia m-au lasat sa fierb, caci voi ardilenii va si jucati cu nervii sudici, e clar :D',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(6051,663,'WhiteWolf','laskmerge@gmail.com','http://whitewolf.1gb.at','89.32.115.74','2007-09-27 19:10:44','2007-09-27 17:10:44','Corect raspuns, corecta atitudine.\r\nDa\' pun pariu ca era patzit sau, pur si simplu n-a vrut sa (se) riste :) :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6052,663,'Miruna','mirunavasilescu@yahoo.com','http://potsafacsiasaceva.blogspot.com/','86.106.59.163','2007-09-27 19:52:43','2007-09-27 17:52:43','Mda, si eu zic ca a jucat prudent. Voi aveti microunde la serviciu?? In Cluj ma mut!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(9617,819,'eu,Miruna','mirunavasilescu@yahoo.com','http://potsafacsiasaceva.blogspot.com/','86.106.59.163','2007-12-12 01:01:32','2007-12-11 23:01:32','Daaa, eu doresc sa coalizez cu Andreea si sa crosetam o Tiganiada doar a muierilor. Razbunarea va fi a noastra!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9618,819,'eu,Miruna','mirunavasilescu@yahoo.com','http://potsafacsiasaceva.blogspot.com/','86.106.59.163','2007-12-12 01:16:05','2007-12-11 23:16:05','Esti constient ca jumatate din filmulet e cu brontozauru\' ala de l-ati prajit, nu?\r\nDa, sa fie Tiganiada feminina, sa fie!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(6055,658,'nenea cosmos','domnu_cosmos@yahoo.com','http://nenea.wordpress.com/','92.80.60.141','2007-09-27 21:31:21','2007-09-27 19:31:21','daca aveam voie de la conducere sa muncesc in locul ala la ora aia trebuia sa vina exact persoana care mi-a dat start pentru ca sa imi dea stop, nu o purie cu figuri in cap.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(6056,658,'nenea cosmos','domnu_cosmos@yahoo.com','http://nenea.wordpress.com/','92.80.60.141','2007-09-27 21:31:38','2007-09-27 19:31:38','daca',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(9066,838,'WhiteWolf','contact@white-wolf.ro','http://white-wolf.ro','89.39.81.95','2007-11-30 19:26:18','2007-11-30 17:26:18','Corect spus din om si femee\r\nCine-o mai vazut om cu koaele in piept ? :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.10) Gecko/20071115 Firefox/2.0.0.10','',0,0),(9584,858,'DÃ£nilÃ£','','','82.77.202.17','2007-12-11 17:04:16','2007-12-11 15:04:16','Nu te mai scot...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11;MEGAUPLOAD 1.0','',0,0),(9587,819,'WhiteWolf','contact@white-wolf.ro','http://white-wolf.ro','89.32.115.125','2007-12-11 18:32:27','2007-12-11 16:32:27','Hinu\' merita sa-i ierti intarzierile si \"alcoolizmele\" :) Buna triaba o facut, pan\' la urma\r\nPita de Simpa, palariile si barbile plus costumatia si insemnele heraldice fak tot chichirezu. \r\nMi\'aj pla ce dor de casa mi-o vint \r\nDa lasa.... trece ia si iarna asta si da iar coltu\' ierbii. S\'apÃ£ mai vorbim. :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(6148,666,'Fomeile','asewe@yahoo.com','http://de-aia.blogspot.com','86.106.48.234','2007-09-29 11:25:36','2007-09-29 09:25:36','ai ma gropare, astea is chestii super grele... nu-s de weekend!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.1) Gecko/20061204 Firefox/2.0.0.1','',0,0),(7988,785,'WhiteWolf','contact@white-wolf.ro','http://white-wolf.ro','89.32.115.123','2007-11-14 16:05:19','2007-11-14 14:05:19','Cel mai meserias e Romy din Cardinal, Gropare.\r\nAla de lucra mai acu ceva ani in groapa la Hermannstadt si s-a carat cand s-au reprofilat pe striptizuri aia cu groapa din Piata cu vrajitoare :)\r\nAm un preten care s-a chinuit sa-l scoata din minti aproape juma\' de an; in final tot pretenul a facut cu nervu\' :D\r\nSi nu doar ca e super ok fecioru\'.\r\nMerge drept chiar si cand e beat :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8188,790,'WarSongu','eternaldawnlord@yahoo.com','http://www.warsongu.wordpress.com','193.32.3.83','2007-11-16 17:49:19','2007-11-16 15:49:19','indeed, stiu ca multi au zenzatia de caldura insuportabila in preajma ta...hehe...mai scrii, sayaddhino?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; FunWebProducts; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(8015,788,'eu,Miruna','mirunavasilescu@yahoo.com','http://potsafacsiasaceva.blogspot.com/','86.106.59.163','2007-11-15 00:32:01','2007-11-14 22:32:01','Eu am ceasul de la mobil care e cu o ora si cinspe minute inainte. Cinspe minute ca sa fiu sigura ca nu intarzii, si o ora pentru ca el inca nu a trecut la ora de iarna. Da\' nu mai bine povestesti cum a fost la scorpioni? Am mentionat ca m-am pupat tacticos chiar pe buze cu dansii, toti, cand au fost la cerbul de aur, la brasov? A, n-am mentionat? Uite mentionez acus.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7990,785,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-11-14 16:24:25','2007-11-14 14:24:25','Deci daca il stii pe Romy, deja insamna ca ne-am invartit prin aceleasi cercuri ovale! Adevarat ca mititeii aia de la Cardinal erau cat o puza de magar? Geeeez...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(9213,843,'vizionarul','alinmiron_19@yahoo.com','http://vizionarul.wordpress.com','82.208.146.10','2007-12-05 13:00:04','2007-12-05 11:00:04','ar mai fi:\r\n- nu pot apasa pedala pana-n fund!\r\n- ce vrea politistul ala de tot da din maini?\r\n- scotand capul pe geam la semafor, catre tipele de pe trotuar: Ce faci fetele, nu vii sa dam o tura?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(8852,816,'WhiteWolf','contact@white-wolf.ro','http://white-wolf.ro','89.39.83.44','2007-11-27 02:47:35','2007-11-27 00:47:35','Eh, lasa... nu va incinjetz\' la povesti si vorbe de clacÃ£. Zau.\r\nStiti cum se zice; cratitza la dreapta, el curba la stanga, a fentat-o :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8688,807,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2007-11-23 22:26:09','2007-11-23 20:26:09','Dupa 12 nuaptea\r\n\r\nve-t-z\r\n\r\nafla.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8689,807,'irina','irinamimoza@yahoo.com','','86.121.22.124','2007-11-23 22:40:47','2007-11-23 20:40:47','pana dupe 12 nuaptea sa stai tu, care n-ai somn. io nu mai rezist, asa ca o sa aflu raspunsul  ala de e asa de simplu, ca nu l-o putut ghici nimenea, maine.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8690,807,'July','jullya24@yahoo.com','','83.103.179.55','2007-11-23 22:55:05','2007-11-23 20:55:05','....dupa 12 nuaptea....avand in vedere ca e vb de Groparu\'...si ca de data asta vrea sa se exprime la o ora cu \"patratel roshu\"...cred ca ne pregateste ceva maretz....cin\' poate sti ce idei fierb in capshorul ala....',0,'1','Opera/9.10 (Windows NT 5.1; U; en)','',0,0),(8691,807,'eu,Miruna','mirunavasilescu@yahoo.com','http://potsafacsiasaceva.blogspot.com/','86.106.59.163','2007-11-23 22:57:11','2007-11-23 20:57:11','Nu mai suport bolta aia de mere, vad indicii peste tot, parc-as fi la notpr0n. Ma duc sa beau o bere pe banii mei!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8012,788,'DÃ£nilÃ£','','','84.232.149.204','2007-11-14 23:45:11','2007-11-14 21:45:11','Mie Ã®mi seamÄƒnÄƒ mai mult a 59, dar care 59 e rudÄƒ bunÄƒ cu 68! Cititorii fideli ai blogului ÅŸtiu care-i ÅŸpÃ¢rla. CeilalÅ£i sÄƒ facÄƒ un exerciÅ£iu de imaginaÅ£ie: una din pÄƒrÅ£i rÄƒmÃ¢ne datoare! SÄƒ-ÅŸi spunÄƒ oare cuvÃ¢ntul vÃ¢rsta Ã®naintatÄƒ a lu` Gropy?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.4','',0,0),(8658,803,'unu','csssvaf@yahoo.com','','195.212.29.187','2007-11-23 16:23:31','2007-11-23 14:23:31','La noapte plec la amsterdam, deci cand bag la ganja ma gandesc la tine gropare , promise !',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(6226,668,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-10-02 13:30:20','2007-10-02 11:30:20','@ andre: ezac :| ze very guy',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6227,662,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','82.77.126.148','2007-10-02 13:35:08','2007-10-02 11:35:08','gata, dat leapsa mai departe. sa-mi mai dai lepse din astea de m-ajuta sa ma descarc de fluide si lichide, da? :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6229,670,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','82.77.126.148','2007-10-02 14:49:08','2007-10-02 12:49:08','oioioii gropare, asta sa-ti fie invatatura de minte. banii se verifica acolosha, pe loc, dupa ce ti i-o dat. daca nu vroia sa ti-i schimbe ce faceai? :P cu protectia consumatorului nu faceai nimic, ca nu puteai dovedi ca ea ti-o dat banu rupt',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(8255,792,'eu,Miruna','mirunavasilescu@yahoo.com','http://potsafacsiasaceva.blogspot.com/','86.106.59.163','2007-11-17 21:38:55','2007-11-17 19:38:55','Eu cred ca tu de fapt te mai duci la o nunta dar nu vrei sa recunosti. :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(6232,670,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-10-02 15:31:36','2007-10-02 13:31:36','La pasarea chioara ii face \'mniezau cuib, la groparele chior il apara de bani rupti! (sper sh pe viitor)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6233,662,'Adi Calarasu','acalarasu@gmail.com','http://adriancalarasu.wordpress.com/','62.217.241.242','2007-10-02 15:42:21','2007-10-02 13:42:21','Moooaaaah, deci tocmai te-ai luat de tagma mea!\r\nGata, scriu blogul ala despre carti traduse najpa!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(6234,669,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-10-02 15:52:37','2007-10-02 13:52:37','Mo, deci de data asta creca o fi ramas moartea la bere prea mult sh o batut-o barba-su!!! (e super tare sa fii tinerel sh sa te razi de moarte, ca-i dai m***) :D:D:D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(9191,16,'Lush','copilurau@yahoo.com','','193.231.18.7','2007-12-04 22:44:38','2007-12-04 20:44:38','FFFFF tare...dupa asta imi vine sa ma las de blogul meu..satu tot in 16...  www.blogulucostel.blogspot.com',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9192,842,'Lush','copilurau@yahoo.com','','193.231.18.7','2007-12-04 22:52:45','2007-12-04 20:52:45','gropare, ar trebui sa te faci sofer de troleu  www.blogulucostel.blogspot.com   ma promovez si eu la tine k u esti chiar tare...hai sa ne promovam reciproc...desi si eu ma vreau un funny..da is mai slabutz ca u..am numa 75 de kile..da stau in 16, et 5:D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9083,838,'Andreea MKT','supergirgir@yahoo.com','','89.43.186.64','2007-12-01 15:09:38','2007-12-01 13:09:38','evident ca Groparitza e mai tare, e de-a mea, mah:)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.10) Gecko/20071115 Firefox/2.0.0.10','',0,0),(8248,792,'vizionarul','alinmiron_19@yahoo.com','http://vizionarul.wordpress.com','89.35.80.185','2007-11-17 17:08:53','2007-11-17 15:08:53','lasÄƒ mÄƒ gropare ce-i cÄƒ-i sÃ¢rb, e european ca noi toÅ£i, aÅŸa cÄƒ beÅ£ii plÄƒcute.\r\nLa cÃ¢te popoare migratoare au trecut prin zona asta, trebuia sÄƒ fie aicea la noi cel mai mare nod feroviar ÅŸi rutier din europa... ÅŸi nu-i de mirare cÄƒ naÅ£iile din spaÅ£iu aiesta carpatodanubianopontic se aseamana... Oricind una sau mai multe sedinte de Ã®mbetat, indiferent de etnia participanÅ£ilor sunt binevenite.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8249,97,'Ovidiu','','','89.137.74.222','2007-11-17 17:17:59','2007-11-17 15:17:59','superb ... nici nu stiu cum am ajuns sa citesc articolul asta dar ma bucur de micile strazi laturalnice pe care le intalnesc in cursul navigarii pe net.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(8250,58,'Vincenzo','','http://horo.hotfunspace.com/page-1.html','195.225.177.190','2007-11-17 17:26:20','2007-11-17 15:26:20','<strong>Page 1-9...</strong>\n\nWriter Taran Jordan describes a gulch as\n...',0,'1','USERAGENT','trackback',0,0),(9121,840,'NRGY','dani@live.co.uk','','86.121.174.70','2007-12-03 06:50:45','2007-12-03 04:50:45','O mizerie. Rusine sistemului nostru juridic si celor cu putere decizionala.\r\n\r\nSi... Iliescu`le, noi nu te`am uitat cu gratierea aia ;)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9181,842,'vizionarul','alinmiron_19@yahoo.com','http://vizionarul.wordpress.com','89.35.87.15','2007-12-04 16:58:45','2007-12-04 14:58:45','mai gropy ma... da \"rau\" esti ma... sunt curios cand termini tu scoala de choffeuri cat o imbatranit nenea instructoru...:D:D:D',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(6246,57,'Midnite','boddy_aq@yahoo.com','http://diseara.ro','89.114.108.83','2007-10-02 22:46:47','2007-10-02 20:46:47','. ...continuarea,,\r\n\r\ntu, poet necunoscut\r\n$u&amp;u-ti muma-n $u* sa-ti #u@\r\ncand mai vii pe la closet,\r\ncaca-te, nu fi poet!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(6247,670,'nenea cosmos','domnu_cosmos@yahoo.com','http://nenea.wordpress.com/','92.80.63.206','2007-10-02 22:55:32','2007-10-02 20:55:32','ba groapa, tie iti zic astia ca dobinda vine de la bucuresti. eu care m-am interesat pentru tine acilea am aflat ca o scoate calculatoru\'. asta ca sa stii si tu, ca bill gates e de vina.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(9159,841,'Sergiu BiriÅŸ','sergiu.biris@trilulilu.ro','http://www.sergiubiris.ro','89.137.4.179','2007-12-03 21:19:02','2007-12-03 19:19:02','Gropare, am fumat 7 ani de zile, ziua si pachetu\'. M-am lasat intr-o zi dintr-o data, desi aveam 2 cartuse de tzigari pe care ulterior le-am aruncat. A trecut deja un an si cateva luni de cand nu mai fumez &amp; I feel great. Nici nu mai simt nevoia. Cam <a href=\'http://www.sergiubiris.ro/personal/doua-luni/\' rel=\"nofollow\">asta</a> simteam dupa 2 luni de nefumator. Hope it helps. Keep it up mah, ca potzi :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9160,841,'baghy','baghy83@lycos.it','http://baghy.info/','78.12.6.155','2007-12-03 22:22:10','2007-12-03 20:22:10','Dinamovist ba Gropare? Nu stiu ce e mai nasol. Asta sau fumatul :))',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(9139,839,'CÄƒlÄƒ','acalarasu@gmail.com','http://adriancalarasu.wordpress.com/','62.217.241.242','2007-12-03 15:55:29','2007-12-03 13:55:29','Citindu-te imi dau seama ca sunt un fericit. Io cica-s fumator, dar ultima tigara am fumat-o... sambata seara, parca. Pur si simplu n-am pofta...\r\n\r\nPS - Nicoretu\' mai mult face pofta de fumat! Ai grija!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(9140,839,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-12-03 16:30:11','2007-12-03 14:30:11','Vreau sa trag din chestia asta oricata voluptate se poate! :D FÄƒrÄƒ aditivi ÅŸi coloranÅ£i artificiali nicoreÅ£i.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.10) Gecko/20071115 Firefox/2.0.0.10','',0,0),(6395,675,'Miruna','mirunavasilescu@yahoo.com','http://potsafacsiasaceva.blogspot.com/','86.106.59.163','2007-10-05 21:24:58','2007-10-05 19:24:58','Si daca eu nu beau inseamna ca nu-s demna de tara asta?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6397,675,'baghy','baghy83@lycos.it','http://baghy.info/','78.12.8.67','2007-10-05 22:04:00','2007-10-05 20:04:00','ai scris destul :))',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(6398,675,'macabroo','raduccc@yahoo.com','http://rezistenta.blogspot.com','82.76.52.94','2007-10-05 22:11:55','2007-10-05 20:11:55','Deci da! Dar oare, lu\' ganditoru\' ii mirosea puternic gura a usturoi? Pe grasa o combinase din mila, pentru ca stia sa fac varza, barza manz bine sau pentru ca avea soldurile late, deci putea sa nasca multi copii, si totodata putea sa supravietuiasca peste iarna?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(9042,832,'WhiteWolf','contact@white-wolf.ro','http://white-wolf.ro','89.32.115.34','2007-11-30 09:03:18','2007-11-30 07:03:18','Spune pana la capat ! :)\r\n<b>Muzica de dans si bune maniere</b> :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.10) Gecko/20071115 Firefox/2.0.0.10','',0,0),(9043,831,'manole','redtailanda@yahoo.com','http://www.mesterulmanole.wordpress.com','81.181.92.157','2007-11-30 10:20:14','2007-11-30 08:20:14','poezie misteaux, pacat ca nu te-ai oprit la timp...e in plus ultima strofa, parerea mea.\r\nin rest, cred ca bantuie (la apogeu) in blogosfera un sictir de tara asta (si nu de geografie - e, poate un pic si la ea)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows 98)','',0,0),(9396,852,'manole','redtailanda@yahoo.com','http://www.mesterulmanole.wordpress.com','89.32.123.108','2007-12-09 10:34:16','2007-12-09 08:34:16','11. Toata noaptea mirele a ciupit o gajica de cur. Si ce daca? Acuma e al tau!\r\n12.La masa cu soacra-ta sta ultima lui prietena.\r\n13.Ase ca-ntre prietene ti-am spus sa nu-l iei p-asta!\r\n14.Auzi mirele stie de filmuletul nostru de pe net?\r\n\r\nase de completare... daca e permis. ca oameni buni si di treba, pesti tÄƒt.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(9182,832,'lucruri bune care se intimpla &laquo; andreanum &amp; co','','http://andreanum.wordpress.com/2007/12/04/lucruri-bune-care-se-intimpla/','72.233.2.49','2007-12-04 17:07:18','2007-12-04 15:07:18','[...] Intimplator, imediat ce am apucat sa-i promit astuia ca il citez pe el si nu pe altul, am aflat ca groparele deja scrisese despre acelasi fenomen. Asa ca m-am impiedicat citeva zile, sa las sa treaca umoarea [...]',0,'1','Incutio XML-RPC -- WordPress/MU','pingback',0,0),(9183,842,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-12-04 17:13:39','2007-12-04 15:13:39','D\'apoi las\' ca nenea instructoru isi spala obrazele in bunoacele si bunesele si bunaciunile care vin la scoala de soferi, ca nu-s toti elevii prostalai dificili ca mine!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9087,838,'cÄƒlÄƒ','acalarasu@gmail.com','http://adriancalarasu.wordpress.com/','89.32.19.126','2007-12-01 16:40:50','2007-12-01 14:40:50','ma, nu-nvatza ma fomeia la beut!\r\nce-ai, vrei sa devina obisnuintza, dupa aia sa trebuiasca sa-mparti mereu cu ea?!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) )','',0,0),(9143,840,'Lexis','g_lexis2005@yahoo.com','http://www.alexandraghitalexis.blogspot.com','89.38.76.46','2007-12-03 17:30:20','2007-12-03 15:30:20','iar ti-am lasat o leapsa, scuze, nu ma pot abtine...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9045,832,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','82.77.126.148','2007-11-30 10:29:18','2007-11-30 08:29:18','groparu, deci daca e voie cu fete atunci viu si io! miruna, daca vii la cluj sa-mi dai un semn!!!! :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.10) Gecko/20071115 Firefox/2.0.0.10','',0,0),(9323,850,'Usim','mihaimitan@gmail.com','','87.237.108.33','2007-12-07 18:06:21','2007-12-07 16:06:21','Da chiar asa, am si pierdut numaratoarea nuntilor la care ai fost anul asta.\r\nAi atatea costume sau numa\' o uniforma de nunti, botezuri si inGropaciuni? :-))',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; .NET CLR 2.0.50727)','',0,0),(9322,847,'dodger','vick_redhound@YAHOO.COM','','89.43.11.130','2007-12-07 17:47:36','2007-12-07 15:47:36','NU ESTI SANATOS FRATE, SA MA BATA MAMA DACA ESTI!!! =))',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; .NET CLR 1.1.4322)','',0,0),(6258,664,'daredariuz','','','89.137.228.97','2007-10-03 06:21:27','2007-10-03 04:21:27','de bine cuaie!',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; InfoPath.1)','',0,0),(7856,772,'Viking','liviutz_86@yahoo.com','','89.122.234.5','2007-11-09 17:39:35','2007-11-09 15:39:35','culmea ironiei... sa citesti postu despre iulius din polus (asa cum am facut eu :) )',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(7857,772,'Groparu','groparu_ro@gmail.ro','http://www.groparu.ro','82.77.126.254','2007-11-09 17:51:20','2007-11-09 15:51:20','@ nana: alea is langa kinejii din valize!\r\n\r\n@ cronicaru: deci mol de groparit!\r\n\r\n@ viking: TAAAAREEEEEEE =))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(6406,402,'darie','cs@yahoo.com','','70.81.78.176','2007-10-06 05:04:44','2007-10-06 03:04:44','Veti vota pentru Traian Basescu la viitoarele alegeri prezidentiale?: http://www.geocities.com/sondajeopinie',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1) Gecko/20061010 Firefox/2.0','',0,0),(6614,646,'darius f','darius2u@yahoo.com','http://desprepsd.wordpress.com/','82.79.33.247','2007-10-10 18:23:42','2007-10-10 16:23:42','Un sex shop, o firma de pompe funebre, o firma de salubrizare, etc.\r\n\r\nParerea mea.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(6615,676,'cezar','khensthoth2001@yahoo.com','','82.137.51.179','2007-10-10 19:11:30','2007-10-10 17:11:30','ba...cum sta treaba cu taguitu?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(6616,676,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2007-10-10 19:15:37','2007-10-10 17:15:37','Deci ii ca un fel de-a prinselea, scoti o idee, o intrebare, o chestie de genu asta, si trimiti la altii sa le afli parerile. Cumva cam ce or facut alea doo pustoaice care or imbolnavit tot satu\' de sifilis.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6617,691,'funinromania','cristiscu@gmail.com','http://funinromania.blogspot.com','204.244.209.115','2007-10-10 19:16:08','2007-10-10 17:16:08','Britney, Paris, Lindsay... generatia fufelor tinere ajunse prea de timpuriu starlete. O tragedie despre ce face faima si banul la o varsta cand n-ai destula maturitate. Cel mai rau imi pare de Lindsay Lohan :(',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(7858,758,'Tudor','','http://dingrajd.blogspot.com/','89.136.23.215','2007-11-09 21:44:35','2007-11-09 19:44:35','PoÅ£\' conta pe mine Gropare... daca nu ai dusmani .. \r\n\r\nIa adunÃ¢Å£ prekhienarii si pretenoÅŸii di pi valea viilor si fÄƒÅ£ on club . un enimi-clab... si aÅŸe o sa ai dusmani cati vrei.. binenÅ£Äƒles ca  toti o sa aiba acelasi numar de enemis .. adica dupÄƒ o formoala matematica bine calculata \r\n\r\nE = n - 1  , unde E = numaru de dusmeni (parca as scrie o m**ea) , n = numaru de menbrii ÅŸi normal ca -1 ca doar no sa iti fi propriu dujmen. \r\n\r\nParerea mea..',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(6619,676,'Cezar blog - Leapsa - nume de indian','','http://cezar.haipa.ro/2007/10/10/leapsa-nume-de-indian/','193.203.204.226','2007-10-10 19:17:11','2007-10-10 17:17:11','[...] Leapsa - nume de indian  (No Ratings Yet) &nbsp;Loading ...  October 10th, 2007 by  cezar De la Groparu. [...]',0,'1','Incutio XML-RPC -- WordPress/supermoded by haipa v6','pingback',0,0),(6620,692,'nume','numeduc@mail.com','','62.224.242.137','2007-10-10 19:21:00','2007-10-10 17:21:00','iar oaminii din bacau is bacani. asa si este !',0,'1','Mozilla/5.0 (Macintosh; U; PPC Mac OS X Mach-O; de; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6621,691,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2007-10-10 19:27:24','2007-10-10 17:27:24','Mah, io m-am asteptat la chestia asta, d-aia am refuzat sa pornesc prima mea formatie de girls, finc-acum as fi fost super bogat si nefericit.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6622,692,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2007-10-10 19:28:23','2007-10-10 17:28:23','Da! Sau petremihaibacani. (http://ro.wikipedia.org/wiki/Petre_Mihai_B%C4%83canu)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6624,692,'milanesta','ana_stefanaaa@yahoo.com','','89.34.180.55','2007-10-10 21:26:45','2007-10-10 19:26:45','HAITI = grupuri de lupi flÄƒmÃ¢nzi care bÃ¢ntuie prin judetul Botosani   ;)',0,'1','Opera/9.10 (Windows NT 5.1; U; en)','',0,0),(9054,831,'baghy','baghy83@lycos.it','http://baghy.info/','78.12.2.226','2007-11-30 13:36:07','2007-11-30 11:36:07','White am pus poezia lu Groparu si s-a dus totul pe apa sambetei :))',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(9147,839,'irina','irinamimoza@yahoo.com','','86.121.23.68','2007-12-03 19:06:18','2007-12-03 17:06:18','io nush cum e cu fumatu, ca nu practic, da la faza cu oalele care misca te inteleg, ca am si io. si culmea, tot mamaliga o fost acolo. acum intrebarea e: ce ne facem? continuam sa ne uitam la ele ca vitelu la poarta noua sau intreprindem ceva?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9148,841,'L3ST','webmaster@l3st.com','http://www.l3st.com/','89.34.244.21','2007-12-03 19:16:19','2007-12-03 17:16:19','Mult succes. Eu m-am lasat de vreo 5 ori .. intr-o saptamana! :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 ImageShackToolbar/4.3.5 Firefox/2.0.0.11','',0,0),(9149,841,'July','jullya24@yahoo.com','','89.123.242.127','2007-12-03 19:26:00','2007-12-03 17:26:00','...cunoastem, cunoastem....da\' sa vezi la noapte chin...o sa visezi ca esti patronu\' la British American Tabacco, si ca stai pe un munte de pachete...si mama ce curve is toate ca se dau la tine ceva de groaza!!...da las...ca ai zis ca esti capos...poate treci si de faza asta!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(9105,838,'manole','redtailanda@yahoo.com','http://www.mesterulmanole.wordpress.com','89.32.123.108','2007-12-02 19:37:47','2007-12-02 17:37:47','un\' esti gropare, di dou zile?\r\nca eu ce mai cetesc sa mi se descreteasca fruncea?\r\nha?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(9164,839,'dodger','vick_redhound@YAHOO.COM','','89.43.11.130','2007-12-03 23:11:49','2007-12-03 21:11:49','Fratilor, eu nu reusesc sa ma las. Incerc si iar incerc da... nu am reusit decat sa le raresc de cateva ori, ca dupa aia iar bagam ca furnalu. Si faza cu oalele... Bai baietz si fete, ziceti mersi ca ale voastre sunt in balcon; ca ale meles in bucatarie si nu mai am curaj sa deschid usa.... AJUTOOOOOOOOOOOR',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; .NET CLR 1.1.4322)','',0,0),(9171,841,'WhiteWolf','contact@white-wolf.ro','http://white-wolf.ro','89.39.82.129','2007-12-04 06:25:07','2007-12-04 04:25:07','Bun. Am inteles si\'n general si\'n particular cat te poti dovedi de \"BAD\" ; chit ca n-ai pomenit nimic de moonwalk :P\r\nMa risc, totusi, fac o intrebare:\r\n<b>Si cu tzigara \"de dupÃ£\" cum ramane ?!?</b> :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9173,841,'Femeile','ps@yahoo.com','http://ce-vor-femeile.blogspot.com','213.157.188.71','2007-12-04 09:41:52','2007-12-04 07:41:52','vezo aci - http://ultima-moda.blogspot.com/2007/12/nico-clean-crema-din-tabac-ce-iti-face.html\r\n\r\npoate te ajuta :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9174,763,'Hammer','hammer@alpinet.org','http://www.alpontos.wordpress.com','86.120.55.79','2007-12-04 11:27:53','2007-12-04 09:27:53','Si stai ca asta e un oras cu primare sas...:-)) Da\' numa atat ai vazut tu in orasul meu natal?? Slabutz..!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(9175,801,'TIGANII si-au pierdut identitatea ?!? Sau pur si simplu o reneaga ?!? &raquo; Artistu&#8217; zice ca&#8230;','','http://artistu.voce.ro/2007/12/04/tiganii-si-au-pierdut-identitatea-sau-pur-si-simplu-o-reneaga/','91.200.120.1','2007-12-04 12:04:13','2007-12-04 10:04:13','[...] romilor in societatea romaneasca&#8221;, el a pus foarte bine problema ! NO OFFENCE ! * Idee partial funny, dar care la final te pune pe ganduri, by Groparu ! * Uite un tzigan bloager ! Io l-am trecut in FEED READER si promit sa il mai citesc [...]',0,'1','Incutio XML-RPC -- WordPress/2.2.3','pingback',0,0),(9321,807,'Mih_nea','mihnea_xxyahoo.com','','62.217.236.12','2007-12-07 17:25:46','2007-12-07 15:25:46','daca ne uitam un pic, parca ar fi litera U intoarsa  - deci U De MeRe\r\nparca-i mai original decat meri la vot :)\r\nraspund abia in decembrie ca abea ieri am descoperit blogul asta...',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(9306,850,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','82.77.126.148','2007-12-07 13:48:40','2007-12-07 11:48:40','mda, dar tu nu ai sa reusesti niciodata sa ai un orgasm de 30 de minute, ca un porc necastrat! :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9307,850,'baghy','baghy83@lycos.it','http://baghy.info/','78.12.6.155','2007-12-07 13:48:55','2007-12-07 11:48:55','si pierzi comparatia intre tine si porc',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(9308,847,'Kissu','','','82.77.126.254','2007-12-07 14:24:41','2007-12-07 12:24:41','Baaahhh... neseriosule! Cum adica \"vreo 2 ciocolatzici ieftine, o napolitana expirata si neshte bombonele de la Pastile din 2006, cica cadou de la Mosh\"...?! Tu cand ai fost ultima data la cumparaturi la raionul de dulciuri?... Se vede ca n-ai copii de crescut... :p Las\' ca ajungi si tu ca mine... Si daca tot nu-ti place ce-ai primit, sa stii ca 7 days\'ul ti l-am ingurgitat, ca mie imi plac si asa... \"ciocolatzici ieftine, o napolitana expirata si neshte bombonele de la Pastile din 2006, cica cadou de la Mosh \"...\r\n\r\nPS De data asta ti-am facut trafic, dar altadata... la revedere! Ne vedem joi! :p',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; InfoPath.1; .NET CLR 2.0.50727)','',0,0),(8970,822,'eu,Miruna','mirunavasilescu@yahoo.com','http://potsafacsiasaceva.blogspot.com/','86.106.59.163','2007-11-29 09:26:15','2007-11-29 07:26:15','Ia ultima fotografie semeni cu tata, ca m-am si speriat putin.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.10) Gecko/20071115 Firefox/2.0.0.10','',0,0),(9152,841,'Razvan Antonescu','razvan.antonescu@gmail.com','http://idei-locale.blogspot.com','79.113.138.204','2007-12-03 19:49:28','2007-12-03 17:49:28','ba nu mai scrie asa mult ca nu imi ajunge sa fumez o singura tigara per post si tre sa bag doua :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071018 Firefox/2.0.0.8 Flock/1.0RC3 VRE Toolbar 1.42','',0,0),(9153,841,'Mile','','http://milecarpenisan.wordpress.com/','79.114.67.197','2007-12-03 20:01:17','2007-12-03 18:01:17','Da de ce faci asta gropare? E un chin la care te supui DEGEABA. Tigarea e chiar buna la momentul potrivit. Poti insa sa le raresti...dar ia gandeste-te era buna mahoarca aia de la Cecenia? MMMM era.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; FunWebProducts; SIMBAR={A7F3C004-B2DD-4145-98BD-0344DDF9CD6E}; .NET CLR 2.0.50727)','',0,0),(9154,841,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2007-12-03 20:26:48','2007-12-03 18:26:48','@ all: deci am de gand sa rezist pentru ca mi-am pus in cap, si io-s capos, si si mazochist, deci de doo ori fericit, desi de 0 ori femeie!\r\n\r\n@ Mile: deci la mahoarca aia cecenÄƒ nu am interdictie :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9038,831,'darius f','darius2u@yahoo.com','http://desprepsd.wordpress.com/','82.79.52.137','2007-11-30 08:02:29','2007-11-30 06:02:29','Foarte tare poezia. Poate ar trebui sa deschizi o rubrica \"The poetry of the month\" si sa ne delectezi cu asa ceva mai des.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.10) Gecko/20071115 Firefox/2.0.0.10','',0,0),(6628,688,'calarasu','acalarasu@gmail.com','http://adriancalarasu.wordpress.com','89.32.19.126','2007-10-10 22:57:58','2007-10-10 20:57:58','puuuaaah, ce m-ai speriat ma, credeam ca-mi zici ca s-a facut asistentu\' de maro fatza de popica pt ca nu stia sa-ti zica ce-l intrebai tu si ti-a raspuns dom\' popica, cum se zice... instead!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(8905,813,'eu,Miruna','mirunavasilescu@yahoo.com','http://potsafacsiasaceva.blogspot.com/','86.106.59.163','2007-11-27 20:25:15','2007-11-27 18:25:15','Exaaaact!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8906,815,'eu,Miruna','mirunavasilescu@yahoo.com','http://potsafacsiasaceva.blogspot.com/','86.106.59.163','2007-11-27 20:26:44','2007-11-27 18:26:44','Deci asa ma enervati voi astia care sunteti masculini de gen si va tine sa va inghesuiti in oameni, sa va croiti singuri loc la metrou sau in troleu...asa o ciuda mi-e pe voi de nu pot sa va explic.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8907,815,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2007-11-27 21:05:45','2007-11-27 19:05:45','Apai tu, Miruna, da, chiar tu, ala ocupa tri loace, ca d-aia m-am naravat io, care-s arghelean 100% (spre nenorocul meu) si ma naravez dupa 3 zile, de obicei, cand ma prind de ofensa; si d-aia m-am hotarat sa intreprind aceasta expeditie de pedepsire! Alfel sa stii ca kiar am mult bun simptz, si in rest numa ma uit, da\' nu si pun mana. OK, pun mana, da\' nu si gust!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8908,818,'Scaevola','nevermind@yahoo.com','http://scaevola.weblog.ro/','82.78.115.81','2007-11-27 22:48:29','2007-11-27 20:48:29','Si voi chiar credeti miturile astea urbane? Probabil ca sunteti la fel de convinsi ca Ozzy, care e ecologist convins (de nevasta-sa, desigur, convins), a decapitat si un porumbel cu gura, la nu stiu ce conferinta de presa... In afara de Morrison, care si-a arat scarbavnicul madular intr-un concert la Los Angeles, fapt filmat si pentru care Lizardu\' si-a luat si arest, restul acestor \"grozavenii\" sunt fantezii erotice. Asa cum spunea un antevorbitor, in mod cert arunca doar cu apa - o faceau si cei de la Maiden sau J Priest - dar de aici si pana la excremente e un drum mai lung decat de la Radio Bucuresti la Radio Ereven...',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 2.0.50727)','',0,0),(8909,820,'NRGY','dani@live.co.uk','','86.121.174.200','2007-11-27 23:36:47','2007-11-27 21:36:47','Just happened faza 6 cu 5 minute inainte sa citesc minunatul tau post :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8910,820,'evilpenguin','evilpenguin666@gmail.com','http://evilpenguin666.wordpress.com','81.181.214.176','2007-11-27 23:42:36','2007-11-27 21:42:36','6-le mi se Ã®ntampla des :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.10) Gecko/20071115 Firefox/2.0.0.10','',0,0),(8911,820,'macabroo','raduccc@yahoo.com','http://rezistenta.blogspot.com','82.76.52.94','2007-11-27 23:50:39','2007-11-27 21:50:39','Cand pica ala micu. Sa-l botezi Traienel si sa-ti iei la revedere de la el. Dar el sa se agatze de margini si sa tipe ca-l cheama Cornel si ca are familie. Oricum gasesc extrem de expresiv pentru situatie acest filmulet pe care eu il gasesc demn de privit. http://www.youtube.com/watch?v=QFVoLz88hiU',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.10) Gecko/20071115 Firefox/2.0.0.10','',0,0),(8912,813,'dracu','lucrac2006@yahoo.com','http://new.ablog.ro/','85.186.144.251','2007-11-28 00:11:07','2007-11-27 22:11:07','ete inca unu din aia 3-4 care au votat cu tziganii :D.\r\n\r\ntu nu ti-ai luat-o pt asta? ca mie mi-a sarit lumea la gatzi deja :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8913,820,'WhiteWolf','contact@white-wolf.ro','http://white-wolf.ro','89.39.83.179','2007-11-28 00:24:40','2007-11-27 22:24:40','Mandra patrie, inventivi locuitorii ...dansei. Chit ca nu-i deloc unisex\r\nDa\' io zic ca-i bine; zau.\r\nPana nu se lasa cu impotente sau frigiditati, totul oricat de colateral dammages ar fi, tot cu fantezie se si remediaza\r\nGresesc ?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.10) Gecko/20071115 Firefox/2.0.0.10','',0,0),(6633,690,'Mile','','','86.125.48.205','2007-10-11 02:56:45','2007-10-11 00:56:45','Iti spun eu ca am fost acolo ...singura cladire care nu a primit nici o bomba si nici un glonte in razboi a fost...bineinteles Ministerul Petrolului...in rest totul ardea. (Beton textul tau )',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(8995,820,'CÄƒlÄƒ','acalarasu@gmail.com','http://adriancalarasu.wordpress.com/','62.217.241.242','2007-11-29 16:22:34','2007-11-29 14:22:34','Eu nu am facut niciodata kaky la munca, il las acasa dimineata.\r\nEra intr-un film cu mafioti - nasu\' ii selecta pe cei ce vroiau sa intre in Familie dupa urmatorul criteriu:\r\n-Te caci dimineata, la pranz sau seara?\r\nDaca nu se caca dimineata era respins!\r\n\r\nD-aia zic, pai e fromos, domn Groparu, sa margi cu sacul ala plin de rahat dupe domneavoastra tuata zioa?!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(7549,742,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-10-30 10:01:02','2007-10-30 08:01:02','@ Lupulainu: nuz, mah. nuz.\r\n\r\n@ lilith: d-na columbeaaaaanuuuu, ce placere sa aflu ca imi cetitz blogu\'!!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7860,779,'baghy','baghy83@lycos.it','http://baghy.info/','78.12.13.1','2007-11-09 23:41:58','2007-11-09 21:41:58','m-am saturat eu la cate nunti ai fost',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(7861,779,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2007-11-09 23:49:34','2007-11-09 21:49:34','Da, numa\' ca asta e fara cotizatie! Dimpotriva, e cu primire :D Deci is un fel de mire (bueeeek...!)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7862,779,'UnCopilutz','uncopilutz@yahoo.com','http://www.uncopilutz.haipa.ro','79.113.137.64','2007-11-10 00:17:37','2007-11-09 22:17:37','Ai grijÄƒ sÄƒ nu Ã®ncurci \"da\"-ul cu \"nu\"-ul cÃ¢nd or rÄƒspunde Ã®nsurÄƒÅ£eii, c-apoi TU o sÄƒ fii Äƒla care n-o sÄƒ mai aibÄƒ loc, nu nunta.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 2.0.50727)','',0,0),(8066,788,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-11-15 13:19:43','2007-11-15 11:19:43','Amu se zice ca masculii pÄƒroÅŸi Ã®s futÄƒcioÅŸi.\r\n\r\nIo nuÅŸ ce sÄƒ mai cred.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7851,772,'nana','razornana@yahoo.com','','86.34.163.6','2007-11-09 15:59:05','2007-11-09 13:59:05','l-am vazut si eu ieri...impropriu spus, ca pe nenea de sub fata acra nu prea l-am zarit... dar fetitele in pungi de cadou unde-s? :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7789,769,'nenapocano','faget@mail.com','','62.224.224.74','2007-11-07 21:13:28','2007-11-07 19:13:28','..da\' de-al cui esti din Togo ? :D',0,'1','Mozilla/5.0 (Macintosh; U; PPC Mac OS X Mach-O; de; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7790,769,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','85.186.77.129','2007-11-07 21:53:59','2007-11-07 19:53:59','io nu am fost in faget punct :P',0,'1','Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.0.12) Gecko/20070731 Ubuntu/dapper-security Firefox/1.5.0.12','',0,0),(7791,769,'.marius','marius@perijoc.com','http://marius.wirelessisfun.com','89.36.21.108','2007-11-07 21:59:43','2007-11-07 19:59:43','@lililth apai esti din cluj din cluj?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8996,832,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-11-29 16:23:08','2007-11-29 14:23:08','@ Miruna, printre soapte: claro ca are voeh! Da\' asta va fi mai incolo, nu maine, la deskidere.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.10) Gecko/20071115 Firefox/2.0.0.10','',0,0),(7002,712,'Botache','nasturei_verzi@yahoo.com','http://www.nasturei.wordpress.com','82.77.126.148','2007-10-22 10:20:38','2007-10-22 08:20:38','La aia cu pwla, vezi ca exista si varianta ca ea sa fie prea mare. O chestie intr-adevar trista. Poate chiar cea mai trista dintre toate aceste povestioare. ^.^',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.0; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7003,712,'Dorin','dorin.lazar@gmail.com','http://dorinlazar.wordpress.com/','82.77.42.66','2007-10-22 10:22:43','2007-10-22 08:22:43','Åži tipul cu pwla mare a plecat ÅŸi a fÄƒcut filme porno cu actori gay.\r\nThe end :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7004,712,'Dorin','dorin.lazar@gmail.com','http://dorinlazar.wordpress.com/','82.77.42.66','2007-10-22 10:24:11','2007-10-22 08:24:11','Sau dÄƒdea la tot cart\'eru\'.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(8257,790,'UnCopilutz','uncopilutz@yahoo.com','http://www.uncopilutz.haipa.ro','79.113.139.123','2007-11-17 22:08:29','2007-11-17 20:08:29','BunicuÅ£a stÄƒ, oare, cu \"Wiew My Webcam\" pe Yahoo Messenger?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 2.0.50727)','',0,0),(8258,792,'UnCopilutz','uncopilutz@yahoo.com','http://www.uncopilutz.haipa.ro','79.113.139.123','2007-11-17 22:10:39','2007-11-17 20:10:39','Mda, mda, a anunÅ£at ÅŸi el. PoftÄƒ mare!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 2.0.50727)','',0,0),(9047,831,'Sergiu BiriÅŸ','sergiu.biris@trilulilu.ro','http://www.sergiubiris.ro','85.186.68.72','2007-11-30 11:14:10','2007-11-30 09:14:10','Eu zic ca se poate preda la clasa I cu siguranta. Sa invete si ei realitatea, nu aberatii idealiste :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.10) Gecko/20071115 Firefox/2.0.0.10','',0,0),(8967,830,'mirra','','','83.103.137.234','2007-11-29 07:15:07','2007-11-29 05:15:07','Alea is arse gata:)) trebe doar stinse...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.10) Gecko/20071115 Firefox/2.0.0.10','',0,0),(9150,841,'Lexis','g_lexis2005@yahoo.com','http://www.alexandraghitalexis.blogspot.com','89.38.76.46','2007-12-03 19:34:33','2007-12-03 17:34:33','spor la rezistat',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9014,831,'July','jullya24@yahoo.com','','83.103.179.55','2007-11-29 21:35:12','2007-11-29 19:35:12','...eh...place, place...ar trebui sa te gandesti la un intreg volum..:)',0,'1','Opera/9.10 (Windows NT 5.1; U; en)','',0,0),(8986,832,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','82.77.126.148','2007-11-29 15:22:26','2007-11-29 13:22:26','oooo, viu si ioooo la deschidere!!! sper sa ajung, ca maine am o carutza de andrei si andree care dau de baut! daca is treaza la ora ceea viu sa vaz cu ochii mei!\r\npoti spune, asa, pentru ca sa stiu, ce fel de muzica se asculta acolo? ca io nu ascult chiar orice! :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.10) Gecko/20071115 Firefox/2.0.0.10','',0,0),(8987,820,'dush','tirbushon@gmail.com','http://dushrece.blogspot.com','193.230.155.70','2007-11-29 15:37:36','2007-11-29 13:37:36','e bun...la voi inca e decent anuntu\' ala din toalete...la noi scria ashe..citez \"domnilor, daca la dumneavoastra la mamuca se foloseau brusturii  la noi la oras se trage apa si se foloseste hartia igienica, iar pentru maini apa curenta si sapunul..toate cele bune...cacaciosilor\" dupa ce au prins niste urme ca de tractor si alte inginerii d\'astea closetiste..',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.10) Gecko/20071115 Firefox/2.0.0.10','',0,0),(8988,832,'natty','natty2277@yahoo.com','','86.106.49.165','2007-11-29 16:01:07','2007-11-29 14:01:07','da\' e bar sau discoteca:)?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(8989,832,'mishu','mishu@doingtheartwork.com','http://www.doingtheartwork.com','82.77.126.254','2007-11-29 16:01:07','2007-11-29 14:01:07','Thank you blog guru! Thank you, doingtheartwork.com va ramane profund indatorata domnule groparu.ro. Thank you, thank you! As mai scrie thank you da\' nu incape tot ce vreau sa esprim eu in aceste 2 cuvinte!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.10) Gecko/20071115 Firefox/2.0.0.10','',0,0),(9156,841,'nenea cosmos','domnu_cosmos@yahoo.com','http://www.nenea.wordpress.com','92.80.47.22','2007-12-03 20:53:31','2007-12-03 18:53:31','Recuperezi pentru Sf. Nicolae?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(9052,822,'adi','adyrotaru@yahoo.com','','89.120.56.7','2007-11-30 13:05:38','2007-11-30 11:05:38','Vai ce buze faine ai :))',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(8991,832,'Bernadette','briqo_o@yahoo.com','','82.77.126.254','2007-11-29 16:16:43','2007-11-29 14:16:43','domnu\' mishu..sa va ajut in exprimare..http://www.yonkis.com/mediaflash/unmillon.htm',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; FDM; .NET CLR 1.1.4322)','',0,0),(8992,832,'eu,Miruna','mirunavasilescu@yahoo.com','http://potsafacsiasaceva.blogspot.com/','86.106.59.163','2007-11-29 16:18:37','2007-11-29 14:18:37','La intalnirea asta a bloggerilor are voie si fetele? ca io n-am vazut pana amu Cluju\'. E departe?\r\nSilvan suna tare ca de obicei.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.10) Gecko/20071115 Firefox/2.0.0.10','',0,0),(8993,832,'eu,Miruna','mirunavasilescu@yahoo.com','http://potsafacsiasaceva.blogspot.com/','86.106.59.163','2007-11-29 16:19:09','2007-11-29 14:19:09','aaah, Bernadette, stii ca exista un cantec frumos care se cheama exact asa, nu?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.10) Gecko/20071115 Firefox/2.0.0.10','',0,0),(8994,832,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-11-29 16:22:03','2007-11-29 14:22:03','@ Razvan, fÄƒrÄƒ vidrÄƒ: deci ba, io-s gropar, nu spalator de buzi ca am ramas fara bani de platit prin bare!\r\n\r\n@ lilith, natty: ii club, deci se danseaza, daca se vrea, se bea, musay, si se orice mai vreti.\r\n\r\n@ Mishu: I am no blog curu!\r\n\r\n@ Bernadette: da sh linku cu \"you\'re welcum, you\'re welcum, you\'re welcum, you\'re welcum, you\'re welcum, you\'re welcum, you\'re welcum, you\'re welcum,...\"',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.10) Gecko/20071115 Firefox/2.0.0.10','',0,0),(6186,639,'nimeni','nimeni@nimeni.com','','79.118.5.42','2007-09-30 19:52:16','2007-09-30 17:52:16','No, stimabile, partea a doua Ã®i miÅŸto, da\' nuÅŸ de ce cÃ¢nd clicÄƒi pe prima crocodilu Äƒla mÄƒ Ã®njurÄƒ de mamÄƒ ÅŸi-mi zice ceva de genu \"Accesul la acest fisier este restrictionat\"',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(7957,784,'vizionarul','alinmiron_19@yahoo.com','http://vizionarul.wordpress.com','89.35.80.185','2007-11-13 21:10:35','2007-11-13 19:10:35','La multi ani gropare, sanatate si toate dorintele tale sa ti se indeplineasca!\r\nFaina zodie ma, da greu ii pana apuca careva sa va inteleaga...',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; .NET CLR 1.1.4322; .NET CLR 3.0.04506.30; MEGAUPLOAD 1.0; InfoPath.1; .NET CLR 2.0.50727)','',0,0),(7958,784,'nenea cosmos','domnu_cosmos@yahoo.com','http://www.nenea.wordpress.com','92.80.12.217','2007-11-13 22:28:42','2007-11-13 20:28:42','SÄ‚ FII TARE ÃŽN CUPÄ‚ ÅžI-N ÅžENILE!\r\n\r\nhttp://cmms.cat.com/cmms/servlet/cat.dcs.cmms.servlet.DynamicImageServlet?imageid=C253826&amp;imageType=9',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(6188,667,'kalapkura','kalapkura@yahoo.com','http://ciuciu','89.136.55.236','2007-09-30 21:07:56','2007-09-30 19:07:56','gropare, da mataluta de la ce lesini? nu de alta da e din trusa de machiaj a voastra filoloajele',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6189,666,'nenea cosmos','domnu_cosmos@yahoo.com','http://nenea.wordpress.com/','92.80.9.73','2007-09-30 22:47:05','2007-09-30 20:47:05','ptiu satana, asta e pagina cu numarul ala...',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(7959,784,'oedip','oedip74@gmail.com','http://oedip.blogspot.com','89.137.99.163','2007-11-13 23:59:46','2007-11-13 21:59:46','mai sunt 2 minute din  ziua de 13 si ma grabesc -da\' cu drag-sa-ti zic La multi ani!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7960,784,'you wanna','','','92.81.155.33','2007-11-14 00:09:30','2007-11-13 22:09:30','la muuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuulti aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaani!!!!!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7969,784,'eu','ripahoratiu@yahoo.com','','82.77.126.254','2007-11-14 10:34:00','2007-11-14 08:34:00','Astazi e ziua taaaaaaaaaaa,\r\nZi urata ca tiiiiiiineeeee\r\nTe-ai nascut, da\' de ce\r\nNe pedepsesti pe toti (nu rimeaza, nu are ritmu\' potrivit, da se potriveste de minune)\r\nCat de mult ma-nerveeeezi...\r\n\r\nIti dai seama cat de mult m-am scremut, ca, la 9 luni si ceva anisori, sa fac o poezie pentru spermatozoidul campion; ar tre\'i sa dai ceva de baut in acest sens.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.2; .NET CLR 1.1.4322; .NET CLR 2.0.50727; InfoPath.1; .NET CLR 3.0.04506.30)','',0,0),(7968,785,'raluca','ralucaghervan@yahoo.com','http://360.yahoo.com/ralucaghervan','89.137.11.203','2007-11-14 10:09:09','2007-11-14 08:09:09','mie nu mi-a placut de el ca:\r\n1. nu a vrut sa imi dea cartofi prajitzi simpli, numai ca si garnitura, si pe urma la altzii le-a adus\r\n2. am cerut de 3 ori un pahar gol, de fiecare data a dat din cap zambitor cum ca ar fi inteles, dar pahar iok\r\n3. cascavalul pane (pe care a trebuit sa il comand ca sa pot manca cartofi prajitzi) avea dimensiunile unei felii de bagheta, dar a fost delicios, deci s-a compensat',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.0.3705; .NET CLR 1.1.4322)','',0,0),(7965,784,'sepukku','dinamoenr1@yahoo.com','','85.120.159.10','2007-11-14 09:46:21','2007-11-14 07:46:21','la multi ani ma gropare!!!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0)','',0,0),(7966,784,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-11-14 10:00:15','2007-11-14 08:00:15','Deci io luv u all, asa sa stiti, si o sa mai cersesc d-estea, urari de LMA si la anu\'!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7967,785,'Ce vor muierile','ps@yahoo.com','http://ce-vor-femeile.blogspot.com','213.157.188.71','2007-11-14 10:04:16','2007-11-14 08:04:16','apoi sigur ti-o scuipat in zama',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(6192,667,'nenea cosmos','domnu_cosmos@yahoo.com','http://nenea.wordpress.com/','92.80.9.73','2007-09-30 23:22:32','2007-09-30 21:22:32','cine e constantinescu?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(6193,341,'Eoglidcx','forgpostst@mail.com','http://eogli.com','89.41.103.238','2007-10-01 02:29:54','2007-10-01 00:29:54','http://eogli.com    porno portal',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1)','',0,0),(6195,667,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-10-01 08:17:49','2007-10-01 06:17:49','@ Bibleotecaru\': PIN nu e partidu ala care are atatia membri cati un PIN de la card? Ca mi se pare ca am auzit de el...\r\n\r\n@ kalapkura: mo, io leshin numa cand iau jet de spray in fatza de la studentele pe care le pishc in autobuz!\r\n\r\n@ nenea: ii ala care o fost starleta principala din Don Quijote. De la Cotroceni.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6196,666,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-10-01 08:20:54','2007-10-01 06:20:54','@ lilith: de la mine ai nota 40 pentru comentariu\' asta!!! Wespect...\r\n\r\n@ Bibliotecaru: mah, porumbeii nu is pasarici? MULTE pasarici?\r\n\r\n@ nenea: da, mo, e pajina cu numaru\' ala, si d-abia astept sa vie pajina cu nr. 6969, sa va vad atunci ce mai comentati!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6197,665,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-10-01 08:21:34','2007-10-01 06:21:34','@ Nenea: da, mo, sh cine ii cara sanvishuri lu\' sysadmin\' dintr-o coperativa? IO, MAH, IO!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6198,667,'macabroo','raduccc@yahoo.com','http://rezistenta.blogspot.com','80.96.196.2','2007-10-01 08:55:56','2007-10-01 06:55:56','....si a calcat pe minge in \'98 de era sa-si rupa sheile. \r\nTermenul corect, Gropare, e \"intronizarea\" preafericitului patriarh bla bla. \r\nIntuitia si fotbalul jucat in orele de fizica din liceu imi spun ca tre\' sa aiba legatura si cu procesul de ionizare. \r\nAdica apa aia tre sa fie sfintita cumva. Iar ca sa fie PREA-sfintita cred ca trebuie sa treaca de doua ori prin trupul PREA fericitului. That\'s the circle of life.',0,'1','Opera/9.23 (Windows NT 5.1; U; en)','',0,0),(6199,667,'lilith','marcu_luiza@yahoo.com','http://www.aberatiunti.blogspot.com','82.77.126.148','2007-10-01 09:00:09','2007-10-01 07:00:09','o lesinat si, totusi, s-a mai si ridicat de jos? pacat, mare pacat! cred ca era posedat... trebe musai chemati calugarii din Tanacu pentru o mica exorcizare, sa piara duhurile rele!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6201,666,'koyrosh','a@a.com','','82.77.126.254','2007-10-01 10:16:33','2007-10-01 08:16:33','mo, franzolea, e bine s-o ai mare, mai ales daca stai cu dansa la soare, sa tzie umbra pamantului (macar aia). jtii tu la ce ma refer :D:D:D',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(8016,788,'Lexis | leapsa','g_lexis2005@yahoo.com','http://alexandraghitalexis.blogspot.com/2007/11/mi-venit-o-idee.html','89.38.76.46','2007-11-15 00:38:28','2007-11-14 22:38:28','Foarte original',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8017,788,'WhiteWolf','contact@white-wolf.ro','http://white-wolf.ro','89.32.115.123','2007-11-15 00:40:58','2007-11-14 22:40:58','Io vreau sa-ti semnalez doo chestii\r\n1 Ciasu\' tau ii asa paros ca se da macio. Nush de ce ai lasat asta subanteleasa, trebuia specificata in clar ca sa nu aiba, mai apoi, vorbe pe la trebonal, sireacu.\r\n2. Io cre\' ca DÃ£nilÃ£ are sheva sinji de moldovvian in dansul.\r\nCa de cand shed in Galati am aflat (pana si eu) care e treaba cu \"ÅŸpÃ¢rla\" si \"jegÃ£raia\" :P\r\nDa\' n-ai de ce-l pÃ£li numa\' pentru atata triaba',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8018,785,'WhiteWolf','contact@white-wolf.ro','http://white-wolf.ro','89.32.115.123','2007-11-15 00:45:03','2007-11-14 22:45:03','Am fo\' coleg de liceu cu Romica, Gropare. Jeneratii destul de apropiate :)\r\nSi-n plus, la beuturÃ£ e la profesionisti de cand il stiu \r\nCat despre cercurile elea, tot ce se poate. \r\nDaca mai adaugi ca, de bun ce ieream, numa Energeticu si Industrialu\' 3 le-am ratat (\"mai bine accepti sa te transferam inainte sa te exmatriculam si sa pierzi anu\') se poate zice ca astrele\'s favorabile :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(6204,63,'prieteni &laquo; niciodata&#8230;','','http://niciodata.wordpress.com/2007/10/01/prieteni/','72.233.2.65','2007-10-01 14:48:35','2007-10-01 12:48:35','[...] Si te uiti in agenda in telefon si de fiecare Paste, Craciun, Revelion constati ca dai ca dementu&#8217; cate 163 de mesaje care de care mai imbecile de parca ar fi concurs de poezii tematice la soimii patriei, si la 158 dintre ei le-ai ura, de fapt, din toata inima, altceva. [...]',0,'1','Incutio XML-RPC -- WordPress/MU','pingback',0,0),(6205,667,'marz','mariusrott@yahoo.com','','81.12.163.178','2007-10-01 15:24:13','2007-10-01 13:24:13','a lesinat ca l-a invins sistemu\' si a apucat sa manance in dimineata aia... doar a zis clar la stiri, nu stiu ce ne mai ascundem dupa desht.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.2) Gecko/20070219 Firefox/2.0.0.2','',0,0),(6206,667,'marz','mariusrott@yahoo.com','','81.12.163.178','2007-10-01 15:24:58','2007-10-01 13:24:58','erata: \"NU a apucat\"',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.2) Gecko/20070219 Firefox/2.0.0.2','',0,0),(6207,662,'ania','soredarkshines@gmail.com','http://aniakhaki.blogspot.com/','89.123.106.233','2007-10-01 19:17:23','2007-10-01 17:17:23','http://aniakhaki.blogspot.com/2007/09/leapsalepra-oficial.html in special edit pentru un gropar! si la 5 nu te sustin... ca iei painea de la gura designerilor din egoism... sa ai ce pune pe blog :&gt;',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6208,662,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2007-10-01 19:42:37','2007-10-01 17:42:37','Aha! deci te tragi pe poponetz!!! Deci e OK, numa revino-tz, ca ej racita.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6209,662,'ania','soredarkshines@gmail.com','http://aniakhaki.blogspot.com/','89.123.106.233','2007-10-01 20:28:27','2007-10-01 18:28:27',':( da... sper sa-mi revin! si nu ma trag pe cur ca nu am chef sa-mi rup pantalonii :&gt; ioi... ce vulgar vorbeste ania asta...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6210,662,'nenea cosmos','domnu_cosmos@yahoo.com','http://nenea.wordpress.com/','92.80.16.26','2007-10-01 20:58:21','2007-10-01 18:58:21','de unde se vede ca in administratia locala dinsii nu sint nici macar labagii, pentru ca labagiilor li se scoala. puteti voi sa dati leapsa numa numa, parol ca le vor veni doar idei despre cum sa isi amenajeze birourile:\r\nprimavara parchet de mahon ca e belea\r\nvara marmura peste parchet sa fie racoare\r\ntoamna o mocheta gigea peste marmura sa nu ii critice lumea\r\niarna linoleum ca intra taranii uzi pe picioare si strica parchetul, marmura si mocheta',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(8694,807,'nenea cosmos','domnu_cosmos@yahoo.com','http://www.nenea.wordpress.com','92.80.60.163','2007-11-23 23:27:18','2007-11-23 21:27:18','deci eu dupa ce m-am uitat circa vreo 5 minute la imagine am inteles ca mesajul subliminos este ca o sa ma doara capul daca ma mai gindesc prea mult. am intrat pe comenturi, am citit ceva cu mere, evident, tot mere sint si in poza, normal ca nu scrie lumea de clatite si brichete, da sa zapacesc daca eu pricep ce mesaj subliminal ai tu acilea. m-am apucat sa numar merele, 25 de bucati clar vizibile, 25, iar nu vad legatura. jur ca nu ma apuc sa numar frunze, esti prea complicat pentru mine. eu vreau premiul pentru cel care n-a inteles cel mai frumos mesajul tau, sau n-ai asa premiu? dai ma si tu ceva?\r\n\r\napropo, si de ce e scris sub poza *LA VOT* ?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(8633,803,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','82.77.126.148','2007-11-23 11:57:18','2007-11-23 09:57:18','bai, ce rau ai fost cu bernadette! vai de eram in locul ei nici nu apucai sa termini de gandit ideea ca te si trosneam :)))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8077,788,'adi','adyrotaru@yahoo.com','','89.120.56.7','2007-11-15 16:01:58','2007-11-15 14:01:58','Imi place \"globu\'\" lu\' groparu\' ca pana la urma, asa cum toate drumurile duc la roma (cu \"rr\" mic mic de tot!, muri-o-ar toti cu tot cu tigani!), tat ashe, tate discutiile se duc in sexuri.\r\nVivat Kant, c-o fo\' on vizionar la fel de mare ca Einstein, pe domenii conexe, naturlich.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(8078,788,'ss','criss_team@yahoo.com','','81.196.150.198','2007-11-15 16:03:53','2007-11-15 14:03:53','@lexis: oio, da cum sa nu. alea-s cele mai focoase. conditia necesara si suficienta i sa nu uite de salonu de cosmetica.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7','',0,0),(8005,785,'Lexis | leapsa','g_lexis2005@yahoo.com','http://alexandraghitalexis.blogspot.com/2007/11/mi-venit-o-idee.html','89.38.76.46','2007-11-14 21:37:02','2007-11-14 19:37:02','leapsa pentru tine',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8070,789,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-11-15 15:16:45','2007-11-15 13:16:45','@ irina: deci unii chiar n-are treaba deloc, sa-mi deie mie rozete!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8071,788,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','82.77.126.148','2007-11-15 15:19:44','2007-11-15 13:19:44','futacios nu e tot una cu viril! deci hotaraste-te, ce esti? :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8072,788,'ss','criss_team@yahoo.com','','81.196.150.198','2007-11-15 15:21:49','2007-11-15 13:21:49','femelele paroase is futacioase :D :-\"',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7','',0,0),(8074,788,'Lexis','g_lexis2005@yahoo.com','http://www.alexandraghitalexis.blogspot.com','89.38.76.46','2007-11-15 15:25:48','2007-11-15 13:25:48','@ss: or fi futacioase da\' nu cred ca le fute nimeni',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(6058,657,'nenea cosmos','domnu_cosmos@yahoo.com','http://nenea.wordpress.com/','92.80.60.141','2007-09-27 22:12:01','2007-09-27 20:12:01','nu-ti fur nimic ca eu sint insurat si in alt oras.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(9176,841,'Bernadette','briqo_o@yahoo.com','','82.77.126.254','2007-12-04 15:18:06','2007-12-04 13:18:06','da za tzigara de rev nu i valabila nu? :-\" puf.. puf.. puf ..',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; FDM; .NET CLR 1.1.4322)','',0,0),(9177,841,'macabroo','raduccc@yahoo.com','http://rezistenta.blogspot.com','80.96.196.2','2007-12-04 16:24:53','2007-12-04 14:24:53','Am citit redactor (lol). Deh nimeni nu-i perfect. Da\' lu ala din reclama cum de-i iese asha de bine: \"nu vi si tu la o tzigare?..nu nu incerc sa mi-o scurtez\"',0,'1','Opera/9.23 (Windows NT 5.1; U; en)','',0,0),(9178,831,'sktes','sktes_2002@yahoo.com','http://sktes.wordpress.com/','79.113.137.154','2007-12-04 16:43:30','2007-12-04 14:43:30','Daca mai ai nevoie de materiale ca in ultima poza, da un semn .. ca din aia si io-s capabil sa fac. Macar atat. (Ca sa cac o poezie ca asta nu stiu daca poci)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9179,841,'vizionarul','alinmiron_19@yahoo.com','http://vizionarul.wordpress.com','89.35.87.15','2007-12-04 16:55:54','2007-12-04 14:55:54','stiati ca 2 din actorii care au aparut in rolul de calaret in reclamele Marlboro au murit de cancer la plamani? :D',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(9180,842,'L3ST','webmaster@l3st.com','http://www.l3st.com/','89.34.244.21','2007-12-04 16:56:14','2007-12-04 14:56:14','Hahahaha geniale fazele',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 ImageShackToolbar/4.3.5 Firefox/2.0.0.11','',0,0),(8280,792,'PhenoBarbieDoll','oana.gavrila@mediafax.ro','http://blog.360.yahoo.com/poisongirl94','86.120.236.133','2007-11-18 10:59:22','2007-11-18 08:59:22','Gropare, am incredere in tine ca ai beut responsibly (cum zic aia la teveu), adica cu simt de raspundere.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727)','',0,0),(9193,842,'baghy','baghy83@lycos.it','http://baghy.info/','78.12.6.155','2007-12-04 23:11:28','2007-12-04 21:11:28','e si cazul sa intri in lumea soferilor',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(9194,842,'CAESARUS','caesarus@adresafalsa.ro','http://utopium-advertising.blogspot.com','79.113.90.186','2007-12-04 23:22:31','2007-12-04 21:22:31','Am ras cu lacrimi...esti dus...da asta face multi bani!\r\nTe tzuc ma hai ca dupa ce iei carnetu te las sa conduci bascula!',0,'1','Mozilla/5.0 (Macintosh; U; Intel Mac OS X; en) AppleWebKit/523.12 (KHTML, like Gecko) Version/3.0.4 Safari/523.12','',0,0),(8975,820,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','82.77.126.148','2007-11-29 11:34:52','2007-11-29 09:34:52','instant mi-a pierit pofta de mancare!!! bine ca n-am mancat deloc, ca poate pateam puntu 4. :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.10) Gecko/20071115 Firefox/2.0.0.10','',0,0),(6067,657,'adi','adyrotaru@yahoo.com','','89.137.85.108','2007-09-28 01:19:39','2007-09-27 23:19:39','Revin:\r\nhttp://blog.360.yahoo.com/blog-qfjEjEAwf78Z0nYnlNICv0g-?cq=1&amp;p=106',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(6145,659,'Huby aka Carlanu','','','85.120.255.114','2007-09-29 10:51:10','2007-09-29 08:51:10','Numa anu` trecut iereau vreo 3 igluri la marjinea caii ferate pe langa Babeni - Valcea si langa ele vreo 3 pirande cu carute.....aja ca......n-am prea sarit .......cortu`.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(9079,838,'cuierul de bere al groparului','soredarkshines@gmail.com','http://aniakhaki.blogspot.com/','92.81.150.19','2007-12-01 11:55:53','2007-12-01 09:55:53','am cunoscut groparul :D da\' mai tare-i groparita! si birtu asta de ii face reclama nu e asa cool cum ma asteptam... da nah...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(6172,658,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','85.186.77.129','2007-09-29 21:02:31','2007-09-29 19:02:31','super tare profesoara! era una din asta, focoasa rau, in baia mare. imi placea de ea, si chiar visam noaptea ca-s barbat si ca... :P',0,'1','Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.0.12) Gecko/20070731 Ubuntu/dapper-security Firefox/1.5.0.12','',0,0),(6173,666,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','85.186.77.129','2007-09-29 21:03:52','2007-09-29 19:03:52','auzi? da la punctu 2 nu prea iti dau dreptate, si stiu eu ce zic!',0,'1','Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.0.12) Gecko/20070731 Ubuntu/dapper-security Firefox/1.5.0.12','',0,0),(6611,646,'darius f','darius2u@yahoo.com','http://desprepsd.wordpress.com/','82.79.33.247','2007-10-10 17:21:29','2007-10-10 15:21:29','Amu hapt ase de in defavoarea ta nu is la ING. Pe de alta parte daca te-ai pune si tu sa mai afisezi cate un banner pe blogu asta de celebritate care esti, ti-ar iesi jumatatea aia de bere plus un pachet de tigari cu timbru de Ukraina.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(6447,676,'ania','soredarkshines@gmail.com','http://aniakhaki.blogspot.com/','89.123.78.176','2007-10-07 15:24:56','2007-10-07 13:24:56','loool :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6448,676,'Sasha','yo_sasha1988@yahoo.com','http://vampysasha.blogspot.com/','89.34.153.180','2007-10-07 16:17:14','2007-10-07 14:17:14','Little-White-Chick =))',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Avant Browser; InfoPath.1)','',0,0),(6449,676,'moroseanca','morosenii@mail.com','','62.224.238.251','2007-10-07 16:31:55','2007-10-07 14:31:55','sitting cow ^-',0,'1','Mozilla/5.0 (Macintosh; U; PPC Mac OS X Mach-O; de; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6496,646,'pliscu','pliscu@gmail.com','http://pliscu.blogspot.com','89.137.100.242','2007-10-08 18:59:05','2007-10-08 16:59:05','normal ca tre` sa jecmaneasca pe cineva ca sa isi recupereze dobanda de la contul curent (5.9%)...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6498,646,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2007-10-08 19:25:17','2007-10-08 17:25:17','Dec ba - sincer - mi se rupe inima din cauza lor, si a pierderilor pe care le inregistreaza mai ales din cauza cheltuielilor cu personalul ala de la ghiseu care - dupa cum se stie - castiga mii de euro pe saptamana, iar shafii lor, sireacii, abia daca primesc salariul mediu pe economie.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6499,646,'homeless','editor@goodmorning.ro','http://www.goodmorning.ro','82.76.54.45','2007-10-08 19:51:19','2007-10-08 17:51:19','Hai ca esti norocos, dupa toate cele ai primit banii, ti-ai luat casa...\r\nDar eu am intrat cu dosarul pregatit gata dupa un \"credit pentru nevoi personale\", femeia de la ghiseu s-a uitat incintata la mine, la dosarul in care aveam TOATE actele, asa cum ma invatasera ei pe site, m-a verificat prin calculatoare si m-a trimis la alt ghiseu sa-mi deschid un cont la ei si sa depun in el 100 de euroi.\r\nCum a aflat ca am depus banii, mi-a dat inapoi dosarul si mi-a spus ca nu se poate, ca amarita pentru care garantasem un imprumut acum trei ani si mai bine iar nu si-a platit la timp datoria si eu apar ca rau-platnic.\r\nSi, da, mi-a spus ca stia asta inca in prima clipa, de cind am depus dosarul. Oare de ce m-o fi pus sa le dau suta aia? Asa, ca sa am si eu inca un cont deschis la o banca?... :)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(6183,666,'Bibliotecaru','um0834@yahoo.com','http://giconet.blogspot.com/','86.121.0.130','2007-09-30 16:39:15','2007-09-30 14:39:15','Din cele trei, porumbeii au Ã®ntodeauna dreptate. Ele sunt animale ÅŸi nu ÅŸtiu sÄƒ mintÄƒ. Se exprimÄƒ sincer. Restul... CÃ¢nd ai spus de soclu, flori ÅŸi alte alea, mÄƒ gÃ¢ndeam cÄƒ pui o vorbÄƒ de-un sicriu... Iar dacÄƒ ÅŸi o micÄƒ \"puÅ£ulicÄƒ\" este \"super mare\"... cam ce ar fi mic?',0,'1','Mozilla/5.0 (Windows; U; Win 9x 4.90; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6142,659,'Huby aka Carlanu','','','85.120.255.114','2007-09-29 10:43:50','2007-09-29 08:43:50','Iesti plin de enerjie aja ca muta-te mataluta in spatele monitorului si vezi care-i dextra.....\r\n\r\nMultam......de intelejere !\r\n\r\nNo offence si ia vezi care Tagan isi mai cere scuze !',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(6175,664,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','85.186.77.129','2007-09-29 21:34:21','2007-09-29 19:34:21','eu nu as mai fi iesit deloc prima oara! :\"&gt;',0,'1','Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.0.12) Gecko/20070731 Ubuntu/dapper-security Firefox/1.5.0.12','',0,0),(6076,663,'Andrei Crivat','andrei@andreicrivat.ro','http://www.andreicrivat.ro','89.137.83.141','2007-09-28 09:36:52','2007-09-28 07:36:52','- Tu tot timpul citesti ziarul cand mananci?\r\n- Depinde de anturaj, zic eu. Depinde de anturaj.\r\n\r\nAsta mi-aminteste cand stateam cu nashu Luci la o berica, si la noi la masa a venit un cunoscut pe care nu-l simpatizam in mod deosebit. Si ne-a vazut le asa... neprietenosi, cam acri, si a zis plin de entuziasm: \"Hai, ma baieti, sa ne veselim, ce dracu, suntem intr-o companie selecta...\" iar eu si nashu Luci, aproape la unison, i-am spus \"poate tu, ma baiatule, poate tu\". Mno, a nost n-a ras, cred ca s-a suparat.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; SLCC1; .NET CLR 2.0.50727; Media Center PC 5.0; .NET CLR 3.0.04506)','',0,0),(6225,662,'ania','soredarkshines@gmail.com','http://aniakhaki.blogspot.com/','89.123.95.63','2007-10-02 13:21:39','2007-10-02 11:21:39','imi pare rau gropare :(( daca stiam ca imi dai tu leapsa asta nu o luam de la omu care a cutezat sa o dea inaintea ta :( ma ierti? :((',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6081,664,'ss','criss_team@yahoo.com','','81.196.150.198','2007-09-28 10:11:04','2007-09-28 08:11:04','o stiut el stelea ce zice...mare domn.\r\nsi secunda aia crec-o fost mai multe si pupilele-ntinse la maxim, la cate detalii ti-o invadat retina.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7','',0,0),(6082,664,'adi','adyrotaru@yahoo.com','','89.120.56.7','2007-09-28 10:17:47','2007-09-28 08:17:47','odies but goldies...',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(6083,664,'adi','adyrotaru@yahoo.com','','89.120.56.7','2007-09-28 10:18:16','2007-09-28 08:18:16','scuze, oldies',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(6223,668,'Andreea MKT','supergirgir@yahoo.com','http://marlahermina.deviantart.com/gallery/','82.77.126.254','2007-10-02 11:57:09','2007-10-02 09:57:09','adi sicretu nu e unu cu ceva c hestie de vikingi in cap, ceva casca scandinava cu cuarne? ca o fo cu ceva bursa undeva unde efrig? si statea cu necro?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(6085,665,'curioasa','totmea@yahoo.com','','89.123.66.62','2007-09-28 11:28:16','2007-09-28 09:28:16','si nu-i mai bine decit rasfututu de fututi?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(6086,665,'ss','criss_team@yahoo.com','','81.196.150.198','2007-09-28 11:47:50','2007-09-28 09:47:50','ai uitat de bossumflata/e.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7','',0,0),(6087,665,'christina','christina.androne@gmail.com','http://luminescent.weblog.ro','80.97.2.39','2007-09-28 12:34:17','2007-09-28 10:34:17','adica: upper management, middle management, seniori, medii si juniori?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6088,665,'macabroo','raduccc@yahoo.com','http://rezistenta.blogspot.com','80.96.196.166','2007-09-28 12:37:53','2007-09-28 10:37:53','Evrika, acum inteleg de ce cu cat urci mai mult in scara ierarhica esti futut mai mult si la randul tau iti creste pofta sa futi pe altii. Ce te faci insa daca toti aia mai urcati pe scara decat tine sunt negrii?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6089,665,'Miruna','mirunavasilescu@yahoo.com','http://potsafacsiasaceva.blogspot.com/','86.106.59.163','2007-09-28 13:11:03','2007-09-28 11:11:03','Haha, bad day at the office?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6090,665,'Hammer','hammer@alpinet.org','','86.120.55.79','2007-09-28 13:27:42','2007-09-28 11:27:42','Puii mei, ce incepe sa samene multinationala cu armata ce se facea odata...sau tu n-ai servit ?:-))',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(6091,658,'Hammer','hammer@alpinet.org','','86.120.55.79','2007-09-28 13:34:57','2007-09-28 11:34:57','S-a shuntat o veriga decizionala acolo...deci se poarta si pe dincolo, eh?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(6092,657,'oedip','oedip74@gmail.com','http://oedip.blogspot.com','139.18.194.141','2007-09-28 14:19:29','2007-09-28 12:19:29','io nu Å£aÅŸ recomanda faza cu mobilierul cÄƒ pormÄƒ la labÄƒ faci firezar pÄƒ gios ÅŸi te schimbÄƒ alia urjent!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6094,665,'pliscu','pliscu@gmail.com','http://pliscu.blogspot.com','89.137.100.118','2007-09-28 14:30:40','2007-09-28 12:30:40','Un pic mai bine e intr`o firma mica, unde esti de toate. Deodata sau pe rand.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6095,664,'.marius','marius@wirelessisfun.com','http://marius.wirelessisfun.com','89.36.21.108','2007-09-28 14:42:53','2007-09-28 12:42:53','Eu as fi intrat si a doua oara... ;-)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6097,665,'Arhi','arhi@arhiblog.com','http://arhiblog.com','82.78.208.49','2007-09-28 15:10:46','2007-09-28 13:10:46','decat sa fiu si futut si futator intr-o firma cu 2 angajati, din care unul e patronul, mai bine sunt locul de intrare a pulii intr-o firma mare. De ce? Ca ma fac eu mare...:P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6098,665,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-09-28 15:39:49','2007-09-28 13:39:49','@ Arhi: sa inteleg ca o putulica in curuletz e un pas inainte?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6222,662,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-10-02 11:39:27','2007-10-02 09:39:27','@ Ania: da\' voo nu va e rusinica sa preluati lepshe inainte de a vi le da io?\r\n\r\n@: Cozmos de ros: plus blanurile de tigru siberian, sa nu raceste secretaa cand o tranteshte dom\' director cu spatele gol pe linoleumul-parchet-marmura!\r\n\r\n@ lilith: spitting will set you free! parol. Mai ales daca e intre ochi de politician.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6321,671,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-10-04 15:25:31','2007-10-04 13:25:31','Cobileanski are onoarea de a se afla in blogroll la mine, si e aproape cel mai bestest friend of mine, desi nu stie de existentza mea. Da\' e OK, I can laiv with that! \r\n\r\nAnyways, nici saitu\' asta si nici neonor propitaru\' sau niciodata nu vor reusi nimic artistic de calitate, dintr-un motiv simplu, as you happen to know: nici saitu\' nici neonor propitaru\' nuz basarabeni!\r\n\r\n',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6322,672,'Razvan','razvan.antonescu@gmail.com','http://idei-locale.blogspot.com','81.196.150.96','2007-10-04 15:26:31','2007-10-04 13:26:31','Ba tu stii de cand ma rog io sa intre unu d\'asta ca tine in mine sa imi fac si io bara spate? Unu ca tine ii bun. Nici nu pusca airbagu da ii suficient cat sa schimb spatele. Nu mai ai si alti pretini biciclisti? Ca iti dau itinerariu zilnic :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6218,643,'Ionutz','ionut.diacu@gmail.com','http://www.desprecazare.ro','86.105.169.7','2007-10-02 10:49:18','2007-10-02 08:49:18','da-mi un email sa vb',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6219,668,'VIP','ps@yahoo.com','http://vipuri.blogspot.com','213.157.188.71','2007-10-02 11:12:22','2007-10-02 09:12:22','sa-ti traiasca! :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(6220,668,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-10-02 11:21:01','2007-10-02 09:21:01','E, mah, sa! Ca ii ficior fain (aviz amatuarelor si profesionistelor!)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6221,669,'oedip','oedip74@gmail.com','http://oedip.blogspot.com','139.18.194.141','2007-10-02 11:36:19','2007-10-02 09:36:19','pt o clipa si io tat asta am crezut c-am murit si nu mai sunt si nu mai pot bee ca tat omu dar mi-am revenit si te anunt ca beu si pip acasa pt ca aici e vremea de tata pula ploo si e vand si e frig si e nashpa si chiar daca jermanica o luat campionatu de gagici la footbol tat nu e bairam cum m\'asteptam... asa ca desi asa pare n\'am murit dar mai incerc... si vb ioanei, spiritul oedipian il voi putra doar io de amu \'nainte! :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6180,666,'nenea cosmos','domnu_cosmos@yahoo.com','http://nenea.wordpress.com/','92.80.3.29','2007-09-30 13:54:59','2007-09-30 11:54:59','de multe ori ti se ridica o statuie maro, nu mai conteaza ce fac porumbeii.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(6181,665,'nenea cosmos','domnu_cosmos@yahoo.com','http://nenea.wordpress.com/','92.80.3.29','2007-09-30 13:59:11','2007-09-30 11:59:11','rasfututu pina si de catre pulime intr-o intreprindere nu poa sa fie decit ingineru IT, ca numa ala tre sa sara in sus prin diagonala ierarhiei cind un mail nu a circulat de la ceo la departamentul cacamaca sau retur cu CC la toti dadatorii cu parerea.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(6106,665,'Arhi','arhi@arhiblog.com','http://arhiblog.com','81.181.174.123','2007-09-28 20:31:06','2007-09-28 18:31:06','Groparu, daca nu te tii de nimic....',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6107,665,'albanezu','mist_ab_2k@yahoo.com','','89.35.80.185','2007-09-28 21:02:32','2007-09-28 19:02:32','@Groparu:  Oricare shef, shefutz sau shefuletz are la activ unul sau mai multe analuri, cu cat e mai sus, cu atat mai multe!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6109,666,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','85.186.77.129','2007-09-28 21:31:35','2007-09-28 19:31:35','si toate gandurile astea vin din vasta ta experienta de viata? :D :D',0,'1','Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.0.12) Gecko/20070731 Ubuntu/dapper-security Firefox/1.5.0.12','',0,0),(6110,663,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','85.186.77.129','2007-09-28 21:36:29','2007-09-28 19:36:29','miruna, io tot in cluj is, da n-am microunde la lucru. :( poate imi gasesc si io un job la groparu... :(',0,'1','Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.0.12) Gecko/20070731 Ubuntu/dapper-security Firefox/1.5.0.12','',0,0),(6182,667,'Bibliotecaru','um0834@yahoo.com','http://giconet.blogspot.com/','86.121.0.130','2007-09-30 16:06:20','2007-09-30 14:06:20','Poate nu Patriarh, dar sigur <i>Patria</i>? <i>Ah</i>hhh! Prea multe emoÅ£ii de ieri, de la fÃ¢ntÃ¢na artezianÄƒ. A fost emoÅ£ionat de revederea siglei PNÅ¢-CD zburdÃ¢nd Ã®n aerul tare al BucureÅŸtilor. LeÅŸin, deci sunt liber! Ori poate a dat nas Ã®n nas, Ã®nainte de momentul leÅŸinului, cu candidatul PIN, domnul CocainÄƒ.',0,'1','Mozilla/5.0 (Windows; U; Win 9x 4.90; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6114,666,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2007-09-28 22:20:01','2007-09-28 20:20:01','Nu, din chiar insushi preputzul gandirii!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6115,665,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2007-09-28 22:23:01','2007-09-28 20:23:01','@ albanezu: da, mo, da ce ne facem cu aia care tat iau analuri supt coada, sh numa\' nu mai avanseaza veci?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6116,666,'Miruna','mirunavasilescu@yahoo.com','http://potsafacsiasaceva.blogspot.com/','86.106.59.163','2007-09-28 22:24:45','2007-09-28 20:24:45','Da\' nu mai bine sa fii invitat la o nunta super najpa care sa te faca sa exclami \"I ain\'t ever doin\' this shit!\", garantand astfel o viata perfecta de burlac, cu sosete aruncate pe unde vrei tu?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6117,666,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2007-09-28 22:39:58','2007-09-28 20:39:58','Ba da! Sh mai ales - cum zice vorba - tragand sorin ovidiu vanturi peste tot prin camera, fara o sumedenie de proteste ca trebuia sa mananci petale de trandafir!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6585,689,'macabroo','raduccc@yahoo.com','http://rezistenta.blogspot.com','80.96.196.2','2007-10-10 11:14:15','2007-10-10 09:14:15','O sa te lege ca ai traumatizat pisihic catzaua\'. Cam cum dadea o baba cu pietre in mine ca dadeam pumni in cap la un caine. Caine infipt strasnic sub genunchi. \"Vorbeste frumos cu cainele! Ca are sentimente!\"',0,'1','Opera/9.23 (Windows NT 5.1; U; en)','',0,0),(6589,689,'Hammer','hammer@alpinet.org','','86.120.55.79','2007-10-10 12:51:48','2007-10-10 10:51:48','La faza cu catzaua apari la antena1 si nenea ala cu blog ce s-o infectat  pentru un post de-al tau legat de protectia animalelor o sa zica cu un ton delicat, intelectual: \"I told youu\" si toti aparatorii maidanezilor se vor imbraca la cravata si vor face campanii de presa impotriva ta si cand o sa stai in statie la troleu oamenii o sa zica in shoapta, in spatele tau: uite, asta e ala ce leaga caini de copaci si dupa aia urla la ei...si uite asa ...brusc...o sa mai ai un motiv de a cauta o idee de cum sa te simti mai bine...da alta:-)\r\nBuna incercare:-)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(6590,690,'Hammer','hammer@alpinet.org','','86.120.55.79','2007-10-10 12:59:59','2007-10-10 10:59:59','In fine, ideea e ca amu eram pe val daca in 89, imediat dupa Craciun, pe acolo, declaram razboi americanilor si ne predam instant, fara bombing and fucking. Ei ne faceau al nustiucatelea stat si MacDonaldsu baga mici si sarmale in meniu. Dar cred ca nu or fost de acord aia de la companiile aeriene care in anii astia au avut profituri enorme carand creiere din romania peste ocean:-) Ashe ca nu am avut bombing, da fucking avem la greu. WTF, suntem unici, unde a mai pomenit cineva o tzara unde ministrul sa ia shpaga in caltaboshi :-)))',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(6591,676,'zdranga','coraelena@gmail.com','http://zdrangazdranga.blogspot.com/','82.208.130.87','2007-10-10 13:17:38','2007-10-10 11:17:38','na, io am luat treaba asta in serios si chiar am cautat nume de indieni, pana sa ma regasesc pe mine. nu m-am putut hotari, asa ca am gasit un compromis.&gt; zic asa:pana la 30 de ani, m-o chemat AYITA (Cherokee name meaning first to dance). dupa 30 de ani, oops ma cheama MAKKITOTOSIMEW (Algonquin name meaning she has large breasts) hehe.\r\nbonus, ti-am dat si tie un nume - DEMOTHI. te las pe tine sa descoperi ce inseamna.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(6592,690,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-10-10 13:18:50','2007-10-10 11:18:50','Prostu\'! Io as fi cerut ca spaga un internat de fete de liceu, normal, majore, daca trebe, finca - guess what - caltabosh io cam am! (amu ati aflat si care e pretul meu, cu ocazia asta, daca ajung vreodata Decebal Traian Remes)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6594,689,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-10-10 13:34:42','2007-10-10 11:34:42','Atunci poti sa ii soptesti cu drag la ureche fraza aia memorabila, nu-i musai sa ii strigi in bot. Io i-as mai fi spus alte chestii care i se spun unei bitch (gen: \"whose mother-in-law are you?\"), da\' exact din considerente de campanie anti-violentza impotriva animalelor m-am resemnat si uite, am bagat un comentariu la postul asta care e tot al meu.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6595,676,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-10-10 13:39:57','2007-10-10 11:39:57','@ lilith: fether nu e feather, iarna nu-i ca vara!\r\n\r\n@ zdranga: limba Google zice ca Demothi insamna Ala-care-vorbeste-in-timp-ce-merge. Dar cum se zice Ala-care-merge-in-timp-ce-vorbeste? Sau, si mai rau, Ala-care-bea-fumeaza-pupa-pescuieste-canta-si-doarme-in timp-ce-vorbeste-si-umbla?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6596,689,'Hammer','hammer@alpinet.org','','86.120.55.79','2007-10-10 13:44:35','2007-10-10 11:44:35','Bagatul de commenturi la posturi proprii poate fi astfel o idee de cum sa te simti mai bine:-)))) Hai, cu putin efort mai descoperim cateva :-D',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(6597,692,'ss','criss_team@yahoo.com','','81.196.150.198','2007-10-10 14:03:04','2007-10-10 12:03:04','no, si io eram convins ca bacanie = mijmash a la bacau.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7','',0,0),(6598,689,'eu','ripahoratiu@yahoo.com','http://simaice?','82.77.126.254','2007-10-10 14:07:17','2007-10-10 12:07:17','Gropare, fata mosului, daca e sa-ti mearga prost, oricat de spermatozoid e compionul din care te-ai nascut, iti merge prost pan\'la capat. Asa ca esti intr-o mare eroare cu metoda pen\'ca la:\r\n\"\r\n....\r\n4. Legi catelusa de un pom.\r\n5. Te uiti la catelusa si intrebi:\r\n\r\n- WHOâ€™S THE BITCH NOW????\"\r\n\r\nraspunde copacul: \"You, motherfucker, keep out your dirty hands out of my leaves!\". \r\n\r\nChestie cunoscuta, de altfel, cum ca copacii au o sensibilitate crescuta la legatu\' de maidaneze de ei...',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.2; .NET CLR 1.1.4322; .NET CLR 2.0.50727; InfoPath.1; .NET CLR 3.0.04506.30)','',0,0),(6503,646,'raluca','ralucaghervan@yahoo.com','http://360.yahoo,com/ralucaghervan','89.137.11.203','2007-10-08 21:39:59','2007-10-08 19:39:59','zice in lege ca nimeni, nici patronul, nici banca la care ai credit si nici altcineva nu te poate constrange sa inchei pensia privata obligatorie la ei. Asha ca eu iti sugerez sa o inchei la mine (cu Interamerican), ca sunt dragutza si nici nu te pun sa completezi formular, numa sa dai cu semnatura. :) \r\nIti urez rate mici si rare!',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.0.3705; .NET CLR 1.1.4322)','',0,0),(6504,646,'varza','tudor.maris@gmail.com','http://rottencabbage.haipa.ro','58.106.103.21','2007-10-08 21:54:47','2007-10-08 19:54:47','Io zic urmatorul: du-te la banca, spune-le ca vrei sa-ti faci asigurare, asteapta si completeaza formulare, apoi spune-i la doamna de acolo: \"doamna, am facut o greseala, nu mai am lei la mine.... POT SA VA DAU PULE?\" :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6505,646,'nenea cosmos','domnu_cosmos@yahoo.com','http://nenea.wordpress.com/','92.80.40.142','2007-10-08 22:02:13','2007-10-08 20:02:13','acu incepi sa ii intelegi pe aia care jefuiesc banci. oricit ar fura, tot numa de la banca fura, intelegi?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(6506,677,'nenea cosmos','domnu_cosmos@yahoo.com','http://nenea.wordpress.com/','92.80.40.142','2007-10-08 22:10:33','2007-10-08 20:10:33','tetea, pai 21 de pule e ok, da cum iti balangani galeata aia de coaie?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(6507,646,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2007-10-08 22:19:23','2007-10-08 20:19:23','@ raluca: nice try...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6510,646,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2007-10-08 23:57:57','2007-10-08 21:57:57','@ cosmos: inteleg perfect, mama lor de capitalisti!!!\r\n\r\n@ varzaru: mah, apropos de dat pule, depinde cati ani, ce bust, ce dantura, ce ochi, ce decolteu, ce greutate, ce par, ce nume, cum miroase, daca o fost baiat inainte sau s-o nascut fetitza, ce-s parintii, ce studii are, cum ii sade buricu\', DA IN PRIMU SI-N ULTIMU RAND DACA VREA SA PRIMEASCA PULELE MELE!!! Ca restu\' oricum nu conteaza si nu o contat.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6608,646,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-10-10 16:47:20','2007-10-10 14:47:20','Mo, deci nuz platit in euro, ca cand am mers sa strang capshuni in Spania or zis ca sa nu-i sun io, ca ma suna ei; atata numa ca cursurile valutare de la banci is destul de in defavoarea mea, si trebuie sa fiu atent cu fiecare leutz, finca cu un leu poti cumpara - la urma urmei - juma de bere la magazin sau 4 sau 5 tigari pretioase!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6607,646,'darius f','darius2u@yahoo.com','http://desprepsd.wordpress.com/','82.79.33.247','2007-10-10 16:06:31','2007-10-10 14:06:31','Mda, stiam eu ca asa o sa zici. Da de ce nu depui lei si dupa aceea ii transformi cu ordinatoru in euro. Io ceva de genul asta fac. Sa nu-mi spui ca tu esti platit in euro ca tata tat ma tai!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(6606,691,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-10-10 15:46:20','2007-10-10 13:46:20','Da, mah, si la coltzu\' asta si pute a pipi de caine :|',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6573,689,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','82.77.126.148','2007-10-10 09:00:19','2007-10-10 07:00:19','stau mai bine ca tine. eu am mancat pizza, semn ca salarul tocmai s-o dus! :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6613,646,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2007-10-10 18:19:04','2007-10-10 16:19:04','Apoi io nush ce firma e intr-atata de idioata incat sa isi asocieze numele cu unu care scrie de pule sh pkisde pe blog cu o patima care - sincer - ma sperie. A, si parca mai era o faza... ? Da, aia cu \"io nuz de vanzare!\" (cel putin nu inca :D )',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6605,691,'Botache','nasturei_verzi@yahoo.com','http://www.nasturei.wordpress.com','82.77.126.148','2007-10-10 15:36:22','2007-10-10 13:36:22','A dracu fufa asta, nu poti intoarce putin capu, pe enternet, ca o gasesti la fiecare colt.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.0; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6600,691,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-10-10 14:27:32','2007-10-10 12:27:32','Da, mah, ar fi trebuit sa zic \"aceasta mircea mutu a show-bizului\" :| mea culpa.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6602,691,'ss','criss_team@yahoo.com','','81.196.150.198','2007-10-10 15:10:31','2007-10-10 13:10:31','io ma gandesc la o \"aceasta Fizz a showbiz-ului\", da parca pana si aicea tot i pe minus britney :(',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7','',0,0),(6603,689,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-10-10 15:14:50','2007-10-10 13:14:50','Bun, dar daca si copacul si catzalusha is lesbience? Si si eu is lezbianca??? Iti dai seama ce threesome iese??? oioioi...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6577,646,'mm7163','mm7163@yahoo.de','','82.77.126.134','2007-10-10 10:08:28','2007-10-10 08:08:28','Åži de la mine multe \"urari de sanatate\"* pt tÄƒte ajentiile fuckINGului, in special pentru aienjii ofis zorilor, cu care am avut treaba (eu cu ei, ca ei cu mine nu pre). Am deschis cont, card, completat formulare, dus acte, alte acte ,cacaturi, platit taxe, comisioane, si ei nici macat un raspuns, de mai bine de o luna...poi cum pana mea sa-tz pui bazele in ÄƒÅŸtia?! Si \"salutari\"* si biroului de credit a miticilor din bucale unde sanalizeaza dosarele ca si aia merita ca pt astia o fo taxa aia de ANALiza dosar. Am incheiat businessu cu ei, ma pish pe raspunsu lor (daca si cand o\' mai veni), si o sa le  prezint o reclamatie cand mai am drum pe la ei, poate si-or reveni.\r\nInca odata, \"numa\' de bine\"*!\r\n\r\n(*) m...stiti voi...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 ImageShackToolbar/4.3.5 Firefox/2.0.0.7','',0,0),(6458,676,'Numele meu de indian at Jurnal de noapte','','http://www.andreicrivat.ro/2007/10/07/numele-meu-de-indian/','212.227.64.193','2007-10-07 20:15:12','2007-10-07 18:15:12','[...] LeapÈ™a venitÄƒ de la Groparu. [...]',0,'1','Incutio XML-RPC -- WordPress/2.2','pingback',0,0),(6459,676,'Arhi','arhi@arhiblog.com','http://arhiblog.com','82.79.189.58','2007-10-07 20:30:01','2007-10-07 18:30:01','Mamdouh Kalpesh = Glorificam pe lordul perfectiunii, in hindi.\r\nda, stiu, sunt tare, multumesc:D:D:D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(9097,816,'Replicile sÄƒptÄƒmÃ¢nii 19 at Jurnal de noapte','','http://www.andreicrivat.ro/2007/12/02/replicile-saptamanii-19-2/','212.227.64.193','2007-12-02 10:48:04','2007-12-02 08:48:04','[...] Locul femeilor e la cratiÅ£Äƒ. DacÄƒ nu ar fi acolo, cu ce ar putea ÅŸi ele sÄƒ deie dupÄƒ noi, sireacele? (Groparu) [...]',0,'1','Incutio XML-RPC -- WordPress/2.2','pingback',0,0),(6462,676,'nenea cosmos','domnu_cosmos@yahoo.com','http://nenea.wordpress.com/','92.80.10.175','2007-10-07 22:39:51','2007-10-07 20:39:51','http://nenea.wordpress.com/2007/10/07/leapsa-cu-tirnacopul/',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(6482,675,'albanezu','mist_ab_2k@yahoo.com','','83.103.154.202','2007-10-08 14:54:56','2007-10-08 12:54:56',':D gropare... tablitele astea de la Tartaria, contin informatii criptate, sh` cand s-or imbetat stramosii aia de p-acia or pierdut cheile de decriptare... ashe c-amu cine se uita la ele se uita ca rama la bordura sau ca broasca-n tzaje.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6483,677,'macabroo','raduccc@yahoo.com','http://rezistenta.blogspot.com','80.96.196.2','2007-10-08 15:04:42','2007-10-08 13:04:42','Succes la pisoar.',0,'1','Opera/9.23 (Windows NT 5.1; U; en)','',0,0),(6641,690,'underscore','','','82.76.131.10','2007-10-11 11:33:10','2007-10-11 09:33:10','Nijte fatarnici. Cea mai mare companie a lor e de stat si e un alt stat.\r\nSi pare ca e de stat acolo pentru ei, spre deosebire de celalalt de stat',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.2; WOW64)','',0,0),(6643,669,'robocop','robo@yahoo.com','','80.96.146.16','2007-10-11 15:42:58','2007-10-11 13:42:58','Am si eu o nelamurire, ma-sa lu\' Oedip e de fapt si ea o doamna?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(8849,817,'Usim','mihaimitan@gmail.com','','86.121.184.193','2007-11-27 02:02:49','2007-11-27 00:02:49','Dar de lamaie.ro, ce spui Gropare?\r\n\r\nParerea mea!',0,'1','Opera/9.10 (Windows NT 5.1; U; en)','',0,0),(8839,816,'Alina','arabela3x@yahoo.com','http://www.bilzone.ro','86.122.195.208','2007-11-26 23:32:39','2007-11-26 21:32:39','Barbatii sunt niste comori pentru noi, de aceea trebuie sa-i ingropam :)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1)','',0,0),(8840,816,'Laura','mars1953@web.de','','84.160.94.140','2007-11-26 23:44:45','2007-11-26 21:44:45','Pe de alta parte, femeile \"sireace\" n-au nevoie de cratitze pentru a face acesti adorabili marshavi sa se smiorcaie, au ele instrumente de tortura mult mai eficiente :-)) ... si groparu stie asta si de aia e rautacios ...',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(8701,807,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2007-11-24 00:59:37','2007-11-23 22:59:37','MERI\r\n\r\nla\r\n\r\nvot!!!!\r\n\r\nMERI, mah, meri, meri, meri...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8702,807,'baghy','baghy83@lycos.it','http://baghy.info/','78.12.2.226','2007-11-24 01:05:06','2007-11-23 23:05:06',':)))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))\r\n:))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(8730,807,'cip','cipis74@yahoo.com','','83.103.137.209','2007-11-24 20:47:02','2007-11-24 18:47:02','deci...PCR',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(8731,807,'cip','cipis74@yahoo.com','','83.103.137.209','2007-11-24 20:49:15','2007-11-24 18:49:15','adica pardon RSR',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(8705,807,'eu,Miruna','mirunavasilescu@yahoo.com','http://potsafacsiasaceva.blogspot.com/','86.106.59.163','2007-11-24 02:23:42','2007-11-24 00:23:42','Ce prostie =))=))=))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8706,807,'eu,Miruna','mirunavasilescu@yahoo.com','http://potsafacsiasaceva.blogspot.com/','86.106.59.163','2007-11-24 02:24:10','2007-11-24 00:24:10','Nu, adica e foarte dragut, sa nu ma intelegi gresit....:))))))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8727,812,'baghy','baghy83@lycos.it','http://baghy.info/','78.12.2.226','2007-11-24 19:05:43','2007-11-24 17:05:43','numai acolo mai lipsesc',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(8728,807,'Cromleck','goodfriendsandtwobottlesofpills@yahoo.com','http://verbalmasturbate.blogspot.com/','194.126.187.75','2007-11-24 19:06:55','2007-11-24 17:06:55','Seamana cu un ochi. PNTCD?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8841,813,'eu,Miruna','mirunavasilescu@yahoo.com','http://potsafacsiasaceva.blogspot.com/','86.106.59.163','2007-11-26 23:44:49','2007-11-26 21:44:49','Am fost in comisie. :(',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8900,815,'NRGY','','','86.121.174.200','2007-11-27 17:17:35','2007-11-27 15:17:35','Uite ca bancu` e stiut si apreciat si de noi astia de nu suntem din Cluj :) Danutz Premium Pils :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8738,812,'nenea cosmos','domnu_cosmos@yahoo.com','http://www.nenea.wordpress.com','92.80.63.113','2007-11-25 03:26:48','2007-11-25 01:26:48','ce e aia gugÄƒl?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(6465,658,'Aqua','ra18grm@yahoo.com','','86.127.27.1','2007-10-08 00:30:22','2007-10-07 22:30:22','super tare! de retinut replica:)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(6480,677,'sabina','','','81.12.163.178','2007-10-08 14:29:43','2007-10-08 12:29:43',':))',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(6485,677,'mishu','mishu@doingtheartwork.com','http://www.doingtheartwork.com','82.77.126.254','2007-10-08 16:20:01','2007-10-08 14:20:01','lol macabroo',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6479,676,'macabroo','raduccc@yahoo.com','http://rezistenta.blogspot.com','80.96.196.2','2007-10-08 13:51:45','2007-10-08 11:51:45','Numele meu de Buffalo Bill Show e Vasile, pentru ca restul de nume bune fusesera luate.',0,'1','Opera/9.23 (Windows NT 5.1; U; en)','',0,0),(6477,676,'ss','criss_team@yahoo.com','','81.196.150.198','2007-10-08 12:29:00','2007-10-08 10:29:00','cand ma striga pe numele indian ma striga gel-in-freza-apus-pe-faleza-ritmul-vibreaza ... da amu is numa ma-pajte-o-raceala',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7','',0,0),(6471,676,'morÃ³seanca','morosenii@mailcom','','62.224.231.150','2007-10-08 08:18:25','2007-10-08 06:18:25','oedip, io n-am nimic impotriva sa te cheme shiting cow, chiar daca ar exista riscu sa creada oaminii ca io cu tine suntem neamuri, doamne feri !\r\ndeci, da.\r\nsitting cow Â®',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6472,676,'katmai','katmai@keptprivate.com','http://512kbps.com','195.212.29.171','2007-10-08 08:37:00','2007-10-08 06:37:00','WigWam-DumDum-Apache-Linux-Kernel-Ring-Ding-Ding-Teleenciclopedia . Spell that motherfucker :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7 (CK-IBM)','',0,0),(6473,676,'ania','soredarkshines@gmail.com','http://aniakhaki.blogspot.com/','89.123.121.237','2007-10-08 09:22:00','2007-10-08 07:22:00','eu tot nu-mi gasesc nume de indian :(',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6532,677,'VIP','ps@yahoo.com','http://vipuri.blogspot.com','213.157.188.71','2007-10-09 10:34:31','2007-10-09 08:34:31','nici nu vreau sa ma gandesc prin cate maini or trecut pulele tale!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6475,676,'george','reallyinsane@gmail.com','','193.138.195.202','2007-10-08 10:18:38','2007-10-08 08:18:38','beleshpu-lami-roshco-iu',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(8929,822,'WhiteWolf','contact@white-wolf.ro','http://white-wolf.ro','89.39.83.88','2007-11-28 18:37:51','2007-11-28 16:37:51','Let\'s stick to the subject nigga\' !\r\nCar\'va\'zica, care-i sensul si durata guerillei ashteia ? \r\nLuptezi singurel ? In gajka ? AndÃ£rgraund ori la vedeala ?  Vrei suporteri sau dai mumulescovici demonilor dujmanosi ?\r\nExplica-ne mitologia ca sa stie tot LUZERU ce preia prin blogurile primordial persoanle. \r\nDa ?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.10) Gecko/20071115 Firefox/2.0.0.10','',0,0),(6647,688,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2007-10-11 21:25:45','2007-10-11 19:25:45','...ceee vreemuri!!! :( ce ficiori eram odata!!! :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6534,683,'nobody','','','193.226.17.210','2007-10-09 10:57:05','2007-10-09 08:57:05','eu zic sa profitati fiecare de ziua postei (9 octombrie)...uitati-va in fata...uitati-va in spate...',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.2; SV1; .NET CLR 1.1.4322; .NET CLR 3.0.04506.30)','',0,0),(6535,685,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','82.77.126.148','2007-10-09 11:44:40','2007-10-09 09:44:40','inseamna ca in a doua poza, nenea ala care fuge se grabea la buda, dupa atata bere, nu? sau poate era promotie la ursus si se grabea sa prinda si el uun dop de bere... sunt confuzata, damn it!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6536,683,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','82.77.126.148','2007-10-09 11:45:35','2007-10-09 09:45:35','azi e ziua postei? wow! azi nu ies din casa!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6638,688,'Andreea MKT','supergirgir@yahoo.com','http://marlahermina.deviantart.com/gallery/','82.77.126.254','2007-10-11 08:54:35','2007-10-11 06:54:35','ma, il stii pe cÃ¢nele alea de la Litere? Era unu mare si niegru ca pÄƒcatu, io i-am pus nume \"DobrilÄƒ\" Ã®n memoria lu fostu preten. No, cÃ¢nele Äƒla era ÅŸi femeie de serviciu, ÅŸi bodyguard ÅŸi sanbernar, era di tÄƒte. Despre Äƒla di ce nu scrii? Ä‚la era mai important ca tÄƒtÄƒ faculta de Litere.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(6646,688,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2007-10-11 20:43:19','2007-10-11 18:43:19','@ Greucica: Da, bah pulash, tu tot timpu erai acolo cand bagam!!!! Lol...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6640,689,'eu','ripahoratiu@yahoo.com','http://simaice?','82.77.126.254','2007-10-11 10:44:56','2007-10-11 08:44:56','Realitatea e in alta parte, pen\'ca ezista niste legi universale, ale entropiei si ale fizicii conform carora apa curge pe cea mai panta dintre pante, lucrurile evolueaza nu din rau in mai rau ci din rau in groaznic de rau, apocaliptic de rau. Si-atunci lucrurile se intampla de fapt dupa cum urmeaza:\r\n â€¦.\r\n4. Legi catelusa de un pom.\r\n5. Te uiti la catelusa si pana apuci sa intrebi:\r\n\r\n- WHOâ€™S THE BITCH NOW????â€\r\nobservi ca pomu\' e seful tau, femeia cu care (impresie de moment) vrei sa-ti petreci restu\' zilelor si noptilor implicit sau mai rau - nevasta, dumnezeu, mama, singura vanzatoare din lume care iti da pe credit, sau orice alt personaj cu o inflenta covarsitoare asupra vietii tale. Pana bagi si scoti tu de seama chestia asta, maidanezu pe care il credeai maidaneza tocmai marcheaza pe la un capat unul dintre picioarele VIP-ului vietii tale, in timp ce, cu celalalt capat si cu toti caninii, clestii, coarnele, ghearele, etc. din dotare, ii marunteste atent tibia si peroneul celuilalt picior. Mai ai timp sa te gandesti \"Totusi, viata merita traita...\"\r\n....\r\nDe fapt dai o solutie gresita la niste false probleme.\r\nCand ti se intampla cele de mai sus te duci acasa. Iti aduci aminte de cuiul care tre\' batut (in orice casa tre\' batut un cui undeva). Iei un ciocan si un cui si lovesti cu sete. Evident, ratezi cuiul, cf. acelorasi principii universale de mai sus + cursului logic al evenimentelor. Evident, 3-4 deste de la mana cealalta, implicata in proces, nu. Ca sa-ti dai peste destele de la mana in care tii ciocanul iti tre\' mai multa tehnica, mie insumi nu mi-a reusit decat de fo doo ori, asa ca te rezumi la mana cu cuiul. Deci iti arzi una adevarata peste deste. Subit constati cu bucurie ca toate problemele tale de pana atunci au devenit insignificante, meschine si efemere. Starea de bine poate sa tina de la cateva ore la cateva zile, in functie de intensitatea loviturii. La nevoie repeti actiunea (la urma urmelor tre\' batut cuiu\' ala, nu?). Si pui sare, dupa gust...',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.2; .NET CLR 1.1.4322; .NET CLR 2.0.50727; InfoPath.1; .NET CLR 3.0.04506.30)','',0,0),(6527,683,'Razvan','razvan.antonescu@gmail.com','http://idei-locale.blogspot.com','81.196.150.96','2007-10-09 09:53:59','2007-10-09 07:53:59','Nu bre...tu erai ala de dadea cu divaisurile de umblat in dinozauri :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6526,683,'Greuceanu','','','89.21.118.252','2007-10-09 09:44:55','2007-10-09 07:44:55','intr-un trib din neolitik ai fi fost sulitza cu cap de piatra!!!! masa de pranz nu puteai fi ca ai spetele prea inguste!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(6586,689,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-10-10 11:15:38','2007-10-10 09:15:38','=))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(8950,782,'Bogdan','','','193.254.62.8','2007-11-28 23:26:23','2007-11-28 21:26:23','WOW ce tare esti ..... hai mai nene ne lasi :)',0,'1','Opera/9.20 (Windows NT 5.1; U; en)','',0,0),(9209,842,'cronicaru\'','tzone_a@yahoo.com','http://cronicaru.blogspot.com/','193.230.230.101','2007-12-05 11:36:38','2007-12-05 09:36:38','ai uitat-o pe aia cu scosu capului pe geam si strigat tare cand ar trebui sa dai cedeaza la pietoni \"dete tanti la o parte ca asta calca nu fuche\" :)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(8979,830,'cronicaru\'','tzone_a@yahoo.com','http://cronicaru.blogspot.com/','193.230.230.101','2007-11-29 12:04:47','2007-11-29 10:04:47','si cucii si cocosii',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(8980,830,'eu,Miruna','mirunavasilescu@yahoo.com','http://potsafacsiasaceva.blogspot.com/','86.106.59.163','2007-11-29 12:14:58','2007-11-29 10:14:58','Deci Covaci nu e gras, e numa\' mic.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.10) Gecko/20071115 Firefox/2.0.0.10','',0,0),(9136,840,'vizionarul','alinmiron_19@yahoo.com','http://vizionarul.wordpress.com','82.208.146.10','2007-12-03 14:07:53','2007-12-03 12:07:53','deci.. dacacozma se duce si-l ia pe iliescu si se baga amandoi la zdup atuncea n-o fost eliberat degeaba, daca nu nu.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.10) Gecko/20071115 Firefox/2.0.0.10','',0,0),(9158,841,'IepurasulAtomic','praetorian21uk@yahoo.com','','192.100.124.219','2007-12-03 21:16:50','2007-12-03 19:16:50','\"Sunt in stare sa o chem pe Nikita la o cina romantica.\r\n\r\nIs in stare sa prind o balena albastra si sa o violez fara scrupule.\"\r\n\r\nSimt cumva o insinuare ushuara? :)) Pare-mi-se ca astea doua vin una dupa alta...si mi-i frica tare ca si Nikita si balena albastra is tot una. Aud comentarii de aprobare? :) \r\n\r\nDe fumat nu zic nika, ca io nu sufar de boala asta. Si unde nu sufar si/sau nu cunosc, nu ma bag ;).\r\n\r\nPace p\'afara!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(8940,830,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2007-11-28 21:01:37','2007-11-28 19:01:37','Eeeeeeee...\r\n\r\n...zac!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8941,822,'psaico','blog@psaico.info','http://www.psaico.info','78.96.86.55','2007-11-28 21:12:19','2007-11-28 19:12:19','nice :) cine le-a facut ? imi pui o pila ? :&gt;',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.10) Gecko/20071115 Firefox/2.0.0.10','',0,0),(8942,830,'oedip','oedip74@gmail.com','http://oedip.blogspot.com','139.18.194.141','2007-11-28 21:36:30','2007-11-28 19:36:30','nu mah... se ard toate pasaricile!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8930,822,'WhiteWolf','contact@white-wolf.ro','http://white-wolf.ro','89.39.83.88','2007-11-28 18:38:55','2007-11-28 16:38:55','A! - si sa nu uit, ca-i important !!!\r\n<b>Care dintre cele 7 e desenat cu stanga ?</b>',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.10) Gecko/20071115 Firefox/2.0.0.10','',0,0),(8961,830,'nandos','nandos@k.ro','http://www.nandos.wordpress.com','92.80.94.114','2007-11-29 04:18:34','2007-11-29 02:18:34','\"Toata lumea are fixuri, numai eu am fÄƒr-unsferturi\" \r\n\r\nlol, laf, haha, astea. :) \r\n\r\n\"ToatÄƒ lumea are fixuri, numai eu am mobil\" FRAERE! :P\r\n\r\nP.S. Te/am votat. Si pentru ca vreau neaparat sa cÄƒÅŸtigi, am fÄƒcut-o dÄƒ maimulte ori. DÃ®n cauza ta, acu am fo 8 bloguri.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.10) Gecko/20071115 Firefox/2.0.0.10','',0,0),(9155,841,'vizionarul','alinmiron_19@yahoo.com','http://vizionarul.wordpress.com','89.35.87.15','2007-12-03 20:32:47','2007-12-03 18:32:47','gropare iote ce scrie nenii doctori specialisti aicea ce boale ii paste pe fumatori: http://www.smoking-cessation.org/content/affectsbody.asp',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(9100,831,'Lexis','g_lexis2005@yahoo.com','http://www.alexandraghitalexis.blogspot.com','89.38.76.46','2007-12-02 14:52:05','2007-12-02 12:52:05','sa-mi zici cand iti scoti volumu\' de poezie',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9082,838,'Andreea MKT','supergirgir@yahoo.com','','89.43.186.64','2007-12-01 15:08:51','2007-12-01 13:08:51','draga GRO,\r\n\r\nbricheta ta e la mine si sper sa castigi pariul. te-am vazut pt prima data ametzit si erai tare dulce.\r\n\r\nbuna caipirina aia cu zmeura si gheatza, buna e...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.10) Gecko/20071115 Firefox/2.0.0.10','',0,0),(6651,396,'Nascut din spermatozoizi campioni &raquo; Blog Archive &raquo; De ce o castigat Baselu referendumu&#8217;','','http://www.groparu.ro/?p=414','82.103.137.253','2007-10-12 13:16:41','2007-10-12 11:16:41','[...] Dupa cum poate mai tineti minte, trebia sa votati cu DA ca sa-l alungaÅ£i, ÅŸi cu NU daca vroiati sa il reinstaurati la cÃ¢rma patriei mele cu munÅ£i ÅŸi vÄƒi (Ã®ntr-o vreme aparuserÄƒ ÅŸi buletine de vot cu a treia opÅ£iune). [...]',0,'1','Incutio XML-RPC -- WordPress/2.1.2','pingback',0,0),(6652,414,'WhiteWolf','contact@whitewolf1.info','','89.32.115.68','2007-10-12 13:37:02','2007-10-12 11:37:02','Restul de 25% sunt din tabara lui <b>\"mÃ£ doare capu\' \"</b>. Respectiv, <b>am buba la cap\"</b>\r\nNu-i asa ? :P',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(6653,693,'WhiteWolf','contact@whitewolf1.info','','89.32.115.68','2007-10-12 13:39:42','2007-10-12 11:39:42','Nush\' ce sa zÃ c...\r\nN-am fo\', nu am vaz\'t, tre\' sa te cred pe cuvant. O vreme o (mai) fac :P\r\nDa\' mie tot imi suna o tzarÃ£ a <b>polutzie</b> numele la hardughia de ne-ai prezentat-o.\r\nSi daca ai mai pisheat (se poate citi si \"udat\") si pantalonashii, inclin sa cred ca am dreptate :)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(6654,693,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-10-12 13:43:48','2007-10-12 11:43:48','Mah, adevaru e ca Polus seamana cu Falus in pronuntzie :|',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6655,693,'Razvan','razvan.antonescu@gmail.com','http://idei-locale.blogspot.com','81.196.150.96','2007-10-12 13:50:14','2007-10-12 11:50:14','Deci. Tu esti gay da te dai hetero tat repetand \"Hostese demenÅ£ial de faine\". Altfel nu ezplica lipsa de poze. Si aia ce ai tremurat tu acolo ca ezplicatie nu tine. De loc',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6660,414,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-10-12 15:13:18','2007-10-12 13:13:18','Da, sau \"stii, am neshte bube acolo!\", \"stii, nu-mi place de tine chiar asa de mult!\", \"stii, pare incredibil, dar pana si o urata ca mine poate avea prieten, si eu il iubesc!\", \"stii, mie-mi plac fetele!\", \"stiti, sunteti prea batran pentru mine!\", \"stii, cum dreq te gandeai ca noi doi am fi putut sa ne...??? LOOOOOOL!!!!\", \"stii, as prefera sa ramanem amici!\", \"stii, tu cu AIA vrei sa ma iubesti? LOOOOOOL!\", \"stii, nu am baut suficient ca sa ma... stii tu... sa ma... cu tine!\", \"cine, noi doi? noi doi sa ne...? NOI DOI????? lasa-ma un pic sa rÃ¢d: =))\" - si daca ma mai caut iti mai zic vreo tri volume!  :|',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6661,693,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','82.77.126.148','2007-10-12 15:19:14','2007-10-12 13:19:14','am spus si in blogul meu, dar spun si aci: nu calc veci si pururi in polus! mi-e greata numa de publicitatea ce i s-o facut, d-apoi sa mai vad si pe viu. daca cineva vrea sa ma omoare, sa ma duca la polus!\r\n\r\neu sunt fana iulius, asa ca il astept cu mare interes',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6662,414,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','82.77.126.148','2007-10-12 15:21:31','2007-10-12 13:21:31','eu nu spun niciodata nu, asa ca te rog sa ma scoti din categoria aia, da? multumesc! :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6663,414,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-10-12 15:29:18','2007-10-12 13:29:18','Deci respectul meu pentru tine tocmai s-a agravat dilatandu-se!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6664,414,'eu','ripahoratiu@yahoo.com','http://simaice?','82.77.126.254','2007-10-12 15:40:39','2007-10-12 13:40:39','Bah, pe mine ce ma mira cu adevarat nu e ca ai 3 volume de nu-uri - dupa cum te stiu io - ci ca nu mai esti fata mare. Era in viata sau ai luat tacerea drept consimtamant?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.2; .NET CLR 1.1.4322; .NET CLR 2.0.50727; InfoPath.1; .NET CLR 3.0.04506.30)','',0,0),(6665,414,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','82.77.126.148','2007-10-12 15:41:40','2007-10-12 13:41:40','si daca iti spun ca pe mine nu ma doare niciodata capul, se mai dilata? ;;) respectul, zic :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(8826,816,'evilpenguin','evilpenguin666@gmail.com','http://evilpenguin666.wordpress.com','81.181.214.176','2007-11-26 20:43:29','2007-11-26 18:43:29','Mah, pai hai s-o luam aÈ™a: depinde unde ar sta. DacÄƒ ar fi mecanici auto, ar da cu carburatoare, dacÄƒ ar fi vÃ¢nzatoare la sex-shop ar da cu dildo-uri, etc. Sunt sigur cÄƒ ar gÄƒsi È™i atunci solutii.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7621,751,'July','jullya24@yahoo.com','','83.103.179.55','2007-11-01 11:44:18','2007-11-01 09:44:18','....frumos...sa tot ai asa pretini, sa-ti faca astfel de urari de ziua ta....bravooo',0,'1','Opera/9.10 (Windows NT 5.1; U; en)','',0,0),(7622,751,'chevantonje','','','82.76.65.140','2007-11-01 12:10:39','2007-11-01 10:10:39','La multzi multzi multzi ani !!!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; t20010828)','',0,0),(8954,822,'baghy','baghy83@lycos.it','http://baghy.info/','78.12.2.226','2007-11-29 00:57:44','2007-11-28 22:57:44','imi place ala cu palaria',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(6657,677,'pliscu','pliscu@gmail.com','http://pliscu.blogspot.com','89.137.100.118','2007-10-12 13:59:26','2007-10-12 11:59:26','gasesti tot ce vrei in ziua de azi la casele de schimb valutar: dolari, euro, lire, shillingi, pula',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6658,693,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-10-12 14:05:06','2007-10-12 12:05:06','Io nuz gay! Singurele funduri la care ma uit is de femei. Am verificat si asa e. \r\nSi nu am vrut sa fac poze finca io nu impart cu altii femeile care-mi place.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6659,693,'nenea cosmos','domnu_cosmos@yahoo.com','http://www.nenea.wordpress.com','193.231.82.119','2007-10-12 14:07:21','2007-10-12 12:07:21','ba groapa, deci sa vezi ca asta primavara am fost eu in calitate de nu conteaza la deschiderea mallului din pitesti aflat acolo la intersectia lui riul doamnei cu riul arges deci intre cracii doamnei ca asa se zice acolo la locul respectiv. la ora 10 (parca) se adunase lumea grupa mare, pensionari, elevi, cocalari, alergatori dupa superoferte, public. astia stateau pe la usi. tot atunci la una dintre intrari au luat cuvintul investitorii si pe urma si l-au dat de la unii la altii si pe urma lu nea ministru, lu nea primaru, lu nea prefectu, lu nea care a mai contat pe acolo. frumos a fost ca teoretic astia vipurile trebuia sa dea un tur prin fata vitrinelor pline cu chiloti si cravate si abia pe urma sa intre pulimea. la x trecut de fix din motive care este ele pulimea a dat buluc in pravalie. e clar ca vipurili nu terminase spiciurili caci ei abia incepuse. s-a alarmat organizatorii lu peste si au pus-o pe una sa dea la microfoane de alea cu : toata lumea sa paraseasca mallu, va rugam iesiti afara, pula mea, caz in care la usa aia unde se tineau spiciurile in boxe aduse special pentru asta se auzea la belea din boxele pravaliei numa: iesiti, afara, eject, mars, nu s-a deschis, etc. toata suprapunerea asta a durat cam 15 minute pina a ajuns unu la tanti aia care rupea microfonul si a impuscat-o pe loc, sa nu se mai chinuie. uite asa vipurile au vorbit degeaba ca nu s-a auzit nimic si pe urma au vizitat mallu impreuna cu pulimea din oras, satra de peste girla, politistii de la circulatie si muncitorii de la autostrada, plus ciutanii care venisera sa ocupe loc la concertul foarte inaugural. mi-au placut taranii care isi faceau poze pe scarile rulante si babele care intrebau cit e kilu\' de ciorapi cu toc.\r\ntreaba buna cu mallurile astea ca fiecare nou mall care apare e mai mare decit toate celelalte si are ceva special, deci aisberguri, avioane, submarine si crocodili. dar brandul polus e din aceeasi familie cu sugus si nu are sens sa iti mai bati capul pe subiect, au fost altii mai isteti cind au gasit numele astea.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 2.0.50727)','',0,0),(9131,839,'July','jullya24@yahoo.com','','89.123.230.145','2007-12-03 12:21:54','2007-12-03 10:21:54','...faina treaba...ce sa zic decat: MULTA BAFTA....nu vreu\' sa te descurajez dar am trecut si io prin asta cu ma las, nu ieu nik\' ca poci si singura... si \"nu renunt la renuntat\" si dupe vreo 5 zile tremuram mai rau ca ce dorm la -15 grade afara pe cartoane...si deci inevitabil am renuntat la renuntat....daca gasesti tu formula magica sa o impartasesti omenirii',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(9020,831,'baghy','baghy83@lycos.it','http://baghy.info/','78.12.2.226','2007-11-29 22:57:15','2007-11-29 20:57:15','esti un scump :P',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(9012,831,'Doro','kettlerdorothea@yahoo.com','http://www.kettlerdorothea.ro','89.122.253.17','2007-11-29 21:26:10','2007-11-29 19:26:10','N-am Ã®nÅ£eles exact despre ce zici cÄƒ mi s-a fÄƒcut milÄƒ, please explicÄƒ ÅŸi mie!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.10) Gecko/20071115 Firefox/2.0.0.10','',0,0),(8944,830,'evilpenguin','evilpenguin666@gmail.com','http://evilpenguin666.wordpress.com','81.181.214.176','2007-11-28 22:25:01','2007-11-28 20:25:01','È˜i dacÄƒ da, crezi cÄƒ le-ar pÄƒsa? :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.10) Gecko/20071115 Firefox/2.0.0.10','',0,0),(9069,838,'zgura','','','89.123.121.48','2007-11-30 21:20:24','2007-11-30 19:20:24','Asteptam cu deosebita anticipatiune primul(?) post live in stare de ebrietati, calare pe uaifai',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.10) Gecko/20071115 Firefox/2.0.0.10','',0,0),(8238,790,'Lexis','g_lexis2005@yahoo.com','http://www.alexandraghitalexis.blogspot.com','89.38.76.46','2007-11-17 09:57:23','2007-11-17 07:57:23','\'ai mah, o idee geniala cu domeniile alea, cel mai mult imi place aia cu lenin :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(9211,843,'Mile','','http://milecarpenisan.wordpress.com/','79.114.67.197','2007-12-05 12:36:44','2007-12-05 10:36:44','Ba nu esti normal m-am tavalit pezos de ras si era sa filtrez si alcetva da prin pantaloni (galben dar nu se bea decat la (MISA)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; FunWebProducts; SIMBAR={A7F3C004-B2DD-4145-98BD-0344DDF9CD6E}; .NET CLR 2.0.50727)','',0,0),(7732,761,'.marius','marius@perijoc.com','http://marius.wirelessisfun.com','89.36.21.108','2007-11-06 07:59:38','2007-11-06 05:59:38','eu cred ca a scazut calitatea studentelor la cluj in asemenea masura, incat groparele (also known lately as the *new* *improved* undertaker) vrea sa evolueze pe plan international deopotriva cu ansamblul martisorul al Casei de Cultura a Studentlor si extrem de talentatul taragotist Dumitru Farcas... \r\n\r\nvezi link: http://www.youtube.com/watch?v=twWfVGLebVU',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(9064,763,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','85.186.77.129','2007-11-30 18:44:46','2007-11-30 16:44:46','ma mir ca nu vad macar un caca ratacit pe acolo!! :D',0,'1','Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.0.13pre) Gecko/20071022 Ubuntu/dapper-security Firefox/1.5.0.13pre','',0,0),(8925,822,'NRGY','dani@live.co.uk','','86.121.175.44','2007-11-28 17:12:12','2007-11-28 15:12:12','Super reusite. Al 4-lea imi place cel mai tare. Pot sa-mi fac si eu groparu2.ro si sa folosesc un logo de aici? :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.10) Gecko/20071115 Firefox/2.0.0.10','',0,0),(8924,822,'mirra','','','83.103.137.234','2007-11-28 17:05:49','2007-11-28 15:05:49','sunt cele mai tari!\r\nmai ales cel cu palaria;te reprezinta 100%',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.10) Gecko/20071115 Firefox/2.0.0.10','',0,0),(8923,820,'WarSongu','eternaldawnlord@yahoo.com','http://www.warsongu.wordpress.com','193.32.3.83','2007-11-28 16:47:51','2007-11-28 14:47:51','bre, \"mica-sa-i\"=\"maica-sa-i\"?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; FunWebProducts; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(7403,735,'nenea cosmos','domnu_cosmos@yahoo.com','http://www.nenea.wordpress.com','92.80.36.187','2007-10-27 21:58:34','2007-10-27 19:58:34','am fost acum douÄƒ veri la histria sÄƒ Ã®i arÄƒt lui cosmos junior bolovanii lu\' tata lu\' tata lu\' tata lu\' tata  lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata lu\' tata moÅŸu.\r\ndacÄƒ Ã®i arÄƒt ÅŸi poza asta a ta o sÄƒ ia zece la istorie ÅŸi el Ã®ncÄƒ nici nu a Ã®nceput ÅŸcoala.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(7741,756,'Groparu','groparu_ro@gmail.ro','http://www.groparu.ro','82.77.126.254','2007-11-06 11:07:35','2007-11-06 09:07:35','@ andrei: say no more!!!! gata, nu ma las, uite-ma-s ca deja comentesc! Finca imi pot imagina o lume fara bloagele mele, dar nu si un stomah de gropar fara gatelile tele. Aia-i clar! (Andrei, will u be my wife? ;;)\r\n\r\n@ restu\': ms ms ms de aprecieri, da\' sa stiti ca promit ca daca ma las de blogareala nu o sa-mi si tai venele, deci nu e nevoie sa incurajati maniacu\' de frica ca te miri ce mai face, candideaza la presedintie sau trece la PSD!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7742,761,'Greuceanu','','','195.149.72.105','2007-11-06 11:34:32','2007-11-06 09:34:32','Gropare Wallace!\r\n\r\ntoata viata am fost alaturi de tine si de tara!  voi striga in rand cu tine ori de cate ori ridici paloshu\': FFFFRRRRREEEEEEEEEEEEEEEEDOM!!!!!! sa ne sacrificam!',0,'1','Opera/9.24 (Windows NT 5.1; U; en)','',0,0),(7743,761,'nelli','mezeinelli@gmail.com','http://www.mezeinelli.wordpress.com','86.34.194.202','2007-11-06 12:15:13','2007-11-06 10:15:13','relaÅ£ia romÃ¢no-maghiarÄƒ nu o vrei sÄƒ repari? :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7744,761,'adi','adyrotaru@yahoo.com','','89.120.56.7','2007-11-06 12:50:45','2007-11-06 10:50:45','zic si io oarecum offtopic, fac pishu pe broscari',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(7745,761,'vizionarul','alinmiron_19@yahoo.com','http://www.vizionarul.wordpress.com','83.103.154.202','2007-11-06 12:50:57','2007-11-06 10:50:57','ma gropare io creca tu vrei sa refaci poporul roman... ca burebista cu nevasta lu traian...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7746,761,'koyrosh','a@a.com','','82.77.126.254','2007-11-06 13:28:05','2007-11-06 11:28:05','la rugamintea lu\' groparu\' bag acilia o treaba care poate fi o tzara offtopic, da\' e cu italieni: in primul rand, cine or facutara roma? romulus si remus, nu? ei, chiar nu vede nime\' ironia sortii? romulus (emailat sau nu) si-o fi zis: mo, io v-am facut, io va omor. ceea ce si face!',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(7747,759,'koyrosh','a@a.com','','82.77.126.254','2007-11-06 14:37:00','2007-11-06 12:37:00','sa va zic io poveste povestitoare: acu\' fo 2 ani, acelasi gropar, care cu onor e de fatza la abereatziunile dansului, scria despre un prunc la oncologie. care nu mai e. au ramas doar ratele....',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(7748,761,'VIP','ps@yahoo.com','http://vipuri.blogspot.com','213.157.188.71','2007-11-06 15:16:42','2007-11-06 13:16:42','da sa fie verificate ma! ca cine stie cu ce minunatzii te trezesti! si de ce numa peste 18 ani?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7751,753,'WarSongu','eternaldawnlord@yahoo.com','http://www.warsongu.wordpress.com','193.32.3.83','2007-11-06 16:21:08','2007-11-06 14:21:08','Mishule, sami traiesti bre, u made mai dei sa moara sa faca!\r\ngropare, esti VIP bre... dacati faci partida aia tiganeasca te voi urma panla moarte!',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; FunWebProducts; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(7750,751,'WarSongu','eternaldawnlord@yahoo.com','http://www.warsongu.wordpress.com','193.32.3.83','2007-11-06 16:12:20','2007-11-06 14:12:20','bre groparele care este, da maricon nunseamna curmal?pederast?curlangiu?poponaut?pidoznic?ciclop?curlangiu?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; FunWebProducts; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(7519,742,'WhiteWolf','laskmerge@gmail.com','http://white-wolf.ro','89.39.81.238','2007-10-30 02:11:47','2007-10-30 00:11:47','<b>GENIALULE !!!</b> esti superb.\r\nMacar din cand in cand, acolo, de sÃ£mÃ ntsÃ£ :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7631,442,'lucian A.V.','mr_odonel@hotmail.com','','81.34.169.81','2007-11-02 00:34:11','2007-11-01 22:34:11',':)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; es-ES; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(8920,820,'Andreea MKT','supergirgir@yahoo.com','http://marlahermina.deviantart.com/gallery/','82.77.126.254','2007-11-28 16:36:38','2007-11-28 14:36:38','creca anuntzul ala a lui mishu e pentru mine, asa banui.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(8921,820,'Usim','mihaimitan@gmail.com','','87.237.108.33','2007-11-28 16:36:55','2007-11-28 14:36:55','Daca la voi la firma buda nu-i unisex, atunce-i pluri-sex?\r\n\r\nParerea mea!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; .NET CLR 2.0.50727)','',0,0),(9151,841,'vizionarul','alinmiron_19@yahoo.com','http://vizionarul.wordpress.com','89.35.87.15','2007-12-03 19:35:52','2007-12-03 17:35:52','lasa ma gropare, gandeste-te ca daca te lasi, ai sanse mai mici sa mori de cancere si alte maladii asociate, rezisti mai mult la secs cu o femee, si in plus esti mai sanatos. Gandeste-te ca daca te lasi de fumat de asteapta 100 de virgine!!!',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(7627,751,'Greuceanu','','','195.149.72.105','2007-11-01 23:55:46','2007-11-01 21:55:46','da mah! sa traiazca! Io-s var\'so! adfika ala din ultimu\' viers.... da ce nu fac io pt. var\'mio?!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(8814,813,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-11-26 16:16:29','2007-11-26 14:16:29','Da, ba Lupulainu\', visatz, ca si io visez la o clipitÄƒ cand nu voi mai fi discriminat cÄƒ fac pipi pe colacu de la budÄƒ!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8796,813,'Botache','nasturei_verzi@yahoo.com','http://www.nasturei.wordpress.com','82.77.126.148','2007-11-26 11:36:20','2007-11-26 09:36:20','Visam la o Romanie civilizata. ^.^',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.0; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8797,813,'Dorin','dorin.lazar@gmail.com','http://dorinlazar.wordpress.com/','82.77.42.66','2007-11-26 11:37:43','2007-11-26 09:37:43','lilith - tre\' sÄƒ punÄƒ omul cuvÃ®ntul \'leapÅŸÄƒ\' ca sÄƒ percutezi? :P Omul vrea feedback :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8798,813,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','82.77.126.148','2007-11-26 11:43:49','2007-11-26 09:43:49','dorin, azi e luni, deci te rog frumos nu ma lua tare ca ametesc! nu fac conexiuni lunea.. la mine tre sa scrie clar LEAPSA ca sa inteleg...:)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7629,753,'NRGY','','','86.121.184.179','2007-11-02 00:16:17','2007-11-01 22:16:17',':)))))\r\n\r\nSuperstar!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7630,753,'IepurasulAtomic','praetorian21uk@yahoo.com','','62.217.245.97','2007-11-02 00:29:49','2007-11-01 22:29:49','Ma...sa nu ma bati cand ma vei intalni data viitoare, da\' io pe asta cu \"v-am citit blogu\' \" n-o mai cred :)). Chiar si numa\' pen\' ca astia de la banci nu stie sa citeste, care este. Ei stie sa calculeshte. Pen\' citit angajeaza angajati care e terminati la litere, care este, si ei, ca cei mai sus mentionati, numa\' asha ca sa aiba si ei treaba pe lumea asta. Ca-s putini care-s asha de succes ca tine ;). In alta ordine de idei insa, apreciez ca esti starlet pen\' ca cel putin io te citesc cel putin o data(am scris initial \"odata\", dupa nou\' regulament, da\' mi-am amintit ca io nu ader la asta, ca ma \'nerveaza) pe zi. Si io chiar nu-s asha de statornic nici fatza d-o femeie...si nici pe invers nu-s, chiar daca dupa gena imi plac morcovii.Pace p\'afara...daca mai are rost :))!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(9048,832,'Vlad','dez_legat@yahoo.com','','79.113.138.232','2007-11-30 11:15:34','2007-11-30 09:15:34','desbumbi nasturii la chemesha jenerale!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.10) Gecko/20071115 Firefox/2.0.0.10','',0,0),(8172,790,'Andreea MKT','','','89.43.186.64','2007-11-16 14:53:23','2007-11-16 12:53:23','Deci Oana BrianaiamicaPhenoBarbieDoll e infiltrata in blog gratzie Satanei si lui Meri Menson, Batman si Braian Molko (Brian este porecla ei de fapt, intreab-o daca nu o crezi!) si a venit cu ganduri ascunse in Gropaciune ca sa ne faca rau. Am cunoscut-o la Sighisoara la Festivalul Nebunilor si de atuncia ma feresc de ea ca dracu de tamaie.\r\n\r\nAleluia de 3 ori si 4 matanii!\r\n\r\n(Si tot din cauza ei am eu amigdalita)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8173,790,'PhenoBarbieDoll','poisongirl94@yahoo.com','http://blog.360.yahoo.com/poisongirl94','193.230.230.101','2007-11-16 15:06:40','2007-11-16 13:06:40','si din cauza amigdalitei si febrei, Andre a uitat sa mentioneze ca tot eu sunt vinovata si pentru incalzirea globala. va multumesc pentru atentie :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8153,790,'cronicaru\'','tzone_a@yahoo.com','http://cronicaru.blogspot.com/','193.230.230.101','2007-11-16 12:09:44','2007-11-16 10:09:44','ceotzi avea cu bietu om. asa comnuist cum era macar nu ne calca cu jipurili pi gat ca astia. mai striga si el din cand in cand mai animalule dar...gata cu vorba ca ne cheama carmaciu sa facem curatenie',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(8155,790,'andreanum','andreanum@yahoo.com','http://andreanum.wordpress.com','194.30.177.1','2007-11-16 12:34:09','2007-11-16 10:34:09','asta ar fi chiar culmea, sa dam bani ca sa ne stropeasca asta cu zoaie de pe cirpele caghebiste. Da ce, e ateneu, sa donam cite un leu pt el? Da-l dreacu, minca-l-ar vermii si rimele :D',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1)','',0,0),(8915,820,'nenea cosmos','domnu_cosmos@yahoo.com','http://www.nenea.wordpress.com','92.80.32.143','2007-11-28 00:41:01','2007-11-27 22:41:01','http://nenea.wordpress.com/2007/09/20/teleleu-prin-veceu/',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(8873,818,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','82.77.126.148','2007-11-27 12:41:07','2007-11-27 10:41:07','baaai denigratorule! arunca cu apa, nu excremente! vai, ashe m-am atacat de-mi vine sa te rup in doua! ozzy e un domn, da? :((',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8874,816,'manole','redtailanda@yahoo.com','http://www.mesterulmanole.wordpress.com','81.181.92.157','2007-11-27 12:41:43','2007-11-27 10:41:43','mda, cu conditia sa nu tii cratitele in bucatarie...\r\naveam un coleg care-mi spunea ca el stapanul casei lui si face numai ce vrea IAR daca el vrea sa stea sub pat, e TREABA LUI...',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows 98)','',0,0),(8875,815,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','82.77.126.148','2007-11-27 12:42:22','2007-11-27 10:42:22','explicati-mi si mie care e faza cu Danutz...  nu-s la punct cu toate stirile! :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8809,813,'sabina','','','81.12.163.178','2007-11-26 14:04:07','2007-11-26 12:04:07','O, Doamne, WarSongule, ce adanc!!!',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(8810,813,'Greuceanu','','','195.149.72.105','2007-11-26 14:16:48','2007-11-26 12:16:48','Romanie?!.... mi-e dor sa ma ia furnicaturile care imi ridicau camasa de pionier cand m-au facut intr-a cincea comandant de grupa..... si mi-a atarnat ca o decoratie de general acel shnur rosu de epolet si al treilea nasture de sus in jos, apoi cei doi ciucuri rosii si ei au fost arborati de nasturele de la buzunaru stang al camasii...., mi-e dor sa simt ce m-a facut sa simt romania cand a batut anglia si eram in anul II si am facut baie in piscina lui Avram Iancu de la CJ.... mi-i dor sa-mi dea lacrimile cand auzeam vocea celei mai numeroase si mai barbateshti armate in care eram si eu inclus... care in acelashi timp striga ca un zgomot de stanca pravalita de pe varful Moldoveanu in Fundatura Dracului ..: \"ROOOOmaaaaaaaniiiiiiiiiiaaaaaa!!!!!!\", sa mi se inclesteze pumnii cand strigau fratii mei...\"Pe ei! pe ei! pe ei pe mama lor!\"...... sa-mi cada perdeaua sangerie peste privire cand am vazut hoarde ungureshti vanand romani.... imi doresc sa mai zambesc inca o data si sa simt din nou sentimentul natiei sfinte atunci cand Constantinescu a zis:\"Frati romani!!! AM INVINS!!!!\", vreau sa sarut tibia dostorului ce mi-a zis...\" nu primesc nimik de la dvs.... tot ceea ce imi doresc este sa iasa toata operatia bine, iar un buchet de flori pentru domnishoara asistenta este suficient.... vreau ca Romania mea sa evolueze, sa vad macar cateva portiuni de drum cu 4 benzi, vreau o masina straina, vreau sa am in romania casuta mea, vreau dreptul de a munci dublu decat altii si dreptul de a fuma si a bea dublu! vreau sa fac foc in padure! vreau sa beau cu prietenii  si cu sotiile lor! vreau sa ma-mbat cu nevasta-mea fara sa se uite vreun mahomed la mine..... vreau sa plec oriunde in lume pt ca am dreptul de a munci dublu - triplu decat altii! vreau PC cu imprimanta, vreau cablu si internet, vreau concediu in Grecia, vreau sa sudui si sa scuip de cate ori ma-mbat si am chef pe oricine ar fi presedinte si prim =- ministru!, vreau sa le zic rusilor ca n-au nici un drept sa-mi ceara mie socoteala, pt ca sunt mai cacati ca noi! vreau sa o doara-n cur pe romania de recomandarile Bancii Mondiale! vreau sa nu-mi mai fie dor niciodata de tara mea asha cum mi-a fost cu catziva ani inainte!',0,'1','Opera/9.24 (Windows NT 5.1; U; en)','',0,0),(6645,688,'Greuceanu','','','89.21.118.71','2007-10-11 20:23:00','2007-10-11 18:23:00','imi aduc aminte/\r\nde-o poveste veche,\r\ncand ceea ce mi s-a parut cel mai meseriash la popika asta a fost cand m-a intrbat sh pe mine.... \"don\' Flaviu, am ceva ssssspecial pt dvs... haideti, nu ma puteti refuza!!!!... era pe holul de intrare al facultatii de Litere B &amp; B Cluj.... cum bajka mea sa gust acolo la 7.50 dimineata?! ... nu-i nimik, zice... haidetz cu mine.... no mah! sh deschide un dulap de ala militar de pe hol sh zice.. \"poftiti!... cum dreaku sa poftesc mah in dulap?! dar daca nu ai fi venit ut.... nu cred ca pofteam... dar asha Baza este si am poftit! toti trei! in dulap..... o scos glajutza.... sh io ghiogiltz!ghiogiltz!, tu numa\' ghiogiltz ca erai anu 1, iar cand a venit randu\' lui.....\"no hi! nea\' popika! hi baga-i ca-ncepe cursu\' lu Neamtzu\'!.... uimitor a fost raspunsu\' lui...\"io nu mai beu de 11 ani mah ficiori mah..... ca de mai beu ma curatz1 dar asha-mi place sa vad macar pe altii cum beuuuuuu.. ioi mah! de aia aduk io beutura la jkoala...\"w301864.284',0,'1','Opera/9.23 (Windows NT 5.1; U; en)','',0,0),(8919,815,'Usim','mihaimitan@gmail.com','','87.237.108.33','2007-11-28 16:34:30','2007-11-28 14:34:30','Ghe unghe argelean 100% dara? Ca intelesei ca ticu-tu-i de prin meleaguri oltenesti, Gropare. Cred de de aici si sclipirea de iuteala in actiune :-))',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; .NET CLR 2.0.50727)','',0,0),(9210,843,'manole','redtailanda@yahoo.com','http://www.mesterulmanole.wordpress.com','81.181.92.157','2007-12-05 12:29:54','2007-12-05 10:29:54','inca una : treb sa ajung urgent, la gajica, ai ceva impotriv sa merg pe contrasens?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows 98)','',0,0),(6994,709,'koyrosh','a@a.com','','82.77.126.254','2007-10-22 08:54:42','2007-10-22 06:54:42','franzoala.... tu o ai asa de mare si intr-o dunga, ca ai un koyrosh pe post de preten :P',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(9212,843,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-12-05 12:45:54','2007-12-05 10:45:54','Man, deci numa atata vreu sa te rog: ai fo\' singuru care l-ai intervievat pe Mirun Cozma, da\' sa nu-i zici de saitu meu nici daca te tortureaza. \r\n\r\nPls mult.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9157,841,'manole','redtailanda@yahoo.com','http://www.mesterulmanole.wordpress.com','89.32.123.108','2007-12-03 20:55:29','2007-12-03 18:55:29','ÅŸi-mi ierai simpatic....\r\nÅŸ-acuma mii o milÄƒ....\r\ndacÄƒ tu reuÅŸeÅŸti, parol, ma las ÅŸi io.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(9017,831,'baghy','baghy83@lycos.it','http://baghy.info/','78.12.2.226','2007-11-29 22:37:13','2007-11-29 20:37:13','o pun pe blog. pot?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(9018,831,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2007-11-29 22:41:42','2007-11-29 20:41:42','dap',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.10) Gecko/20071115 Firefox/2.0.0.10','',0,0),(9010,831,'Mister Bean','arni77@hotmail.com','','85.195.119.22','2007-11-29 20:50:31','2007-11-29 18:50:31','ioi gropare poet te faceam!',0,'1','http://Anonymouse.org/ (Unix)','',0,0),(9094,838,'Lucian','pascutlucian@yahoo.com','http://www.phy.bris.ac.uk/people/pascut_l/index.html','137.222.230.143','2007-12-01 23:31:42','2007-12-01 21:31:42','Salut Gropare,\r\n\r\nIi foarte tare situl!! Ce sa zis precum stapanul asa si situl!!\r\n\r\nAm fost colegi de camin in 14 si ne-am intalnit in Pub pe Horia in luna septembrie, dupa 5 ani de zile!! mi-ai zis de situl tau. Trimit-mi un email ca sa povestim .',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; UBIS-RESNET 2.0; SLCC1; .NET CLR 2.0.50727; Media Center PC 5.0; .NET CLR 3.0.04506; InfoPath.1)','',0,0),(9072,838,'alcool','gasirea@yahoo.com','http://www.topmanele.blogspot.com','89.123.156.210','2007-11-30 23:39:48','2007-11-30 21:39:48','cool tare postu',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; SU 3.005)','',0,0),(9598,819,'porculeanu','oitza@yahoo.com','','24.19.31.87','2007-12-11 20:36:46','2007-12-11 18:36:46','si mai ziceti de studentese ce burti au =))',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727)','',0,0),(9599,819,'vizionarul','alinmiron_19@yahoo.com','http://vizionarul.wordpress.com','89.35.87.15','2007-12-11 20:46:22','2007-12-11 18:46:22','lasa ca studentele care n-au burti au coaja de portocale pe coapse si pe buci',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648)','',0,0),(8952,822,'WhiteWolf','contact@white-wolf.ro','http://white-wolf.ro','89.39.81.72','2007-11-28 23:47:03','2007-11-28 21:47:03','Tu\'tz mai cetejti imeilu ala de la Iahuu ? :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.10) Gecko/20071115 Firefox/2.0.0.10','',0,0),(8927,822,'catalin','solo@xsolo.biz','http://xsolo.biz','190.17.95.131','2007-11-28 18:34:28','2007-11-28 16:34:28','Palaria e noul trend?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.10) Gecko/20071115 Firefox/2.0.0.10','',0,0),(8953,830,'baghy','baghy83@lycos.it','http://baghy.info/','78.12.2.226','2007-11-29 00:56:57','2007-11-28 22:56:57','Cum zice si evilpenguin. nu le pasa :))',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(6996,712,'mishu','mishu@doingtheartwork.com','http://www.doingtheartwork.com','82.77.126.254','2007-10-22 09:23:42','2007-10-22 07:23:42','mercedes-e :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(8984,832,'Razvan Antonescu','razvan.antonescu@gmail.com','http://idei-locale.blogspot.com','81.196.150.96','2007-11-29 14:58:51','2007-11-29 12:58:51','Sa inteleg ca plateste convocatoru in decembrie? Din banii de advertorial nemarcat?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.10) Gecko/20071115 Firefox/2.0.0.10','',0,0),(8933,815,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2007-11-28 19:23:23','2007-11-28 17:23:23','Da mo! Numa ca capu\' tat ghe arghelean cioban cotropit de unguri, sasi si alte nationalitati o ramas... da\' ne-or cotropit numa finca i-am lasat noi, ca odata cu iei or vint sh femeile lor, sh asa ne-am pastrat gena sanatoasa!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8934,813,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2007-11-28 19:34:28','2007-11-28 17:34:28','Mah, ioz cam inalt, si si musc bine. In afara de cateva gajici, nu o avut nime\' curagiu!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(9046,820,'Looser008.Net','agent_008_2008@yahoo.com','http://www.looser008.net/','195.160.206.172','2007-11-30 10:59:24','2007-11-30 08:59:24','Groparule esti tare :) Am ras de m-a duLut buLtica la postu\' asta... gracias ca m-ai ajutat sa incep dimineatza zambind....Noroc ca nu trebuia sa merg la job.... ca nu am :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.8.1.10) Gecko/20071115 Firefox/2.0.0.10','',0,0),(9023,831,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2007-11-29 23:48:35','2007-11-29 21:48:35','Deci cata vreme nu apare (c) la materialele mele si esti numa un blogger meseriash, feel free, mai ales daca ceri permisie;;)\r\n\r\nDaca esti ceva institutie, deja vorbim $$$.\r\n\r\nDar tu, Baghy, cu Groparu, cei avea tat timpu\' o relatie speciala!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.10) Gecko/20071115 Firefox/2.0.0.10','',0,0),(7618,750,'Miruna','mirunavasilescu@yahoo.com','http://potsafacsiasaceva.blogspot.com/','86.106.59.163','2007-11-01 05:32:54','2007-11-01 03:32:54','Domnule, nu-i de ras, nu-i deloc de ras. Eu am frigider Arctic doar ca dupa ce am citit despre sursa lui de inspiratie mi-e frica sa mai umblu prin el.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(6671,693,'duiliu','lasama@mail.com','','62.224.197.164','2007-10-12 20:50:38','2007-10-12 18:50:38','ai uitat sa ne spui de hostese',0,'1','Mozilla/5.0 (Macintosh; U; PPC Mac OS X Mach-O; de; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(7604,749,'pirelli','honda@mail.com','','62.224.237.46','2007-10-31 10:31:44','2007-10-31 08:31:44','macar stii de unde ti se trage : ti-ai naucit piciorul cu duhoarea din pantofi :D bietu\', ce sa se stie face ? era dezorientat si nu vedea pe unde umbla, pentru caci avea lacrimi in ochi.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7274,735,'ss','criss_team@yahoo.com','','81.196.150.198','2007-10-25 17:05:42','2007-10-25 15:05:42','mo, baile erau locurile unde legionarii faceau jacuzzi si beau sampanie cu daco-getele, geor-getele, marga-retele si toate celelalte vete care inca de pe vremea aia erau renumite pentru frumusetea lor si formele lor sexi, bine scoase in evidenta de costume de baie jolidon, desigur.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7','',0,0),(8865,817,'mirmen','mirmen_bursi@yagoo.com','','83.103.142.179','2007-11-27 09:55:14','2007-11-27 07:55:14','@groparu\r\nm-ai strigat ;;)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(7165,717,'Basty','basty@canvas.ro','http://basty.wordpress.ro','82.77.126.21','2007-10-24 12:24:39','2007-10-24 10:24:39','Io imi depun CV-ul pentru postul de Navalitor Sef. Ma am bine cu organizarea si cu multi.. cum se zice.. taschingul ( :D ), deci ma pot ocupa de n+1 inamice deodata, ditamai capitan de oshti ce sunt eu.',0,'1','Mozilla/5.0 (Macintosh; U; Intel Mac OS X; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(6673,697,'baghy','baghy83@lycos.it','http://baghy.info/','78.12.8.67','2007-10-12 22:26:34','2007-10-12 20:26:34','e o doamna?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(6674,693,'ania','soredarkshines@gmail.com','http://aniakhaki.blogspot.com/','89.123.108.147','2007-10-12 22:58:00','2007-10-12 20:58:00','am fost si eu azi :( pull and bear nu era deschis :( nu au the body shop... in concluzie... polus e cam degeaba! si au pesti vii in carrefour ...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6675,414,'WhiteWolf','contact@whitewolf1.info','','89.39.81.99','2007-10-12 23:09:37','2007-10-12 21:09:37','\"Deci\" nenea Cosmos a pus cea mai corecta, universala si indubitabila concluzie posibila :) :) :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6958,712,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','85.186.77.129','2007-10-21 14:27:21','2007-10-21 12:27:21','ba ar fi o varianta, dar mi-e tare rusine s-o spun :\"&gt;',0,'1','Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.0.12) Gecko/20070731 Ubuntu/dapper-security Firefox/1.5.0.12','',0,0),(7386,735,'CAESARUS','caesarus@adresafalsa.ro','','79.113.88.253','2007-10-27 17:10:41','2007-10-27 15:10:41','Ioi bine-i sa te prostesti!!!!',0,'1','Mozilla/5.0 (Macintosh; U; Intel Mac OS X; en) AppleWebKit/419.3 (KHTML, like Gecko) Safari/419.3','',0,0),(7387,735,'CAESARUS','caesarus@adresafalsa.ro','','79.113.88.253','2007-10-27 17:11:12','2007-10-27 15:11:12','SERBULIUS LA TOATA LUMEA!',0,'1','Mozilla/5.0 (Macintosh; U; Intel Mac OS X; en) AppleWebKit/419.3 (KHTML, like Gecko) Safari/419.3','',0,0),(7515,740,'Miruna','mirunavasilescu@yahoo.com','http://potsafacsiasaceva.blogspot.com/','86.106.59.163','2007-10-30 01:11:01','2007-10-29 23:11:01','Pf, mie mi-a zis o duduie odata, acu\' vreun an, dupa ce am intrebat-o juma de ora despre cum vine treaba cu un cont si dobanda la el, \"da\' tu n-ai facut matematica la scoala???\". Am iertat-o ca asa e, n-am prea facut. =))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7783,760,'zau asa!','totmea@yahoo.com','','89.123.116.181','2007-11-07 12:52:11','2007-11-07 10:52:11','nu te-o recunoscut ca esti Groparu\'? si nu s-o dat drept italience? pfiii. quando mai usci tu la ocazione, vengo io sa te iau, sa spalam o data, pardon, odata rusinea natiei.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(7784,760,'WhiteWolf','contact@white-wolf.ro','http://white-wolf.ro','89.39.81.125','2007-11-07 15:02:58','2007-11-07 13:02:58','@zau asa, pe repede inapoi cateva posturi pana dai despre si cu opinia Groparelui pe muchea la ce se intampla la italienici\r\nSi-ai sa vezi :)\r\nQuando vine vorba de Italia(na) nimic nu mai face ,Groparu, la buna intelegere. Numa\' cu violu si cotropirea dovedesti :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8976,822,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','82.77.126.148','2007-11-29 11:36:54','2007-11-29 09:36:54','ptiu, piei ispita! imi place nomber trei! la mai mareeee',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.10) Gecko/20071115 Firefox/2.0.0.10','',0,0),(6949,704,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','85.186.77.129','2007-10-21 08:10:21','2007-10-21 06:10:21','bei gropare, matale nu esti hacker, esti cracker! diferenta, bre! :P',0,'1','Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.0.12) Gecko/20070731 Ubuntu/dapper-security Firefox/1.5.0.12','',0,0),(6950,712,'PhenoBarbieDoll','oana.gavrila@mediafax.ro','http://blog.360.yahoo.com/poisongirl94','86.120.236.133','2007-10-21 08:57:53','2007-10-21 06:57:53','Din ciclul \"careful what you wish for, you just might get it\" :D',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 2.0.50727)','',0,0),(6951,712,'mercedes','delrio@mail.com','','62.224.220.36','2007-10-21 09:52:45','2007-10-21 07:52:45','romanticul-e  ^_^',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7695,758,'VIP','ps@yahoo.com','http://vipuri.blogspot.com','213.157.188.71','2007-11-05 09:43:55','2007-11-05 07:43:55','...pula, nu gluma',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7696,758,'Arhi','arhi@arhiblog.com','http://arhiblog.com','82.79.66.93','2007-11-05 10:13:00','2007-11-05 08:13:00','io zic sa cauti xboss publichublist, si sa iti vezi de trebi:)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7697,758,'WarSongu','eternaldawnlord@yahoo.com','http://www.warsongu.wordpress.com','193.32.3.83','2007-11-05 10:50:12','2007-11-05 08:50:12','iti dai zeama ca ala care tza dat kick si avea nicku de cioclu era probabil vrun putzoi de 15-16 ani cu ochelari, cosuri, carare (era sa scriu cacare) pe mijloc si tricou cu immortal, nu?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; FunWebProducts; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(7688,756,'Fluture','fluture093@yahoo.fr','http://blog.FriendlyFrog.ro','83.141.153.230','2007-11-04 13:09:15','2007-11-04 11:09:15','WhiteWolf, ai pus punctul pe i.\r\nGropare, te rog, nu vreau sa te am pe constiinta, sa stiu ca te-am tras dupa mine in groapa (sic!).\r\n\r\nSucces la scris si multam, mi-ai marit traficul cu 500%:-))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; fr; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(8827,816,'Laura','mars1953','','84.160.94.140','2007-11-26 20:54:33','2007-11-26 18:54:33','Cu mare placere atata timp cat au barbati care au ce le aduce ce sa bage in cratita. Si ceea ce le aduce sa fie si comestibil. \"Dragostea doar, din pacate, trece prin stomac\".',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(7691,756,'PhenoBarbieDoll','poisongirl94@yahoo.com','http://360.yahoo.com/poisongirl94','193.230.230.101','2007-11-04 15:44:00','2007-11-04 13:44:00','pai unde pune Groparu\' mana (sau linkul, dupa caz), creste! :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(8847,817,'nenea cosmos','domnu_cosmos@yahoo.com','http://www.nenea.wordpress.com','92.80.17.41','2007-11-27 01:35:40','2007-11-26 23:35:40','si totusi voturi se numara, hehe... tocmai in cosmos!',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(8851,817,'WhiteWolf','contact@white-wolf.ro','http://white-wolf.ro','89.39.83.44','2007-11-27 02:46:15','2007-11-27 00:46:15','Don\'t care, don\'t like\r\nCu koncursu\' au tÃ mpit poporu, Gropare !!!!\r\nRemember Florin Calinescu \"cu manutzele astea doua\" ... respectiv primul miliardar pe carti postale ? :P\r\nDaca\'i tot el da\' andÃ£cavÃ£r; as Cozmos ?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(6953,704,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2007-10-21 11:30:03','2007-10-21 09:30:03','Hacker, cracker, rapper, Ploiesti, Pitesti, Filiasi, care \'mniezau mai e diferentza?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7576,748,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-10-30 17:51:06','2007-10-30 15:51:06','@ Anonymous: ar fi si mai super najpa sa inlocuiasca statuia calului Matthiasului cu statuia Solenzei primarului!\r\n\r\n@ Cala: am cautat indelung dupa cel mai najpa poll de pe net. Asteptarea mi-a fost rasplatita!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7577,748,'zdranga','coraelena@gmail.com','http://zdrangazdranga.blogspot.com/','82.208.130.87','2007-10-30 17:52:56','2007-10-30 15:52:56','io zic cÄƒ mai toate pot fi valide, ÅŸi Ã®n acelasi timp Ã®ncÄƒ! carevasÄƒzicÄƒ Ã®nlocuim cuvÃ¢ntul cal cu boc, Ã®i punem coaie ÅŸi puÅ£Äƒ mici mici sÄƒ nu crape groparu de ciudÄƒ, cÄƒ vrem sÄƒ mai blogÄƒreascÄƒ totuÅŸi, topim tot ce poate crea fetiÅŸisme ÅŸi regina festiÅŸurile, subsemnata, Ã®ÅŸi face o mulÅ£ime de inele din *aparatul topit*!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(7561,746,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-10-30 11:13:14','2007-10-30 09:13:14','Hai, da\' nu promit ca o sa fie suficient loc in porbagaj :|',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7562,746,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','82.77.126.148','2007-10-30 11:14:59','2007-10-30 09:14:59','nu-i stres, stau pe capota! :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7563,746,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-10-30 11:29:57','2007-10-30 09:29:57','OK. O sa vorbesc cu soferu\' sa te ia pe capota.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7785,760,'zau asa!','totmea@yahoo.com','','89.123.116.181','2007-11-07 15:55:18','2007-11-07 13:55:18','@ lupuilane (suna fain). sint la zi, sint la zi. consimteam deci, pentru onoarea patriei. la cum il vaz, nu cred ca plec cu regrete.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(7787,760,'WhiteWolf','contact@white-wolf.ro','http://white-wolf.ro','89.39.83.53','2007-11-07 18:04:25','2007-11-07 16:04:25','ApÃ£i, de.\r\nDeja vine miros de adevarata provocatie :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7772,761,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2007-11-07 00:27:09','2007-11-06 22:27:09','Deci mo, io ce-am vazut prin Milano nu parea deloc gretzos!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7035,712,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','82.77.126.148','2007-10-22 14:35:15','2007-10-22 12:35:15','nu, dar daca vrei sa vezi ce-i mergi la divertis... sper sa nu-ti fie prea stramt :|',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7036,712,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-10-22 14:47:07','2007-10-22 12:47:07','Mi-ai loat o cana???\r\n\r\nO sa-mi fie :|',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7037,712,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-10-22 14:48:36','2007-10-22 12:48:36','PS: am fost magar?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(8822,807,'Usim','mihaimitan@gmail.com','','87.237.108.33','2007-11-26 19:01:48','2007-11-26 17:01:48','Io zic ca Iepurasu\' merita oricum o bere pentru profetia de peste 40 de comentarii. Si nici n-a fost nevoie sa le faca el :-))\r\n\r\nMai asteptam comentatii pentu cota de 69 (a doua bere)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; .NET CLR 2.0.50727)','',0,0),(8818,814,'WarSongu','eternaldawnlord@yahoo.com','http://www.warsongu.wordpress.com','193.32.3.83','2007-11-26 18:00:31','2007-11-26 16:00:31','lol...colegu meu:\r\n\"bah, esti urat si prost!\"\r\nio:\r\n\"bah, pa cine mortii matii faci tu urat?!?\"',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; FunWebProducts; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(8819,813,'andreanum','andreanum@yahoo.com','http://andreanum.wordpress.com','194.30.177.1','2007-11-26 18:05:58','2007-11-26 16:05:58','deci acest maret post si unele dintre maiestrele vuastre comentarie m-au facut sa compun un textulet cu vrerile mele pe care o sa-l publice niste baieti in revistuta explore care apare la galati. Va spun doar titlul: vot uninominal pentru presedintele de cartier. Si vi-l aduc in dar pe la sfirsitul saptaminii, dupe ce apare dinsul de sub tipar, ca asa e corect, sa fie intii la el si dupa aia in groapa asta :D',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1)','',0,0),(7452,735,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2007-10-28 12:20:21','2007-10-28 10:20:21','@ Caesarus, da\' cum \'mniezau mah ai aflatara tu mah de saitu\' asta mah? Oare traim chiar asa intr-o lume globalizata? Oricum, very good to hear from you (mah!)\r\n\r\n@ nenea cosmos: ai cui erau bolovanii aia, cand erau? Ca n-am prea intzales!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7453,720,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2007-10-28 12:21:09','2007-10-28 10:21:09','@ p3 & petria: nu am fo\' inke, da\' vedetz ca cand merem va lom ca ghizi! Howk.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(8938,822,'cÄƒlÄƒ','acalarasu@gmail.com','http://adriancalarasu.wordpress.com/','89.32.19.126','2007-11-28 20:52:29','2007-11-28 18:52:29','Groparu se rebranduieste!\r\nMie-mi place tare ala al patrulea cu cimitiru\' cu peneluri stilizate.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) )','',0,0),(8312,792,'Andreea MKT','','','89.43.186.64','2007-11-18 19:52:14','2007-11-18 17:52:14','deci tot aud ca groparu le bea. dar sincer, nush....fatza lui inca este accea a unui copil inocent (cum sa se imbete copilul asta?) si coleg de treaba care te ia in brate daca ai o problema. gropare, convinge-ma ca tu BEI!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7039,713,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','82.77.126.148','2007-10-22 15:21:54','2007-10-22 13:21:54','gata gropare, mission completed! pfffiuuu.. inca o leapsa incheiata cu succes!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7040,712,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','82.77.126.148','2007-10-22 15:25:13','2007-10-22 13:25:13',':))) nu o cana bre! e o caciulita maaaareeeee si din cauciuc! :D da e mare rau... cred ca are diametrul de vreo 10 cm. pentru un om asa de mooodest, trebe caciulita la fel de modesta!\r\n\r\nam fost magarita? :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7021,713,'vizionarul','alinmiron_19@yahoo.com','http://www.vizionarul.wordpress.com','83.103.154.202','2007-10-22 13:19:54','2007-10-22 11:19:54','Pif sau Rahan se pun? Chiar daca pe vremea aia ma uitam la poze, ca nu pricepeam francais-u\'? Si daca stau bine sa-mi aduc aminte, erau cartile alea.. \"Animale din continente\" Iar carte de bebleoteca... nu mai retin titlul, doar ca mirosea a lipici dintr-ala Pescarus, bun de mancat.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(8098,786,'mira','miramar@mail.com','','62.224.216.11','2007-11-15 20:16:45','2007-11-15 18:16:45','deduc ca te asteapta o perioada de abstinenta sexuala acuma :D \r\nsau a fost degetu de la mÃ¢na stÃ¢nga ? ca sa nu te intreb daca esti stÃ¢ngaci, lol',0,'1','Mozilla/5.0 (Macintosh; U; PPC Mac OS X Mach-O; de; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7798,769,'UnCopiluty','uncopilutz@yahoo.com','http://www.uncopilutz.haipa.ro','79.113.139.81','2007-11-08 01:27:53','2007-11-07 23:27:53','Io mi-am Ã®ntrebat femeia ÅŸi zice cÄƒ ea n-a fost la FÄƒget decÃ¢t la fript grÄƒtare de 1 Mai. E!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 2.0.50727)','',0,0),(8878,815,'macabroo','raduccc@yahoo.com','http://rezistenta.blogspot.com','80.96.196.2','2007-11-27 13:02:16','2007-11-27 11:02:16','pai trebuie sa fi consumatoare ca sa te prinzi, si sa incerci sa te lasi intr-o dimineata ploioasa de luni ca sa razi...',0,'1','Opera/9.23 (Windows NT 5.1; U; en)','',0,0),(8879,815,'PhenoBarbieDoll','poisongirl94@yahoo.com','http://blog.360.yahoo.com/poisongirl94','193.230.230.101','2007-11-27 13:05:28','2007-11-27 11:05:28','@lilith: Ursuleee, ai auzit ma ca au scos ajtia o bere cu numele tau?si ursu\' se duce la bar mandru nevoie mare si zice: dati-mi, va rog, o bere Danutz!\r\n\r\n@Groparu\': deci nu numa\' clujenii stie bancu aiesta!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.10) Gecko/20071115 Firefox/2.0.0.10','',0,0),(8880,815,'PhenoBarbieDoll','poisongirl94@yahoo.com','http://blog.360.yahoo.com/poisongirl94','193.230.230.101','2007-11-27 13:06:38','2007-11-27 11:06:38','si am pus apostrof dupa \"Groparu\" nu ca mi-o alunecat dejtu\' pe taste, ci finca l-am apostrofat, da? :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.10) Gecko/20071115 Firefox/2.0.0.10','',0,0),(8881,818,'macabroo','raduccc@yahoo.com','http://rezistenta.blogspot.com','80.96.196.2','2007-11-27 13:09:43','2007-11-27 11:09:43','Urmatorul pas e sa-l musti de cap si sa i-l scuipi in fatza inca pulsanda...',0,'1','Opera/9.23 (Windows NT 5.1; U; en)','',0,0),(8896,815,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-11-27 16:21:14','2007-11-27 14:21:14','Mah, deci.\r\n\r\nEle cand cade, cade direct in poAla mea. D-aia imi place mie de soferii RATUC, ca pune frane bruste, si femeile ori se tin de bara, ori pica.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.10) Gecko/20071115 Firefox/2.0.0.10','',0,0),(8883,815,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','82.77.126.148','2007-11-27 13:58:02','2007-11-27 11:58:02','ahaaaa.... vezi? eu nu stiam bancu asta, ca eu nu sunt consumatoare de ursus. la mine place numa tuborg, stela, beks si uneori o timisoreana...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8884,817,'mirmen','mirmen_bursi@yagoo.com','','83.103.142.179','2007-11-27 13:59:14','2007-11-27 11:59:14','pai,a divulgat secretu\' : pita si apa; de circ se-ngrijeste singur; cu pretinii; te califici :))',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(8885,815,'PhenoBarbieDoll','poisongirl94@yahoo.com','http://blog.360.yahoo.com/poisongirl94','193.230.230.101','2007-11-27 14:01:33','2007-11-27 12:01:33','io nu-s consumatoare de bere in general, da\' Danutz e tare :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.10) Gecko/20071115 Firefox/2.0.0.10','',0,0),(8886,818,'Felix','felix.felix@gmail.com','','213.233.122.144','2007-11-27 14:30:38','2007-11-27 12:30:38','sa nu te lasi luat de avant si sa banezi de acasa ip-ul de la serviciu al adminului de retea :)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(8895,818,'baghy','baghy83@lycos.it','http://baghy.info/','78.12.2.226','2007-11-27 16:17:26','2007-11-27 14:17:26','cine a produs excrementele?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(8888,818,'makavelis','ashipos@yahoo.com','http://makavelis.blogspot.com/','89.137.50.52','2007-11-27 14:42:12','2007-11-27 12:42:12','as urca pe scena si i-as baga pe gura cu tot ce a aruncat. vedete pline de ei si fanii lesinati dupa un besinos\r\np.s. si cei de la Mafia s-au pisat pe spectatori la un concert',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8889,818,'CÄƒlÄƒ','acalarasu@gmail.com','http://adriancalarasu.wordpress.com/','62.217.241.242','2007-11-27 14:45:35','2007-11-27 12:45:35','that\'s BULLshit!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(8891,771,'mirra','','','83.103.137.234','2007-11-27 15:32:42','2007-11-27 13:32:42','mai stiu pe cineva care s-a  inscris la soferit  de prin iunie si de atunci inca tot face scoala.Shi pun pariu ca e scoala aia de pe Horea,unde fac reduceri...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8892,815,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-11-27 16:00:10','2007-11-27 14:00:10','Io astept sa scoata astia bere Groparu! Pana atunci, ma rezum la a o scoate eu singur, din mine. La baie, of cos. Of cos.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.10) Gecko/20071115 Firefox/2.0.0.10','',0,0),(8893,815,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-11-27 16:00:38','2007-11-27 14:00:38','OOOK, uneori si pe garduri.\r\nRecunosc.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.10) Gecko/20071115 Firefox/2.0.0.10','',0,0),(8894,815,'baghy','baghy83@lycos.it','http://baghy.info/','78.12.2.226','2007-11-27 16:16:00','2007-11-27 14:16:00','Ziarul Capital pe troleibuz. Nu au cazut femelele la picioarele tale?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(7137,711,'NRGY','','','86.121.178.151','2007-10-24 00:55:06','2007-10-23 22:55:06','Deci impartim acelasi punct de vedere :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7025,713,'Pandora','bluemotogirl@yahoo.com','http://cutiapandorei.blogspot.com/','82.77.126.3','2007-10-22 13:44:37','2007-10-22 11:44:37','Asta cu prima carte cetita seamana cu \"tu de la ce varsta ai prima amintire?\". Prima carte care imi amintesc s-o fi citit e Pollyanna de Eleanor H. Porter, dar se poate sa fi fost doar prima care m-a impresionat (daca ma ajuta memoria, eram prin clasa a 5-a cand am citit-o).',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(8843,816,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2007-11-27 00:18:39','2007-11-26 22:18:39','@ Laura: da, da\' si noi va kinuim, ca nu va lom sunca de fiecare data, sa avetz ce baga in cratitza! :P\r\n\r\n@ Alina: carnitza voastra e lutul in care ne ingropam cel mai cu diligentza, da-da-da!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(6686,470,'Teo','teo.iorga@yahoo.com','','86.123.139.103','2007-10-13 08:37:00','2007-10-13 06:37:00','Bre Gropare, ai cam incurcat numaratoarea.\r\nDupa ultimele calcule coranice si aproximativ musulmane, lotu` e de 72 de pasarele. Da` baiu` e ca nicaieri in Coran nu scrie daca sunt fecioare sau feciori, asa ca io unu` as fi suspicios.\r\nAm zis!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(7249,717,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','83.103.133.158','2007-10-25 06:59:28','2007-10-25 04:59:28','istoria se repeta! inainte veneau turcii si ne furau femeile, dupa aia se duceau singure, nesilite de nimeni! asa si cu groparu! :D',0,'1','Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.0.12) Gecko/20070731 Ubuntu/dapper-security Firefox/1.5.0.12','',0,0),(7250,718,'marz','mariusrott@yahoo.com','','81.12.163.178','2007-10-25 07:59:31','2007-10-25 05:59:31','si sa nu uitam ca Istanbulul a fost inainte Constantinopol, care a fost capitala Imperiului Roman de Rasarit, care s-a format din Imperiul Roman, ca nu mai puteau sa tina romanii atatea provincii, din cauza de neindexare valoare adaugata la imparatu\' si ca se retrase Aurelianu din Dacia in 271 (nexam aurum no more, care estem). Plus boboarele migratoare. Si in Dacia Romana era Napoca, dupa cum se atesta cu sapaturile lui Funar dupa cioburi de oale la poala calului lui Matei Corvin. Napoca este acum Cluj, unde s-a ridicat soclul pentru statuia lui Cuza.\r\nThe circle is now complete !',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.2) Gecko/20070219 Firefox/2.0.0.2','',0,0),(8805,813,'Cipri','cipricorodan@yahoo.com','','194.147.102.225','2007-11-26 13:06:14','2007-11-26 11:06:14','Eu unul mi-am gasit alte subiecte pentru vise. Romania o pastrez pentu momentele cand am nevoie de entertainment sau pentru cand vreau sa ma enervez un pic, pentru momentele cand vreau sa fiu lasat cu gura cascata, aiurit si zapacit de evenimente.\r\nPariez ca ti-ar fi dor de actuala Romanie daca ti s-ar implini visul. Sa fim seriosi, unde ti-ai mai gasi atunci subiectele pentru blogarit? Romania din vis e sterila, plictisitoare si ti-ai baga picioarele in ea. Parol',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(8806,813,'alienatu','andrew.romania@yahoo.com','','89.123.19.163','2007-11-26 13:07:13','2007-11-26 11:07:13','Io visez la o beuta cu amicii in Romania de acu\'',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9b1) Gecko/2007110904 Firefox/3.0b1','',0,0),(8947,822,'CAESARUS','caesarus@adresafalsa.ro','','79.113.91.25','2007-11-28 23:15:14','2007-11-28 21:15:14','Ba ma scarpin in cap si ma \"crucesc\" ce-ti mai coace mintea. Dca e sa ne dam cu parerea ...claaar.. ultima te reprezinta, mai putin faza cu crucile. Esti gropar ca sapi...gropi!!!... putzuri.... da nu ai vrut sa-ti zici Putzar....asa ca puii mei tu eti un revolutionar...ce atate cruci??? VIVA LA REVOLUCION - REBELIUNEEE!!!',0,'1','Mozilla/5.0 (Macintosh; U; Intel Mac OS X; en) AppleWebKit/523.12 (KHTML, like Gecko) Version/3.0.4 Safari/523.12','',0,0),(8948,822,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2007-11-28 23:18:25','2007-11-28 21:18:25','pt tÄƒÅ£i: sÄƒ afle tÄƒt poporu ca Caesarus de mai sus mi-o facut cadou de ziua mea tricou cu Che Guevara personalizat, pe care scriea prenumele gropÄƒresc! Amu-s cÃ¢Å£iva ani.\r\n\r\nFincÄƒ ÅŸtia cÄƒ eram fan, mai ales cÄƒ eram Ã®n plinÄƒ adolescenÅ£Äƒ.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8949,820,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2007-11-28 23:20:46','2007-11-28 21:20:46','Nu poate fi tractoristu la fel de golan pe cat is io de tigan!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7795,760,'john_doe','mihai_pripon@yahoo.com','','81.180.170.53','2007-11-07 22:49:46','2007-11-07 20:49:46','Auzi,ba,Gropare!Este o vorba:\"Dupa o betie clara,oriunde ma lovesti, tat la ficat dai\".Cre ca ti se potriveste de minune',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(7321,720,'darius f','darius2u@yahoo.com','http://desprepsd.wordpress.com/','82.79.52.137','2007-10-26 07:29:47','2007-10-26 05:29:47','Ai forgotat sa ne spui un lucru esential. Di ce te-ai dus acolo? Ai ceva baiuri la plamani?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7322,735,'Programare Sociala','against_spamz@yahoo.com','http://programaresociala.ro','89.121.162.183','2007-10-26 07:44:18','2007-10-26 05:44:18','Da macar apa era si ea calda?',0,'1','Opera/9.24 (Windows NT 6.0; U; en)','',0,0),(7323,735,'ss','criss_team@yahoo.com','','81.196.150.198','2007-10-26 10:40:59','2007-10-26 08:40:59','comisia de disciplina o studiat probele foto si o decis ca-i vorba doar de-o simulare de pishu.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7','',0,0),(7324,720,'p3','','','193.231.18.12','2007-10-26 11:12:52','2007-10-26 09:12:52','eh....merita vazuta shi salina din dej;)...asta dak n-ai vazut-o deja',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(7325,720,'zau asa!','totmea@yahoo.com','','89.123.121.67','2007-10-26 11:26:59','2007-10-26 09:26:59','oaaaai...cum te-o strigat haul! ce-o vrut?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(7326,735,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-10-26 14:15:58','2007-10-26 12:15:58','@ ss: deci m-ai prins. I was faking it :|',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7056,713,'Eauite ce m-a tÄƒguit &laquo; Nandos','','http://nandos.wordpress.com/2007/10/22/eauite-ce-m-a-taguit/','66.135.48.187','2007-10-23 00:10:50','2007-10-22 22:10:50','[...] ce m-a&nbsp;tÄƒguit  pÄƒ mine groparu. CecÄƒ sÄƒ-i spui cam ce carte am citit io prima uarÄƒ. Puah Dej n-am tzÃ®nere dÄƒ minte, da`toce [...]',0,'1','Incutio XML-RPC -- WordPress/MU','pingback',0,0),(7818,770,'laurie','','','69.131.172.203','2007-11-08 17:22:13','2007-11-08 15:22:13','thou art my hero 2 (blushes) (sigh!) :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7736,761,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','82.77.126.148','2007-11-06 09:45:39','2007-11-06 07:45:39','italiencele is naspa!! is grase si urate!!!! mai bine mergi la moldovence!!! stiu eu o vasluianca focoasa foc! :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7737,758,'Sorinelu\'','sorinelm@gmail.com','','86.122.9.37','2007-11-06 09:54:23','2007-11-06 07:54:23','pe cand dc.groparu.ro ?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) )','',0,0),(7738,761,'Groparu','groparu_ro@gmail.ro','http://www.groparu.ro','82.77.126.254','2007-11-06 10:08:10','2007-11-06 08:08:10','@ catalin: ...ca sa nu mai vorbim de chinezoaice, sud-americance, thailandeze... o s-avem de lucru! MULT!\r\n\r\n@ Lupulainu\': mo, deci nici in cele mai perverse vise de-ale mele nu am gasit picior de mascul! Si scopul vietii mele e sa-mi transpun visele in realitate :D\r\n\r\n@ tu, miruna, da, tu: de ce crezi tu ca numa\' patru zile pe saptamana am timp de italience? :D :D :D\r\n\r\n@ .marius: mo, deci nu o scazut calitatea lor, da\' io nush cum mniezau se face ca tat imbatranesc :| numa capu\', din fericire, nu se mai coace odat\'!\r\n\r\n@ lilith: poi si cum sa-mi dau seama ca is dementiale daca nu incerc cu najpete mai intai?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7739,759,'PhenoBarbieDoll','poisongirl94@yahoo.com','http://blog.360.yahoo.com/poisongirl94','193.230.230.101','2007-11-06 10:09:57','2007-11-06 08:09:57','Usim, tu deja esti mai tare ca Wolfowitz pentru ca am incredere ca sosetele tale nu sunt gaurite!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7043,707,'sminchy','','','82.76.75.160','2007-10-22 15:50:33','2007-10-22 13:50:33','deci, bre, gropare, mata esti prea ermetic numa\' pentru cine n-are brishca :D',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; InfoPath.1)','',0,0),(6694,693,'10mbc','alin.banc@gmail.com','','89.137.5.71','2007-10-13 12:16:09','2007-10-13 10:16:09','Fratilor, la mine e si mai rau... Am fost pana la polus de 2 ori, de fiecare data am intrat pe strazile alea, dar niciodata nu am intrat in vreun magazin. Prima data eram prea adormit si nu m-am riscat, iar a doua oara am fost prea plictisit. Asa-i daca am fost nevoit sa o duc pe 10mfc la serviciu. Acuma pana o sa imi mai vina chefu de plimbari pe jos prin polus mai trece. Oare nu te lasa cu masina pe acolo? Sau macar cu bitza. A... btw... 10mfc e o hostesa. Tzac Groparule!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(7026,712,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-10-22 14:04:32','2007-10-22 12:04:32','Iar ti-ai cumparat lenjerie...?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(8666,807,'Conia','','','193.226.17.210','2007-11-23 18:20:36','2007-11-23 16:20:36','Unii aduna roadele si altii profita de ele.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(8667,807,'IepurasulAtomic','praetorian21uk@yahoo.com','','192.100.130.8','2007-11-23 18:29:37','2007-11-23 16:29:37','Io nu-mi pot da seama daca lumea se inghesuie mai tare la berea aia gratis, sau se uda de placere cu gandu\' c-or ajunge sa bea o bere cu maharu\' cel mare, un fel de Zeu exilat intre omini! Io va doresc succes tuturor da\' sa castige numa\' unu\'. Ca-i ca la Loto, sa fie castigatori putini, ca premiu se imparte la toti. Si va dati seama sa-l impartiti pe Groparu\' pana-l obositi? N-ar fi pacat? :) In alta ordine de idei, daca se da o bere pentru cate comentarii speculez ca vor fi la postu\' asta, atunci zic si io: minim 40 :). Ash sta la bere, da\' tre\' sa plec vreo 2 saptamani prin alte state. \r\n\r\nGropare, nu uita, sa castige cineva cu bani si care nu prea tine la beutura, numa\' ashe ca dupa ce dai tu o bere, sa primesti inapoi inzecit. Este ca-s drac? He he he...Pace p\'afara copii!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(7014,712,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','82.77.126.148','2007-10-22 12:18:40','2007-10-22 10:18:40','ahhaaaaahhaaaa!!! cata modestieeeeee!!!!!!! groparule, cand e ziua ta?? am un cadou frumos pentru tine!!! ;;) pot sa ti-l dau si daca nu e ziua ta! :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7015,713,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','82.77.126.148','2007-10-22 12:19:44','2007-10-22 10:19:44','loool... pot sa iau si io leapsa asta?? pot? pot?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(6696,414,'10mbc','alin.banc@gmail.com','','89.137.5.71','2007-10-13 12:20:33','2007-10-13 10:20:33','Blog pe blog se dilata.. ahhh agatza.... ah... wevr',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(7116,711,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2007-10-23 20:09:23','2007-10-23 18:09:23','Man, deci da, is bagat: io ma aflu de o parte a putulicii, iar cealalta parte e infiptÄƒ, mÄƒre, Ã®n tÄƒtÄƒ clasa politicÄƒ - pesedei, pedei, penelei, peremei, udemerei, conservatorei, sh dreq sa-i keptene, cÄƒ mulÅ£i mai Ã®s!\r\n\r\nDeci nu fac politicÄƒ decÃ¢t de la nivel de scuipat, nepÄƒrtinitor, pe toÅ£i, cu mare drag.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(8831,813,'baghy','baghy83@lycos.it','http://baghy.info/','78.12.2.226','2007-11-26 21:32:21','2007-11-26 19:32:21','Gropare nu visezi tu rau. Dar cu Groparita care e faza? Ca eu nu stiam de ea',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(7031,713,'pliscu','pliscu@gmail.com','http://pliscu.blogspot.com','89.137.100.118','2007-10-22 14:23:01','2007-10-22 12:23:01','si probabil ca nu`i singurul nume care te duce cu gandul la bere...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7032,713,'vizionarul','alinmiron_19@yahoo.com','http://www.vizionarul.wordpress.com','83.103.154.202','2007-10-22 14:24:58','2007-10-22 12:24:58','ioai doamne... chiar c-aratau beton tantiile alea imbracate asa sumar... Multa vreme cautam femei in viata reala sa semene cu alea... \r\nDa cand am vazut ca fomeile noastre nu-s ca-n carti, adica sa vaneze, sa se bata cu leii si tigrii si cu alte animale, ca de egzemplu alti barbati dintr-aia parosi si muschilosi si sa  iasa invingatoare si fresh, am avut un soc... da mi-a trecut relativ repede, ca intre timp am mai crescut si mi-am dat io seama cum se mananca o femeie... :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7033,713,'vizionarul','alinmiron_19@yahoo.com','http://www.vizionarul.wordpress.com','83.103.154.202','2007-10-22 14:26:37','2007-10-22 12:26:37','ai ce ma plictixesc la scarbici azi... n-am dormit az noapte numa vro 3 ore si-s rupt... noroc cu cafeaua asta ce ma face sa par treaz si cu restu colegilor ocupati cu lucru... mai am un pic si trec neobservat....',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7008,712,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-10-22 11:06:38','2007-10-22 09:06:38','...sau avea o pwla asa de mare, ca intr-o buna zi si-a facut un blog - www.groparu.ro :|',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(8791,807,'Andreea MKT','supergirgir@yahoo.com','http://marlahermina.deviantart.com/gallery/','82.77.126.254','2007-11-26 10:22:21','2007-11-26 08:22:21','Dragi fratzi,\r\n\r\nNu, de fapt, Groparu ne-a dat tzeapa. nu e vorba de nici un mar, de nici un meri, de nici un vot european. de fapt, imaginea prezinta acele frunze verzi care simbolizeaza nesfarsirea. iar forma lor alungita da senzatia de continuitate. si in spate este margineanu care intra in fleshbeck.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(7811,769,'VIP','ps@yahoo.com','http://vipuri.blogspot.com','213.157.188.71','2007-11-08 15:27:50','2007-11-08 13:27:50','da cat ii terenu acol?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7844,771,'cronicaru\'','tzone_a@yahoo.com','http://cronicaru.blogspot.com/','193.230.230.101','2007-11-09 11:26:47','2007-11-09 09:26:47','Groparu\', hai ma ca se poate. iti tinem proptele daca e cazu. de fapt ce dreaq ma bag io ca nici nu stiu cum o fi sa conduci prin napoca la ora de dat buzna out from uzina. io-mi luai carnetel ca facura toti misto de mine  la o masa de carciuma. si m-a prins. l-am luat in mai putin de-o luna, asa cum pariasem, dar unde dreaq sa conduci? pe bordurile lu videanu? da\' cred ca de voi are grija cioc-boc ala, asa ca bafta. a, si bafta si la calcat :)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(7845,771,'July','jullya24@yahoo.com','','83.103.179.55','2007-11-09 11:41:41','2007-11-09 09:41:41','...eh...e buna ideea cu capu\' instructorului....se stie ca in viatza, pentru a obtine ce vrei, tre\' sa mai calci si pe cadavre..:)',0,'1','Opera/9.10 (Windows NT 5.1; U; en)','',0,0),(7847,770,'WarSongu','eternaldawnlord@yahoo.com','http://www.warsongu.wordpress.com','193.32.3.83','2007-11-09 13:10:09','2007-11-09 11:10:09','ma fute si pa mine o grija...ceai scris despre doftorita? siar mai fi o grija...era buna doctorita?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; FunWebProducts; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(7848,624,'WarSongu','eternaldawnlord@yahoo.com','http://www.warsongu.wordpress.com','193.32.3.83','2007-11-09 13:22:34','2007-11-09 11:22:34','poietule',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; FunWebProducts; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(7849,770,'Groparu','groparu_ro@gmail.ro','http://www.groparu.ro','82.77.126.254','2007-11-09 14:20:27','2007-11-09 12:20:27','Deci despre doftoritza care mi-o scos gandurili de cristiantudopopestiala din mansarda - intr-un viitor apropiat!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7824,771,'you wanna...','ioanaonthenet@yahoo.com','','89.123.72.124','2007-11-08 21:58:47','2007-11-08 19:58:47','asa,\r\nasta era sutu in c\\r care-mi trebuia sa ma apuc sa fac si eu scoala de soferi. nu-i vorba, ca eu am de ceva timp cosmaruri in care conduc ditamai truck-urile si nu stiu cum sa pun frana',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(7825,771,'you wanna...','ioanaonthenet@yahoo.com','','89.123.72.124','2007-11-08 22:00:40','2007-11-08 20:00:40','a,\r\nsi by the way\r\nsa nu te puie pacatele sa te lasi de blog',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(7826,771,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','85.186.77.129','2007-11-08 22:38:03','2007-11-08 20:38:03','putem face pariuri? eu pariez ca te-ai inscris la alfa,si daca te-ai inscris la alfa, nu or sa fie najpa cu tine, ghinionul tau...:D da\' daca te-o pus dracu sa te duci la auto rally, atunci am pus-o! :))',0,'1','Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.0.12) Gecko/20070731 Ubuntu/dapper-security Firefox/1.5.0.12','',0,0),(7827,771,'baghy','baghy83@lycos.it','http://baghy.info/','78.12.13.1','2007-11-08 22:44:39','2007-11-08 20:44:39','macar asa nu mai stai la ocazie',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(7828,771,'DÃ£nilÃ£','','','82.77.202.17','2007-11-08 23:15:32','2007-11-08 21:15:32','mue beuturÃ£ !!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8790,807,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','82.77.126.148','2007-11-26 10:17:18','2007-11-26 08:17:18','deci sa va zic ce am inteles eu din poza aia! coroanele alea formeaza o gaura... groapa e tot o gaura, de unde rezulta ca Groparu MERE la vot! :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8157,790,'Andreea MKT','','','89.43.186.64','2007-11-16 12:57:43','2007-11-16 10:57:43','Deci dragii mei gropari,\r\naceasta intrusa, Oana PhenoBarbieDoll este creatzia lui Satana.\r\nVa rog frumos sa nu ii permitetzi sa mai intre onlain sa gropareasca\r\npe inocentza noastra. Este o fiinta macabra cu tricou cu Manson si\r\nsuflet cu tridentu infipt in el.\r\n\r\n3 cruci cu limba si 3 matanii!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8158,790,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-11-16 13:26:55','2007-11-16 11:26:55','@ all: deci va dati seama ce JOS a ajuns Ilici? Oare isi face si profil pe Hi5?\r\n\r\n@ Andre: deci pe langa toate astea, o suspectesc ca e si mediafaxÄƒ!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7062,711,'macabroo','raduccc@yahoo.com','http://rezistenta.blogspot.com','80.96.196.2','2007-10-23 10:28:49','2007-10-23 08:28:49','Si Loredana e shashuie... dar asta nu inseamna ca tre\' sa o facem presedinta.',0,'1','Opera/9.23 (Windows NT 5.1; U; en)','',0,0),(8946,820,'andreanum','andreanum@yahoo.com','http://andreanum.wordpress.com','89.40.184.91','2007-11-28 23:04:05','2007-11-28 21:04:05','auzi ba, ia vezi, ia-o mai usor cu tractoristii, ca stiu io pe unu care cred ca-i de dimensiunile tale doar ca oleaca mai golan si creca nu-i place ca marea sa sa fie considerata \"mica\". Io atita itz zic, spre binele tau si al firmei, caci daca se ridica \"mica\" cred ca purtati pampersi totz vreo 10 zile. Si luati si antibiotice sa nu vi se infecteze :D',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(8937,830,'alienatu','andrew.romania@yahoo.com','','89.123.8.28','2007-11-28 20:29:11','2007-11-28 18:29:11','Inca o cugetare adanca marca groparu? :)',0,'1','Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.1.6) Gecko/20061201 Firefox/2.0.0.6 (Ubuntu-feisty)','',0,0),(8917,596,'Felix','felix.felix@gmail.com','','213.233.122.144','2007-11-28 15:51:30','2007-11-28 13:51:30','pai cum este posibil sa nu fi existat nici o caminista care sa isi faca o datorie de onoare din a stampara pofta de mancare a groparului?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(7163,717,'Arhi','arhi@arhiblog.com','http://arhiblog.com','82.78.209.163','2007-10-24 12:05:03','2007-10-24 10:05:03','iar ele, eroic, sa iasa cu pieptul dezgolit in calea navalitorilor...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7265,720,'macabroo','raduccc@yahoo.com','http://rezistenta.blogspot.com','80.96.196.2','2007-10-25 15:23:05','2007-10-25 13:23:05','Romania, Harta Rutiera + cazuri de Yeti (Yeti pwla). Ultima poza e o capodopera. Cred ca am varsat o lacrima.',0,'1','Opera/9.23 (Windows NT 5.1; U; en)','',0,0),(7028,713,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-10-22 14:10:57','2007-10-22 12:10:57','@ lilith: my leapsa is your command! (sau invers)\r\n\r\n@ vizionarul: asa-i ca erau dementiale neanderthalienele alea imbracate sumar, numai in blanitza lor de saber tooth tiger?\r\n\r\n@ Pandora: pe mine numele \"Porter\" ma duce instant cu gandul la bere...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7796,769,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','85.186.77.129','2007-11-07 22:52:58','2007-11-07 20:52:58','numa de vro 3 ani. :\"&gt; in rest sunt din vaslui, din vaslui :D (da, sunt moldoveanca si ma mandresc cu asta! :P )',0,'1','Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.0.12) Gecko/20070731 Ubuntu/dapper-security Firefox/1.5.0.12','',0,0),(7059,711,'PhenoBarbieDoll','poisongirl94@yahoo.com','http://360.yahoo.com/poisongirl94','193.230.230.101','2007-10-23 08:44:29','2007-10-23 06:44:29','yuhuuuu, Groparu creste traficul pe Mediafax! Multumiiiim :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7060,711,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-10-23 09:22:24','2007-10-23 07:22:24','Esti mediafaxÄƒ tu Ã®nsaÅ£i?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7683,757,'kalapkura','kalapkura@yahoo.com','http://ciuciu','89.136.55.236','2007-11-04 02:44:54','2007-11-04 00:44:54','fain. ma ie unu tot valea viilor langa arad.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8621,801,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-11-23 10:22:45','2007-11-23 08:22:45','Apoi da, moi fata... sh mie imi ziceau sashii \"Laptiuc\" si ma traumatizau (daca mai spui cuiva de porecla asta, te sinucid!) + plus ca o sasoaica mi-o spart capu cand aveam vreo 5 ani. Elke o chema!\r\n\r\nDar cand incepi cu \"Ei bine, aici Ã®mi motivez, ura faÅ£Äƒ de romi ÅŸi mai exact faÅ£Äƒ de care categorii dintre ei\" - cam umbli pe nisipuri miscatoare. Crezi ca daca incerci sa te scoti dupe aia, intr-o postare lunga, reusesti?\r\n\r\nIn locul tau, as face o postare la fel de serioasa in care as lauda romii Äƒia pe care nu-i urasti. Si ai mai contrabalansa :) si nici nu s-ar mai inflama in halu\' asta blogosfera. Te pot ajuta si io, ca am afinitati sentimentale CRASE cu muzica lor!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7602,749,'July','jullya24@yahoo.com','','83.103.179.55','2007-10-31 10:21:10','2007-10-31 08:21:10','Io zic ca dak nu vei mai fi inclus in blogrollul lu\' Zoso sa te lashi...Mircea Badea tocami d\'aia nu sh\'a facut blog....ca stia ca nu il pune Zoso in blogroll...:))',0,'1','Opera/9.10 (Windows NT 5.1; U; en)','',0,0),(6704,693,'Emaginatoru','e_magist@yahoo.com','','79.113.142.89','2007-10-13 15:11:52','2007-10-13 13:11:52','Deci parerea mia e ca daca vrei sa vez pesti si apa mai meri o tzara pan\' la Tarnitza si de vrei sa cumperi ceva nu ti sa merita sa meri pana la Polus ca preturile e tot alea de nu mai mari ca la ceilalti (nu dau nume cum ar fi: Cora  sau Kaufland). Magazinele cu fite is tat alea de la Sora cu aceeasi marfa/preturi.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(7752,751,'Groparu','groparu_ro@gmail.ro','http://www.groparu.ro','82.77.126.254','2007-11-06 16:21:16','2007-11-06 14:21:16','@ Warsongu: deci ba, ba da, da\' cica prin America de Sud (recte Chile) astia folosesc in sensu de jmeker, pulash, pulica, d-alea.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7597,749,'Cala','acalarasu@gmail.com','http://adriancalarasu.wordpress.com/','89.32.19.126','2007-10-31 01:04:16','2007-10-30 23:04:16','moooaaaa, deci tu stii ce-ai pierdut?!?!\r\n:))',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) )','',0,0),(8902,817,'Usim','mihaimitan@gmail.com','','87.237.108.33','2007-11-27 18:02:27','2007-11-27 16:02:27','Si Abjectu dac-ar scrie si el mai des ar scrie mai bine.......',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; .NET CLR 2.0.50727)','',0,0),(7773,689,'The Reaper','','','82.77.185.142','2007-11-07 01:23:15','2007-11-06 23:23:15','Me Sexy!!!',0,'1','Opera/9.21 (Windows NT 5.1; U; en)','',0,0),(7774,760,'clarvazatoarea','unclientfericit@gmail.com','','89.84.149.111','2007-11-07 02:38:05','2007-11-07 00:38:05','Apai no draga gropare, io pe kine te si vad pe la 65-70 de ai, asa, cu musteti si ochi straluciosi, si libidinos, libidinos la greu.\r\nAcu nu te supara, no.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8977,818,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','82.77.126.148','2007-11-29 11:39:35','2007-11-29 09:39:35','eu fiind fana Ozzy de pe la 6 ani, stiu destule despre el! arunca cu apa, si de muscat capete, musca doar din liliecii de cauciuce. asta pana unu din public i-a aruncat unu adevarat de a stat bietu ozzy in spital si-a facut injectii in buric...\r\nfaza cu porumbelul e veche, era tanar, rebel, mama i\'m comming hooome... dar s-a lecuit, credeti-ma pe cuvant! si nu imi place sa mi se vorbeasca idolii de rau! na! :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.10) Gecko/20071115 Firefox/2.0.0.10','',0,0),(7776,760,'WhiteWolf','contact@white-wolf.ro','http://white-wolf.ro','89.39.82.208','2007-11-07 04:02:36','2007-11-07 02:02:36','Daca-i cu si din Sibiu n-are cum fi decat bine si de foarte bine.\r\nSfarsitul povestii. :P\r\n\r\np.s; normal ca s-ar fi incalecat pe o shea sa ne zica <b>toata</b> povestea ashea -pana la urma- numai ca ,sa fim seriosi, de cate ori se intampla sa iti acorde bunoacele (douÃ£) incredere intr-o viata de barbat ?\r\nZau, cred ca merita circumstante de alea de atenueaza :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8978,830,'macabroo','raduccc@yahoo.com','http://rezistenta.blogspot.com','80.96.196.2','2007-11-29 11:43:11','2007-11-29 09:43:11','Pot sa le pedepseasca eventual bagandu-le intr-un acvariu. Mai putin pe Covaci, care e gras si sparge orice acvariu.',0,'1','Opera/9.23 (Windows NT 5.1; U; en)','',0,0),(7567,746,'pliscu','pliscu@gmail.com','http://pliscu.blogspot.com','89.137.100.118','2007-10-30 12:06:57','2007-10-30 10:06:57','soferul <a href=\"http://www.groparu.ro/?p=712\" rel=\"nofollow\">BMW-ului</a>?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7568,746,'VIP','ps@yahoo.com','http://vipuri.blogspot.com','213.157.188.71','2007-10-30 13:25:37','2007-10-30 11:25:37','nu ar trebui sa puta asa tare daca nu i-ai purtat de mult...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7569,746,'ss','criss_team@yahoo.com','','81.196.150.198','2007-10-30 13:54:46','2007-10-30 11:54:46','cu cat is mai imputiti adidasii cu atata dai goluri mai cacacioase.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7','',0,0),(7596,740,'Manticore','contact@vizeamerica.com','http://www.adspedia.ro','89.137.101.199','2007-10-31 00:51:10','2007-10-30 22:51:10','Apropos de Banca Transilvania, am pus pe Trilulilu un screenshot care spune mult despre calitatea serviciilor lor, si nu ma refer doar la site :) &gt;&gt; http://www.trilulilu.ro/tinuzzo/e129f9ee89f44b',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7571,746,'gogu von gogu','','','80.96.3.82','2007-10-30 15:57:57','2007-10-30 13:57:57','picioare care sunt infipte in acelasi loc',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(7572,748,'','','','212.93.140.77','2007-10-30 16:54:53','2007-10-30 14:54:53','parerea mea ...ca se va inlocui statuia calului cu statuia Bocului...si vor ramane coaiele de la cal',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; InfoPath.2)','',0,0),(7573,746,'Sorinelu\'','sorinelm@gmail.com','','86.122.9.37','2007-10-30 16:57:35','2007-10-30 14:57:35','o sa am onoarea sa-i dau la picioare la Groparu\' :D',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) )','',0,0),(7595,749,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2007-10-31 00:08:26','2007-10-30 22:08:26','Ce sa mai zic io de reputatia mea de blogger, ca tocmai mi-am pierdut sansa de a fi vreodata inclus in blogrollul lui Zoso?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7086,715,'Combo','bogdan.coman@gmail.com','http://bogdancoman.blogspot.com','195.60.77.9','2007-10-23 15:20:14','2007-10-23 13:20:14','Vezi ca aia care nu sunt Y sunt X nu XX :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12','',0,0),(7819,770,'WhiteWolf','contact@white-wolf.ro','http://white-wolf.ro','89.39.81.120','2007-11-08 17:53:46','2007-11-08 15:53:46','Ei, da; intr-adevar. :) Asta da\r\nChiar cÃ£ ....',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(6711,693,'10mbc','alin.banc@gmail.com','','89.137.5.71','2007-10-13 18:15:14','2007-10-13 16:15:14','Da, dar nimic nu se compara cu \"shopping cat vezi cu ochii\" la propriu. Trebuia sa fie o aberatie de asta si aici. Btw, am auzit ca o sa fie si un cinema. Niiice. Unul in plus in CJ. Motive sa merg la cora si nu la polus? 1. salvez un litru de motorina pe fiecare drum. 2. nu trebuie sa alerg pe jos 2 km ca sa imi gasesc pastele alea cu ou. 3. pentru ca s-a deschis polus nu mai e asa aglomerat :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(7157,715,'zau asa!','totmea@yahoo.com','','89.123.124.188','2007-10-24 09:13:45','2007-10-24 07:13:45','ce bine semanai cu soru-ta!!!!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(7160,715,'parsiimpar','lummi31@gmail.com','http://parsiimpar.wordpress.com/','81.196.54.24','2007-10-24 09:48:24','2007-10-24 07:48:24','niciodata,\r\nnorocul vostru  ca s-a inventat automobilul:)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(8877,818,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-11-27 12:52:18','2007-11-27 10:52:18','Shafu meu - care si el e un mare domn, atata numa ca nu arunca cu apa dupa noi, numa\' cu mailuri de kko - o fost mult mai plastic in incercarea de a-mi demonstra aceeasi chestie. Mi-o zis: \"10% din salar pe anu 2008!\"\r\n\r\nAsa ca i-am banat IP-ul ca sa nu ma poata verifica ce scriu, cel putin o perioada, pana ii trece vinisoarele alea rosii din ochi, de la furie.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.10) Gecko/20071115 Firefox/2.0.0.10','',0,0),(8834,813,'Usim','mihaimitan@gmail.com','','87.237.108.33','2007-11-26 22:48:44','2007-11-26 20:48:44','Miruna, ea: Pai parca ziceai ca n-ai votat? De unde stii c-am intrebat: \"Io cu cine votez? hic\" Au iereai in Comisie?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; .NET CLR 2.0.50727)','',0,0),(8835,807,'IepurasulAtomic','praetorian21uk@yahoo.com','','192.100.124.219','2007-11-26 22:53:49','2007-11-26 20:53:49','Asha-i? Mersi Usim, numa\' tu ai observat. Ca Groparele e prea ocupat cu alegerile europene....huoooo! Cu berea mea cum ramane, Gropare? :) Pace p\'afara!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(8616,800,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-11-23 09:14:45','2007-11-23 07:14:45','@ .marius: upstairs, just like wireless, is fun!\r\n\r\n@ Lupulainu: mah, adevaru ca atata de cald si de bine ii inauntru, ca mai ca nu-mi mai vine sa ies vreodata!!!\r\n\r\n@ Miruna: suntem romani, singuru meu regret e ca nu avem o tzava sa o tÃ¢rÃ¢m prin Ã®ntreprindere...\r\n\r\n@ CÄƒlÄƒ: u cowardly dog, it\'s not about humping LEGS!!! it\'s about humping BETWEEN THE LEGS!!! (what do they teach you in those schools, I wonder!)\r\n\r\n@ Noi, Miruna: this kinda reminds me of the time I used to be a... uhm... blogger?!?!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8876,813,'manole','redtailanda@yahoo.com','http://www.mesterulmanole.wordpress.com','81.181.92.157','2007-11-27 12:46:09','2007-11-27 10:46:09','pentru asta te-am votat.\r\nsi eu visez la o Romanie in care, la vot, te pune sa semnezi dupa ce iti da buletinul si tu dai stampila inapoi ...',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows 98)','',0,0),(7088,715,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-10-23 15:25:53','2007-10-23 13:25:53','@ Combo: mah, sincer as fi pus XXX, da\' jmekerii aia de la bio-something deja or pus numa unu :| (rectificai)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(8808,813,'WarSongu','eternaldawnlord@yahoo.com','http://www.warsongu.wordpress.com','193.32.3.83','2007-11-26 13:49:28','2007-11-26 11:49:28','io nu visez la alta romanie. nu visez la nici o tara. visez insa la intreaga lume. visez la ziua in care omu o sa inteleaga ca nu detine pamantul. ca nici o bucatice de pamant nu e a lui, a familiei lui, a tarii lui. astea sunt concepte arbitrare, un blestem numit babel pe care omul, in nevolnicia lui l\'a ridicat la rang de virtute, cultura, onoare. nu copii, voi nu aveti, si nu o sa aveti niciodata pamantul, si milioanele de oameni care si\'au varsat sangele pentru un petec de pamant au fost prosti, nu eroi. si au sfarsit devenind pamant. pamantul ne are pe noi, si nu invers. asa a fost in negura istoriei, pe cand omul inca mai stia sa vorbeasca pamantului si sa\'l asculte, si asa va fi sa fie din nou, sau vom pieri. pentru ca daca nu, pamantul se va scutura de noi ca de niste paduchi puturosi. deci visez la ziua in care omul isi va aduce aminte de acest adevar. sau o fi nomadismul din sange care\'mi sopteste asta?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; FunWebProducts; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(7156,711,'PhenoBarbieDoll','poisongirl94@yahoo.com','http://360.yahoo.com/poisongirl94','193.230.230.101','2007-10-24 08:36:00','2007-10-24 06:36:00','io insami mi-s mediafaxa, da, sa traiti :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(8862,815,'macabroo','raduccc@yahoo.com','http://rezistenta.blogspot.com','80.96.196.2','2007-11-27 09:34:54','2007-11-27 07:34:54','Si acum ca ati supus bestia ce aveti sa ne declarati?',0,'1','Opera/9.23 (Windows NT 5.1; U; en)','',0,0),(8867,815,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-11-27 10:19:10','2007-11-27 08:19:10','@ macabroo: deci cu zidari e simplu. Data viitoare am sa ma leg de calugarii Shaolin din trolee. Sa vedem care-i mai tare!!! Ca pe Ninja si Batman am inteles ca deja-i bat politaii de le suna apa-n cap.\r\n\r\n@ punctmarius: \"Danutz Ursus, at your service!\" :D (numa clujenii stie bancu aiesta!)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8717,807,'Helpthegrass','','','81.181.92.133','2007-11-24 13:30:44','2007-11-24 11:30:44','Se pare ca noi ideei aveam cam multe, ce mai, zburdam veseli pe imasi. Daca mai statea vreo doua zile sigur descopeream si OZN uri prin poza.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.5) Gecko/20041107 Firefox/1.0','',0,0),(6718,693,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','85.186.77.129','2007-10-13 21:08:21','2007-10-13 19:08:21','cinema o sa fie si la iulius. sunt destule cinema-uri cat sa nu te duci atata drum pana la polus pentru un film pe care poti la fel de bine sa-l vezi in centru. sunt zvonuri (deh, merg des cu taxiul, si lumea vorbeste) ca in iulius vor fi 10 cinemauri, din alea tip americane, mici si primitoare. zic ca ai de unde alege. eu nu m-as duce pana la polus pentru un film, cafea pantofi si ce mai vand ei acolo.',0,'1','Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.0.12) Gecko/20070731 Ubuntu/dapper-security Firefox/1.5.0.12','',0,0),(6719,697,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','85.186.77.129','2007-10-13 21:09:17','2007-10-13 19:09:17','bai, sa-ti fie de bine si sa nu-tz steie in gatlej!',0,'1','Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.0.12) Gecko/20070731 Ubuntu/dapper-security Firefox/1.5.0.12','',0,0),(6916,704,'adi','acalarasu@gmail.com','http://adriancalarasu.wordpress.com','89.32.19.126','2007-10-20 00:43:01','2007-10-19 22:43:01','da, sa nu recunosti nimica in istanta! (asa face oltenii de obicei, deci poti sa faci si tu cel putin pe jumanate)\r\nsi daca te scapi cunva, adu-ti aminte ca ai dreptu\' la un singur telefon!\r\n\r\ndeci studiaza temeinic ofertele de pe piata GSM, poate de data asta nemeresti unul (si) mai destept decat tine, ha ha.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(8766,812,'CAESARUS','caesarus@adresafalsa.ro','','79.113.89.30','2007-11-25 21:00:54','2007-11-25 19:00:54','ma da deshtept esti!....sa te tzuce tata!',0,'1','Mozilla/5.0 (Macintosh; U; Intel Mac OS X; en) AppleWebKit/419.3 (KHTML, like Gecko) Safari/419.3','',0,0),(6918,704,'evilpenguin','evilpenguin666@gmail.com','','81.181.214.176','2007-10-20 01:02:57','2007-10-19 23:02:57','Super tare. Recomand www.hackthissite.org (nu, nu-i site-ul meu, doar imi place si am user si m-a distrat foarte tare odata)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6721,693,'natty','natty2277@yahoo.com','','86.106.49.165','2007-10-13 21:23:00','2007-10-13 19:23:00','da\' zara si mango nu o sa fie in iulius lilith....\r\nmie imi place polus dar sa nu mai fie asa aglomerat... dar vad ca pe aici sunr multi carora nu le place asa ca sanse sunt sa se mai aeriseasca locul:)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(7161,717,'ss','criss_team@yahoo.com','','81.196.150.198','2007-10-24 11:49:05','2007-10-24 09:49:05','sa ridicam armele, si la pedepsit studentese!\r\nle luam prin invaluire? :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7','',0,0),(7859,758,'Groparu','groparu.ro@gmail.com','http://','89.137.109.142','2007-11-09 23:30:25','2007-11-09 21:30:25','Deci cum dreq sa imi cat io dujmani pintre proprii mei cetitori? Care is mult mai puÅ£ini decÃ¢t credeam io cÄƒ ii aduce geniul meu carpatin?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,2),(7126,715,'niciodata','','http://niciodata.wordpress.com','83.103.230.13','2007-10-23 22:25:15','2007-10-23 20:25:15','incepand din spermatozoid speranta de viata a femeilor e mai mare decat a barbatilor... nu e corect dar, vorba bancului, recuperam la parcarea cu spatele. Si definitely si la gararea laterala!',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; SLCC1; .NET CLR 2.0.50727; Media Center PC 5.0; .NET CLR 3.0.04506)','',0,0),(7082,711,'vizionarul','alinmiron_19@yahoo.com','http://www.vizionarul.wordpress.com','83.103.154.202','2007-10-23 14:52:35','2007-10-23 12:52:35','cand a facut academia navala era doar un putzoi... pentru cei din anii mai mari.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(6723,693,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','85.186.77.129','2007-10-13 21:42:27','2007-10-13 19:42:27','zara si mango ce-s? magazine de haine? sau bijuterii? chiar nu stiu :\"&gt; \r\noricum, haine nu o sa imi iau de la magazine de fite, ca nu sunt snoaba. prefer sa ma duc in central daca vreau sa ma imbrac. bijuterii, in afara de cerceii mostenire de la bunica, nu port. cosmeticalele nu le suport. asa ca nu vad motivul pntru care m-as duce in polus. altii nu au decat sa mearga, nu-i opreste nimeni. e o chestie de gustibus ;)',0,'1','Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.0.12) Gecko/20070731 Ubuntu/dapper-security Firefox/1.5.0.12','',0,0),(8301,57,'mutu','vick_redhound@YAHOO.COM','','89.43.11.130','2007-11-18 17:35:46','2007-11-18 15:35:46','ha ha\r\n\r\nGrea e viata\r\nSi pustie\r\nCand te caci\r\nSi n-ai hartie',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 2.0.50727; .NET CLR 1.1.4322)','',0,0),(7079,711,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-10-23 14:14:45','2007-10-23 12:14:45','@ Pheno: exista doo tipuri de femei sexy pe lumea asta: cele care e sashii si cele care nu se sashii. Parerea mea.\r\n\r\n@ Hammer: Mah, oare presedintele o facut academia navala cand era baietel? Hmmm...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7606,748,'Botache','nasturei_verzi@yahoo.com','http://www.nasturei.wordpress.com','82.77.126.148','2007-10-31 11:29:15','2007-10-31 09:29:15','Sa nu micsoreze sau sa modifice in vreun fel coitele calului! Alea erau baza. De acuma inainte, cum  o sa le zic la oameni punctul de intalnire? La Matei in loc de La coite? Pfffffft! Bataie de joc!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.0; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(6872,706,'Miruna','mirunavasilescu@yahoo.com','http://potsafacsiasaceva.blogspot.com/','86.106.59.163','2007-10-18 22:12:36','2007-10-18 20:12:36','Eu cred ca e o schema a nevesti-sii si ca el habar n-are.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(9167,841,'Laura','mars1953@web.de','','84.160.110.155','2007-12-04 00:13:05','2007-12-03 22:13:05','Deci te lasi de fumat ... dupa ce citesc pe-aici probabil o sa intri in groapa complet sanatos si potent de numa\' ?! Oau!',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(8026,786,'Usim','mihaimitan@gmail.com','','86.121.184.193','2007-11-15 03:16:47','2007-11-15 01:16:47','D\'aia au nemtii banci in berarii ca sa nu rupa deste de Gropar.\r\n\r\nPolicele mainii mele stangi empatizeaza cu destul groparesc, fiind grav avariat, reparat la urgente cu (8) opt suturi, dupa ce dasteptul de stapanesu\' (adica Usim) o incercat sa desfaca, nu o nuca, ci o aluna de padure in coaja, cu un briceag. Ca de ciocan ii fu lene sa se caute.\r\n\r\nDaca dreapta nu ar fi fost ocupata sa tina de briceag, sa fi vazut atunce abstinenta la Usim.',0,'1','Opera/9.10 (Windows NT 5.1; U; en)','',0,0),(8825,813,'Laura','mars1953@web.de','','84.160.94.140','2007-11-26 20:19:53','2007-11-26 18:19:53','Eu visez la o Romanie in care sa pot sa-mi permit sa mananc sunca dupa o zi nenorocita de munca.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(6871,700,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2007-10-18 22:09:42','2007-10-18 20:09:42','@ abstinent: io am vazut si curci bete, mult mai ridicule decat neshte puicutze. Io am vazut asta cu ochii astia care sunt de-o parte si de cealalta a nasului, si ale caror pleopi erau larg deschise, desi ma pisham pe mine de ras. PS: Totusi, mi se pare ca o femeie beata are asa, o doza de senzualitate care nu o paraseste. Stii de ce? Finca in clipele alea le par si eu atragator! :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(8832,816,'macabroo','raduccc@yahoo.com','http://rezistenta.blogspot.com','82.76.52.94','2007-11-26 21:38:36','2007-11-26 19:38:36','da... cu tigai ce are?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8833,813,'eu,Miruna','mirunavasilescu@yahoo.com','http://potsafacsiasaceva.blogspot.com/','86.106.59.163','2007-11-26 21:45:14','2007-11-26 19:45:14','In lumina maximelor evenimente de ieri, eu doresc o tara in care oamenii care vin la vot sa nu intrebe comisia \"eu ce trebuie sa votez?\", sa stie de ce au venit acolo, sa stie sa scrie si sa vorbesca, ca daca nu, nu pupa vot, pastele mamii ei de treaba!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(6932,712,'nenea cosmos','domnu_cosmos@yahoo.com','http://nenea.wordpress.com/','92.80.24.97','2007-10-20 15:29:03','2007-10-20 13:29:03','deja logica ta a invins-0 pe logica mea, adica nu pot sa spun decit:\r\n\r\nies, mastÄƒr...',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(6729,697,'oedip','oedip74@gmail.com','http://oedip.blogspot.com','139.18.194.141','2007-10-14 00:21:08','2007-10-13 22:21:08','poi da si pe mine nu m-ai chemat :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6924,712,'Adi Calarasu','acalarasu@gmail.com','http://adriancalarasu.wordpress.com/','89.32.19.126','2007-10-20 08:29:18','2007-10-20 06:29:18','cand ne vedem visele implinindu-se sub ochii nostri nedumeriti, umezi SI MARI!\r\n:))',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(7762,760,'Usim','mihaimitan@gmail.com','','87.237.108.33','2007-11-06 18:33:49','2007-11-06 16:33:49','Cuvintele d-voastra ma doare si ma bucura. Si, si ce s-a mai intamplat? De ce  te-ai oprit din povestit?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; .NET CLR 2.0.50727)','',0,0),(7763,760,'nana','razornana@yahoo.com','','78.96.156.60','2007-11-06 18:42:09','2007-11-06 16:42:09','da..asteptam continuarea... nu se poate sa nu mai fie ceva :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; hu; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(7764,760,'Usim','mihaimitan@gmail.com','','87.237.108.33','2007-11-06 18:43:50','2007-11-06 16:43:50','Tocmai cand se complica povestea si totul era mai interesant.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; .NET CLR 2.0.50727)','',0,0),(8901,815,'Usim','mihaimitan@gmail.com','','87.237.108.33','2007-11-27 17:49:40','2007-11-27 15:49:40','PhenoBarbieDoll esti pheno. Tare l-ai mai apostrofat. De unde ai scos-o?\r\n\r\nSar\'na!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; .NET CLR 2.0.50727)','',0,0),(6926,707,'Adi Calarasu','acalarasu@gmail.com','http://adriancalarasu.wordpress.com/','89.32.19.126','2007-10-20 08:39:34','2007-10-20 06:39:34','deci in principiu tresa intrebi catitorul de unde ii, si daca zice ca-i sudist ii mai zici odata.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(6927,707,'Adi Calarasu','acalarasu@gmail.com','http://adriancalarasu.wordpress.com/','89.32.19.126','2007-10-20 08:43:47','2007-10-20 06:43:47','cetitorul, zic, si daca e de exemplu din Calarasi, ii explici :|\r\nhaide ma, ca m-am prins :))',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(6928,706,'Adi Calarasu','acalarasu@gmail.com','http://adriancalarasu.wordpress.com/','89.32.19.126','2007-10-20 08:46:34','2007-10-20 06:46:34','haidi breee, si francejii are bombe dinalea?!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(6929,712,'nenea cosmos','domnu_cosmos@yahoo.com','http://www.nenea.wordpress.com','193.231.82.119','2007-10-20 09:44:26','2007-10-20 07:44:26','deci bmw are 5 stele ncap la testu de pietoni.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 2.0.50727)','',0,0),(6930,712,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2007-10-20 10:30:30','2007-10-20 08:30:30','Sau poate tipesa avea 5 stele nbody la testu de coliziune cu o masina nemtzasca...?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6910,709,'Miruna','mirunavasilescu@yahoo.com','http://potsafacsiasaceva.blogspot.com/','86.106.59.163','2007-10-19 19:59:46','2007-10-19 17:59:46','Exista sitcomuri porno??? Nu ma-nvata nimic la facultatea aia...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(6911,704,'DÃ£nilÃ£','','','84.232.145.230','2007-10-19 21:40:59','2007-10-19 19:40:59','PromiÅ£Äƒtor Ã®nceput... hecÄƒre! =))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.4','',0,0),(6912,704,'zgura','','','79.113.128.254','2007-10-19 21:52:58','2007-10-19 19:52:58','Ai grija sa nu te inchida. Nu recunosti nimic, niciodata. Ne-am inteles?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(7084,715,'ss','criss_team@yahoo.com','','81.196.150.198','2007-10-23 15:15:26','2007-10-23 13:15:26','curea lata si bratzare, subtirel cu capu\' mare.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7','',0,0),(6868,702,'cucu','pupaza@mail.com','','62.224.211.78','2007-10-18 20:25:16','2007-10-18 18:25:16','..deci expresia aia cu \"nu fut3 buha\" era la propriu ? *shock*',0,'1','Mozilla/5.0 (Macintosh; U; PPC Mac OS X Mach-O; de; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(7464,737,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','85.186.77.129','2007-10-28 20:23:55','2007-10-28 18:23:55','cu rusine in suflet si bujori in obrajori marturiesc ca nu stiu unde e muzeul de istorie... deci unde e muzeul de istorie? :\"&gt;',0,'1','Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.0.12) Gecko/20070731 Ubuntu/dapper-security Firefox/1.5.0.12','',0,0),(7465,738,'cocofifi','coco@mail.com','','62.224.203.4','2007-10-28 20:25:02','2007-10-28 18:25:02','..si se chiuie \"cristos o-nviet\" ?',0,'1','Mozilla/5.0 (Macintosh; U; PPC Mac OS X Mach-O; de; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(6885,702,'baghy','baghy83@lycos.it','http://baghy.info/','78.12.9.34','2007-10-19 01:14:36','2007-10-18 23:14:36',':))) cica sa-i taie gatul sa simta mai multe.incredibil',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(8802,813,'catalin','catalin_heghes@yahoo.com','http://sec.ablog.ro','82.79.27.13','2007-11-26 12:46:04','2007-11-26 10:46:04','io visez la o romanie cum e asta de acum. ca mie imi place, da? daca nu l-as vedea pe becali la teveu, iar pe pe strada pe cioflingarii ai de umbla cu telefoanele in care urla manele m-as plictisi. s-apoi daca as avea cu cine sa votez la fel la fiecare scrutin si as fi convins ca fac ceea ce trebuie sa fac iarasi m-as plictisi. ar fi ca si cum as vota o condica de prezenta la intrarea in fabrica. deci... mama masii... mie imi place romania asa cum e. ceea ce nu inseamna ca tre sa dati cu pietre-n mine :P',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(8815,814,'koyrosh','a@a.com','','82.77.126.254','2007-11-26 16:53:18','2007-11-26 14:53:18','imi aduc aminte de o discutie intre doo coledge: am visat-o pe andreea. da? si ce mai face?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(8801,813,'Cristian Ungur','cristian.ungur@utopium.ro','http://cristianungur.blogspot.com','85.186.103.54','2007-11-26 12:00:30','2007-11-26 10:00:30','Eu visez la o Romanie in care cuvintele \"clasa\" si \"politica\" sa nu se constituie intr-o contradictie in termeni. Dupa ce vad doua trei sire de spinare umbland prin Parlament, ma duc si le votez. k?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(6887,707,'Andrei Crivat','andrei@andreicrivat.ro','http://www.andreicrivat.ro','89.137.83.141','2007-10-19 08:19:16','2007-10-19 06:19:16','nu, nu, deci Miruna se inseala DRAMATIC. deci io nu stiam bancul, da ? deci pana nu mi l-ai spus. Deci bine ca l-ai pus. ioi.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; SLCC1; .NET CLR 2.0.50727; Media Center PC 5.0; .NET CLR 3.0.04506)','',0,0),(7753,761,'Groparu','groparu_ro@gmail.ro','http://www.groparu.ro','82.77.126.254','2007-11-06 16:22:12','2007-11-06 14:22:12','@ VIP: mo, cica e mult mai legal asa in orice tzara. Am mentionat oare ca vreau sa fac asta pe insula mea? Si pe insula mea te miri ce reguli voi mai baga!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7302,735,'Geniul','victor@ciutacu.ro','http://www.ciutacu.ro','81.12.224.196','2007-10-25 23:47:07','2007-10-25 21:47:07','Nu-mi spune ca pana si tu te pisi! S-a mai dus dracu\' o bunaciune de mit',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 2.0.50727; InfoPath.1)','',0,0),(6883,698,'Nascut din spermatozoizi campioni &raquo; Blog Archive &raquo; Deci, pentru ca m-am facut ne-nteles','','http://www.groparu.ro/?p=707','82.103.137.253','2007-10-19 00:48:43','2007-10-18 22:48:43','[...] din posturile mele anterioare, intitulat Tilisca, unde se deschide berea cu brisca, am ales acest titlu deoarece faceam o referire delicata (ca un funigel de delicata) la un banc [...]',0,'1','Incutio XML-RPC -- WordPress/2.1.2','pingback',0,0),(6884,707,'Miruna','mirunavasilescu@yahoo.com','http://potsafacsiasaceva.blogspot.com/','86.106.59.163','2007-10-19 00:55:09','2007-10-18 22:55:09','Hai ca toata lumea stie bancu\' cu brisca!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(7262,717,'Victor Ciutacu','victor@ciutacu.ro','http://www.ciutacu.ro','82.76.75.160','2007-10-25 14:22:50','2007-10-25 12:22:50','@gropy: eu n-am simpatii, ci doar antipatii; mai mari sau, dupa caz, mai mici:)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(7556,742,'macabroo','raduccc@yahoo.com','','80.96.196.2','2007-10-30 10:50:39','2007-10-30 08:50:39','Observ ca devine un trend! Fa un slide:D Uite melodia http://www.trilulilu.ro/tuPoetic/aedc1f7d9150c3',0,'1','Opera/9.23 (Windows NT 5.1; U; en)','',0,0),(7557,742,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','82.77.126.148','2007-10-30 10:54:51','2007-10-30 08:54:51','bai... aj vrea eu sa am banii doamnei columbeanu, da nu-i am! si tat nu mi-i greu!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7468,737,'WhiteWolf','laskmerge@gmail.com','http://white-wolf.ro','89.39.82.18','2007-10-28 21:13:52','2007-10-28 19:13:52','@portarul, meri mah, la crajma la care o fo\' si Groparu .Ii mult mai sanatos decat sa iti defilezi prostia pe aici si inca cu girofaru\' aprins.\r\nBlogu\' ala de care zici (cu vreo 3 zile vechime) si care chiar ie facut de meseriasi o sa ajunga sa-si faca reclama si singur cat se prinde \"blogosfera\" ca face vorbire despre albirea vizelor la americanii aia din S.U.A. Plus ca tanti de il are in proprietate nu-i Simona Senzual; chiar stie ce vrea \r\nGropare, nu te lasa amajit, ia si te linijteste. Nu dau review-uri mascate. :P\r\nAm vrut numa sa te pup pentru <b>Io nush ce formatie e Iris asta, ca niciodata nu or fost in stare sa cante playback!</b> si <b>Smurzi</b>\r\nFuarte tare, frate  :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7482,740,'July','jullya24@yahoo.com','','83.103.179.55','2007-10-29 17:05:52','2007-10-29 15:05:52','deci nu e corect sa te taca pe tine tantalau....cata lipsa de consideratie!:)....erai doar cu capu un nori...sau..?!...tantalu adevarat e unu are si-a uitat cardu in bancomat si avea si codu pin scrijelit pe el(card)....no aluia cum trebe sa-i mai zica atunci....?',0,'1','Opera/9.10 (Windows NT 5.1; U; en)','',0,0),(6866,703,'laurie','','','69.131.172.203','2007-10-18 20:16:58','2007-10-18 18:16:58','speaking of stupid :\r\nhttp://www.fahruz.org/Engrish/slides/A%20favorite%20goods%20make%20a%20girl\'s%20heart%20beautifully.html',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6867,700,'abstinent','drinkmore@mail.com','','62.224.211.78','2007-10-18 20:17:01','2007-10-18 18:17:01','rÃ¢deti voi si glumiti, domnilor, dar cert este ca o priveliste mai jalnica decÃ¢t un barbat beat ofera doar o femeie beata. nu e cool deloc',0,'1','Mozilla/5.0 (Macintosh; U; PPC Mac OS X Mach-O; de; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(7111,715,'WhiteWolf','laskmerge@gmail.com','','89.39.82.123','2007-10-23 19:08:49','2007-10-23 17:08:49','Ma simt mult mai (corect) informat, acum. :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7267,720,'Basty','basty@canvas.ro','http://basty.wordpress.ro','82.77.126.21','2007-10-25 15:30:51','2007-10-25 13:30:51','Bag seama ca si in salina te vede Jesus. Nu mai poate omul sa se ascunda niciunde ca sa puna de-o preacurvie scurta, la naiba !',0,'1','Mozilla/5.0 (Macintosh; U; Intel Mac OS X; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(8914,820,'nenea cosmos','domnu_cosmos@yahoo.com','http://www.nenea.wordpress.com','92.80.32.143','2007-11-28 00:38:29','2007-11-27 22:38:29','http://nenea.wordpress.com/jurnalul-unui-closet/',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(8866,817,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-11-27 10:17:02','2007-11-27 08:17:02','@ mirmen: eu sunt vocea celui care striga in pustie... disperarea, stimata doamna, pura disperare! Ca Dariusica asta al dvs. iar ia toate premiile, si ne lasa pe noi fara macar o ascutitoare sau un breloc cu PetromV!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8821,813,'nenea cosmos','domnu_cosmos@yahoo.com','http://www.nenea.wordpress.com','92.80.4.41','2007-11-26 18:38:26','2007-11-26 16:38:26','deci eu visez la o Romanie Cosmica!',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(7591,748,'macabroo','raduccc@yahoo.com','http://rezistenta.blogspot.com','82.76.52.94','2007-10-30 22:54:53','2007-10-30 20:54:53','O sa faca calul ponei!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7592,748,'laurie','','','69.131.172.203','2007-10-30 23:05:14','2007-10-30 21:05:14','ni ce multi suntem, nea gropare :) cheama studentele sa formam fan clubul',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7593,748,'Cala','acalarasu@gmail.com','http://adriancalarasu.wordpress.com/','89.32.19.126','2007-10-30 23:49:14','2007-10-30 21:49:14','Sh-am uitat sa zic: mama, cat am baut intr-o seara langa statuia lui Matei asta al vostru, care nu stiam eu atunci cine a fost pt. ca eram pushti pe atunci - spre deosebire de acum cand tot nu stiu cine a fost  - cat am baut, zic! Am baut cu roacherii de nici Matei nu mai stia exact cine a fost, cred.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) )','',0,0),(6890,707,'conia','','','193.226.17.210','2007-10-19 10:09:58','2007-10-19 08:09:58','si pe Valea Sebesului e uzual acest banc...',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.2; SV1; .NET CLR 1.1.4322; .NET CLR 3.0.04506.30)','',0,0),(6891,708,'sabina','','','81.12.163.178','2007-10-19 11:12:57','2007-10-19 09:12:57','scarbos...',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(8683,807,'irina','irinamimoza@yahoo.com','','86.121.22.124','2007-11-23 21:47:56','2007-11-23 19:47:56','io ma gandesC Ca poza aia de ai pus-o tu acolo reprezinta o idilica livada de fructe din frumoasa europa (aici sunt mere, dar pot fi pere, portocale, capsuni, caise etc.), adica unde se duc romanii sa presteze despre munca. ca sa ma explic, noi o sa votam duminica pe europarlamentarii aia care o sa ne usureze drumu\' catre mult visatele livezi, unde putem sa ne punem noi, romanii, in valoare multitudinea de calitati cu care suntem inzestrati. \r\n\r\np.s: io nu beau alcool, ca-mi deranjeaza simtul olfactiv, si inainte, dar si dupa ingurgitarea lui, dar pt un semi-zeu as putea sa fac o exceptie.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(6893,708,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','82.77.126.148','2007-10-19 11:53:29','2007-10-19 09:53:29','criminal cu sange rece ce esti! trebea sa-i dai o bere si dupa aia s-o omori!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6894,708,'vizionarul','alinmiron_19@yahoo.com','http://www.vizionarul.wordpress.com','83.103.154.202','2007-10-19 12:54:46','2007-10-19 10:54:46','ucigas insectofob... ma gropare... trebuia sa-ti faci mila de ea si s-o scoti afara in frig,  iera mai umana treaba... macar murea de frig... iti ramanea pe constiinta... pardon pe oglinda.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(6895,708,'vizionarul','alinmiron_19@yahoo.com','http://www.vizionarul.wordpress.com','83.103.154.202','2007-10-19 12:57:20','2007-10-19 10:57:20','erata: ...  Macar nu iti ramanea pe constiintaâ€¦ pardon pe oglinda.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(8659,803,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-11-23 17:00:13','2007-11-23 15:00:13','Deci ase as vrea sa scriu acilea neshte chestiiiiiiiii referitor la Amsterdam...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(6906,704,'marius sescu','marius.sescu@yahoo.com','http://www.mariussescu.com/','79.112.84.65','2007-10-19 19:29:07','2007-10-19 17:29:07','Bravo, groparu apare...fara numar!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6907,704,'tetabeta','alfa@omega.com','','62.224.216.193','2007-10-19 19:46:31','2007-10-19 17:46:31','vezi, de aia nu am eu incredere in versiunile beta.\r\nvine orice gropar de colea la hackuit si-i mai si iese :p',0,'1','Mozilla/5.0 (Macintosh; U; PPC Mac OS X Mach-O; de; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6900,709,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','82.77.126.148','2007-10-19 15:24:56','2007-10-19 13:24:56','raule, nu asa te comporti cu un coleg de servici! :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6901,709,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-10-19 16:24:35','2007-10-19 14:24:35','Hmmm... io am dat filmu inapoi, si am vazut ca se poate! Da\' el cand zice de maica-mea, care de fapt e-o doamna, cum e?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6908,704,'tetabeta','alfa@omega.com','','62.224.216.193','2007-10-19 19:49:00','2007-10-19 17:49:00','creca ti-a hackuit si tie cineva blogu, ca nu mere bagatu de comentarii.\r\ndeci, ziceam ca de aia n-am io incredere in nici o versiune beta.\r\nvine orice gropar de colea si ti-o hackuieste si-i mai si iese :p',0,'1','Mozilla/5.0 (Macintosh; U; PPC Mac OS X Mach-O; de; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6898,708,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-10-19 14:13:50','2007-10-19 12:13:50','@ lilith: io am intrebat-o care e ultima ei dorintza, si mi-a raspuns, ca Goethe: LUMINA, MAI MULTA LUMINA!!! I-am indeplinit dorintza.\r\n\r\n@ Vizionarul: si-o lasat o musca sanii striviti de oglinda mea aburita! Sunt un nemernic Å£Ã¢Å£ofag.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6899,706,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-10-19 14:14:42','2007-10-19 12:14:42','@ Lupulainu: Oare s-o fi indragostit de Pukin...?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(7624,752,'cronicaru\'','tzone_a@yahoo.com','http://cronicaru.blogspot.com/','193.230.230.101','2007-11-01 17:51:11','2007-11-01 15:51:11','grija mare la fasole',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(8143,777,'Paszti','pasztorjozsef@yahoo.com','','81.12.230.166','2007-11-16 10:18:38','2007-11-16 08:18:38','aaa, si mai este o tabla in fata prefecturii, scrie pe ea CONSILIUL JUDETEAN CLUJ - PARCARE\r\nTot ma gangeam cine poate sa fie Parcare ala, ca de Vicepresedinte am auzit da de asta inca nu',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727)','',0,0),(7218,717,'July','jullya24@yahoo.com','','83.103.179.55','2007-10-24 21:58:49','2007-10-24 19:58:49','No ii musai sa stiu dak Marea Rebeliune are loc doar in Cluj, sau va ganditi la un turneu national....ar fi frumos din partea voastra....ar fi nedrept ca unele studente sa sufere doar pt ca nu au fost destul de inspirate si informate ca sa dea la Cluj...dak nu..ata este,ma mut acolo:)',0,'1','Opera/9.10 (Windows NT 5.1; U; en)','',0,0),(7462,737,'portarul','port@yahoo.com','','77.81.203.47','2007-10-28 18:08:38','2007-10-28 16:08:38','Liberalii au inteles sa pregateasca ziua euroblogurilor deschise. Au inceput la genul feminin, cu http://www.valean.eu/',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7097,715,'Andreea MKT','supergirgir@yahoo.com','http://marlahermina.deviantart.com/gallery/','82.77.126.254','2007-10-23 16:47:10','2007-10-23 14:47:10','Groparu traieste 8 zile numa de ciuda sa iasa testu de sarcina cu doo linii si sa se infioare domnisoarele.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(6745,693,'10mbc','alin.banc@gmail.com','','89.137.5.71','2007-10-14 14:29:17','2007-10-14 12:29:17','Pentru mine polus e mult mai aproape decat iulius. in schimb faza aia cu 10 cinemauri mici si primitoare e super. btw, unde e cinemaul in polus ca nu l-am gasit si am cautat :(',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6746,693,'Marius','pop.marius@gmail.com','http://Lityx.blogspot.com','89.123.80.120','2007-10-14 19:42:03','2007-10-14 17:42:03','Cred ca Iulius (care deja a cam sifonat-o cu deschiderea intarziata si imi imaginez cam cat pierd pe zi toti chiriasii) va fi mult mai de \"life-style\" decat Polus-ul. Daca in Polus e inghesuiala de magazine (destule marci tari - in sensul in care isi permit sa aduca produse de marca la preturile lor adevarate), Iulius cred ca va fi mult mai spectaculos, mai multe cafenele si spatiu de \"stat in vitrina, sa te admire lumea\". Inghesuiala a fost groaznica la Polus si din cauza asta au fost multi nervi in toate partile dar adevaratele impresii vor aparea intr-o luna-doua, cand se mai stabilizeaza traficul. pana una alta, de acord cu natty. Lillith, e loc de toti. Si, Gropare, \'mneata ai fost interpret?! Mai mai ca m-as fi uitat inspre scena, da\' hostess-ele...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(8803,813,'si mester','','','89.137.120.50','2007-11-26 12:49:07','2007-11-26 10:49:07','io nu visez la o alta ro, io ma stradui sa o am : n-m plecat in strainataturi - pt a-mi emancipa poporu\' ! am inceput cu nenea de la ziare care a vociferat ca i-am inmanat numai marunti, cei mai marunti. am cerut banii inapoi si am cumparat de alaturi chiar daca pe nenea nici gandu\' nu-l doare. as iesi in februarie sa militaz in strada pt interzicerea consumului public de seminte, as iesi o data pe luna cu tricou verde(eco nu ..gardist) si manusi sa curat zone de agrement DAR as planta si pancarde acolo. am fo\' la vot unde ...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(6828,700,'macabroo','raduccc@yahoo.com','http://rezistenta.blogspot.com','80.96.196.2','2007-10-17 08:56:37','2007-10-17 06:56:37','Bai da, daca tot era rus, si-l mai chema si Ivan? Stia sa faca un \"Crazy Ivan\"?',0,'1','Opera/9.23 (Windows NT 5.1; U; en)','',0,0),(6829,700,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-10-17 09:07:20','2007-10-17 07:07:20','@ macabroo: io-te, mah, cine se uita la filme cu supmarine rusesti!!!! (probabil ca era-n stare sa faca crazy Ivan cu nevasta-sa, da\' numa dupa ce se dregea cu motorina de-aia)\r\n\r\n@ Tina: asta e ca si cum daca te cheama Vulpe, bunu\' ar fi trebuit sa fi fost vanat de casa regala britanica!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6748,693,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','85.186.77.129','2007-10-14 20:31:33','2007-10-14 18:31:33','Marius, da, e loc de toti. am spus doar ca eu nu m-as duce acolo si atat ;) pentru ca nu vad rostul cand am aproape multe alte magazine, cinemauri, cafenele. asta nu inseamna ca l-as vedea ras de pe harta clujului. m-ai inteles gresit.\r\ne bine ca s-a deschis polus, economia clujului va creste. dar eu nu m-as duce acolo ;)',0,'1','Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.0.12) Gecko/20070731 Ubuntu/dapper-security Firefox/1.5.0.12','',0,0),(6771,698,'nenea cosmos','domnu_cosmos@yahoo.com','http://nenea.wordpress.com/','92.80.38.32','2007-10-15 21:02:22','2007-10-15 19:02:22','clopurile, cu alea nu ma prind care e treaba, or fi masoni.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(8722,807,'andreanum','andreanum@yahoo.com','http://andreanum.wordpress.com','89.40.130.202','2007-11-24 16:08:38','2007-11-24 14:08:38','asta e subliminal teritorial, bah, gropare, noi miticii, de ecsenplu, spunem mergi la vot nu meri la vot :D',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(7104,711,'NRGY','','','86.121.178.151','2007-10-23 17:24:35','2007-10-23 15:24:35','Gropare, sa`nteleg din ce zice WhiteWolf ca si tu esti bagat in rahatu` asta de politica? Mi`ar pare rau sa aflu asa ceva. Mie imi place de tine apolitic :) Dar, totusi, intrebarea e pe bune.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7215,717,'Helpthegrass','helpthegrass@yahoo.com','','92.80.120.135','2007-10-24 21:49:43','2007-10-24 19:49:43','@ Miruna Cred ca ar trebui sa iti anunti si prietene din tara. Sti cum este la rasmerita. De la o scantaie se raspandeste toata tara. Si uite asa apar grupari si prin Bucuresti...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7095,711,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-10-23 16:38:37','2007-10-23 14:38:37','@ Pheno: sau nu...? ca ziceai ca si tu ej sashie (citez: #  PhenoBarbieDoll Says: \"io insami da, sa traiti :d\"). Sau nu am inteles eu bine, citind cu ochii mei asezati de-o parte si de alta a nasului?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7327,735,'VIP','ps@yahoo.com','http://vipuri.blogspot.com','213.157.188.71','2007-10-26 15:03:45','2007-10-26 13:03:45','gropareee. citeste articolul asta: http://de-aia.blogspot.com/2007/10/italieni-nebuni-taxe-pe-bloguri-in.html\r\n\r\nii tare de tot ma',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7328,717,'andreanum','andreanum@yahoo.com','http://andreanum.wordpress.com','194.30.177.1','2007-10-26 16:18:13','2007-10-26 14:18:13','daca e sa ajungeti in bucuresti, sa stiti ca eu stiu sa gatesc o slanuca cu ceputza si tzuicutza, dar nu am decit doua camere: nu veniti tati odata, incercati sa trageti la sorti ordinea si sa intrati pe rind, cite unul macsim doi, caci nimic nu iubesc mai mult decit o cina ardileneasca in intimitate. Gropy, daca dai mail iti dau si adresa si iti desenez si o harta, sa nu flaminzesti pe stradute, ca stau intr-un cartier complicat.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1)','',0,0),(7119,715,'Miruna','mirunavasilescu@yahoo.com','http://potsafacsiasaceva.blogspot.com/','86.106.59.163','2007-10-23 20:41:14','2007-10-23 18:41:14','In numele femeilor de pretutindeni, nu pot sa spun decat: sÃ¢c!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7329,735,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-10-26 16:33:38','2007-10-26 14:33:38','Io zic ca e manevra pesedista. Tu ce crezi?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7463,737,'cocofifi','coco@mail.com','','62.224.203.4','2007-10-28 20:23:09','2007-10-28 18:23:09','aia cu \"io am tinut cu dacii toata viata mea\" m-o dat gata. hahaha si hihihiii !',0,'1','Mozilla/5.0 (Macintosh; U; PPC Mac OS X Mach-O; de; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7101,711,'WhiteWolf','laskmerge@gmail.com','','89.32.115.96','2007-10-23 17:09:03','2007-10-23 15:09:03','Io crez\' ca te-ai tembelit de te-a loat pohta sa-i faci lu\' asta promotion.\r\nAz\' maine te da esthia afar\' de prin imperiu Ciutacesc ca te banuie de mercenariate.\r\nShezi linistit om fain. Zau, nu se merita :)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(8769,803,'smokingcoolcat','smokingcoolcat@yahoo.com','http://smokingcoolcat.blogspot.com/','86.121.115.10','2007-11-25 23:09:44','2007-11-25 21:09:44','daca tot iti plac lepsele ia una si de la mine: http://smokingcoolcat.blogspot.com/2007/11/ceas-de-blogger.html',0,'1','Opera/9.21 (Windows NT 5.1; U; en)','',0,0),(8714,807,'psaico','blog@psaico.info','http://www.psaico.info','78.96.86.55','2007-11-24 13:05:57','2007-11-24 11:05:57','meri la vot =)))\r\nhai ca eu deja ma gandeam la adam si eva .. sau pm .. dar prea simplu era mesajul :)))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8864,815,'.marius','marius@perijoc.com','http://marius.wirelessisfun.com','89.36.21.108','2007-11-27 09:36:48','2007-11-27 07:36:48','Te cheama si Danutz? de ce intreb, pentru ca si pe urs il chema Danutz...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7103,715,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-10-23 17:24:10','2007-10-23 15:24:10','Coada fusese iubita inainte de toate spermatozoitzele, d-aia era asa sifonata :|',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7865,114,'ot','','','86.105.69.144','2007-11-10 06:26:21','2007-11-10 04:26:21','de la un doctor dedicatie:\r\n\r\n&gt;&gt;&gt;&gt; &gt; &gt; Ati vazut prea bine ca la consultatii\r\n&gt;&gt;&gt;&gt; &gt; &gt; Doctorii te-ntreaba despre emanatii.\r\n&gt;&gt;&gt;&gt; &gt; &gt; Vor sa stie totul: abundenta, faze,\r\n&gt;&gt;&gt;&gt; &gt; &gt; Unii le zic \"vanturi\", altii le zic \"gaze\".\r\n&gt;&gt;&gt;&gt; &gt; &gt; Dar sa nu va mire daca medicina\r\n&gt;&gt;&gt;&gt; &gt; &gt; Studiaza astazi foarte mult \"basina\".\r\n&gt;&gt;&gt;&gt; &gt; &gt; Fiindca, biologic, pentru toti e clar,\r\n&gt;&gt;&gt;&gt; &gt; &gt; A basi e-un lucru foarte necesar.\r\n&gt;&gt;&gt;&gt; &gt; &gt; Toata lumea bese, asta-o axioma\r\n&gt;&gt;&gt;&gt; &gt; &gt; Nu intereseaza sunet sau aroma.\r\n&gt;&gt;&gt;&gt; &gt; &gt; In privinta asta toti suntem la fel\r\n&gt;&gt;&gt;&gt; &gt; &gt; Floarea nobilimii, preoti, printi, printese,\r\n&gt;&gt;&gt;&gt; &gt; &gt; Papa de la Roma bese si iar bese.\r\n&gt;&gt;&gt;&gt; &gt; &gt; Insa o chestiune trebuie-nteleasa\r\n&gt;&gt;&gt;&gt; &gt; &gt; Fiecare bese, dar la el acasa!\r\n&gt;&gt;&gt;&gt; &gt; &gt; Fara martori merge, tare sau incet,\r\n&gt;&gt;&gt;&gt; &gt; &gt; Nimeni nu-ti dicteaza sa te besi discret\r\n&gt;&gt;&gt;&gt; &gt; &gt; Vrei rafale scurte sau prelungi sa sune\r\n&gt;&gt;&gt;&gt; &gt; &gt; Treaba ta, esti liber, poti sa faci si spume!\r\n&gt;&gt;&gt;&gt; &gt; &gt; Si chiar daca nimeni nu-ti sta imprejur,\r\n&gt;&gt;&gt;&gt; &gt; &gt; Poti sa besi in lege, pana pici in fund.\r\n&gt;&gt;&gt;&gt; &gt; &gt; Eticheta cere, insa, sa fii foarte pudic\r\n&gt;&gt;&gt;&gt; &gt; &gt; Bunul simt pretinde sa nu besi in public.\r\n&gt;&gt;&gt;&gt; &gt; &gt; Ce-ar fi, bunaoara, s-auzi pe cutare\r\n&gt;&gt;&gt;&gt; &gt; &gt; C-a basit in public doamna nu-stiu-care\r\n&gt;&gt;&gt;&gt; &gt; &gt; Sau ca domnisoara, profesoara X,\r\n&gt;&gt;&gt;&gt; &gt; &gt; S-a basit in clasa, ieri la 9 fix?\r\n&gt;&gt;&gt;&gt; &gt; &gt; Cum ar fi privite, sau calificate,\r\n&gt;&gt;&gt;&gt; &gt; &gt; Ar mai fi prestigiu, autoritate?\r\n&gt;&gt;&gt;&gt; &gt; &gt; Cine le-ar mai crede fiinte gratioase?\r\n&gt;&gt;&gt;&gt; &gt; &gt; Ar fi socotite niste basinoase.\r\n&gt;&gt;&gt;&gt; &gt; &gt; Dar ma-ntorc acuma iar la medicina\r\n&gt;&gt;&gt;&gt; &gt; &gt; Sa-ti risti sanatatea pentru o basina?\r\n&gt;&gt;&gt;&gt; &gt; &gt; Sa n-o lasi sa iasa daca esti in public,\r\n&gt;&gt;&gt;&gt; &gt; &gt; Fiindca eticheta cere sa fii foarte pudic?\r\n&gt;&gt;&gt;&gt; &gt; &gt; In privinta asta sunt pareri mai multe,\r\n&gt;&gt;&gt;&gt; &gt; &gt; Cine-ar sta pe toate sa le mai asculte?\r\n&gt;&gt;&gt;&gt; &gt; &gt; Astfel, dupa unii poti sa besi oricat\r\n&gt;&gt;&gt;&gt; &gt; &gt; Dar sa stii la vreme sa le strangi de gat.\r\n&gt;&gt;&gt;&gt; &gt; &gt; Poti sa fii acelasi om cu demnitate\r\n&gt;&gt;&gt;&gt; &gt; &gt; De le dai tacut drumu-n libertate\r\n&gt;&gt;&gt;&gt; &gt; &gt; Asta-i o parere, una dintr-o mie\r\n&gt;&gt;&gt;&gt; &gt; &gt; Dar morala spune ca-i ipocrizie\r\n&gt;&gt;&gt;&gt; &gt; &gt; Ce deosebire intre om si cal\r\n&gt;&gt;&gt;&gt; &gt; &gt; Ar mai fi atuncea sub aspect moral?\r\n&gt;&gt;&gt;&gt; &gt; &gt; Cand te-arati in lume demn, gras si frumos\r\n&gt;&gt;&gt;&gt; &gt; &gt; Si-n realitate esti un basinos?\r\n&gt;&gt;&gt;&gt; &gt; &gt; Cati nu sunt din astia care bas de zor,\r\n&gt;&gt;&gt;&gt; &gt; &gt; Parca stii vreodata ce-i la curul lor?\r\n&gt;&gt;&gt;&gt; &gt; &gt; Dar ramane lege ca e indecent\r\n&gt;&gt;&gt;&gt; &gt; &gt; Sa slobozi la gaze pe esapament.\r\n&gt;&gt;&gt;&gt; &gt; &gt; Fie, cu morala nu te poti certa\r\n&gt;&gt;&gt;&gt; &gt; &gt; Dar mai vine gazul fara voia ta.\r\n&gt;&gt;&gt;&gt; &gt; &gt; Suiera si geme, cu prelung ecou\r\n&gt;&gt;&gt;&gt; &gt; &gt; Iar tu ai nesansa sa fii la birou.\r\n&gt;&gt;&gt;&gt; &gt; &gt; In astfel de cazuri, spune, ce te faci?\r\n&gt;&gt;&gt;&gt; &gt; &gt; Sa recurgi la scuze sau sa te prefaci?\r\n&gt;&gt;&gt;&gt; &gt; &gt; Din experienta eu va spun cinstit\r\n&gt;&gt;&gt;&gt; &gt; &gt; Ca nicicand in viata nu am indraznit\r\n&gt;&gt;&gt;&gt; &gt; &gt; Sa recurg la scuze, ar fi fost mai rau\r\n&gt;&gt;&gt;&gt; &gt; &gt; Sa roseasca lumea toata-n jurul meu.\r\n&gt;&gt;&gt;&gt; &gt; &gt; Am tarsit un scaun, am facut ceva,\r\n&gt;&gt;&gt;&gt; &gt; &gt; Ca sa nu se creada c-am basit cumva.\r\n&gt;&gt;&gt;&gt; &gt; &gt; Si oricat s-ar spune ca sunt ipocrit\r\n&gt;&gt;&gt;&gt; &gt; &gt; S-au facut si altii ca n-au auzit.\r\n&gt;&gt;&gt;&gt; &gt; &gt; Chiar si-ndragostitii cand admira luna,\r\n&gt;&gt;&gt;&gt; &gt; &gt; Cu sau fara voie, scapa cate una\r\n&gt;&gt;&gt;&gt; &gt; &gt; Dar cu-o tuse seaca, bine regizata\r\n&gt;&gt;&gt;&gt; &gt; &gt; Sau cu-o melodie mai pe nas cantata\r\n&gt;&gt;&gt;&gt; &gt; &gt; Fac sa se ascunda tot, a poezie,\r\n&gt;&gt;&gt;&gt; &gt; &gt; Chiar si nedorita, scurta galagie\r\n&gt;&gt;&gt;&gt; &gt; &gt; Ce-a trecut prin mate si s-a dus in vant\r\n&gt;&gt;&gt;&gt; &gt; &gt; Si care ne-ncurca viata pe pamant.\r\n&gt;&gt;&gt;&gt; &gt; &gt; Dar astfel de cazuri cand ipocrizia\r\n&gt;&gt;&gt;&gt; &gt; &gt; E asociata chiar cu poezia,\r\n&gt;&gt;&gt;&gt; &gt; &gt; Crime moralistii nostri le socot.\r\n&gt;&gt;&gt;&gt; &gt; &gt; Caci morala-si baga nasul peste tot.\r\n&gt;&gt;&gt;&gt; &gt; &gt; In final, tot omul se intreaba trist:\r\n&gt;&gt;&gt;&gt; &gt; &gt; Sa asculti de medic, sau de moralist...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1) Gecko/20061010 Firefox/2.0','',0,0),(6801,700,'baghy','baghy83@lycos.it','http://baghy.info/','78.12.9.34','2007-10-16 21:57:34','2007-10-16 19:57:34','si eu am cunoscut un moldovean rus tot Ivan il chema si zicea ca bea doi litri de vodca pe zi. Dar ala cu alcoolul dublu rafinat e prea de tot',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(6802,693,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2007-10-16 22:29:00','2007-10-16 20:29:00','@ Marius: D\'apoi ce, numa io sa ma aberesc p-acilea?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(8719,807,'zulea','zulea1@gmail.com','','89.137.121.165','2007-11-24 15:14:23','2007-11-24 13:14:23','Si io care credeam ca e vorba de tzuica, ca doara din mere se face tzuica. Sau macar RDM (asta-i tot o bautura, de pe vremea cind era stema aia de dinainte de gaura din steag ... aceia care o facut armata mai de mult sigur stie).\r\n\r\nDa ce-i cu votul asta, si cind este, si pentru ce este ????',0,'1','Mozilla/5.0 (Macintosh; U; Intel Mac OS X; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7478,738,'','','','80.96.196.2','2007-10-29 14:25:58','2007-10-29 12:25:58','Pare a fi un compot la mijloc!',0,'1','Opera/9.23 (Windows NT 5.1; U; en)','',0,0),(7583,746,'nenea cosmos','domnu_cosmos@yahoo.com','http://www.nenea.wordpress.com','92.81.12.78','2007-10-30 21:39:53','2007-10-30 19:39:53','in timp ce tu esti la fotbal noi citim de papucii tai, bravo ma.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(8820,814,'nenea cosmos','domnu_cosmos@yahoo.com','http://www.nenea.wordpress.com','92.80.4.41','2007-11-26 18:37:27','2007-11-26 16:37:27','deci petra e misto.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(7555,746,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-10-30 10:43:25','2007-10-30 08:43:25','Nu, prin Gheorgheni, zona aia tampon (hehe!) cu Borhanciu\'. Nu pot sa iti zic exact, ca am ajuns intr-un porbagaj de masina, noaptea, legat fedelesh si cu ochii acoperiti.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7099,715,'WhiteWolf','laskmerge@gmail.com','','89.32.115.96','2007-10-23 17:05:41','2007-10-23 15:05:41','Ereai murdÃ£rel pe cuadÃ£ ? :P\r\nSau e tot o chestie de tine de biolojie ?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(6804,697,'Bibliotecaru','um0834@yahoo.com','http://giconet.blogspot.com/','86.121.5.56','2007-10-16 23:21:08','2007-10-16 21:21:08','Din cÃ¢nd Ã®n cÃ¢nd, e bine sÄƒ staÅ£i Ã®ntr-un picior... aÅŸa, de autocontrol. DacÄƒ piciorul care atinge pÄƒmÃ¢ntul de pÄƒmÃ¢nt rÄƒmÃ¢ne erectat, e bine. DacÄƒ nu atingeÅ£i pÄƒmÃ¢ntul cu douÄƒ picioare erectate, e grav, staÅ£i pe spate Ã®n poziÅ£ia lumÃ¢nare. Numai Newton care a inventat gravitaÅ£ia... altfel era bine HÃ‚C!',0,'1','Mozilla/5.0 (Windows; U; Win 9x 4.90; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6805,700,'Dojo','dojo@wtricks.com','http://www.dojoblog.info','86.106.47.217','2007-10-16 23:22:20','2007-10-16 21:22:20','Acum daca te pui cu rusii .. te baga sub masa .. al meu a fost la rusi acum multi ani si s-a socat de cat duc ei si mai ales femeile .. astia-s campioni la \"ras\" bautura ...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(7578,748,'WhiteWolf','laskmerge@gmail.com','','89.32.115.125','2007-10-30 18:27:19','2007-10-30 16:27:19','L-am ciuruit si io pe boc\r\nDa\' parca ma ia cu regret, acum pen\'ca nu prea are cum\r\n<b>Cin\'drac o mai vaz\'t Boc fara aeroport si aveon ? :P',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(7579,748,'nelli','mezeinelli@yahoo.com','http://www.mezeinelli.wordpress.com','213.233.78.208','2007-10-30 19:33:04','2007-10-30 17:33:04','ÅŸi textul de pe statuie va fi: \"ÅŸi cu pulÄƒ micÄƒ, ÅŸi cu pretenÅ£ii\"',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7580,748,'olahus','miusever@yahoo.fr','http://surpriseroumaine.blogspot.com/','89.136.138.77','2007-10-30 20:32:57','2007-10-30 18:32:57','un blog indecent de haios!\r\nimi pare bine ca l-am cunoscut\r\n\r\n\r\nsalutari din hilariopolis (Bucuresti :P )',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7609,748,'10MBC','alin.banc@gmail.com','http://www.maestral.ro','217.156.21.3','2007-10-31 15:37:41','2007-10-31 13:37:41','Gropare, imi place pulu tau. am votat de 20 de ori cu o chestie si nu o avut nici pa naiba. asta ii ca si la radio. te poti inscrie de cate ori vrei, numa\' ca aici ii pa gratis',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7582,748,'nenea cosmos','domnu_cosmos@yahoo.com','http://www.nenea.wordpress.com','92.81.12.78','2007-10-30 21:36:53','2007-10-30 19:36:53','de unde pina unde il buseste pe asta risul cind vorbeste de micul meu orasel natal?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(7067,711,'PhenoBarbieDoll','poisongirl94@yahoo.com','http://360.yahoo.com/poisongirl94','193.230.230.101','2007-10-23 11:00:58','2007-10-23 09:00:58','io insami da, sa traiti :d',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(8897,818,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-11-27 16:21:40','2007-11-27 14:21:40','Excrementatoru\'!!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.10) Gecko/20071115 Firefox/2.0.0.10','',0,0),(7090,711,'PhenoBarbieDoll','poisongirl94@yahoo.com','http://360.yahoo.com/poisongirl94','193.230.230.101','2007-10-23 16:00:01','2007-10-23 14:00:01','Gropare, io cred ca te-ai molipsit de la Baselu si nu mai vezi bine de-mi raspunzi mie la ce zice Macabroo :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(6936,712,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2007-10-20 18:46:48','2007-10-20 16:46:48','Nu iesi, mah, ca n-am terminat inca cu tine!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7766,761,'gogu von gogu','','','89.35.172.31','2007-11-06 21:38:56','2007-11-06 19:38:56','ba groparule te ajut si eu cu 4000 doamne intre 30-50 ani .ce zici',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12','',0,0),(7770,761,'baghy','baghy83@lycos.it','http://baghy.info/','78.12.13.1','2007-11-07 00:15:29','2007-11-06 22:15:29','Gropare dar sunt urate astea si asa cum vrei tu nu gasesti 4000 in toata Italia',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(7768,761,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2007-11-06 21:56:12','2007-11-06 19:56:12','Negativ! numa cu fetele lor :D\r\n\r\nOOOOK, gata, pana-n 35 de ani, e ghini?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7760,757,'Groparu','groparu_ro@gmail.ro','http://www.groparu.ro','82.77.126.254','2007-11-06 17:45:25','2007-11-06 15:45:25','Mo, deci urmieaza sh asta!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7466,737,'conia','','','194.153.242.9','2007-10-28 20:27:05','2007-10-28 18:27:05','http://www.mnit.ro/contact.php',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(7483,740,'CÄƒlÄƒ','acalarasu@gmail.com','http://adriancalarasu.wordpress.com/','62.217.241.242','2007-10-29 17:15:26','2007-10-29 15:15:26','deci ala cu pinu\' e tatal tantalailor!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(7594,749,'Cala','acalarasu@gmail.com','http://adriancalarasu.wordpress.com/','89.32.19.126','2007-10-30 23:52:01','2007-10-30 21:52:01','Asta cu bautu\' cot la cot cu Ciutacu il incrimineaza rau pe giurnalist :D',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) )','',0,0),(7230,717,'Miruna','mirunavasilescu@yahoo.com','http://potsafacsiasaceva.blogspot.com/','86.106.59.163','2007-10-25 00:55:52','2007-10-24 22:55:52','Cred ca e vorba armonia intr-un singur cuplu, si anume groparu-studentele clujence.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7231,717,'Miruna','mirunavasilescu@yahoo.com','http://potsafacsiasaceva.blogspot.com/','86.106.59.163','2007-10-25 00:56:45','2007-10-24 22:56:45','\"De\". \"de armonia\". m-am emotionat.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7575,748,'CÄƒlÄƒ','acalarasu@gmail.com','http://adriancalarasu.wordpress.com/','62.217.241.242','2007-10-30 17:37:41','2007-10-30 15:37:41','mooaaah, ce pul\r\npardon\r\nce poll mijto ti-ai tras\r\n:)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(7605,749,'cronicaru\'','tzone_a@yahoo.com','http://cronicaru.blogspot.com/','193.230.230.101','2007-10-31 11:26:28','2007-10-31 09:26:28','gropare, da\' nu-i normal sa lucrezi cu astfel de curve daca asta meserie ti-ai ales? puteai sa te faci si tu cuptorist la crematoriul Pheonix si lucrai si tu cu bunaciuni ca Cenusareasa spre exemplu.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(7193,717,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2007-10-24 17:52:01','2007-10-24 15:52:01','@ all: deci extindem atacul si la ne-studente?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(8692,807,'Eugen','mail@peugen.net','http://www.peugen.net','89.34.104.217','2007-11-23 22:58:07','2007-11-23 20:58:07','M-am benoclat eu ca boul la imaginea aia cateva minute bune si tot nu vad decat o oarecare asemanare cu fosta stema comunista. Inca o ora si aflam. Minuneaza-ne, stimabile!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8125,777,'nenea cosmos','domnu_cosmos@yahoo.com','http://www.nenea.wordpress.com','92.80.11.130','2007-11-16 06:01:00','2007-11-16 04:01:00','la mintea mea si pozele tale ce sa inteleg, ca vicele are doua masini si secretarul numa\' una?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(7207,717,'Miruna','mirunavasilescu@yahoo.com','http://potsafacsiasaceva.blogspot.com/','86.106.59.163','2007-10-24 19:37:58','2007-10-24 17:37:58','Eu le-am anuntat, da\' sa stii ca sunt numai doua si sunt timide, deci sa nu va duceti in numar mare si mergeti si voi cu o floare, ceva.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7277,720,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','83.103.133.158','2007-10-25 18:09:05','2007-10-25 16:09:05','nu pot sa nu remarc porcoseniile gen \"radu+veta=love\". trist, foarte trist! de aici vine zicala \"numele prostilor pe toate gardurile\"',0,'1','Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.0.12) Gecko/20070731 Ubuntu/dapper-security Firefox/1.5.0.12','',0,0),(7608,748,'Hammer','hammer@alpinet.org','http://www.alpontos.wordpress.com','86.120.55.79','2007-10-31 12:24:51','2007-10-31 10:24:51','Se va desprinde din statuie Ã®ntreg aparatul reproducÄƒtor al calului, ÅŸi se va topi.\r\n...si din materialul rezultat se va turna un TUN',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(7204,717,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2007-10-24 18:57:31','2007-10-24 16:57:31','@ Mile: Yyyesssss... amu ne mai trebe decat Elena.\r\n\r\n@ Miruna: da, zi-le sa faca repede dush. Da\' repede!\r\n\r\n@ ciutacu: m-am potolit de cand aflai cum e cu cu simpatiile la ziaristi!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7480,740,'Adi Calarasu','acalarasu@gmail.com','http://adriancalarasu.wordpress.com/','62.217.241.242','2007-10-29 16:47:34','2007-10-29 14:47:34','pai si ce vroiai mai, sa te felicite? ca sa mai faci?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(7481,740,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-10-29 16:55:31','2007-10-29 14:55:31','Sa-mi zica de Kant care nu mai putea crea din cauza ca cei doi copaci din curtea vecinului ii blocau vederea la turla bisericii din orasu-i natal! De Einstein, care avea costume identice, ca sa nu piarda energie inutil gandindu-se cum sa se imbrace in ziua aia! Despre Newton, caruia ii cadeau mere in scufitza! Despre Enescu care facea viori din stiuleti de porumb! \r\n\r\nCred ca-mi dau vana in judecata, ca de cand m-am palit la cap numa noroace d-astea am experimentat.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7192,717,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2007-10-24 17:51:30','2007-10-24 15:51:30','@ oedip: deci, NE POTOLIM, da?\r\n\r\n@ badnurse: nu, mah, o sa-mi trebuiasca numa codeina. Cu votca, of cos. Of cos.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7227,717,'WhiteWolf','laskmerge@gmail.com','http://white-wolf.ro','89.32.115.107','2007-10-25 00:17:08','2007-10-24 22:17:08','Io nu mai rezist si dau din casa :P\r\nChiar nimeni nu se prinde ca, de fapt, Groparu nu indeamna la razboi decat asa, de ochii albastrii si cristalini ai lumii ? \r\nDe fapt, in maretia-i marinimoasa, el pune umarul la imbunatatirea , a calitatii vietii sexuale si a intaririi relatiilor in si intre cupluri :P',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(7469,737,'IepurasulAtomic','praetorian21uk@yahoo.com','','62.217.245.97','2007-10-28 22:14:45','2007-10-28 20:14:45','Bah Gropare, dara io stau cu lacrima in coltzu\' ochiului ca nu puteam sa-ti dau si tie sa bei cu mine(asha mi-o fost jena ma de Groparitza, am zis sa te invit, da\' mi-o fost ca ma bate. Si-asha o comisesem ca n-am stiut bancuri cu iepurasi. Tu te-ai scos cu numerele de telefon, ce tz-o pasat, \'re-ai al dracu\' :P)...asha dara, io cu lacrima in ochi si tu pui organele sa ma bata. Da\' niste organe de gajici bune n-ai fi asmutit pe mine ma, numa\' organe din alea cu pulane groase. Frumos asha, zici tu? Ma, si-asha m-am ascuns de ei sa nu ma vada cum beu(ca nu stiam de-i legal ori ba), da\' dejaba ma ascund io...la 2 metri ai mei...vai vai vai. Partea buna insa(c-asha m-a-nvatat mama, sa fiu optimist) ii ca daca o luam pe cocoasa, smurdu era acolo langa mine si nu pierdeam prea mult sange :). Pace p\'afara si violenta erotico-porno-pasionala in asternut ;)!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(7296,717,'baghy','baghy83@lycos.it','http://baghy.info/','78.12.16.206','2007-10-25 22:54:45','2007-10-25 20:54:45','ma inscriu in partidul razbunatorilor',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(7297,720,'baghy','baghy83@lycos.it','http://baghy.info/','78.12.16.206','2007-10-25 22:55:05','2007-10-25 20:55:05','la toti ni greu e mult prea tare',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(7254,717,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','82.77.126.148','2007-10-25 10:53:03','2007-10-25 08:53:03','cineva se uita pra mult la futurama! :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7181,717,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','82.77.126.148','2007-10-24 15:55:34','2007-10-24 13:55:34','ai noroc ca-mi plac lupii! :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7174,717,'WhiteWolf','laskmerge@gmail.com','','89.32.115.142','2007-10-24 13:59:52','2007-10-24 11:59:52','Io\'tz doresc succese maxime si chiar daca ai sa sfarsesti invins, lupta-te glorios. Si fara graba :D\r\nPana una-alta, scuza-ma de vorba proasta, vezi cum faci si ce rezolvi locco. \r\nlilith chiar te umileste in propriul bordei :P\r\n \r\np.s; gurl, nu o lua personal, e doar din cauza ca imi plac dilemele tale existentiale :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7190,717,'badnurse','hospitaal@mail.com','','62.224.218.18','2007-10-24 17:42:00','2007-10-24 15:42:00','nu creca  turcii o sa aiba nevoie de penicilina dupa aia, dar tu..in mod sigur !\r\nhahaaaaa',0,'1','Mozilla/5.0 (Macintosh; U; PPC Mac OS X Mach-O; de; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7293,720,'DÃ£nilÃ£','','','84.232.157.246','2007-10-25 21:59:20','2007-10-25 19:59:20','Gropy, mÄƒmicÄƒ... ai plecat d-acilea dÃ®ntre noi ÅŸi te-ai dus colea (nu RÄƒutu) la ei. Le-ai respirat bÄƒutura, le-ai beut femeile ÅŸi le-ai futut aeru\' (pretenii jtie de Ceay\'z (un fel de joc de cuvinte...hrmmm... cu g\'ase...)) Trecut-au anii  (nu Ani aia boccie, alta...) ÅŸi mÄƒ mutai ÅŸi io de la noi, la hÄƒialalÅ£i ei (haCapitalÄƒ, haVicky, haPraga (nu Kitty Cepraga, obsedaÅ£ilor!!!!), haSuslaetaj. Gropy jtie... BÄƒ, da\' n-am priceput de ce ai tÄƒi (ÅŸi nu ai mei), dupÄƒ ce rÃ¢gÃ¢ie, bes, se scurmÄƒ-n nas, stuchesc pe jos ÅŸi se scarpinÄƒ-n cur plesnind de bine, tre\' sÄƒ declame cu voce de PÄƒunescu ÅŸi moacÄƒ de GuÅ£Äƒ: \"La tÄƒÅ£i ni-i greu!\" Care-i ÅŸpilu\' cu greu\' Äƒsta? Un fel de \"bÄƒ da\' superior mi-s...\"? Chiar Ã®s curios...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.4','',0,0),(7172,717,'Basty','basty@canvas.ro','http://basty.wordpress.ro','82.77.126.21','2007-10-24 13:38:02','2007-10-24 11:38:02','@Pliscu: conform organigramei pe care o consult cu ochii beliti si atentia marita chiar acu\' ni, avem post de Tavalitor Sef si Executive Ciufulitor . Ambele neocupate. Da\' vezi ca e concurenta mare. 10 pe post.',0,'1','Mozilla/5.0 (Macintosh; U; Intel Mac OS X; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7553,746,'pliscu','pliscu@gmail.com','http://pliscu.blogspot.com','89.137.100.118','2007-10-30 10:28:37','2007-10-30 08:28:37','Unde joci? La \"Eugen Pora\"?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7765,753,'Usim','mihaimitan@gmail.com','','87.237.108.33','2007-11-06 20:38:25','2007-11-06 18:38:25','WarSongu, gandeste-te cum il ademenim pa Gropar in Bucureti la o bere. Am vazut ca-l chemasi si tu si, ca si mie, ti-a raspuns asa ca da, da, o sa....',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; .NET CLR 2.0.50727)','',0,0),(7757,759,'Groparu','groparu_ro@gmail.ro','http://www.groparu.ro','82.77.126.254','2007-11-06 17:04:09','2007-11-06 15:04:09','@ Usim: deci nimic nu bucura mai tare inima mea batrana decat comentariile! Deci feel free sa baji la greu. Cat despre berule... Äƒr vini ele!\r\n\r\n@ ratz: ba da, stiam in ce ma bag. Da\' relatia asta parazitara imprumutat-banca nu e ca o casatorie? \"Cand am luat-o parca nu era asa grasa!!!!\"\r\n\r\n@ koyrosh: da, ma, da, si in Polinezia is insule unde tot tribu face sex si papa gulii dulci, de elea de ce nu zici nimic?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7281,735,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2007-10-25 18:41:01','2007-10-25 16:41:01','Da, mah, da ce mascul e ala care nu face pishu supt dush?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7272,735,'macabroo','raduccc@yahoo.com','http://rezistenta.blogspot.com','82.76.52.94','2007-10-25 16:58:30','2007-10-25 14:58:30','Era cast castrul?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7202,718,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','83.103.133.158','2007-10-24 18:45:18','2007-10-24 16:45:18','are voie numai daca nu face pishu pe ea! :\"&gt;',0,'1','Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.0.12) Gecko/20070731 Ubuntu/dapper-security Firefox/1.5.0.12','',0,0),(7170,717,'pliscu','pliscu@gmail.com','http://pliscu.blogspot.com','89.137.100.118','2007-10-24 13:01:27','2007-10-24 11:01:27','@Basty: post de Tavalitor Sef este? ca mi-as depune si eu un CV ;)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7754,755,'WarSongu','eternaldawnlord@yahoo.com','http://www.warsongu.wordpress.com','193.32.3.83','2007-11-06 16:22:42','2007-11-06 14:22:42','adica?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; FunWebProducts; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(7755,759,'WarSongu','eternaldawnlord@yahoo.com','http://www.warsongu.wordpress.com','193.32.3.83','2007-11-06 16:32:12','2007-11-06 14:32:12','Miruneatzo, am io rate, si credit si cate si mai cate, da mie lene sa fac scandal. iote fa tu scandal pa ratele mele',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; FunWebProducts; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(7252,717,'Mi-am irosit viata. &laquo; Snu snu anyone ?','','http://basty.wordpress.com/2007/10/25/mi-am-irosit-viata/','66.135.48.142','2007-10-25 09:24:05','2007-10-25 07:24:05','[...] la fel de multe fetite dragute ca in ziua de azi. Nu la fel de dezgolite, ca in visele stim noi cui, dar la fel de multe. Unchiu&#8217; preferat, barbat plin de barbatie barbateasca, normal, in [...]',0,'1','Incutio XML-RPC -- WordPress/MU','pingback',0,0),(8916,820,'nenea cosmos','domnu_cosmos@yahoo.com','http://www.nenea.wordpress.com','92.80.32.143','2007-11-28 00:45:03','2007-11-27 22:45:03','mai am articole, scriu si o epopee, urmeaza o capodopera, sint specialist, fac caca in fiecare zi de foarte multi ani, am centura neagra in facut caca. sint sensei, sint guru.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(7187,717,'oedip','oedip74@gmail.com','http://oedip.blogspot.com','139.18.194.141','2007-10-24 17:22:04','2007-10-24 15:22:04','bah, deci, din cate am auzit, azi te-ai intalnit pa troleie cu Aia Mica... deci la Aia Mica sa nu te dai ca te sparg la buci :))))))))))))))))))))) prin tricou, evident ;)\r\n\r\n... ca am gasit niste semnalmente gen ochelari, blugi cu talie joasa, etc, etc... :)))))))))))))))))\r\n\r\nsau, ma rog, daca ma rgi frumos, te las... da numa O TURA!!! bine? :))))))))))))))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7194,717,'Mile','','http://milecarpenisan.wordpress.com','86.127.182.221','2007-10-24 17:59:32','2007-10-24 15:59:32','\"Buna seara Mile Carpenisan e la fata locului...\" va spune ceva? Cum sa incepeti un asemenea razboi de uzura fara reporter special de razboi. Asta e il sun pe Petreanu in A1 si cer sa ma trimita pe frontul de la Cluj.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; FunWebProducts; SIMBAR={A7F3C004-B2DD-4145-98BD-0344DDF9CD6E})','',0,0),(7195,717,'Whitewolf','laskmerge@gmail.com','','89.39.81.140','2007-10-24 18:05:55','2007-10-24 16:05:55','Gropare, scoate votkuleana pe mese ! Leaga kainele , ia-ti tzolu festiv si plateste corespondentul de razboi: e dedicat meseriei, o stim cu totii :)\r\nMile, bine ai sosit !',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(7196,717,'Miruna','mirunavasilescu@yahoo.com','http://potsafacsiasaceva.blogspot.com/','86.106.59.163','2007-10-24 18:06:09','2007-10-24 16:06:09','E cazul sa-mi avertizez prietenele din Cluj?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7256,717,'Basty','basty@canvas.ro','http://basty.wordpress.ro','82.77.126.21','2007-10-25 13:12:19','2007-10-25 11:12:19','Cine ? Eu nu recunosc nimic. Ce Futurama ? Ce-i aia ? Vreo marca de pateu ? Pastrama ?',0,'1','Mozilla/5.0 (Macintosh; U; Intel Mac OS X; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7257,715,'niciodata','','http://niciodata.wordpress.com/','217.10.215.6','2007-10-25 13:37:23','2007-10-25 11:37:23','@parsiimpar: as putea da exemplu si telecomanda televizorului, si inca multe altele :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7258,717,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','82.77.126.148','2007-10-25 13:50:25','2007-10-25 11:50:25','nu nu! snu snu e o replica din futurama! :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7493,740,'Botache','nasturei_verzi@yahoo.com','http://nasturei.wordpress.com','79.113.130.189','2007-10-29 19:43:57','2007-10-29 17:43:57','=))) Asta e prea tare! Nici io nu am patit-o asa urat cu bancile. \r\n\r\nOricum, le ia cam multa anularea tranzactiei. ^.^ Eu zic sa mergi in fiecare zi pe capul lor.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7198,718,'Whitewolf','laskmerge@gmail.com','','89.39.81.140','2007-10-24 18:14:25','2007-10-24 16:14:25','Asa o complicatie numai in tara (asta) evropeana de care faci vorbire se putea intampla si intalni.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(7199,717,'Victor Ciutacu','victor@ciutacu.ro','http://www.ciutacu.ro','82.76.75.160','2007-10-24 18:16:00','2007-10-24 16:16:00','@gropy: tragem aer adanc in piept si ne potolim, da?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(7200,718,'Miruna','mirunavasilescu@yahoo.com','http://potsafacsiasaceva.blogspot.com/','86.106.59.163','2007-10-24 18:23:26','2007-10-24 16:23:26','Eu zic ca mai rau era daca ramaneai cu siretul desfacut. Parerea mea. Da\' ai voie sa te sprijini de statuie?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7167,717,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','82.77.126.148','2007-10-24 12:43:33','2007-10-24 10:43:33','la naiba! nu mai sunt studenta! oare sa fug de navalitori si din cand in cand sa ma impiedic? :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7255,718,'macabroo','raduccc@yahoo.com','http://rezistenta.blogspot.com','80.96.196.2','2007-10-25 12:10:34','2007-10-25 10:10:34','Fara Istambul n-am fi avut probabil multe alte chestii importante: shaorma, kebab, peshchesh, bacshish, aur de 14 carate ieftinache, ghiudem, Hagi, Popescu si Hakan Sukur, \"turkish delight\" (na), Baiazid privind la dansul il intreaba cu dispretz, chilotzi si ciorapi de palstic, sherbet, sarailie, Adi Ilie, tele Canak, Tarkan Shimirik, Constantin si Elena, romanul \"Orient Expres\", Orient expres cu Stelian Tanase, capodopera \"A doua cadere a Constantinopolului\" cu Loredana Groza si Aurelian Temisan etc.',0,'1','Opera/9.23 (Windows NT 5.1; U; en)','',0,0),(6854,702,'Miruna','mirunavasilescu@yahoo.com','http://potsafacsiasaceva.blogspot.com/','86.106.59.163','2007-10-18 15:21:28','2007-10-18 13:21:28','Eu iti multumesc din inima pentru al doilea link. Cand se mai ivea ocazia sa aflu ca \"Like any woman, a chicken needs to be in a relaxed and receptive mood before you can successfully have sex with it.\"?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6855,702,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-10-18 15:34:49','2007-10-18 13:34:49','Da, dar mie mi se pare o bÄƒdÄƒrÄƒnie sÄƒ numeÅŸti un fuck buddy (fie el si gaina, curcan sau nagÃ¢Å£) \"it\". \r\n\r\nStie careva ce e aia nagÃ¢Å£?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6856,702,'evilpenguin','evilpenguin666@gmail.com','','89.114.108.212','2007-10-18 16:18:04','2007-10-18 14:18:04','Pai si ce, n-are dreptate? :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6857,701,'evilpenguin','evilpenguin666@gmail.com','','89.114.108.212','2007-10-18 16:25:22','2007-10-18 14:25:22','Completez si eu cu niste variante:\r\n\r\nAxion Grasime Remes\r\nRaid Tantar Remes\r\nGroapa Bucsa Remes (bucurestenii stiu de ce)\r\nManelar Manelar Remes\r\nsi varianta me de suflet Nokia Sony-Ericsson Remes',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6858,702,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-10-18 16:28:00','2007-10-18 14:28:00','Are, numa ca daca ii zici la fomeea ta \"it\" in engleza, devine brusc tensionata si ne-relaxata, si canci tavaleala, dupe aia!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6859,702,'laurie','','','69.131.172.203','2007-10-18 16:29:29','2007-10-18 14:29:29','thanx 4 the image, gropare. chicken will never taste the same :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6860,702,'Miruna','mirunavasilescu@yahoo.com','http://potsafacsiasaceva.blogspot.com/','86.106.59.163','2007-10-18 16:29:45','2007-10-18 14:29:45','Cine mai zice \"nagÃ¢Å£\"? =))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(7454,738,'irina','irinamimoza@yahoo.com','','86.121.21.71','2007-10-28 13:02:27','2007-10-28 11:02:27','\"se sparg ouale pe rind intr-o farfurioara si li se da drumul in cratita cu grije. \"\r\n\r\nasta e reteta grea. tre\' sa ai mare grijE cand dai drumu oualelor.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7470,738,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2007-10-28 22:39:24','2007-10-28 20:39:24','@ cocofifi: si ca sa-tz dai sama de ce cumnat coios, da\' neamtz am io, amu-s doi ani de cand i-am dat mesaj de Pasti cu Hristos a-nviat sh d-alea. Sh el - care stie romaneste de la tractoristii romani cu care-o lucrat - imi da SMS inapoi: \"Restul familiei sunt dorm. Numai eu sunt amviat!\"',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7456,735,'nenea cosmos','domnu_cosmos@yahoo.com','http://www.nenea.wordpress.com','92.80.55.176','2007-10-28 13:51:04','2007-10-28 11:51:04','ÃŽn puii mei, Ã®Å£i mai explic odatÄƒ cÄƒ azi eÅŸti mai obosit ca mine: erau bolovanii luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata luâ€™ tata moÅŸu.\r\n\r\nCLAR?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(7385,735,'CAESARUS','caesarus@adresafalsa.ro','','79.113.88.253','2007-10-27 17:09:42','2007-10-27 15:09:42','Maaa canaee tat am stat si n-am zis nimica la tate prostiile pe care le-ai facut si le-ai zis maaa.... da sa te pishi tu ma pe ruinile alea maaaa.....asa te-am invatat maaa...dupe ce te-am luat la mine in casa maaa....pe chirie ieftina....te pisi tu pe ruinile mele......\r\n\r\nDa maaaa......semnu....semnu ala indicator....l-ai luat acasa....sau s-o dus tata scoala pe apa sambetei maaa..',0,'1','Mozilla/5.0 (Macintosh; U; Intel Mac OS X; en) AppleWebKit/419.3 (KHTML, like Gecko) Safari/419.3','',0,0),(6862,702,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-10-18 16:49:01','2007-10-18 14:49:01','@ laurie: Nel... ÄƒÄƒÄƒ... nu e cazu\' sa devii vegetarian! \r\n\r\n@ Miruna: cum cine!!! NAGÃ‚Å¢ELE, clar!!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6863,702,'laurie','','','69.131.172.203','2007-10-18 16:58:35','2007-10-18 14:58:35','vegetariana nu ma fac veci, gropare iubitor de fauna ce esti ;) oricum, nu dupa ce-am vazut c-ati mancat la tilisca :) . and fuck that nelu guy already, ok? peace, brotha',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6864,702,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','85.186.77.129','2007-10-18 18:20:50','2007-10-18 16:20:50','serios, chiar era impetuos necesar sa pui mirobolantul link nomber 2? fuck! o sa mananc numa picioare de broasca de-acum inainte! cine stie pe la ce cocosei au fost gainie astea inainte sa la mananc io?',0,'1','Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.0.12) Gecko/20070731 Ubuntu/dapper-security Firefox/1.5.0.12','',0,0),(7559,746,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','82.77.126.148','2007-10-30 10:56:55','2007-10-30 08:56:55','in capatul lu\' linia 3? acolosha la poligon?\r\ndaca da, viu sa te vaz, ca sunt prin zona! :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7382,720,'alexandru petria','apetria@gmail.com','http://realiatealuipetria.blogspot.com/','92.81.148.30','2007-10-27 12:45:37','2007-10-27 10:45:37','Da\' la Salina Ocna Dej ai fost?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows 98; Win 9x 4.90; SaveWealth)','',0,0),(6878,706,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2007-10-18 22:56:23','2007-10-18 20:56:23','@ zgurÄƒ: oare Sarkozy ceteshte groparu.ro? Ceee tareeee aaar fiiii... (\"Sarko, lasi pls doo boambe peste rushi? Plsssss...!) \r\n\r\n@ Miruna: nu, lumea e plina de abstinenti de la abstinenta! Ca io asa fac, ma abtin sa ma abtin.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6879,703,'WhiteWolf','contact@whitewolf1.info','','89.39.82.246','2007-10-18 23:56:17','2007-10-18 21:56:17','Inca nu-i cazu\', Gropariule\r\nShezi, ia si te linisteste si apoi te potolesti; da ? :P\r\nMai intai trebuie sa se pronunte cercetatorii americani si oamenii de stiinta arondati ziarului Libertatea',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6838,701,'varza','tudor.maris@gmail.com','http://rottencabbage.haipa.ro','58.106.103.21','2007-10-17 12:14:15','2007-10-17 10:14:15','Virtuozitate pura si istorie asemenea.\r\nO mentiune doar... Logan Clio Remes as fi zis eu......\r\nPe bune no, cine-i Mahindra? Da Logan?\r\nSi, pentru a completa istoricele figuri, propun urmatorii clasici:\r\nTom Jerry Remes\r\nBugs-Bunny Elmer-Fudd Remes, cu variatia Bugs-Bunny Yosemite-Sam\r\nRoad-Runner Wile-E.-Coyote Remes\r\nPepsi Coca-Cola Remes\r\nOrange Vodafone Remes\r\nCarrefour Cora Remes\r\nMetro Selgros Remes\r\nIo macar pe astia ii stiu, nu bag Mahindre in post... :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6839,698,'ip','ipecheanu@gmail.com','','89.40.228.179','2007-10-17 12:15:29','2007-10-17 10:15:29','chiar ma gandeam cu ce te-am putut deranja,mai ales ca nici nu eram de aceeasi parte a  baricadei(a se intelege mesei).Si mai usor cu flashback-urile,sa nu cazi in astenie:D',0,'1','Mozilla/5.0 (Macintosh; U; PPC Mac OS X Mach-O; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6840,700,'Vlad','dez_legat@yahoo.com','','79.113.137.216','2007-10-17 12:37:45','2007-10-17 10:37:45','este bautura?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6880,706,'WhiteWolf','contact@whitewolf1.info','','89.39.82.246','2007-10-18 23:58:24','2007-10-18 21:58:24','Or\'sh\'cum, are chuaie fomeia asta.\r\nNu-i de colo \'shea sa renuntzi la croissantu\' zilnic , prezidential. Ma\'ntzelegi ?\r\nCa sa zic ashea',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6833,699,'VIP','ps@yahoo.com','http://vipuri.blogspot.com','213.157.188.71','2007-10-17 09:46:27','2007-10-17 07:46:27','ma, di ce be daca nu rezista?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6834,700,'Botache','nasturei_verzi@yahoo.com','http://www.nasturei.wordpress.com','82.77.126.148','2007-10-17 09:53:40','2007-10-17 07:53:40','Cum sa compari rumanu cu cei mai mari bautori de pe planeta asta, rusii? Noi suntem mici copii pe langa ei. :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.0; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6835,700,'conia','','','193.226.17.210','2007-10-17 10:04:55','2007-10-17 08:04:55','In loc sa cautati cine bea mai mult, mai bine pe ceilalti, ca asa ramane bautura pentru noi.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.2; SV1; .NET CLR 1.1.4322; .NET CLR 3.0.04506.30)','',0,0),(6875,703,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2007-10-18 22:19:28','2007-10-18 20:19:28','Deci ba, de fiecare data cand dau click acilea, tre\' sa restartez calcu, ca mi-i reflex de cand vedeam ecran albastru!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6876,706,'zgura','','','79.113.129.173','2007-10-18 22:24:05','2007-10-18 20:24:05','Eu pot sa zic sigur cine nu se mai baga: Sarkozy.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6877,706,'Miruna','mirunavasilescu@yahoo.com','http://potsafacsiasaceva.blogspot.com/','86.106.59.163','2007-10-18 22:44:59','2007-10-18 20:44:59','Pai probabil ca fix pozitia asta, sau sa zic mai bine lipsa ei, a stat la baza rupturii.\r\nSi ce, acum, ca nu e permis pacatul carnal, e plina lumea de abstinenti?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6842,698,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-10-17 13:43:43','2007-10-17 11:43:43','Apai la cate vitamine are berea, io zic ca mai am o sansa! :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6843,701,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-10-17 14:06:18','2007-10-17 12:06:18','Mah, Mahindra e o masina exact ca Loganu\', atata numa ca e mult mai meseriasha si mai facuta in India decat Loganu\'.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6844,701,'george','reallyinsane@gmail.com','','193.138.195.202','2007-10-17 14:30:06','2007-10-17 12:30:06','Corect ar fi fost Dacia Mahindra RemeÅŸ.\r\nPentru cÄƒ RenÃ² face Logan in RomÃ¢nica la Dacia ÅŸi mai face Logan Ã®n India la Mahindra.\r\n(doar cÄƒ Loganu indian e mai tare http://www.mahindrarenault.com/logan/logan-showcase-gallery.html)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6845,701,'DÃ£nilÃ£','','','82.77.202.17','2007-10-17 15:38:38','2007-10-17 13:38:38','Bill Steve Remes se califica ?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6846,701,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-10-17 15:38:59','2007-10-17 13:38:59','@ george: True. Si si carnea de vita indiana e mai tare! Ca cica Zebu-urile alea is pline de zgarciuri.\r\n\r\n@ Danila: nush, ca cica, dupa cum se stie, Steve o furat de la Bill TÄ‚T.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6873,702,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2007-10-18 22:14:57','2007-10-18 20:14:57','Copii, amu pe bune: nu mai mancati legume, finca pe ele se pune pipi de cal si caca de vaca! Mai bine o puicutza cu ceva experientza de putzulica. Parerea mea...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6874,706,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2007-10-18 22:18:46','2007-10-18 20:18:46','Da, era o reclama la branzica frantzulozeasca pre care o cheama President: \"Il n\'ya a rien au dessus du president!\"\r\n\r\nNa ui amu ca cica nij nevasta presedintelui nu mai sta deasupra lui... da\' daca Dumnezeu isi da si el demisia din Dumnezeul de deasupra presedintelui? Atunci sa te tii! (sper sa se permita dupe aia pacatul carnal, aia ar fi super)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6852,701,'depe','blogdeumor@yahoo.vom','http://www.blogdeumor.wordpress.com','84.232.215.243','2007-10-18 12:10:21','2007-10-18 10:10:21','Dumnezeu Diavolul Remes',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(7077,711,'Hammer','hammer@alpinet.org','http://www.alpontos.wordpress.com','86.120.55.79','2007-10-23 13:25:40','2007-10-23 11:25:40','Nush de ce am impresia ca i-am vazut ceva poze de prin pruncie si avea aceasi privire inconfundabila, da\' mai candida :-D',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(6850,700,'raluca','ralucaghervan@yahoo.com','','89.137.11.203','2007-10-18 00:52:51','2007-10-17 22:52:51','pentru ca cine nu stie de Aisha, merita sa afle. E o introducere a acoolului dublu rafinat in trend. Se ia Alcool Dublu rafinat, se ia santal de fructe cat mai diverse, se amesteca 3 l de suc la 1 de alcool, se serveste cu gheatza si pentru cei mai fitzoshi cu umbrelutza si felii de ananas si portocala pe scobitoare. e foarte bun. numa cand vrei sa te ridici de la masa, sa ai mare grija ca reperele nu sunt chiar unde le fixasheshi, si picioarele nu sunt chiar unde le-ai comandat sa fie.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.0.3705; .NET CLR 1.1.4322)','',0,0),(6823,700,'Tina','tinaivan83@yahoo.com','','81.196.54.124','2007-10-17 07:19:54','2007-10-17 05:19:54','pe mine ma cheama Ivan, si as vrea sa nu fie nevoie sa dorm 10 ore dupa ce beau o bere, ca altfel dorm la birou, cu capul pe tastatura...cat despre ce vorbiti voi aici, n-am baut niciodata...\r\ncat despre origini rusesti...nici strabunicu\' nu era rus...mai departe nu mai stiu...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6750,693,'Marius','pop.marius@gmail.com','http://Lityx.blogspot.com','89.123.80.120','2007-10-14 21:04:44','2007-10-14 19:04:44','Ai dreptate si imi cer scuze. Scuze si pentru off-topic gropare. La mai mare!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6798,700,'Miruna','mirunavasilescu@yahoo.com','http://potsafacsiasaceva.blogspot.com/','86.106.59.163','2007-10-16 18:58:35','2007-10-16 16:58:35','Deci da, pentru ca bunica mea rusoaica il baga sub masa pe bunicul meu care era rus numa\' pe un sfert, deci da!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6799,697,'TiliÈ™ca, episodul 2 - flagrantul at Jurnal de noapte','','http://www.andreicrivat.ro/2007/10/16/tili%c8%99ca-episodul-2-flagrantul/','212.227.64.193','2007-10-16 19:09:24','2007-10-16 17:09:24','[...] strÄƒduit s-o ascundem cÃ¢t mai bine, de aia ne-am retras Ã®n MÄƒrginime, unde n-a intrat picior de nimeni&#8230; da&#8217; instinctu&#8217; de jurnalist al naÈ™ului Victor n-a rezistat È™i ne-a dat Ã®n [...]',0,'1','Incutio XML-RPC -- WordPress/2.2','pingback',0,0),(6767,698,'ip','ipecheanu@gmail.com','','89.40.228.179','2007-10-15 18:28:23','2007-10-15 16:28:23','Daca nu plecam,filozof ramaneam.Oricum,a fost un privilegiu sa te cunosc in carne si oase(si mult accent ardelenesc).',0,'1','Mozilla/5.0 (Macintosh; U; PPC Mac OS X Mach-O; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6768,698,'leat','satraiti@army.com','','62.224.214.25','2007-10-15 20:08:43','2007-10-15 18:08:43','hahahahaha, gropare! mare figura esti!!',0,'1','Mozilla/5.0 (Macintosh; U; PPC Mac OS X Mach-O; de; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6769,698,'WhiteWolf','contact@whitewolf1.info','','89.39.81.124','2007-10-15 20:33:29','2007-10-15 18:33:29','DÃ¢nd sa coboare si ultima treapta a modulului lunar, Neil Armstrong vede imprimate-n praful selenar niste urme ciudate. De opinci, parca.\r\nIngandurat, se departeaza nitel de modul si da sa se apropie de un crater.\r\nDin crater apare un tip neverosimil Ã®n context: cu palariuta mica si neagra si cu chimir. Creatura intinde hotarat mana catre Armstrong:\r\n- Servus, io mi-s Ion!\r\nAstronautul, siderat, il intreaba:\r\n- Si de unde esti tu?\r\n- Apai din Sibiu, dara.\r\n- Si cu ce ai venit aici?!, continua americanul.\r\n- Cu brÃ¢nza din Poiana! Noâ€¦\r\n<b>Q.E.D.</b>',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6770,698,'nenea cosmos','domnu_cosmos@yahoo.com','http://nenea.wordpress.com/','92.80.38.32','2007-10-15 21:00:23','2007-10-15 19:00:23','dau eu click pe saitu lu ciutacu jr si nu-ÅŸ cum apas da\' numa ce vad tot pe victor sugind berea aia asta vara. no, imi zic, Ã®i bai mare, tre sa ma gindesc, nu ca m-as pricepe. ma duc la dulap sa imi iau peruca mea preferata, aia blonda, mi-o pun pe cap si vin din nou la ecranu monitorului. incep gindirea:\r\n\r\nlogic, fiti atenti!\r\n\r\n1) daca ciutacu e in bustu gol inseamna ca astia ori s-au dus la mediterana si pe noi ne-au prostit ca au fost la taranoaia, ori la groparu la taranoaia e ca la mediterana, ori taranoaia lu groparu e la mediterana, deci logic, sibiul e pe o insula.\r\n\r\n2) au zis ca se duc sa bea bere, ciutacu e cu berea in mina, deci tot ce am gindit la punctul 1) e corect\r\n\r\n3) daca vecinu din poza cu ciutacu are casa de 10 etaje atunci si groparu o avea macar de vreo cinci, deci groparu e bogat, deci e bine sa sapi gropi\r\n\r\n4) daca e bine sa sapi gropi de ce vorbeste de oierit? pai dintr-un singur motiv, asa pun ei capcane sa prinda oile\r\n\r\n5) ca sa faca avere groparu a sapat gropi asa multe de a prins toate oile din muntii nostri (care sint pe malul mediteranei) si si-a facut casa cu cinci etaje\r\n\r\n6) intrebare: cite gropi si cite oi a prins vecinu lu groparu de si-a facut casa de 10 etaje si de aici. logic, au mai ramas oi? raspuns: da, una. au mincat-o ei dupa ce au tranformat-o in sloi.\r\n\r\nconcluzie finala:\r\n\r\natentie mare ca logica a invins\r\n\r\ngroparu e de pe malu marii. vecinul lui e pescar la copca (gropi in gheata, nu stiti nimic!).\r\nnumarul oilor este egal cu numarul gropilor.\r\nciutacu i-a omorit pe crivat si pe jeg ca aia lipsesc din poza.\r\ngroparu e marinar. marinar de oi. le mulge si face brinza de peste.\r\n\r\nne dai bre si noua niste brinza de peste, trai-ti-ar familia?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(6789,699,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-10-16 15:44:46','2007-10-16 13:44:46','Am si sarbeutorit!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6790,700,'Andrei Crivat','andrei@andreicrivat.ro','http://www.andreicrivat.ro','89.137.83.141','2007-10-16 16:16:26','2007-10-16 14:16:26','mo, crede-ma, nu rusii bea mai mult si mai mult in veatza. rusoaicele be, crede-ma. ca-s om trecut prin viata. si prin rusoaice. sa vezi doamnele cum be, ma, ai fi invidios. cu adevarat.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; SLCC1; .NET CLR 2.0.50727; Media Center PC 5.0; .NET CLR 3.0.04506)','',0,0),(6791,700,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-10-16 16:18:27','2007-10-16 14:18:27','Oare doamnele alea erau neshte barbati cu tzitzi, si d-aia beau?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6788,699,'Basty','basty@canvas.ro','http://basty.wordpress.com','82.77.126.21','2007-10-16 15:32:50','2007-10-16 13:32:50','Asadar olteanul cel prieten, cumsecade si politicos aka Huby aka CÃ¢rlanuâ€™ a fost detasat de catre agentia nationala agriculturalo-secreta de la numarat oo slash beri la numarat oi ? Eu as sarbatori asea zi glorioasa.',0,'1','Mozilla/5.0 (Macintosh; U; Intel Mac OS X; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6786,699,'Tina','tinaivan83@yahoo.com','','81.196.54.124','2007-10-16 13:50:53','2007-10-16 11:50:53','finca am verificat....:)))\r\nesti contagios.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6787,699,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-10-16 14:39:49','2007-10-16 12:39:49','Apai cu contagiunea: mie doctoru\' mi-o zis ca ciuperca aia urata a mea nu e transmisibila. Ba ca mai e si comestibila!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6792,700,'Andrei Crivat','andrei@andreicrivat.ro','http://www.andreicrivat.ro','89.137.83.141','2007-10-16 16:20:31','2007-10-16 14:20:31','nu ma gropare, ca si io am vrut sa-mi repar orgoliul cand am vazut ca ma imbatam de 10 ori mai usor ca ea... da\' am verificat, era fomeie pana in maduva oaselor, ca sa zic asa. alta scuza nu gasim ? ca mi-ar prinde si mie bine...',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; SLCC1; .NET CLR 2.0.50727; Media Center PC 5.0; .NET CLR 3.0.04506)','',0,0),(6793,700,'Andrei Crivat','andrei@andreicrivat.ro','http://www.andreicrivat.ro','89.137.83.141','2007-10-16 16:21:18','2007-10-16 14:21:18','m-ar ajuta la psihic, adica',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; SLCC1; .NET CLR 2.0.50727; Media Center PC 5.0; .NET CLR 3.0.04506)','',0,0),(6794,700,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-10-16 16:24:15','2007-10-16 14:24:15','(tot stau si ma gandesc, si numa\' chestii vulgare imi vin in cap!)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6795,700,'Pandora','bluemotogirl@yahoo.com','http://cutiapandorei.blogspot.com/','82.77.126.3','2007-10-16 17:24:13','2007-10-16 15:24:13','Nu numai rusoaicele... Eu am cunoscut 3 lituanience cat am fost in SUA. Foarte simpatice fetele. Atat ca atunci cand erau ele in casa, disparea orice urma de alcool in cel mult 5 minute (de la vin si bere la votka cu culoare dubioasa). Am ajuns sa nu le zicem, noi romanasii, ca aveam alcooale la noi, si ne prefaceam ca bem suc...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6800,698,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2007-10-16 21:37:44','2007-10-16 19:37:44','@ ip: cum Dumnezeu sa-l iau de afront? Da\' cand am cetit ca o fo\' privilegiu sa ma cunosti (apropos, p-orma m-am prins io cine-mi esti :D) am analizat foarte la rece cand am mai auzit vorbele astea singura data in viatza mea: cand eram spermatozoid - campion - sh m-am intalnit cu d-na ovul. Numa\' atunci. Si am avut un flashback.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6797,698,'ip','ipecheanu@gmail.com','','89.38.21.186','2007-10-16 18:31:29','2007-10-16 16:31:29','poate ma vei lamuri candva de ce ai luat comentariul meu ca pe un afront personal...',0,'1','Mozilla/5.0 (Macintosh; U; PPC Mac OS X Mach-O; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6764,698,'Miruna','mirunavasilescu@yahoo.com','http://potsafacsiasaceva.blogspot.com/','86.106.59.163','2007-10-15 15:27:59','2007-10-15 13:27:59','Pare frumos la voi acolo. \"The paragon of animals\", auzi! :)):))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6765,698,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-10-15 15:53:01','2007-10-15 13:53:01','Da, e tare batranul Will.\r\n\r\nIti dai seama dac-ar fi avut blog? Oioioi... (gratar de oi)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6753,697,'MaTr3o','matr3o@yahoo.com','http://matr3o.com','92.80.204.137','2007-10-15 00:42:01','2007-10-14 22:42:01','paraschiva rules',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6783,699,'Tina','tinaivan83@yahoo.com','','81.196.54.124','2007-10-16 13:26:09','2007-10-16 11:26:09','pai daca n-are a face cu corpul, am exclus adjectivul \"frumoasa\"....ti-am zis eu ca-s prea multe calitati sa le gasesti la o singura femeie...\r\nsi nu cred ca ai vreun neuron de femeie in cap...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6778,699,'Tina','tinaivan83@yahoo.com','','81.196.54.124','2007-10-16 10:07:38','2007-10-16 08:07:38','Gropare, putem sa te clonam? :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6779,699,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-10-16 10:16:12','2007-10-16 08:16:12','Hmmm!!! Nu mai bine clonati toate fetele frumoase, iubitoare, destepte, sensibile, carora le place CounterStrikeul si folbalul, barbatii cu par pe spate si berea, si cand o gasiti pe prima mi-o aratati si mie, sa vad daca intr-adevar exista asa ceva?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6762,414,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-10-15 14:44:21','2007-10-15 12:44:21','Ce-avetz mah! Am zis io ca nu-mi place pescuitu\'?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6758,697,'Victor Ciutacu','victor@ciutacu.ro','http://www.ciutacu.ro','82.76.75.160','2007-10-15 12:06:07','2007-10-15 10:06:07','Da\' fie ca inca ai cadere, Groparimea Ta:)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(6759,472,'Teo','teo.iorga@yahoo.com','','86.123.139.103','2007-10-15 13:43:23','2007-10-15 11:43:23','La bobitele alea li se spune miufci defapt. Stiu ca am avut si eu :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6780,699,'Tina','tinaivan83@yahoo.com','','81.196.54.124','2007-10-16 10:25:20','2007-10-16 08:25:20','cred ca va trebui sa restrangi aria de calitati si conditii daca vrei sa vezi vreo clona in viata asta...:))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6781,698,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-10-16 11:11:03','2007-10-16 09:11:03','@ ip: deci ciutacii deja avusesera privilegiul asta de a-mi vedea madularele, ca sa zic asa, ca sa nu mai vorbim de jegster si de crivatzi. Si atunci ma intreb: oare chiar eu am publicat comentariul asta al tau?\r\n\r\n@ Cosmos: clopurile le-am primit de la Neil Armstrong , cand i-am vandut drepturile de comercializare a branzei de pejte. Da\' sa nu mai zici la nime\'.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6782,699,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-10-16 11:16:35','2007-10-16 09:16:35','De ce? Eu sunt o asemenea femeie, bine ascunsa, de alfel, intr-un corp care nu are nimic in comun cu femeile, afara numai de momentele in care fac dush cu ele (OK, poate la faza cu paru\' de pe spate poate am exagerat!)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(6757,697,'VIP','ps@yahoo.com','http://vipuri.blogspot.com','213.157.188.71','2007-10-15 10:02:45','2007-10-15 08:02:45','e o doamna... sa-ti traiasca! :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(8146,790,'PhenoBarbieDoll','poisongirl94@yahoo.com','http://blog.360.yahoo.com/poisongirl94','193.230.230.101','2007-11-16 11:01:46','2007-11-16 09:01:46','Bunicutza nu blogareste, ci blogeste, pentru ca, citez, \"am intrat si eu in randul blogistilor\".',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8660,807,'Felix','felix.felix@gamil.com','','213.233.122.144','2007-11-23 17:52:45','2007-11-23 15:52:45','astea sint mere pentru export, nu punem noi dintii pe ele...',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; InfoPath.1)','',0,0);
INSERT INTO `wp_comments` VALUES (8661,807,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2007-11-23 17:57:22','2007-11-23 15:57:22','Ye, mah. Da\' nu te-ai prins ce vroiam sa zic io cu imajinea asta?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8212,790,'baghy','baghy83@lycos.it','http://baghy.info/','78.12.13.1','2007-11-16 23:01:10','2007-11-16 21:01:10','lasa ca are copos adsense pe blog :)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(8555,801,'Usim','mihaimitan@gmail.com','','87.237.108.33','2007-11-22 23:03:57','2007-11-22 21:03:57','Te astept si moi.\r\nSi desi sunt de acord cu tine cum ca tre\' sa ne avem ca fratii io nu poci sa ma inteleg cu persoanele ce fac parte din popoarele care urmeaza, strict in urmatoarea ordine: cea serpiliana, a vulturiana, reptiliana si balauriana.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; .NET CLR 2.0.50727)','',0,0),(8557,799,'Catalin','catalin_heghes@yahoo.com','http://sec.ablog.ro','86.125.185.165','2007-11-22 23:05:44','2007-11-22 21:05:44','nu stiu... inca nici io ca nu m-am decis, dar cam asta e rationamentu dupa mine. cum e prea mare compromisul, probabil ca voi lua o decizie ceva mai spontana cand m-oi vedea cu stampila-n mana',0,'1','Mozilla/5.0 (Windows; U; Win 9x 4.90; en-GB; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(8668,807,'Arhi','admin@arhiblog.com','','82.77.85.53','2007-11-23 18:35:39','2007-11-23 16:35:39','ma, te insori?!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(8678,807,'andreanum','andreanum@yahoo.com','http://andreanum.wordpress.com','89.40.135.63','2007-11-23 20:35:29','2007-11-23 18:35:29','au lua\' mere?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(8679,807,'IepurasulAtomic','praetorian21uk@yahoo.com','','62.217.245.97','2007-11-23 20:39:48','2007-11-23 18:39:48','Ba, io atat va zic...Gropare, nu te baga :)...se ajunge la peste 40 de comentarii si daca tre\' sa scriu io pana la 40.\r\n\r\nAcuma ma Gropare, cum ar fi sa fie fix 69 de comentarii? Fara insinuari, numa\' asha, ca-i misto numaru\'. Eh, vezi cum ma gandesc io la toate!? :) Vezi sa tii berea rece pe cand ma intorc.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(8644,805,'cronicaru\'','tzone_a@yahoo.com','http://cronicaru.blogspot.com/','193.230.230.101','2007-11-23 14:00:47','2007-11-23 12:00:47','hehe, buna\r\nia fii atent acilea ce facu un baiet de prin pietele din Satu Mare:\r\nhttp://crinadunca.blogspot.com/2007/11/gigi-face-ct-ceapa.html',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(8498,798,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-11-22 08:57:15','2007-11-22 06:57:15','aaaaaarrrghhhhhh, toooo laaaaate...\r\n\r\nLe-o zis muma-mea, da\' creca o uitat sa le zica si de .ro.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8197,790,'InnOcente','innocente@innocente.ro','http://www.innocente.ro','89.165.215.227','2007-11-16 18:57:04','2007-11-16 16:57:04','Eu n-am Ã®nÅ£eles ce trebuie sÄƒ fac. Oricum votez cu \"MÄƒiAnimalule\" :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(9369,842,'WarSong','stygos@yahoo.com','http://www.warsongu.wordpress.com','86.104.198.22','2007-12-08 18:05:36','2007-12-08 16:05:36','bre, azi is cam dislexic...am citit \"inginer si demon\", si \"va pute infiorator gaura\"... plm, ma duc sa ma culc...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(7634,753,'WhiteWolf','contact@white-wolf.ro','http://white-wolf.ro','89.39.82.118','2007-11-02 02:55:09','2007-11-02 00:55:09','Bottom line\r\nIntr-o foarte buna (si insorita, ti-o doresc, ca face bine la reumatizm) zi ai sa iti remembÃ£resti cu mare plejÃ£r anii asthia original de tumultuosi.\r\nDeci, da. Te poti potoli. Pana maine :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7635,754,'WhiteWolf','contact@white-wolf.ro','http://white-wolf.ro','89.39.82.118','2007-11-02 02:59:32','2007-11-02 00:59:32','Bonus Track :P\r\nPana la urma, viteza e o problema de bani',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7636,753,'eu,Miruna','mirunavasilescu@yahoo.com','http://potsafacsiasaceva.blogspot.com/','86.106.59.163','2007-11-02 03:55:43','2007-11-02 01:55:43','Te-a recunoscut dupa voce? :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(9024,831,'baghy','baghy83@lycos.it','http://baghy.info/','78.12.2.226','2007-11-30 00:23:20','2007-11-29 22:23:20','asa ca intre ardeleni :)))',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(9146,839,'spamuletz','','','62.217.247.242','2007-12-03 18:37:41','2007-12-03 16:37:41','gropare, Ã®Å£i trebuie ÅŸi-o motivaÅ£ie, nu doar portocale, altfel nu-Å£i iese... Unii se lasÄƒ de boalÄƒ, alÅ£ii cÄƒ-i lasÄƒ sau, invers,  de dragul aproapelui...  Mie mi-a ieÅŸit figura: de 6 ani cafeaua de dimineaÅ£a are gust mai bun.',0,'1','Mozilla/5.0 (SymbianOS/9.2; U; Series60/3.1 NokiaN95/12.0.013; Profile/MIDP-2.0 Configuration/CLDC-1.1 ) AppleWebKit/413 (KHTML, like Gecko) Safari/413','',0,0),(9135,839,'vizionarul','alinmiron_19@yahoo.com','http://vizionarul.wordpress.com','82.208.146.10','2007-12-03 14:06:11','2007-12-03 12:06:11','io am reusit sa ma las doar dupa o pneumonie dusa pe picioare timp de vreo 3 luni si ceva - tuseam si credeam ca de la tigari, da cand am ramas doar cu ramele de la plamani nenea de la radiografii s-o speriat si-o crezut ca mi-o incurcat radiografiile cu ale unui bosorog cu silicoza de la Copsa-Mica. Dupa pneumonia asta, un picior rupt, 3 saptamani de stat cu cizma, in pat... si in plus, o iubita tare focoasa cu care am facut muuuulta muuulta.....muuulta dragoste. De 5 ani de zile m-am lasat de fumat, si in primele luni dupa perioada critica ma distram pe seama disperarii amicilor mei ce ramaneau fara tigari... Asa ca gropare, multa bafta!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.10) Gecko/20071115 Firefox/2.0.0.10','',0,0),(8670,807,'eu,Miruna','mirunavasilescu@yahoo.com','http://potsafacsiasaceva.blogspot.com/','86.106.59.163','2007-11-23 19:40:53','2007-11-23 17:40:53','Daaa, tocmai voiam sa scriu ca daca ma uit cumva mai cas seamana cu stema aia comunista. Da\' ma bucur ca nu-s singura care vede steme de republica :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7668,649,':: WhiteWolf | Las Ca Merge :: &raquo; Impreuna Salvam Cu Avant','','http://www.white-wolf.ro/?p=244','89.38.214.199','2007-11-03 10:38:12','2007-11-03 08:38:12','[...]  gaseste o super dileala pe HotzNiuz si pentru ca nu-i fire din aia de se abtine, improasca un post absolut corespunzator. Lumea, care plictisita, care curioasa sau, pur si simplu, care mimeaza ca lucreaza sarind (de [...]',0,'1','Incutio XML-RPC -- WordPress/2.3','pingback',0,0),(7669,756,'PhenoBarbieDoll','oana.gavrila@mediafax.ro','http://blog.360.yahoo.com/poisongirl94','86.120.236.133','2007-11-03 10:49:49','2007-11-03 08:49:49','Groparu must go on!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 2.0.50727)','',0,0),(7671,756,'Arhi','arhi@arhiblog.com','http://arhiblog.com','82.79.66.93','2007-11-03 12:42:25','2007-11-03 10:42:25','voi ati inteles relativ pe dos. adica omul se exprima ca fluture ala se lasa de blogea, nu el',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7672,756,'PhenoBarbieDoll','oana.gavrila@mediafax.ro','http://blog.360.yahoo.com/poisongirl94','86.120.236.133','2007-11-03 12:59:25','2007-11-03 10:59:25','\"sa faca ce si pe mine ma bantuie de ceva vreme incoace de cand calitatea postarilor mele se tat dilueaza pana devine alcool pur\". Am \'ntzeles ca si pe Groparu\' il mai bate din cand in cand un gand. Deci Gropare, sa nu te mai bata din astea, ca te bat cititorii :D mai ales acu\' ca esti starlet si te recunoaste lumea.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 2.0.50727)','',0,0),(7698,757,'WarSongu','eternaldawnlord@yahoo.com','http://www.warsongu.wordpress.com','193.32.3.83','2007-11-05 10:52:40','2007-11-05 08:52:40','nu bagi un sontac panancoa, sa bei si cu mine?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; FunWebProducts; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(7699,755,'WarSongu','eternaldawnlord@yahoo.com','http://www.warsongu.wordpress.com','193.32.3.83','2007-11-05 10:55:21','2007-11-05 08:55:21','ce kilu meu e aia SEO?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; FunWebProducts; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(7674,756,'WhiteWolf','contact@white-wolf.ro','http://white-wolf.ro','89.32.115.182','2007-11-03 14:23:34','2007-11-03 12:23:34','Unii se lasa, altii se apuca sau se .... reapuca. Parca, viatza-i zice; nu ?\r\nOricum, io zic sa incerci sa observi \"the big picture, Gropare. Flututele e -cel putin de cand te stii, tu, pe muma Terra- ceva, prin definitie, efemer.\r\nVietzuieste putin, intens si, mai nou, prin reclame la tv. Mai putin pe blog.\r\n Far\' de Gropar, insa, ne va fi si mai greu spre imposibil. \r\nLa tÃ£tzi :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7675,753,'nenea cosmos','domnu_cosmos@yahoo.com','http://www.nenea.wordpress.com','92.80.26.167','2007-11-03 16:43:08','2007-11-03 14:43:08','era un banc unde se zice ca 1000 de avocati pe fundul marii reprezinta un bun inceput.\r\n\r\naaa, era cu bancheri postul asta? cu aia care iti iau peste 200 000 euro ca sa iti dea 100 000 euro?\r\n\r\nEXTINDETI BANCUL!',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(7676,753,'Usim','mihaimitan@gmail.com','','86.121.184.237','2007-11-03 19:13:39','2007-11-03 17:13:39','Bancherul iti imprumuta umbrela intr-o zi insorita si ti-o cere inapoi cand ploua.........\r\n\r\nE citat, nu-mi apartine.',0,'1','Opera/9.10 (Windows NT 5.1; U; en)','',0,0),(7700,758,'WhiteWolf','contact@white-wolf.ro','http://white-wolf.ro','89.39.81.86','2007-11-05 14:17:08','2007-11-05 12:17:08','Poate nu suntem noi suficient de inteligentsi , Gropare.\r\nO fi vreo noua varianta la Numa(i)-Numai(i) song si are omu\' cine stie ce copyright pe ea.\r\nOricum, Arhi zice bine ca sa iti vezi de trebi :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8792,807,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','82.77.126.148','2007-11-26 10:39:10','2007-11-26 08:39:10','care margineanu statea pe vine si cauta capete de... sfecla? :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7680,756,'July','jullya24@yahoo.com','','83.103.179.55','2007-11-03 22:28:52','2007-11-03 20:28:52','Cum se poate sa fi avut si tu asa ganduri?!....lasa tu sa apreciem noi cat de buna e calitatea postarilor tale....pan amu  e buna...foarte buna....in afara de asta( care cam dezamageste)...unde ai mai vast\' tuh Gropar\' care sa se lase?...si oricum nu te lasam noi pe tine..:P',0,'1','Opera/9.10 (Windows NT 5.1; U; en)','',0,0),(7703,758,'vizionarul','alinmiron_19@yahoo.com','http://vizionarul.wordpress.com/','89.35.80.185','2007-11-05 16:54:58','2007-11-05 14:54:58','normal. ca doar dc-ul este urmasul mirc-ului. La mine in retea, cand cauti muzica gasesti m**nele si cam atat... dar sub diverse denumiri.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7704,759,'kmi','camelianeculai@gmail.com','','80.86.103.122','2007-11-05 17:58:14','2007-11-05 15:58:14','Ai stat vreodata cu chirie? Eu am stat 5 ani, intr-o garsoniera de 22 mp. In 2000 dintr-un salariu de 150 usd, 75 usd ii dadeam pe chirie...crede-ma ca atunci imi tremurau mainile mai tare ca acu\', la banca/credit...\r\nCe sa zic?...\"Nu e vina mea daca parintii tai nu sunt milionari. va fi insa NUMAI vina mea, daca socrii nu vor fi\" :)))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7705,759,'kmi','camelianeculai@gmail.com','','80.86.103.122','2007-11-05 17:59:59','2007-11-05 15:59:59','scuze, scuze\r\n faza de la final era \"nu e vine ta daca parintii nu sunt milionari. Va fi insa numai vina ta, daca socrii tai nu vor fi...\" \r\nscuze.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7706,759,'Arhi','arhi@arhiblog.com','http://arhiblog.com','82.79.66.93','2007-11-05 18:08:16','2007-11-05 16:08:16','io am luat pe 31 banii, si pe 1  mai aveam exact 50 de lei...restul, la banci. deci da, muie',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7707,759,'CÄƒlÄƒ','acalarasu@gmail.com','http://adriancalarasu.wordpress.com/','62.217.241.242','2007-11-05 18:24:44','2007-11-05 16:24:44','Eu nu am nici o rata!\r\nDar luna asta vreau sa-mi depun actele ca sa-mi iau casa pe vreo 20 de ani si vreau deci sa le urez bancilor anticipat, inca de pe acum, stiind ce ma asteapta, vreau sa le urez, ziceam... EXACT!\r\n:))',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(7708,755,'CÄƒlÄƒ','acalarasu@gmail.com','http://adriancalarasu.wordpress.com/','62.217.241.242','2007-11-05 18:33:33','2007-11-05 16:33:33','search engine optimization?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(7709,759,'Usim','mihaimitan@gmail.com','','87.237.108.33','2007-11-05 19:46:51','2007-11-05 17:46:51','Bancherul iti imprumuta umbrela intr-o zi insorita si ti-o cere inapoi cand ploua.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; .NET CLR 2.0.50727)','',0,0),(7710,759,'nelli','mezeinelli@yahoo.com','http://www.mezeinelli.wordpress.com','213.233.103.121','2007-11-05 19:57:07','2007-11-05 17:57:07','MUIE, MUIE! FUCKFUCKFUCK! ar fi fain ca banca mea sa dea faliment :d pentru a ne plati nunta si a cumpara un laptop ne chinuim opt ani.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.9','',0,0),(7711,759,'WhiteWolf','contact@white-wolf.ro','http://white-wolf.ro','89.39.82.4','2007-11-05 20:17:53','2007-11-05 18:17:53','Usim, daca taceai, ......\r\nSi nu din cauza ca Groparu nu are chef de bance azi iar eu consider ca are motive ci, pur si simplu, pentru ca esti chiar in cunostiinta de cauza si nu poti pretinde ca habar nu ai ce camatarie cu acte in regula fac bancile.\r\nEventual, daca vrei, pot adauga chestii de genul <b>\"Cei mai bine platiti romani in luna iulie au fost angajatii din domeniul intermedierilor financiare. Cei care lucreaza in acest sector au castigat, in medie, aproape 3.000 lei. La polul opus s-au situat muncitorii din industria de prelucrare a lemnului, din tabacarie si croitorie. Salariul net din aceasta ramura a ajuns, in luna iulie, la aproximativ 600 lei. (raport al Institutului National de Statistica)\"</b> \r\nPentru ce ?\r\nPentru o <b>DAE de aproximativ 33-34%</b> la un card Real, de exemplu ?\r\nConsideri, -asa intre noi, vorbind- ca  o scumpire a creditului ca urmare a majorarii dobinzii-cheie  pare justificata ? - foarte simplu se poate renunta la ceva din \"costurile suplimentare\" pentru a compensa scumpirea finantarii in lei. Nu ?\r\nSau ca a baga \"la promotie\" servicii care ar trebui sa fie gratuite (asigurarile, de exemplu) e cel putin incorect ?\r\n Natural, sunt putini cei care stiu ca, in unele cazuri, cheltuielile cu plata comisioanelor reprezinta cel putin jumatate din costurile de dobinda. Daca mai adaugam si asigurarile si, poate, unele taxe, o sa constatam ca la finalul perioadei de creditare am dat pe comisioane si pe taxe trei sferturi din cit am platit dobinda :)\r\nDar macar pentru aia care o stiu, lasa-l pe Groparu sa fie suparat o zi pe luna :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7712,759,'ave13','mihaimara@yahoo.com','http://ave13.blogspot.com','194.102.61.163','2007-11-05 20:27:17','2007-11-05 18:27:17','Mda, bancile astea. Mama a primit sapt trecuta scrisoare de la banca. Cum ca pentru ei e foarte greu sa tina pasul cu inflatia si cu stie Dumnezeu ce alte motive de kko au scris acolo si ca au majorat dobanda la creditul facut de mama. Parca de la 9 la 12,5%. Nu sunt sigur d eprocente, dar stiu ca rata a crescut de la 51 la 57 de euro :S Pfff.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7713,750,'ave13','mihaimara@yahoo.com','http://ave13.blogspot.com','194.102.61.165','2007-11-05 20:41:52','2007-11-05 18:41:52','Ce bine ca il interesau doar tipele :D :)))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7714,759,'vizionarul','alinmiron_19@yahoo.com','http://vizionarul.wordpress.com/','89.35.80.185','2007-11-05 20:43:07','2007-11-05 18:43:07','io prefer sa fac pe bosketarul cu studii superioare, un pic rasist, xenofob si necunoscut decat sa fiu in rand cu lumea. Probabil ca atunci cand voi vrea sa fiu in rand cu lumea, nu voi mai purta blugi si adidasi ieftini si voi incerca sa transpir cat mai mult pentru compania/corporatia la care voi lucra, si pentru femeea pe care oi avea langa mine [desi imi voi pune intrebarea: De ce dracu sta asta cu mine?] ca sa am bani sa-mi platesc ratele la casa de care nu ma voi bucura in totalitate decat la batranete. Pana atuncea MuIe bancilor!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7715,737,'ave13','mihaimara@yahoo.com','http://ave13.blogspot.com','194.102.61.165','2007-11-05 20:46:30','2007-11-05 18:46:30','Si noi am vrut sa mergem la Muzee cu intrare moca dar ni s-a spus (am dat teelefoane la muzee) ca doar studentii intra moca, restul tre sa plateasca 6ron. 6ron x 3 muzee.... :S',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7719,759,'catalin','catalin_heghes@yahoo.com','http://sec.ablog.ro','89.137.109.142','2007-11-05 22:07:04','2007-11-05 20:07:04','CÄƒlÄƒâ€¦ sÄƒ nu te puie ala micu, roÅŸu, cu coarne sÄƒÅ£ iei credit. mai ai timp sÄƒ te rÄƒzgÃ¢neÅŸti. gÃ¢ndeÅŸte-te ca la o cÄƒsÄƒtorie cu o fufÄƒ ce-Å£i violeazÄƒ portofelu, Ã®n cel mai nasol mod, tÄƒtÄƒ luna. drept cÄƒ-i pe periodÄƒ fixÄƒ treaba, daâ€™ io zic sÄƒ cujeÅ£i bine Ã®nainte sÄƒ-Å£ pui verigheta!!!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(7717,758,'etranjer','strange@mail.com','','62.224.202.70','2007-11-05 20:55:35','2007-11-05 18:55:35','io am renuntat la DCC pentru ca ma zboara de pe hub din cauza IP-ului : \"only for romanians\". nici n-apuc sa-i bag in mama lor de romÃ¢nasi ca mine',0,'1','Mozilla/5.0 (Macintosh; U; PPC Mac OS X Mach-O; de; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7718,546,'creatzzzza','','','89.121.203.82','2007-11-05 21:18:51','2007-11-05 19:18:51','foarte tare... !! ;) esti super..:)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(7720,761,'catalin','solo@xsolo.biz','http://xsolo.biz','190.17.95.131','2007-11-05 22:28:10','2007-11-05 20:28:10','eventual facem un grup, ca sa terminam intaliencele mai repede. apropo nu sint probleme si prin scandinavia? :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7721,759,'Usim','mihaimitan@gmail.com','','87.237.108.33','2007-11-05 22:32:40','2007-11-05 20:32:40','WhiteWolf, sunt foarte constient de aspectele pe care le-ai prezentat in comentariu si, crede-ma, mi-as dori ca toti clientii existenti sau potentiali ai unei institutii de credit (in afara caselor de ajutor reciproc ale pensionarilor :-)) sa le cunoasca si din alte surse decat din reclamele bancilor si sa actioneze in cunostinta de cauza in momentul in care intra intr-o astfel de \"afacere\". Nevoia, din pacate, ii impinge pe foarte multi sa nu mai tina cont de nimic si, neavand alternativa, sa intre in vartejul ratelor.\r\nNu inteleg, insa, virulenta intrebarilor pe care mi le pui si la care nu am eu personal un raspuns ci doar o opinie care, cred, coincide cu opinia pe care o simt in comentariul tau. Mi-as fi dorit sa ma cheme Wolfowitz (ex presedinte al bancii mondiale) si ca tata sa aibe in proprietate una sau mai multe banci si atunci cred ca puteam sa-ti raspund de ce banca lu\' tata are dobanzi atat de mari si costuri care nu sunt transparente pentru client.\r\nCat despre vina de a lucra in sistemul bancar, afla ca voi lua masuri si cand voi face anii de pensie, Doamne ajuta, imi voi da demisia de unde lucrez si ma voi recalifica in tabacarie sau croitorie. Nu si in industria lemnului ca aia au bani multi ca fac coparseie la negru pe bani grei :-).\r\nM-o mancat si am postat o fraza pe care am auzit-o si eu pe undeva si care mi-a placut foarte mult tocmai pentru ca este foarte ilustrativa chiar pentru subiectul discutat. Si nu pentru a-l amari si mai tare pe Groparu ci tocmai pentru a face haz de necaz.\r\n\r\nGropare, daca am gresit ca am deschis gura, te rog, ma scuza, promit ca nu voi mai face comentarii in ziua ACEEA a lunii :-). Si ca sa ma spal de pacate, te invit sa-ti ineci amarul in BR RC (bere rece) pe banii si placerea mea. Si ia-l si pe Colt Alb cu tine pt. ca mi-ar face, sincer, placere sa continuam discutia cu gatul putin mai umed.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; .NET CLR 2.0.50727)','',0,0),(7722,761,'Groparu vrea Ã®n ascuÅ£itoare&#8230; | TrÄƒim Ã®n RomÃ¢nia ÅŸi asta ne ocupÄƒ tot timpul','','http://www.traiminromaniasiastaneocupatottimpul.com/2007/11/05/groparu-vrea-in-ascutitoare/ro/','64.13.232.36','2007-11-05 22:53:16','2007-11-05 20:53:16','[...] &#8230;pÃ¢nÄƒ Ã®i mai rÄƒmÃ¢ne doar de-un ciot, ÅŸi se sacrificÄƒ liniÅŸtit (pe viaÅ£Äƒ :D) pentru salvarea relaÅ£iilor romÃ¢no-italiene. [...]',0,'1','Incutio XML-RPC -- WordPress/2.2.3','pingback',0,0),(7723,761,'WhiteWolf','contact@white-wolf.ro','','89.39.82.4','2007-11-05 23:30:59','2007-11-05 21:30:59','Ce chizdoiu ma-sii ai Gropare ? Vreai sa ne rushinezi chiar pe tÃ£tzi ?? Faci atac la stramoshi si istoria de \'jde mii de ani, dilimane ???\r\n<b>Cu Romulus si Remus cum ramane  daca incepi sa dai dovezi de heterosexualitate in plan european?</b>',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7724,761,'WhiteWolf','contact@white-wolf.ro','','89.39.82.4','2007-11-05 23:32:45','2007-11-05 21:32:45','M-ai enervat\r\n<b>Nu te abate de la curs ! Ca incep sa se smuceasca pe columna traian si Decebal</b> :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7725,761,'Arhi','arhi@arhiblog.com','http://arhiblog.com','82.77.85.23','2007-11-05 23:46:35','2007-11-05 21:46:35','da, si din miscarea lor inainte si=napoi, a iesit poporul roman.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7726,759,'ratz','oitza@yahoo.com','','24.19.31.87','2007-11-06 00:18:29','2007-11-05 22:18:29','eu nu pricep de ce e asa de suparat Groparu...nu a stiut de la inceput in ce \"intra\"? sau au inceput sa se acumuleze deranjant ratele luate pt masina de spalat, pentru coltar, frigider, aragaz, microunde, bacancii pentru iarna, etc, etc?\r\niar pentru ave13, mama dumeavoastra a facut in cunostinta de cauza alegerea intre rata fixa [ care era probabil mai mare ] si rata flexibila la momentul incheierii contractului?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727)','',0,0),(7817,770,'Groparu','groparu_ro@gmail.ro','http://www.groparu.ro','82.77.126.254','2007-11-08 17:12:43','2007-11-08 15:12:43','IOOO? Ia cauta pe google \"narcisist\", si vezi ce site iti apare intre primele rezultate :D  :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7728,761,'eu,Miruna','mirunavasilescu@yahoo.com','http://potsafacsiasaceva.blogspot.com/','86.106.59.163','2007-11-06 05:06:01','2007-11-06 03:06:01','Dar eu nu-nteleg...s-au terminat studentele din Cluj?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7729,759,'eu,Miruna','mirunavasilescu@yahoo.com','http://potsafacsiasaceva.blogspot.com/','86.106.59.163','2007-11-06 05:07:02','2007-11-06 03:07:02','Ah, abia astept sa am rate ca sa pot sa fac si eu scandal.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7813,769,'Groparu','groparu_ro@gmail.ro','http://www.groparu.ro','82.77.126.254','2007-11-08 16:12:27','2007-11-08 14:12:27','Intre 100 si 140 EUR/mp. Moca.\r\n\r\nPS: Fara utilitati cine stie ce.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7814,769,'Shadow','ahimi2001@yahoo.com','','193.231.20.2','2007-11-08 16:21:31','2007-11-08 14:21:31','io pe asta nu o crez gropule.... ca la noi in medias.... nu se vorbeste cu E:P',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(7815,769,'Groparu','groparu_ro@gmail.ro','http://www.groparu.ro','82.77.126.254','2007-11-08 16:38:35','2007-11-08 14:38:35','MedieÅŸanul aÅŸiela ierea un arbust transpus in poluarea clujeanca, deci efectele ClujnobÃ¢l este, dupa cum se stie, imprevizibile!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7816,770,'cocofifi','gino@mail.com','','62.224.219.33','2007-11-08 16:41:31','2007-11-08 14:41:31','aai, modestucule, tzucate-ai',0,'1','Mozilla/5.0 (Macintosh; U; PPC Mac OS X Mach-O; de; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7943,760,'si mester','','','89.137.120.50','2007-11-13 16:21:29','2007-11-13 14:21:29','La mu(l)ti ani! de ziua ta iti dau neste foto de la un chef daca-mi dai neste chestii ramase la tine. nu intram in detalii ca nu pe toata lumea intereseaza ca am o galeata ,un spaclu si o surubelnita la tine.io de ziua ta am net, dupa o abstinenta de ha-ha.iti urez sa-ti rezolvi si tu o treaba de-asta birocratica. daca-i cumva pe la cadastru sa-mi zici si mie cum ai facut',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro-RO; rv:1.7.12) Gecko/20050919 Firefox/1.0.7','',0,0),(7913,784,'WhitreWolf','contact@white-wolf.ro','http://white-wolf.ro','89.39.82.190','2007-11-13 02:02:02','2007-11-13 00:02:02','Sai ai si ani si zile si sanatate cat sa apuci sa te vezi scapat de rate.\r\nSa ai si bulan cat iti e necesar ca sa duci la capat scoala de shoferi si sa te vezi cu carnet.\r\n In rest, sanatate daca ai, restul (mai si) cumperi.\r\n<b>La Multi Ani ! </b>\r\n\r\np.s; Ma gandesc la aia cu dintr-un om mai faci un sofer dar dintr-un sofer om, niciodata; tu-tzi dai seama ce variatiuni se pot improviza daca pui Gropar(u) in loc de om ? :) :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7930,784,'parsiimpar','lummi31@gmail.com','http://parsiimpar.wordpress.com/','81.196.54.24','2007-11-13 12:30:08','2007-11-13 10:30:08','Hei, tup si eu :)\r\n\r\nUite, La multi ani! Sa fii sanatos! Sa fii vesel ! Sa ai motive sa zambesti!  Asa ca petreceri frumoase si intilniri cu baute la care sa nu ti se faca rau!\r\nIti doresc scantei multe si al propriu si la figurat!\r\nNumai bine pentru tine la o virsta tare frumoasa!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(7915,771,'Lexis','g_lexis2005@yahoo.com','http://www.alexandraghitalexis.blogspot.com','89.38.76.46','2007-11-13 06:56:51','2007-11-13 04:56:51','Ohoooo bine ai venit printre noi amice, ne intalnim pe sosea. Am si io o intreaga istorie in legatura cu treaba asta... pfiuuu noi sa fim sanatosi',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7916,784,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','85.186.77.129','2007-11-13 08:00:49','2007-11-13 06:00:49','la multi ani si la multi bani, groparule! si sa fii iubit dimineata, la pranz si seara dupa fiecare masa!',0,'1','Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.0.12) Gecko/20070731 Ubuntu/dapper-security Firefox/1.5.0.12','',0,0),(7917,784,'pliscu','pliscu@gmail.com','http://pliscu.blogspot.com','89.137.100.242','2007-11-13 08:38:43','2007-11-13 06:38:43','La multi ani!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7918,784,'nana','razornana@yahoo.com','','86.34.163.6','2007-11-13 08:43:20','2007-11-13 06:43:20','ioiiiiiiiiii... la multi ani gropare! vezi sa bei macar pan\'la ziua mea! :D marti 13 :p apai in cele 3 ceasuri rele poti sa faci pauza si sa lucrezi :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7905,784,'IepurasulAtomic','praetorian21uk@yahoo.com','','62.217.213.228','2007-11-12 23:47:10','2007-11-12 21:47:10','Usim: Ce dracu\' sa fac si io, mi-era sete?! :)) Salutam domnu\' bancher ;)!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(7906,784,'July','jullya24@yahoo.com','','83.103.179.55','2007-11-13 00:05:20','2007-11-12 22:05:20','La multi ani!!...Sa traiesti cat ii vre\' si sa bei si mai mult, cu ocazia minunatului eveniment!',0,'1','Opera/9.10 (Windows NT 5.1; U; en)','',0,0),(7907,784,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2007-11-13 00:05:54','2007-11-12 22:05:54','...deja beu!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7908,782,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2007-11-13 00:23:55','2007-11-12 22:23:55','Deci ba, deci vezi ca io inca ma uit in sus la tine, da?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7909,784,'oitza','oitza@yahoo.com','','24.19.31.87','2007-11-13 00:26:18','2007-11-12 22:26:18','La multi ani, Gropare! :)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727)','',0,0),(7910,784,'eu,Miruna','mirunavasilescu@yahoo.com','http://potsafacsiasaceva.blogspot.com/','86.106.59.163','2007-11-13 00:26:50','2007-11-12 22:26:50','La multi ani. Nu?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7911,784,'Usim','mihaimitan@gmail.com','','86.121.184.193','2007-11-13 01:02:03','2007-11-12 23:02:03','La multi ani sanatosi! Da!',0,'1','Opera/9.10 (Windows NT 5.1; U; en)','',0,0),(7912,784,'eu,Miruna','mirunavasilescu@yahoo.com','http://potsafacsiasaceva.blogspot.com/','86.106.59.163','2007-11-13 01:07:24','2007-11-12 23:07:24','Sanatosi, da.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7929,784,'fan','totmea@yahoo.com','','89.123.87.205','2007-11-13 12:23:35','2007-11-13 10:23:35','Scurt si la obiect. Subiect, pardon. Sa-ti traiasca si sa te-mogateasca (tezaurul).',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(7931,784,'Sorinelu\'','sorinelm@gmail.com','','86.122.9.37','2007-11-13 12:44:21','2007-11-13 10:44:21','la multi ani celui mai potent gropar nascut din cel mai potent spermatozoid campion.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) )','',0,0),(7932,784,'Hoot','adisor_hoot@yahoo.com','','89.33.45.234','2007-11-13 13:10:39','2007-11-13 11:10:39','la multi ani pt un vechi coleg de arme ... unicul Groparu',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7933,784,'chevantonje','','','82.76.65.140','2007-11-13 13:36:56','2007-11-13 11:36:56','La multzi ani, la multzi ani, la multzi ani !!!\r\nSi pentru ca sarbatorirea ta nu e altceva decat o alta ocazie de a ma lauda (a se citi a ma baga in seama gratuit) pe mine insumi propriu si personal (vb. poetului), cred ca sunt in asentimentul tuturor atunci cand afirm clar si raspicat ca, una peste alta: La tatzi ni-i greu !!! No, sa fitzi iubitzi si fericitzi !!!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; t20010828)','',0,0),(7870,771,'Dojo','webmaster@dojodesign.ro','http://www.avemblog.ro','89.137.246.152','2007-11-10 18:10:34','2007-11-10 16:10:34','Felicitari pentru mersul la \"scoala\". Si eu am inceput de ceva timp, asa ca suntem \"colegi\", chiar daca (banuiesc eu) la destui km distanta. BAFTA :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7886,782,'Botache','nasturei_verzi@yahoo.com','http://www.nasturei.wordpress.com','82.77.126.148','2007-11-12 13:01:05','2007-11-12 11:01:05','Genial!!! Imi pare rau ca nu m-am gandit io prima la treaba asta!! =))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.0; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7887,779,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','82.77.126.148','2007-11-12 13:16:55','2007-11-12 11:16:55','bai, rau ai facut ca ai mers la scorpioni! jur pe ce am io mai sfant ca la concerte moka io nu mai calc! concert de kk, sunet de kk, vreme de kk, organizare de kk.... numa nervi mi-am facut! :(((((',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7889,779,'daisy','daisy@yahoo.com','','89.137.17.128','2007-11-12 14:20:23','2007-11-12 12:20:23','Eu nu stiu zau tu lilith cum esti...dar lasa-ma sa iti zic cum mi te inchipui: mica, neagra de invidie, complexata de kilograme si frustrata de altele...Nu am vazut o vorba buna iesita din degetele tale!!!\r\n\r\nToate\'s de kkat, toate is naspa...dar din cate vad fugi numai la chestiile gratuite....',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(7878,779,'baghy','baghy83@lycos.it','http://baghy.info/','78.12.13.1','2007-11-11 22:16:35','2007-11-11 20:16:35','Gropare cum ai mai ajuns pe blogul pe wordpress? sau nu ai fost tu de ai comentat?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(7880,779,'Adi Calarasu','acalarasu@gmail.com','http://adriancalarasu.wordpress.com/','89.32.19.126','2007-11-12 00:56:54','2007-11-11 22:56:54','Ieeee, mah! Rock you like a huricane!\r\nCum o fo? Mai poate batranii?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) )','',0,0),(7881,779,'Adi Calarasu','acalarasu@gmail.com','http://adriancalarasu.wordpress.com/','89.32.19.126','2007-11-12 01:03:16','2007-11-11 23:03:16','Stii de ce te intreb?\r\n1. Astia de la stiri s-au spurcat la utube si le e lene sa mai trimita reporteri sau sa foloseasta corespondenti speciali de pe la evenimente gen.\r\nsi 2) \r\n\"- departe-i Sibiul?\r\n- da, aproape la fel de departe precum Clujul...\r\nde mine cel putin...',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) )','',0,0),(7942,784,'ss','criss_team@yahoo.com','','81.196.150.198','2007-11-13 16:13:21','2007-11-13 14:13:21','apai sa traiesti mai mult si mai bine decat traieste banca la care platesti tu rate! :D\r\n\r\nsi o dedicatiune: http://www.trilulilu.ro/UploaderHoria/7ffee7fe8a5bcb',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7','',0,0),(7941,784,'VIP','ps@yahoo.com','http://vipuri.blogspot.com','213.157.188.71','2007-11-13 15:49:27','2007-11-13 13:49:27','be numa tu ma! la multi ani!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7935,784,'galatzi','galatzy_2004@yahoo.com','http://www.groparu.ro','213.92.80.220','2007-11-13 13:46:39','2007-11-13 11:46:39','Gropare, cam slabutz azi ... Citeste omul dimineatza prea frumosul articol ... La 1.42 intra la groparu in blog si vede ca sugubatzu\' nu a mai scris nimic... \r\n\r\nCum poti sa iti bati joc de niste copii ? Cum poti sa ii dezamgesti ? Cum ?\r\n\r\nNu stii cum e ... Pentru k tu nu ai un GROPAR in bucmarc... care tine loc de cafeaua de dimineatza... \r\n\r\nAcum imi dau seama k poate e ziua ta si nu ti-am zis LA MULTI ANI!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(7936,784,'mumuland','','','80.97.64.199','2007-11-13 13:53:19','2007-11-13 11:53:19','la multi ani ma gropare...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12','',0,0),(7937,784,'Altar','','','86.123.139.103','2007-11-13 13:55:44','2007-11-13 11:55:44','Noah, daca-i musai, La multi ani!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7938,784,'cronicaru\'','tzone_a@yahoo.com','http://cronicaru.blogspot.com/','193.230.230.101','2007-11-13 14:03:57','2007-11-13 12:03:57','ma speriesem la inceput cu \"Fierro di essere Romeno\". ma calmai dupa ce citii si acu urlu: groparu e potent. apropo, o zi de marti, 13, asa cum iti doresti tu. ai grija ce-ti doresti insa ca e marti, 13, si s-ar putea sa ti se indeplineasca.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(7939,784,'blue','blue.chio@yahoo.com','','89.34.15.18','2007-11-13 14:51:34','2007-11-13 12:51:34','La multi ani!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 2.0.50727)','',0,0),(7940,784,'mishu','mishu@doingtheartwork.com','http://www.doingtheartwork.com','82.77.126.254','2007-11-13 15:07:51','2007-11-13 13:07:51','Cine ii blue si de ce asa laconic?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7890,779,'VIP','ps@yahoo.com','http://vipuri.blogspot.com','213.157.188.71','2007-11-12 14:33:54','2007-11-12 12:33:54','no ai f***-o? cum o fost?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7891,772,'daisy','daisy@yahoo.com','','89.137.17.128','2007-11-12 14:40:32','2007-11-12 12:40:32','Pacat numa\' ca asti au copiat ideea. Chestia cu semaforu\' o facuto si Polus-ul, nuh? \r\nNuma ca acolo erau gagici ...si mamah ce gagici....cam ca hostessele lui Groparu ...',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(7892,779,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','82.77.126.148','2007-11-12 15:00:59','2007-11-12 13:00:59','am fost pentru ca am vrut sa fiu cu prietenii mei, in niciun caz ca sa inghet de frig intr-o piata in care nici macar scena nu au pus-o cum trebe, sa nu mai zic de panourile alea.. numai cefe groase am vazut, si manelisti, si copiii care se catarau pe roata, pe stalpi sau in copaci (Sibiu, capitala culturala europeana, ce sa-ti spun!?)\r\nneagra de invidie pentru ce? pentru un concert care nu mi-a placut? daca ti-a placut tie, foarte bine. mie mi s-a parut execrabil, pentru ca il compar cu cel din brasov, cand au venit la cerbul de aur! ALA a fost concert bun, dar nu porcaria asta in care mai mult de un \"vaajjjjjjjjj\" nu am auzit mare lucru! puteau sa faca in asa fel incat toata lumea sa fie multumita! tu ai vazut cati au plecat din piata aia cu muuult inainte de bis?? :))\r\nnu mai pupa in fund o trupa doar pentru ca au cantat moca sau ca au nush cata vechima, pentru ca nu asa se masoara calitatea.\r\n\r\nsi nu stiu de ce crezi tu ca as fi complexata de ceva... aa, ba da, am un complex de superioritate fata de cei ca tine care eticheteaza oamenii fara a-i cunoate, doar pentru ca au puncte de vedere diferite! :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7893,779,'Paszti','pasztorjozsef@yahoo.com','','81.12.230.166','2007-11-12 17:03:48','2007-11-12 15:03:48','Ala n-o fost concert, o fost numa furtuna in olita.\r\nDrept ca nici baut n-am fost da abia se auzea muzica.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727)','',0,0),(7900,784,'IepurasulAtomic','praetorian21uk@yahoo.com','','62.217.213.228','2007-11-12 21:27:49','2007-11-12 19:27:49','La multi ani? La multi ani asha pe gratis? Da\' chiar pe gratis? Pai ce ne-am(adica neam, ca io nu stie sa scrie) de roman potent mai is io ma de fac urari asha pe degeaba? Pai d-aia mai(adica \"m-ai\") descris tu acolo sus de mam(adica \"m-am\"...stiu, si io am inceput sa ma plictisesc) simtit in toate. Adica baaaaah, sa stii aci de la mine ca io dintre toate de mai sus, cel mai tare is potent, pen\' ca de aia ma cheama Iepurasu\' ATOMIC, nu asha unu\' oarecare. Problema mea ii ca nime\' nu se f*&amp;e cu mine. Da\' nu-i nika, ca ma descurc si singur. Numa\' asha, sa moare proastele de ciuda :). Mno, si-acu c-am terminat-o cu ironia, frustrarile si balariile:\r\n\r\nLA MULTI ANIIIIIIIII BAAAAAAAA GROAPA!!!! Sa ne traiesti si mai ales SA NE CINSTETI BAAAA!!!(asta ca sa nu zici ca nu-s neam de traista :)) ). \r\n\r\nPSeu: De cand ai avut accidentu\' ala cu maramureseanu\' de o scapat nevatamat de bicicleta ta(pe care apropo l-am vazut pe la casa de cultura la vreo 2 zile dupa si-am ras ca bou\' ca ce coincidenta...deci pot jura la tribunal ca n-o patit nika), carevasazica de cand cu evenimentu\' rutier m-am gandit io ca-i ceva in neregula cu tine. Acuma ca zici ca iesti nascut in 13, m-am lamurit :).Da\' pentru asta tot nu scapi nebaut....ah, pardon, fara sa dai de baut am vrut sa zic ;).',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(7895,782,'nenea cosmos','domnu_cosmos@yahoo.com','http://www.nenea.wordpress.com','92.80.49.51','2007-11-12 20:20:20','2007-11-12 18:20:20','frate, da si tu dume sa putem sa comentam si noi, astea asa geniale nu ne lasa a ne desfasura, pai numai tu sa dai petarda, noi nimic?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(7896,782,'nenea cosmos','domnu_cosmos@yahoo.com','http://www.nenea.wordpress.com','92.80.49.51','2007-11-12 20:21:16','2007-11-12 18:21:16','nu ne lasi loc nici macar de-o caramea?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(7897,784,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','85.186.77.129','2007-11-12 20:43:49','2007-11-12 18:43:49','ai uitat incheierea: \"pentru ca suntem un neam de potenti\"!! pai se poate??',0,'1','Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.0.12) Gecko/20070731 Ubuntu/dapper-security Firefox/1.5.0.12','',0,0),(7898,784,'macabroo','raduccc@yahoo.com','http://rezistenta.blogspot.com','82.76.52.94','2007-11-12 21:15:38','2007-11-12 19:15:38','Deci respiram adanc si ne calmam da...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7899,784,'Andreea MKT','','','89.43.186.64','2007-11-12 21:19:18','2007-11-12 19:19:18','deci, domnule groparele:)\r\n\r\ndvs avetzi o colega, andreea mkt, pe numele ei, careia azi i s-o descoperit 3 (triii) purulete albe pe amigdale si pe ganglioni, chestie care o face mai focoasa la 40 de grade decat ce ai putea dumneata sa iti imaginezi (blea, stiu ca suna gretzos faza cu purulentzele albe, dar e blogul tau si nu ma jenez). si medicamentele o costat-o pe andreea mkt 70 lei si sunt fabricate in italia.\r\n\r\nsa le ia?\r\nsa nu le ia?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7901,784,'Usim','mihaimitan@gmail.com','','87.237.108.33','2007-11-12 21:50:12','2007-11-12 19:50:12','Teai (adica te-ai) cam grabit cu urarile, m-ai (adica mai) sunt vreo doua ore pana la sarbatoare, Iepurasule :-)))',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; .NET CLR 2.0.50727)','',0,0),(7928,760,'Guru','','','212.93.140.211','2007-11-13 11:49:26','2007-11-13 09:49:26','La Multi ani!!!!!!  Sa o tii tot asa, esti tare GROPARE, ceaules!!! La multi aniiiiii!!!!!! iti citesc zilnic ispravile.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(7903,784,'baghy','baghy83@lycos.it','http://baghy.info/','78.12.13.1','2007-11-12 22:39:02','2007-11-12 20:39:02','La multi ani Gropareeeeeeeeeeeeeeeeeeee. Inca un scorpion celebru dupa mine :))) .\r\nFoarte bun postul ca de obicei.\r\nSa cresti mare',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(7919,784,'macabroo','raduccc@yahoo.com','http://rezistenta.blogspot.com','80.96.196.2','2007-11-13 09:05:52','2007-11-13 07:05:52','hepi barssdei',0,'1','Opera/9.23 (Windows NT 5.1; U; en)','',0,0),(7920,784,'.marius','marius@perijoc.com','http://marius.wirelessisfun.com','89.36.21.108','2007-11-13 09:10:22','2007-11-13 07:10:22','La multi ani gropare... :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7921,784,'Bernadette','briqo_o@yahoo.com','','82.77.126.254','2007-11-13 09:19:55','2007-11-13 07:19:55','La multi ani! ',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; FDM; .NET CLR 1.1.4322)','',0,0),(7922,784,'Radu','ratradu@gmail.com','','82.76.12.137','2007-11-13 09:59:06','2007-11-13 07:59:06','La multi ani Gropare si sa ne traiesti! \r\nNoroc si pita unsa!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7923,784,'LUMI','luminicoara@yahoo.com','','81.12.163.178','2007-11-13 10:07:37','2007-11-13 08:07:37','La multi ani cu veselie \r\nSanatate pe vecie \r\nCasa plina de bucate \r\nDragoste pe saturate \r\nBani la greu \r\nNoroc cu carul \r\nLa multi ani si sus paharul!!',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(7924,784,'mishu','mishu@doingtheartwork.com','http://www.doingtheartwork.com','82.77.126.254','2007-11-13 10:15:01','2007-11-13 08:15:01','mishu: la multi ani ma PULA\r\nmishu: hai la tzigare\r\nmishu: sa ne traiesti 1000 de ani\r\nGroparu: da ba pula!!! sa traim cu toti\r\nmishu: sa ne pui linkuri la blogroll\r\nGroparu: am kemat vlazi si ragai la kef!!!\r\nmishu: sa ne dedici posturi\r\nGroparu: da, claro!\r\nmishu: sa ne traduci defectuos conferintze si sa iei multi bani pe asta\r\nmishu: de toate sa ne faci in pula mea\r\nmishu: si sa ne traieshti ma\r\nmishu: noa haida la tzagara\r\nGroparu: viu! viu\r\n\r\nNu ma obosesc sa scriu de 2 ori. Da\' sa traieshti matale si cu mica-ta (care e o doamna) :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7925,784,'fan','totmea@yahoo.com','','89.123.87.205','2007-11-13 10:45:48','2007-11-13 08:45:48','La cati ani vrei tu! Sa ai tat ce ti de trebuinta!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(7926,784,'fan','totmea@yahoo.com','','89.123.87.205','2007-11-13 10:47:26','2007-11-13 08:47:26','Poezie! Poezie! Io vreu sa vad o poezie dedicatiune aniversara, ca de la Gropar la Gropar. Hai ca-ti meriti.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(7927,784,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-11-13 11:31:44','2007-11-13 09:31:44','Pula mea de dinozaur\r\nDaca vrea omoar-un taur\r\nFincÄƒ este un tezaur!\r\n\r\nNa, ca mi-am zis-o.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7834,771,'Inn0cente*','innocente@innocente.ro','http://www.innocente.ro','194.169.235.5','2007-11-09 06:56:11','2007-11-09 04:56:11',':)) Deci o sÄƒ mergem toÅ£i cu metroul. CÃ¢nd o sÄƒ fac eu ÅŸcoala de ÅŸoferi (nu cred cÄƒ mai e mult) sÄƒ vÄƒ luaÅ£i elicoptere, avioane sau deltaplane :p Deci o sÄƒ fiu o ÅŸatenÄƒ cu o ÅŸuviÅ£Äƒ blondÄƒ la volan...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(7835,771,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','85.186.77.129','2007-11-09 08:20:26','2007-11-09 06:20:26','ce tare! nu am mai vazut suvite blonde la volan! this is a must see! :P',0,'1','Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.0.12) Gecko/20070731 Ubuntu/dapper-security Firefox/1.5.0.12','',0,0),(7836,771,'nana','razornana@yahoo.com','','86.34.163.6','2007-11-09 08:30:43','2007-11-09 06:30:43','deci acum: stanga, dreapta, iar stanga si apoi treceti strada...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7837,770,'Greuceanu','','','195.149.72.105','2007-11-09 08:57:59','2007-11-09 06:57:59','pula ta Gropare!\r\n\r\ncica e o firma care \"organizam festivitati speciale si primiri speciale cu multime si fanfara.... preturi fara concurenta....\" e ok sa-i sunam cand intri in uorash amu la scorpions.... sa vina tatzi sa te ajtepte la autogara carabulea si sa-i lase singuri pe scorpions!',0,'1','Opera/9.24 (Windows NT 5.1; U; en)','',0,0),(7841,771,'kmi','camelianeculai@gmail.com','','80.86.103.122','2007-11-09 10:18:12','2007-11-09 08:18:12','@copila: foarte tare comentariul :))\r\n\r\ngropare, am avut un coleg la penultimul job, genul \"rocker\" ...capabil, neingrijit si fan alcool si, ca si tine, s-a inscris de vreo 3 ori la diverse institutii de instructaj in ale condusului. Bineinteles ca faceam misto de el de cate ori aveam ocazia, pana intr-o zi, cand i s-a pus pata pe un motor (Harley or smth) si si-a luat si A-ul si B-ul sa ne potoleasca :)\r\n\r\nBafta multa.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7842,771,'Groparu','groparu_ro@gmail.ro','http://www.groparu.ro','82.77.126.254','2007-11-09 10:20:10','2007-11-09 08:20:10','@ you wanna: si io am tat felu de cojmare, cu batrane libidinoase.\r\n\r\n@ lilith: nij la alfa, nij la omega! veti afla, de asta-s sigur, ca nu isi poate tine Groparu\' gura...\r\n\r\n@ Danila: intr-adevar, dar voi putea sa-mi injectez votca, direct, sa nu mai obosim tractu digestiv :D\r\n\r\n@ innocente-delincvente: ne lom si permis de submarin, de foreza de petrol si de elicopter de atac? SA NU SCAPE NIMENI!!!!\r\n\r\n@ baghy: dap. Blogul meu va saraci. Dar voi lua studenti cu mine, ca sa nu mor singur.\r\n\r\n@ copila: tate calca, unele chiar si fluiera si incearca sa te aghetze!\r\n\r\n@ July: o sa incep cu capu\' instructorului de bara de protectie, ca trec printr-o faza testosteronica a vietii!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7843,771,'Groparu','groparu_ro@gmail.ro','http://www.groparu.ro','82.77.126.254','2007-11-09 10:20:56','2007-11-09 08:20:56','@ kmi: deci sa deie sfantul Dumnezau sa imi ieu si A, si B, si XXX!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7839,771,'copila','totmea@yahoo.com','','89.123.116.181','2007-11-09 10:03:37','2007-11-09 08:03:37','Tate masinile calca, mah. Nu ne mai amagi...',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(7840,771,'July','jullya24@yahoo.com','','83.103.179.55','2007-11-09 10:11:21','2007-11-09 08:11:21','am o nedumerire....dak la volanul biciletei fiind, ai accidentat mortal o mashina, la ghidonul unei masini ce ai putea accidenta?..(in afara de pietoni si pastrand proportile primei intamplari)....dak nu iti dai seama inca eu zic sa incerci cu masina de la scoala pt inceput....ca sa sti exact la ce o sa-ti expui masinutza pe viitor....multa bafta!',0,'1','Opera/9.10 (Windows NT 5.1; U; en)','',0,0),(8056,788,'p3','','','193.231.18.12','2007-11-15 12:08:37','2007-11-15 10:08:37','pfuai mah!! sh tu ai ceas ca al meu?! sh mi-o zis cand l-am looat ca-i unicat!!! :-',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8054,786,'cronicaru\'','tzone_a@yahoo.com','http://cronicaru.blogspot.com/','193.230.230.101','2007-11-15 12:03:06','2007-11-15 10:03:06',':) poa era musai sa aiba baietzii scaune la cap sa nu-si prinda groparu dejtele in ele',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(8061,789,'irina','irinamimoza@yahoo.com','','86.121.21.75','2007-11-15 12:54:33','2007-11-15 10:54:33','baaaaiii, te-au decorat aia de la rezistenta urbana: Roza Verde in Grad de Caterinca Suprema cica. \r\nzi si tu impresii, ceva. cum te simti acum, fericitule?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8053,785,'katmai','katmai@keptprivate.com','http://www.512kbps.com','210.7.19.186','2007-11-15 11:48:18','2007-11-15 09:48:18','uh ... greu mai greu mai :) trebea sa ii zici ca viseaza, si sa iasa dracu din transa. ca l-au hipnotizat bulangiii sa lucreze moka.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8861,817,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-11-27 08:55:01','2007-11-27 06:55:01','@ Usim: da, mo, ezac, si mai Ã®z care scriu mai bine ca mine!\r\n\r\n@ WhiteWolf: mooo, deci ideia Ã®i sÄƒ Ã®i faci trafic lu Nenea Cozmos! IntrÄƒ la iel pe pajinÄƒ ÅŸi apasÄƒ Refresh de 60 de ori, ÅŸi asta zilnic. Numa atata te rog.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8037,788,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','82.77.126.148','2007-11-15 09:59:08','2007-11-15 07:59:08','vezi ca si de la mine ai o leapsa! si am sa te bat la cap pana o vad pe blog! e prea faina sa fie ratata! \r\n\r\nsi apropo de lapsa ta: din aceasta poza deduc ca esti un mascul viril! asta dupa parul de pe mana! si ingenios, asta dupa ceas. dupa culoarea ceasului, deduc ca iti plac brunetele si berea bruna!\r\nsi daca ma contrazici, ai pus-o! :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8038,463,'Nascut din spermatozoizi campioni &raquo; Blog Archive &raquo; Stirile zilei','','http://www.groparu.ro/?p=789','82.103.137.253','2007-11-15 10:02:58','2007-11-15 08:02:58','[...] GÄƒbiÅ£a din &#8220;4 luni, 3 saptamani si 2 zile&#8221; a lu&#8217; Cristian Mungiu, despre care am mai scris, a fost prechezitionata de o gajcÄƒ de Garcea italieni, care or confundat-o cu o proxenetÄƒ.  [...]',0,'1','Incutio XML-RPC -- WordPress/2.1.2','pingback',0,0),(8039,786,'.marius','marius@perijoc.com','http://marius.wirelessisfun.com','89.137.107.129','2007-11-15 10:05:47','2007-11-15 08:05:47','Gropare, palaria jos, faci haz de necaz din dejte zdrobite si compresate... *ROFL* \r\n\r\nCat despre Gente... doar cateva cuvinte: pizza buna, si cam atat. In rest, servire execrabila, curatenie mai putin, suc la pahar din sticla de 2 litri and so on... Acuma vad ca instaleaza si capcane... tz tz tz',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8059,789,'cronicaru\'','tzone_a@yahoo.com','http://cronicaru.blogspot.com/','193.230.230.101','2007-11-15 12:40:01','2007-11-15 10:40:01','aia cu macaronaru de veni sa ciordeasca taitei si fidea miemimi roase a publisite cu masca de zoro la euromegashopu din cluj de se deschise de caurand si in bucale.  daca tot e pe moca si presa pune botu de ce nu?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(8041,784,'Marius','pop.marius@gmail.com','http://Lityx.blogspot.com','92.81.139.97','2007-11-15 10:14:35','2007-11-15 08:14:35','La multi ani gropare! Se pune daca e cu intarziere? Si felicitari pentru post (ala al Craciunului)!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8042,786,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','82.77.126.148','2007-11-15 10:15:17','2007-11-15 08:15:17','mie imi place la gente, dar nu la pizzerie, ci la restaurant! niciodata nu am putut manca doua feluri, asa portii mari au!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8049,789,'Iubeste si tu italienii!','ps@yahoo.com','http://de-aia.blogspot.com/2007/11/iubiti-italienii-din-romania-leapsa.html','213.157.188.71','2007-11-15 11:13:51','2007-11-15 09:13:51','Mosule, du si tu leapsa asta mai departe:\r\n\r\nhttp://de-aia.blogspot.com/2007/11/iubiti-italienii-din-romania-leapsa.html',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8045,789,'katmai','katmai@keptprivate.com','http://www.512kbps.com','210.7.19.186','2007-11-15 10:52:31','2007-11-15 08:52:31','am idee mai buna, hai sa ii prindem pe toti italienii, sa ii punem impreuna cu tiganii la munca, sa ne repare strazile, si noi sa cotizam la recolta de bere, cu kalashurile langa iei, si uite asa sa aducem romania pe culmi de aur, si glorie, si sa merem in vacanta la italiencele singure acasa, si sa le fericim, pentru ca sunt triste cu sotii lor la munca in romania :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8046,789,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','82.77.126.148','2007-11-15 10:53:07','2007-11-15 08:53:07','sa nu vad italience la mine in tzara ca bolunzesc! ti-am zis io sa cauti cehoaicele, dar tu nuuu... ai ce ai cu alea cgrase din cizma lor de tara!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8047,786,'katmai','katmai@keptprivate.com','http://www.512kbps.com','210.7.19.186','2007-11-15 10:54:08','2007-11-15 08:54:08','si totusi ... pizza cum fu ? :D\r\n\r\nim back btw :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8048,788,'katmai','katmai@keptprivate.com','http://www.512kbps.com','210.7.19.186','2007-11-15 10:54:46','2007-11-15 08:54:46','skimba uora pliz !',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8102,57,'booton','fanebutonel@yahoo.com','','86.122.177.26','2007-11-15 21:46:47','2007-11-15 19:46:47','Lirici hemoroidale\r\npentru angrenari dorsale\r\nin suporturi miniaturale\r\nmortii lor de polutii bipolare\r\ndin glande pineale\r\npredispuse mimicii rectale',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8103,58,'booton','fanebutonel@yahoo.com','','86.122.177.26','2007-11-15 21:49:02','2007-11-15 19:49:02','esti incredibil omule.si inca n-am apucat se citesc decat destul de putin',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8107,788,'baghy','baghy83@lycos.it','http://baghy.info/','78.12.13.1','2007-11-15 23:19:31','2007-11-15 21:19:31','indubitabil',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(8794,813,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','82.77.126.148','2007-11-26 11:26:59','2007-11-26 09:26:59','asta e o leapsa, sau ce? eu visez la o Romanie... o alta Romanie...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8813,813,'WhiteWolf','contact@white-wolf.ro','http://white-wolf.ro','89.39.83.121','2007-11-26 16:06:58','2007-11-26 14:06:58','Io visez la o Romanie iesita din stand-by\r\nO Romanie unde stirile nu mai vorbesc despre Cotroceni si BEC ci, simplu, despre oameni, adevar, politete si moralitate.\r\nVisez la Romania lui <b>\"No, hai !\"</b> dupa care sa nu se mai auda niciodata <i>\"bre, da\' ma leshi?\"</i>. O Romanie a lui \"servus\" dara fara popa Toekes euro-parlamentar.\r\nSi asta-i tot.\r\n Visam ca tampitzii, ca asa vrea Groparu :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8648,805,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','82.77.126.148','2007-11-23 14:18:39','2007-11-23 12:18:39','de ce nu i-ati desenat mustatza si dinti lipsa? m-ati dezamagit! :(',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8698,807,'parsiimpar','lummi31@gmail.com','http://parsiimpar.wordpress.com/','89.39.83.37','2007-11-24 00:02:55','2007-11-23 22:02:55','Hmm...\r\n1.Sa fie vorba oare de merele pentru placintele din \"la placinte inainte, la razboi inapoi?\r\n2.Sa fie alea merele ce vor ajunge pe mesele europenilor cu ajutorul europarlamentarilor alesi duminica de noi?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8687,807,'eu,Miruna','mirunavasilescu@yahoo.com','http://potsafacsiasaceva.blogspot.com/','86.106.59.163','2007-11-23 22:21:34','2007-11-23 20:21:34','Cum, nu e \"mereti la vot\"? Haidi bre cu semnificatia ascunsa, ca tre sa ies in oras si ma roade curiozitatea.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8647,797,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','82.77.126.148','2007-11-23 14:17:48','2007-11-23 12:17:48','danke schÃ¶n! HVB sa fie, dara!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8111,789,'macabroo','raduccc@yahoo.com','http://rezistenta.blogspot.com','82.76.52.94','2007-11-16 00:51:50','2007-11-15 22:51:50','Aceeia, desi suntem acestia, o luam in nume de bine. Am zis.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8693,807,'The Original Yankee','crisan_emil@yahoo.com','','89.43.186.64','2007-11-23 23:07:53','2007-11-23 21:07:53','buey, ieste o transcedere bucolica a steagului uniunii europene !!!\r\nscoate becksu.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8652,805,'WarSongu','eternaldawnlord@yahoo.com','http://www.warsongu.wordpress.com','193.32.3.83','2007-11-23 14:45:56','2007-11-23 12:45:56','http://warsongu.wordpress.com/2007/11/23/gropareeeeeeeeeeeefutumiteash/',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; FunWebProducts; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(8662,807,'July','jullya24@yahoo.com','','83.103.179.55','2007-11-23 17:59:49','2007-11-23 15:59:49','...deci...MEREtzi\' la vot....si o sa mer\'...da nu la vot...ci la busteni, sa respir neshte air curat...ca dak tot e mare agitatie in romanica sa nu stau io in sfanta zi dejaba\'...',0,'1','Opera/9.10 (Windows NT 5.1; U; en)','',0,0),(8663,807,'eu,Miruna','mirunavasilescu@yahoo.com','http://potsafacsiasaceva.blogspot.com/','86.106.59.163','2007-11-23 18:02:19','2007-11-23 16:02:19','Ma, asta-i ca imaginile alea de la rebus, de dintr-o oaie si doi struguri tre sa scoti o propozitie despre iarna?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8649,805,'pliscu','pliscu@gmail.com','http://pliscu.blogspot.com','89.137.100.118','2007-11-23 14:19:31','2007-11-23 12:19:31','@baghy: niste muste cufurite rau de tot',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8544,799,'July','jullya24@yahoo.com','','83.103.179.55','2007-11-22 22:02:50','2007-11-22 20:02:50','iti recomand Parazitii feat Mircea Badea- Politiceanu\' roman......poate te dumireste asta....pe mine m-o scos din ceatza....io o sa stau sa dorm toata ziua cand is alegerile:)',0,'1','Opera/9.10 (Windows NT 5.1; U; en)','',0,0),(8685,807,'Helpthegrass','helpthegrass@yahoo.com','','92.80.125.169','2007-11-23 22:05:59','2007-11-23 20:05:59','Aia cu stema comunista este chiar interesanta. \r\nDar daca facem merele stelute, ca tot este cerul albastru, parca apare steagul UE. Si cum la pomul laudat sa nu meri cu sacul.... parca sunt mai aproape de adevar. Oricum nu o sa mergem totii la pomul asta, doar 35 or sa vad cum este cu pomul, restul (cei mai multi) doar in poze.\r\nSi toate astea doar dupa un pahar de vin:D. Dar noaptea este inca tanara si postarile doar la inceput.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8568,801,'eu,Miruna','mirunavasilescu@yahoo.com','http://potsafacsiasaceva.blogspot.com/','86.106.59.163','2007-11-23 00:18:43','2007-11-22 22:18:43','Tu-ti dai seama cat ai de baut daca vii la Bucuresti? :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8546,799,'marta','mmm7206@yahoo.com','','86.121.12.31','2007-11-22 22:09:25','2007-11-22 20:09:25','1 - politica sociala europeana nu prea are de-a face cu pensionarii, mai curand cu standarde generale pentru populatia activa - standarde care privesc si asigurarile sociale, ce-i drept, dar care vor avea efect asupra noastra; cu siguranta nu are competente privind asigurarile sociale nationale.\r\n2 - imi pare ca cel putin daniel daianu si renate weber pot dialoga cu alde\' nenea si tanti din parlamentul european (ufff... si eu nu sunt tocmai adepta doctrinei liberale, dar pe de o parte la noi in tara nu imi plac alternativele iar la nivel european sunt mai aproape de centru decat popularii)\r\n3 - in familie, mama va vota cu udmr-ul ca sunt membri ppe (si taranistii sunt, de altfel, dar ei nu trec pragul electoral so why bother?) - nu se lasa convinsa nici de faptul ca tata, taranistul care a convertit-o la crestin-democratie voteaza acum cu liberalii, nici de faptul ca va fi injurata de toti cei siliti sa centralizeze voturile, de la presedintele sectiei de votare la cel al biroului electoral judetean, ca le strica statisticile (va fi probabil singurul vot pt udmr in judetul nostru moldovea)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727)','',0,0),(8167,777,'WarSongu','eternaldawnlord@yahoo.com','http://www.warsongu.wordpress.com','193.32.3.83','2007-11-16 14:09:05','2007-11-16 12:09:05','deci aia cu birou de pelerinaj rulz. asteptam cu nerabdare si oficiu de pupat moaste (sau candelabre, cum vrei tu) si institutu de halit anafura...ambele de la Paralela 45',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; FunWebProducts; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(8168,786,'WarSongu','eternaldawnlord@yahoo.com','http://www.warsongu.wordpress.com','193.32.3.83','2007-11-16 14:15:18','2007-11-16 12:15:18','andreio, cum ie fai fato asta cu \"servicii rapide ardelenesti\"? adeca daca ceri ceva cu pui tre sastepti sa futa cocosu gaina, asta sa faca ou, sal clociasca, sa creasca puiu care sa fie sacrificat in conformitate cu normele europene, jumulit, gatit siabia porma servit?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; FunWebProducts; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(8162,777,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-11-16 13:55:17','2007-11-16 11:55:17','@ nana: sa-mi dai 50.000 ca i-am facut reclama!\r\n\r\n@ Paszti: \"parcare\" e terenul de joaca al unei specii urbane de femei, din cate stiu io, si are de-a face cu prefectura finca in ambele meserii e vorba de curvasaraie. Io asa stiu.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8651,797,'WarSongu','eternaldawnlord@yahoo.com','http://www.warsongu.wordpress.com','193.32.3.83','2007-11-23 14:30:02','2007-11-23 12:30:02','ALLPPHHAAAAA BBAAAANNKKKK adica? mam cracanatara pe mine de ras la faza cu caciula.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; FunWebProducts; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(8203,790,'vizionarul','alinmiron_19@yahoo.com','http://vizionarul.wordpress.com','89.35.80.185','2007-11-16 20:23:19','2007-11-16 18:23:19','Dupa bon-bonel, bunicuta vrea sa fie in randul lumii cica... dar vorba aia... Nu intra in lumea drogurilor ca deja suntem prea multi!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8164,790,'WarSongu','eternaldawnlord@yahoo.com','http://www.warsongu.wordpress.com','193.32.3.83','2007-11-16 14:01:43','2007-11-16 12:01:43','doresc ca si pe aceasta cale sa fac un apel la constiinta sociala, sa ne adunam cu mic cu mare, si in sinergia faptelor sa punem pula de la pula si sa\'i dam acestu element antisocial o muie atat de strasnica incat sa eludeze meandrele concretului!\r\n\r\n\r\nPS, fenobarbidoala e o adevarata, pupa tata pe ia.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; FunWebProducts; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(7639,753,'macabroo','raduccc@yahoo.com','http://rezistenta.blogspot.com','80.96.196.2','2007-11-02 09:56:27','2007-11-02 07:56:27','In atentia domnului lucrator la \"o banca\" care citeste acum.\r\n\r\nPuteti sa ma consiliati in legatura cu pensiile private oferite de catre institutia dumneavoastra financiar-bancara? de asemenea puteti sa-mi oferiti credit fara ramburs si sa imi spuneti cat a fost cursul pe data de 22 februarie anul curent?\r\nVa multumesc.',0,'1','Opera/9.23 (Windows NT 5.1; U; en)','',0,0),(7663,756,'Andrei Crivat','andrei@andreicrivat.ro','http://www.andreicrivat.ro','89.137.83.141','2007-11-03 03:19:23','2007-11-03 01:19:23','Gropare, daca te lasi de blogareala, ma las si io de gatit. canci carnaciori de caprioara si mistret, canci fructe de mare, canci bruschete cu creveti, canci in general. A, si i will not like you anymore daca te lasi. parol.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7657,753,'eu,Miruna','mirunavasilescu@yahoo.com','http://potsafacsiasaceva.blogspot.com/','86.106.59.163','2007-11-02 23:30:12','2007-11-02 21:30:12','Haha, mie-mi place de Usim.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(8642,805,'baghy','baghy83@lycos.it','http://baghy.info/','78.12.2.226','2007-11-23 13:19:39','2007-11-23 11:19:39','zici ca s-au cacat mustele',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(8696,807,'Helpthegrass','helpthegrass@yahoo.com','','92.80.125.169','2007-11-23 23:56:20','2007-11-23 21:56:20','Clar este facatura. Defapt la radacina este Elodia. Asta era raspunsul :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(7642,753,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2007-11-02 13:58:42','2007-11-02 11:58:42','Ma, io-ncercai sa il conving sa ma ajute sa spal neshte bani pe care ii am de pe cand traficam mac in Afganistan, da\' o zis ca nu ma mai aude bine si o inkis.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7643,754,'Greuceanu','','','195.149.72.105','2007-11-02 16:21:26','2007-11-02 14:21:26','Daca Euro Car SRL (sibiu) - firma specializata in distributie de ciorapi si dresuri, iar \"Adi internet SRL \"(sebes Alba)- Magazin mixt, atunci rezulta \"Rodi Construct  SRL(Sibiu) - \"Magazin de Blugi!\" - la cerere se pot oferi detalii unde se gasesc aceste cateva exemple!',0,'1','Opera/9.24 (Windows NT 5.1; U; en)','',0,0),(7644,753,'Usim','mihaimitan@gmail.com','','87.237.108.33','2007-11-02 16:34:37','2007-11-02 14:34:37','Miruna, daca citesti articolele lui Groparu iti poti face o imagine despre Om, poti afla si numele si alte informatii. Trebuie doar sa sti sa citesti si sa-ti faca placere sa-l citesti. In plus a postat la un moment dat inregistrarea unei emisiuni la radio si, da, l-am recunoscut si dupa voce :)))\r\n\r\nmacabroo, la prima intrebare raspunsul este nu, ma ocup cu alte probleme in banca; la a doua este iar nu. Pentru cea de a treia intrebare, daca chiar va intereseaza si nu doar va aflati-n treaba, va rog sa fiti un pic mai explicit ca sa inteleg ce anume doriti (valuta, tipul cursului de schimb: cotatia BNR, cursul de vanzare sau cumparare al unei anume institutii financiare etc.). Oricum in era internetului nu cred ca aveti nevoie de mine sa va gasesc un amarat de curs valutar, dar va stau la dispozitie oricum. Trebuie doar sa postati un comentariu la groparu.ro si sigur il voi citi in aceeasi zi.\r\n\r\nIepurasulAtomic, stiu sa citesc si sa si \"calculesc\" insa, intr-adevar nu am talent de prozator sau poet si recunosc ca am copiat in liceu cometariile de la limba romana. \"Terminat\" la litere nu am cum sa fiu pentru nici \"inceput\" la litere nu sunt. De aia lumea il citeste pe Groparu si nu pe un umil functionar de banca.\r\n\r\nGroparu, m-ai convins din momentul in care ai zis \"alo\", insa nu eram singuri pe fir :))))........ Daca este vorba de banutii romanesti de \"plastec\" ii poti spala fara probleme. Numa\' sa dai turatia masinii de spalat mai mica, sa nu ii mototoleasca prea rau :)). Daca este vorba de dolari, si acestia se pot spala cu mare succes. Si se pot si calca apoi daca s-au mototolit. Sunt facuti dintr-un amestec de hartie si un material textil special. Euroii, in schimb au un sistem foarte bun anti-laundering, se strica si nu-i mai poti utiliza dupe aia. Acord asistenta pro-bono.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; .NET CLR 2.0.50727)','',0,0),(7645,753,'IepurasulAtomic','praetorian21uk@yahoo.com','','192.100.130.7','2007-11-02 16:45:35','2007-11-02 14:45:35','Usim&gt;&gt;',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(7646,753,'IepurasulAtomic','praetorian21uk@yahoo.com','','82.77.123.64','2007-11-02 16:48:27','2007-11-02 14:48:27','Deci eu chiar aveam mai multe de zis, da\' vad ca wordpressu\' e pus pe glume:\r\n\"\r\n&gt; Citind cu-n ochi comentariul tau observ ca v-ati simtit(sau te-ai simtit, daca-mi permiti) atacat de comentariu\' meu. Si sincer, acum ca vad ca ezisti pe bune(mi-ai tras-o Gropare la faza asta :)) si ca mi-am recitit comentariu\', inteleg si de ce te-ai simti asha. Da-mi voie sa-mi cer scuze daca(sau mai bine spus \"ca\") te-am jignit. Comentariu\' era fix orientat in directia Groparului, fatza de care am considerat ca-mi permit. Nicidecum n-a fost vreun atac in directia ta(mai ales ca nici macar nu ne stim) si nici a unei institutii bancare sau functionar al unei banci. N-am nimic personal cu unele mai sus mentionate, doar relatii profesionale aproape inevitabile :). Sper sincer sa fiu iertat, pen\' ca fraza \"Pace p\'afara!\" pe care o folosesc la final n-are doar caracter de vorba-n vant. Tind sa cred ca ma ghidez dupa ea si-i invit pe toti sa faca la fel.\r\n\r\nCarevasazica...Pace p\'afara! ;)  \"',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(7647,753,'WhiteWolf','laskmerge@gmail.com','','89.39.83.90','2007-11-02 16:52:28','2007-11-02 14:52:28','Io cre\' ca Usim este si va ramane, in timp, kheatra de temelie, Gropare\r\nEl a fost, este si (inca ce) va mai fi dovada ca, incepand din acest moment, blogul tau devine unul profesional.\r\nCatzi bloggeri betzivi, membrii ai unei asociatii cu blazon si tot ce se mai cere se pot lauda ca au asistenti bancari cu servicii la cheie (pro bono sau nu, tot aia-i semnificatia) si Iepurasi Atomici ?\r\nAud ?\r\nGroparu, zÃ£ uan end onli :P\r\n Usim, nene, frumos ai reusit sa distrugi toate prepuielile romanilor cu ca cei asemeni tie ar fi un fel de \"trebuie sa consulti un specialist\" :))\r\nCe specialisti, domnule ? Niste oameni, acolo, si ei',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(7648,753,'Hammer','hammer@alpinet.org','http://www.alpontos.wordpress.com','86.34.169.230','2007-11-02 16:59:34','2007-11-02 14:59:34','Dar cand ai primit un \"salut Gropare\" dintr-o masina in mers, cu nr de MM (vis a vis de Vodaphone langa statuia lui  Matei) nu tzai pus intrebari de unde ejti cunoscut? :-))',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows CE; IEMobile 6.12)','',0,0),(7649,755,'.marius','marius@perijoc.com','http://marius.wirelessisfun.com','89.36.21.108','2007-11-02 17:10:17','2007-11-02 15:10:17','nuah nu-i frumos ce faci aici... si e si vechi de 2 zile... tz tztz',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7650,755,'Arhi','arhi@arhiblog.com','http://arhiblog.com','82.79.66.93','2007-11-02 17:21:10','2007-11-02 15:21:10','asta se numeste SEO, nu?:)))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7651,753,'Usim','mihaimitan@gmail.com','','87.237.108.33','2007-11-02 18:13:40','2007-11-02 16:13:40','IepurasulAtomic, scuzele, desi nu erau necesare, sunt primite. Nici eu nu m-am priceput sa inteleg in ce parte bati. Recunosc, mi-e mai greu cu literele :-). De aici si admiratia pentru cei ce pot/stiu/au talent sa scrie si sa transforme orice kkt intr-o povestioara haioasa care iti lumineaza ziua. Apreciez gestul si-mi permit sa te citez: Pace p\'afara!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; .NET CLR 2.0.50727)','',0,0),(7652,755,'NRGY','','','86.121.182.143','2007-11-02 18:16:42','2007-11-02 16:16:42','Absolut de acord la faza cu paharu`. Asta am zis si eu de prima data cand am vazut. Si da, e un fel de SEO :))\r\n\r\nJenibil :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7653,751,'Crang','remusmitroi@yahoo.com','','84.232.152.26','2007-11-02 18:32:30','2007-11-02 16:32:30','no, pentru asta, cu sau fara tine, o sa beu\r\nchelteu dupa chelteu.\r\n Mult\' am fain !Saruta-ti-asi ghiulÄƒu Maistre',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; .NET CLR 1.1.4322)','',0,0),(7654,755,'.marius','marius@perijoc.com','http://marius.wirelessisfun.com','89.36.21.108','2007-11-02 19:38:05','2007-11-02 17:38:05','Ah, si am uitat... ultima data cand am verificat nu trebuie sa ti se scoala ca sa iti fie supta... :D \r\n\r\nAm auzit si eu... ca a mea se ai scoala... cate 2 - 3 minute dimineata... :(',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(7655,753,'baghy','baghy83@lycos.it','http://baghy.info/','78.12.17.170','2007-11-02 22:01:01','2007-11-02 20:01:01','Groparu Vip. pentru restul exista Mastercard',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(7656,750,'baghy','baghy83@lycos.it','http://baghy.info/','78.12.17.170','2007-11-02 22:03:06','2007-11-02 20:03:06','figiderele Artic sunt buuuuuune si romanesti. Faza cu lateii m-a spart :))))',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(8684,807,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2007-11-23 22:01:46','2007-11-23 20:01:46','Deci d-abia astept sa va kishati pe voi de ras :D finca it\'s kind of idiotic...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8697,807,'Helpthegrass','helpthegrass@yahoo.com','','92.80.125.169','2007-11-23 23:57:47','2007-11-23 21:57:47','P.S. Oricum stiam ca politicieni au pielea TOV AL, dar nu cred ca trebuia sa ne reamintesti inainte de vot:D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8542,801,'baghy','baghy83@lycos.it','http://baghy.info/','78.12.2.226','2007-11-22 21:56:39','2007-11-22 19:56:39','bine spus Gropy',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(8543,799,'baghy','baghy83@lycos.it','http://baghy.info/','78.12.2.226','2007-11-22 22:00:24','2007-11-22 20:00:24','Gropare cand iti faci partid?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(8462,798,'cilu','','','89.137.99.120','2007-11-21 21:58:12','2007-11-21 19:58:12','Bai,ii fi tu oare Groparu din Caminul 14 de acu\' cativa (4-5) ani ??\r\nSi cu care m-am certat eu la o mica betie prin Jay\'s??',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(8463,798,'nenea cosmos','domnu_cosmos@yahoo.com','http://www.nenea.wordpress.com','92.80.37.56','2007-11-21 21:59:32','2007-11-21 19:59:32','bÄƒ groparule care eÅŸti, da\' tu nu ai Ã®nvÄƒÅ£at la ÅŸcoala generalÄƒ cÄƒ cea mai bunÄƒ minciunÄƒ Ã®i adevÄƒru\'? RecunoÅŸteai smerit cÄƒ aÅŸe de mult Å£i-o plÄƒcut strÄƒchinile cele cÄƒ dacÄƒ surioara ta nu Å£i le dÄƒdea Å£ie le-ai fi rÄƒpit Ã®ntr-o noapte numa\' ca sÄƒ le ai tu. Åži pÄƒ urmÄƒ naÅŸu, la insistenÅ£ele naÅŸei, din supÄƒrarea lui de zici cÄƒ e cu trebi prin spitale tot Ã®Å£i aducea Ã®n seara asta o glajÄƒ cu ceva fain, numa\'.\r\n\r\nOcazie cu care mi-am adus aminte de un banc cu ardeleni pe care l-am auzit aici in BucureÅŸti de la un oltean.\r\nCicÄƒ se duce pÄƒrintele la cÄƒrciuma din comunÄƒ. IntrÄƒ, binecuvÃ®nteazÄƒ pe toÅ£i ÅŸi cere o mÄƒsurÄƒ de la cÃ®rciumar. Acu popa cam avea obiceiul de nu plÄƒtea, mai binecuvÃ®nta niÅ£el ÅŸi se cÄƒrÄƒbÄƒnea. CÃ®rciumarul stÄƒtea cu sticla Ã®n mÃ®nÄƒ ÅŸi se cam codea sÄƒ toarne. PÄƒrintele Ã®i zice:\r\n- MÄƒi fiÅŸior, amu dÄƒ numa\' glaja-ncoace, cÄƒ beu direct din ea, nu-i bai, nu mai speli un Å£oi cÄƒ gura me Ã®i cÄƒt mÄƒsura.\r\nIa popa sticla ÅŸi Ã®ncepe a turna fÄƒrÄƒ limitÄƒ. ÃŽn timpul Äƒsta cÃ®rciumarul Ã®i zice:\r\n- DarÄƒ cacu-m-aÅŸ Ã®n mÄƒsura ta pÄƒrinte, cÄƒ-i spartÄƒ.\r\nAÅŸa bancuri Ã®mi spune mie Cosmos cel venerabil, Dark Vader, tata. Åži nici nu mai respirÄƒ greu cÄƒ s-a lÄƒsat de fumat. AÅŸa mai aflu ÅŸi eu cum e dincolo de munÅ£ii noÅŸtri.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(8554,801,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','86.105.121.103','2007-11-22 22:57:21','2007-11-22 20:57:21','Ceee, baaa, vrei sa ma convingi de ceea ce deja stiu, ca arghelenii astia stau fff prost cu intelectu??? ;;)\r\n\r\nViu, mah, la anu-n Bucale. Musay.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8388,790,'WhiteWolf','contact@white-wolf.ro','http://white-wolf.ro','89.39.82.62','2007-11-19 19:06:07','2007-11-19 17:06:07','@darius f , n-ai vazut ce paros ii Groparele ?\r\nCum sa nu sara ? Asta sare pe tot ce prinde, indiferent de situatie si/sau pozitie.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8389,793,'WhiteWolf','contact@white-wolf.ro','http://white-wolf.ro','89.39.82.62','2007-11-19 19:07:00','2007-11-19 17:07:00','Ne mai tii mult in stand by ? :)\r\nTe-o nins ? Oile\'s la adapost ? :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8632,801,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-11-23 11:54:08','2007-11-23 09:54:08','Tu, Doro :) \r\n\r\nTe bagi cu mine sa facem o postare in care NUMAI sa laudam tiganii? Facem un duplex blogo-postic cum nu o mai fost, si ne-am spalat amandoi obrajii! Si se potoleste si Warsongu\'. Iti trimit neshte piese muzicale care mie imi stau infipte in suflet ca peana in lemn, si descrii geniul muzical al romilor. Te bagi? I\'m in!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8439,797,'WhiteWolf','contact@white-wolf.ro','http://white-wolf.ro','89.39.82.181','2007-11-21 04:22:59','2007-11-21 02:22:59','Hai, dom\'ne ca recunosc eu\r\nLa faza cu caciula am rad de m-am scuturat, geniu paros ce esti',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8441,797,'PhenoBarbieDoll','poisongirl94@yahoo.com','http://blog.360.yahoo.com/poisongirl94','193.230.230.101','2007-11-21 09:52:25','2007-11-21 07:52:25','cand te duci sa platesti rata, le zici ca ai depus o caciula la ei si te interesezi cat e dobanda :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8442,797,'Andreea MKT','supergirgir@yahoo.com','http://marlahermina.deviantart.com/gallery/','82.77.126.254','2007-11-21 10:16:36','2007-11-21 08:16:36','io nu am rate de nici un fel\r\nce, satan, si tu ai rate?\r\npana la 30 de ani nu fac nici o rata si nici un copil.\r\naia-i clar.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(8680,807,'Usim','mihaimitan@gmail.com','','87.237.108.33','2007-11-23 21:09:50','2007-11-23 19:09:50','Iti dau eu o bere daca-mi zici.  Ca degeaba m-am holbat de ma doare ochii ca tot iaca niste mere vad fara alte simboale absconse. Daca ierea neste fripturi....ca io de la mere fac arsuri.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; .NET CLR 2.0.50727)','',0,0),(8675,807,'scritipoliti','marumar@mail.com','','62.224.234.174','2007-11-23 20:23:34','2007-11-23 18:23:34','eheiii, la pomu\' laudat...\r\npastreaza-ti berea, yak !',0,'1','Mozilla/5.0 (Macintosh; U; PPC Mac OS X Mach-O; de; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8499,798,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-11-22 09:09:49','2007-11-22 07:09:49','@ cilu: deci baaaaa, trebuia sa ne si caftim oleaca, sa fie mai induiosatoare reintalnirea!\r\n\r\nDa, mah, ioz.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8528,800,'eu,Miruna','mirunavasilescu@yahoo.com','http://potsafacsiasaceva.blogspot.com/','86.106.59.163','2007-11-22 19:17:38','2007-11-22 17:17:38','Brian, mama, tu esti??',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8520,800,'WhiteWolf','contact@white-wolf.ro','http://white-wolf.ro','89.32.115.196','2007-11-22 17:44:13','2007-11-22 15:44:13','Mai intai intra si mai pe urma iese\r\nCa sa nu-l bagi pe om in paradoxuri.\r\nIn rest, spor la intrudershi :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8527,405,'Nascut din spermatozoizi campioni &raquo; Blog Archive &raquo; Deci, despre tigani','','http://www.groparu.ro/?p=801','82.103.137.253','2007-11-22 19:08:16','2007-11-22 17:08:16','[...] alfel decat mine. Si dupa ce va bucurati, mai explicati-mi de ce TOTI romanii, cand am fost la Tiganiada, cand s-or gandit ca suntem tigani cu bani, erau in stare sa ne linga mochetele si ghiulurile de [...]',0,'1','Incutio XML-RPC -- WordPress/2.1.2','pingback',0,0),(8522,799,'WhiteWolf','contact@white-wolf.ro','http://white-wolf.ro','89.32.115.196','2007-11-22 17:47:39','2007-11-22 15:47:39','Cu aia de or lua-o intre danshii pÃ£ <b>\"zÃ£ cuin of zÃ£ romeiniÃ£n porn\", Aaaaaaaaaalinaaaaaaa  Plugaruuuuuuuu</b>  daca ne promit sa o lase sa ajunga si pe langa mijloacele noastre.\r\nStiu ca se vor inflama - o tzÃ rÃ£ cititoarele tale si porea posibil si doamna de Gropar (care e o doamna, af cors)- da cre\' ca zic corect',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8447,794,'.marius','marius@perijoc.com','http://marius.wirelessisfun.com','89.137.107.129','2007-11-21 12:49:17','2007-11-21 10:49:17','@ groparu taci ca nu a pus link... :))) \r\n\r\nspor cu ridichea si ai grija cine trage de ea... ca am auzit ca e cam mare ;-)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8435,797,'catalin','catalin_heghes@yahoo.com','http://sec.ablog.ro','82.78.131.83','2007-11-20 20:54:45','2007-11-20 18:54:45','degeaba meri ca-ti cere factura de la caciula... care factura fac pariu ca n-o ai',0,'1','Mozilla/5.0 (Windows; U; Win 9x 4.90; en-GB; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(8436,797,'muc-cel-mare','','','89.137.120.1','2007-11-20 22:21:59','2007-11-20 20:21:59','eeeeeheei, rautate  mica! da lasa ca si-o merita. parca le doare sa se uite la tine frumos (va exersa cu auditu\' )',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8640,797,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-11-23 12:58:20','2007-11-23 10:58:20','Nu pot sa divulg numele bancii beta, sau gama, sau nu mai stiu ce alta litera din alfabetu\' grecesc ie! (sau stiu, da\' nu poci spune, ca semnai cu ei ceva contract ce nu-i voi denigra prea tare) \r\n\r\nExperientza faina cu creditele - HVB. Nu Tiriac, nu Unicredit, sediu\' de HVB de la mama lui, si nu ar trebui sa fie probleme. Ca io n-am avut.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8639,805,'pliscu','pliscu@gmail.com','http://pliscu.blogspot.com','89.137.100.118','2007-11-23 12:38:52','2007-11-23 10:38:52','cand se plictisesc, sa incerce si jocul <a href=\"http://www.onlinesport.ro/stiri/fotbal/fotbal-intern/liga-1/steaua/19042/joc-trimite-l-pe-becali-cat-mai-departe-de-ghencea.htm\" rel=\"nofollow\">asta</a>! :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8538,801,'Laura','mars1953@web.de','','84.160.126.167','2007-11-22 21:34:28','2007-11-22 19:34:28','Pentru curajul tau de a ne invita la iubire beau un pahar de vin italian, mananc niste branza frantuzeasca si ascult o doina romaneasca!',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(8563,798,'nenea cosmos','domnu_cosmos@yahoo.com','http://www.nenea.wordpress.com','92.81.18.126','2007-11-22 23:37:28','2007-11-22 21:37:28','bai, stii care e beleaua? am apucat sa invat o meserie, cum sa mai ajung acum politician?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(8564,799,'nenea cosmos','domnu_cosmos@yahoo.com','http://www.nenea.wordpress.com','92.81.18.126','2007-11-22 23:41:54','2007-11-22 21:41:54','gropare, deci eu ca inamicul numero 18 al lui basescu prefer si votez varianta lui la referendumul cu uninominala. deasemenea dintre multe rele probabil ca daca ajung la vot dau cu stampila in liberali, futui. acu sa zica cineva ca nu a cistigat alianta da, ca astia si separati tot fac \"treaba buna impreuna\"...',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(8449,672,'Hammer','hammer@alpinet.org','http://www.alpontos.wordpress.com','86.120.55.79','2007-11-21 13:55:51','2007-11-21 11:55:51','Iaca si patimile altui biciclist :)\r\n\r\nhttp://bucurenci.ro/2007/11/16/oda-pentru-black-magic-woman/\r\nhttp://bucurenci.ro/2007/11/11/pe-banii-mei/',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(8634,803,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-11-23 12:03:59','2007-11-23 10:03:59','Io zic ca era mai bine daca ma pleznea, finca eram la balcon, si chiar nu is curios cum e piesa aia a lu R. Kelly \"I belieeeve I can flyyyy\" traita live!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8627,801,'Doro','kettlerdorothea@yahoo.com','http://www.kettlerdorothea.ro','89.122.253.17','2007-11-23 11:15:44','2007-11-23 09:15:44','Rromii ce trebuie lÄƒudaÅ£i, i-am lÄƒudat Ã®ntr-un paragraf deja, Ã®n aceaÅŸi postare, ÅŸi nu pot sÄƒ pricep cum toatÄƒ lumea trece cu vederea acel paragraf!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8518,799,'catalin','catalin_heghes@yahoo.com','http://sec.ablog.ro','84.232.142.163','2007-11-22 17:22:32','2007-11-22 15:22:32','dÄƒpinde dÄƒ doctrinÄƒ mÃ¢ncaÅ£-aÅŸ (teoretic). practic Ã®ncearcÄƒ sÄƒ faci comprimosul cel mai bun Ã®ntre lista cu puli... politicienii cÃ¢t mai buni, proveniÅ£i dintr-un partid cu oameni cÃ¢t mai curaÅ£i (mÄƒ rog... asta e o Å£Ã¢rÄƒ cam imposibil), afiliaÅ£i la o familie puli... politicÄƒ europeanÄƒ cÃ¢t mai puternicÄƒ. cam asta e problema.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(8669,807,'Andreea MKT','supergirgir@yahoo.com','','89.43.186.64','2007-11-23 19:16:47','2007-11-23 17:16:47','ete floesch, deja s-o zis care e faza: meretzi la vot!\r\n\r\nmie mi se pare ca tata alambicatura aia cu merele care stau asa nia ca intr-o coroana, e ca stema aia comunista cu doua spice care se unesc intr-o coroana. \r\n\r\nma, la anu dau la Arte!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8548,801,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','86.105.121.103','2007-11-22 22:32:12','2007-11-22 20:32:12','@ Anto\': deci da, bah Sherlock, te-ai prins si tu ca iz incoerent, ce sa zic, brava!\r\n\r\n@ Laura: asa, si aibi de grija sa ai si ceva mascul prin asternut, ca sa se merite seara!\r\n\r\n@ Baghy: tu nu mai tat zi de mine, ca mi-ai dat clasa big time cu traficu\', si ma repet: Blavooo!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8549,799,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','86.105.121.103','2007-11-22 22:43:15','2007-11-22 20:43:15','@ baghy: partidu meu de beutura si fomei exista de la maica Eva incoa\' :D you\'re welcome to join !\r\n\r\n@ July: nu-mi killari sperantzia! Finca nu poate ei vota cat furam noi - sau invers!\r\n\r\n@ marta: mucho kosenem pt. comentariu foarte pertinent, de connoisseur, as zice! \r\n1. True, dar UE poate scoate directive si recomandari si mai iashte un tip-doo de legi cu caracter mult mai coercitiv, care sa oblige guvernele nationale sa face ceva referitor la aia din parc care joaca sah; si acilea va trebui oarecum sa ne bazam cÄƒ hÄƒia de la Bruxelles de i-am trimes noi vor ÅŸti sÄƒ apere cauza driaptÄƒ!\r\n2. Good point cu Miss Renate :) DÄƒianu mi se pare venit din aceeasi cloaca cu Isarescu, care ne-o restrictionat creditele, da\' el depasea pragu de 35% de indatorare cu ceva procente la greu (\'tu-i mama lui! - da, stiu, e o abordare personalÄƒ)\r\n3. Ma surprinde optiunea mamei tale, din cate stiam UDMR-ul s-a instrainat la greu de populatia maghiara. FincÄƒ cicÄƒ una e doctrina, alta e politica partidului!\r\nMai hai p-acilea ÅŸi mai comenteÅŸte, pls ;)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8356,790,'darius f','darius2u@yahoo.com','http://desprepsd.wordpress.com/','82.79.52.137','2007-11-19 08:37:58','2007-11-19 06:37:58','Nush ce ai cu Iliescu, ce ti-o facut el tie de sari asa pe el? Parca tu erai apolitic.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8515,800,'.marius','marius@perijoc.com','http://marius.wirelessisfun.com','89.36.21.108','2007-11-22 15:56:37','2007-11-22 13:56:37','unde e upstairs asta? :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8419,794,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-11-20 09:39:52','2007-11-20 07:39:52','Asa-asa, fura-mi cititorii!!! Dupa ce m-ai facut de ras ca tz-am pus mana pe tocu\' de la gun, mi-i mai si furi! Ce urmeaza sa zici amu, ca-s gay, tocmai dupa ce am pus poaza cu tricou meu aniversar???',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8569,801,'baghy','baghy83@lycos.it','http://baghy.info/','78.12.2.226','2007-11-23 00:26:10','2007-11-22 22:26:10','my traffic sucks. se cauta alina plugaru si monica i-o suge lu Iri. ah da si Nicolaeeee Guta',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(8412,794,'Mile','','','86.125.60.222','2007-11-20 03:46:14','2007-11-20 01:46:14','by the way...watch my blog tomorrow to see some pictures from the best place for fishing - SURDUC. Let\'s do it !',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; FunWebProducts; SIMBAR={A7F3C004-B2DD-4145-98BD-0344DDF9CD6E})','',0,0),(8628,801,'mishu','mishu@doingtheartwork.com','http://www.doingtheartwork.com','82.77.126.254','2007-11-23 11:17:07','2007-11-23 09:17:07','Gropy? ;;)\r\nahahhahahhahah\r\n\r\nMa, io mi-am dat seama ca esti destept ma. Cand am vazut ca gandesti putin mai putin ca mine mi-am dat seama ca impreuna am fi geniali ma. Din fericire tu esti flaming heterosexual si eu doar hetero, flamele le las deoparte asa ca nu putem exista impreuna decat platonic si eu la chestii din astea nu ma bag. Da\' ce voiam sa zic... \r\n\r\nEu sper sa nu descoperim planete locuibile \"la indemana\". Ca stricam tot ma Gropy ma. Vorba aia, unde mergem facem gropi, am impresia ca tot ce atinge omul moare sau se distruge. Asa ca fuck civilisation, mai stam aici pana stricam tot si facem bum si-apoi sa vina saturienii sa ne recicleze.\r\n\r\nSi apropo, asa ca tema de gandire: Ce inseamna porcu\' care f*te oaia din Insomnia? Stie careva?\r\n\r\nAaaa si inca ceva! Vizitati-mi www-u\' eu numai de aia comentez ca sa imi fac reclama :) Adieu!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8474,798,'baghy','baghy83@lycos.it','http://baghy.info/','78.12.2.226','2007-11-22 01:47:36','2007-11-21 23:47:36','vezi sa nu le zici ca ai blog :))',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(8432,794,'vizionarul','alinmiron_19@yahoo.com','http://vizionarul.wordpress.com','89.35.80.185','2007-11-20 17:57:55','2007-11-20 15:57:55','ma gropare tu chefuiesti de zici c-amu esti student...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8364,792,'macabroo','raduccc@yahoo.com','http://rezistenta.blogspot.com','80.96.196.2','2007-11-19 10:39:08','2007-11-19 08:39:08','Deci facetzi o transmisie in direct de la locul incidentului. \"Radu..ai legatura...\"',0,'1','Opera/9.23 (Windows NT 5.1; U; en)','',0,0),(8523,799,'adi','adyrotaru@yahoo.com','','89.120.56.7','2007-11-22 17:59:01','2007-11-22 15:59:01','Eu fotez cu PC-ul din 2 consideratiuni:\r\n\r\n1. Is pecist (accept eventualele injuraturi sau laude)\r\n\r\n2. Voiculescu e putred dar numai de bogat ce se afla, fiind singurul parlamentar care nu (mai) ia absolut nici un leu de la buget (nici macar indemnizatia). In schimb, sunt alti \"catzei\" de-ai lui care iau bani fara a avea dreptul (vezi de ex emisiunile Nashul de pe B1 TV).\r\n\r\n3. (bonus, v-am pacalit, ca-s 3 de fapt, nu 2 consideratiuni): tocmai m-am intors de la o sedinta cu Voiculescu la care a promis catorva pensionari cu lacrimi in ochi ca o sa promoveze 2-3 initiative pentru ei (adica pt pensionari, ca masa de manevra ce se afla ei). Pe mine omenashii aia m-au impresionat ca dupa o viata de munca si de platit biruri la stat, acuma mor (literalmente!!!) de foame. Fosti cercetatori au ajuns cersetori (nu e gluma, din pacate). Oameni care se vedea pe ei ca in tinerete aveau vÃ¢na in ei, acuma erau ca niste copii neajutorati care cauta un ajutor providential (cand vezi asa ceva iti vine sa plangi mai tare ca la titanic!).\r\n\r\nScuzati postarea mai lunga, poate prea serioasa si cu tenta electorala.\r\nMi-ati dat ocazia, am profitat.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(8524,799,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-11-22 18:36:28','2007-11-22 16:36:28','@ da, mo CÄƒtÄƒ, da\' care iz aia? Ca doara n-o fi echipa nationala de folbal!!!\r\n\r\n@ Lupulainu\': Io m-as fi si iubit cu tanti aia, da\' numa\' daca as fi fost primu\' cu care s-ar di tavalit inainte de a-si incepe promitatoarea cariera! :D\r\n\r\n@ adi: deci iti dai seama ce jos o ajuns blogu meu, daca pana si PC-istii are un cuvant de spus! ;;) (glumesc, normal)\r\nTrue cu pensionarii, am si io doi acas\'. Atata numa ca nu prea am incredere ca PC va rezolva situatia asta! Si numa\' din cauza lu\' Seres si Voiculescu. Parol. Finca si-or cam dat cu firma in cap. Parol x 2!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8525,800,'eu,Miruna','mirunavasilescu@yahoo.com','http://potsafacsiasaceva.blogspot.com/','86.106.59.163','2007-11-22 18:37:01','2007-11-22 16:37:01','Da\' deloc nu va arde de munca! :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8526,800,'CÄƒlÄƒ','acalarasu@gmail.com','http://adriancalarasu.wordpress.com/','62.217.241.242','2007-11-22 18:59:09','2007-11-22 16:59:09','Aaa, Gravedigger, whose leg do i have to hump to get a dry martini around there?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(8368,793,'IepurasulAtomic','praetorian21uk@yahoo.com','','82.77.123.64','2007-11-19 11:13:37','2007-11-19 09:13:37','Zi-mi si mie te rog daca omu\' asta are vreun filmuletz pe youtube, c-am cautat da\' fix numele asta nu l-am gasit. Nu ca n-as avea incredere in gusturile tale, da\' chiar daca e gratis, tot ash vrea sa stiu la ce ma bag, daca ma bag ;). Multam. Ah da, cuminte cuminte am fost, ca nu prea mai tin minte nimic din weekendu\' asta, asha ca zi-ne ce-ai facut tu. Nu de alta, da-mi trebe si mie niste intamplari pe care sa le pot relata din weekend, ca ale mele...deh...nu suntem toti elefanti ;).\r\n\r\nPace p\'afara!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(8410,794,'Mile','','','86.125.60.222','2007-11-20 03:09:31','2007-11-20 01:09:31','cineva fara sa isi dea seama ce face mi-a pus mana pe pistol si l-a strans tare de tot si daca nu ma credeti o sa gasiti amprentele lu\' Groparu pe coai...aaa manerul pistolului meu. daca carecumva gasiti arma in padure langa o groapa in care e astupata Elodia si vedeti ca e Colt aveti vinovatul dupa amprentare si nickname.\r\nP.S. in rest de chef ce sa spun a fost bestial si nu am vazut pe nimeni coios pe acolo (exagereaza Groparu) dar am intalnit niste oameni atat de faini incat am putut zice la final ca a fost cea mai tare petrecere la care am fost dupa 15 ani. Merci Gropare pentru asta si Ramo e de acord cu mine!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; FunWebProducts; SIMBAR={A7F3C004-B2DD-4145-98BD-0344DDF9CD6E})','',0,0),(8618,801,'Doro','kettlerdorothea@yahoo.com','http://www.kettlerdorothea.ro','89.122.253.17','2007-11-23 09:23:23','2007-11-23 07:23:23','Groparu, repeÅ£i o discuÅ£ie greÅŸitÄƒ care a avut loc ÅŸi acum o sÄƒptÄƒmÃ¢nÄƒ. Nu mai e nevoie sÄƒ repetÄƒm tot circu\'. PoÅ£i sÄƒ spui orice dupÄƒ mine pentru cÄƒ mi-e lene sÄƒ Ã®ncerc sÄƒ mai demonstrez Ã®ncÄƒ o datÄƒ aceleaÅŸi chestie anumÄƒ cÄƒ \"NU urÄƒsc oameni de etnie rromÄƒ\" ci la altceva m-am referit. Cui Ã®i e lene sÄƒ citeascÄƒ toate comentariile, sÄƒ rÄƒmÃ¢nÄƒ cu impresie greÅŸitÄƒ despre mine, cui nu-i e lene, bravo!\r\nPÄƒzea, aveÅ£i de citit http://www.kettlerdorothea.ro/2007/09/25/de-ce-urasc-tiganii.htm ÅŸi http://kettlerdorothea.ro/2007/11/14/de-ce-urasc-tiganii-ii-reactie.htm dacÄƒ le citiÅ£i cu atenÅ£ie eu zic cÄƒ n-aveÅ£i ce sÄƒ nu Ã®nÅ£elegeÅ£i',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8401,793,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2007-11-20 00:53:34','2007-11-19 22:53:34','Minkenash, mah! Nu mai razbesc cu vizitele si alea-alea.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8506,798,'psaico','blog@psaico.info','http://www.psaico.info','78.96.86.55','2007-11-22 11:44:54','2007-11-22 09:44:54','=))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8502,798,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-11-22 09:53:24','2007-11-22 07:53:24','@ cosmos: deci faza cu mintitu nashilor mei e dementiala. Si bah: daca tot minti mai bine ca mine, nu te faci politician? Te votez in fiecare zi, jur!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8426,794,'WhiteWolf','contact@white-wolf.ro','http://white-wolf.ro','89.39.82.181','2007-11-20 14:49:44','2007-11-20 12:49:44','Si cu ridicea aia niagra in loc de cap si tot ar trebui sa bunghesti ca-ti fura cititorii cu stil :)\r\nSi-n plus, ce sa mai.... ; beat sau nebeat, mana ai pus-o de buna-voie. Ca doar daca te-ar fi fortat, nu te abtineai sa nu zici.\r\nAsa ca lasa ca el :) Fapta recunoscuta e pe juma\' iertata si\'n plus, aia cu \"lume faina, oameni dragi, eram beat muci\" chiar e credibila. :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8532,801,'Razvan Antonescu','razvan.antonescu@gmail.com','http://idei-locale.blogspot.com','79.113.137.250','2007-11-22 19:44:23','2007-11-22 17:44:23','Am vaga impresie ca o fo cam subtila pt tinte chestia asta. Really.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071018 Firefox/2.0.0.8 Flock/1.0RC3 VRE Toolbar 1.42','',0,0),(8635,797,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','82.77.126.148','2007-11-23 12:15:36','2007-11-23 10:15:36','la ce banca ti-ai facut rata, sa stiu sa nu ma duc. vreau sa-mi fac rata pentru obiective, ca e scumpe ca dracu si nu-mi ajung salariile pe juma de an! :(',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9','',0,0),(8552,801,'CÄƒlÄƒ','acalarasu@gmail.com','http://adriancalarasu.wordpress.com/','89.32.19.126','2007-11-22 22:47:01','2007-11-22 20:47:01','\"sunt obligat sÄƒ ii urasc pe mitici \"\r\nce-seamna, dom\'ne, sa ai principii...\r\nLasa Gropule, nu t-oi prinde io-ntr-o zi la beutura, ca sa vedem noi care-i al mai tare-n... percepte?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) )','',0,0),(9540,856,'vizionarul','alinmiron_19@yahoo.com','http://vizionarul.wordpress.com','89.35.87.15','2007-12-11 08:17:37','2007-12-11 06:17:37','lasa ma gropare, ca toate trec, daca ai rezistat deja 10 zile fara tigari, sa stii ca rezisti de-amu inainte o viata... Depinde de vointa ta si cred ca tu esti  un om hotarat. Ti-e greu fara tigari ca esti in sevraj ma... corpu tau s-a invatat cu otrava si incet incet se dezvata. Io zic sa te plimbi mai des cu Ratucu la orele de varf cand iasa liceencele de la scoala sau sa-ti faci un obicei de a te plimba prin campusurile studentesti, macar iti clatesti si tu ochii si trece mai usor',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648)','',0,0),(9542,856,'Adrian Popa','admin@adrianpopa.ro','http://www.adrianpopa.ro','89.137.83.141','2007-12-11 09:00:28','2007-12-11 07:00:28','of grea leapsa, intr-o perioada atat de incarcata de evenimente :)\r\ndar incerc sa raspund azi sau maine.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9544,853,'mirra','','','83.103.137.234','2007-12-11 09:40:31','2007-12-11 07:40:31','bravo,traffik!Tare de tat!:)))))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9549,858,'macabroo','raduccc@yahoo.com','http://rezistenta.blogspot.com','80.96.196.2','2007-12-11 10:19:15','2007-12-11 08:19:15','Straniu. Dar hei, nu te-a facut sa te simti tanar?',0,'1','Opera/9.23 (Windows NT 5.1; U; en)','',0,0),(9550,858,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-12-11 10:21:36','2007-12-11 08:21:36','Ba cum nu! Mi-o adus aminte de vremile cand inotam vesel, spermatozoideste vorbind.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9742,868,'baghy','baghy83@lycos.it','http://baghy.info/','78.12.17.109','2007-12-13 16:23:34','2007-12-13 14:23:34','Mirra si eu zic ca tine :))',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(9414,842,'nenea cosmos','domnu_cosmos@yahoo.com','http://www.nenea.wordpress.com','92.80.7.164','2007-12-09 17:04:04','2007-12-09 15:04:04','deci intri si tu in rindul lumii, iti iei carnet, in sfirsit inveti si tu o meserie...',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(9621,819,'July','jullya24@yahoo.com','','83.103.179.55','2007-12-12 01:45:03','2007-12-11 23:45:03','....subscriu si io...sa hie si Tiganiada feminina!',0,'1','Opera/9.10 (Windows NT 5.1; U; en)','',0,0),(9502,853,'traffik','','','86.123.185.94','2007-12-10 20:24:13','2007-12-10 18:24:13','Am dat telefon la numarul din anunt si zice ca nu vinde. da fapt cumpara. Si nu porci, cumpara capre.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9589,819,'Andreea MKT','supergirgir@yahoo.com','','89.43.186.64','2007-12-11 19:17:57','2007-12-11 17:17:57','mah, sunt incantata. io ma gandesc serios sa o racolez pe gagicata si pe inca cateva gagici de pe blogu asta ca e gagici bune si sa facem tiganiada feminina. si noi nu ne dam shuturi in  c@, dar putem ghici in palma, face blesteme, negocia, putem ramane gravide si putem fura.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9608,846,'Ionut','ion@yahoo.com','','89.34.225.25','2007-12-11 22:48:47','2007-12-11 20:48:47','Hehe, l-am luat. Cu toata modestia  :), trebuie sa recunosc ca am fost meserias, am condus fara greseala. Am mai dat si-asa doar cu o mana pe volan, ca sa punctez la impresia artistica :)   Daca ma pica il aruncam din masina :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(9593,819,'vizionarul','alinmiron_19@yahoo.com','http://vizionarul.wordpress.com','89.35.87.15','2007-12-11 20:02:28','2007-12-11 18:02:28','pa glesnÄƒ Äƒla sÄƒ-l tundeÅ£ chel ÅŸi sÄƒ-l puneÅ£ sÄƒ mÃ¢nce peÅŸte crud cÄƒ iel oricum samÄƒnÄƒ cu Smeagol...',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648)','',0,0),(9594,819,'vizionarul','alinmiron_19@yahoo.com','http://vizionarul.wordpress.com','89.35.87.15','2007-12-11 20:02:53','2007-12-11 18:02:53','pe ielvis... pardon.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648)','',0,0),(9603,819,'WhiteWolf','contact@white-wolf.ro','http://white-wolf.ro','89.39.81.227','2007-12-11 21:10:12','2007-12-11 19:10:12','<b>Gud point</b> porculeanu :) :)\r\nSi inca la dublu :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9604,819,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2007-12-11 21:19:36','2007-12-11 19:19:36','Baaaa, voi tineti cu iele?\r\n\r\nNu uitati ca barbatu are functie estetica numa\' de cand cu Justin Timberlake.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9605,819,'baghy','baghy83@lycos.it','http://baghy.info/','78.12.6.155','2007-12-11 21:38:59','2007-12-11 19:38:59','Ielvis in pielea goala pe rau in sus ca somonii e superb :)))',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(9225,844,'vizionarul','alinmiron_19@yahoo.com','http://vizionarul.wordpress.com','89.35.87.15','2007-12-05 18:32:19','2007-12-05 16:32:19','ce bou de petcu si ala, el nu stie ca femeile e facute sa le iubim nu sa le bruscam?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(9226,842,'Lexis','g_lexis2005@yahoo.com','http://www.alexandraghitalexis.blogspot.com','89.38.76.46','2007-12-05 18:36:04','2007-12-05 16:36:04',':)) fuuuuuarte fain frate, misto...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9227,843,'Lexis','g_lexis2005@yahoo.com','http://www.alexandraghitalexis.blogspot.com','89.38.76.46','2007-12-05 18:37:46','2007-12-05 16:37:46','Doamne, bine ca am scapat :| imi aduci aminte de vremurile mele... adica ieri si alaltaieri :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9228,844,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2007-12-05 18:53:33','2007-12-05 16:53:33','Corect! Exceptand cazurile de legitima aparare, dimineatza, de la crajma.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9229,844,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','85.186.77.129','2007-12-05 19:13:09','2007-12-05 17:13:09','asta nu-i barbat, in pana mea! eu cand aud de barbati ca \"bruscheteaza\" femei fac cu nervii si vad negru in fata ochilor!! apai daca eram in locul fetii, io, cu aia 1,63 ai mei, ii trageam una de sa ma tina minte!! cu tot cu aia 1,80-ul lui!! am mai batut eu baieti la viata mea, si mai mari ca el... asa ca sa nu il prind ca-i arat eu bruschetare!!! &gt;:(',0,'1','Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.1.10) Gecko/20060601 Firefox/2.0.0.10 (Ubuntu-edgy)','',0,0),(9230,844,'Alexandra Groza &raquo; Blog Archive &raquo; Violenta in presa - bruscare a la Petcu','','http://www.alexis-design.info/violenta-in-presa-bruscare-a-la-petcu/','66.228.121.163','2007-12-05 20:39:37','2007-12-05 18:39:37','[...] In primul rand vreau sa le multumesc celor care au scris despre patania (sa ii zicem asa ) de azi dimineata: Razvan, Mihai Prodan, Andrei Crivat, Chinezu, Radu, Vasile si Groparu. [...]',0,'1','Incutio XML-RPC -- WordPress/2.2','pingback',0,0),(9231,844,'&raquo; E prea de tot Vasile Racovitan: Ã®n alb ÅŸi negru','','http://www.vasileracovitan.com/2007/12/05/e-prea-de-tot-2/','72.52.136.8','2007-12-05 20:45:55','2007-12-05 18:45:55','[...] colegÄƒ, tot din presÄƒ, vÄƒ invit sÄƒ o citiÅ£i la alÅ£ii - RÄƒzvan, Mihai, Radu, Andrei, Chinezu, Groparu ÅŸi, logic, pentru cÄƒ nu avea cum sÄƒ lipseascÄƒ, Alexandra, eroinÄƒ fÄƒrÄƒ voie. Eu o sÄƒ mÄƒ [...]',0,'1','Incutio XML-RPC -- WordPress/2.3','pingback',0,0),(9232,844,'ViolenÈ›Äƒ de salahor Ã®n presÄƒ at Jurnal de noapte','','http://www.andreicrivat.ro/2007/12/05/violenta-de-salahor-in-presa/','212.227.64.193','2007-12-06 00:17:54','2007-12-05 22:17:54','[...] mai scris: Prodan, Chinezu, Vasile, Groparu, Radu, [...]',0,'1','Incutio XML-RPC -- WordPress/2.2','pingback',0,0),(9315,847,'szidi','','','82.77.126.254','2007-12-07 15:03:36','2007-12-07 13:03:36','De expl.Chokotoff de la Poiana nu-i ciocolatica ieftina... si cioco Milka....Se pare ca ti-ai ingropat Moshu 2008.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(9242,846,'July','jullya24@yahoo.com','','83.103.179.55','2007-12-06 13:05:19','2007-12-06 11:05:19','Lasa-l mah pe asta....nu vezi ca nu stie nica\'...mai bine cauta altu\' fara atatea pretentii absurde...Ute\' deia nu fac io scoala de soferi, ca instructorii astia nu sunt buni de nimic...nu stiu cin\' le-o fi dat carnet si lor.',0,'1','Opera/9.10 (Windows NT 5.1; U; en)','',0,0),(9243,846,'manole','redtailanda@yahoo.com','http://www.mesterulmanole.wordpress.com','81.181.92.157','2007-12-06 13:11:53','2007-12-06 11:11:53','groparele, s-au cam schimbat rolurile... si nu meriti ca tu-mi esti simpatic iar el mi-e imbecil. nici dupa doua luni - dupa ce-ai luat carnetu\' - nu vezi toate semnele din copaci si masina are atatea butoane, de manete ce sa-ti mai zic! era rosu la semafor!- zice unu\' verde din dreapta mea /ta- care semafor? intreb eu/tu si tot ase. Da\' tu fi relaxat ca e pe banii tai!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows 98)','',0,0),(9240,844,'manole','redtailanda@yahoo.com','http://www.mesterulmanole.wordpress.com','81.181.92.157','2007-12-06 09:40:33','2007-12-06 07:40:33','a bruscha, a batea, a injura, a scuipa, a jigni - apanjul celor  cu mai putine sau fara argumente, niste moluste cu muschi.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows 98)','',0,0),(9245,846,'milanesta','ana_stefanaaa@yahoo.com','','89.34.180.55','2007-12-06 13:51:45','2007-12-06 11:51:45','Lasa ca e bine asa :D ...sa te toace de la inceput sa te obisnuiesti cu stresul :)) \r\nEu in locul tau mi-as cauta o instructoare :D poate sunt si de astea .Ca pe alea le mai vrajesti de uita sa mai urle la tine :))',0,'1','Opera/9.10 (Windows NT 5.1; U; en)','',0,0),(9276,847,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2007-12-06 20:41:06','2007-12-06 18:41:06','@ catalin: sa-mi zici si mie ce gust are vita argentiniana din care s-au infruptat deopotriva puterile axei si ale antantei, in WWII!\r\n\r\n@ Lumi: io-s acelasi, numa cu privire oleaca ÅŸi mai tÃ¢mpÄƒ ÅŸi cearcÄƒne mai borÅ£oase decÃ¢t mÄƒ ÅŸtiai :D\r\n\r\n@ Lilith: surprize de care, ca de la prostituate? ;;)\r\n\r\n@ traffic: e o firma companie coperativa. In weekend e super fain.\r\n\r\n@ vizionarul: man, astia fin poza is numa cei mai adaptati social din firma. Estia-s.\r\n\r\n@ Usim: ca sa-mi deie mie subecte de blog! :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9249,58,'Mih_nea','mihnea_xxyahoo.com','','62.217.236.12','2007-12-06 14:21:55','2007-12-06 12:21:55','Esti dus cu pluta rau de tot, in sensul bun. Zi-mi numele tau real, ca vreau sa-ti urmaresc cariera.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(9250,846,'iulia','iuliaiacob2003@yahoo.com','','86.123.85.9','2007-12-06 14:58:04','2007-12-06 12:58:04','of of....sa mai radem si noi sa ne descretim fruntile:) \r\nplace la mine blogul tau sau ce o fi\r\nde la alba iulia city',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; IEMB3; IEMB3)','',0,0),(9252,100,'Mih_nea','mihnea_xxyahoo.com','','62.217.236.12','2007-12-06 15:39:36','2007-12-06 13:39:36','am ras cu lacrimi',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(9275,847,'Usim','mihaimitan@gmail.com','','87.237.108.33','2007-12-06 20:23:00','2007-12-06 18:23:00','Inginerii tai sunt bestiali! Sunt sarea si piperul postului.\r\nCum de s-au adunat la tine la slujba?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; .NET CLR 2.0.50727)','',0,0),(9255,846,'Lexis','g_lexis2005@yahoo.com','http://www.alexandraghitalexis.blogspot.com','89.38.76.46','2007-12-06 15:59:18','2007-12-06 13:59:18','vai ce caterinca... :)) Bine i-ai facut... aia cu \"relaxeaza-te\" e replica mea favorita...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9259,846,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-12-06 16:28:23','2007-12-06 14:28:23','Deci clar ca nu disper! Mai ales ca data viitoare vreau sa vorbesc cu un dentist, sa imi stranga o saptamana ce prinde prin cariile clientilor, ca sa am ce-i pune la nenea pe volan.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9257,847,'NRGY','dani@live.co.uk','http://netsquad.org','86.121.174.24','2007-12-06 16:19:10','2007-12-06 14:19:10','Mmmmm... Pufuuleeti.... Mie de ce nu mi`ai adus nik?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9258,846,'vizionarul','alinmiron_19@yahoo.com','http://vizionarul.wordpress.com','89.35.87.15','2007-12-06 16:19:51','2007-12-06 14:19:51','mai gropare, parca-l vad pe fostul meu instructor cand citesc fragmentul de mai sus... atata s-o disperat omul ala c-o zis ca nu iau permis... si l-am luat din prima! asa ca nu dispera, asculta ce zice, zi ca el si fa ca tine!',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(9260,847,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-12-06 16:30:42','2007-12-06 14:30:42','Cum nik! Tz-am adus mirosul din ghetele pe care le porti zilnic.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9261,847,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-12-06 16:30:57','2007-12-06 14:30:57','Da, man, s-a aflat. Toata blogosfera stie.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9262,847,'PhenoBarbieDoll','poisongirl94@yahoo.com','http://blog.360.yahoo.com/poisongirl94','193.230.230.101','2007-12-06 16:31:56','2007-12-06 14:31:56','Tzoooo! call me Sherlock :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9263,846,'na instructor','','http://www.instructor-auto.octet.ro','81.196.150.96','2007-12-06 16:40:15','2007-12-06 14:40:15','In caz ca vrei sa scapi de stressu cu instructoru',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.648; .NET CLR 3.5.21022)','',0,0),(9264,847,'catalin','solo@xsolo.biz','http://xsolo.biz','190.2.54.69','2007-12-06 17:00:41','2007-12-06 15:00:41','Aci moshu aduce super gratare azi. Obiceiul nu este, insa azi la 21(ora Arg) fac un \"super grande mega asado\" cu vreo 10 kg de pura carne de vaca argentiniana. Toti sint invitati, sper poze faine apoi......',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9314,850,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-12-07 14:58:03','2007-12-07 12:58:03','@ lilith: dupa cum spunea un clasic in viatza: decat 3 ore lÄƒlÄƒite, mai bine 3 minute pasionale!\r\n\r\n@ baghy: io zic ca nu incape comparatie, finca io daca ma curentez nu mi-i frica ca vine careva sa deie un buzunar la gÃ¢Å£i! (numa bancile, da asta-i altÄƒ discuÅ£iune)\r\n\r\n@ mirra: nici nu stii cat adevar grait-ai!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9267,847,'Lumi','luminitadanciu@yahoo.com','','209.221.168.249','2007-12-06 18:29:01','2007-12-06 16:29:01','Very funny pics. Which one is you, Gropare? :D\r\nI wanna see what you look like these days...',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; InfoPath.1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(9268,847,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','85.186.77.129','2007-12-06 18:54:00','2007-12-06 16:54:00','daca nu sunt pufuleti cu surprize... atunci esti degeaba! :(',0,'1','Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.1.10) Gecko/20060601 Firefox/2.0.0.10 (Ubuntu-edgy)','',0,0),(9269,847,'traffik','','','86.123.182.205','2007-12-06 19:02:00','2007-12-06 17:02:00','Imi pun intrebari serioase despre firma la care lucrezi!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9312,850,'mirra','','','83.103.137.234','2007-12-07 14:36:22','2007-12-07 12:36:22','porcu ca porcu,frate,pacat ca ai ratat oaia...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9313,845,'mirra','','','83.103.137.234','2007-12-07 14:37:51','2007-12-07 12:37:51','Azi toti am fost moshi, na si de ciuda!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9279,437,'^^','cr7_fan@yahoo.com','','86.34.244.69','2007-12-06 21:39:43','2007-12-06 19:39:43','Hai k imi place :))',0,'1','Opera/9.21 (Windows NT 5.1; U; en)','',0,0),(9278,846,'De aia','assw@yahoo.com','http://de-aia.blogspot.com','79.113.132.110','2007-12-06 21:24:54','2007-12-06 19:24:54','gropare, io am zas. direct pilot te faci ;)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.2) Gecko/20070219 Firefox/2.0.0.2','',0,0),(9273,847,'vizionarul','alinmiron_19@yahoo.com','http://vizionarul.wordpress.com','89.35.87.15','2007-12-06 20:01:07','2007-12-06 18:01:07','ma gropare... copchii aia okelaristi, unde i-o gasit firma ta? Astia-s fiinte d-alea superinteligente si inadaptate la viata in societate? sau si-au facut poze cu okherii bunicilor?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(9274,676,'Superoferta 2 in 1','','http://www.visurat.org/?p=1238','74.54.41.98','2007-12-06 20:11:50','2007-12-06 18:11:50','[...] Groparu ma intreaba (fara sa`i ceara acceptul retardului JEGos) care ar fi numele meu de indian. Numele meu [...]',0,'1','Incutio XML-RPC -- WordPress/2.3.1','pingback',0,0),(9235,845,'baghy','baghy83@lycos.it','http://baghy.info/','78.12.6.155','2007-12-06 00:56:30','2007-12-05 22:56:30','Gropare uita-te aici http://www.protv.ro/stiri/tu-stii-ce-mai-face-copilul-tau/educatia-si-tehnologia-primeaza-in-fata-traditiilor-de-generatii.html . :)))',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(9236,845,'baghy','baghy83@lycos.it','http://baghy.info/','78.12.6.155','2007-12-06 00:56:47','2007-12-05 22:56:47','si la video',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(9320,850,'vizionarul','alinmiron_19@yahoo.com','http://vizionarul.wordpress.com','89.35.87.15','2007-12-07 17:25:36','2007-12-07 15:25:36','ma gropare ar trebui sa te faci maestru de ceremonii ca vad ca anu asta ai fost la o gramada de nunti si sindrofii...',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(9282,847,'Andreea MKT','supergirgir@yahoo.com','','89.43.186.64','2007-12-06 23:04:20','2007-12-06 21:04:20','Deci Gro si Tzo, cei doi barbatzi de nadejde ai firmei noastre mi-au dat si mie doua pungi de pufuletzi care miros intocmai ca shosetele lor. Nu mai vrem!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9318,850,'mirra','','','83.103.137.234','2007-12-07 16:49:38','2007-12-07 14:49:38','Stiu frate,ca de-aia am zis!!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9324,850,'WhiteWolf','contact@white-wolf.ro','http://white-wolf.ro','89.39.81.137','2007-12-07 19:19:43','2007-12-07 17:19:43','<b>Asomare</b> iti spune ceva ? :P\r\n\"Sa spunem altfel: veterinarul satului iti intra in curtea casei si iti impusca porcul in cap. Obligatoriu. Ametit cu tranchilizante, porcul va fi o victima tacuta. Departe de a mai avea loc vreo urma de ritual de vinatoare, va fi o simpla si europeana capitulare. Porcul romanesc va muri inainte sa apuce sa dea nici cea mai mica batalie. Asa suna teoretic chestiunea, conforma cu regulamentele de la Bruxelles.\"\r\nPune mana si aplica :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9327,850,'vizionarul','alinmiron_19@yahoo.com','http://vizionarul.wordpress.com','89.35.87.15','2007-12-07 22:44:36','2007-12-07 20:44:36','@whitewolf: si unde-i farmecu taierii porcovanului!?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(9406,852,'ovidiu666','ovidiulechintan@yahoo.com','http://ovidiu666.wordpress.com','89.137.118.254','2007-12-09 14:51:45','2007-12-09 12:51:45','ultimul post e de la vreo increngatura pe net, intre blog-uri... nu eu l-am postat... ?!...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9405,852,'hai la nuntÄƒ&#8230; taci din gurÄƒ! :)) &laquo; blogu&#8217; lu&#8217; ovidiu666','','http://ovidiu666.wordpress.com/2007/12/09/hai-la-nunta-taci-din-gura/','72.233.44.27','2007-12-09 14:50:00','2007-12-09 12:50:00','[...] Top 10 chestii care nu se spun miresei la o nunta [...]',0,'1','Incutio XML-RPC -- WordPress/MU','pingback',0,0),(9404,852,'ovidiu666','ovidiulechintan@yahoo.com','http://ovidiu666.wordpress.com','89.137.118.254','2007-12-09 14:48:40','2007-12-09 12:48:40','mirii au fost la fel de tari ca si astia?...\r\nhttp://www.youtube.com/watch?v=Vqiw-Kqtlr0',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9333,847,'macabroo','raduccc@yahoo.com','http://rezistenta.blogspot.com','82.76.52.94','2007-12-07 23:28:54','2007-12-07 21:28:54','Parca era vorba gropare sa nu pui poae intime de cand am facut intalnirea aia blogaristica. Imi puneam macar puloverul cu bradul. Oameni suntem ce mama naibiului!',0,'1','Opera/9.24 (Windows NT 5.1; U; en)','',0,0),(9334,850,'andreanum','andreanum@yahoo.com','http://andreanum.wordpress.com','80.97.188.148','2007-12-08 00:09:06','2007-12-07 22:09:06','stai cu porcu ca oaia e primejdioasa, se ataseaza de cioban si pune probleme sentimentale la gatit :D',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(9403,852,'ovidiu666','ovidiulechintan@yahoo.com','http://ovidiu666.wordpress.com','89.137.118.254','2007-12-09 14:43:11','2007-12-09 12:43:11','cacat! :)) da!\r\nce sa fac daca numa\' la amor imi zboara capu\'! ambele! :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9402,852,'George','orizonturi.nocturne@yahoo.co.uk','','89.32.80.151','2007-12-09 14:42:12','2007-12-09 12:42:12','intaia noapte de razboi...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9401,852,'ovidiu666','ovidiulechintan@yahoo.com','http://ovidiu666.wordpress.com','89.137.118.254','2007-12-09 14:39:21','2007-12-09 12:39:21','15. ce mancare de rahat ati servit. nu tu ai gatit-o, nu?\r\n16. de-acuma incolo sa nu mai bei in halul in care ai facut-o la nunta ta!\r\n17. nu bagati si maneau aia de la denisa - ultimul sarut?\r\n18. ai citit \"ultima noapte de dragoste, intaia noapte de amor\"?\r\n19. sper ca nu o sa ajunga la fel de urat, gras si prost ca socru-to\'!\r\n20. fuck! stii ca am planificat gresit \"petrecerea burlacelor\"?!... e maine!\r\n21. pot sa adun eu capacele de la cola?\r\n22. vezi ca mirele s-a dus sa vada meciu\' (sau varianta hard - serialul \"neveste disperate\")\r\n23. incalta-te la loc. mai bine sa suporti tu durerea, decat noi mirosu\'...\r\n24. azi e si ziua ta, nu? ce nasol o sa fie peste cativa ani, cand n-o sa te mai poti bucura nici macar de ziua ta...\r\n25. ma duc sa ma imbat! nunta mai naspa ca asta, rar mi-a fost dat sa traiesc...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9341,847,'radell','radell@gmail.com','','89.123.72.51','2007-12-08 04:47:01','2007-12-08 02:47:01','Asa cum porumbului fiert i se mai spune si mamaliga pe bat\r\npropun ca pufuletii sa se numeasca mamaliga gonflabila ca prea \r\ncu multa dragoste tineai sacii aia in brate.',0,'1','Opera/9.22 (Windows NT 5.1; U; en)','',0,0),(9348,850,'vizionarul','alinmiron_19@yahoo.com','http://vizionarul.wordpress.com','89.35.87.15','2007-12-08 10:41:11','2007-12-08 08:41:11','nu doar probleme sentimentale,  gandeste-te cum se ruineaza niste planuri de viitor.... o adevarata relatie.... iar ciobanul va fi frustrat si dezamagit ca nu se va mai inverzi in genunchi ca alta data....',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(9349,846,'ovidiu666','ovidiulechintan@yahoo.com','http://ovidiu666.wordpress.com','89.137.118.254','2007-12-08 10:55:01','2007-12-08 08:55:01','eu il strangeam de gat dupa primele interjectii! si ii lasam productia din nas (toata si suflata) pe parbriz.\r\na! dc vrei, dupa ce termini, mai ales ca e iarna, arunca vreo doua oua pe parbriz, imprastie-le pe tot parbrizul, dupa care pune niste ziare pe el. dupa pompa de benzina belita de modul tau de a conduce, va trebui sa-si schimbe si parbrizul. stiu din proprie experinta. ;)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9350,841,'ovidiu666','ovidiulechintan@yahoo.com','http://ovidiu666.wordpress.com','89.137.118.254','2007-12-08 11:05:47','2007-12-08 09:05:47','eu m-am lasat trei ani de zile, dupa cinci ani de tras si impins fumu\' din piept. si m-am apucat iar ca bou\' (cu accent pe u, ca pe cfr n-am cum)! si acum incerc iara. dar numai cand e iubita prin preajma... sssst!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9386,852,'baghy','baghy83@lycos.it','http://baghy.info/','78.12.6.155','2007-12-09 02:09:21','2007-12-09 00:09:21','punctul 10 e criminal. :)))',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(9387,852,'L3ST','webmaster@l3st.com','http://www.l3st.com/','89.34.247.119','2007-12-09 02:17:55','2007-12-09 00:17:55','Hahaha esti durere omule :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9204,842,'Femeile','ps@yahoo.com','http://ce-vor-femeile.blogspot.com','213.157.188.71','2007-12-05 09:57:49','2007-12-05 07:57:49','no ma gropare, te faci pilot?!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9205,763,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-12-05 10:10:02','2007-12-05 08:10:02','Nu, mah, am mai vast si cele mai betoane fomei din zona!!!! :O',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9206,842,'manole','redtailanda@yahoo.com','http://www.mesterulmanole.wordpress.com','81.181.92.157','2007-12-05 10:18:30','2007-12-05 08:18:30','chilot si spuni. :)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows 98)','',0,0),(9207,842,'sabina','','','81.12.163.178','2007-12-05 10:31:22','2007-12-05 08:31:22','=))',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(9214,843,'galatzi','galatzy_2004@yahoo.com','http://galatzy.nabelea.com','213.92.80.220','2007-12-05 13:07:19','2007-12-05 11:07:19','http://www.libertatea.ro/index.php?section=articole&amp;screen=stire&amp;sid=192855\r\n\r\nGropare, nici tu nu te-ai gandit la asta ... :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7','',0,0),(9311,847,'mirra','','','83.103.137.234','2007-12-07 14:33:45','2007-12-07 12:33:45','pffff!Colejii tai is mortali,ce mai.....baetzi de baetzi.....de fapt nu ma mir seamana cu tine si dara cin se-aseamana se-aduna,hahahahahahaha',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9223,844,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-12-05 17:15:06','2007-12-05 15:15:06','Amu ce-i o strada la scara universului?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9217,843,'manole','redtailanda@yahoo.com','http://www.mesterulmanole.wordpress.com','81.181.92.157','2007-12-05 14:04:22','2007-12-05 12:04:22','am fo unde a spus galatzi. astia nu pot veni si m-nainte ase cam cu fo 40 di ani? :)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows 98)','',0,0),(9222,844,'Andrei Crivat','andrei@andreicrivat.ro','http://www.andreicrivat.ro','89.137.83.141','2007-12-05 16:59:43','2007-12-05 14:59:43','de pe Albac, parerea mea de sudist, fir-as al dreaq de mitic',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9219,843,'baghy','baghy83@lycos.it','http://baghy.info/','78.12.6.155','2007-12-05 15:23:07','2007-12-05 13:23:07','de unde le mai scoti? :))))',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(9220,843,'cilu','','','80.97.64.238','2007-12-05 15:28:48','2007-12-05 13:28:48','Chestiile 1 si 2 spuse una dupa alta cred ca l-au derutat pe bietul instructor!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(9221,843,'cilu','','','80.97.64.238','2007-12-05 15:29:23','2007-12-05 13:29:23','Ca sa nu mai adaugam si punctul 6!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(9359,832,'ovidiu666','ovidiulechintan@yahoo.com','http://ovidiu666.wordpress.com','89.137.118.254','2007-12-08 15:07:18','2007-12-08 13:07:18','dc ii primiti si pe nou-sositii in blogareala ma bag si eu.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9360,820,'ovidiu666','ovidiulechintan@yahoo.com','http://ovidiu666.wordpress.com','89.137.118.254','2007-12-08 15:14:41','2007-12-08 13:14:41','caca-m-as! :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9391,852,'sweeper','ak70g2@gmail.com','','86.107.192.53','2007-12-09 05:27:21','2007-12-09 03:27:21','Gropare... Tu o sa ma omori pe mine... De ras!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; .NET CLR 2.0.50727)','',0,0),(9596,819,'nefe','unclientfericit@gmail.com','','89.84.149.111','2007-12-11 20:20:40','2007-12-11 18:20:40','Fara muieri? Pff!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9297,847,'manole','redtailanda@yahoo.com','http://www.mesterulmanole.wordpress.com','89.32.123.108','2007-12-07 07:03:27','2007-12-07 05:03:27','cu cat ma uit mai bine la poza cu coleji tai,  nu pot ca sa nu te intreb daca nu cumva ai facut confuzie? ca n-ar fi vorba de fapt de mosu\', ci de masa lor zilnica. :)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(9319,847,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-12-07 16:57:52','2007-12-07 14:57:52','@ buciuman: ye, man, am vazut si io ca ati pus poza cu mine si tovarasii mei!\r\n\r\n@ colegii: dadada, am gresit, am gresit, dati-mi voie sa-mi feresc cenusa din cap ca sa vad tastele: am gresit, nu ciocolata era expirata, ci gura mea, si da, intr-adevar, pufuletii miroseau a bocanci de armata ruseasca, da\' io ce vina am, ca io am cerut pufuleti cu miros de armata africana, si m-or inselat la magazin? E OK acuma? Rupeti va rog demisia aia pe care m-ati silit sa o semnez pls.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9302,847,'Buciuman','aaa@ggg.com','http://rezistenta.blogspot.com/','86.121.53.95','2007-12-07 11:08:17','2007-12-07 09:08:17','Bai vezi ca poza aia a fost primtre primele posturi pe blogul nostru http://rezistenta.blogspot.com/2007/05/bairam-la-automatica.html',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; InfoPath.2; .NET CLR 2.0.50727)','',0,0),(9697,863,'Andreea MKT','supergirgir@yahoo.com','','89.43.186.64','2007-12-12 20:54:08','2007-12-12 18:54:08','norocoasa mandra daca urmeaza sfaturile tale',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9699,819,'eu,Miruna','mirunavasilescu@yahoo.com','http://potsafacsiasaceva.blogspot.com/','86.106.59.163','2007-12-12 21:08:52','2007-12-12 19:08:52','WhiteWolf, deci noi vom avea locul nostru, mai frumos decat al lor!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9700,863,'.marius','marius@perijoc.com','http://marius.wirelessisfun.com','89.36.21.108','2007-12-12 21:32:39','2007-12-12 19:32:39','Io is curios unde a plecat marko bela... :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9702,863,'vizionarul','alinmiron_19@yahoo.com','http://vizionarul.wordpress.com','89.35.87.15','2007-12-12 21:36:38','2007-12-12 19:36:38','creca l-o linsat pe groparu un sfert de koloszvar de o sters postu cu Markobela... si crede ca daca ne baga pe sub nas poiezia asta cu sÃ¢ni ce se bÄƒlÄƒngÄƒne uitam de marko...',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648)','',0,0),(9704,856,'LeapÈ™Äƒ cu cadouri at Adrian Popa','','http://www.adrianpopa.ro/2007/12/12/leap%c8%99a-cu-cadouri/','212.227.64.193','2007-12-12 21:52:54','2007-12-12 19:52:54','[...] primit de la Groparu, unul dintre bloggeri mei preferaÈ›i, o nouÄƒ leapÈ™Äƒ - cel mai frumos [...]',0,'1','Incutio XML-RPC -- WordPress/2.1.3','pingback',0,0),(9705,863,'Laura','mars1953@web.de','','84.160.121.230','2007-12-12 21:58:41','2007-12-12 19:58:41','Tulai Doamne, ce invidie ma cuprinde ca nu is io prietena (suna asa platonic) aia la care i-ai facut o asa urare (\"nevinovata\")! Dar daca tot o publici sa o iau ca si cand le-ai ura (de fapt le-ai iubi) si la pamantencele de rand?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(9707,863,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','85.186.77.129','2007-12-12 22:50:15','2007-12-12 20:50:15','io sa primesc o asa urare, as inscriptiona-o pe o stanca mare mare si as da cu ea in capul celui ce-a scris-o! :lol:',0,'1','Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.1.11) Gecko/20060601 Firefox/2.0.0.11 (Ubuntu-edgy)','',0,0),(9418,850,'Sergiu BiriÅŸ &raquo; Blog Archive &raquo; De week-end','','http://www.sergiubiris.ro/personal/de-week-end/','204.10.109.185','2007-12-09 18:16:54','2007-12-09 16:16:54','[...]   Am revenit de la TiliÅŸca (Sibiu), invitat fiind de prietenul Andrei CrivÄƒÅ£. Groparu&#8217; missed the event, nevoit fiind sÄƒ Ã®ÅŸi vadÄƒ de calitatea de nuntaÅŸ. De veselit ne-am veselit, evenimente au [...]',0,'1','Incutio XML-RPC -- WordPress/2.3.1','pingback',0,0),(9574,859,'.marius','marius@perijoc.com','http://marius.wirelessisfun.com','89.137.107.129','2007-12-11 14:52:49','2007-12-11 12:52:49','sti ca ai lasat \"cadoul\" de la mine in Le General nu? si era our first official date!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9576,847,'catalin','solo@xsolo.biz','http://xsolo.biz/pics/argentina/mosh-asado/','190.17.92.168','2007-12-11 14:54:34','2007-12-11 12:54:34','Aici sint pozele cu 10,5 kg pe gratar. Si nu am un sarpe in mina ;-)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9577,858,'DÃ£nilÃ£','','','82.77.202.17','2007-12-11 15:02:46','2007-12-11 13:02:46','Io te-am bagat, io te scot :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11;MEGAUPLOAD 1.0','',0,0),(9499,852,'Lumi','luminitadanciu@yahoo.com','','209.221.168.249','2007-12-10 20:18:23','2007-12-10 18:18:23','Si totusi nu ne-ai spus cum a fost la cununie. Ai dat buchetul de flori si un mozol miresii? Sau in timpul ceremoniei stateai pe-o margine si te gandeai la bazaconiile aste -hilarious by the way- sa le pui pe blog. Ce-o fi in mintea ta de gropar numa tu stii...',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; InfoPath.1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(9500,855,'vizionarul','alinmiron_19@yahoo.com','http://vizionarul.wordpress.com','89.35.87.15','2007-12-10 20:18:46','2007-12-10 18:18:46','PLD + PD = PSF - Poti Sa-i Futzi!',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648)','',0,0),(9610,846,'Groparu','groparu_ro@yahoo.com','http://','89.137.109.142','2007-12-11 23:07:17','2007-12-11 21:07:17','FELICITARI MAAAAH!!!\r\n\r\nNu credeam ca mai ceteshti, asa ca nu am apucat sa iti urez bafta, da\' uite - iti urez acum!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,1),(9513,847,'dojo','webmaster@dojodesign.ro','http://dojoblog.info','89.137.246.152','2007-12-10 23:04:40','2007-12-10 21:04:40','Zau ca nu ma pot abtine .. inteleg ca au de purtat ocheti, dar din ce secol sfinte Sisoe is aia .. Jesus ce ochelari \"retro\" :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9519,856,'Lumi','luminitadanciu@yahoo.com','','209.221.168.249','2007-12-11 01:01:42','2007-12-10 23:01:42','Gropare, pot confirma si eu. S-or ingrasat studentele de nu-i adevarat, zici ca manca numa slana cu ciocolata tata ziua. Eu, care pusei intre timp pe mine vreo 8 kile bune, ma simteam tot subtire prin cele baruri clujene. Si liceencele jibe, da jibe-jibe. Insa eu le compatimesc sincer, n-o sa stie  niciodata normalele astea ce thill e cand in clasa a 12-a -ca sa iesi peste 40 de kile la cantar- tre sa te prezinti la cabinet cu suruburi in buzunare.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; InfoPath.1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(9435,852,'oana dobre','oana.dobre@gmail.com','','213.164.224.195','2007-12-10 00:58:03','2007-12-09 22:58:03','Super tare textul groparesc, super misto si comentariile de pe marginea gropii! Bine ca m-a ferit Doamne Doamne de spontaneitati din astea!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; SIMBAR={45FD39F1-162D-4995-A8A3-8F4764D6BC01}; InfoPath.1)','',0,0),(9467,852,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','82.77.126.148','2007-12-10 11:33:11','2007-12-10 09:33:11','31. miresuco, vez ca mirele nu vrea sa te rascumpere... si-o gasit alta gagica dupa ce te-am furatara noi! \r\n\r\n32. cica mirele o ajuta pe maica-ta sa-si incheie fermoarul la corset, in baie.\r\n\r\n33. ti-a venit ciclu sau ce esti asa rosie pe rochie? \r\n\r\n:D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9485,855,'Mih_nea','mihnea_xxyahoo.com','','62.217.236.12','2007-12-10 16:07:44','2007-12-10 14:07:44','PLM - plecat la magazin\r\nSTF - sa-ti traiasca familia!\r\nFMM - frate mersi mult!\r\n\r\nsemnat: (fost?) liberal derutat',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(9486,853,'ovidiu666','ovidiulechintan@yahoo.com','http://ovidiu666.wordpress.com','89.137.118.254','2007-12-10 16:11:26','2007-12-10 14:11:26','n-am bani, i-as cumpara pe toti. asa face un macel! da\' nu cred ca as putea astepta pana la Craciun!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9580,858,'vizionarul','alinmiron_19@yahoo.com','http://vizionarul.wordpress.com','89.35.87.15','2007-12-11 16:08:27','2007-12-11 14:08:27','un alt serial number gropare... si-ai scapat.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648)','',0,0),(9570,460,'rwe','ravedmg@yahoo.com','','89.21.124.2','2007-12-11 13:48:56','2007-12-11 11:48:56','bre\' man! ideea e ca amandoi sunt tiliscani de orijine, iar in Tili e la moda sa faci U ce are si vecinu-vezi casele din tili...oameni mandri, care in loc de caruta in sura aveau Frontera (amu\' s\'au mai schimbat masinile, nujtiu care mai e la moda acolo) dar harnici, gospodari, de buna credinta, si destul de apigi la manie :)) cam acid articolul, dar na ...\r\n= cat despre benzina aia ieftina ca braga = s\'au dus timpurile alea',0,'1','Opera/9.24 (Windows NT 5.1; U; en)','',0,0),(9429,852,'Andreea MKT','supergirgir@yahoo.com','','89.43.186.64','2007-12-09 22:18:46','2007-12-09 20:18:46','ce sa nu ii spui miresei:\r\n\r\n26. auzi mariana, poti sa ma ajuti sa bag in plasa farfuriile alea pline cu prajituri si cotletele alea de porc? si asa nu le mananca nimeni si e pacat de D-zeu, atata mancare...\r\n\r\n27. mariana, doar stii ca inainte costel era swinger!\r\n\r\n28. a, si dupa aia o fost homosexual, isi dorea copii si mi-o zis ca daca ii dau un ovul, imi da un vitel taiat, 3 gaini de la ma-sa mare si un sac de cartofi.\r\n\r\n29. Geanta aia e imitatie Louis Vuitton, nu-i asa? E, de parca nu-i acelashi lucru, imitatie, original  nu-i nici o diferenta intre ele!\r\n\r\n30. in microfon \"Costele, tata, de ce ti se zicea Pateu in facultate?\"',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9507,846,'Ionut','ion@yahoo.com','','89.34.225.25','2007-12-10 22:01:07','2007-12-10 20:01:07','Las\' ca eu am simtit masina de la a 10-a sedinta. Apropo, maine am examen :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(9492,852,'psaico','blog@psaico.info','http://www.psaico.info','78.96.86.55','2007-12-10 18:15:54','2007-12-10 16:15:54','votez nr. 10 ;)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9469,853,'vizionarul','alinmiron_19@yahoo.com','http://vizionarul.wordpress.com','82.208.146.10','2007-12-10 11:37:53','2007-12-10 09:37:53','ce bou ii ala ce-i vinde... in loc sa-si ia pistol dintr-ala cu curent... sa le dea omoru la toti... io as incepe cu cei din lista.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648)','',0,0),(9515,856,'Andreea MKT','supergirgir@yahoo.com','','89.43.186.64','2007-12-11 00:06:59','2007-12-10 22:06:59','1. sa port marimea 95B la sutien\r\n2. sa fac 2 gemene mici si razacioase pe care sa le numesc dru si dru si sa nu stiu care e una si care e ailalta\r\n3. sa ma angajez femeie de serviciu la Inchisoarea Gherla la Dushuri Baietzi si jobul meu sa fie ala ca ii limpezesc (de clabuci) cu un furtun mare.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9512,846,'dojo','webmaster@dojodesign.ro','http://dojoblog.info','89.137.246.152','2007-12-10 23:02:55','2007-12-10 21:02:55','Hai ca nu e mult .. rezista cu stoicism, da de carnet si da-i naibii de magari. Si eu mi-am luat carnetul recent, dupa 1 luna de distractii ... conteaza plasticu\' ala .. ia-l :)\r\n\r\nBAFTA',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9489,820,'cipoc','cipoc2003@yahoo.com','','193.231.140.75','2007-12-10 17:40:51','2007-12-10 15:40:51','stiti care e faza?dc sa pierd eu 10 min la buda aks cand pot sa pierd 10 min din timpul de program!asa se gandeste romaneste:P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9466,853,'July','jullya24@yahoo.com','','83.103.179.55','2007-12-10 10:43:04','2007-12-10 08:43:04','buey....astia sunt toti porci de slana\'....ce de unsoare iese de la ei, s-o zis cu gluma!',0,'1','Opera/9.10 (Windows NT 5.1; U; en)','',0,0),(9482,855,'Blu3','mide765@yahoo.com','','86.106.50.83','2007-12-10 15:44:42','2007-12-10 13:44:42','de acord :)) cea mai tare ecuatie pe ziua de azi :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9473,853,'manole','redtailanda@yahoo.com','http://www.mesterulmanole.wordpress.com','81.181.92.157','2007-12-10 13:08:13','2007-12-10 11:08:13','La aÅŸe ofertÄƒ, cine draq poa sÄƒ alegÄƒ?\r\nIo zÃ®c, ca sÄƒ nu fie cu supÄƒrarie, cÃ¢te doi din fiecare!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows 98)','',0,0),(9474,855,'Andrei Crivat','andrei@andreicrivat.ro','http://www.andreicrivat.ro','89.137.83.141','2007-12-10 13:11:15','2007-12-10 11:11:15','io È›-am zÃ®s: PLM - plecat la magazin. Hai STF',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9475,855,'baghy','baghy83@lycos.it','http://baghy.info/','78.12.6.155','2007-12-10 13:17:08','2007-12-10 11:17:08','asta da ecuatie :))))))))))))))))))))))))',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(9476,855,'July','jullya24@yahoo.com','','83.103.179.55','2007-12-10 13:22:19','2007-12-10 11:22:19','....ce relatie minunata se intrevede:))...exista si vreo\' necunoscuta in ea?',0,'1','Opera/9.10 (Windows NT 5.1; U; en)','',0,0),(9456,852,'mirra','','','83.103.137.234','2007-12-10 07:28:25','2007-12-10 05:28:25','Gropare,esti dus rau cu capu\'....Da care din alea 10 le-ai zis tu la cununia la care ai fost? Ca nu pot sa cred ca n-ai facut chiar nici o gafa.:))))))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9463,853,'macabroo','raduccc@yahoo.com','http://rezistenta.blogspot.com','80.96.196.2','2007-12-10 10:24:02','2007-12-10 08:24:02','Da porcii stiu? Nu e gen, trafic de carne? Vie?',0,'1','Opera/9.23 (Windows NT 5.1; U; en)','',0,0),(9464,853,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-12-10 10:29:46','2007-12-10 08:29:46','Nu, man, ii trafic de carne viÅ£Äƒ-de-vie.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9470,853,'eu,Miruna','mirunavasilescu@yahoo.com','http://potsafacsiasaceva.blogspot.com/','86.106.59.163','2007-12-10 12:08:27','2007-12-10 10:08:27','Deci eu nu-nteleg...cum? Te duci la om acasa, buna ziua, am venit sa cumpar un porc, da va rog, ii dai banii, urci porcul in Dacie si te duci acasa cu el? Si daca nu ai Dacie, il iei cu autobuzul? Si ii faci bilet? Se duce naibii lumea asta.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9471,853,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-12-10 12:19:08','2007-12-10 10:19:08','Nu, mai tu Miruna, mergi la Parlament sau la Notarii Pudici, si le zici: Buna ziua, io vreu sa cumpar 4 dintre voi, va ofer 5 lei si o guma Orbit... ii iei si dupa ce iti dai seama ca au pesta porcina ii trimeti la ecsport.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9572,859,'curioasa','totmea@yahoo.com','','89.123.93.213','2007-12-11 14:20:17','2007-12-11 12:20:17','dar la ce-ti trebuia? ai de toatele. sa vezi ca acuma strici tot... hapsinule!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(9460,852,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-12-10 09:07:14','2007-12-10 07:07:14','@ mirra: la cununia asta am zis altele, de alta sorginte, gen: \"care-i mireasa si care-i mÄƒ-sa? ca io nu-mi dau seama!\"',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9557,856,'Mih_nea','mihnea_xxyahoo.com','','62.217.236.12','2007-12-11 12:12:04','2007-12-11 10:12:04','cu actiunile albalact se pare ca se rezolva, cu celelalte mai greu :)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(9563,859,'nana','razornana@yahoo.com','','86.34.163.6','2007-12-11 12:54:55','2007-12-11 10:54:55','masea de minte? :p',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9564,859,'July','jullya24@yahoo.com','','83.103.179.55','2007-12-11 13:02:11','2007-12-11 11:02:11','...acum ai facut mah?...ai dat spaga sau ceva?...ca la mine nu a fost asa de promt...',0,'1','Opera/9.10 (Windows NT 5.1; U; en)','',0,0),(9600,819,'porculeanu','oitza@yahoo.com','','24.19.31.87','2007-12-11 20:53:26','2007-12-11 18:53:26','evident :)\r\nprintre ce tipe naspa \"va invartiti\" :)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727)','',0,0),(9566,856,'irina','irinamimoza@yahoo.com','','86.121.22.98','2007-12-11 13:13:00','2007-12-11 11:13:00','he heee e bine daca celelalte studente s-au ingrasat, ca io tocma am pierdut vreo 2 kile si poate poate se fac toate grase si-mi raman mie toti masculii sexi si fara par pe piept  sa-mi aleg io pe care vreau si cat de des vreau.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9567,817,'.marius','marius@perijoc.com','http://marius.wirelessisfun.com','89.137.107.129','2007-12-11 13:27:08','2007-12-11 11:27:08','Nah ca m-a bazait jegu sa il votez pe el, da io te-am votat pi tini mah...  abia astpt sa am un pic de timp sa pun poz(n)ele alea pe niet ;-)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9568,859,'manole','redtailanda@yahoo.com','http://www.mesterulmanole.wordpress.com','81.181.92.157','2007-12-11 13:28:46','2007-12-11 11:28:46','nu-ti fie cu suparare, da cu care cap ai strigat?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows 98)','',0,0),(9597,853,'Bibliotecaru','um0834@yahoo.com','http://giconet.blogspot.com/','86.121.2.220','2007-12-11 20:27:02','2007-12-11 18:27:02','Ä‚ÅŸtia de pe listÄƒ sunt deja vÃ¢nduÅ£i, poate Ã®i cumpÄƒrÄƒ...',0,'1','Mozilla/5.0 (Windows; U; Win 9x 4.90; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9561,859,'mirra','','','83.103.137.234','2007-12-11 12:39:14','2007-12-11 10:39:14','O constatare,intelijenta,marca groparele,dar nu functiona decat un neuron,nu?:)))...Sau nu era unde trebe...',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(10111,895,'Mih_nea','mihnea_xxyahoo.com','','62.217.236.12','2007-12-18 08:38:47','2007-12-18 06:38:47','cred ca sunt(em?) mai multi, nu te promovezi tu cum trebuie :)\r\neu de exemplu am aflat de groparu.ro  acum nici 2 sapt., de la o forumista de pe agf.ro\r\nda\' stii cum e bulgarele de zapada, odata ce incepe sa prinda viteza creste mai repede',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(9799,888,'Laura','mars1953@web.de','','84.160.89.119','2007-12-14 20:26:46','2007-12-14 18:26:46','Ai luat masa cu turci? Tradatorule!!! \r\nPentru ultima parte ai totusi circumstantze atenuante.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(9801,888,'WhiteWolf','contact@white-wolf.ro','http://white-wolf.ro','89.32.115.122','2007-12-14 21:02:35','2007-12-14 19:02:35','Si aia de la  \"cooperativa\" cam stiu ce soi de \"traduceri\" spontane si glorioase faci tu ? :)\r\nSau, la ora aia, nu prestai ca sa-ti castigi petecele lunare pentru gaurile de la banci ?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9807,889,'LumiD','luminitadanciu@yahoo.com','','209.221.168.249','2007-12-15 01:44:25','2007-12-14 23:44:25','nu incerca niciodata, never ever, sa le intelegi pe femei. Io, unu, renunt public - mai degraba ma apuc de fizica nucleara si de matematici cuantice.\r\n\r\n\r\nMda, fizica nucleara cica ar fi logica, nimeni nu spune ca tre sa-ti folosesti inteligenta logico-matematica sa intelegi inefabilul amazonean. Incearca intelighentia emotionala si daca nu tine-  pe aia materiala, pentru ca se stie: diamods are a girl\'s best friend. \r\nPS... De asemenea, sta scris undeva prin ceva manual de folosire a muierii ca porcii sovinisti nu sunt setati corespunzator sa inteleaga femeia.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; InfoPath.1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(9810,889,'innuennda','innuenda.innuenda@gmail.ro','http://360.yahoo.com/innuennda','92.80.42.157','2007-12-15 03:41:51','2007-12-15 01:41:51','Incep cu sfarsitul, c\'asha ce-mi place sa teermin!! ...\r\nLa faza cu femeile, LumiD zice ca barbatu\' sa-shi foloseasca inteligenta emotionala, nu pe a\' matematica. Io zic sa nu-si foloseasca inteligenta deloc. Sa-si foloseasca mainile, gura si ce-o mai da Dumnezeu...\r\nSi ce femeie e aia de pretinde barbatului sa o inteleaga?! Eu nu pretind decat sa nu ma contrazica. In rest, poa\' sa faca pe prostu\'...ce treaba am eu?!\r\nLa faza cu poeziile m-ai lovit! Se aplica si la versuri albe? Care-va-sa-zica de asta ma emotionez cand citesc facturi...bloguri...oameni.\r\nSa te lasi de fumat stie toata lumea ca-i simplu. Atata numa\' ca si mai simplu e sa te apuci la loc, dupa ce te-ai lasat.\r\nParintii se intorc impotriva ta numa\' cand tu dai ca berbecu\' sa te arunci in gol. Daca si-ar cere scuze ar insemna ca s-au prins in sfarsit ce au la usa. Dar deh, parintii, stii...tot parinti!\r\nDaca prinzi oleaca la impartit cascaval s-o fi dubland numarul de prieteni.Da\' pe tine nu te afecteaza mai mult ca se tripleaza numaru\' dusmanilor?\r\nDaca vreun sef care nu te-nghite din pura neatractie fizica te fute cu Turnul Eiffel, da-i si tu muje cu hidrantul si o sa fiti cumva chit! Parerea mea!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10087,895,'zone-ro','zone-ro@google.com','http://zone-ro.blogspot.com/','89.33.174.237','2007-12-18 03:36:28','2007-12-18 01:36:28','Relax man, ca oricum o duci mai bine decat multi blogeri\r\nhttp://zone-ro.blogspot.com/',0,'1','Opera/9.23 (Windows NT 5.2; U; en)','',0,0),(10102,895,'manole','redtailanda@yahoo.com','http://www.mesterulmanole.wordpress.com','89.32.123.108','2007-12-18 07:05:15','2007-12-18 05:05:15','daca is inteligenti, atunce n-ai socotit bine. trebuie imultiti cu 2. asa se face ca ai 1200. si ca sa nu mai spun ca, s-ar putea, nu spun sigur si nici cine,un inteligent apare o data da\' cetesc cate doi. :)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(9671,860,'sabina','','','81.12.163.178','2007-12-12 14:00:17','2007-12-12 12:00:17','=)) clean dilau ce esti.... =))',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648)','',0,0),(9674,860,'.marius','marius@perijoc.com','http://marius.wirelessisfun.com','89.36.21.108','2007-12-12 14:52:09','2007-12-12 12:52:09','deci io vreau badge din ala cu \"Io il citesc pe Groparu zalnic!\" \r\n\r\nauzi la el... sa ii aduca black snapper! tz tz tz ;-)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9667,819,'WhiteWolf','contact@white-wolf.ro','http://white-wolf.ro','89.39.81.148','2007-12-12 13:39:24','2007-12-12 11:39:24','Vretz\' dijaba.\r\nPana nu saritzi cu beroaicele la Gropar, ca sa aflati si minunata locatie secreta, indiferent de forma voastra de organizare si alte shit-uri din alea de tip \"gurlz power\" tot niika nu va iasa.\r\nPen\' ca, far\' de eviroment, farmecul va lipsi atat de mult ca nici un pui de kitsch nu va iasa',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9669,819,'Mih_nea','mihnea_xxyahoo.com','','62.217.236.12','2007-12-12 13:50:53','2007-12-12 11:50:53','cam slabutz cu rugby-ul...\r\nda\' grohaitorul arata bineee',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(9666,860,'WhiteWolf','contact@white-wolf.ro','http://white-wolf.ro','89.39.81.148','2007-12-12 13:36:13','2007-12-12 11:36:13','Lumea stie si ma stie, mi-s fan declarat (cu eticheta si tot ce trÃ£bÃ£) Groparu.\r\nDa\', macar intr-o propozite a frumosului articol de azi , cred, ai exagerat.\r\nZau, cine naiba sta dupa <b>\"clitoris de elefÄƒnÅ£icÄƒ indianÄƒ culeÅŸi la muson\"</b> ? \r\nCum, bre, sa culeji din alea cand traje musonu \' ? :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9660,860,'vizionarul','alinmiron_19@yahoo.com','http://vizionarul.wordpress.com','82.208.146.10','2007-12-12 12:08:44','2007-12-12 10:08:44','umbra lu hitler... lol',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648)','',0,0),(9664,819,'Andreea MKT','supergirgir@yahoo.com','http://marlahermina.deviantart.com/gallery/','82.77.126.254','2007-12-12 12:55:23','2007-12-12 10:55:23','mirra\r\nsi eu sunt femeie serioasa, dar asta nu inseamna ca nu stiu sa dau in ghioc si sa fac chestia aia cu datul din sani. Plus stiu melodii tiganesti si de mahala, am nasu acvilin, sunt bruneta, am cercei kitchoshi primiti de la rude neam prost care mi-o zas ca-s de aur, si la nevoie ma pot tzigani.\r\ndeci vreau!!',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; InfoPath.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(9725,868,'Mih_nea','mihnea_xxyahoo.com','','62.217.236.12','2007-12-13 08:48:13','2007-12-13 06:48:13','recunosc ca am facut-o odata cand juca Steaua (pe vremea aia inca mai castiga) si am zis un URAAAA!!!! puternic cand am auzit ca a dat gol. Ea intai a crezut ca terminasem, si cand a aflat adevarul s-a cam ofticat :)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(9726,863,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-12-13 09:28:51','2007-12-13 07:28:51','Deci Marko Bela urmeaza sa fie reciclat.\r\n\r\n@ Lupulainu: Stiam io ca ej cu minie! \r\n\r\n@ Laura: stii vorba aia, dati-mi o pereche de sÃ¢ni ficÅŸi, ÅŸi am sÄƒ rÄƒstorn universul!\r\n\r\n@ lilith: tulai, Doamne, da\' nu te-ai prins ca aiesta nu-i sait de puritani??? Sait obscen, cinste cui te-a scris!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9728,863,'mirra','','','83.103.137.234','2007-12-13 10:07:10','2007-12-13 08:07:10','cand ai de gand sa le publici aieste versuri,tine-mi si mie un volum cu autograf...:))))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9729,868,'mirra','','','83.103.137.234','2007-12-13 10:11:40','2007-12-13 08:11:40','De unde dracu le tot scoti? Citesc si ma minunez in fiecare zi ca multe iti mai debiteaza capatana aia...Da imi place si ma distrez de mor!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9731,868,'Bernadette','briqo_o@yahoo.com','','82.77.126.254','2007-12-13 11:06:57','2007-12-13 09:06:57','deci...pe wish listu de X-mas in firma in care lucreaza Groparu apare:\r\n\r\n\"-X-ulescu: Sa fac sex cel putin o data pe saptamana! Cu femei diferite!!!!!!!!!!\r\n-Groparu: Sa nu fiu femeia cu care X-ulescu vrea sa faca sex :|\"',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; FDM; .NET CLR 1.1.4322; .NET CLR 3.0.04506.648; .NET CLR 3.5.21022)','',0,0),(9732,868,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-12-13 11:12:51','2007-12-13 09:12:51','Da, deci eu am fost cel care a completat \"Cu femei diferite!!!!!!!!!!\" din Christmas wishul lui x-ulescu, cu un mic amendament: x-ulescu ii kiar shafu\' meu. Practic cerseam sa nu ma mai f*** nici la crieri, nici alminteri.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9689,863,'andreanum','andreanum@yahoo.com','http://andreanum.wordpress.com','80.97.190.199','2007-12-12 19:17:54','2007-12-12 17:17:54','pervert ej ma',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(9690,863,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2007-12-12 19:42:40','2007-12-12 17:42:40','Sh asta e de bine sau de rau?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9691,863,'WhiteWolf','contact@white-wolf.ro','http://white-wolf.ro','89.39.83.170','2007-12-12 19:42:41','2007-12-12 17:42:41','ai inceput sa ne oferi , putin cate putin, episoade din <b>Groparufornication</b> :) \r\nMie-mi place. Aia de se simt jenati sa-si reaminteasca ca-i postul Craciunului si sa-si rearanjeze icoanele si candelele cand mai apar postari din astea :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9658,860,'mirra','','','83.103.137.234','2007-12-12 11:31:05','2007-12-12 09:31:05','nota 10 pa cuvantu\' meu de black snapper!:)))))',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(9650,860,'manole','redtailanda@yahoo.com','http://www.mesterulmanole.wordpress.com','81.181.92.157','2007-12-12 10:41:21','2007-12-12 08:41:21','de nota 200...10.:)))))',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows 98)','',0,0),(9652,860,'mo','verde_poveste@yahoo.com','','194.126.220.20','2007-12-12 10:58:13','2007-12-12 08:58:13','Muahahahahahahahaha! Meri-n crizmas e cea mai tare injuratura de sezov ever!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1)','',0,0),(9653,860,'mo','verde_poveste@yahoo.com','','194.126.220.20','2007-12-12 10:58:43','2007-12-12 08:58:43','Hmmm,  chiar si de sezon. Heh....',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1)','',0,0),(9654,860,'','','','85.186.76.213','2007-12-12 11:04:29','2007-12-12 09:04:29','no, da\' se mai risipeÅŸte bunÄƒtate  de streng prusac  ÅŸi pe cÃ®te-o chinezÄƒrie de original yankee :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9655,860,'mirmen','mirmen@bursi@yahoo.com','','85.186.76.213','2007-12-12 11:08:05','2007-12-12 09:08:05','...n-am vrut s-o dau anonimÄƒ, da\' alÅ£ii au amabilitatea sÄƒ atenÅ£ioneze uitucii ÅŸi   neatenÅ£ii, tu ai vraiÅŸte uÅŸile :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9656,860,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-12-12 11:13:03','2007-12-12 09:13:03','...si io care credeam ca \'coperiÅŸu Ã®i problema!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9657,819,'mirra','','','83.103.137.234','2007-12-12 11:24:22','2007-12-12 09:24:22','andreea draga,gajica lu\' groparele e muiere serioasa,nu face ea prostii d\'aiestea,dar cu tiganiada feminina sa hie,soro,sa hie!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(9641,859,'ovidiu666','ovidiulechintan@yahoo.com','http://ovidiu666.wordpress.com','89.137.118.254','2007-12-12 08:37:58','2007-12-12 06:37:58','minte? ce-i aia?... \r\noare becali o strigat \"doamne, da-mi bani!\" si i-o dat?... oare la mine merge? da\' ce sa aleg - minte, bani, femei?... hmmm... \r\nnu mai bine strig \"doamne, da-mi pace!\"?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9648,819,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-12-12 10:35:48','2007-12-12 08:35:48','Deci ba sweeper, la Tiganiada nu se vinde indulgentze, ca la Vatican :) si daca ma blastemi, numa bine faci, ca minusurile de la alte blesteme cu minusu\' de la blestemu\' tau = egal dÄƒ plus!\r\n\r\nAduceti o bere-ncoa la Groparu.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9738,868,'WhiteWolf','contact@white-wolf.ro','http://white-wolf.ro','89.39.82.7','2007-12-13 14:47:27','2007-12-13 12:47:27','V-am zÃ s ? V-am ! :)\r\n<b>Groparufornication</b> :P\r\nSa vedetz\' dupa Anu Nou, cand cu \"la multi ani, Ioane, la multi ani Vasile\", \"dicstractie\" .\r\nPrecis o sa fie mai multe episoade odat\'',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9753,868,'Laura','mars1953@web.de','','84.160.118.88','2007-12-13 20:40:30','2007-12-13 18:40:30','In timp ce la el e \"dupa sex\" e la ea \"in timp ce\": - dragul nu, e vina mea ca tu cu mult prea laudata ta p... nu poti avea decat un singur orgasm. Eu, cu modestul meu clitoris, sunt doar la al doilea asa ca te rog aduna-te \"the show must go on...\"',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(9754,868,'','','','84.160.118.88','2007-12-13 21:51:13','2007-12-13 19:51:13','barbatu-meu, la care in mod exceptzional ii dau dreptate, o zis: penibilitatzile de la inceput se transforma in dulcetzuri pe parcursul anilor, de ambele partzi...\r\nPS: virgula vine dupa dragule, nu dupa nu. e important.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(9755,868,'Laura','mars1953@web.de','','84.160.118.88','2007-12-13 21:52:20','2007-12-13 19:52:20','anonymos=laura, pardon',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(9865,890,'mirra','','','83.103.137.234','2007-12-15 19:40:28','2007-12-15 17:40:28','acuma sigur ai parola:pulamea:)))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9849,888,'Mihai Ursu','agentimperialist@yahoo.com','http://mihaiursu.wordpress.com','83.166.206.107','2007-12-15 15:45:16','2007-12-15 13:45:16','ai dracului osmanlÃ®i, acuma vor sÄƒ se rÄƒzbune ÅŸi au venit deghizaÅ£i Ã®n oameni cinstiÅ£i, sÄƒ ne Ã®ntoarcÄƒ Å£epele cu care i-a tratat proctologul de la TÃ®rgoviÅŸte de Ã®i usturÄƒ ÅŸi acum... pÄƒrerea mea e sÄƒ ÅŸi le bage la loc Ã®n Kurdistan...',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(9862,890,'baghy','baghy83@lycos.it','http://baghy.info/','78.12.17.109','2007-12-15 18:52:09','2007-12-15 16:52:09',':))))',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(9863,890,'Laura','mars1953@web.de','','84.160.84.239','2007-12-15 18:57:22','2007-12-15 16:57:22','Mishto. Asa-mi placi de numa\'!',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(9843,889,'vizionarul','alinmiron_19@yahoo.com','http://vizionarul.wordpress.com','89.35.87.15','2007-12-15 14:49:40','2007-12-15 12:49:40','ma gropare... innuennda are dreptate la faza cu femeile... Daca nu ma crezi, imi fac poza la limba sa-ti arat ce lunga si fortzoasa mi s-o facut... iar la lasatu de fumat... pai tot o fomeie te poate ajuta... bagati secs pana iti iasa tie tigarile din cap... sa vezi ce fain ii cand esti drogat de la secs...:D:D:D... ioi ce vremuri...',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648)','',0,0),(9830,868,'Lexis','g_lexis2005@yahoo.com','http://www.alexandraghitalexis.blogspot.com','89.38.76.46','2007-12-15 09:45:31','2007-12-15 07:45:31','poza e jeniala, aduce cu o .... gaina :d',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10116,895,'PhenoBarbieDoll','poisongirl94@yahoo.com','http://blog.360.yahoo.com/poisongirl94','193.230.230.101','2007-12-18 09:27:47','2007-12-18 07:27:47','Domnu\' Groparu, sa stitzi ca io va cetesc de pe doo IPuri diferite! deci fac si io ce pot, sh va rog sa apreciatzi.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10117,895,'danutz','danutz-ape@yahoo.com','','79.112.2.110','2007-12-18 09:28:58','2007-12-18 07:28:58','stai relax. eu zic ca e bine. da cei mai putini cati ai avut?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10532,911,'Arhi','admin@arhiblog.com','http://www.arhiblog.com','82.77.85.193','2007-12-21 09:04:42','2007-12-21 07:04:42','abureli. noi si in trecut ne  intreceam in sfanta lupta a berilor',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.9b2) Gecko/2007121120 Firefox/3.0b2','',0,0),(10538,911,'vizionarul','alinmiron_19@yahoo.com','http://vizionarul.wordpress.com','82.208.146.10','2007-12-21 10:25:13','2007-12-21 08:25:13','ma ierectia aia ce apare dimineata, si de nu stiu cate ori seara, ii din cauza ca organul respectiv trebe hranit, si instalatia probata. Qestia asta o stiu de la un nenea doctoru.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648)','',0,0),(10543,911,'adi','adyrotaru@yahoo.com','','89.120.56.7','2007-12-21 11:18:26','2007-12-21 09:18:26','vizionarule, inteleg.\r\n\r\nii ca cum ai curata caloriferele in perioada 1-20 octombrie, sa fie pregatite cand vine fluxul de caldura, sau in speranta ca a veni el si fluxul cela.\r\ninstalatia tre probata si daca are oaresce scurgeri sau niscai bolfe tre mers fuga la doftor (sau pisolog), sa fie in regula cand a veni, daca a veni fluxul.\r\n\r\ningenioasa mama natura, cand te gandesti ca noi, omenashii, credem ca noi le inventam pe toate...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.7.8) Gecko/20050511 Firefox/1.0.4','',0,0),(10544,911,'adi','adyrotaru@yahoo.com','','89.120.56.7','2007-12-21 11:20:15','2007-12-21 09:20:15','am uitat sa mai zic ca eu nu cred in cacofonii si ca nota zece cu stelutze de craciun pentru blog.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.7.8) Gecko/20050511 Firefox/1.0.4','',0,0),(10545,914,'Anti','fa@email.ro','http://www.gheorgheni.net','89.137.17.33','2007-12-21 11:22:21','2007-12-21 09:22:21','Mai nene, daca nu stiai, cele mai multe motoare de cautare te \"avanseaza\" printre rezultatele date, daca site-ul tau este gasit in alte site-uri de acelasi gen - cazu\' de fata bloguri, parca crosslinking ii zice.\r\n\r\nNa, asa macar imi fack si io reklama...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10548,914,'Doro','kettlerdorothea@yahoo.com','http://www.kettlerdorothea.ro','89.122.253.17','2007-12-21 12:16:49','2007-12-21 10:16:49','Åži eu am cÃ¢Å£iva care fac asta: la sfÃ¢rÅŸtiul fiecÄƒrei postÄƒri \"IntrÄƒ pe blogul cutÄƒricÄƒ..\" primele dÄƒÅ£i am ÅŸters alea ÅŸi gata, sperÃ¢nd cÄƒ se va corecta. CÃ¢nd am vÄƒzut cÄƒ insistÄƒ l-am bÄƒgat la spam... Cum zicea ÅŸi Andrei Crivat... nu-nÅ£eleg de ce promovezi un spammer',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10552,914,'Liviuuuu','liviuuuu2002@yahoo.com','','85.204.137.250','2007-12-21 12:46:17','2007-12-21 10:46:17','Vorba aia: \"numele prostilor pe toate gardurile\"',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10555,912,'moro','victorneicu@gmail.com','http://resese.blogspot.com','141.85.252.73','2007-12-21 13:07:35','2007-12-21 11:07:35','heeh, si uite asa se vede cum Groparele a fost putin mai mult emotionat cand  a scris asta.\r\npai \"Ne scoalÄƒ mama pe mine ÅŸi sora, pune un Å£ol pe noi, ÅŸi Å£uÅŸti Ã®n pivniÅ£Äƒ, unde deja stÄƒtea tot blocul\"...\r\n\"care bineinteles sunt niste doamne\"???',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10556,911,'innuennda','innuenda.innuenda@gmail.ro','http://360.yahoo.com/innuennda','92.80.17.220','2007-12-21 13:29:09','2007-12-21 11:29:09','ba sa crezi, daca dau valoare semantica textului ! :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10558,912,'innuennda','innuenda.innuenda@gmail.ro','http://360.yahoo.com/innuennda','92.80.17.220','2007-12-21 13:53:01','2007-12-21 11:53:01','RÃ¢su\'-plÃ¢nsu\'. DacÄƒ nu o spunea Nichita Ã®nainte, o spuneam eu acum.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10560,912,'justlikethat','ngabyn@gmail.com','http://justlikenow.blogspot.com','193.37.136.254','2007-12-21 14:10:31','2007-12-21 12:10:31','hmm ... la mine a fost mai altfel, fiind din Focsani, nu s-a dat asa mare scandal, eram toti in priza ce-i drept dar ... am stat cat de cat calmi ...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10562,912,'WhiteWolf','contact@white-wolf.ro','http://h','89.32.115.216','2007-12-21 14:24:42','2007-12-21 12:24:42','Groparu ori e beat ori intr-o scurta perioada de pierdere a uzului ratiunii.\r\nCitindu-va comentariile nu pot decat sa ma felicit ca eu nu le permit\r\n Daca vi s-ar fi strans curul la fel ca celor din Sibiu pana tarziu, in jurul zilei de 29 Decembrie ori de cate ori auzeati focuri de pistol mitraliera si de TAB, la ora asta va abtineati de la comentarii .... umoristice.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10122,895,'Arhi','admin@arhiblog.com','http://www.arhiblog.com','82.77.85.247','2007-12-18 10:04:41','2007-12-18 08:04:41','domnu groparele, multi dintre noi face cat 10....',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; ro; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10123,895,'vizionarul','alinmiron_19@yahoo.com','http://vizionarul.wordpress.com','82.208.146.10','2007-12-18 10:21:58','2007-12-18 08:21:58','nenea groparu, io va cetesc de pe trei IPee diferite: de acasa, de la scarbiciu si de pe la shefu din birou... ashe ca, io incerc s-ajut. :P',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648)','',0,0),(10124,900,'vizionarul','alinmiron_19@yahoo.com','http://vizionarul.wordpress.com','82.208.146.10','2007-12-18 10:26:17','2007-12-18 08:26:17','mai vacile ie sfinte la indieni si la unii romani pentru ca ne da lapte. Ele-s un fel de gaini de ferma d-alea refuzate. Bine le-ati facut! Eu prefer sa zic apasat \"Multumesc\"  indiferent ca saluta sau nu. Oricum la cursurile lor de vanzatori, bunu simt creca era facultatitv sau l-au facut ei cu femeea de serviciu care nici ea nu dadea pe la scoala prea des..',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648)','',0,0),(9683,860,'Usim','mihaimitan@gmail.com','','87.237.108.33','2007-12-12 17:45:56','2007-12-12 15:45:56','Nu esti intreg la mintile dumitale! Parol deoneur!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; .NET CLR 2.0.50727)','',0,0),(9682,819,'Felix','felix.felix@gmail.com','','213.233.122.144','2007-12-12 16:52:46','2007-12-12 14:52:46','transcedental, in pula mea...',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(9644,860,'The Original Yankee','crisan_emil@yahoo.com','','89.43.186.64','2007-12-12 10:08:08','2007-12-12 08:08:08','Gropare, e asta cumva primul tau blog rasist?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9647,860,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-12-12 10:31:14','2007-12-12 08:31:14','Nu, mah! Finca de la sibian la arian nu prea exista diferentza de rasa.\r\n\r\nAaa, daca e primu meu post xenofob? Hmmm... posibil, da\' io am ce am cu cumnatu-meu numa\' finca mi-o dus-o pe sorella la mama dreq, in Vaterlandu\' lor. Atata tat :D Norocu lui ca mi-o tras doi nepoti frumosi si destepti, si amu io i-s dator lui :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9646,819,'sweeper','ak70g2@gmail.com','','89.122.203.71','2007-12-12 10:26:58','2007-12-12 08:26:58','nene gropare... blestemat sa fii in veci ca nu iei si alta lume acolo...',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1)','',0,0),(9781,860,'prodan','mihai.prodan@gmail.com','http://prodan.wordpress.com','82.77.126.171','2007-12-14 11:16:53','2007-12-14 09:16:53','groparulee, deci eÅŸti Äƒl mai copac de pÄƒ faÅ£a cluujului!!\r\nHAHAHAHAHAAAHAHAHAHAHAHAHAAAAAHAAAA\r\nÅŸi eu vreau badge!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9782,888,'pliscu','pliscu@gmail.com','http://pliscu.blogspot.com','89.137.100.118','2007-12-14 11:24:07','2007-12-14 09:24:07','@andreea: si... le-o facut el? :-/',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9783,888,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','82.77.126.148','2007-12-14 11:32:17','2007-12-14 09:32:17','si ce cauta turcaletii in cluj?? vor sa ne rapeasca?? sa ne duca in turcia?? eh??',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9784,888,'vizionarul','alinmiron_19@yahoo.com','http://vizionarul.wordpress.com','82.208.146.10','2007-12-14 11:34:56','2007-12-14 09:34:56','@lilith... vor doar fomei cat mai multe c-am auzit ca turcaletii sunt pasionati de terenuri de golf.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648)','',0,0),(9844,889,'N-are cum!','agentimperialist@yahoo.com','http://mihaiursu.wordpress.com','83.166.206.107','2007-12-15 15:04:09','2007-12-15 13:04:09','Frate, nu mai incerca sa le intelegi pe muieri! Cum zice si un cintecel din tabara de la Navodari 1983, \"Femeile e niste bulangii!\"',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(9846,889,'Laura','mars1953@web.de','','84.160.84.239','2007-12-15 15:29:01','2007-12-15 13:29:01','Gropare, tu esti un tip inteligent.\r\nNu ma dezamagi cu mediocritatzi din astea, ce naiba!',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(9847,889,'innuennda','innuenda.innuenda@gmail.ro','http://360.yahoo.com/innuennda','92.81.20.100','2007-12-15 15:37:08','2007-12-15 13:37:08','Vizionarule, e clar...esti un om cu o viziune. \r\nLa faza cu limba ta cea lunga si fortzoasa ai vrut, desigur, sa ne spui ca esti limbut, nu? :) Ca altfel nu fortzoasa sau lunga ne intereseaza sa fie. Ci...cum s-o spun pe asta...mai mieroasa, ashea :))\r\nAh si imi place ca ai retinut ca femeilor nu le place sa fie contrazise si te-ai conformat!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10000,893,'mirra','','','83.103.137.234','2007-12-17 07:50:43','2007-12-17 05:50:43','Ca sa poti durmi linijtit,io iti zic ca si mie imi tot trimit mesaje spam cu viagra, extazis,cu pule mari si mici si cu exercitii Kegel pt muschii vaginali, da\' io asa cum a zis manole dau delete,nu ma mai obosesc sa citesc asemanea chestii.\r\n@vizionarul:sanii nu se maresc asa ci prin masajele pe care le fac barbatii si prin mangaieri, amu ii drept ca nu tota lumea stie,dar asta e,...iar punctu\' j la barbati se afla in creier,se stimuleaza cu alcohol nu au nevoie de femei pt asta...Deci,nu femeile au o problema,ci barbatii aia care nu STIE ANUMITE LUCRURI!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10001,864,'ics','i_uana@yahoo.com','','86.126.112.82','2007-12-17 08:21:01','2007-12-17 06:21:01','\"grande burtihan navidad \"? n-are nici o noima, Gropare  /:)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10003,894,'mirra','','','83.103.137.234','2007-12-17 08:25:59','2007-12-17 06:25:59','vezi ca atunci cand nu esti singur in pat,sa nu te simti ca Mos Craciun si sa vrei sa imparti bunatati la mai multa lume deodata....:))))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10005,864,'mirra','','','83.103.137.234','2007-12-17 08:34:59','2007-12-17 06:34:59','Sarada sta in mana care este in buzunar si reprezinta:\"Fetitelor na-va,DAD!\"\r\nDeci,care e premiul,ca am dezlegat sarada?:)))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9761,868,'Greuceanu!','','','195.149.72.105','2007-12-13 23:19:24','2007-12-13 21:19:24','azi merg sa tai porku!  URRRRRRAAAAAAAA!!!!!!!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(9824,889,'Arhi','admin@arhiblog.com','http://www.arhiblog.com','82.79.189.63','2007-12-15 08:32:28','2007-12-15 06:32:28','gura la pacatoase adevar graieste',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; ro; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10050,864,'vanvancik','vania_md@yahoo.com','','82.77.20.141','2007-12-17 19:30:12','2007-12-17 17:30:12','DAN AVID, recte zgircit, puchinos, etc',0,'1','Mozilla/4.0 (compatible; MSIE 5.5; Windows 98; Win 9x 4.90)','',0,0),(10591,915,'Tavi','nessajab4@yahoo.com','','194.99.245.11','2007-12-21 18:55:07','2007-12-21 16:55:07','Atunci iti doresc sabatori sanatoase si imbelsugate in bere si fomei si la anu sa fie tot asa ( sa ajunji aproape a te satura desi jtiu ca\'i imposibil sa te saturi mai ales de fomei never ever... ).',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10597,915,'Ciupercutza','alabalaportocala1@gmail.com','http://ciupercutza.wordpress.com','194.79.45.97','2007-12-21 20:09:15','2007-12-21 18:09:15','Sarbatori frumoase! La multi ani!\r\nTe asteptam la anu\'!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(10134,813,'Dani','daniel.codrea@yahoo.com','http://www.altecuvinte.wordpress.com','89.137.17.71','2007-12-18 12:37:48','2007-12-18 10:37:48','Io visez la o Rumanie in care chiar de shtiu ungareshte sa nu mi se arunce cu oo-n cap cas bozgor, ca la mine stiu si romaneshte.\r\nIo visez la o tzara un\' sa nu tragi ca magaru pt un salar cat putza de bacterie.\r\nIo visez la o dimineatza in care imi va placea sa zic, ia mah deacilea, cas roman.\r\nIo visez la o Romanie......',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(10136,903,'Razvan Antonescu','razvan.antonescu@gmail.com','http://idei-locale.blogspot.com','81.196.150.96','2007-12-18 12:44:37','2007-12-18 10:44:37','Bre da studiu zice daca tre sa fie in ambalaj sau nu?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10137,903,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-12-18 12:46:06','2007-12-18 10:46:06','Da, zice :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10138,903,'Razvan Antonescu','razvan.antonescu@gmail.com','http://idei-locale.blogspot.com','81.196.150.96','2007-12-18 12:47:40','2007-12-18 10:47:40','CE?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10139,903,'Razvan Antonescu','razvan.antonescu@gmail.com','http://idei-locale.blogspot.com','81.196.150.96','2007-12-18 12:48:57','2007-12-18 10:48:57','Porcule nu zice. Si nici macar nu zice daca sa te uiti la ei (ambalaj sau fara) in realitate sau is bune si surogatele',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10140,903,'Razvan Antonescu','razvan.antonescu@gmail.com','http://idei-locale.blogspot.com','81.196.150.96','2007-12-18 12:49:54','2007-12-18 10:49:54','Si pe de alta parte, privitu\' fara a pune mana o prelungi el viata da\' decat batraneti cu ulcer mai bine pas',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10144,895,'justlikethat','ngabyn@gmail.com','http://justlikenow.blogspot.com','193.37.136.254','2007-12-18 13:16:19','2007-12-18 11:16:19','acuma ... de citit te citim, da tu ne citesti pe noi ? :)) ... egoistule :D !',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10145,903,'zone-ro','zone-ro@google.com','http://zone-ro.blogspot.com/','89.33.174.237','2007-12-18 13:18:12','2007-12-18 11:18:12','http://zone-ro.blogspot.com/\r\n\r\nasa zic si eu , daca ramai numai cu privitul nu cred ca iti prelungesti asa de mult viata :D',0,'1','Opera/9.23 (Windows NT 5.2; U; en)','',0,0),(10078,864,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2007-12-18 01:53:36','2007-12-17 23:53:36','Deci gandul parsiv din mintea Groparelui este Felix Navidad, deci destepti frumosi, cinste cui v-a scris!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10079,895,'justlikethat','ngabyn@gmail.com','http://justlikenow.blogspot.com','92.80.152.136','2007-12-18 02:24:59','2007-12-18 00:24:59','eh :) relax, e bine shi asha :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9768,868,'io, fumeia','','','89.137.120.1','2007-12-14 02:27:35','2007-12-14 00:27:35','inainte:\r\n1.is catolica, nu poci  sa fac sex\r\n2.saruti ca taica-tau\r\n3.iti plac copiii? am 6 acasa.\r\n\r\nin timpu:\r\n1.lenutzzz...aaa groparele  ,nu acolo ca ma gadil\r\n2.is it in yet?\r\n3.wow! io-te la putzuli...aaaa.......poate trebuia sa-ti spun mai devreme, dar ma chema vasile inainte de operatie\r\n4.trezeste-ma cand termini, bine?\r\n5.stai sa apuc un pic cu dintii, ca aluneca\r\n\r\ndupa:\r\n1.a fost ok, dar pe frati-tau l-a tinut mai mult!\r\n2. stai calm, toti o patesc, macar odata\r\n3. cum vrei sa-l botezam p-asta mic?',0,'1','Mozilla/5.0 (Macintosh; U; Intel Mac OS X; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9780,888,'Andreea MKT','supergirgir@yahoo.com','http://marlahermina.deviantart.com/gallery/','82.77.126.254','2007-12-14 10:43:30','2007-12-14 08:43:30','eu vroiam sa le fac un dans din buric dar eram cu gagicu:)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; InfoPath.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(11449,914,'','','','86.121.15.248','2007-12-30 21:04:20','2007-12-30 19:04:20','hmmmm... tu esti cel mai bun exemplu ca scoala nu aduce si minte',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; SLCC1; .NET CLR 2.0.50727; .NET CLR 3.0.04506)','',0,0),(9854,889,'mirra','','','83.103.137.234','2007-12-15 17:31:05','2007-12-15 15:31:05','Femeile nu trebuie intelese,ci iubite,ele inteleg multe dupa aia,cu conditia sa nu fie blonde!!!:)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9855,889,'mirra','','','83.103.137.234','2007-12-15 17:37:04','2007-12-15 15:37:04','A, si in problema cu sefu\'....Rezolvarea e simpla;cauta-i amanta,fa-o sa se indragosteasca de tine si apoi traiesti ca un boier,femeia care iubeste nu-l va lasa pe cel iubit de izbeliste!!!:)))).Femeile au suflet intotdeauna:-P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9856,889,'mirra','','','83.103.137.234','2007-12-15 17:37:59','2007-12-15 15:37:59','Depinde doar de barbat cat de bine stie sa-l mangaie:-P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9870,890,'Denisa Lala','denisalala@gmail.com','http://www.denisuca.com','79.118.51.107','2007-12-15 21:51:21','2007-12-15 19:51:21','Fix aÅŸa am pÄƒÅ£it io cu adminu\' de la lucru, care erea om bÄƒtrÃ¢n ÅŸi m-o sunat - cÄƒ io eram acasÄƒ, Ã®n vÃ¢rfu\' patului - sÄƒ-mi cearÄƒ parola. Åži io nu ÅŸi nu, cÄƒ nu Ã®l cunoÅŸteam, nu ÅŸtiam cÄƒ cine Ã®i, dar mai ales cÄƒ aveam tot o parolÄƒ de-asta. Se saturÄƒ omul de conversat cu mine ÅŸi sunÄƒ mai sus. Åži mÄƒ sunÄƒ ÅŸefa cu o falcÄƒ-n cer ÅŸi una... nu ÅŸtiu unde o avea, cÄƒ dacÄƒ nu le dau parola, tre\' sÄƒ mÄƒ duc io la Deva - de la Hunedoara, Ã®n zi liberÄƒ - sÄƒ o introbag.\r\nÅži sun, spÄƒÅŸitÄƒ, ÅŸi dictez parola: c-a-c-a-t-m-a-r-o. ÃŽncÄƒ mi-i ruÅŸine cÃ¢nd mÄƒ Ã®ntÃ¢lnesc cu omul Äƒla, deÅŸi au trecut cinci ani de atunci...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9858,890,'traffik','','','86.123.164.234','2007-12-15 18:09:35','2007-12-15 16:09:35','Si acuma tot pe aia o ai? Dar la messenger? :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10198,903,'Laura','mars1953@web.de','','84.160.113.192','2007-12-18 21:19:43','2007-12-18 19:19:43','si cu toate aceste efecte benefice un reprezentant de la o casa de asigurare de stat germana o anuntzat ca aceasta cercetare nu da dreptul la playboy pe retzeta gratuita... serios. Se ashteapta reactzia caselor de asigurari private...',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(10199,895,'kosmin','cosmin.popescu30@gmail.com','http://kosmin.net','78.96.32.221','2007-12-18 21:21:18','2007-12-18 19:21:18','O duci bine.600 vizitatori /zi e un record destul de bun.Stai chiar foarte bine as putea spune.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10200,903,'kosmin','cosmin.popescu30@gmail.com','http://kosmin.net','78.96.32.221','2007-12-18 21:30:54','2007-12-18 19:30:54','Inseamna ca de aia se uita barbatii dupa sani...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10201,903,'Felix','felix.felix@gmail.com','','82.76.4.55','2007-12-18 21:51:04','2007-12-18 19:51:04','la urmatoru loc de munca o sa cer sa vad poze in costum de baie ale angajatelor. nu de alta, dar sa vad cat am de trait de pe urma jobului...',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; InfoPath.1)','',0,0),(10208,893,'.marius','marius@perijoc.com','http://marius.wirelessisfun.com','89.137.107.129','2007-12-18 22:39:54','2007-12-18 20:39:54','Gropare, jur ca ai si cititori frumosi destepti si alte celea...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10211,895,'pliscu','pliscu@gmail.com','http://pliscu.blogspot.com','89.137.124.147','2007-12-18 23:33:05','2007-12-18 21:33:05','pai tre` sa existe un echilibru... amu si traficu vrei sa`ti fie mare?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10052,893,'kosmin','cosmin.popescu30@gmail.com','http://kosmin.net','78.96.32.221','2007-12-17 20:23:18','2007-12-17 18:23:18','Spamuri sunt de tot felul.Nici nu imi dau seama de unde tot imi vin pe mail.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10055,900,'Laura','mars1953@web.de','','84.160.107.64','2007-12-17 20:34:46','2007-12-17 18:34:46','Dupa mine ce atzi facut voi e curaj civic. Numaâ€™ o durere am: e pacat sa jignim vacile comparandu-le cu nishte amarate vanzatoare.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(9879,889,'Andreea MKT','supergirgir@yahoo.com','','89.43.186.64','2007-12-15 23:50:30','2007-12-15 21:50:30','matematica cuantica nu exista',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9884,890,'Tudor','','http://dingrajd.blogspot.com/','89.137.248.165','2007-12-16 01:49:10','2007-12-15 23:49:10','Tare faza cu paroalele astea. Cum era si parola de retea de la Fan-fest di la Rosia Montana... P U L A A U R. Crek e ceva legat de \"enviromentul\" si starea de duh pe care o ai in care lucrezi la computator. :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9885,381,'innuennda','innuenda.innuenda@gmail.ro','http://360.yahoo.com/innuennda','92.81.20.100','2007-12-16 01:56:33','2007-12-15 23:56:33','In primul rand, gropare, respect! Esti mai sincer decat o durere de masea. Apreciez asta la un om. \r\nIn al doilea rand, Paler a fost, este si va ramane un mare scriitor. Desigur, scriitura lui trebuie mai intai citita, ca sa fie recunoscuta ca atare. Zici ca nu l-ai citit. Dar tie ti-as putea ierta si asta. Ai tu o nonsalanta anume, aceeasi pe care o am eu-o doamna- cand injur ca un birjar (intre prieteni) si raspund la perplexitatile lor cu \"ce? sunt intelectuala, imi permit sa fiu vulgara; vulgaritatea e aproape licenta poetica intr-un context intelectual!\"',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9888,890,'zone-ro','zone-ro@google.com','http://zone-ro.blogspot.com/','89.33.174.237','2007-12-16 02:44:56','2007-12-16 00:44:56','http://zone-ro.blogspot.com/\r\n\r\nmi-a placut comentariul lui mirra',0,'1','Opera/9.23 (Windows NT 5.2; U; en)','',0,0),(9889,868,'zone-ro','zone-ro@google.com','http://zone-ro.blogspot.com/','89.33.174.237','2007-12-16 02:46:12','2007-12-16 00:46:12','aia cu banii e tare. mai era ceva de genu:\r\n\r\ndupa ce faci sex sa intrebi: cat ma costa?',0,'1','Opera/9.23 (Windows NT 5.2; U; en)','',0,0),(10888,915,'Brigitte','','','80.96.211.121','2007-12-24 16:20:45','2007-12-24 14:20:45','Sarbatori fericite gro\' dragule!!! :*:*:*',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 2.0.50727)','',0,0),(10151,903,'vizionarul','alinmiron_19@yahoo.com','http://vizionarul.wordpress.com','82.208.146.10','2007-12-18 14:25:27','2007-12-18 12:25:27','io is dependent de aceeasi pereche de tzatze de vreo 4 ani...',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648)','',0,0),(10154,893,'Adrian Marchis','adrian_marchis@yahoo.com','http://www.none.org','82.77.126.112','2007-12-18 14:42:01','2007-12-18 12:42:01','Hahahahaha, prea tare !! :))',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; SIMBAR={5D9226CD-9CC9-4BC3-B9E2-268A556AB08F}; .NET CLR 2.0.50727; .NET CLR 1.1.4322)','',0,0),(10155,895,'Dragos','dragos@secured.ro','http://dragos.secured.ro','194.116.217.245','2007-12-18 14:47:08','2007-12-18 12:47:08','Mai Gropare mai, nu ti-a zis nasu Ciutacu ? Pai suntem prea putini oameni de valoare, mai, in tara asta (asa i-a zis si lui cineva). Pai Io (cu I mare) zic ca is muult mai putini, ca unii mai ajung la tine si din gresala. Hai sa ne traiesti.',0,'1','Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.1.11) Gecko/20071204 Ubuntu/7.10 (gutsy) Firefox/2.0.0.11','',0,0),(10156,895,'Dragos','dragos@secured.ro','http://dragos.secured.ro','194.116.217.245','2007-12-18 14:52:45','2007-12-18 12:52:45','Serios acuma, ca-mi adusei aminte, pentru ce vrei trafic mare, ca adwords si stuff n-ai pe blog. Credeam ca esti pe calitate nu pe cantitate :P.',0,'1','Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.1.11) Gecko/20071204 Ubuntu/7.10 (gutsy) Firefox/2.0.0.11','',0,0),(10157,895,'innuennda','innuenda.innuenda@gmail.ro','http://360.yahoo.com/innuennda','92.80.22.193','2007-12-18 15:05:13','2007-12-18 13:05:13','Gropare, ai grija, cine pleaca de la o premisa falsa poa\' sa ajunga la o concluzie gresita. :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10166,895,'dorin','','','89.35.85.157','2007-12-18 16:51:39','2007-12-18 14:51:39','D-le Groparu(le). Io va citesc singur, inchis in camera, sa nu vada nimeni. Oare fac bine??????????????',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(10168,903,'mihai ursu','agentimperialist@yahoo.co','http://mihaiursu.wordpress.com','83.166.206.107','2007-12-18 17:18:01','2007-12-18 15:18:01','bine, bah gropare, si aia care traiesc in insulele tropicale unde nu e iarna, ger (prin urmare nici clisa, nici sacarica, nici palinca, nici moj craciun) si nici nevoie de acoperit fizicu\' uman al femeii care merge tompless de mititica, inseamna ca aia traiesc pe termen nelimitat? sint niste nemuritori? poate de aia le si tin despuiete, ca sa nu mai moara niciodata? si, daca da, atuncea de ce, totusi, mai dau si cu ortu\'n popa? care e explicatia? le mai taie cheful si durata vietii piesajul sinilor nevestei cind o iau incet catre buric, dupa o anumita virsta? ca, asa, mi s-ar parea si mie ca exista dreptate pe lume.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(10169,903,'baghy','baghy83@lycos.it','http://baghy.info/','78.12.17.109','2007-12-18 17:18:03','2007-12-18 15:18:03','nu cred',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(10170,895,'baghy','baghy83@lycos.it','http://baghy.info/','78.12.17.109','2007-12-18 17:19:14','2007-12-18 15:19:14','Gropare esti unul din cei mai tari. Productie proprie si de calitate. Ma faci sa rad ca nimeni altul',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(10171,895,'Ciupercutza','alabalaportocala1@gmail.com','http://ciupercutza.wordpress.com','193.226.142.214','2007-12-18 17:19:40','2007-12-18 15:19:40','Gropare, tu de fapt esti curios cine te citeste, nu? :P La mine in firma toata lumea :) Ti-am facut reclama.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(10172,903,'mihai ursu','agentimperialist@yahoo.co','http://mihaiursu.wordpress.com','83.166.206.107','2007-12-18 17:23:36','2007-12-18 15:23:36','ASADAR, FAC UN APEL! VREAU SA TRAIESC! FETELOR, VOI AVETI PUTEREA SA MA AJUTATI! NU VA INTOARCETI SINII DE LA PRIVIREA MEA... DA, SI NICI PRIVIREA DE LA MINE, CUM VRETI VOI...',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(10173,895,'spintecantropus erectus','','','84.232.141.81','2007-12-18 17:24:14','2007-12-18 15:24:14','is mai putini!',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727)','',0,0),(10179,903,'manole','redtailanda@yahoo.com','http://www.mesterulmanole.wordpress.com','89.32.123.108','2007-12-18 18:15:53','2007-12-18 16:15:53','eu nu prea cred in teoria asta a ta mai groparele. daca ar fi asa iti dai seama ca toti ginecologii (care printre alea,alea, trateaza si tate) ar fi vesnici?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(10180,895,'Usim','mihaimitan@gmail.com','','87.237.108.33','2007-12-18 18:16:16','2007-12-18 16:16:16','Numara-ma si pe mine. Si tot de pe doua IP-uri. Si si de pe telefon cand stau si-o astept pe prietena mea in fata portii, sa se urneasca.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; .NET CLR 2.0.50727)','',0,0),(10182,903,'julianus','julianuss@mail.com','','193.231.107.209','2007-12-18 18:22:17','2007-12-18 16:22:17','Unde trebuie sa ma uit si cat timp ca sa mi se prelungeasca pinguinu\'?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; .NET CLR 1.1.4322)','',0,0),(10183,895,'julianus','julianuss@mail.com','','193.231.107.209','2007-12-18 18:25:41','2007-12-18 16:25:41','Pai de ce ne certi tu pe noi, astai care am votat? Intreaba-i pe ailantii care joaca soliter. Chiar - nu poti sa-ti faci soliter ici-sa?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; .NET CLR 1.1.4322)','',0,0),(10184,900,'julianus','julianuss@mail.com','','193.231.107.209','2007-12-18 18:30:03','2007-12-18 16:30:03','Io ma pregatesc sa montez ceva de lamurit vecinii sa inchida usa de la intrare. \r\nLa vaci, urmatorul pas este sa le plasezi ceva coji de ceapa pe sub tejghele ca sa se simta in elementul lor. O sa plece si o sa le inlocuiasca altele proaspete si prietenoase.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; .NET CLR 1.1.4322)','',0,0),(10188,895,'Laura','mars1953@web.de','','84.160.113.192','2007-12-18 19:25:16','2007-12-18 17:25:16','innuennda are dreptate. De ce crezi oare ca numa\' cei din \"tzara asta\" te citesc?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(9950,893,'innuennda','innuenda.innuenda@gmail.ro','http://360.yahoo.com/innuennda','92.80.23.237','2007-12-16 16:38:49','2007-12-16 14:38:49','Cum de ce? Pentru ca se stie: pe femei nu le intereseaza ce simt barbatii!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10147,903,'Incredibil. O sa traiesc vesnic! &raquo; Sietchul lui L3ST','','http://www.l3st.com/2007/incredibil-o-sa-traiesc-vesnic.html','193.203.205.14','2007-12-18 13:31:44','2007-12-18 11:31:44','[...] Stirea via [...]',0,'1','Incutio XML-RPC -- WordPress/2.3.1','pingback',0,0),(9970,852,'Replicile sÄƒptÄƒmÃ¢nii 20 at Jurnal de noapte','','http://www.andreicrivat.ro/2007/12/16/replicile-saptamanii-20/','212.227.64.193','2007-12-16 23:06:28','2007-12-16 21:06:28','[...] ÅŸtii cÄƒ nu-i adevÄƒrat cÄƒ nu existÄƒ mireasÄƒ urÃ¢tÄƒ. (Groparu, Top 10 chestii care nu se spun miresei la o [...]',0,'1','Incutio XML-RPC -- WordPress/2.2','pingback',0,0),(10600,916,'eye-contact','chania22@gmail.com','http://pure-eyecontact.blogspot.com','86.121.65.149','2007-12-21 20:21:41','2007-12-21 18:21:41','dap, sau sa nu zici: mai am o gramada acasa si se stricau ca n-are cine sa le manance (mere) asa ca vi le-am adus voua (colegilor de birou), cum am zis eu:))) -&gt;in loc sa fiu si eu diplomata si sa zic: dragi colegi, stiti cat de simpatici imi sunteti, in semn de iubire v-am adus niste mere! (apuca-v-ar pantecaraia)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(11458,915,'Delavad','avadoru@yahoo.com','http://www.lavad.wordpress.com','89.121.222.2','2007-12-31 00:57:20','2007-12-30 22:57:20','PrimiÅ£i cu â€¦ BloguÅŸorul?\r\n\r\nMÄƒi, copii, ceâ€™n Äƒsta An\r\nVâ€™aÅ£i spus dorul, cu alean,\r\npe Äƒst blog: puneÅ£i Ã®n pom\r\nÅŸi http://www.lavad.wordpress.com\r\n\r\nSÄƒnÄƒtate ÅŸi bucurii!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9974,894,'Bogdan','bogdan_veseli@yahoo.com','','195.149.72.75','2007-12-17 00:51:47','2007-12-16 22:51:47','salut sibiene, ma bucur ca te-am descoperit',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9976,864,'nenea cosmos','domnu_cosmos@yahoo.com','http://www.nenea.wordpress.com','92.80.20.177','2007-12-17 01:08:49','2007-12-16 23:08:49','deci ceva pesedist...',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(9978,864,'WhiteWolf','contact@white-wolf.ro','http://white-wolf.ro','89.39.82.179','2007-12-17 01:30:24','2007-12-16 23:30:24','Vrei sa aderi la \"<b>P</b>ola <b>C</b>alului ?\r\nSau ne sfatuiesti, calduros si \"preteneste\" sa o facem noi ; cat mai rapid si definitiv ? :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9979,864,'.','treblinka3@yahoo.com','','89.136.185.1','2007-12-17 01:31:30','2007-12-16 23:31:30','Feliz navidad, pff!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9980,867,'WhiteWolf','contact@white-wolf.ro','http://white-wolf.ro','89.39.82.179','2007-12-17 01:31:50','2007-12-16 23:31:50','Bah, deci, tu chiar faci politica in vacanta parlamentara. Da ?\r\nCeva\'i tare <b>wrong</b> cu tine, mai nou :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9981,894,'WhiteWolf','contact@white-wolf.ro','http://white-wolf.ro','89.39.82.179','2007-12-17 01:33:59','2007-12-16 23:33:59','Las\' ca merge (<b>â„¢Â©</b> WhiteWolf, sa nu avem dupa aia vorbe la tribunal, da?)\r\nNasol era daca te simteai D.J. si te apuca chefu\' sa sucesti oarece ...potentiometre :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9985,864,'innuennda','innuenda.innuenda@gmail.ro','http://360.yahoo.com/innuennda','92.80.30.39','2007-12-17 03:05:11','2007-12-17 01:05:11','\"FELIX\" (numele de cod al lu\' nenea) NAVIDAD, Gropare!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9964,819,'dorin','','','89.39.183.157','2007-12-16 21:14:26','2007-12-16 19:14:26','Io va urmaresc din umbra, si imi place ce vad, da tare am vrut sa trag cu ochiu la Tiganiada. Da nu mio intrat deloc. Oi fi io prea tanar?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(9965,314,'uana','i_uana@yahoo.com','','86.126.112.82','2007-12-16 21:38:00','2007-12-16 19:38:00','io nu vreau s tziu post, vreau s termin de cetit toata arhiva pan\' la sfarsitu anului si ar fi mare realizare si asta ...mai am inca vreo nshpe mii d \'posturi\' si e gata treaba :-c',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10045,894,'sweeper','ak70g2@gmail.com','','86.107.192.53','2007-12-17 18:08:30','2007-12-17 16:08:30','Bre nene Gropare, asculta la fratele tau:\r\n\r\nE NAJPA RAU SA FII SINGUR IN PAT!\r\n\r\nItzi mai dadeam o sugestie, da\' se supara departamentu\' de marketing pe mine.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; .NET CLR 2.0.50727)','',0,0),(10046,900,'Andreea MKT','supergirgir@yahoo.com','','89.43.186.64','2007-12-17 18:10:20','2007-12-17 16:10:20','Gro si Mishu:)\r\n\r\nBaietzi, eu pe voi va iubesc dar ce ati facut azi e o copilarie. Mi se pare infantil sa lipiti colante pentru niste femei pe care nu le cunoasteti si pe care le-ati facut \"vaci\" dupa ce le-ati judecat 10 secunde in functie de un singur episod.\r\nE ca atuncia cand ne certa vecinul la bloc ca facem galagie si eu scriam cu creta pe usa \"Imbecilule\":) Hai ca va pup, a voastra colega, Andreea MKT si sa nu ma injurati maine la serviciu:)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10588,912,'Lumi','luminitadanciu@yahoo.com','','209.221.168.249','2007-12-21 18:38:56','2007-12-21 16:38:56','RGropare,\r\nFoarte bun post! Bine scris! Multumesc pentru amintiri...',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; InfoPath.1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(10017,893,'eu,Miruna','mirunavasilescu@yahoo.com','http://potsafacsiasaceva.blogspot.com/','86.106.59.163','2007-12-17 12:32:36','2007-12-17 10:32:36','Domnuuuu...Diaconescu, alta e problema. Daca eu primesc spamuri cu penis enlargement si viagra, oare sunt si barbati care primesc spamuri cu operatii de marire a sanilor? Asta ma intreb eu dimineata cand veific mailu\'.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10043,898,'Alex','alex.cioflica@jottstudios.com','http://alex.cyanad.ro','86.106.48.69','2007-12-17 17:43:24','2007-12-17 15:43:24','Mersi.\r\n\r\nSi multumim mult Adi Fedorovici pt crocodilu\' si spiridusu animat, versiunea originala!\r\n\r\nSarbatori fericite.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10058,900,'manole','redtailanda@yahoo.com','http://www.mesterulmanole.wordpress.com','89.32.123.108','2007-12-17 21:14:16','2007-12-17 19:14:16','groparele, super ideea, o dau si la bucuresti',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(10023,894,'manole','redtailanda@yahoo.com','http://www.mesterulmanole.wordpress.com','89.32.123.108','2007-12-17 15:18:55','2007-12-17 13:18:55','da cind nu iesti singurel in pat?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(10038,900,'zone-ro','zone-ro@google.com','http://zone-ro.blogspot.com/','89.33.174.237','2007-12-17 17:10:25','2007-12-17 15:10:25','http://zone-ro.blogspot.com/\r\n\r\n\r\nin curand o sa apara ceva nou in Romania unde o sa fie pedepsiti toti comerciantii astia prosti si nesimtiti',0,'1','Opera/9.23 (Windows NT 5.2; U; en)','',0,0),(10039,898,'zone-ro','zone-ro@google.com','http://zone-ro.blogspot.com/','89.33.174.237','2007-12-17 17:12:31','2007-12-17 15:12:31','http://zone-ro.blogspot.com/\r\n\r\npai nu vad nici nu motiv de suparare',0,'1','Opera/9.23 (Windows NT 5.2; U; en)','',0,0),(10040,900,'eu','ripahoratiu@yahoo.com','','82.77.126.254','2007-12-17 17:13:48','2007-12-17 15:13:48','Bah, le stiu si io pe alea, well done!!!!\r\nPe langa faptul ca n-am dus la pascut caprele impreuna - pentru simplul motiv ca eu sunt nascut la oras si n-am dus caprele la pascut in general - pe langa faptul ca \"clentu\' nostru stapanu\' nostru\", pe langa faptu\' ca fo juma din ele pot sa-mi fie fiice daca nu eram atent cu f\'un spermatozoid mai campion, asa; intr-adevar, se uita bovin-rumegator la tine de parca asteapta sa le duci la monta cand le dai un buna-ziua si nuii macar un muget, behait, mormait, marait de raspuns n-auzi. \r\nSi iti mai dau si rest cate-o lama de Orbit ca vesnic n-au marunt, chiar ma gandeam sa le strang si sa ma duc sa platesc cu ele....',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.2; .NET CLR 1.1.4322; .NET CLR 2.0.50727; InfoPath.1; .NET CLR 3.0.04506.30)','',0,0),(10041,898,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-12-17 17:25:01','2007-12-17 15:25:01','Deci @Crocodilu: deci man, deci io nu puteam sa te rog tocmai pa tine sa iti faci bashca de propria opereta! Da las ca am ceva concepte pe care le poti face chiar tu, in care Biris papa crocodilu, si ne da noo burta lui sa ne facem pantofi si geamantane gratise!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10026,819,'WarSongu','eternaldawnlord@yahoo.com','http://www.warsongu.wordpress.com','193.32.3.83','2007-12-17 16:06:26','2007-12-17 14:06:26','praleo...poate nu ma kemi si pa mine data aviatoare...viu cu zongra sa va imbuib canestele cu niste grohaieli romalo...',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; FunWebProducts; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(10032,900,'parsiimpar','lummi31@gmail.com','http://www.luminita-dragomir.ro/blog/','81.196.54.24','2007-12-17 16:57:02','2007-12-17 14:57:02','Asta intra in categoria...magia sarbatorilor?:))))',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(10033,900,'Femeile','ps@yahoo.com','http://ce-vor-femeile.blogspot.com','213.157.188.71','2007-12-17 17:00:40','2007-12-17 15:00:40','mo, unde ii magazinu vietzii? pe 21 Dec acolo unde o iei cata\' Cina?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10034,900,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-12-17 17:02:00','2007-12-17 15:02:00','@mishu, @parsiimpar, @femeile: Ezac!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10035,900,'Radu','mail_radu@yahoo.com','','82.77.126.254','2007-12-17 17:04:52','2007-12-17 15:04:52','Recomand lui Mishu vizionarea filmului \"Falling Down\", cu Michael Douglas.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10036,898,'crocodilu\'','tianatrilulilu@yahoo.com','','85.186.68.71','2007-12-17 17:06:13','2007-12-17 15:06:13','b-b-bre, g-g-groparule, dupe cum v-v-vezi, BiriÅŸ nu se supere, dar era fainÄƒ dacÄƒ Ã®ntrebai m-m-matale ÅŸi pe cela care-o asudat sÄƒ deseneze ÅŸ-animeze chestia \'ceea... cÄƒ doar eÅŸti fix muncit din spermatozoizi campioni.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10028,898,'Mih_nea','mihnea_xxyahoo.com','','62.217.236.12','2007-12-17 16:23:04','2007-12-17 14:23:04','cica vor sa listeze trilulilu la BVB. Al dracu\' sa fiu daca bag vr\'un ban in ceva cu denumirea asta :)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(10029,898,'L3ST','webmaster@l3st.com','http://www.l3st.com/','89.34.247.119','2007-12-17 16:25:54','2007-12-17 14:25:54','Haha ce tare-i. Felicitari Alex!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10030,898,'Sergiu BiriÅŸ','sergiu.biris@trilulilu.ro','http://www.sergiubiris.ro','85.186.68.72','2007-12-17 16:35:26','2007-12-17 14:35:26','hahaha, bravo ma :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10014,893,'kosmin','cosmin.popescu30@gmail.com','http://kosmin.net','213.157.169.198','2007-12-17 11:50:59','2007-12-17 09:50:59','Pentru spam exista si un plugin automat Aksimet, parca se cheama;Cat despre \"nevastuici\", cred ca ar avea mare succes daca ar scoate vreo firma produce pentru micit \"nevasuicile\" !!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10007,864,'dorin','','','89.35.85.157','2007-12-17 09:18:47','2007-12-17 07:18:47','DAD IVAN????????????????',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(10031,900,'mishu','mishu@doingtheartwork.com','http://www.doingtheartwork.com','82.77.126.254','2007-12-17 16:52:34','2007-12-17 14:52:34','Vaci cu cabina!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10016,867,'eu,Miruna','mirunavasilescu@yahoo.com','http://potsafacsiasaceva.blogspot.com/','86.106.59.163','2007-12-17 12:29:39','2007-12-17 10:29:39','Cam ca \"Lucrurile pe care nu le spui, se pierd\". ÃŽÃ®Ã®Ã®Ã®h!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9947,893,'manole','redtailanda@yahoo.com','http://www.mesterulmanole.wordpress.com','89.32.123.108','2007-12-16 16:15:18','2007-12-16 14:15:18','si ele primesc tot cialis si viagra. de le dau delete...iti spun eu.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(10623,912,'julius constantinescu','julius@universitateacraiova.ro','http://www.7plus.ro','84.232.162.106','2007-12-22 00:13:56','2007-12-21 22:13:56','hai ca ti-am bagat blogu\' in bookmarks. sunt asa sensibil la linguseli...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9955,867,'Tavi','nessajab4@yahoo.com','','194.99.245.11','2007-12-16 17:57:50','2007-12-16 15:57:50','Eu mai stiu una ... if you can\'t beat them...arrange to have them beaten...\r\n\r\nToata stima si respectul Groparu\'...mi-ai inseninat o zi de lucru ( de duminica dupa-masa )...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9943,893,'vizionarul','alinmiron_19@yahoo.com','http://vizionarul.wordpress.com','89.35.87.15','2007-12-16 15:38:57','2007-12-16 13:38:57','@zone-ro: sanii se maresc prin frecare cu hartie intre ei... N-ai vazut ce buci au femeile asa mai spre 40 de ani? din cauza ca se freaca cu hartie intre ele...\r\n@groparu: mai bine ca femeile sa primeasca busola ca sa-i ajute pe unii barbati sa le gaseasca punktu ge.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648)','',0,0),(10620,912,'Victor','vick_redhound@yahoo.com','','89.43.11.130','2007-12-21 23:30:40','2007-12-21 21:30:40','Cateva lacrimi pentru cei cazuti atunci... In toata Romania. Ma uitam la TV de ziua mea de nastere, pe 23 august, si vedeam o mana de oameni stransi sa sarbatoreasca \"marea zi a eliberarii poporului roman\". Pe lumina ochilor mei, daca as sti unde se strang as intra in ei ca lupu-n oi. \r\n\r\nSa nu va amintiti doar ce a fost la Revolutie, amintiti-va tot! Amintiti-va de lagarele comuniste, amintiti-va de mancarea la ratie, de emisiunile tovarasului, de tot ce a fost. Caci daca uitam vom putea fi din nou calcati in picioare.\r\n\r\nEu la Revolutie aveam 5 ani, si nu am intelegeam mare lucru; de asemenea nu am avut contact prea mare cu comunismul. Tot ce imi aduc aminte e ca ma trimitea mama la alimentara cu bonul sa iau paine. Nu eram in Bucuresti pe vremea aia...\r\n\r\nIti multumesc, Gropare, ca ne-ai reimprospatat memoria.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; .NET CLR 1.1.4322)','',0,0),(9956,867,'July','jullya24@yahoo.com','','78.96.211.35','2007-12-16 18:05:20','2007-12-16 16:05:20','apai no, o fi fost si el beat inca dupe un chef si....i-o fost lene sa mai stearga, asa ca o facut completarea respectiva, decat sa corecteze unde trebuia....(mai stim noi pe cineva care face deastea...dar tu ne ejti simpatic si el nu!)',0,'1','Opera/9.10 (Windows NT 5.1; U; en)','',0,0),(9935,894,'zone-ro','zone-ro@google.com','http://zone-ro.blogspot.com/','89.33.174.237','2007-12-16 13:47:22','2007-12-16 11:47:22','asta cu chipul si asemanarea lui e cam relativa :) \r\n\r\nhttp://zone-ro.blogspot.com/',0,'1','Opera/9.23 (Windows NT 5.2; U; en)','',0,0),(9936,893,'zone-ro','zone-ro@google.com','http://zone-ro.blogspot.com/','89.33.174.237','2007-12-16 13:48:49','2007-12-16 11:48:49','http://zone-ro.blogspot.com/\r\n\r\nsunt de acord cu tine, daca nu se poate mai stramta, macar sa le mareasca sanii :P',0,'1','Opera/9.23 (Windows NT 5.2; U; en)','',0,0),(10616,916,'July','jullya24@yahoo.com','','92.81.59.122','2007-12-21 22:52:31','2007-12-21 20:52:31','ce de isss....pai decat sa te chinui sa ti minte sa nu cumva sa zici una din chestiile astea cand dai cadoul...mai bine nu mai dai nimic si gata....',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(10617,916,'krossfire','profesornukem@yahoo.com','http://krossfire.wordpress.com','86.123.207.153','2007-12-21 22:53:14','2007-12-21 20:53:14','Uite iubito, ti-am adus un plectrum de chitara semnat Ozzy Osbourne. Daca nu-ti place, mi-l dai mie !',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9932,893,'Arhi','admin@arhiblog.com','http://www.arhiblog.com','82.77.85.247','2007-12-16 12:04:22','2007-12-16 10:04:22','pentru ca la ele pipistropul functioneaza. la noi ne-ar imbolnavi de prostat, si nu vrem asta, ptr ca nu avem bani de prostamol uno, care eunsuplimentalimentarincazdemanifestarineplacutecontactatimediculsaufarmacistul.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; ro; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10603,915,'porculeanu','oitza@yahoo.com','','24.19.31.87','2007-12-21 20:58:36','2007-12-21 18:58:36','un gand frumos si abia astept sa te citesc dupa :)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727)','',0,0),(10607,801,'C.','','','86.127.163.237','2007-12-21 21:56:32','2007-12-21 19:56:32','=)))))))))))tare!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; FunWebProducts)','',0,0),(9920,889,'vizionarul','alinmiron_19@yahoo.com','http://vizionarul.wordpress.com','89.35.87.15','2007-12-16 10:35:00','2007-12-16 08:35:00','@innuennda: limba mea a ajuns asa de la \"alfabet\" :P',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648)','',0,0),(9923,890,'Mihai Ursu','agentimperialist@yahoo.com','http://mihaiursu.wordpress.com','83.166.206.107','2007-12-16 11:02:54','2007-12-16 09:02:54','hai cÄƒ Ã®Å£i zic io una tare (ÅŸi sper sincer cÄƒ au schimbat bÄƒieÅ£ii parolele de acum aproape patru ani)\r\naÅŸadar, eram Ã®ntr-o zonÄƒ de conflict, nu zic care, unde tocmai se petrecuserÄƒ niÅŸte chestii chiar nasoale, cu vreo 28 de morÅ£i de partea bÄƒieÅ£ilor buni, Ã®n urmÄƒ cu aproape patru primÄƒveri.\r\nÅŸi mÄƒ nimeresc io pe timp de noapte Ã®n maÅŸina de patrulÄƒ a unor militari romÃ¢ni, cu care trebuia sÄƒ ajungem la un obiectiv nasol, vizat permanent de bulangii de inamici cu arme. cum ne apropiam, auz pe staÅ£ie, Ã®n romÃ¢neÅŸte, \"stai, cÄƒ trag!\".\r\ncomandantul echipajului pune mÃ®na pe staÅ£ie ÅŸi rÄƒspunde calm: \"tragi Ã®n pizda mÄƒ-ti!\". hahaha, ce ne-am mai rÃ®s noi, a fost tare. \r\npÃ®nÄƒ cÃ®nd ne zice ofiÅ£erul cÄƒ alea erau parola ÅŸi rÄƒspunsul aprobate Ã®n cadrul misiunii.\r\nÅŸi, de cÃ®te ori mÄƒ vÄƒd cu ofiÅ£erul Ã®n cauzÄƒ, aÅŸa Ã®mi vine sÄƒ rÃ®d, cÄƒ Ã®mi amintesc de episodul de noapte, cÃ®nd o Ã®njurÄƒturÄƒ era diferenÅ£a Ã®ntre bine-mersi acasÄƒ sau ciuruialÄƒ cu gloanÅ£e romÃ¢neÅŸti.\r\naltfel, un bÄƒiat genial, cÄƒ acum e ÅŸeful unei structuri meseriaÅŸe... sÄƒ trÄƒieÅŸti, comandante!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(9925,890,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2007-12-16 11:06:29','2007-12-16 09:06:29','CEEE TAAAREEE =))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(9927,867,'Mihai Ursu','agentimperialist@yahoo.com','http://mihaiursu.wordpress.com','83.166.206.107','2007-12-16 11:24:08','2007-12-16 09:24:08','pai, clar, daca stie dusmanul tot ce iti poate pielea, normal ca mai bine ti se face prieten (sau tovaras). can\'t beat them, join them...\r\napropos, la fraza de mai jos a mai uitat cineva o virgula...\r\niar diacriticele sint si ele lipsa, ca in textul de fata.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(9928,867,'Mihai Ursu','agentimperialist@yahoo.com','http://mihaiursu.wordpress.com','83.166.206.107','2007-12-16 11:27:22','2007-12-16 09:27:22','apropos, am sters aia, cum ai vrut. si eu sint un gentleman, am aceleasi principii...',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(9929,867,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2007-12-16 11:37:12','2007-12-16 09:37:12','Mersi de sterjere ;)\r\n\r\nDeci te referi numai la faptul ca in mod normal, cand subordonata precedeaza propozitia principala, e de bun simptz sa interpui o virgula? Virgula aia care lipseste si din ultima fraza, aia pusa de dizainaru meu de curte, tzuc-o mama? Da, e adevarat!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10609,915,'July','jullya24@yahoo.com','','92.81.59.122','2007-12-21 22:06:26','2007-12-21 20:06:26','Sarbatori fericite!... sa ai parte de toate cele bune...',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(10610,915,'c|neva','cineva_df@yahoo.com','http://www.diaconuflorin.ro','89.33.215.60','2007-12-21 22:11:00','2007-12-21 20:11:00','Apoi gropare...cum am auzit si cum imi place mie sa spun: Sarbatori Diferite...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10611,916,'c|neva','cineva_df@yahoo.com','http://www.diaconuflorin.ro','89.33.215.60','2007-12-21 22:12:11','2007-12-21 20:12:11','Urate replici mah...ce dracu...mai bine taci decat sa zici chestii de genu asta cand oferi un cadou...eftin..',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10217,903,'Angel Vamanu','s','http://zebeu.blogspot.com/','89.32.80.187','2007-12-19 00:34:21','2007-12-18 22:34:21','la radio erevan s-a pus o intrebare buna.. : \"merita sa pierzi 10 ani din viatza uitandute la tÃ¢te si sa traiesti cu 5 mai mult?\"',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; WOW64; SLCC1; .NET CLR 2.0.50727; Media Center PC 5.0; InfoPath.2; .NET CLR 3.5.20706; .NET CLR 3.0.590)','',0,0),(10219,895,'Angel Vamanu','s','http://zebeu.blogspot.com/','89.32.80.187','2007-12-19 00:37:00','2007-12-18 22:37:00','vreau si eu macar 500/zi :)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; WOW64; SLCC1; .NET CLR 2.0.50727; Media Center PC 5.0; InfoPath.2; .NET CLR 3.5.20706; .NET CLR 3.0.590)','',0,0),(10221,903,'Angel Vamanu','s','http://zebeu.blogspot.com/','89.32.80.187','2007-12-19 00:54:54','2007-12-18 22:54:54','curiozitatea m-a facut sa ma apuc d calculat.. :) si am luat asa.. 10min/zi timp de 80 de ani se pierd cam 5.555555....56 ani uitandute la tÃ¢te :) deci e bine... dar daca te gandesti k odata ajuns la 80 de ani mai ai 5 ani de trait si nu ti se mai scoala si ai si ajuns sa te cam caci p tine.. cred k mai bine te uiti un singur minut p zi  la tÃ¢te si p cat posibil altele in fiecare zi sa nu te plictisesti..\r\n\r\nin rest numa bine.. tot asa gropane...!',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; WOW64; SLCC1; .NET CLR 2.0.50727; Media Center PC 5.0; InfoPath.2; .NET CLR 3.5.20706; .NET CLR 3.0.590)','',0,0),(10223,903,'Angel Vamanu','s','http://zebeu.blogspot.com/','89.32.80.187','2007-12-19 01:11:37','2007-12-18 23:11:37','si totusi realitatea bate blogu\' :)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; WOW64; SLCC1; .NET CLR 2.0.50727; Media Center PC 5.0; InfoPath.2; .NET CLR 3.5.20706; .NET CLR 3.0.590)','',0,0),(10254,895,'kosmin','cosmin.popescu30@gmail.com','http://kosmin.net','213.157.169.198','2007-12-19 07:45:25','2007-12-19 05:45:25','E nevoie de timp, rabdare si ceva cunostinte despre SEO.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(10256,895,'mirra','','','83.103.137.234','2007-12-19 08:07:23','2007-12-19 06:07:23','Cine se aseamana se aduna!:)) Amu ca om fi destepti sau nu,ce conteaza, important e sa ne adunam...Si asa incet o sa ne adunam,dar e cam greu de gasit oameni care sa se asemene cu noi!:))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10258,903,'mirra','','','83.103.137.234','2007-12-19 08:14:53','2007-12-19 06:14:53','Io sed asa la cafea si ma intreb,oare cercetarea nu are de fapt doua parti?Aia cu privitul tatzelor si una care nu s-a dat publica cu privitul de penisuri?! Daca stai si te uiti pe diferite statistici vezi ca femeile au o medie de viatza mai mare decat barbatii, sunt mai multe vaduve decat vaduvi.Oare de ce?... Va las pe voi sa trageti concluzii!!!:)))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10523,914,'julianus','julianuss@mail.com','http://www.astalavista.box.sk','193.231.107.209','2007-12-21 07:09:18','2007-12-21 05:09:18','Io stiam ca e periculos sa pupi mana curvelor si sa dai click pe linkuri lela.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; .NET CLR 1.1.4322)','',0,0),(10267,895,'Mihai','mhangansv@yahoo.com','','81.196.150.96','2007-12-19 10:01:21','2007-12-19 08:01:21','Mno, concluzia e clara. Pe cand faci un partid?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10268,895,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-12-19 10:06:32','2007-12-19 08:06:32','@all: deci da, va multumesc ca ma skarpinatz in asa hal! :D yessss... otzara mai la stanga, asaaaa...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10270,58,'Geovanni','','http://groups.google.com/group/tuhlaes/web/big-cocks-tiny-girls','195.225.178.15','2007-12-19 10:31:02','2007-12-19 08:31:02','<strong>big cocks tiny girls...</strong>\n\nTo better understand the changing terms of global competition\n...',0,'1','USERAGENT','trackback',0,0),(10271,906,'cip','cipis74@yahoo.com','','89.137.107.153','2007-12-19 10:32:15','2007-12-19 08:32:15','...asta-i din ciclu\' PATZASHTI!',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(10278,906,'julianus','julianuss@mail.com','','193.231.107.209','2007-12-19 11:41:53','2007-12-19 09:41:53','Daca patzea asta o muiere, ne craceam de ras. Asa, e doar din ciclul \"numa monitoru stie...\"',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; .NET CLR 1.1.4322)','',0,0),(10464,911,'CÄƒlÄƒ','acalarasu@gmail.com','http://adriancalarasu.wordpress.com/','62.217.241.242','2007-12-20 20:21:01','2007-12-20 18:21:01','Io atata zic: ba, bine ca nu e adevarata chestia aia cu barza (da, am aflat si eu zilele astea!) ca nush ce glume dintr-astea tendentioase si aluzive mai faceam noi...',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(10472,907,'L3ST','webmaster@l3st.com','http://www.l3st.com/','89.34.247.119','2007-12-20 21:53:52','2007-12-20 19:53:52','zone-ro - te roaga eu nu-ti mai incercui commenturile cu linkul spre blog ca imi zgarii retina!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10476,911,'zone-ro','zone-ro@google.com','http://zone-ro.blogspot.com/','89.33.174.237','2007-12-20 22:53:17','2007-12-20 20:53:17','http://zone-ro.blogspot.com/',0,'1','Opera/9.23 (Windows NT 5.2; U; en)','',0,0),(10477,907,'zone-ro','zone-ro@google.com','http://zone-ro.blogspot.com/','89.33.174.237','2007-12-20 22:54:28','2007-12-20 20:54:28','hai basti\r\n\r\nhttp://zone-ro.blogspot.com/',0,'1','Opera/9.23 (Windows NT 5.2; U; en)','',0,0),(10479,907,'Nascut din spermatozoizi campioni &raquo; Blog Archive &raquo; Pentru http://zone-ro.blogspot.com/','','http://www.groparu.ro/?p=914','82.103.137.253','2007-12-20 23:19:26','2007-12-20 21:19:26','[...] Says: December 20th, 2007 at 2:29 pm [...]',0,'1','Incutio XML-RPC -- WordPress/2.1.2','pingback',0,0),(10482,914,'Razvan Antonescu','razvan.antonescu@gmail.com','http://idei-locale.blogspot.com','79.113.139.55','2007-12-20 23:30:08','2007-12-20 21:30:08','PLM...daca stiam ca asta tre ca sa faci un post despre cultul personalitatii mele incepeam de mai de mult si io. Na. Ia de aici:\r\n\r\nhttp://idei-locale.blogspot.com',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071018 Firefox/2.0.0.8 Flock/1.0RC3 VRE Toolbar 1.42','',0,0),(10483,911,'sweeper','ak70g2@gmail.com','','86.107.192.53','2007-12-20 23:39:11','2007-12-20 21:39:11','Nene Gropare, ii crimnal commentu\' astuia dinantea mea...',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; .NET CLR 2.0.50727)','',0,0),(10484,914,'andrei crivat','andrei@andreicrivat.ro','http://www.andreicrivat.ro','89.137.83.141','2007-12-20 23:43:36','2007-12-20 21:43:36','deci chiar nu pricep, de ce promovezi un spammer ? intreb deadly serious.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10450,911,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-12-20 17:03:53','2007-12-20 15:03:53','Poi nu il demolezi, numa-l explici sa inteleaga tat rumÃ¢nu! CÄƒ una nu o Ã®mpiedicÄƒ pe ailantÄƒ.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10455,907,'nimeni','nimeni@nimeni.com','','193.230.233.253','2007-12-20 18:37:00','2007-12-20 16:37:00','Io aÅŸtept ziua Ã®n care scrierile Groparului o sÄƒ fie recitate dimineaÅ£a la radio de cÄƒtre Buzdugan ÅŸi Morar, evident ca ÅŸi cÃ¢nd le-ar fi iscat minÅ£ile lor (lipsÄƒ) :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10566,912,'innuennda','innuenda.innuenda@gmail.ro','http://360.yahoo.com/innuennda','92.80.17.220','2007-12-21 15:12:57','2007-12-21 13:12:57','Pentru lupulalb, de stepa sau singuratic: umoristic esti tu si copiii tai din blog, profundule! Noi suntem de-a dreptul gravi. \r\nIntru intelegerea sintagmei urmareste desenul:\r\n\r\nRÃ¢su\' plÃ¢nsu\' (Nichita Stanescu)\r\n\r\nPleoapÄƒ cu dinÅ£i, cu lacrimÄƒ mÃ¢njitÄƒ,\r\nsare cÄƒzutÄƒ Ã®n bucate,\r\ndovadÄƒ cÄƒ nu pot trÄƒi numai acum\r\nsunt amintirele mele, toate ...\r\n\r\nDovadÄƒ cÄƒ nu pot vedea fÄƒrÄƒ martori\r\ne copilÄƒria, adolescenÅ£a mea,\r\ndublÃ¢nd nefiinÅ£a acestei secunde\r\ncu nefiinÅ£a ei de cÃ¢ndva.\r\n\r\nAh, rÃ¢su\' plÃ¢nsu\'\r\nah, rÃ¢su\' plÃ¢nsu\'\r\nmÄƒ bufneÅŸte cÃ¢nd spun\r\nsecundei vechi putrezind Ã®n secunda\r\nde-acum.\r\n\r\nAh, rÃ¢su\' plÃ¢nsu\'\r\nah, rÃ¢su\' plÃ¢nsu\'\r\nÃ®n ochiul lucrurilor reci\r\nÅŸi-n dintele lor muÅŸcÄƒtor, ca ÅŸi sceptrul\r\nneinventaÅ£ilor regi.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10568,912,'WhiteWolf','contact@white-wolf.ro','http://white-wolf.ro','89.32.115.216','2007-12-21 15:39:20','2007-12-21 13:39:20','Tare-i rau cand te manca-n stufuletz. Stiu\r\nDar chiar ai senzatia ca imi pasa de gravitatea ta sau cine si de ce te busheste ?\r\nZau, respira adanc si lasa lumea sa faca cozonacii.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10573,912,'c|neva','cineva_df@yahoo.com','http://www.diaconuflorin.ro','89.33.215.60','2007-12-21 16:36:40','2007-12-21 14:36:40','Aveam vreo 3 ani atunci iar prin nordul moldovei nu imi aduc aminte sa fi fost cine stie ce...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10574,912,'innuennda','innuenda.innuenda@gmail.ro','http://360.yahoo.com/innuennda','92.80.17.220','2007-12-21 17:00:38','2007-12-21 15:00:38','@ whitewolf : Din respect pentru subiectul articolului, pentru autorul blogului, pentru Craciun si pentru mine care nu am organ pentru de-alde tine, o sa ma opresc aici. Tin totusi sa iti impartasesc un secret: \"stufuletz\" nu mai poarta femeile cam de pe vremea cand aveai tu parte de ele. Hehehehe',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10578,915,'vizionarul','alinmiron_19@yahoo.com','http://vizionarul.wordpress.com','89.35.87.15','2007-12-21 17:29:55','2007-12-21 15:29:55','dorÄƒ n-ai vrun gÃ¢nd sÄƒ nu mai bloguieÅŸti pÃ¢nÄƒ dupÄƒ sÄƒrbÄƒtori?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648)','',0,0),(10576,912,'WhiteWolf','contact@white-wolf.ro','http://white-wolf.ro','89.39.81.118','2007-12-21 17:26:39','2007-12-21 15:26:39','Si-i de rau sau de bine ?\r\nPentru Craciun, respect, subiectul articolului si Groparu ?\r\nAprinde lumanarea, pune capac la oala cu sarmale, lasa cozonacii sa creasca in voie si renunta la inversunarea-ti de femeie un rushinea-n vant. Zau, de Craciun trebuie sa fim mai buni.\r\n Bagarea ta in seama inutila are baze gresite.\r\nDaca as fi stiut ca se impune sa fac comentarii de genul \"nu se adreseaza innuenndei care, nu-i asa, e mai preus de plebe\", asa faceam. Uite ca-m gresit; nu intra-tat cat sa-mi cer scuze da\' tot greseala e\r\nAcum <b>ho !</b> \r\nCu sau fara stufulets, n-ai ficatul care s-ar impune :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10579,915,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-12-21 17:36:09','2007-12-21 15:36:09','Plec in seara asta din Cluj, unde am acces la net, si nu cred ca mai ajung la vreun calc pana in 3 ianuarie! De fapt, eu asa sper, sa nu mai ajung la nici un calc pana in 3 ianuarie. A, si mai sper sa nu mai vad lucruri patrate, cubice sau care seamana cu monitoare!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10491,914,'Darius','darius.groza@gmail.com','http://jeg.ro','195.225.66.166','2007-12-21 00:24:58','2007-12-20 22:24:58','Din motive de prinÅ£ip, n-am dat click pe nici unul dintre zone-ro-uri. Åži n-o sÄƒ dau Ã®n continuare. Propun o adaptare a vechii mele idei:\r\n\r\nSÄƒ ne semnÄƒm pe multe bloguri cu nicku\' zone-ro ÅŸi link-uri spre Groparu\', atÃ¢t Ã®n formular, cÃ¢t ÅŸi Ã®n conÅ£inut.',0,'1','Mozilla/5.0 (Macintosh; U; Intel Mac OS X; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10492,914,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2007-12-21 00:30:33','2007-12-20 22:30:33','@ just like that: ai fiii prins!!! sau surprins, nu mai stiu :)\r\n\r\n@ jegutzu: aha. Deci din tÄƒtÄƒ povestea, ajung ca numele meu sa fie asociat cu cel al unui spammer. Hmmm! (esti pe-o mana cu iel?)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10494,914,'L3ST','webmaster@l3st.com','http://www.l3st.com/','89.34.247.119','2007-12-21 00:54:51','2007-12-20 22:54:51','Zone-ro asta e din categoria vacilor cugetatoare, da raspunsuri filozofice gen \"Hai basti\".',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10496,907,'Sabie','ma_cristian@yahoo.com','http://n-amsite.ro','89.36.180.55','2007-12-21 00:57:36','2007-12-20 22:57:36','VorbeÅŸte frumos mÄƒi hÃ¢rlete !',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10497,914,'baghy','baghy83@lycos.it','http://baghy.info/','78.12.17.109','2007-12-21 01:07:50','2007-12-20 23:07:50','numai tu puteai sa faci asa ceva. Am observat si eu faza cu zone-ro. Doar aici face asa sau si pe alte bloguri?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(10499,914,'Darius','darius.groza@gmail.com','http://jeg.ro','195.225.66.166','2007-12-21 01:26:40','2007-12-20 23:26:40','MÄƒ, da\' noi nu pentr trafic luptÄƒm aci, scÃ¢rnÄƒvie? Te-ndoieÅŸti de talentele miele? Ia hai pÃ¢nÄƒ-n faÅ£Äƒ la Opera Plaza c-o camerÄƒ, cÃ¢teva minute. :)',0,'1','Mozilla/5.0 (Macintosh; U; Intel Mac OS X; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10502,914,'OLiX','oliver.simionescu@gmail.com','http://olixbolix.blogspot.com','86.106.0.184','2007-12-21 01:57:14','2007-12-20 23:57:14','macar de-si punea ala un counter ceva ca sa vada daca si de unde-i vin vizitatorii si, mai mult, sa vada cati vizitatori are. eu nu vad niciun counter la el, da` poate are unu` invizibil.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10374,900,'Blegoo','blegoo@yahoo.com','','24.238.60.30','2007-12-20 02:51:55','2007-12-20 00:51:55','@Andreea MKT: Gresesti abismal, fatuca! Ce au facut feciorii aia doi, este act de patriotism, launtric simtit, tainic meshterit si bine muncit!\r\nDimocratia iaste, care vaz\'ica...implicatiune, nu doara intoarcere de obraji!\r\nBunaoara, chiar si Mihai Viteazul.... :)',0,'1','Mozilla/5.0 (Macintosh; U; PPC Mac OS X; en) AppleWebKit/418.8 (KHTML, like Gecko) Safari/419.3','',0,0),(10284,906,'zone-ro','zone-ro@google.com','http://zone-ro.blogspot.com/','89.33.174.237','2007-12-19 12:51:54','2007-12-19 10:51:54','http://zone-ro.blogspot.com/\r\n\r\n:))',0,'1','Opera/9.23 (Windows NT 5.2; U; en)','',0,0),(10285,906,'Mih_nea','mihnea_xxyahoo.com','','62.217.236.12','2007-12-19 12:58:54','2007-12-19 10:58:54','tare... au patzit-o si altii\r\nadevarul e ca ar trebui sa folosim parole cand vb pe mess',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(10516,911,'innuennda','innuenda.innuenda@gmail.ro','http://360.yahoo.com/innuennda','92.80.47.199','2007-12-21 05:06:10','2007-12-21 03:06:10','Cu preistoricii ca cu preistoricii, daâ€™ cu antropoidele ÅŸtiti cÃ¢t ne asemÄƒnÄƒm?\r\nÅžtiÅ£i, de exemplu, de ce toÅ£i bÄƒrbaÅ£ii vorbesc despre erectorul lor ca despre un â€œreactor nuclearâ€, â€œpaloÅŸ grosâ€, â€œanacondÄƒâ€, â€œtorpilÄƒâ€ etc etc, cu alte cuvinte de ce Ã®ÅŸi hiperbolizeazÄƒ micul procreator? Penâ€™cÄƒ pe vremea antropoidelor, printre masculi, exista o ierarhie foarte clarÄƒ, bazatÄƒ pe dimensiuni. Aveai dimensiune? Erai mascul dominant! Nu aveai dimensiune, atunci nu te Ã®mperecheai, pentru cÄƒ numai masculul dominant se Ã®mperechea. Or, ce bÄƒrbat cu scaun la cap ar vrea ca ceilalÅ£i sÄƒ creadÄƒ despre el cÄƒ nu se Ã®mperecheazÄƒ? \r\nApoi cicÄƒ tot pe vremurile alea, cÃ¢nd un mascul dominant Ã®ntÃ¢lnea un mascul strÄƒin (despre care nu ÅŸtia dacÄƒ nu cumva e ÅŸi el dominant prin vreun alt grup ÅŸi atunci treâ€™ sÄƒ intre amÃ¢ndoi la â€œbarajâ€) Ã®ncepea un adevÄƒrat ritual demonstrativ ÅŸi ameninÅ£Äƒtor, bÄƒtÃ¢ndu-se cu pumnii Ã®n piept, ieÅŸind la atac pentru a se ÅŸti o datÄƒ pentru totodeauna cine este masculul dominant. Ei, am semne cÄƒ tot aÅŸa e pÃ¢nÄƒ astÄƒzi, penâ€™cÄƒ unde se reunesc mai mulÅ£i bÄƒrbaÅ£i, nu dureazÄƒ mult pÃ¢nÄƒ sÄƒ-ÅŸi arate muÅŸchii ÅŸi sÄƒ auzi despre faptele lor de â€œarmeâ€ printre fomei, despre cÃ¢tÄƒ adulaÅ£iune au primit productoarele lor de plÄƒcere, despre cÃ¢t Ã®s de bÄƒrbaÅ£i faini eiâ€¦no! :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10292,867,'Ionut','ion@yahoo.com','','89.34.225.25','2007-12-19 14:04:08','2007-12-19 12:04:08','Zici ca-i Sean Connery',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(10293,906,'innuennda','innuenda.innuenda@gmail.ro','http://360.yahoo.com/innuennda','92.80.43.69','2007-12-19 14:18:56','2007-12-19 12:18:56','Spune-i lu\' colegu ca p\'asta cu samponu\' trei intr-unu\' (doamne in societate, bucatarese in bucatarie si curve in pat), din gama pentru par (nu pÄƒr) subtire o mai cumpara numa aia de-s la primele lor polutii nocturne.\r\nBarbatii adevarati au gasit deja femeile adevarate si, de aceea, trateaza cu respect subiectul.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10295,895,'Lexis','g_lexis2005@yahoo.com','http://www.alexandraghitalexis.blogspot.com','89.38.76.46','2007-12-19 14:41:03','2007-12-19 12:41:03','600? da\' de max 60 ai mei ce mai zici? :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10297,895,'Brigitte','','','78.96.84.16','2007-12-19 15:01:50','2007-12-19 13:01:50','mai gro\' draga tu de fapt cautai sa mi te flatuleze lumea huh? rusinica..testezi omuletii astia .. te ceteste populatia mioritica ca esti de belea..aberatiuni la scara maaare',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 2.0.50727)','',0,0),(10304,906,'L3ST','webmaster@l3st.com','http://www.l3st.com/','89.34.247.119','2007-12-19 16:20:51','2007-12-19 14:20:51','Hahahaha OWNAGE!! :)))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10306,908,'Mih_nea','mihnea_xxyahoo.com','','62.217.236.12','2007-12-19 16:47:29','2007-12-19 14:47:29','corect, dar provoaca boli diferite',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(10308,908,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-12-19 16:58:41','2007-12-19 14:58:41','Corect, is doo feluri diferite de curvistenie!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10309,907,'Cris','crismocanu@gmail.com','http://mydaysmymind.blogspot.com','82.76.6.241','2007-12-19 17:10:23','2007-12-19 15:10:23','Incredibil cat iti poate umbla imaginatia aia...',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1)','',0,0),(10311,908,'innuennda','innuenda.innuenda@gmail.ro','http://360.yahoo.com/innuennda','92.80.43.69','2007-12-19 17:15:37','2007-12-19 15:15:37','Da. Ar mai fi si alte asemanari:\r\n- ambele categorii lucreaza mult cu gura\r\n- au zilnic numeroase contacte cu clientii \r\n- ambele categorii sunt dispuse sa te rezolve cat mai repede posibil, desi ambelor categorii li se rupe, de fapt, de tine\r\n- ambele meserii sunt practicate mai ales de tineri (desi curvele batrane nu vor sa priceapa asta si pace!)...etc...etc',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10312,907,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-12-19 17:15:51','2007-12-19 15:15:51','...murdara imaginatie, BTW,, ca sa imi permit ca sa te complectesc!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10314,908,'mihai ursu','agentimperialist@yahoo.com','http://mihaiursu.wordpress.com','83.166.206.107','2007-12-19 17:19:30','2007-12-19 15:19:30','draga Groparule, aici trebuie sa remarc, cu profunda mihnire, ca, spre deosebire de companiile de telefonie mobila, curvele nu taxeaza la secunda dupa primul minut.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(10315,908,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-12-19 17:22:03','2007-12-19 15:22:03','@ innuennda: mai da-neeeee!!!\r\n\r\n@ mihaitza: man, deci depinde cat te tzine :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10318,908,'Tavi','nessajab4@yahoo.com','','194.99.245.11','2007-12-19 17:43:15','2007-12-19 15:43:15',':) Cand citesc ce scrii tu acilea imi aduc aminte de o vorba tare faina...\r\n\"Eu nu sufar de nebunie...eu ma bucur de ea in fiecare minut.\"',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10320,907,'eye-contact','chania22@gmail.com','http://pure-eyecontact.blogspot.com','86.121.72.141','2007-12-19 18:10:35','2007-12-19 16:10:35','da nu mai bine nu mergi deloc cu taxiul?\r\nsi-apoi, ce e asa de gretos la 3 stropi de pisu? exista lucruri muuuuuuuuult mai neplacute pe care poti sa le bagi in gura!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10322,907,'WhiteWolf','contact@white-wolf.ro','http://white-wolf.ro','89.39.82.86','2007-12-19 18:21:30','2007-12-19 16:21:30','Asadar, se incheie si 2007 si tot nu ti-ai luat carnetul; da ? :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10323,908,'Usim','mihaimitan@gmail.com','','87.237.108.33','2007-12-19 18:28:27','2007-12-19 16:28:27','Innuennda rulez, frat..sorry, soro!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; .NET CLR 2.0.50727)','',0,0),(10328,907,'L3ST','webmaster@l3st.com','http://www.l3st.com/','89.34.247.119','2007-12-19 19:17:57','2007-12-19 17:17:57','Omule ma faci sa comentez la fiecare post. Chiar asa ?! Deci lol.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10330,895,'traffik','','','86.123.161.54','2007-12-19 19:43:50','2007-12-19 17:43:50','Daca am intrat de 2 ori (din greseala) se contorizeaza 2 oameni? Dar daca in timp ce eu citesc ceva interesanta pe blogul tau o chem si pe Violeta \"Hai fa Violeto sa vezi ci zice asta!\" se contorizeaza 2 oameni? Dar daca eu citec cu un ton ridicat la toate vacile masculine si feminine din birou, se contorizeaza 4 oameni?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10336,906,'mirra','','','83.103.137.234','2007-12-19 20:55:36','2007-12-19 18:55:36','nashpa!:))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10339,907,'July','jullya24@yahoo.com','','89.123.201.80','2007-12-19 21:50:49','2007-12-19 19:50:49','no, apai...azi a fost ultima zi cand am folosit taxi-ul...mersi fain, caci ute\' asa ma faci sa ma mentin intr-o forma atletica!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(10343,908,'manole','redtailanda@yahoo.com','http://www.mesterulmanole.wordpress.com','89.32.123.108','2007-12-19 22:07:51','2007-12-19 20:07:51','si ar mai fi, cablul de tv-eu, interneti tot ase cu prepay, nu ase?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(10399,909,'mirra','','','83.103.137.234','2007-12-20 09:22:55','2007-12-20 07:22:55','asa ar fi corect,dar...ce-i corect in tara asta?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10400,908,'mirra','','','83.103.137.234','2007-12-20 09:24:06','2007-12-20 07:24:06','@innuenda: Esti faina!:)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10348,907,'vizionarul','alinmiron_19@yahoo.com','http://vizionarul.wordpress.com','89.35.87.15','2007-12-19 23:02:27','2007-12-19 21:02:27','vezi gropare, io d-aia le dau bani ficsi la tacsimetristi...:P',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648)','',0,0),(10349,895,'Bubu','bubu@yahoo.com','','88.161.114.233','2007-12-19 23:11:49','2007-12-19 21:11:49','ete nah, fa si tu un efort si promoveaza-ti entry-urile, mai baga un link la ghidoo, agregatoare',0,'1','Opera/9.23 (Windows NT 5.1; U; fr)','',0,0),(10350,908,'vizionarul','alinmiron_19@yahoo.com','http://vizionarul.wordpress.com','89.35.87.15','2007-12-19 23:14:35','2007-12-19 21:14:35','sa nu-i uitam pe popi... care sub pretextu ca vin sa ne boteze in fiecare an, ne taxeaza prepay pentru urmatoru\'',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648)','',0,0),(10354,907,'baghy','baghy83@lycos.it','http://baghy.info/','78.12.17.109','2007-12-19 23:56:11','2007-12-19 21:56:11',':)))) la inceput am crezut ca nu primesti rest din cauza ca te stiu cu bani. dupa am realizat toata gandirea',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(10355,909,'baghy','baghy83@lycos.it','http://baghy.info/','78.12.17.109','2007-12-19 23:56:26','2007-12-19 21:56:26','eu zic sa nu mai dam nimic inapoi',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(10406,903,'BÃ©ranger','info@beranger.org','http://beranger.org','86.35.80.10','2007-12-20 10:12:25','2007-12-20 08:12:25','Bai labagiilor, voi stiti ce este acela un HOAX, ce e aia o legenda urbana, si cum se numesc aia de pun botul la orice cacat de asa-zis studiu care NU A APARUT NICIODATA in \"prestigioasa bla-bla\"?\r\n\r\nhttp://www.snopes.com/humor/iftrue/breasts.asp',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10359,909,'Usim','mihaimitan@gmail.com','','195.189.142.182','2007-12-20 00:38:33','2007-12-19 22:38:33','Ar trebui',0,'1','Opera/9.50 (J2ME/MIDP; Opera Mini/4.0.9751/209; U; en)','',0,0),(10409,909,'manole','redtailanda@yahoo.com','http://www.mesterulmanole.wordpress.com','81.181.92.157','2007-12-20 10:31:40','2007-12-20 08:31:40','poate ca traim in romanica? si poate ca ea tot mai e in perioada de tranzitie? da\' de comisionul de returnare  al sumei integrale,inainte de termen, ce zici?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows 98)','',0,0),(10412,903,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-12-20 10:56:45','2007-12-20 08:56:45','Deci ba Beranger, \'ai proz esti! \r\n\r\nDeci te invit sa te uiti la cururi de ingineri din puscarie, boulangeriule, daca asta-ti face mai mare placere. Vezi ca L3st o scris deja despre hoaxul asta (al saptelea comentariu), si daca ai fi avut rapdare sa cetesti comentariile comentatorilor si nu te-ai fi lansat ca musca-n cacat sa te dai mai grande ti-ai fi dat seama ca nu e cazu sa mai deschizi pliscu. Io numa atata stiu: ca atatea endorfine se scapa-n vinele mele cand vaz un decolteu frumos, ca nij nu e nevoie ca chestia asta sa fie documentata stiintific! Da\' daca tu stii mai bine, be my guest si nu-mi mai scadea media IQ-ului vizitatorilor mei pe sait. Uite, iti dedic si o poezioarÄƒ: <strong>OK, you stay away</strong>!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10414,903,'nicu','nicbendea@yahoo.com','','89.33.41.114','2007-12-20 11:38:36','2007-12-20 09:38:36','de la ce distanta trebe privitii sanii?',0,'1','Opera/9.02 (Windows NT 5.1; U; en)','',0,0),(10423,907,'marisilvla','marisa.flutursh@yahoo.com','http://www.viatzadescolar.wordpress.com','84.232.212.209','2007-12-20 13:23:20','2007-12-20 11:23:20','O sa ajungi sa ne ingropi de atata ras:)) =))',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(10446,911,'Arhi','admin@arhiblog.com','http://www.arhiblog.com','82.77.85.193','2007-12-20 16:48:50','2007-12-20 14:48:50','urasc sa fiu tocmai eu cel ce iti demoleaza mitul, dar erectia de dimineata se datoreaza unei chestii numite apoxie. ceva cu lipsa de oxigen prin zona si acumularea de sange.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; ro; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10429,909,'zone-ro','zone-ro@google.com','http://zone-ro.blogspot.com/','89.33.174.237','2007-12-20 14:26:32','2007-12-20 12:26:32','http://zone-ro.blogspot.com/\r\n\r\nmereu se vor lua taxe si comisioane la banci, dar macar sa stii pt ce dai anumiti bani si de ce. dar la noi nici macar atat. nu mai zic de faptul ca ar trebui sa fii anuntat inainte sa ti se ia ceva',0,'1','Opera/9.23 (Windows NT 5.2; U; en)','',0,0),(10430,907,'zone-ro','zone-ro@google.com','http://zone-ro.blogspot.com/','89.33.174.237','2007-12-20 14:29:34','2007-12-20 12:29:34','http://zone-ro.blogspot.com/\r\n\r\nprimesti rest insa doar daca restul tau e mai mare de 1 leu nou. daca nu ai de primit mai mult  de atat , atunci nu insista sa ti se dea rest pt ca iti vor spune ca nu au. DAR, daca taximetristul lucreaza la o firma , poti suna la dispecerat si daca ii faci plangere cei de la firma il pot suspenda sau chiar da afara, si cel putin 1 saptamana nu mai potate lucra in calitate de taximetrist. Ei cred ca noi nu stiu de lucrurile astea dar daca ai vrea sa ii freci o poti face ca nimeni nu se uita la un taximetrist ca si asa ca is prea multi :D\r\n\r\nhttp://zone-ro.blogspot.com/',0,'1','Opera/9.23 (Windows NT 5.2; U; en)','',0,0),(10443,911,'catalin','solo@xsolo.biz','http://xsolo.biz','190.17.92.168','2007-12-20 16:26:46','2007-12-20 14:26:46','oi tio, esti dement frate! in sensul bun al cuvintului! nu stiu de unde scoti textele astea. criminale!!!!! =))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10441,911,'Tavi','nessajab4@yahoo.com','','194.99.245.11','2007-12-20 16:11:12','2007-12-20 14:11:12','Atata timp cat anaconda e voioasa tat e bine... sa vezi atunci cand nu mai da semne de viata atunci ii bai mare de tat...\r\nSi asa ca si o cujetare profunda...\r\nDe ce puarta soldatii kamikaze casca daca tat mereu sa moara????',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10438,911,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2007-12-20 15:45:04','2007-12-20 13:45:04','Man, deci depinde cine e la celalalt capat al anacondei! Nu la capatu\' cu femeile, la celalalt capat :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10433,907,'Paszti','pasztorjozsef@yahoo.com','','81.12.230.166','2007-12-20 15:06:34','2007-12-20 13:06:34','Tot despre rest... deja asteptam sa vad ce sa faca farmacista ca nu avea guma de mestecat la vanzare ... mi-o dat Algocalmin! Bine ca nu mi-o dat pilula de dupa, ca de f*** m-o f***',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727)','',0,0),(10434,911,'sabina','','','81.12.163.178','2007-12-20 15:11:58','2007-12-20 13:11:58','=))',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648)','',0,0),(10488,914,'justlikethat','ngabyn@gmail.com','http://justlikenow.blogspot.com','92.80.165.85','2007-12-21 00:07:34','2007-12-20 22:07:34','dap .. cand faci asta esti cam spammer .. parerea mea :)\r\n...acuma nu pot sa pretind ca oricine la care am sa comentez ar sa ma citeasca :), nici tu nu faci asta macar :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10884,915,'ss','criss_team@yahoo.com','','89.32.145.164','2007-12-24 15:19:00','2007-12-24 13:19:00','sarbautori fericite tuturor!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7','',0,0),(10872,915,'nana','razornana@yahoo.com','','86.34.163.6','2007-12-24 11:45:48','2007-12-24 09:45:48','Sarbatori fericite si la mai multe bloguri :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10874,916,'O gajica','peculiarme@gmail.com','http://peculiarme.wordpress.com','79.115.8.91','2007-12-24 12:02:20','2007-12-24 10:02:20','Mi-a fost dat sa aud: Ti-l luasem de ziua ta, dar cum nu ne-am vazut atunci, ti-l dau de Craciun.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10444,911,'george','reallyinsane@gmail.com','','193.138.195.202','2007-12-20 16:28:29','2007-12-20 14:28:29','Deci man, depinde si de posesorul anacondei sa-si hraneasca femeia doar cu antricot de dinozaur fara colesterol ca sa nu aive oaresce greturi matinale, banuiesc.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10437,911,'george','reallyinsane@gmail.com','','193.138.195.202','2007-12-20 15:40:33','2007-12-20 13:40:33','Jos palarioara pentru argumentatie!\r\nDoar ca intre timp fomeile par sa-si petreaca diminetile dereticand prin pesteri si infigand toace in obraza adversarei, altfel nu-mi esplic de ce raman saracele anaconde sa se epuizeze singure prin chiloti...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10771,912,'Dincolo de stiri','adrian.tone@mediafax.ro','http://www.mediafax.ro/blog/general/la-majorat/','86.120.236.133','2007-12-23 10:21:28','2007-12-23 08:21:28','Nu voiam sa scriu despre Revolutie, dar din acelasi spirit care ne-a facut dupa 18 ani sa socializam pe blog si nu la carciuma sau la biblioteca, il copiez pe gropar cu ale lui povestiri din Sighii. Care si el la randul lui copie pe Mile din Timisoara. Si uite asa, in toata tara. Deci, din Bucuresti...',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727)','',0,0),(10777,911,'.org','jinx.steph@google.com','','79.112.103.10','2007-12-23 11:57:18','2007-12-23 09:57:18','and so, the mystery of the Morning Wood got revealed :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10645,912,'zulea','zulea1@gmail.com','','89.137.121.165','2007-12-22 04:29:00','2007-12-22 02:29:00','Gropare, pe sor\'ta o cheama Dana cumva? Si a terminat la Scoala Generala 21 din Sibiu?\r\nDaca zici DA, ai castigat 400 beri + pescuit in Delta cu mulinete Daiwa la crap cu cazare, mancare si +400 beri pe puntea barcii. PE BUNEEE',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(11368,860,'Ada','ademirgian@gmail.com','http://injoaca.blogspot.com','78.96.206.116','2007-12-29 19:30:14','2007-12-29 17:30:14','Meserias cumnat. Pana la urma a gatit pestele ala au ba?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10661,915,'mirra','','','83.103.137.234','2007-12-22 08:09:42','2007-12-22 06:09:42','Sa-ti deie Domnul, numai bine,sanatate,femei frumoase,si impliniri pe toate planurile!Sarbatori fericite,prietene!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10663,916,'mirra','','','83.103.137.234','2007-12-22 08:12:31','2007-12-22 06:12:31','cadoul pe care ti l-am cumparat de Craciun,stiu sigur ca nu-ti place.:)))\r\nP.S.eu am folosit replica asta!:)))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10669,916,'Ureche Mare','','http://www.ju-jutsu.ro','82.79.191.160','2007-12-22 09:39:20','2007-12-22 07:39:20','Vara fierbinte. Intr-o (sau intro) statie de autobuz asteptam un coleg de serviciu (vesnicul coleg intarziat) care nu mai venea. Langa mine o fata frumusica. Mi-a atras atentia pentru ca se uita insistent la ceas. Dupa 20 de minute apare un tip. Genul cu plete si cu tricou inscriptionat \"Korn\". Frumusica sare la gatul lui si trage un ditamai pupoiu. El se da un pas inapoi, ii arata tricoul si ii spune: Iti place ce tricou mi-am cumparat de ziua ta?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(10747,916,'eu,Miruna','mirunavasilescu@yahoo.com','http://potsafacsiasaceva.blogspot.com/','86.106.59.163','2007-12-23 03:51:12','2007-12-23 01:51:12','Chestie pe care  o practic frecvent, fara cea mai mica jena: \"Poftim, ti-am luat cartea asta de Craciun, sper sa-ti placa. Asa-i ca mi-o dai si mie s-o citesc inainte sa te apuci tu de ea?\"',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10685,893,'Dana','ndbucur@yahoo.com','','89.165.133.13','2007-12-22 14:02:07','2007-12-22 12:02:07','Cand s-or lauda fumeile cu nevastuicile mai stramte dimineata decat seara, asa cum fac domnii cu erectiile matinale, s-or inventa si medicamente sa le rezolve problema.. :)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; IEMB3; InfoPath.2; .NET CLR 1.1.4322; .NET CLR 3.0.04506.30; IEMB3)','',0,0),(10741,912,'','','','79.113.152.78','2007-12-23 02:39:35','2007-12-23 00:39:35','Spre deosebire de tine, gropare, la ora aia eram si atunci manasturean. Mama urma sa mearga la serviciu, si ea fiind asistenta medicala. \r\nTaica-meu care fusa sa repare ceva la camburator pe la masina, vorba aia cu 2-3 vecini (la o dacie tot tipul sar 2-3 sa te ajute) se baga in casa si zice grava maica-mii:\r\n-Tu, vine Cucu!\r\nAmu doctoru Cucu era ceva sef pe la spital la mama si nu ne onorase cu vizita niciodata. Mama se repede urgent, intra in baie si striga de-acolo: ce-i trebe? Spune-i ca nu-s acasa!\r\nApoi, tata:\r\n-Nu Cucu, tu! CUG-ul!\r\nEu n-am priceput pe loc. In casa s-a facut liniste.\r\nMai tarziu am ascultat demonstrantii: coloana de muncitori de la platforma CUG ajunsesera pe Mehedinti. Strigate. Mai tarziu s-au auzit si impuscaturi.\r\nTata a pus iar radioul VEF pe calorifer si a cautat Europa Libera. Nu mergea. A vrut sa plece si tata. Stiu ca plangeam si il trageam de maneca sa nu iasa din casa. S-a scuturat si a zis ca nu iasa numa\' pana in fata blocului.Noroc ca s-a tinut de cuvant.\r\nVreo doua zile ne-am ferit sa trecem pe langa ferestre ca auzisem de unii care fusesera impuscati prin geam.\r\nApoi a mers Europa Libera. Se numarau victime, se numarau eroi. Nu mai stiu la cate zile a mers mama la lucru dar povestea de un tanar soldat in termen cu ambele picioare amputate care povestea:\r\n-Tanti, eram in centru la Fabrica de Bere. Era noapte, nu vedeam nimic. Am auzit o mitraliera \"trr-trr-trr\". Apoi am simitit ceva cald la picioare. Am scos si eu mitralera si am facut \"trr-trr-trr\". Nu stiu daca l-am impuscat ca m-am trezit aici.\r\n\r\nAsa am vazut eu revolutia.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10719,907,'Ana','aceeasi_ana@yahoo.com','http://www.anaayana.wordpress.com','92.80.177.87','2007-12-22 20:55:58','2007-12-22 18:55:58','Asta mi-a adus aminte de bancul ala cu iepurasul care vroia sa imprumute o cratita de la urs :)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(10731,912,'zulea','zulea1@gmail.com','','89.137.121.165','2007-12-23 00:16:41','2007-12-22 22:16:41','@ Groparu: Berea-i pregatita, zi doar unde trebe trimisa, livrata, ... cu pestii si Delta, asteptam ghioceii, ca barca mea e de fibra, nu-i spargator de ghetza rusesc, si nici nu am sobe de teracota pe barca ...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10737,916,'cuierul de bere al groparului','soredarkshines@gmail.com','http://aniakhaki.blogspot.com/','89.123.114.89','2007-12-23 02:00:06','2007-12-23 00:00:06','4 lei? nu e cam mult? :)) un leu eu zic ca ajunge la anumite persoane :&gt;',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10818,914,'zone-ro','zone-ro@gmail.com','http://zone-ro.blogspot.com','89.41.54.98','2007-12-23 20:37:59','2007-12-23 18:37:59','is de acord cu Hurri, ca e misto sa se certe lumea pe bloguri. si mie chiar imi place cearta. cat desprepovestile lacrimogene te invit sa urmareste emisiuni tv, eu aici am zis ce aveam de zis. iar la faza cu seralul va rog pliscul mai mic, cand o sa ai cata scoala am eu, adica 12 clase+ 6 an ide faculta (arhitectura)+2 master mai vb pana atunci jet. ii las pe academicienii de pe bloguri sa se exprime frumos, eu is adept Rem Koolhaas si imi place uratul, deci nu va asteptati la ceva frumos din partea mea :D .\r\n\r\nGroparule inca mai astept replica ta. :D\r\n\r\nps. toti astia care ati terminat ase-ul sau mai stiu eu ce faculta fantoma va rog corectati-ma in continuare in legatura cu gramatica si cu exprimarea. fara voi nush ce m-as face. ntzntzntz',0,'1','Opera/9.21 (Windows NT 5.2; U; en)','',0,0),(10788,914,'zone-ro','zone-ro@gmail.com','http://zone-ro.blogspot.com','89.41.54.98','2007-12-23 15:06:47','2007-12-23 13:06:47','Nenea Groparu`,\r\n\r\nMs pt faza asta, desi nu trebuia ca puteam sa continui eu ce am incept. Recunosc ca poate nu e frumos ceea ce am facut si am exagerat un pic, deci imi recunosc vina. Eu iti zic asa : nu o sa se mai intample faze de astea pt ca nu e fair play. Daaaaaaaar, de la faza asta si pana la commenturi gen L3st e cale luunnnga fratele meu. E foarte usor sa zic si eu ca imi bag p.u.l.a in capul lui de idiot, cat despre stats-uri ca zicea cineva ceva, ii zic asa: esti un prost ca daca te uitao in source vedea ca e analytics-ul ce pu.la mea esti chior? iar tu nenea Liviuuuuuuuu se pare ca si numele tau apare pe toate gardurile chiar vrei sa te tina minte bine lumea ca iti adaugi atatia de uuuuuuu :) imi aduci aminte de fazele alea de la galeriile de fotbal cand toti stiga : uuuuuuuuuuuuuuuuu si la urma , sugi pu.la :D\r\n\r\nDeci in concluzie , astia cu commenturi de lingatori ar fi bine sa se abtina ca daca va iau la bani marunti nu sunteti asa de brezi.\r\nNenea Groparu` tu ce sa zic? ai dreptate in felul tau cu toate ca daca erau commenturi cu linkul meu nush unde era problema? iti statea ceva in gat? pana la urma te plangeai zilele astea ca nu ai traffic. pai bucura-te tata ca mai contribui si eu cu putin traffic (stiu ca te poti lipsi de vizita mea ) dar pana la urma revin la intrebarea : chiar te deranja ce puneam eu pe la commenturi? hmm ok. pai daca e asa de naspa sterge si postul ala cu zone-ro si sterge-mi toate commenturile ca sa uitam problema asta.',0,'1','Opera/9.21 (Windows NT 5.2; U; en)','',0,0),(10714,912,'oedip','oedip74@gmail.com','http://oedip.blogspot.com','89.137.99.163','2007-12-22 20:31:25','2007-12-22 18:31:25','ba groapa, unde e partea principala a postului, la inceput sau la sfarsit???\r\n:))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10790,895,'Emaginatoru','','','79.113.152.200','2007-12-23 15:29:37','2007-12-23 13:29:37','Gro, is numa v-o tri sute care tat nu pricep si reiau lectura. Sau nu gata az un articol si il continua maine. Ia si io ce de litere am scris!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10791,914,'zone-ro','zone-ro@gmail.com','http://zone-ro.blogspot.com','89.41.54.98','2007-12-23 15:40:50','2007-12-23 13:40:50','si mai adaug ceva groparule,\r\n\r\ndaca era vreo problema puteai pur si simplu sa zici: ma zone-ro opreste-te ca deja e prea mult, nu sa incepi cu teorii de astea si cu faze de parca ai fi nush ce martir. INCA O DATA, recunosc ca nu a fost bine ce am facut si nu e politicos asa, dar nu is eu nici primul nici ultimul care face de astea pe aici sau prin alte parti. ti-am scris si mai sus, stege tot ce contine zone-ro si cu asta basta ca sa nu mai fie scandal si eu daca vrei iti promit ca nici macar nu mai intru pe blog aici daca e asa mare problema. imi pare rau ca nu am vazut asta acu 2 zile sau cand l-ai postat ca poate mai erau si alte chestii de zis.',0,'1','Opera/9.21 (Windows NT 5.2; U; en)','',0,0),(10798,916,'Gavrus Bogdan','gav_ezowerar@yahoo.com','http://gavrusphoto.blogspot.com/','89.36.245.163','2007-12-23 16:59:59','2007-12-23 14:59:59','3,5,7 si 10 le-am folosit, nu chiar mot a mot dar pe-acolo oricum',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10802,914,'OLiX','oliver.simionescu@gmail.com','http://olixbolix.blogspot.com','86.106.0.184','2007-12-23 17:46:30','2007-12-23 15:46:30','hahah :)) s-a ofticat zone-ro. ofticosuleee !! huooo !!\r\n\r\neu am zis ca probabil sunt invizibile statisticile tale si aici am avut dreptate, adica nu apar pe site.\r\n\r\nin loc sa-i multumesti lui Groparu ca te-a bagat in seama si ti-a facut trafic, te apuci tu sa injuri, samd.\r\n\r\nNu-i frumos ce faci.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10803,914,'L3ST','webmaster@l3st.com','http://www.l3st.com/','89.34.247.119','2007-12-23 17:48:46','2007-12-23 15:48:46','Imi plac astia care scriu povesti lacrimogene lungi si plictisitoare. Noroc ca exista seralul, mai are o sansa tipul.\r\n\r\nLegea bunului simt spune ca nu tre\' sa-ti marchezi teritoriul pe oriunde treci, cum fac cainii. Acu\' o sa zici ca analogia e complexa dar valoarea blogului tau e cam egala cu materialul de marcaj si limbajul tau de tirist evoca cele 4 clase care ti-ar putea acorda cele 4 clase primare.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10804,914,'L3ST','webmaster@l3st.com','http://www.l3st.com/','89.34.247.119','2007-12-23 17:50:45','2007-12-23 15:50:45','*limbajul tau de tirist ti-ar putea acorda cele 4 clase primare. \r\nNa, ca de emotie ma si balbai.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10808,914,'Hurri','virtual_hurricane@yahoo.com','http://hurri23.wordpress.com','89.137.58.105','2007-12-23 18:49:30','2007-12-23 16:49:30','ce fain e cand se cearta lumea in comentariile blogului tau.uneori e mai fain decat blogul insusi.nu e cazul tau,desigur. :)',0,'1','Opera/9.24 (Windows NT 5.1; U; en)','',0,0),(10698,912,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.123.76.40','2007-12-22 16:59:43','2007-12-22 14:59:43','Henzulea, tu ej, mah???\r\n\r\nPregateste bereaaaaaa, pestii si Delta... ca mi-i o seteeee, ca o sa beu cat Dunarea, mah!!!! :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10699,912,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.123.76.40','2007-12-22 17:02:15','2007-12-22 15:02:15','@ Lupulainu: deci ne potolim, da? :) intr-adevar, is intr-o pauza de folosire a ratiunii, da\' asta dureaza de mai mult anisori. Chiar mai multi. Apropos, daca ej prin Sibiu amu, de sarbatori, da un buzzulache! Daca mai ai nr meu. Vreau sa hranesc un lup din codru cu neshte supa de hamei :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10702,914,'nimeni','nimeni@nimeni.com','','79.118.5.42','2007-12-22 17:37:04','2007-12-22 15:37:04','Akismet - Report as Spam? :D',0,'1','Opera/9.23 (Windows NT 5.1; U; en)','',0,0),(10710,916,'Tavi','nessajab4@yahoo.com','','194.99.245.11','2007-12-22 19:32:28','2007-12-22 17:32:28','-Ie-l tu ca io m-am plictisit de el si oricum nu mere bine ( sau pere sau prune ) bine...(io cata fosta gajaca...oare de aia m-o fi lasat????)\r\n- UAIIII e Craciunu\' am uitat complect...scuze ca tz-am luat numa nimic.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(10712,912,'Aya','ayatristan@yahoo.com','','92.80.32.229','2007-12-22 20:13:41','2007-12-22 18:13:41','COMENTARIU STERS DE ADMIN, CARE, DE FAPT, E PUIUL UNEI DOAMNE.\r\n\r\naya, ce treaba are adminu si postarea asta cu politichia si scindarea PSD-ului?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Hotbar 10.0.368.0)','',0,0),(11881,918,'Alex','emeric_bleier@yahoo.com','','89.43.103.44','2008-01-07 21:50:36','2008-01-07 19:50:36','Gropare, vreau si eu pozele de la revel. Alex TM',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; .NET CLR 1.1.4322; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648)','',0,0),(11848,918,'mumuland','','','80.97.64.199','2008-01-07 11:55:44','2008-01-07 09:55:44','ghici cine s-a intors ?....nu bug mafia ma ....ce naiba....La multi ani ! si sa ai parte de pamant cat mai afanat anu asta ma...ce harletu tau :))\r\n\r\n\r\niz io ma.care io?  asta :  ;)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12','',0,0),(11212,915,'Sweeper','ak70g2@gmail.com','','86.107.192.53','2007-12-27 16:47:55','2007-12-27 14:47:55','Gropare, Sarba(u)tori fericita si sa te citesc si\'n 2008 la fel de des! Take care of MKT for me, will ya? :pppp',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; .NET CLR 2.0.50727)','',0,0),(11203,912,'mo','verde_poveste@yahoo.com','','194.126.220.20','2007-12-27 15:09:44','2007-12-27 13:09:44','Nush de ce naiba simt nevoia sa impartasesc treaba asta, dar vreau sa povestesc si eu vagile mele amintiri despre \'89. Aveam sase ani, vad si acum imagini ca prin vis cu mutre ingrijorate, cu mama care isi frangea mainile uitandu-se la televizor, imaginea unui brad impodobit, dar agresiv si lipsit de orice farmec in lumina zilei, unu\' cu mutra de chinez si pulovar tricotat le tv (dinescu), procese, acuzatii, un film destul de monoton care se termina cu impuscarea a doi batranei si mai ales senzatia chinuitoare pe care am incercat-o ceva mai tarziu cand intr-o seara am vazut desene animate timp de o ora si jumatate, anticipand cu groaza intreruperea povestirii din minut in minut... Privind retrospectiv, am senzatia ca si adultii urmareau evenimentele derulandu-se la fel ca mine desenul ala animat - fara bucurie si cu nervii intinsi la maximum, ca si cum nu erau convinsi ca merita ceea ce se intampla.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1)','',0,0),(11838,912,'Mih_nea','mihnea_xxyahoo.com','','62.217.236.12','2008-01-07 09:13:05','2008-01-07 07:13:05','frumoasa \"revolutie\" la Sibiu... un sfert din morti militieni, mari \"teroristi\", si dupa aia colegii lor au stat cu saptamanile in bazinul unitatii aleia... printre ei si unchiul meu de altfel, nevinovat, dar caruia nu i-a cerut nimeni scuze c-a facut degeaba parnaie',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(11191,914,'Killer b','giuflex_titan@yahoo.com','http://blog.360.yahoo.com/blog-npc7SgE2crPieuhtFEc9JFjLjHOr','79.114.167.32','2007-12-27 12:49:46','2007-12-27 10:49:46','http://zone-ro.blogspot.com\r\nDa, e foarte frumos cand se cearta lumea pe blogul altuia, insa este si mai frumos cand sufoci blogul cuiva cu spam (tu avand un blog alcatuit in mare parte din linkuri pe youtube...that\'s not a blog man http://zone-ro.blogspot.com).\r\n\r\nCulmea frumusetii este cand te si lauzi ca ai 12 ani de scoala si 6 de facultate+2 de master si vorbesti mai prost limba romana decat Vanghelie/Jijinio. Eu \"te invit sa urmareste\" cartile de gramatica a limbii romane. In caz ca nu ti-a spus nimeni pana acum chestia asta, la ASE nu se face gramatica.\r\n\r\nhttp://zone-ro.blogspot.com\r\n\r\n\r\nPS: Daca vrei sa te lauzi cu o facultate grea, incearca una tehnica gen automatica/telecomunicatii/cibernetica/cfdp/civile/INSTALATII (sau altele) insa nu arhitectura, care este o apa de ploaie in ceea ce priveste gradul de dificultate.\r\n\r\nhttp://zone-ro.blogspot.com',0,'1','Opera/9.25 (Windows NT 5.1; U; en)','',0,0),(11181,58,'Bruno','','http://groups.google.com/group/jamiso/web/handjob-facial','195.225.177.190','2007-12-27 10:31:02','2007-12-27 08:31:02','<strong>handjob facial...</strong>\n\nWhile Everyday Mommy is saying goodbye, Everyday Design\n...',0,'1','USERAGENT','trackback',0,0),(11805,918,'Usim','mihaimitan@gmail.com','','86.121.181.32','2008-01-06 23:07:01','2008-01-06 21:07:01','De nada, hombre, mai plejar indid. Giast duing mai giob, rili.\r\nSi da tot cu srevetele de bebe. Dar nu scuiparam in fantana ca ne-a fost lene si nu am ajuns pana acolo. Da rotocoale s-au facut in creierasi. Noi am pornit voiniceste intr-o excursie dar, ne-am impiedicat in niste tuici fierte in sat la oameni. Oameni care n-aveau alt scop de sarbatori decat sa te ia de pe strada si sa te cinsteasca. Si se suparau daca nu. Noroc ca am ficatul mare.',0,'1','Opera/9.10 (Windows NT 5.1; U; en)','',0,0),(11124,852,'Radu','','','82.79.81.135','2007-12-26 22:23:57','2007-12-26 20:23:57','invata sa scrii ba incultule \"or\" \"i-o\"',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; FunWebProducts)','',0,0),(11791,918,'mirra','','','83.103.137.234','2008-01-06 07:39:06','2008-01-06 05:39:06','La multi ani! si bine ai revenit! ti-am dus dorul,prietene!!! :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(11793,698,'','','','89.122.150.105','2008-01-06 15:01:19','2008-01-06 13:01:19','daca te-ar auzi tliscanii te-ar papa ;((',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; SIMBAR={2D75ACA8-DD80-47E7-842C-82C4F46B8BF7})','',0,0),(11795,35,'n3cr0fila','candu.phwratyahoo','','82.76.176.152','2008-01-06 17:10:32','2008-01-06 15:10:32','ai uitat de vorbele urate aruncate oamenilor care nu le merita,precum si faptul ca ne purtam mai frumos cu strainii decat cu cei din familie pentru ca stim ca strainii ne pot da oricand dracu`....si oricum te dau dracu`,dar culmea,mai degraba tipi la maica`ta decat la colega de serviciu...\r\n Nota 10 de la mine,desi te pisi pe ea.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(11796,916,'n3cr0fila','candu.phwratyahoo','','82.76.176.152','2008-01-06 17:37:29','2008-01-06 15:37:29','Atata timp cat nu`i dai cadoul facut chiar de persoana respectiva cu un an in urma,e ok.Si chiar si asa...gestu` conteaza,in ma`sa de treaba....',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(11797,907,'n3cr0fila','candu.phwratyahoo','','82.76.176.152','2008-01-06 17:42:30','2008-01-06 15:42:30','poti tine banii in chiloti...in partea din fata sau in aia din spate,in asa fel incat sa nu te stanjeneasca.Cand tre` sa platesti,bagi mana si`i scoti...asa sunteti chit....si ca chitul sa fie mai mult de partea ta,ii poti lasa si vreun muc lipit pe vreo bancheta ceva.Nu e mare treaba,dar te simti oricum mai satisfacut si parca greata nu mai e asa de mare.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(11798,895,'n3cr0fila','candu.phwratyahoo','','82.76.176.152','2008-01-06 17:55:10','2008-01-06 15:55:10','Decat sa conduc 1000 de tarani,prefer sa am ca sclavi familia regala.\r\nAcuma pe bune,multimea citeste numai ceea ce e pe intelesul ei.Abordezi si subiecte mai de finete,si multi nu pricep unde bati.Inca ma mai intreb ce naiba le place astora la vis urat...cel mai reusit articol al lui e ala in care ti-a luat interviu....ma rog.Vorba aia...don`t worry,be happy!..oricum murim cu totii...',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(11799,100,'Marin Dan','vbx_wx@yahoo.com','','79.118.11.174','2008-01-06 18:31:40','2008-01-06 16:31:40','ce plm sa te astepti sa la niste ciobani de la cluj,ce poveste de 2 lei,analfabetilro....TREZITIA LA REALITATE wabacilor',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(11800,100,'ksy','vbx_wx@yahoo.com','','79.118.11.174','2008-01-06 18:33:29','2008-01-06 16:33:29','is de acord cu Marin Dan.....tantalai de oameni...poveste ieftina...Fortza dinamo',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(11492,916,'manole','redtailanda@yahoo.com','http://www.mesterulmanole.wordpress.com','89.32.123.108','2007-12-31 12:35:46','2007-12-31 10:35:46','http://mesterulmanole.wordpress.com/2007/12/31/pentru-toti-2/',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(11494,912,'PIT','paula.tiplea@gmail.com','','85.120.75.140','2007-12-31 13:15:58','2007-12-31 11:15:58','Chestia cu blocul am trait-o si eu. Doar ca nu am ajuns si in pivnita, dar au baricadat intrarile si faceau garda cu randul :) Dar ce mi-a ramas cel mai adanc in memorie era cerul, noaptea, brazdat de cartuse. Si vedeam / auzeam undeva in departare elicopeterele, care, se zicea, atunci, bombardau cimitirul, unde chipurile se ascundeau teroristii. La fel, stiu cand ziceau ca pe Milea e plin de cadavre... Oricum eram prea mica si ai mei ma tineau bine inchisa in casa. Cred ca putin inainte de anul nou am iesit o tura pe Milea (tata avea pe atunci o Skoda 1000 MB). Am fost la Sibiu acum de Craciun si am constatat cu stupoare ca blocurile de langa politie inca mai au urmele de gloante, nu le-a reparat nimeni. \r\nA si alta chestie. Stateam in Vasile Aron, chiar la intrarea in Sibiu. Si vedeam multe ... Cel mai socant au fost cand o divizie (cred ca asta e termenul tehnic) de tab-uri venea dinspre brasov... Pt mine a fost o imagine socanta. Mai ales ca unul dintre ele s-a oprit la una din casele care erau in vale si a inceput sa traga... Chipurile acolo erau teroristii.\r\nGrr ma opresc aici ca incep sa imi amintesc si nu vreau. Desi poate nebunia de atunci m-a calit pentru nebunia de azi... cine stie.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.0.7) Gecko/20060909 Firefox/1.5.0.7','',0,0),(11980,925,'c|neva','cineva_df@yahoo.com','http://www.diaconuflorin.ro','78.96.86.55','2008-01-08 20:55:50','2008-01-08 18:55:50','deosebita relatare :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(11774,918,'Usim','mihaimitan@gmail.com','','194.50.7.237','2008-01-05 14:25:04','2008-01-05 12:25:04','La multi ani Gropare! \r\nAm (pe)trecut si eu in conditii similare celor in care v-ati distratara domniile dumneavoatre. Tot cu cabana (din lemn) tot cu paraias si dus cu servetele umede, tot cu buda fara apa si cu sobe pe lemne dar fara lac ci doar cu o mare de zapada si padure. Zapada, bineinteles, si dansa cu scrieri cu cearneala galbina. Si cel mai important cu PRIETENII. La Malaia. De la Brezoi vreo 20 km, in loc sa faci dreapta pe valea Oltului spre Sighie, o iei spre Voineasa. S-apoi din sat pana in varful dealului unde masina nu putu urca si unde descalecaram. De acolo mai poti urca vreo doi kilometri prin padure pana la fantana Bratienilor, daca vrei. Nu c-ar conta ce-am facut eu, doar ase, ca sa stii!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(11772,918,'kosmin','cosmin.popescu30@gmail.com','http://kosmin.net','78.96.32.221','2008-01-05 14:14:31','2008-01-05 12:14:31','Ati pescuit la copca? Ati prins ceva?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(11766,100,'.marius','marius@perijoc.com','http://marius.wirelessisfun.com','89.137.107.129','2008-01-05 09:57:28','2008-01-05 07:57:28','eu inca rad... :)))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(11767,918,'.marius','marius@perijoc.com','http://marius.wirelessisfun.com','89.137.107.129','2008-01-05 10:22:49','2008-01-05 08:22:49','Ah te-ai intors pui de drac! Nuah sa ne vedem cu bine prin generali piacolo ca asara nu ai dat nici un semn',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(11762,918,'Mile','','http://milecarpenisan.wordpress.com/','86.127.182.227','2008-01-05 07:35:56','2008-01-05 05:35:56','@catalin: de ce citesti daca nu te pricepi? blogul e un spatiu virtual(si public) in care un om isi tine jurnalul personal. Maica(e moarta de ceva ani deci mama lu\' bunica lu\' Mile) nu a fost cu noi si ...era la vremea ei o Doamna. Dumnezeu sa o ierte ...si pe tine la fel!',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; SIMBAR={A7F3C004-B2DD-4145-98BD-0344DDF9CD6E}; .NET CLR 2.0.50727)','',0,0),(11782,918,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2008-01-05 19:18:03','2008-01-05 17:18:03','@ catalin: mah, cica la sÃ¢rbi toata famelia e importanta, nu ca la romani, unde (cel putin la mine-n gasca) orice referire la mama e, de cele mai multe ori, oglindirea ireproÅŸabilÄƒ a unui dispreÅ£ suveran!\r\n\r\n@ kosmin: mo, deci atata mi-as fi dorit, da\' am pescuit numa la bax de bere, nu la copca. Am prins somn de 12 ore si c(r)ap greu, a doua zi. Da\' s-o meritat :D\r\n\r\n@ Usim: mo, deci la faza aia cu recuperarea ti-ai castigat decoratiunea de \"Recuperator groparesc cu rang de cavaler\", si ioz sigur ca, daca te-ai distrat de Rev, o fost si multumita rugilor mele de multumire adresate lui Dumnezau, rugi in care TU ocupai rolul premier! (PS: si voi v-ati spalat cu servetele de bebelusi? Si ai scuipat in fantana Bratienilor, ca sa faci rotocoale?)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(11939,925,'WhiteWolf','contact@white-wolf.ro','http://white-wolf.ro','89.39.81.208','2008-01-08 13:06:58','2008-01-08 11:06:58','Greu de gasit, pe intinsul www-ului , Revelion mai complicat decat ce ne insiri ca ai trait tu, omule.\r\nDa\' daca o fo\' fain, io ma bucur pentru tine.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(11941,918,'Hammer','hammer@alpinet.org','http://www.alpontos.wordpress.com','86.120.55.79','2008-01-08 13:11:17','2008-01-08 11:11:17','Puii mei, era un efort prea mare sa nu bateti pancarda aia cu holzsurubu in brad si sa folositi in schimb o ...panglica?:-)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(12799,956,'julius constantinescu','julius@universitateacraiova.ro','http://www.7plus.ro','84.232.161.96','2008-01-18 04:29:12','2008-01-18 02:29:12','Gropare, da\' tu cati ani ai, ma? Ca pari a fi concubin de cursa lunga...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(12815,954,'Hammer','hammer@alpinet.org','http://www.alpontos.wordpress.com','86.120.55.79','2008-01-18 08:36:25','2008-01-18 06:36:25','In toata povestea asta noi luam cel mai putin:-) Suntem depasiti de o multinationala, si nu e nici prima nici ultima. \r\nAnyway, mai bine sa luam putin decat sa dam mult, nu:-D???\r\nAm zis io ca dupa intregarea Romaniei in UE dau doi ani Germaniei sa se ceara afara din UE:-)))(gluma)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(12816,952,'Hammer','hammer@alpinet.org','http://www.alpontos.wordpress.com','86.120.55.79','2008-01-18 08:41:43','2008-01-18 06:41:43','ce rateu fastuos...imi suna cunoscut!!!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(12817,956,'Mih_nea','mihnea_xxyahoo.com','','62.217.236.12','2008-01-18 08:43:39','2008-01-18 06:43:39','e tanar, da-i poet...',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(12818,956,'darius f','darius2u@yahoo.com','http://desprepsd.wordpress.com/','82.79.52.137','2008-01-18 08:54:51','2008-01-18 06:54:51','Isuse, cata profunzime!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(12822,956,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-01-18 09:35:29','2008-01-18 07:35:29','@ Julica: Feeling lonely, honey...? ;;)\r\n\r\n@ Mih_nea: io zic ca-s niciuna. Si eu arareori ma insel - cu exceptia clipelor cand, bine-nteles, nu am dreptate!\r\n\r\n@ Darius: iti dai seama daca m-as apuca sa scriu desprepsd ce-ar iesi?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(11945,925,'c|neva','cineva_df@yahoo.com','http://www.diaconuflorin.ro','78.96.86.55','2008-01-08 14:01:39','2008-01-08 12:01:39','Partz partz...nu te-o intrebat cu ce parfum te-ai dat?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(11949,925,'.marius','marius@perijoc.com','http://marius.wirelessisfun.com','89.33.41.194','2008-01-08 14:41:30','2008-01-08 12:41:30','cerbii cu coarnele maaaaari! \r\n\r\nSi potarnichileeeeeeeeeeeeeeeeee!!!!\r\n\r\nBUM! BANG! RA-TA-TA-TA!!! \r\n\r\nchestia asta e mai misto zisa cu un pic de pantomima... te astept la berea aia ;-)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(11953,918,'sima','','','81.12.163.178','2008-01-08 15:36:17','2008-01-08 13:36:17','Alex TM - si noi vrem poze...',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648)','',0,0),(11972,925,'mirra','','','83.103.137.234','2008-01-08 19:44:48','2008-01-08 17:44:48','daca a fost fain,bravo, si ca orice lucru fain sa nu se piarda,trebe repetat!:)\r\nAm ras cu lacrimi,mersi ca te-ai intors ca tare tz-am simtit lipsa!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(12192,945,'mirra','','','83.103.137.234','2008-01-10 22:07:17','2008-01-10 20:07:17','no coment!:)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(12193,945,'mirra','','','83.103.137.234','2008-01-10 22:07:37','2008-01-10 20:07:37','no comment!:)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(12142,927,'b0gdan','borzel@gmail.com','http://b0gdan.com','92.80.42.234','2008-01-10 09:54:58','2008-01-10 07:54:58','Poplaca???? As in \"Aurul, profetul si ardelenii\" si toata seria aia absolut geniala???',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(12145,927,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-01-10 10:24:24','2008-01-10 08:24:24','As in... EXACT!\r\n\r\nExista, ca am pipait-o si am urlat: EXISTAAAA!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(12147,927,'CÄƒlÄƒ','acalarasu@gmail.com','http://adriancalarasu.wordpress.com/','62.217.241.242','2008-01-10 11:30:29','2008-01-10 09:30:29','Eeh, n-ai pierdut nimica, Sibiu, Cluj, tot aia e...\r\nBa nu, in Cluj cred ca sunt mai putine oi...',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(12150,927,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-01-10 11:49:38','2008-01-10 09:49:38','...de unde sentimentul meu de frustrare!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(12153,927,'manole','redtailanda@yahoo.com','http://www.mesterulmanole.wordpress.com','81.181.92.157','2008-01-10 12:26:35','2008-01-10 10:26:35','Te lepezi de pacate? Te cam lepezi, gropÄƒrele!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows 98)','',0,0),(12155,945,'sima','','','81.12.163.178','2008-01-10 12:52:12','2008-01-10 10:52:12','=))',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648)','',0,0),(12169,927,'baghy','baghy83@lycos.it','http://baghy.info/','78.12.10.16','2008-01-10 15:47:36','2008-01-10 13:47:36','Atat',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(12230,947,'mishu','mishu@doingtheartwork.com','http://www.doingtheartwork.com','82.77.126.254','2008-01-11 09:41:45','2008-01-11 07:41:45','Catzi is, catzi is???',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(12175,927,'cip','cipis74@yahoo.com','','89.137.107.153','2008-01-10 17:46:59','2008-01-10 15:46:59','Ai ratat-o pe aia cu: Este in SB un magazin pe a carui firma, veche, scrie: \"Ma gandesc la tine\" iar putin mai jos: \"NON STOP\"',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(12177,947,'mishu','mishu@doingtheartwork.com','http://www.doingtheartwork.com','82.77.126.254','2008-01-10 18:10:21','2008-01-10 16:10:21','Da, asa e, am vazut cu ochii mei cum a gustat groparu din farfurie pentru a se convinge ca fusese a shefului :D\r\n\r\nps: ce nerecunoscator... thank you ma! :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(12158,945,'Mih_nea','mihnea_xxyahoo.com','','62.217.236.12','2008-01-10 13:09:09','2008-01-10 11:09:09','pai sa se-obisnuiasca cu ei, ca la cum merg lucrurile cu procesul de pace, nu se stie :)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(12172,946,'WhiteWolf','contact@white-wolf.ro','http://white-wolf.ro','89.39.83.225','2008-01-10 17:17:41','2008-01-10 15:17:41','Asta-i din viitoarea categorie <b>brice si carice</b>\r\nNu-i asa ? :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(12173,945,'WhiteWolf','contact@white-wolf.ro','http://white-wolf.ro','89.39.83.225','2008-01-10 17:19:48','2008-01-10 15:19:48','De te ginesc aia de-ai lui Puleschovici sa vez\' ce protestovici iti vara pe v\'un sait din ala de se urmaresc nazistii supravietzuitori de nu-ti mai ajung cemetirele sa te askunz\r\nAstia taiatz\' imprejur is sensibilosi rau cand ii alaturi de araboci :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(12166,946,'Denisa Lala','denisalala@gmail.com','http://denisuca.com/','89.121.76.151','2008-01-10 15:12:00','2008-01-10 13:12:00','MulÅ£Äƒmim frumos de tÄƒt! :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(12226,946,'vizionaru;','alinmiron_19@yahoo.com','http://www.vizionarul.wordpress.com','83.103.154.202','2008-01-11 08:49:02','2008-01-11 06:49:02','ba sa se iubeasca in toate modurile posibile si imposibile...  chiar si cu bice si alte accesorii casnice si electrocasnice ce ajuta la gasirea sau cresterea placerii. :D:D:D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(12163,945,'catalin','solo@xsolo.biz','http://xsolo.biz','190.17.92.168','2008-01-10 14:45:22','2008-01-10 12:45:22','SILENCE......night =))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(12180,946,'c|neva','cineva_df@yahoo.com','http://www.diaconuflorin.ro','78.96.86.55','2008-01-10 19:37:57','2008-01-10 17:37:57','Apoi pentru casa din adsense mai e de munca.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(12182,945,'psaico','psaico@psaico.info','http://www.psaico.info','78.96.86.55','2008-01-10 19:41:28','2008-01-10 17:41:28','trebuia sa strigi in parcare la kaufland .. ca ieseam pe balcon :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(12183,946,'psaico','psaico@psaico.info','http://www.psaico.info','78.96.86.55','2008-01-10 19:42:38','2008-01-10 17:42:38','\"sa va iubiti fara bice\" .. perversi mici si blogosferici :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(12300,950,'Blu3','mide765@yahoo.com','','86.106.50.83','2008-01-12 10:41:48','2008-01-12 08:41:48',':)))))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(12302,950,'c|neva','cineva_df@yahoo.com','http://www.diaconuflorin.ro','78.96.86.55','2008-01-12 11:07:37','2008-01-12 09:07:37','Si sa dea un partz de-atata ras?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(12314,949,'krossfire','profesornukem@yahoo.com','http://www.krossfire.ro','86.107.145.25','2008-01-12 15:04:28','2008-01-12 13:04:28','Sapte februrarie....dar tre\' sa mergi in China, sa te imbraci in rosu si sa te obisnuiesti sa mananci cu tepusele.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(12318,949,'catalin','solo@xsolo.biz','http://xsolo.biz','190.17.92.168','2008-01-12 16:14:06','2008-01-12 14:14:06','In Aprilie parca e Anu Nou in Nepal, nu imi amintesc data pe moment.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(12324,950,'Ladystarlight','mail_aniri@yahoo.com','http://pilulele.blogspot.com','85.204.114.160','2008-01-12 18:36:44','2008-01-12 16:36:44','ÅŸi dacÄƒ nu se gÃ¢dilÄƒ?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12','',0,0),(11658,100,'Nascut din spermatozoizi campioni &raquo; Blog Archive &raquo; Deci Craciunul din 2007','','http://www.groparu.ro/?p=917','82.103.137.253','2008-01-03 11:29:23','2008-01-03 09:29:23','[...] Anu asta, ca de obicei, fusai la colindit. Nu am mai vazut femei batute de barbati si viceversa, ca anu&#8217; trecut. [...]',0,'1','Incutio XML-RPC -- WordPress/2.1.2','pingback',0,0),(11710,917,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-01-04 10:28:50','2008-01-04 08:28:50','Deci Julius, deci apropos de sosea, nevestele alora de revelionarÄƒ cu mine nu umblÄƒ la ÅŸosele sau parcari; sh noi, la kefuri, suntem ca mÄƒgarii lu Buridan, fincÄƒ ce alegi dintre fomeie ÅŸi beuturÄƒ, cÄƒ nici nu mai ÅŸtii lÃ¢ngÄƒ care sÄƒ vrei sÄƒ te trezeÅŸti!\r\n\r\nPS: deci flatarea mea rÄƒmÃ¢ne constantÄƒ cÃ¢nd vÄƒz cÄƒ mÄƒ ceteÅŸti :\"&gt;',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(11713,917,'Lexis','g_lexis2005@yahoo.com','http://www.alexandraghitalexis.blogspot.com','89.38.76.46','2008-01-04 12:33:36','2008-01-04 10:33:36','bine ai revenit',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(11718,917,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-01-04 16:22:57','2008-01-04 14:22:57','Bine v-am regasit, sper eu, sanatosi la trupuri! :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(11719,918,'Andrei Crivat','andrei@andreicrivat.ro','http://www.andreicrivat.ro','89.137.83.141','2008-01-04 16:31:00','2008-01-04 14:31:00','pai ce sa vedeti.. era ta\'su, nu ?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(11720,918,'mihai ursu','agentimperialist@yahoo.com','http://mihaiursu.wordpress.com','83.166.206.107','2008-01-04 16:34:17','2008-01-04 14:34:17','las ca vezi tu varianta video... a picture speaks a thousand words. si io inca nu mi-am revenit din noptile alea pierdute din care am iesit, paradoxal, in cistig. ramineti aproape (treji)!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(11723,556,'Groparu','groparu_ro@yahoo.com','http://','82.77.126.254','2008-01-04 17:22:19','2008-01-04 15:22:19','Nu-i manz, e ditamai calutzu.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,1),(11724,918,'Nurya','','http://nurya2007.blogspot.com','81.196.216.97','2008-01-04 17:41:34','2008-01-04 15:41:34','Ma bucur ca vo placut la muntele fara apa curenta... si apropos sa sti ca depinde ce paznic ai prins k mie mi-o zis de unde vine apa... hic hic ....\r\ntraiasca  BAIA IN SERVETELE PT BEBELUSI ....\r\n\r\nasteptam continuarea .... \r\n\r\no sa vezi si la mine ...filmul revului 2008',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1) Gecko/20061010 Firefox/2.0','',0,0),(11722,556,'buksza','','','79.113.76.148','2008-01-04 17:13:14','2008-01-04 15:13:14','groparule vai de manzu tau',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12','',0,0),(11685,917,'iulian n.','','','81.181.42.122','2008-01-03 19:55:01','2008-01-03 17:55:01','Macar omu o incercat... Deci nu o sa primeasca toata viata reprosuri ca o cerut-o prin mesinger sau semeseu.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; .NET CLR 2.0.50727)','',0,0),(12200,58,'Ludo','','http://groups.google.com/group/otekal/web/vanessa-hudgens-naked-picture','195.225.177.190','2008-01-11 00:15:36','2008-01-10 22:15:36','<strong>vanessa hudgens naked picture...</strong>\n\nfirst know some of the basics of developmental biology\n...',0,'1','USERAGENT','trackback',0,0),(12202,947,'Kissu','@Groparu','http://www.pacurar.net','79.113.157.248','2008-01-11 00:37:28','2008-01-10 22:37:28','\"Cine esti, cine esti?... Cine esti, cine esti?...\" ;))))))))))',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1)','',0,0),(11695,917,'julius constantinescu','julius@universitateacraiova.ro','http://www.7plus.ro','84.232.160.5','2008-01-04 01:32:18','2008-01-03 23:32:18','Misto textul, Groparule, mai putin finalul, pe care nu l-ai nimerit, intrucat dimineata e foarte frumoasa, dupa cum stim cu totii din binecunoscuta melodie populara: \"Ce frumoasa este viataaaa/ cand te prinde dimineataaa/ dimineata la soseaaa/ cu nevastaaaaa altuia\"',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(11742,918,'vulpita','daniela24rous@yahoo.com','http://vulpita.weblog.ro','78.96.32.221','2008-01-04 23:16:51','2008-01-04 21:16:51','Frumos revelion ati avut!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(11745,909,'UrbanReality','urbanreality.wordpress@gmail.com','http://urbanreality.wordpress.com/','92.81.144.178','2008-01-05 00:32:23','2008-01-04 22:32:23','si daca rambursezi anticipat platesti :P \r\nastea-s bancile ce sa-i faci .',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(11746,917,'c|neva','cineva_df@yahoo.com','http://wwww.diaconuflorin.ro','78.96.86.55','2008-01-05 00:54:34','2008-01-04 22:54:34','Casa de piatra?\r\nLa multi ani diferiti gropare...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(11747,918,'c|neva','cineva_df@yahoo.com','http://www.diaconuflorin.ro','78.96.86.55','2008-01-05 01:01:23','2008-01-04 23:01:23','Veni ursu?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(11748,918,'July','jullya24@yahoo.com','','89.123.250.204','2008-01-05 01:51:48','2008-01-04 23:51:48','se pare ca toata lumea o avut un rev forte fain...\"clasic pe un beat din jurrasick..\"..la multi ani!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(11750,918,'catalin','solo@xsolo.biz','http://xsolo.biz','190.17.92.168','2008-01-05 02:11:21','2008-01-05 00:11:21','emisiunea lu peshte! ce e asta? telenovela? veni verisoara lu mama lu bunica lu mile care defapt era sora lu nepotu lu ursu si care de fapt e padurar acolo si cum focu e interzis in padure vru sa dea amenzi grele in euroi da la final se  puse la baut si gata :-)))))))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(11659,917,'Hammer','hammer@alpinet.org','http://www.alpontos.wordpress.com','86.120.55.79','2008-01-03 11:46:47','2008-01-03 09:46:47','O editie faina de umblat cu colinda, eh? Cu momente memorabile, musai sa ai un reper dupa aia:-D Doamneee, cat o sa regrete procedura aleasa ca sa-i ceara mana, cate impunsaturi voalate (sau nu) o sa primeasca de la ea si de la ai ei, ashe, mai incolo oleaca.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(11661,917,'oedip','oedip74@gmail.com','http://oedip.blogspot.com','89.137.99.163','2008-01-03 12:38:49','2008-01-03 10:38:49','... da de unde scoti tu atatea detalii daca erai in stare avansata de critza? ;)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(11662,916,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-01-03 12:40:12','2008-01-03 10:40:12','Dap. Una scrie comentariul asta.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(11663,917,'Groparu','groparu_ro@yahoo.com','http://','82.77.126.254','2008-01-03 12:46:56','2008-01-03 10:46:56','Mi s-a povestit :D oricum m-am trezit la realitate cand am vazut ce se intampla, din cauza socului.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,1),(11666,911,'Cipi','ciprian@luxmail.ro','http://www.luxmail.ro','92.80.130.0','2008-01-03 13:15:33','2008-01-03 11:15:33',':) Probabil a fost rezolvata/dezvaluita sau poate nu',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; SLCC1; .NET CLR 2.0.50727; Media Center PC 5.0; .NET CLR 3.0.04506; InfoPath.2)','',0,0),(11734,918,'iulianuss','iulianuss@yahoo.com','','193.231.107.209','2008-01-04 20:57:49','2008-01-04 18:57:49','Hai ca va povestesc io mai departe: o vazut ca s-o luat corentu si nu s-o mai vazut nimica. Apoi s-o rupt si filmu, normal.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; .NET CLR 1.1.4322)','',0,0),(11627,57,'Nox','','','89.44.124.172','2008-01-02 22:31:13','2008-01-02 20:31:13','Pe vremea cand eram tzanc, la noi la scoala buda era plina de vrajeli de genu\' : \"Maricica + Fanel = Love\", dar mai era ceva, pe o usa scria \"sunt urme de talpi pe tavan\". Si stiti care e paradoxu\'? Chiar erau urme de talpi pe tavan.......pe bune, fara shto.',0,'1','Opera/9.24 (Windows NT 5.1; U; en)','',0,0),(11628,916,'ucshiva','mail@ucshiva.net','http://ucshiva.net','89.46.44.249','2008-01-02 23:05:17','2008-01-02 21:05:17','Exista persoane care sa spuna chestiile alea ? :))',0,'1','Opera/9.25 (Windows NT 5.1; U; en)','',0,0),(11729,914,'zone-ro','zone-ro@google.com','http://zone-ro.blogspot.com/','89.33.174.237','2008-01-04 19:16:47','2008-01-04 17:16:47','Killer, in locul tau m-as abtine. Comentariul meu a fost unu ironic dar se pare ca neuronul tau e inca mahmur de la atata bautura de Sarbatori. nici macar nu ai avut binevointa de a citi ce am scris eu in posturile precedente, iar in legatura cu scoala/facultatea/alte studii te rog spune-mi tu mie ce facultate ai terminat (daca ai terminat)? sper ca o sa fii sincer. chiar daca ai fi facut una dintre facultatile enumerate mai sus nu pot sa iti dau dreptate. ce se face la cfdp(asta e cam de ratati si se intra cu media de la gradinita cred :P ),instalatii sau altele nici nu se compara cu arh :) crede-ma. poate mai grea decat arh e medicina dar in nici un caz telecomunicatii sau mai stiu eu ce. Si inca ceva, habar nu ai ce vorbesti, arh ce e? nu e tehnica? crezi ca e vreo educatie plastica sau vreun desen asa la misto? la misto e scoala pe care ai facut-0 tu, ca daca un om zice ca arh e apa de ploaie nici nu mai are rost sa ma intreb de ce dracu sunt asa de multi clienti tampiti care cer lucruri de kkt. ai fi in stare sa iti face o casa a la videanu :)) \r\n\r\nAnon...daca ai ceva de zis iesi din anonimat. e plin netu de copii ca tine.\r\n\r\nin concluzie: daca ar fi fost asta nush ce blog si era tot al vostru intelegeam sa va crispati asa, dar nu e cazul. va agitati ca niste tzatze proaste care in sfarsit au gasit ceva concret despre care sa vb. Pana la urma am taiat capul cuiva? Nu va mai ofticati atata degeaba ca nu vad rostul.',0,'1','Opera/9.23 (Windows NT 5.2; U; en)','',0,0),(11621,912,'Groparu','groparu_ro@yahoo.com','http://','89.137.109.142','2008-01-02 19:55:26','2008-01-02 17:55:26','@ PIT: Ca sa vezi ironia sortii - sh io stau la iesirea din Sibiu catre Brasov :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,1),(11672,917,'WhiteWolf','contact@white-wolf.ro','http://white-wolf.ro','89.32.115.56','2008-01-03 15:58:53','2008-01-03 13:58:53','<b>Fain Om !</b>',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(11739,918,'Conia','','','193.226.17.210','2008-01-04 22:16:30','2008-01-04 20:16:30','Te contrazici...semn de interzis...si \"no manele\"...2 negatii',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727)','',0,0),(11679,917,'vizionarul','alinmiron_19@yahoo.com','http://vizionarul.wordpress.com','89.35.87.15','2008-01-03 18:19:50','2008-01-03 16:19:50','Mare om, mare caracter groparu aiesta!',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648)','',0,0),(11993,925,'nenea cosmos','domnu_cosmos@yahoo.com','http://www.nenea.wordpress.com','92.80.40.138','2008-01-08 23:50:39','2008-01-08 21:50:39','frate, eu m-am rupt odata de abia asteptam sa se puna rosu si sa cobor din masina, se uitau aia din celelalte masini cum am pus frina si am fugit din masina de ziceai ca sare in aer. m-am oprit linga esapament sa trag niste aer in piept si pe urma m-am intors si am intrat in masina cu frica. mi-am pus bradutu la nas (desi imi venea sa il mestec) si am inceput sa ma gindesc in timp ce se pusese verde: oare daca eram biciclist ca groparu ce sanse ar mai fi avut bicicleta? probabil de aia ii zice stafie, ca te urmareste cu orele. noroc ca era toamna si aveau aia geamurile inchise la masinile lor. dupa 2 saptamini am vindut masina. ala de a luat-o avea nasul infundat. in tirg nu m-au lasat cu ea decit in capat...\r\n\r\nsi apropo, sa n-ai peste la revelion nu e mare scofala, da nici niste somon fume?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(11996,925,'c|neva','cineva_df@yahoo.com','http://www.diaconuflorin.ro','78.96.86.55','2008-01-09 00:30:43','2008-01-08 22:30:43','S-a bagat unu la compu\' asta, parol. Sa moara je ca nu am scris comentariul acesta http://www.groparu.ro/?p=925#comment-11980 (deosebita relatare :D ) E conspiratiune, parol.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(12000,925,'julius constantinescu','julius@universitateacraiova.ro','http://www.7plus.ro','84.232.161.177','2008-01-09 01:08:05','2008-01-08 23:08:05','Groparule, sa-ti dau un sfat: scrie mai scurt,  bre, ca te pierde omul pe drum. Stii cum e: tu-i dai acolo si fata sta si se uita in tavan...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(12007,925,'Ionut','ion@yahoo.com','','89.34.225.25','2008-01-09 02:14:12','2008-01-09 00:14:12','Bai...mie mi-a ramas gandul la pustoaicele alea de pe hi5 :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(12189,947,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.83.141','2008-01-10 20:08:19','2008-01-10 18:08:19','Cine esti tu, femeie? Nu te-am vazut in viatza mea!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(12370,949,'vizionarul','alinmiron_19@yahoo.com','http://vizionarul.wordpress.com','89.35.87.15','2008-01-13 10:19:07','2008-01-13 08:19:07','Mai gropare, io creca tu esti finlandez, ca numa aia au atatea zile libere pe an... altfel nu-mi explic participarea ta la atatea sindrofii.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(12373,100,'securitatea','securitatea_89@yahoo.com','','79.112.103.234','2008-01-13 11:29:16','2008-01-13 09:29:16','f tare Gropare...:))... Marin si ksy faceti un pas in spate,luati pula si mai cititi odata',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(12376,950,'Buciuman','aaa@ggg.com','http://rezistenta.blogspot.com/','86.121.59.168','2008-01-13 11:56:41','2008-01-13 09:56:41','Eu i-ash fura ceasul.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; InfoPath.2; .NET CLR 2.0.50727)','',0,0),(12379,949,'.marius','marius@perijoc.com','http://marius.wirelessisfun.com','89.137.107.129','2008-01-13 12:49:05','2008-01-13 10:49:05','Spor!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(12380,949,'psaico','blog@psaico.info','http://www.psaico.info','86.106.51.113','2008-01-13 13:14:57','2008-01-13 11:14:57','deschide-ti un local unde se organizeaza revelion in fiecare weekend :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(12387,949,'cÄƒlÄƒ','acalarasu@gmail.com','http://adriancalarasu.wordpress.com/','89.32.19.126','2008-01-13 15:18:36','2008-01-13 13:18:36','(...) inundatiile, codurile de toate culorile - de vara sau iarna, ruptu turtei, taierile de motz, taierile de porc, necazul sefului, plecarea soacrei, venirea soacrei (...)\r\nprileje cacalau, sa mai continui?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) )','',0,0),(12395,948,'catalin','solo@xsolo.biz','http://xsolo.biz/2007/12/30/inghetata-si-arome/','190.17.92.168','2008-01-13 18:49:11','2008-01-13 16:49:11','Aroma de cozonac e ceva prea simplu...dar aroma de carne de cal cruda?Â¿?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(12232,945,'prodan','mihai.prodan@gmail.com','http://prodan.wordpress.com','82.77.126.171','2008-01-11 10:34:47','2008-01-11 08:34:47',':))))\r\nbuey deci tu eÅŸti meseriaÅŸuu, buey!!!!!!\r\n:))))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(12237,948,'Mih_nea','mihnea_xxyahoo.com','','62.217.236.12','2008-01-11 12:55:24','2008-01-11 10:55:24','Cu aroma de Silva neagra, aprob. Cu mujdei, la fel.\r\nAs putea avea mirosurile mele specifice indiferent de situatie :)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(12240,948,'george','reallyinsane@gmail.com','','193.138.195.202','2008-01-11 13:23:59','2008-01-11 11:23:59','Ar merge si una cu aroma de shorma-lipie-mare pui/vita pentru zilele geroase cand ne e lene sa ne ducem pana la arabu din coltz.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(12242,948,'c|neva','cineva_df@yahoo.com','http://www.diaconuflorin.ro','78.96.86.55','2008-01-11 13:40:08','2008-01-11 11:40:08','Cu aroma de pumni in gura sa se linisteasca blogosfera de la atata scandal.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(12245,948,'ss','criss_team@yahoo.com','','82.77.127.115','2008-01-11 13:56:22','2008-01-11 11:56:22','musai un sortiment cu aroma de munca asidua pt momentele cand te intreaba sefu de sanatate.\r\n\r\nsi- cerere speciala- un sortiment cu gust de victorie, pt noi, suporterii lui U.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(12248,948,'CAESARUS','mihai.pop@utopium.ro','http://utopium-advertising.blogspot.com','85.186.103.54','2008-01-11 15:59:57','2008-01-11 13:59:57','Ciorba de burta e cea mai buna din lume la KON TIKI - ii groasa si puturoasa asa cum numa un bulibas adevarat o intelege.\r\n\r\nHai baftalo!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(12777,954,'Laura','mars1953@web.de','','84.160.100.53','2008-01-17 21:28:33','2008-01-17 19:28:33','Draga groparule, daca strainii fac fabrici la noi, printre altele si pt. ca aici forta de lucru e mult mai ieftina decat in Germania. Asta are cel putin doua aspecte: pe de o parte pacat ca ne vindem munca asa ieftin, iar pe de alta parte in Germ. oamenii nu vor si nu-si pot permite sa lucre asa ieftin ca noi. Tocmai pt. ca in Germ. se castiga altfel sunt si conditiile sociale si economice ALTFEL ca la noi. Asa ca luatul si datul sunt cam relative din aceste p.d.v.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(12258,948,'PIT','paula.tiplea@gmail.com','','85.120.75.140','2008-01-11 18:46:51','2008-01-11 16:46:51','eu sunt nostalgica dupa o guma de care pare sa nu isi mai aminteasca nimeni. era pe vremea lu\' ceausescu o guma chinezeasca invelita intr-un celofan jumate alb jumate rosu si cand dadeai ala jos mai avea o folie din aia de se topea in gura :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.0.7) Gecko/20060909 Firefox/1.5.0.7','',0,0),(12260,948,'mirmen','mirmen_bursi@yahoo.com','','195.225.66.166','2008-01-11 19:36:34','2008-01-11 17:36:34','ahaha!!  pit, dragÄƒ, aieÅŸtia tÄƒÅ£ ar borÃ® dupÄƒ o aÅŸa chinÄƒzÄƒrie suavÄƒ, nu tie juca !! :D cre\' cÄƒ totuÅŸ descrierea ÅŸi sugestia facutÄƒ ce i-o mai Ã®nviora :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.8','',0,0),(12255,948,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-01-11 17:42:22','2008-01-11 15:42:22','Deci mo, nush daca penetrarea blogoreii mele in acest segment de piatza (care, de fapt, trebuie sa recunosti ca ar reprezenta mai degraba un upsell decat un cross-sell) nu ar face rau brandului Groparu!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(12251,948,'WhiteWolf','contact@white-wolf.ro','http://white-wolf.ro','89.32.115.65','2008-01-11 17:13:26','2008-01-11 15:13:26','@CAESARUS, mureai daca-ti puneai i.d-ul olecutzica mai neaosh ? :P\r\nAsa, ai circumstante da\', oricum, bulibashu\' o intelege mai repede daca e neagra si puturoasa decat groasa. Eventual vanata dar, oricum, nu se face sa comiti confuzii intre sexe tocmai aici, pe blogul cimitiresc.\r\nSe referea la vomitorium .Si nu la impulÃ£rorium :P\r\n Si ca sa nu se mai indoiasca vreo care cineva cum ca n-as fi fan Groparu :P, chestia cu ciorba de burta tine mai mult de mahmureala si oarece stari de rau de a doua zi. Iar puturosi pot fi doar aia care isi fac drum spre Kon-Tiki , daca se risca sa deschida gurile\r\nIn rest, nonbeliverii , ceretz\' locatia de la Gropar. Nu va minte nici cat un ardei iute. <b>Vindecare garantata !</b>\r\n\r\np.s; omule, da sectie de comenzi pentru fitzoshi, editii limitate si numai comenzi begoase nu-ti tragi la manufactura ?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(12254,948,'WhiteWolf','contact@white-wolf.ro','http://white-wolf.ro','89.32.115.65','2008-01-11 17:37:53','2008-01-11 15:37:53','Doar il tachinam o tzÃ£rÃ£ :)\r\nM-am prins ca macar la ciorbe o participat \"voios\"\r\nSo. Faci au ba si sectie de fitzoshi ? Din aia pentru Virineli ?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(12253,948,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-01-11 17:34:06','2008-01-11 15:34:06','Mo Lupulainu\', da-i pace la Utopium-Advertising.blogspot.com, ca ii boyfriend d-al meu, vechi coleg de apartament si de camin, si martor al multor evenimente in care ni se invarteau tavanele pe deasupra capelor! Si ii chiar un ficior fain. Si stii ca ce comentariu nu merita lasat pe blog, io il dau la bulldog.\r\n\r\nDeci si matale ej fan Kon Tiki? Pfuay, ca deja am salivat abundent peste tastatura!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(12333,950,'Laura','mars1953@web.de','','84.160.110.34','2008-01-12 20:53:00','2008-01-12 18:53:00','ca sa moara de ras ?!',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(12336,949,'eugen','icgel@yahoo.com','','89.41.164.224','2008-01-12 22:09:24','2008-01-12 20:09:24','Cred ca bloggerii ar trebui sa organizeze in fiecare luna cate un Revelion.  Prin urmare, 3 Revelioane in Est, 3 in Vest, 3 in Sud si 3 in Nord. Se strang bani la organizator si ala sa se ocupe de invitatii, de locatie, carnati si leber. Si palinca, evident...\r\nMai ce bine ar fi..\r\n\r\nwww.cepanamea.ro',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(12337,950,'eugen','icgel@yahoo.com','','89.41.164.224','2008-01-12 22:12:00','2008-01-12 20:12:00','Omule, stai asa, daca Dumnezeu nu stie de gluma si-ti rade una peste freza? Ia-L si tu usor asa, vezi cum iti raspunde la glume, baga-te-n seama cu El usor, nu din prima...si apoi Il iai la gadilat... Nu stiu, zic si eu asa...\r\n\r\nwww.cepanamea.ro',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(12338,948,'eugen','icgel@yahoo.com','','89.41.164.224','2008-01-12 22:14:35','2008-01-12 20:14:35','Deci, nu te bagi tu, Gropar, ce eesti, pe persoana fizica, in bucataria romaneasca...Da? Si daca tot ai facut-o, ia zi-mi daca stii procesu\' de fabricatie? Hai, sa te vad...Vezi ca nu stii..Arunci bomba, da\' n-ai fitil...\r\n\r\nwww.cepanamea.ro',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(12341,950,'mirra','','','83.103.137.234','2008-01-12 23:20:18','2008-01-12 21:20:18','si daca ii place si mai vrea? Atunci sa te vaz...:)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(12342,949,'mirra','','','83.103.137.234','2008-01-12 23:24:05','2008-01-12 21:24:05','La ce iti mai trebuie revelioane, ca azi, maine incep nuntile si daca o sa ai si anu\' asta ca anu\' trecut....',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(12081,925,'catalin','solo@xsolo.biz','http://xsolo.biz','190.17.92.168','2008-01-09 18:06:42','2008-01-09 16:06:42','\"Groparu a eliberat stafia!\" tot e bine ca nu fu vulpea, sau jetu, sau cum ii mai zice, ca la cit te apasa fatuca pe burta eu credeam ca ai sa scoti din tine tot gratarul si berea si tot pe gura :-)))))))))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(12363,950,'doomyuwz','ro_maniax@yahoo.com','','79.116.43.100','2008-01-13 07:37:31','2008-01-13 05:37:31','Da-i un cap in gura si arata-i Romania.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727)','',0,0),(12100,925,'eu','','http://nurya2007.blogspot.com','84.232.196.234','2008-01-09 22:29:08','2008-01-09 20:29:08','draga gropare...am ras cu lacrimi...desi am fost acolo ...sa mor ca nu am remarcat mai mult de 2 pisicutze, ba m-am uitat si pe caseta sa mor nu am restul de 4 cred ca e pierderea mea...\r\nany way ai uitat sa spui cum ai cantat tu cu ursu pana v-ati facut degetele negre (mai mult tu decat ursu), ai uitat cum ma terorizai.. (U OK?)...of gropare...mai scrie mai de rev...de greuceanu cum manca el erotico exotic un carnat facut de sarbu dupa reteta originala...mai zi si de super friptura numarul 1 facuta de sarb...\r\nsi app CIUPERCILE TALE fura super....',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(12751,953,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-01-17 16:43:57','2008-01-17 14:43:57','Deci si io am zis ca unii colegi merita o injectie cu votca dizolvata in viagra fix in cap!\r\n\r\nNu-i va face mai meseriashi, da\' sigur ii va omori :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(12752,954,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-01-17 16:44:28','2008-01-17 14:44:28','Deci la postarea asta, sincer, nu stiu cine si ce ar putea sa comenteze!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(12756,954,'eugen','icgel@yahoo.com','http://www.cepanamea.ro','89.41.164.224','2008-01-17 17:40:07','2008-01-17 15:40:07','Deschide Gropare mormantu\'...omule, ce dreaq sa luam noi? Pai crezi ca aia vin aici cu laptele si mierea lor? Nu, lucreaza cu materialu\' clientului...stai c-o sa vezi..',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(12270,948,'Lumi','luminitadanciu@yahoo.com','','209.221.168.249','2008-01-12 00:43:20','2008-01-11 22:43:20','Se pare ca unii ti-au luat-o inainte. Ce-i drept e soda....\r\nhttp://www.jonessoda.com/files/turkey04.html',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; InfoPath.1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(12759,954,'baghy','baghy83@lycos.it','http://baghy.info/','78.12.19.4','2008-01-17 17:56:46','2008-01-17 15:56:46','ce sa luam? mUE?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(12761,952,'Motociclistul','eggprotect@yahoo.com','http://www.motociclist.com','92.80.173.36','2008-01-17 18:22:12','2008-01-17 16:22:12','am dat pe la cateva bloguri recunosc imi cer scuze',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(12765,952,'macabroo','raduccc@yahoo.com','http://rezistenta.blogspot.com','82.76.52.94','2008-01-17 18:58:15','2008-01-17 16:58:15','si SPAMUL tot carne e!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; en-GB; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(12276,948,'Tudor','','http://dingrajd.blogspot.com/','78.97.5.116','2008-01-12 02:25:34','2008-01-12 00:25:34','O ideie ar fi si guma cu gust de tamaie, sau... apa sfintita cu busuioc. da ai de grije cand iti deschizi fabrica si unde ca o sa fie cu ochii pe tine aia de la SMI (Serviciul Monahal de Informatii)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(12328,949,'cÄƒlÄƒ','acalarasu@gmail.com','http://adriancalarasu.wordpress.com/','89.32.19.126','2008-01-12 19:28:06','2008-01-12 17:28:06','adevaru-i ca revelioanele sunt cele mai faine prileje de beute!!!\r\n\r\nda\' nu-i panica, nu mi-e rusine nici cu zilele de sfinti, onomasticele, lasatu\' de sec, nuntile, inmormantarile, divorturi, avorturi, despartiri, impacari, plecari, sosiri, inaugurari, team bildinguri, alegeri, alegeri anticipate, luat examene, picat examene(...)...',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) )','',0,0),(12070,927,'WhiteWolf','contact@white-wolf.ro','http://white-wolf.ro','89.32.115.47','2008-01-09 15:28:00','2008-01-09 13:28:00','Mno, lasa.... Vii tu la tiganiada\r\nMai vorbim ,noi, atunci, de publicitatea asta negativa :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(12064,927,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-01-09 14:12:49','2008-01-09 12:12:49','@ Vizio\': Mo, deci... cu fumatu\', am derapat de vreo 2-3 ori pana acu\'. Da\' uite ca ma tin bine, in ciuda gresalelor!\r\n\r\n@ Mirra: nu, ci din cauza ca noi am fost mereu in avangarda cerebeloasa a Europei asteia batrane si cam senile!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(12060,925,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-01-09 13:42:46','2008-01-09 11:42:46','@ Julica: \"Gropare, cand termini, stinge te rog lumina!\"; si a doua zi: \"No, mah, ai mai stat mult aseara?\"',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(12069,927,'mumuland','','','80.97.64.199','2008-01-09 15:12:21','2008-01-09 13:12:21','ce naiba ma aste sunt devarate monumente ale tarii noastre...ar trebui sa le exploatam ce drecu...\r\n\r\n\r\nis io ma.care io? asta :  ;)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12','',0,0),(12062,927,'vizionaru;','alinmiron_19@yahoo.com','http://www.vizionarul.wordpress.com','83.103.154.202','2008-01-09 13:55:16','2008-01-09 11:55:16','Apai ce sa-i facem mai gropare, doar si-n Sibiu, tot romani stau... Fiecare oras are manelarii lui si fiecare turist ce-a calcat anul asta prin Sibiu era un potential manelar sau anti-manelar. \r\nDa-mi voe sa te felicitez primu\' anu asta cu ocazie ca nu mai fumezi de anu trecut!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(12063,927,'mirra','','','83.103.137.234','2008-01-09 14:06:57','2008-01-09 12:06:57','Am fost anu trecut cu pretenii la concert Scorpions si am vazut si io destule chestii de aiest fel si mi-o parut rau ca n-am avut aparat foto sa ti le trimet si tie.Da chiar de ce a fost facut Sibiul capitala culturala europeana?Ca seamana  cultura locuitorilor cu cea din Europa? Din cate stiu stam prost si la capitolul agricultura!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(12307,948,'macabroo','raduccc@yahoo.com','http://rezistenta.blogspot.com','82.76.52.94','2008-01-12 12:34:17','2008-01-12 10:34:17','Gropare lasa guma de mestecat, e pentru doamne si pentru fetele de la scoala de duminica, ce-ai zice de un produs cu adevarat revolutionar pentru barbati adevarati: TZIGARILE cu arome de tot ce ai zis tu acolo! Am lovit intr-un loc sensibil?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; en-GB; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(12308,945,'macabroo','raduccc@yahoo.com','http://rezistenta.blogspot.com','82.76.52.94','2008-01-12 12:40:48','2008-01-12 10:40:48','ahahahah merita un sketch la Saturday night Live',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; en-GB; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(12295,948,'mirra','','','83.103.137.234','2008-01-12 08:53:51','2008-01-12 06:53:51','nu te complica,gropare,nu te complica, mai bine bei berici si cu un drum iti speli si aparatul renal...Lasa gumele de mestecat, ca strica dintii.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(12422,950,'innuenda','innuenda.innuenda@gmail.com','http://innuennda.blogspot.com','92.81.3.70','2008-01-14 04:26:58','2008-01-14 02:26:58','BÄƒi hÃ¢trilor, nu mai luaÅ£i numele Domnului Ã®n deÅŸert! Ia, toatÄƒ lumea alinierea cu cÄƒrÅ£ile de rugÄƒciuni Ã®n mÃ¢nÄƒ!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(12740,953,'Mih_nea','mihnea_xxyahoo.com','','62.217.236.12','2008-01-17 14:31:35','2008-01-17 12:31:35','eu as fi workoholic doar daca asta ar insemna ca mi s-a intamplat sa mai beau la munca :)\r\nasta pe vremea cand aveam colegi mai mishto, ca ashtia d-acu\'... :(',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(12743,952,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-01-17 14:59:57','2008-01-17 12:59:57','Comentariu de raspuns la comentariul lui Crivatz, Andrei Crivatz: deci da!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(12439,945,'WarSongu','eternaldawnlord@yahoo.com','http://www.warsongu.wordpress.com','193.32.3.83','2008-01-14 13:40:14','2008-01-14 11:40:14','La chaim!',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; FunWebProducts; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(12441,949,'Sorinelu\'','sorinelm@yahoo.com','','86.122.9.37','2008-01-14 15:44:09','2008-01-14 13:44:09','moh, io zic sa meri in Indonezia. uite cate revelioane au astia: http://www.bei.co.id/MainMenu/Trading/TradingHoliday/tabid/85/lang/en-US/language/en-US/Default.aspx',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 2.0.50727)','',0,0),(12442,949,'Stephan Eyck','stefan_b3@yahoo.com','http://interiordesignoradea.blogspot.com','85.186.103.54','2008-01-14 18:21:42','2008-01-14 16:21:42','In noaptea de revelion trebuie sa stam cu ochii deschisi!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(13144,961,'manole','redtailanda@yahoo.com','http://www.mesterulmanole.wordpress.com','81.181.92.157','2008-01-21 09:18:38','2008-01-21 07:18:38','9 milioane - 9 banci , 5 elvetiene si 4 nemtesti. calatoresc si fac restul de ce as mai vrea din dobanda! simplu. :)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows 98)','',0,0),(12709,952,'Mih_nea','mihnea_xxyahoo.com','','62.217.236.12','2008-01-17 08:47:41','2008-01-17 06:47:41','credeam ca ti-a placut prea mult si nu te mai intorci, dac-am vazut ca s-a facut miercuri si n-ai scris. Da\' las\' ca si Timisoara e frumoasa, si mai putin bombardata...',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(12718,952,'Andrei Crivat','andrei@andreicrivat.ro','http://www.andreicrivat.ro','89.137.83.141','2008-01-17 10:35:10','2008-01-17 08:35:10','ma, motociclistu ala a scris la mine FIX aceleasi doua mesaje. deci si ala cu din greseala am dat copy/paste\r\nmno, asta chiar ii tare, mo :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(12719,952,'Andrei Crivat','andrei@andreicrivat.ro','http://www.andreicrivat.ro','89.137.83.141','2008-01-17 10:38:18','2008-01-17 08:38:18','ca o completare filosofica la ce-am zis mai sus. sau chiar filozofica\r\nNICI SPAMU\' NU MAI E CE-A FOST, MO!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(12730,953,'.marius','marius@perijoc.com','http://marius.wirelessisfun.com','89.33.41.194','2008-01-17 12:57:46','2008-01-17 10:57:46','hotnews? :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(12732,953,'Raspundem la intrebari at Gramo`s World','','http://gramo.ro/2008/01/17/raspundem-la-intrebari/','69.93.255.82','2008-01-17 13:01:55','2008-01-17 11:01:55','[...] e greu sa continui o discutie pe blog in mai multe posturi, despre ce-i aia o persoana si de ce un cimpanzeu nu e asa ceva si despre ce crede alde Aristotel despre dreptate (in capitolul [...]',0,'1','Incutio XML-RPC -- WordPress/2.3.1','pingback',0,0),(12946,959,'dush','tirbushon@gmail.com','http://dushrece.blogspot.com','86.125.85.5','2008-01-19 12:58:19','2008-01-19 10:58:19','io zic sa ii bati un cui in podea si s-o legi cu lanturi..daca sclava e sa spele..apai sclava sa fie..si sa spele...ce ..cum adica sa ii arda de dantzuit prin baie :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(12960,957,'ramonici','','','79.113.150.155','2008-01-19 16:12:19','2008-01-19 14:12:19','shi cand te-ai uitat inapoi precum Orfeu, ce ai pierdut a doua oara? :-?',0,'1','Opera/9.10 (Windows NT 5.1; U; en)','',0,0),(12967,956,'Andreea MKT','supergirgir@yahoo.com','','89.43.186.64','2008-01-19 17:33:13','2008-01-19 15:33:13','PFUAAAII, Gropare, ai putea sa scrii un blog \"barbatzi corporatisti, futeti-va nevestele?\" Te rog eu!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(12975,957,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2008-01-19 18:48:04','2008-01-19 16:48:04','Ce o pierdut si Orfeu :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(13081,960,'eugen','icgel@yahoo.com','http://www.cepanamea.ro','89.41.164.224','2008-01-20 17:09:45','2008-01-20 15:09:45','Puterea superba...si butonul rosu...astea doua traduceri imi plac...referitor ;a frecat, hmmm...nu ma bag..',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(13090,960,'Ureche Mare','','http://www.ju-jutsu.ro','82.79.188.108','2008-01-20 19:03:12','2008-01-20 17:03:12','Mie mi-ar fi frica sa declansez butonul rosu de pronire.\r\nSi ala de oprire ce culoare are? Dar oare exista?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1)','',0,0),(13092,957,'ramonici','','','89.33.174.82','2008-01-20 19:35:47','2008-01-20 17:35:47','Orfeu asta (tzuca-l mama) shi-o pierdut muierea pt a doua oara. Nu spune ca ai patzit la fel... :-',0,'1','Opera/9.10 (Windows NT 5.1; U; en)','',0,0),(13096,960,'cÄƒlÄƒ','acalarasu@gmail.com','http://adriancalarasu.wordpress.com/','89.32.19.126','2008-01-20 20:36:44','2008-01-20 18:36:44','Bai deci daca-i facuta de chinezi traducerea, e f. tare! Ca vorba aia, in ziua de azi chinezii sunt capabili sa produca ORICE! Mai ales alti chinezi.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) )','',0,0),(12937,956,'manole','redtailanda@yahoo.com','http://www.mesterulmanole.wordpress.com','80.97.177.117','2008-01-19 11:34:08','2008-01-19 09:34:08','groparele, iti multumesc. :)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(12938,957,'manole','redtailanda@yahoo.com','http://www.mesterulmanole.wordpress.com','80.97.177.117','2008-01-19 11:40:42','2008-01-19 09:40:42','of! groparele ce bine te inteleg. asa mai zice si barbatu-miu. da\' nu ca pleaca la mama-sa, ci la maica-mea. si nu sa stea acolo  ci sa vina inapoi amandoi... :)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(12939,959,'manole','redtailanda@yahoo.com','http://www.mesterulmanole.wordpress.com','80.97.177.117','2008-01-19 11:42:26','2008-01-19 09:42:26','pai, poate vrea sa o inviti ... la dans! s-o fi saturat sa danseze singura! :)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(12644,952,'Motociclistul','eggprotect@yahoo.com','http://www.motociclist.com','92.80.146.109','2008-01-16 19:58:52','2008-01-16 17:58:52','Motociclistule imi pare rau dar momentan nu fac schimb de link-uri. Te voi anunta eu dupa ce fac calculele! Merci de intelegere',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(12645,952,'Motociclistul','eggprotect@yahoo.com','http://www.motociclist.com','92.80.146.109','2008-01-16 20:08:16','2008-01-16 18:08:16','imi pare rau am scris gresit la copy paste doresc sa fac un schimb de linkuri in blogroll cu tine postez zilnic si incerc sa devin si eu un blogger adevarat ! multumesc daca doresti te astept sa postezi la mine cum sa te trec daca e trece-ma Motociclistul !',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(12652,952,'PhenoBarbieDoll','oana.gavrila@mediafax.ro','http://blog.360.yahoo.com/poisongirl94','86.120.236.133','2008-01-16 20:56:51','2008-01-16 18:56:51','Gropare, io nu vreau nici un schimb, numa\' satz urez la multi ani pe stil vechi!',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1)','',0,0),(12454,950,'C.T.Daniel','iwfdanielo@gmail.com','http://www.toddy.wordpress.com','89.34.32.45','2008-01-15 11:42:02','2008-01-15 09:42:02','Care ar fi motivele pentru care faci asta?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US) AppleWebKit/523.15 (KHTML, like Gecko) Version/3.0 Safari/523.15','',0,0),(13058,960,'vizionarul','alinmiron_19@yahoo.com','http://vizionarul.wordpress.com','89.35.87.15','2008-01-20 12:19:29','2008-01-20 10:19:29','tot de pe acelasi sait:\r\n\r\nGreutate mica, usor de folosit, indeplineste operatii de frecare/lustruire podele. Ideal pentru mici spatii comerciale sau pentru casa. Facilitati pentru profil redus, permitand folosirea lui la curatatul pe sub mese, etc. Completa serie de accesorii valabile, incluzand rezervorul de solutie, punte de comanda, dispozitive speciale pentru podea si peria de frecat. Normal, se folosesc dispozitivele pentru podele netede si intinse iar sistemul de perii pentru sectiuni acoperite de mocheta sau gresie. \r\n\r\nDeci s-a inventat masina de frecat...',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648)','',0,0),(13059,959,'vizionarul','alinmiron_19@yahoo.com','http://vizionarul.wordpress.com','89.35.87.15','2008-01-20 12:22:18','2008-01-20 10:22:18','gropare, ai facut o gresala mare ca t-ai luat masina de spalat samnsug... pentru ca samnsug se pricep doar la displee.... Ia incearca de conecteaz-o la calculator pe usebeu sau pe ceva, poate poti juca un soliter...\r\n\r\nDaca vrei masina de spalat ca lumea, ui aicea:\r\n\r\nhttp://www.planetamoldova.net/snd/reclame/masinile_de_spalat.mp3',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648)','',0,0),(12854,957,'Nurya','','http://nurya2007.blogspot.com','81.196.216.97','2008-01-18 17:41:39','2008-01-18 15:41:39','gropare... de ce sa zica femeia asa? de ce ar vrea o femeie sa stea cu soacra???',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1) Gecko/20061010 Firefox/2.0','',0,0),(12855,957,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-01-18 17:45:15','2008-01-18 15:45:15','EXACT! Pentru ca tu esti cu mult mai naspa chiar decat soacra-sa! :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(12860,957,'eugen','icgel@yahoo.com','http://www.cepanamea.ro','89.41.164.224','2008-01-18 19:19:53','2008-01-18 17:19:53','Crect, e cea mai mare pedeapsa pentru un barbat, pentru ca el nu se poate duce la soacra sa se planga..',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(12861,956,'eugen','icgel@yahoo.com','http://www.cepanamea.ro','89.41.164.224','2008-01-18 19:21:14','2008-01-18 17:21:14','Ce blog e asta?  Am citit si...wow...mai...curge apa la baie?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(12862,955,'eugen','icgel@yahoo.com','http://www.cepanamea.ro','89.41.164.224','2008-01-18 19:22:15','2008-01-18 17:22:15','Minciuna curata...arata-ne poza..poza...sa vedem dovada..',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(12863,119,'Nascut din spermatozoizi campioni &raquo; Blog Archive &raquo; Masina de spalat Samsung f1045AV','','http://www.groparu.ro/?p=959','82.103.137.253','2008-01-18 19:41:42','2008-01-18 17:41:42','[...] Nu va luati. Io mi-am loat. [...]',0,'1','Incutio XML-RPC -- WordPress/2.1.2','pingback',0,0),(13051,956,'c|neva','cineva_df@yahoo.com','http://www.diaconuflorin.ro','78.96.86.55','2008-01-20 10:45:25','2008-01-20 08:45:25','Si daca nu e femeia mea cea care face astfel de lucruri, cu toate ca \"poarta bluza ei azurie\"? :&gt;',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(13158,961,'dush','tirbushon@gmail.com','http://dushrece.blogspot.com','193.230.155.70','2008-01-21 11:38:18','2008-01-21 09:38:18','avioane dom\'le..avioane :))..tot nu l-a luat nime..si sa vezi ce mare se face si saptamana asta ;)) \r\n\r\noricum..cre ca as lua firma la care lucru..numa sa il oftic pe imbecilu\' de neamt si sa il pot strange de gat fara sa am remuscari ca as ramane fara munca :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(13159,961,'Mih_nea','mihnea_xxyahoo.com','','62.217.236.12','2008-01-21 11:57:48','2008-01-21 09:57:48','o casa undeva pe langa munte, in mijlocul unui teren de 50 de hectare, sa nu-mi vad vecinii decat cu binoclul, dac-am chef. De ce mai ramane gratare si bere neagra pana mor.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(13154,961,'Tavi','','','194.99.245.11','2008-01-21 11:01:42','2008-01-21 09:01:42','Ma mut in Cuba si o sa beu rom si o sa fumz trabucuri si alte alea desi la mine mere bancul cu Bula cu castigatul la Lotto.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(13152,402,'ruseu','ruseu.maria@yahoo.com','','79.112.4.99','2008-01-21 10:35:48','2008-01-21 08:35:48','in nici un caz nul voi vota pe basescu si nu voi merge deloc la vot intrucit nu am nici o speranta in rominia .in rominia au loc doar hotii slugarnicii perversii si tiganii am o fiica pe care o cresc singura si abia astept sa rezistam sa o ajut sa plece din tara sa ramina in aceasta tara elene basescu si toti copii ilustrii ai hotilor -politicieni care nea adu in cea mai crunta saracie securistii de ieri traiesc foarte bine azi si au furat si fura',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(13151,961,'Nurya','','http://nurya2007.blogspot.com','81.196.216.97','2008-01-21 10:29:41','2008-01-21 08:29:41','9 milioane... banca elvetia si ceva insule - paradis fiscal - aici ar merge vreo 8.500.000 si de restul dezmast cu toata satra... cata bere poti bea gropare? iti iau de 100.000 Euro bere... te bagi?\r\n...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1) Gecko/20061010 Firefox/2.0','',0,0),(12847,956,'Usim','mihaimitan@gmail.com','','92.80.61.3','2008-01-18 15:54:57','2008-01-18 13:54:57','E clar! Esti lulea dupe Groparita!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(12848,957,'ramonici','','','79.113.148.216','2008-01-18 16:09:06','2008-01-18 14:09:06','eshti prea tare! acuma eshti la tema: FEMEIA? apropo.. mi-ai lipsit zilele trecute, cred ca vreo 4 la numar.. ca nu aveam ce citi',0,'1','Opera/9.10 (Windows NT 5.1; U; en)','',0,0),(12849,957,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-01-18 16:10:41','2008-01-18 14:10:41','@ ramonici: apai eram cu mintea in vesnicele plaiuri ale vanatorii, pescuiam din luntrea lu Charon. Cand am ramas fara bere am revenit, ca Orfeu. A, si finca-s al dreq, m-am si uitat inapoi, tat ca el!\r\n\r\n@ Blue: Hmmm... bea bere! Si incearca sa transpui pe blog rÃ¢su\' ala care te prinde cand meri la buda, te uiti in la tine oglinda, si incerci sa pari serios-oasa.\r\nMie nici in ziua de azi nu mi-o reuÅŸit, da\' ui - ma tat kinui. Sh ii kinui sh p-altii!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(12866,956,'innuenda','innuenda.innuenda@gmail.com','http://innuennda.blogspot.com','92.80.51.213','2008-01-18 20:00:13','2008-01-18 18:00:13','Cea mai originala, superba, actuala, duioasa, haioasa, profunda, barbateasca, geniala declaratie de dragoste. Gropare, m-ai spart! O sa te coste! :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(12870,959,'PhenoBarbieDoll','oana.gavrila@mediafax.ro','http://blog.360.yahoo.com/poisongirl94','86.120.236.133','2008-01-18 21:06:05','2008-01-18 19:06:05','\"Fuck your nostril, you bum\" Priceless!',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1)','',0,0),(12873,911,'qwer','qwer_1w@yahoo.com','','77.81.62.158','2008-01-18 21:52:25','2008-01-18 19:52:25','\"ditamai erectia dimineatza\" ....... vezi ca-i de la prostata..... mai mergi pe la urolog..............',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(12875,952,'nenea cosmos','domnu_cosmos@yahoo.com','http://www.nenea.wordpress.com','92.80.2.244','2008-01-18 21:55:36','2008-01-18 19:55:36','toata cultura mea generala si deasemenea si generoasa zice ca la sirbi se trece inot. de pasaport n-am auzit nimic. deci groparul nu stie sa inoate!',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(12876,952,'nenea cosmos','domnu_cosmos@yahoo.com','http://www.nenea.wordpress.com','92.80.2.244','2008-01-18 21:58:47','2008-01-18 19:58:47','deasemenea va recomand sa intrati si pe saiturile:\r\n\r\nwww.biciclist.com\r\n\r\nwww.triciclist.com\r\n\r\nwww.pieton.com\r\n\r\nwww.planorist.com',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(12828,956,'li','alina_livia_lazar@yahoo.com','http://www.alinalivialazar.blogspot.com','89.136.204.179','2008-01-18 11:16:25','2008-01-18 09:16:25','aceasta este o declaraÅ£ie de dragoste',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(12830,956,'darius f','darius2u@yahoo.com','http://desprepsd.wordpress.com/','82.79.52.137','2008-01-18 11:31:51','2008-01-18 09:31:51','Cre ca ar fugi Geoana din tara. Ce ar fi sa incerci odata? Poate ne scapi de probleme si nu mai tre sa facem revolutie.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(12840,957,'george','reallyinsane@gmail.com','','193.138.195.202','2008-01-18 14:47:53','2008-01-18 12:47:53','domnu Groparu, esti tematic.\r\nbanuiesc ca azi esti pe curba aia naspa a bioritmului.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(12841,957,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-01-18 15:00:22','2008-01-18 13:00:22','Cui ii spui tu \"domnu\", mah gentlemanule???',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(12663,952,'zdranga','coraelena@gmail.com','http://www.zdrangazdranga.blogspot.com','79.113.139.246','2008-01-16 23:06:43','2008-01-16 21:06:43','Mi se pare mie sau pentru Serbia ai fi avut nevoie si de viza, oricum? sau de niste slujbe eventual, sa scapi tefer din chefurile lor sau de vreo intoxicatie alimentara? asta desigur pentru neexperimentati...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(12845,957,'Blu3','mide765@yahoo.com','','86.106.50.83','2008-01-18 15:48:10','2008-01-18 13:48:10',':)) de unde dumnezeu le scoti:)) iti citesc blogu zilnic si vreau sa ma apuc si eu de \"blogareala\" numa nu am atata imaginatie ca si tine :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(12628,952,'eugen','icgel@yahoo.com','http://www.cepanamea.ro','89.41.164.224','2008-01-16 16:25:14','2008-01-16 14:25:14','am fost in Serbia de cateva ori. Am petrecut alaturi de ei, dupa Razboiul din Kosovo...dupa ce se imbata, devin dramatici, canta cu totii despre razboi, despre patrie. In rest sunt oameni ok, sufletisti si prietenosi.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(12658,16,'Lush','copilura@yahoo.com','http://www.blogulucostel.com','81.180.153.216','2008-01-16 22:26:33','2008-01-16 20:26:33','Ba..de cand s-a renovat, recunosc..are termopane..ce poti sa iti doresti mai mult?poate colegi mai putin basinosi:))',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1)','',0,0),(12827,956,'Rares','rares.dadarlat@googlemail.com','http://nimic.de.vazut','80.96.36.139','2008-01-18 10:58:48','2008-01-18 08:58:48','Am ras.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(13978,969,'Mih_nea','mihnea_xxyahoo.com','','62.217.236.12','2008-01-28 08:37:31','2008-01-28 06:37:31','bah, sa stii ca nu prea mai avem tantzari...\r\neu votez pt. autobuz, ce va fi adoptat ca mascota sub numele de \"sauna ecologica bucuresteana\" - ecologica pt. ca nu-i nevoie de lemne, carbuni sau gaz ca s-o incalzesti - ajung utilizatorii',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(13165,961,'catalin','catalin_heghes@yahoo.com','http://sec.ablog.ro','84.232.142.163','2008-01-21 13:28:15','2008-01-21 11:28:15','m-as muta intr-o casa pe o faleza din grecia (initial voiam italia... da acuma nu se mai poate) si as sta toata ziua cu bericica si o grecoaica simpatica langa mine. da oare daca nu joc am vreo sansa sa castig?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(13166,961,'ramonici','','','79.113.148.159','2008-01-21 13:29:59','2008-01-21 11:29:59','mi-ash cumpara un sfert din cj, asta la super oferta, ca deh mi se vinde mie ;)) mi-ash mai face 5 camine de studentzi in care sa am shi eu loc sa nu platesc chirie, dar ash sta acolo ca-mi place. aaa... cred ca restu i-ash baga in banci elevtziene shi ash trai numa din dobanda. i-ash face in ciuda lu\' Boc, ca am mai multzi bani decat el &gt;:)',0,'1','Opera/9.10 (Windows NT 5.1; U; en)','',0,0),(14699,976,'Andreea MKT','supergirgir@yahoo.com','','89.43.186.64','2008-02-02 18:24:31','2008-02-02 16:24:31','Turambar, i dont have the patience to watch this. I know Ai No Corrida (the original title) is smth for many. I am just not one of the many:)\r\n\r\nGro, deci cu ce gagica ma sarut luni de la firma?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(14700,976,'Andreea MKT','supergirgir@yahoo.com','','89.43.186.64','2008-02-02 18:25:04','2008-02-02 16:25:04','Turambar: totusi, e ceva ca ai zis Brigitte Lahaie si nu Jenna Jameson.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(14701,976,'Turambar','mirel@ccsb.ro','http://turambarr.blogspot.com','79.114.190.130','2008-02-02 18:25:36','2008-02-02 16:25:36','Fratzioare, daca ma imbat bine, itzi vorbesc shi in japoneza. In ideograme fluturate din mana. Si cu diacritice, bineintzeles... \r\n\r\nArigato gozaimashite, goroparu sama :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(14702,976,'Turambar','mirel@ccsb.ro','http://turambarr.blogspot.com','79.114.190.130','2008-02-02 18:28:29','2008-02-02 16:28:29','@ Andreea: neah. Jenna sucks. Brigitte is the real thing. A normal biuty, spreading herself in bursts of unexpected oral wisdom.  :p\r\n\r\n<i>Sorry fer the double post, but there ain\'t no editing facilities in Cluj, as it seems... </i>\r\n\r\n:)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(13171,961,'mishu','mishu@doingtheartwork.com','http://www.doingtheartwork.com','82.77.126.254','2008-01-21 15:08:21','2008-01-21 13:08:21','Eu te-as cumpara pe tine si te-as pune la munci silnice (iti zic eu de care). Din restul de 8999900 de Euro mi-as face un turul lumii, in special Japan &amp; Co pentru cativa ani in care m-as gandi in ce sa investesc in cazul in care imi mai raman bani :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(13178,957,'Botache','nasturei_verzi@yahoo.com','http://www.nasturei.wordpress.com','82.77.126.148','2008-01-21 16:45:52','2008-01-21 14:45:52','Not fair! Eu m-am gandit la asta prima! :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.0; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(13741,957,'Replicile sÄƒptÄƒmÃ¢nii 21 at Jurnal de noapte','','http://www.andreicrivat.ro/2008/01/26/replicile-saptamanii-21/','212.227.64.193','2008-01-26 10:27:02','2008-01-26 08:27:02','[...] È˜tii care ar fi cea mai mare rÄƒzbunare din partea luâ€™ nevastÄƒ-ta? SÄƒ-È›i zicÄƒ: â€œGata, plec la MAICÄƒ-TA!â€ (Groparu) [...]',0,'1','Incutio XML-RPC -- WordPress/2.2','pingback',0,0),(14693,976,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2008-02-02 17:18:36','2008-02-02 15:18:36','@ Turambar: Ba, deci tu mai stii multe limbi? Ca ma disperi deja! Ce fel de erudit esti tu care stii mai multe limbi chiar decat mine???\r\n\r\n@ sabina: da, stiu, sunt un nemernic ca dau vina pe ele. U should reaaaaally know...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(14691,58,'Cecilio','','http://groups.google.com/group/helena45ae/web/king-of-the-hill-cartoon-porn','194.110.161.30','2008-02-02 16:56:42','2008-02-02 14:56:42','<strong>King Of The Hill Cartoon Porn...</strong>\n\nJon Tester is a third-generation Montana farmer who understands\n...',0,'1','USERAGENT','trackback',0,0),(13188,961,'CAESARUS','caesarus@adresafalsa.ro','http://utopium-advertising.blogspot.com','79.113.91.21','2008-01-21 20:18:11','2008-01-21 18:18:11','As da shaorma gratis o saptamana, in Marty, pe Carnet de student....LA FARFURIE!\r\nDaca mai raman bani...dau si bere!...pe carnet de student clar!',0,'1','Mozilla/5.0 (Macintosh; U; Intel Mac OS X; en) AppleWebKit/523.12.2 (KHTML, like Gecko) Version/3.0.4 Safari/523.12.2','',0,0),(13189,961,'FanFan','mihaela11111@yahoo.com','','89.137.195.207','2008-01-21 20:21:02','2008-01-21 18:21:02','As face un camin de batrani, o gradinita de lux, gratiuta, pentru copiii familiilor cu venituri modeste, si o cafenea elitista, cu seri tematice: o seara de teatru, una de poezie, una de muzica folk, una de rock, una de lectura, unde preturile sa fie mici si oamenii de calitate, si invitatii sa vina de drag, nu pentru bani. Si, anual, o bursa de studii in strainatate unui copil sarac si genial. Si ar mai fi atat de multe... incat mi-e teama ca nu mi-ar ajunge banii... Vise...',0,'1','Mozilla/5.0 (Macintosh; U; Intel Mac OS X; en) AppleWebKit/523.12 (KHTML, like Gecko) Version/3.0.4 Safari/523.12','',0,0),(14618,976,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2008-02-02 03:49:34','2008-02-02 01:49:34','it\'s called \"the blaze of glory\" :D what goes up must come down...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(13197,961,'nenea cosmos','domnu_cosmos@yahoo.com','http://www.nenea.wordpress.com','92.80.12.153','2008-01-21 21:55:02','2008-01-21 19:55:02','frate, deci la mine pe santier exista cacastori ecologice, adica pute a natura (natura umana) acolo asa de intens ca prefer de cind ma stiu sa savirsesc fapta acasa, in minunea mea de buda, oripilind apartamentul, inaintea plecarii la job. numai tu care esti birocraticus iti permiti sa te caci in timpul serviciului, adica platit, eu pe santier fug de fapta asta ca de dracu, mai bine ma fute tot managementul superior decit sa ma cac in santier, indiferent daca tin o ecologica numa pentru mine si tot nu imi vine.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(13198,961,'nenea cosmos','domnu_cosmos@yahoo.com','http://www.nenea.wordpress.com','92.80.12.153','2008-01-21 22:01:04','2008-01-21 20:01:04','iar la alea cu melioanele am socotit-o de mult. ma voi ocupa cu fericirea mea si a neamului meu. 9 melioane pe an inseamna ca am vreo juma de melion dobinda, adica imi ramin vreo 30 000 cocari pe luna dupa ce imi platesc parcarea la un hovercraft si la o basculanta de aia de 100 de tone care este adevarata masina de ciumeg, nu limuzinele pe care le au multi melionarii astia ai nostri. o mie de cocari pe zi cred ca imi ajung. as trai numai de vreo 10 ori mai bine ca acum, deci cred ca m-as descurca.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(13200,964,'ramonici','','','79.113.148.159','2008-01-21 22:39:56','2008-01-21 20:39:56','nu! a fost o postare despre cei plictisitzi de munca :)) shi despre cozile gen \"coada la lapte pe vremea lu\' Ceashca\" :D',0,'1','Opera/9.10 (Windows NT 5.1; U; en)','',0,0),(14678,976,'sabina','simina_muresan@yahoo.com','','86.105.121.103','2008-02-02 14:32:41','2008-02-02 12:32:41',':)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(13204,964,'cÄƒlÄƒ','acalarasu@gmail.com','http://adriancalarasu.wordpress.com/','89.32.19.126','2008-01-21 23:04:40','2008-01-21 21:04:40','bine Gropule, bine ai venit in 2008.\r\ncu tehnologia, zic.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) )','',0,0),(13762,970,'manole','mesterulmanole07@gmail.com','http://www.mesterulmanole.wordpress.com','89.32.123.108','2008-01-26 13:48:57','2008-01-26 11:48:57','mai uita-te si tu la televizor, mai fa un cornet dintr-un ziar. Hai mai Groparele ca nu ne-am schimbat tara! \r\nSi oricum eu am citi: \"De ce pe azi nu am scris nici o postare.\"  :)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(14365,972,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','83.103.128.60','2008-01-31 08:13:39','2008-01-31 06:13:39','sanatate maxima, bai gropare! si io m-am pricopsit cu o griputza, stiu cum ii... mama ma-sii',0,'1','Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.1.11) Gecko/20061201 Firefox/2.0.0.11 (Ubuntu-feisty)','',0,0),(14663,976,'Turambar','mirel@ccsb.ro','http://turambarr.blogspot.com','79.114.190.130','2008-02-02 12:01:20','2008-02-02 10:01:20','typo: ...nu e aceeasi cu cea <b>europeana</b>. my bad. sorry :(',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(14664,973,'Turambar','mirel@ccsb.ro','http://turambarr.blogspot.com','79.114.190.130','2008-02-02 12:03:27','2008-02-02 10:03:27','Si cu o mana supt padura, incercand sa-shi aduca aminte daca o mai are shi unde a pus-o shi ce trebuie sa faca cu ea. Tz tz tz. Old age is such a cold gun... :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(14379,972,'marz','mariusrott@yahoo.com','','81.12.163.178','2008-01-31 10:38:40','2008-01-31 08:38:40','f nasol... acum ca ai virus, ti-a mai bagat si dom\' doftor un phishing.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(14380,972,'zanetti','valy_alexe@yahoo.com','http://www.blogoperativa.com/zanetti','86.55.176.81','2008-01-31 10:52:25','2008-01-31 08:52:25','ai dreptate ma.esti din bucata de creier.nu inteleg de ce sunt mai multi spermatozoizi campioni.\r\nmulta sanatate :)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; SIMBAR={6D4C1160-A44C-41C8-A9CA-57EAC9AD608C})','',0,0),(14662,976,'Turambar','mirel@ccsb.ro','http://turambarr.blogspot.com','79.114.190.130','2008-02-02 12:00:21','2008-02-02 10:00:21','Hmmmm.... Nu\'i chiar ashe, Andreea. It\'s not about porn and sex. Pentru alea egzista Brigitte Lahaie shi alte dame surazatoare shi de larg consum. That movie is about craving, and passion, and desire, and desperation, and formality, and social pressure, and craving, and craziness. \r\n\r\nIt happens to involve sex, but it definitely ain\'t primarly about sex. It\'s about lust and death and fucked-up brains and people. Iar retorica vizuala japoneza shtii si tu ca nu e aceeasi cu cea japoneza. E un gust care se invatza, la fel ca shi ceaiul verde.\r\n\r\nDo i ta shi ma shi te, Anandreea sama... :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(14382,972,'mo','verde_poveste@yahoo.com','','194.126.220.20','2008-01-31 11:09:18','2008-01-31 09:09:18','Ui povestea mea despre vraci comunisti: deci io am inceput scoala cu un an mai tarziu decat altii, nu din cauza ca nu as fi supradotata si ubertalentata ci din cauza ca mostenisem ficatzii din partea lu\' tac-miu si facui o hepatita de tata frumusetea. Pe chestia asta am stat io 2 saptamani intr-un spital jegos si-am mancat la marmelada pe pita de cred ca tata viata n-o sa-mi mai trebuiasca, dupa care inca 2 saptamani am donat zilnic cate o eprubeta de bulion. Cum fu prima donatie de bulion? \r\n\r\nRanjet de la vracea in halat alb: \"vaaaai, ce draguta esti. stai cuminte si dureaza numa-un pic!\"\r\nIo: \"mrrrrrrrrz, grrrrrrz, hrrrrrrrrz\"(ca nu stiam sa injur)\r\nVracea leaga garou\' pe stanga, ma pune sa incordez brandu\' de 6 ani, acu\' face fasss in mana mea, dupa care ea se intinde neglijent inspre eprubete. Scoate una si o atarna de ac intru colectare, dupa care asteptam (acilea poti sa iti imaginzei ceva muzica de lift). ceva mai tarziu, cand se umpluse deja aproape tata eprubeta, ma uit io intr-o doara inspre poala ei si ce vad? o baltita in care tot cade din eprubeta cate-un pic, pic, pic.\r\nIo: \"Tanti, ui cum curge!\"\r\nVracea: \"Ioi! Nu-i nimic, TRECEM LA MANA DREAPTA\"\r\n\r\nSi uite-asa ma intreb si acum daca tanti aia era o vaca cu cabina sau eram io un exemplar atat de special incat ii trebuiau mai multe mostre pentru clonare. Dar fin\'ca pe strada n-am vazut nici o clona, inclin spre varianta unu.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1)','',0,0),(14383,972,'kmi','camelianeculai@gmail.com','','80.86.123.198','2008-01-31 11:13:28','2008-01-31 09:13:28','io incepusem sa te \"dojenesc\" in mintea mea ca nu mai scrii si tu ceva, da\' acu\', cu scriitura asta, nu mai am ce zice :)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1)','',0,0),(14660,976,'Andreea MKT','supergirgir@yahoo.com','','89.43.186.64','2008-02-02 11:25:50','2008-02-02 09:25:50','Am vazut eu Realm Of Senses and it sucked. Si o putza mai mica nu cred ca exista. La sfarsit, Stupid San o ramas si fara aia.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(14387,972,'IepurasulAtomic','praetorian21uk@yahoo.com','','192.100.130.8','2008-01-31 12:17:22','2008-01-31 10:17:22','Pai cum sa crape Groparu\'? Cine-l ingroapa? Deci radem, glumim, da\' nu parasim incinta, clar domnu\' Groparu\'? :) Revenire grabnica, da\' nu mai repede de 9 martie (in acte doar). Ia aminte la oamenii intelepti, ca stiu ei mai bine...',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(14655,58,'Dantel','','http://groups.google.com/group/bellangeref80/web/big-indian-tits','194.110.161.30','2008-02-02 10:28:41','2008-02-02 08:28:41','<strong>Big Indian Tits...</strong>\n\nMp3 Songs Reviews - Downloads Track - Zabra\n...',0,'1','USERAGENT','trackback',0,0),(13624,970,'mirra','','','83.103.137.234','2008-01-25 11:04:51','2008-01-25 09:04:51','apai,da...la tatzi ni greu!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(15599,986,'cepanamea','icgel@yahoo.com','http://www.cepanamea.ro','89.41.164.74','2008-02-09 19:43:06','2008-02-09 17:43:06','Stii ce, spune-i lui Oedip ca nimeni nu-i perfect si ai si tu dreptu\' la un usturoi, macar un usturoi pe zi..',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(13622,970,'oedip','oedip74@gmail.com','http://oedip.blogspot.com','89.137.99.163','2008-01-25 10:10:50','2008-01-25 08:10:50','io zic ca poti... sa-t simti propriul miros... numa ala saracu nu pute, pentru ca nu putza... mno...',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.2)','',0,0),(13515,968,'IepurasulAtomic','praetorian21uk@yahoo.com','','192.100.130.8','2008-01-24 10:42:41','2008-01-24 08:42:41','Deci, ca sa ne pricepem, nu ai inteles (sau invers) :P. Deci:\r\n\r\n1. Io imi dau \"banii de marire de penis pentru operatia DE SAN...\", carevasazica stiam ca asta e cu booobu\' in pensie, deci is cat se poate de informat corect (sau corect informat, ca nici nu mai stiu) in ceea ce priveste asemenea TRAGEDIE, cum o sarit astia in ziar s-o numeasca.\r\n2. Gropare, jeniala ideea asta cu un boob in minus, da\' vezi ca cineva ti-o luat-o inainte. Nenorocitul!!! Da\' mai bine asha, ca pana faceai Medicina, pana te specializai, pana ajungeai chirurg de renume s-o invalidezi pe Laura si sa-i iei painea de la gura si obiectu\' de facut bani...dura si cre\' ca aproape ca nici nu merita.\r\n3. Gropare, io aproape ca te dispretuiesc c-ai sarit peste partea cea mai importanta a statusului meu: cea umanitara. Pai tu in loc sa ma ajuti sa strang bani pen\' saraca fata s-o lasam si fara celalalt san (si-un morcov pentru iepurash ca asha mi-i foame), tu numa\' contemplezi la singurul san care i-o ramas fetei?\r\n4. Deci (din nou)....intentionez sa promit ca ma apuc de scris din nou pe blog, destul de curand. Carevasazica, ochii mari (ca sa nu zic belitzi, ca-i un cuvant asha urat) ca revin. \"I\'ll be back!\" vorba guvernatorului cu ochiu cibernetic.\r\n5. Data viitoare, ca nu mai stiu ce vroiam sa zic....\r\n\r\nAH DA\r\n\r\n6. Ati auzit ca ne-or gasit-o pe Elodia pe Marte (sau o zis Martie?..ca nici...exact, nu mai stiu).\r\n\r\nPace p\'afara!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(13632,970,'psaico','blog@psaico.info','http://www.psaico.info','78.96.86.55','2008-01-25 12:15:50','2008-01-25 10:15:50','odd things huh ? :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(14298,971,'Lorand R. Minyo','lorand.minyo@simpliq.com','http://blogs.simpliq.ro/lorandminyo','89.36.21.82','2008-01-30 19:58:39','2008-01-30 17:58:39','Te citesc de o vreme buna (via Marius/Perry si alti clujeni de-ai nostri de seama) azi dar am ras cu lacrimi la mascotele bucurestiului :)\r\nNoah bun, de azi trecem in blogroll cu siguranta.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(14300,971,'Laura','mars1953@web.de','','84.160.106.40','2008-01-30 20:00:54','2008-01-30 18:00:54','mai groparule, oare te-o parasit vreo femeiusca de ai asa nevoie sa-ti magulesti propriul amor? Ce-mi lipseste e sa vad  arogantza unui blogger care stie singur ca ceea ce scrie are calitate si nu are nevoie sa-i spuna asta peblea. Si cu reclama asta pentru alti bloggeri ce-i? Macar te platesc bine? Fii umpic mai arogant si lasa linusala ca nu mai suntem in epoca ceausista! Pun articolul asta pe seama virozei.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(13504,966,'Mih_nea','mihnea_xxyahoo.com','','62.217.236.12','2008-01-24 08:46:30','2008-01-24 06:46:30','poa\' sa ninga, poa\' sa ploua\r\nmie mi se rupe-n... podgoria pe care mi-a lasat-o bunicu\'\r\no fi ea buna Silva, da\' nici vinul meu nu-i rau :)\r\nmodificam procentul bere-vin',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(14267,971,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2008-01-30 15:42:53','2008-01-30 13:42:53','@ Iepurile: stiu, si lui i-o placut mai mult varianta mea, ca mi-o zis.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(14268,971,'julius constantinescu','julius@universitateacraiova.ro','http://www.7plus.ro','84.232.162.195','2008-01-30 16:02:15','2008-01-30 14:02:15','@Gropare, vezi ca azi m-am pus bine cu sfantul Constantin, asa ca daca dai in mine...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(13756,970,'innuenda','innuenda.innuenda@gmail.com','http://innuennda.blogspot.com','92.80.42.243','2008-01-26 13:10:06','2008-01-26 11:10:06','Gropare, poÅ£i mai mult! Pe azi, nu am citit nici eu nicio postare.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(13220,964,'Usim','mihaimitan@gmail.com','','86.121.183.224','2008-01-22 03:05:59','2008-01-22 01:05:59','Pai n-aveai monitor la masina de spalat? Si mai ales acum ca ti s-a stricat Samsung-ul, poti sa-i folosesti display-ul cu mare succes pe post de monitor. Ce-ti mai trebuia si Asus-ul asta? Avea dreptate cercelatu\'.',0,'1','Opera/9.10 (Windows NT 5.1; U; en)','',0,0),(14155,969,'soferul','lucian.purcareanu@gmail.com','http://soferul.wordpress.com','193.186.33.9','2008-01-29 15:26:31','2008-01-29 13:26:31','Romanian dogs finishing what Guadalcanal didnâ€™t\r\nm-a spart de ras asta :)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1)','',0,0),(14194,969,'nenea cosmos','domnu_cosmos@yahoo.com','http://www.nenea.wordpress.com','92.80.61.155','2008-01-29 22:17:31','2008-01-29 20:17:31','http://nenea.wordpress.com/2008/01/28/leapsa-o-mascota-pentru-bucuresti-oaia/',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(14186,969,'andreanum','andreanum@yahoo.com','http://andreanum.wordpress.com','89.40.184.35','2008-01-29 20:25:43','2008-01-29 18:25:43','io as vota ciinele cu trei picioare ca mascota a capitalei noastre: n-o fi el intreg sau frumos, dar merge frate si-asa, las-o-n mortii ei de treaba.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(14161,969,'catalin','xssolo@gmail.com','http://www.bairescompartido.com/','190.17.92.168','2008-01-29 16:19:58','2008-01-29 14:19:58','e vreo prob cu xsolo.biz? pt ca am comentat recent de 2 ori si nu se intimpla nimica??!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(14162,969,'mihai ursu','','http://mihaiursu.wordpress.com','84.232.196.234','2008-01-29 16:22:11','2008-01-29 14:22:11','mai poti adauga shaorma - compulsory part of a wholesome manelistic diet. sa nu uitam pitzipoanca de centura - soferii de tir e si ei copii si vrea sa se joaca... sau cocioaba cu bulina rosie care costa cit o vila in miami doar pentru ca \"asta e pretul pietei\"...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(13420,968,'Basty','basty@canvas.ro','http://basty.wordpress.com','82.77.126.21','2008-01-23 19:12:58','2008-01-23 17:12:58','Iepurasu\' Atomic cred ca nu a fost informat corect, se pare ca donsoara Andresan merge la servis si doar cu un boob, ca cica ii bate un rulment. Boob-ului. Nu ei. Serios. \r\n\r\nDar imi place ideea ta.',0,'1','Mozilla/5.0 (Macintosh; U; Intel Mac OS X; en) AppleWebKit/523.12.2 (KHTML, like Gecko) Version/3.0.4 Safari/523.12.2','',0,0),(13421,968,'macabroo','raduccc@yahoo.com','http://rezistenta.blogspot.com','82.76.52.94','2008-01-23 19:15:19','2008-01-23 17:15:19','Pentru un moment m-am speriat. Credeam ca e planetara.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; en-GB; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(13422,961,'Ionut','ion@yahoo.com','','89.34.225.25','2008-01-23 19:19:58','2008-01-23 17:19:58','Casa la munte, la mare si in Bucuresti. Sa zicem 1mil$ pana acum.\r\nUn BMW M6 si un VW Golf(pentru oras asta). Multe prostituate de lux.\r\n\r\nMai raman cu 7.5mil. 1mil il pastrez de chelutiala, sa am sa ies si eu la Mac si restul ii bag in banci si imobiliare. Pe care le inchiriez sa iau banii de chirie.\r\n\r\nAcum trebuie doar sa pun un bilet.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(13383,967,'Eugen','icgel@yahoo.com','http://www.cepanamea.ro','89.41.164.224','2008-01-23 12:36:31','2008-01-23 10:36:31','Sa fiu eu frate cu Ciutacu si Badea? Nuuuuuuuuu, nu vreau o astfel de pedeapsa...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(13384,967,'andys','adi.cojocaru@utcb.ro','http://blogoperativa.com/andys/','193.231.5.245','2008-01-23 12:37:38','2008-01-23 10:37:38','&gt;\r\nAsta a fost una dintre dilemele mele la un moment dat... evident, un amic mai destept mi-a dat si raspunsul...',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Maxthon; .NET CLR 2.0.50727)','',0,0),(13385,967,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-01-23 12:40:58','2008-01-23 10:40:58','@ Eugen: din fericire, nici ei nu vor o asemenea pedeapsa! :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(13495,966,'manole','redtailanda@yahoo.com','http://www.mesterulmanole.wordpress.com','89.32.123.108','2008-01-24 07:07:06','2008-01-24 05:07:06','Hai groparele, ca suntem oameni seriosi si hotarati! Nu ne perturba pe noi 25%! Nici ca ne opreste si nici ca ne diminueaza cantitatea! NU mor caii cand vor caini! :)  :)  :)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(13399,967,'manole','redtailanda@yahoo.com','http://www.mesterulmanole.wordpress.com','81.181.92.157','2008-01-23 14:46:14','2008-01-23 12:46:14','mai groparele, da\'n logica asta, consoarta ta si consortul meu is si ei frati vitregi? Ei intre ei? Ei cu noi? Nu-i bine!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows 98)','',0,0),(13404,967,'baghy','baghy83@lycos.it','http://www.baghy.info','78.12.1.110','2008-01-23 15:47:54','2008-01-23 13:47:54','Gropare cu ce merem?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(13408,967,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-01-23 16:39:37','2008-01-23 14:39:37','Cu votca aia de seara... ca cica berea o scumpesc ejtia, nemernicii!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(13437,966,'catalin','catalin_heghes@yahoo.com','http://sec.ablog.ro','82.78.130.173','2008-01-23 21:11:02','2008-01-23 19:11:02','n-am zis nimic de taxa auto, de licitatii trucate, de pensii marite aiurea, de subventiile pentru babele care umplu transportul in comun, de spagile pentru doctori, de microbuzele pentru scoleri cu care se plimba alegatori, de baselu, de taricelu, udrelu si alte specimene... dar sa te loveasca asa in moalele capului si sa scumpeasca berea? asa ceva nu se face!',0,'1','Mozilla/5.0 (Windows; U; Win 9x 4.90; en-GB; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(15953,990,'ametzitul','','http://ametzitul.wordpress.com','62.217.236.12','2008-02-13 09:01:59','2008-02-13 07:01:59','mi-i prezinta shi mie cineva pe arabii ashtia? ofer comision...',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(13427,966,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2008-01-23 19:50:48','2008-01-23 17:50:48','Julica, m-ai magulit acuma cat nu m-ar fi magulit nici Liiceanu!\r\n\r\nIa-l, slefuieste-l, si da-i sa curge!\r\n\r\nPS: Cum adica \"sa-l imbunatatesti\"??? M-ai facut curios.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(16703,1008,'ametzitul','','http://ametzitul.wordpress.com','62.217.236.12','2008-02-21 10:24:03','2008-02-21 08:24:03','comentatorul lui peshte n-o fi shtiut ca Fidel l-a trimis pe Che sa-mprashtie revolutzia prin alte partzi, ca-i era frica de popularitatea lui :)\r\noricum, a mai ramas doar Ghaddafi ultimul revolutzionar-dictator inca la putere, ca Chavez shi Morales ashtia ie mici copii',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(16609,994,'tya','afrimtya@yahoo.com','http://www.afrim-tya.blogspot.com','82.77.126.254','2008-02-19 13:55:04','2008-02-19 11:55:04','@julius: stii bine ca nu-i adevarat. Eu is living proof:P. Ti-a spus asta pt ca ne vrea pe toate numai pt el. Nu-i place sa ne sharuiasca..',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(16610,995,'parsiimpar','lummi31@gmail.com','http://www.luminita-dragomir.ro/blog/','81.196.54.24','2008-02-19 14:35:43','2008-02-19 12:35:43','Gropare,\r\nAi vazut ce urare \"faina\" iti face Lupul Balai pe blogul lui???\r\nCum adica sa te faci calugar, tocmai acum cand ai revenit \"pe piata\"? :)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(16854,1009,'Eddie','el_e91@yahoo.com','http://blog.plustube.net','89.136.68.74','2008-02-24 05:47:19','2008-02-24 03:47:19','Misto',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(16735,1010,'ametzitul','','http://ametzitul.wordpress.com','62.217.236.12','2008-02-22 08:48:31','2008-02-22 06:48:31','pt. tine e compliment, doar pt. mama ta, care-i de fapt o doamna, nu prea sunt sigur  :)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(16612,992,'dan','mail@deceblog.net','http://deceblog.net','79.114.69.80','2008-02-19 15:11:05','2008-02-19 13:11:05','si efecte secundare nika? picat par din nas, ochi beliti ca la controlul de hepatita (desi eu nu am inteles niciodata de ce daca te doare sub coasta se uita la tine in ochi, probabil sa vada daca minti) si atunci cand dorm? (fetele, zic)... daca nu - inseamna ca n-o fo\' prea grav :p',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(17023,1011,'cepanamea','icgel@yahoo.com','http://www.cepanamea.ro','92.80.60.156','2008-02-25 13:57:54','2008-02-25 11:57:54','Ce bine ca nu sunt sef, o sa mo de moarte naturala...\r\nDar nici angajat nu sunt, asa ca nici dupa gratii nu o sa ajung...\r\nDin ce traiesc? Din aer, sore si multa independenta...financiara, desigur!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(16148,989,'Andreea','puistrulet2003@yahoo.com','http://n/a','81.196.150.196','2008-02-14 16:27:22','2008-02-14 14:27:22','Ce nu-mi place mie in mod particular la sarbatoarea asta, e faptul ca devine de la an la an gretos de \"dulce\"; ti se stramba ochiul la atatea inimioare cheap-made si alte exemplare ale prostului-gust.\r\nDar semnificatia pe care o are ziua recunosc imi place (sunt o fire o tar mai romantica, dar nu mult :) ) \r\nAnu asta am hotarat ca nu mai iau nimic....ma fac ca ploua',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(14592,976,'ovi66','ovidiulechintan@yahoo.com','http://ovidiu666.wordpress.com/','79.116.88.190','2008-02-01 23:21:04','2008-02-01 21:21:04','in tinerete daca scriai post-uri din astea erai dat ca link peste tot in messenger, acum abia daca mai primesti cateva vizite si comentarii. :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1) Gecko/20061010 Firefox/2.0','',0,0),(13589,967,'innuenda','innuenda.innuenda@gmail.com','http://innuennda.blogspot.com','92.80.49.226','2008-01-25 00:17:18','2008-01-24 22:17:18','Dupa atÃ¢tea gÃ¢nduri Ã®nchinate lui Dumnezeu, sunt tentatÄƒ sÄƒ-Å£i spun Troparu , nu Groparu :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(14540,976,'mo','verde_poveste@yahoo.com','','194.126.220.20','2008-02-01 14:13:38','2008-02-01 12:13:38','much, chiar. \r\nSi apropo de realm of senses, in caz ca l-a vazut careva, cat de ironic e numele personajului principal, Kichi (kicsi) San ala?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1)','',0,0),(13593,968,'Lumi','luminitadanciu@yahoo.com','','209.221.168.249','2008-01-25 00:47:47','2008-01-24 22:47:47','Hmm, ti se par sanii funny... How about men boobs? Do you find them more appealing and less funny? How about men\'s asses?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; InfoPath.1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(14439,972,'psaico','blog@psaico.info','http://www.psaico.info','78.96.86.55','2008-01-31 20:15:31','2008-01-31 18:15:31','noi sa fim sanatosi ca boala vine singura :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(14534,976,'.marius','marius@perijoc.com','http://marius.wirelessisfun.com','89.36.21.108','2008-02-01 13:44:38','2008-02-01 11:44:38','sex in toaleta?! omg... demult trecute vremurile alea...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(14535,976,'baghy','baghy83@lycos.it','http://www.baghy.info','78.12.1.110','2008-02-01 13:50:26','2008-02-01 11:50:26','in concluzie era mai bine in tinerete',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(14586,976,'Andreea MKT','supergirgir@yahoo.com','','89.43.186.64','2008-02-01 21:47:17','2008-02-01 19:47:17','groparu, eu oricand ma sarut cu colegele noastre, tu numa indica-mi cu care!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(14537,976,'mo','verde_poveste@yahoo.com','','194.126.220.20','2008-02-01 14:08:38','2008-02-01 12:08:38','Too mush sex can kill you? Cineva s-a uitat la \"realm of senses\" de prea multe ori?!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1)','',0,0),(14575,976,'cepanamea','icgel@yahoo.com','http://www.cepanamea.ro','89.41.164.74','2008-02-01 20:16:05','2008-02-01 18:16:05','Hmmm, ce adolescenta ai avut...tare frustrant trebuie sa fi fost...acu, parca e mai bine, zic si eu',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(14577,976,'Usim','mihaimitan@gmail.com','','87.237.108.33','2008-02-01 20:26:50','2008-02-01 18:26:50','LLLLOOOOOLLLLL\r\nNu esti intreg! Iti mai bese mintea multe?\r\nAr trebui sa scoti o antologie cu textele de pe blog. Va fi un best seller.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; .NET CLR 2.0.50727)','',0,0),(14555,976,'mo','verde_poveste@yahoo.com','','194.126.220.20','2008-02-01 16:49:06','2008-02-01 14:49:06','@ Felix: ok, ok, dar e totusi muuuult mai onorabil decat sfarsitul lui Elvis :&gt;',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1)','',0,0),(14583,658,'Turambar','mirel@ccsb.ro','http://turambarr.blogspot.com','82.76.108.17','2008-02-01 21:39:48','2008-02-01 19:39:48','Lilith! Lilith! Nu te opri. Spune. Zi-i! Fantasmeshte poveshteshte spovedeshte. Suntem totzi numa\' urechi in catarg.\r\n\r\nLOL. Shi totushi, gropare, trebuia s-o babardizezi pe scandinoasa. S-ainfigi mainile in ea, sa-i frigi un Romans Countrymen Friends, Lend me your pricks. I have come no to praise Shakespeare But to shag thee. Hard.\r\n\r\nPacat pacat pentru oportunitatu varsat.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(14585,972,'Turambar','mirel@ccsb.ro','http://turambarr.blogspot.com','82.76.108.17','2008-02-01 21:41:32','2008-02-01 19:41:32','Cu glucoza si stricnina. In valoare de trei sute de mii. Pe factura fiscala, cu TeVeA.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(14144,969,'macabroo','raduccc@yahoo.com','http://rezistenta.blogspot.com','82.76.52.94','2008-01-29 13:31:41','2008-01-29 11:31:41','Pai cred ca asta intra la subcategoria Brits, adica e subintelesi pruncii.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; en-GB; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(14511,973,'Basty','basty@canvas.ro','http://basty.wordpress.com','82.77.126.21','2008-02-01 09:48:52','2008-02-01 07:48:52','Gropare, imi si imaginez cum stai in capul patului, cu termometrul supt brat, cu ceaiul fierbinte langa fizic, si comentezi stirile in stilul batraneilor din Muppets :D',0,'1','Mozilla/5.0 (Macintosh; U; Intel Mac OS X; en) AppleWebKit/523.12.2 (KHTML, like Gecko) Version/3.0.4 Safari/523.12.2','',0,0),(14650,58,'Enzo','','http://groups.google.com/group/bellangeref80/web/indian-big-tits','194.110.161.30','2008-02-02 09:23:16','2008-02-02 07:23:16','<strong>Indian Big Tits...</strong>\n\nsolutions, including barcode label printers\n...',0,'1','USERAGENT','trackback',0,0),(13660,970,'cepanamea','icgel@yahoo.com','http://www.cepanamea.ro','89.41.164.224','2008-01-25 19:35:23','2008-01-25 17:35:23','Nimeni nu e perfect, parerea mea!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(14715,976,'totolici','fun4toto@yahoo.com','http://totolici.wordpress.com/','89.137.69.31','2008-02-02 20:59:48','2008-02-02 18:59:48','Da cati 100 de ani ai domle de iti cedeaza fetele locul in autobuz . Adica na eu una sunt mai nesimtita cand vad moshengi in autobuz care se uita spre mine la modul \"fie\'ti mila lasa\'ma sa stau jos\" ma fac ca am vazut  brusc ceva interesant pe geam. Ce-i drept mi se mai face mila cand vad ca sta autobuzul cate juma de ora sa urce cate o babuta si mai cedez si eu locul. Hmm am deviat de la subiect. Si cum ziceam cand vad unu mai batran ca imi face cu ochiu primul gand \"perv\" daca mai continua deja ii spun sa faca o poza ca tine mai mult.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.0.7) Gecko/20060909 Firefox/1.5.0.7','',0,0),(14717,57,'totolici','fun4toto@yahoo.com','http://totolici.wordpress.com/','89.137.69.31','2008-02-02 21:05:26','2008-02-02 19:05:26','Of cum stau lucrurile geniale in locuri de kkt, la propriu. Mai era treaba aia veche cu \"atentie la ursi s\'au gasit urme de laba\" scrisa tot pe pereti de buda de liceu.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.0.7) Gecko/20060909 Firefox/1.5.0.7','',0,0),(14470,972,'baghy','baghy83@lycos.it','http://www.baghy.info','78.12.1.110','2008-02-01 03:10:29','2008-02-01 01:10:29','nu esti normal',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(13569,966,'Usim','mihaimitan@gmail.com','','87.237.108.33','2008-01-24 20:34:28','2008-01-24 18:34:28','Thus I will not drink anymore, then again, I will not drink any less!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; .NET CLR 2.0.50727)','',0,0),(13570,966,'psaico','blog@psaico.info','http://www.psaico.info','78.96.86.55','2008-01-24 20:49:57','2008-01-24 18:49:57','vestea asta trebuia sa vina din partea unei femei dar tinand cont ca e prea grava problema .. nu mai conteaza. trist .. atat de trist :(\r\nna bine .. bem vischi ;)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(16404,991,'Andreea MKT','supergirgir@yahoo.com','','89.43.186.64','2008-02-16 23:43:22','2008-02-16 21:43:22','Groparu trebe transmis pe OTV.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(13313,967,'ramonici','','','89.33.174.82','2008-01-23 01:36:24','2008-01-22 23:36:24','asta o fo\' ceva gand subit...',0,'1','Opera/9.10 (Windows NT 5.1; U; en)','',0,0),(14270,971,'julius constantinescu','julius@universitateacraiova.ro','http://www.7plus.ro/?arhiva=30/01/2008&#38;id=1577','84.232.162.195','2008-01-30 16:06:18','2008-01-30 14:06:18','@gropare, deci da acu\' click pe mine si te duci direct la sfantu\' Constantin',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(13245,960,'Hammer','hammer@alpinet.org','http://www.alpontos.wordpress.com','86.120.55.79','2008-01-22 10:02:46','2008-01-22 08:02:46','Just for fun: http://bucurenci.ro/2007/11/05/dictionar-romglez-roman/',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(13251,959,'andys','adi.cojocaru@utcb.ro','','193.231.5.245','2008-01-22 11:26:10','2008-01-22 09:26:10','Bre gropare, nu intelegi nimic. Si eu am patit aceiasi faza cu masina de spalat. La un moment dat am fost nevoi ca si eu si gagica-mea (care baidauei mi-a dat papucii intre timp) sa sarim pe ea si s-o apasam cu putere ca sa nu iasa din baie. Stiu ca ne-a cam spart intre timp gresia si faianta din zona... dar pana la urma am dovedit-o!!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Maxthon; .NET CLR 2.0.50727)','',0,0),(13256,959,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-01-22 12:20:13','2008-01-22 10:20:13','Andys, welcome to the club :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(13258,964,'george','reallyinsane@gmail.com','','193.138.195.202','2008-01-22 12:51:37','2008-01-22 10:51:37','asta a fost o postare despre jazz.\r\njazz alb.\r\n\r\n(da\' numa\' ca-i citit invers)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(13259,965,'kmi','camelianeculai@gmail.com','','80.86.123.198','2008-01-22 12:55:41','2008-01-22 10:55:41','esti fabulos!',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1)','',0,0),(13296,967,'baghy','baghy83@lycos.it','http://www.baghy.info','78.12.1.110','2008-01-22 23:02:47','2008-01-22 21:02:47','tu si ungurul bulan cu fratica',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(13423,966,'julius constantinescu','julius@universitateacraiova.ro','http://www.7plus.ro','84.232.160.254','2008-01-23 19:30:58','2008-01-23 17:30:58','Groparule, semneaza ca-mi dai textul asta sa-l imbunatatesc putin si sa-l dau in ziar, semnat \"Julius Constantinescu featuring Groparu\"',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(13294,961,'traffik','','http://www.traffik.home.ro/','86.123.182.235','2008-01-22 22:40:31','2008-01-22 20:40:31','Mi-as lua 100 de apartamente in care mi-as indesa 99 de neamuri si rubedenii iar al 100- lea l-as inchiria ca sa fac bani sa imi platesc chiria la apartamentu\' asta unde stau acuma.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(13263,965,'Feli','felician.balint@yahoo.co.uk','','89.137.100.132','2008-01-22 13:27:59','2008-01-22 11:27:59','BETON!! \r\n\r\nSa nu\'mi spui ca va trebui sa\'mi modific toate paginile web si sa pun doar \"linii curbe\" ca in cazul ala nici arabocii n\'o sa\'mi poata plati comisionul ;-)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.2; en-US; rv:1.7.5) Gecko/20070321 Netscape/8.1.3','',0,0),(13457,966,'Greuceanu','','','195.149.72.105','2008-01-24 00:50:18','2008-01-23 22:50:18','MO,\r\n\r\nbem mai putina, dar mai tare ca niciodata .  (tuborg ultrastrong n.a.) io shtiu ce-nseamna!',0,'1','Opera/9.25 (Windows NT 5.1; U; en)','',0,0),(13584,968,'baghy','baghy83@lycos.it','http://www.baghy.info','78.12.1.110','2008-01-24 23:20:10','2008-01-24 21:20:10','http://www.youtube.com/watch?v=_9XCkwdSAjs cu dedicatie pentru Groparu',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(13375,967,'manole','redtailanda@yahoo.com','http://www.mesterulmanole.wordpress.com','81.181.92.157','2008-01-23 10:59:40','2008-01-23 08:59:40','daca ce spui tu o fi adevarat, ca ar avea si ceva logica, cum si mie \"Dumnezeu mi-e tatÄƒ, iar Fecioara Maria nu mi-e mamÄƒ, insamnÄƒ ca Iisus mi-e frate vitreg\" atunci si tu mi-esti frate vitreg. :)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows 98)','',0,0),(13378,960,'oedip','oedip74@gmail.com','http://oedip.blogspot.com','89.137.99.163','2008-01-23 11:54:12','2008-01-23 09:54:12','deci, n-ai inteles... simplicitate traduce pe lat. simplicitas... care este un concept filosofic!!!!!!!\r\n\r\n:)))))))))))))))))))))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(13450,968,'cepanamea','icgel@yahoo.com','http://www.cepanamea.ro','89.41.164.224','2008-01-23 23:32:06','2008-01-23 21:32:06','Toate mesriile au riscuri!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(13305,961,'Sictir','vaduvoiutibi@yahoo.com','http://sictir-sictir.blogspot.com/','86.126.68.196','2008-01-23 00:13:01','2008-01-22 22:13:01','Mi-as platii rata la laptop, as da avans 300 euro pt Logan, mi-as platii facturile la mobil insumand 100 lei. As cumpara un parfum ca e la reducere prin oras si de restul banilor as cumpara bilete la loto.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(13419,967,'kmi','camelianeculai@gmail.com','','80.86.123.198','2008-01-23 18:59:18','2008-01-23 16:59:18','gropare, daca-mi permiti, sunteti chiar \"frati\" (e adevarat, doar dupa tata). \"Vitregi\" (frati) se cheama atunci cand \"sunt pusi la comun\", fara a fi facuti impreuna...Io asa cred :)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1)','',0,0),(13272,965,'Mihai','mhangansv@yahoo.com','','81.196.150.96','2008-01-22 16:00:30','2008-01-22 14:00:30','Excelent!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(13273,965,'Ciprian','ciprian.sorlea@it-exchange.ro','','81.196.150.96','2008-01-22 16:02:27','2008-01-22 14:02:27','Crunt. Da\' rau de tot :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(13298,967,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2008-01-22 23:11:14','2008-01-22 21:11:14','...vii si tu? :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(13299,967,'macabroo','raduccc@yahoo.com','http://rezistenta.blogspot.com','82.76.52.94','2008-01-22 23:30:33','2008-01-22 21:30:33','Bai macar in iad cocalarii n-au nevoie de glugi cu blana. Macar pentru asta...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; en-GB; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(13278,965,'Felix','felix.felix@gmail.com','','213.233.122.144','2008-01-22 18:42:56','2008-01-22 16:42:56','trebuia sa le explica ca e semnul \'plus\'. ala cu care se aduna numerele aduse de ei in europa.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(13279,959,'andys','adi.cojocaru@utcb.ro','','193.231.5.245','2008-01-22 18:46:09','2008-01-22 16:46:09','Multam! Bine v-am gasit!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Maxthon; .NET CLR 2.0.50727)','',0,0),(13280,965,'andys','adi.cojocaru@utcb.ro','','193.231.5.245','2008-01-22 18:51:46','2008-01-22 16:51:46','Ce sa mai explice!! Probabil in clipa imediat urmatoare l-au plesnit cu una bucata Coran cu coperti cartonate peste ochi si i-au declarat Jihad!!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Maxthon; .NET CLR 2.0.50727)','',0,0),(13282,965,'iulianuss','realvision@k.ro','','193.231.107.209','2008-01-22 18:57:26','2008-01-22 16:57:26','Habibi, adevarul este ca ÅŸi io vÄƒd zvasticile oriunde le-aÅ£i ascunde, deÅŸi am ceva dioptrii.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; .NET CLR 1.1.4322)','',0,0),(16421,991,'ascutita','michi.deli@gmail.com','http://ascutita.wordpress.com/','220.96.122.218','2008-02-17 05:01:00','2008-02-17 03:01:00','de mesajul de \"delete\" de la iahu stiam si eu,cica mi-l trimisese un binevoitor',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; SIMBAR={6F0FD749-995D-45FA-868D-69ED48107126}; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(14324,971,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2008-01-31 01:14:35','2008-01-30 23:14:35','@Laura: A dreq cum va datz voi fomeile seama de faze d-estea!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(13988,969,'mo','verde_poveste@yahoo.com','','194.126.220.20','2008-01-28 10:29:37','2008-01-28 08:29:37','Io am urmatoarele propuneri:\r\n1. un caca de cutu aburind si deviza \"embellishing your sidewalks since 1862\"\r\n2. un nene cu dejtiu\' ingropat adanc in nas (ca atatia practicanti ai sportului ca in Bucuresti n-am vazut niciodata) si una bucata citat Caragiale:\"Un om nu trebuie sÄƒ Ã®ncerce decÃ¢t ceea ce poate\".\r\n3. un cap de secretara si 2 pixuri incrucisate dedesubt, eventual cu un alfa si omega la stanga si dreapta (cine are treburi la institutii publice stie de ce)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1)','',0,0),(14409,972,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2008-01-31 15:11:13','2008-01-31 13:11:13','@ Julius: stai linistit ca nici la mine, tocmai finca stiu ca au toate sansele!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(14410,971,'Victor Ciutacu','victor@ciutacu.ro','http://www.ciutacu.ro','82.76.75.160','2008-01-31 15:12:26','2008-01-31 13:12:26','Ba Ciutacu mai si bea uneori cu tine :)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(14411,971,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2008-01-31 15:16:04','2008-01-31 13:16:04','Dap! PuÅ£Ã¢n cÃ¢tie puÅ£Ã¢n...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(14412,973,'Mih_nea','mihnea_xxyahoo.com','','62.217.236.12','2008-01-31 15:32:02','2008-01-31 13:32:02','poate ar trebui sa reinitiem concursul \"cat mai are de trait Britney Spears\"\r\ndar cum prostia e infinita, s-ar putea ca si purtatorii ei sa fie la fel, si sa mai traiasca mult si bine',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(14414,973,'george','reallyinsane@gmail.com','','193.138.195.202','2008-01-31 15:44:09','2008-01-31 13:44:09','da\' despre cantitatile de alcool din trupurile diversilor gropari nu s-a zis nimc?\r\ninvidiosilor!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(14415,973,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2008-01-31 15:47:23','2008-01-31 13:47:23','Nu se zice, numa\' despre cantitatile de trup din alcoolul diversilor Gropari!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(14400,971,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2008-01-31 14:30:43','2008-01-31 12:30:43','Pai e normal, din moment ce ma ai in blogroll, sa creasca traficu\' ca inundatia pe peretele proaspat dat cu lavabila!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(14401,972,'Mile','','http://milecarpenisan.wordpress.com/','79.114.20.9','2008-01-31 14:35:39','2008-01-31 12:35:39','Vezi daca nu mai fumezi...ai inceput sa tusesti si nu te crede nimeni nici macar felceru(asa ii zice in Banat la vraciu ala a tau)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; SIMBAR={A7F3C004-B2DD-4145-98BD-0344DDF9CD6E}; .NET CLR 2.0.50727)','',0,0),(13996,969,'WhiteWolf','contact@white-wolf.ro','http://white-wolf.ro','89.39.82.165','2008-01-28 11:44:53','2008-01-28 09:44:53','Ba, da\'rautz mai esti\r\nAu un Vadim , au o Zavoranca si un Pepe; nu ? La ce sa mai caute mascote suplimentare ?\r\nHai, sa ma dovedesc marinimos. \r\nPiciorul de lemn al pliciului Prigoana cu sticker mirositor de \"SENZATIONAL\" a la Dan Diaconescu; pe sticker scrie <b>Acesta este aschia originala din bata mioritica a lui Bucur</b>',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11 FireShot/0.32','',0,0),(14265,971,'ovi666','','http://ovidiu666.wordpress.com/','194.99.245.11','2008-01-30 15:09:45','2008-01-30 13:09:45','mandru de tine! :)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(14237,971,'Hammer','hammer@alpinet.org','http://www.alpontos.wordpress.com','86.120.55.79','2008-01-30 09:08:10','2008-01-30 07:08:10','si eventual baga un top al chestiilor care nu se spun unui medic:-)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(14329,972,'julius constantinescu','julius@universitateacraiova.ro','http://www.7plus.ro/?arhiva=31/01/2008&#38;id=1615','84.232.162.100','2008-01-31 02:02:15','2008-01-31 00:02:15','Gropare, daca ai gagica, io te sfatuiesc sa mai tragi de viroza asta cat poti, macar pana trece Triunghiul Mortii, Valentine\'s Day - 1 martie - 8 martie. O suni si-i zici ca asa tare vroiai sa-i iei flori si sa mergeti ca penibilii undeva frumos sa va casatoriti macar asa, o zi, da\' uite, cu viroza asta trebe sa stai in pat, plus ca nici ea nu poate veni la tine, ca e supercontagioasa si, pula ta, tu tii la ea, n-ai vrea sa pateasca ceva. No, da\' daca esti prost si nu m-asculti pe mine, care sunt un Waterloo al relatiilor, sa vezi daca n-o sa ajungi sa te gandesti la mine de Valentine\'s mai des ca la Claudia Schiffer.\r\nIar in caz ca, totusi, crapi, io iti urez de pe acum tarana usoara si toate cele bune!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(14259,971,'IepurasulAtomic','praetorian21uk@yahoo.com','','192.100.130.8','2008-01-30 13:42:56','2008-01-30 11:42:56','Gropare, eu bag seama ca tu te-ai apucat de chefuit si ai uitat de noi. Ca nu mai scrii, asta e, cu totii avem momentele noastre de cadere. Mai ales dupa ce ne loveste faima (nu vorbesc in cunostinta de cauza :D). Da\' sa nu ne chemi si pe noi la chef, asha ceva nu se face. Vezi ca te tin minte....:) Felicitari pentru bagarea in seama (adica recunoasterea, vreau sa zic) de catre blogarii fericiti. Acuma fie vorba intre noi, fara sa-l jignesc pe domnul Constantinescu, mie mi-a placut mai tare articolu\' tau inainte de imbunatirile anuntate.\r\n\r\nPace p\'afara!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(13627,970,'julius constantinescu','julius@universitateacraiova.ro','http://www.7plus.ro','84.232.160.65','2008-01-25 11:30:39','2008-01-25 09:30:39','Gropare, vad ca incepi sa scrii ca mircea cartarescu. azi, maine te lipesti de nobelul ala refuzat de sartre.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(13630,970,'mo','verde_poveste@yahoo.com','','194.126.220.20','2008-01-25 11:52:25','2008-01-25 09:52:25','Bine, Gropare, ca tocmai amu\' cand is in pauza de masa te-ai apucat sa iti faci cartografia corpului, bata-te sa te bata! \r\n\r\nSi, fara legatura cu randu\' de mai sus, ma intreb:\r\nDe ce gagicile nu gasesc niciodata puf dintr-ala de buric decat daca se apuca sa caute in buricu\' prekinului?\r\n\r\nDin seria stiri (expirate) Mo-pedia: cica Parfumu\' era cartea preferata a lui Cobain, deci probabil recitea partea cu \"nu iti simti propriul miros\" de fiecare data cand trebuia sa se spele pe cap.... sau.... ceva de genul asta. Nu aud nici o hahaiala? Pfu! La dracu\' cu toata lumea!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1)','',0,0),(13672,968,'Lumi','luminitadanciu@yahoo.com','','209.221.168.249','2008-01-25 21:47:35','2008-01-25 19:47:35','Baby, you know I was kidding, right? The no reply thing makes me wonder if I offended you. Mucho love, Lumi',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; InfoPath.1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(13657,970,'katmai','katmai@keptprivate.com','http://512kbps.com','195.212.29.179','2008-01-25 19:12:21','2008-01-25 17:12:21','aveai nevoie de mine cumva? sa te inspir a? zi a?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(13668,970,'Laura','mars1953@web.de','','84.160.127.130','2008-01-25 21:07:32','2008-01-25 19:07:32','cu scrisul e ca si cu gatitul: ca sa faci un text bun sau un meniu de sa-ti zica barbatu\' ca esti cea mai buna bucatareasa e nevoie de multe ore de munca si rezultatul este asa de repede consumat ...',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(13890,907,'The Original Yankee','crisan_emil@yahoo.com','','89.43.186.64','2008-01-27 14:29:40','2008-01-27 12:29:40','intr-o dimineata , taxi spre birou, scoate nenea sa-mi dea restul, traseul clasic exact conform descrierii tale pana la punctul (4)... si ramane cu mana dreapta intinsa cu 3 lei in ea... iar in stanga portofelul... si ramane siderat ca ii iau portofelul si-mi scot 3 lei din el, ii zic la revedere, cobor si ma duc la munca.\r\n\r\nGropare, educatorul natiunii, cum as da eu in hepatita fara tine!!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(14164,969,'mihai ursu','','http://mihaiursu.wordpress.com','84.232.196.234','2008-01-29 16:26:22','2008-01-29 14:26:22','sau statuia manelistului necunoscut, facuta din bronz vopsit in visiniu cu aur la git si stropita de o arteziana cu BVLGARI (un cuvint pe care nici un manelist nu l-a stiut citi, motiv pentru care a considerat ca e mult prea trendy ca sa nu il cumpere), cu dolari si euro zburind in jurul lui, suflate de un ventilator de mare putere. e adevarat ca nu ar strica sa fie o statuie ecvestra, stiind iubirea de veacuri dintre manelist si coviltir, dar nu ar fi un obiect de arta reusit fara o masina straina al carei nume nu stie sa il pronunte nici un manelist si care sa fie inmatriculata \"fara numar!\"',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(14165,969,'catalin','solo@xsolo.biz','http://xsolo.biz','190.17.92.168','2008-01-29 16:31:12','2008-01-29 14:31:12','bonusul e tare, desi nici cu japonezul nu e rau. ar merge si o valiza plina cu slapi din \"europa\" si un chinezoi mic mic de tot bagat in ea.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(14167,971,'Mana','mariana.ciutacu@yahoo.com','http://www.mana.ciutacu.ro','82.76.60.29','2008-01-29 16:56:35','2008-01-29 14:56:35','Da\' eu cu ce Å£i-am greÅŸit de mÄƒ bagi Ã®n seamÄƒ? Io-s doar micÄƒ ÅŸi neÃ®nsemnatÄƒ, acolo-ntr-un colÅ£.... :)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; InfoPath.1)','',0,0),(14181,969,'PIT','paula.tiplea@gmail.com','','85.120.75.140','2008-01-29 19:35:29','2008-01-29 17:35:29','io le-as pune pe toate cele enumerate aici, cu sloganul PENTRU CA MERITATI :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.0.7) Gecko/20060909 Firefox/1.5.0.7','',0,0),(14404,972,'Groparu','groparu_ro@yahoo.com','http://','89.137.109.142','2008-01-31 14:52:22','2008-01-31 12:52:22','@ Mile: da, mah, de cand nu mai fumez am pierdut si marele premiu la 6/49!\r\n\r\n@ Julica: ma, io m-am legat de tine ca ai un fetish cu femeile cu varice?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,1),(14428,973,'milanesta','ana_stefanaaa@yahoo.com','','89.34.181.207','2008-01-31 18:22:09','2008-01-31 16:22:09','Subiectul Britney e plictisitor :P \r\n\r\nDespre scoala de soferi nu se mai aude nimic ?:D ....hai ca de acolo trebuie sa apara subiectele tari :))',0,'1','Opera/9.25 (Windows NT 5.1; U; en)','',0,0),(14403,972,'julius constantinescu','julius@universitateacraiova.ro','http://www.7plus.ro/?arhiva=31/01/2008&#38;id=1615','84.232.160.56','2008-01-31 14:43:53','2008-01-31 12:43:53','No, oameni buni, i-o scris Mile Carpenisan! Va dati seama ca daca-i scrie si idolul lui Ciutacu, Groparu se face bine instant si din mormant??',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(14049,971,'baghy','baghy83@lycos.it','http://www.baghy.info','78.12.1.110','2008-01-28 22:11:21','2008-01-28 20:11:21','deci tu erai muza care mi-a zis sa imi fac blog? da parca era femeie. Sau eram beat? :)))))))))',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(14050,971,'cepanamea','icgel@yahoo.com','http://www.cepanamea.ro','89.41.164.224','2008-01-28 22:14:57','2008-01-28 20:14:57','Hmmmm, trebuie sa am grija cu tine...devii periculos, daca esti in tandreturi cu Ciutacu..o sa te urmaresc',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(14476,972,'Turambar','mirel@ccsb.ro','http://turambarr.blogspot.com','79.114.190.130','2008-02-01 03:38:27','2008-02-01 01:38:27','E clar. M-ai convins. Eshti de-al nostru. Te ashteptam in Bucureshti, sa bem o tzuica de Scotzia shi sa ne ajutzi sa incalzim coptoarele unde-i rotisam pe aia serioshi, care-s condamnatzi la chinul prin ras. Sa-i facem sa sufere, mama lor de gomoshi pernicioshi, periculoshi shi pufoshi.\r\n\r\nLOL. Mate, you\'ve just made my day. Cum mama naibii am dat de-abia acu de tine, Clujenschy chelavek? :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(14052,971,'Denisa Lala','denisalala@gmail.com','http://denisuca.com','81.196.202.37','2008-01-28 22:22:06','2008-01-28 20:22:06','Groparele nu-i periculos. El e Groparu ÅŸi atÃ¢t. UrmÄƒreÅŸte-l, dar nu pentru cÄƒ-l citeÅŸte Ciutacu, urmÄƒreÅŸte-l pentru cÄƒ meritÄƒ. Scrie atÃ¢t de bestial, Ã®ncÃ¢t! :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(14061,969,'mikloshu roman','','','81.180.163.192','2008-01-28 23:15:42','2008-01-28 21:15:42','Salut mane, io aleg bonusul sa ii reprezinte, oricum sunt deja cautati si doriti*! Toate pline si golite!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(13935,970,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2008-01-27 23:37:16','2008-01-27 21:37:16','Julica, deci io atata-s de curios sa vad ce copkil am mosit din spermatozoizii mei campioni in gandire...!!! Intrebare: tu ce o sa fii la tecstu\' ashela, mamica, sau bunica? ',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(13937,969,'Radu','ratradu@gmail.com','http://ratradu.blogspot.com/','89.121.7.194','2008-01-27 23:52:29','2008-01-27 21:52:29','Io propun ca si mascota oricare dintre primarii bucuresteni, ca asta e un oras cum altu nu-i. \'jdemii de primari deodata si aproape nici unul nu face nica! Poate ca mascote ar avea performante mai bune.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(13939,970,'julius constantinescu','julius@universitateacraiova.ro','http://www.7plus.ro','84.232.163.93','2008-01-28 00:03:49','2008-01-27 22:03:49','http://www.7plus.ro/?arhiva=28/01/2008&amp;id=1485',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(14637,976,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2008-02-02 06:45:03','2008-02-02 04:45:03','@ Usim: hmmm... sa zicem ca vreu mai mult de la viatza, gen: famelie cu 14 prunci :D sa sece ei planeta curului de resurse FEMININE pan\' la capat! (trebe numa fomee care sa merite estea :D )',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(14564,972,'dunec','the_dun3@yahoo.com','http://dunec.wordpress.com/','89.123.180.34','2008-02-01 18:18:10','2008-02-01 16:18:10','nu ne-ai explicat cum te-a consultat:D si pastile... ci pastile ti-a recomandat?:D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(14545,976,'Felix','felix.felix@gmail.com','','213.233.122.144','2008-02-01 15:13:28','2008-02-01 13:13:28','mah, doar ai vazut cum a sfarsit Morrison...',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(14027,969,'dunec','the_dun3@yahoo.com','http://dunec.wordpress.com/','89.123.173.164','2008-01-28 17:09:44','2008-01-28 15:09:44','Da...deci... propun si eu un slogan:\r\no conducta sparta\r\npe fiecare strada bombardata',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(14028,969,'IepurasulAtomic','praetorian21uk@yahoo.com','','192.100.130.8','2008-01-28 17:19:13','2008-01-28 15:19:13','Deci, pe scurt, de departe una dintre cele mai misto postari din ultima vreme, cu un umor subtil(dupa standardele mele) si taios. Imi plec urechile in fatza ta(mi-as da jos palaria, da\' nu port din cauza urechilor). Felicitari! ;)\r\n\r\nPace p\'afara!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(14021,969,'traffik','','http://www.traffik.home.ro/','86.123.182.230','2008-01-28 16:10:08','2008-01-28 14:10:08','Asta e buna??? :D\r\n\r\nhttp://youtube.com/watch?v=QAfXEUEN_A8&amp;feature=related',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(14069,969,'macabroo','raduccc@yahoo.com','http://rezistenta.blogspot.com','82.76.52.94','2008-01-29 00:29:04','2008-01-28 22:29:04','Deci toate ca toate da pe udne dracu circula 221?!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; en-GB; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(14062,971,'Arhi','admin@arhiblog.com','http://arhiblog.com','86.127.9.33','2008-01-28 23:18:59','2008-01-28 21:18:59','deci da',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(13807,970,'bambucea','','','92.80.89.46','2008-01-26 22:17:31','2008-01-26 20:17:31','io zic s te mai uiti in cada .............sigur mai e vreun nenorocit peacolo:)))))',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; SIMBAR={BF3AA6BD-9FA0-4688-959F-0FAD9E5252A0}; .NET CLR 2.0.50727; InfoPath.2; .NET CLR 1.1.4322)','',0,0),(14123,969,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','82.77.126.148','2008-01-29 10:05:26','2008-01-29 08:05:26','as mai adauga un pedofil englez cu 3 prunci agatati de el, iar sloganul: \"let the children come to me!\"',0,'1','Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.0.13pre) Gecko/20071022 Ubuntu/dapper-security Firefox/1.5.0.13pre','',0,0),(14195,971,'Usim','mihaimitan@gmail.com','','87.237.108.33','2008-01-29 22:47:18','2008-01-29 20:47:18','Sanatate multa Gropare! Si ii doresc medicului de famelie sa aiba destul din simptul humorului ca sa-l priceapa pe Gropar. Si sa nu se uite pierdut ca soferul lovit de bicicleta cand l-ai intrebat cum se simte dupa Accident.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; .NET CLR 2.0.50727)','',0,0),(14418,973,'doomyuwz','ro_maniax@yahoo.com','','86.127.2.80','2008-01-31 16:05:51','2008-01-31 14:05:51','Nu ti-ar fi rusine.. \r\n\r\nLeave Britney alone! \r\n\r\nhttp://youtube.com/watch?v=kHmvkRoEowc\r\n\r\n:)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727)','',0,0),(14406,972,'julius constantinescu','julius@universitateacraiova.ro','http://www.7plus.ro/?arhiva=31/01/2008&#38;id=1615','84.232.160.56','2008-01-31 14:57:36','2008-01-31 12:57:36','@groparu: esti ordinar. acum, nici o femeie cu picioare superbe nu se va mai da la mine, stiind clar ca n-are nici o sansa.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(14393,971,'oana dobre','oana.dobre@gmail.com','http://oana-dobre.blogspot.com','89.136.174.145','2008-01-31 12:58:27','2008-01-31 10:58:27','Da\' si in blogrollu\' meu esti, asa sa stii. Chiar daca tocmai ne batem pentru locul 73 in trafic.ro. :D',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; SIMBAR={45FD39F1-162D-4995-A8A3-8F4764D6BC01}; InfoPath.1)','',0,0),(14394,972,'WhiteWolf','contact@white-wolf.ro','http://white-wolf.ro','89.32.115.136','2008-01-31 13:12:34','2008-01-31 11:12:34','D\'aia ej bolnav si te pÃ£lesc gripele iar viruseii te inconjoara mai ceva ca haita de canibali cazanu\' cu romanei cruzi. Ca ej negru\'n ceru gurii, chinui naratorii de retzete si vrei sa-i bagi pe a lu\' Nicolaescu in faliment.\r\nLucri ? MÃ nci o pitÃ£ si-ti platesti o ratÃ£ de acolo de unde lucri ?\r\nMno, lasa-l si pe el sa puna pita pe masa pe stilu\' de o invatzat sau si-o cumparat direct diploma; asta conteaza mai putin.\r\nStii, doar :) La tÃ£tzi ni\'i greu :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11 FireShot/0.32','',0,0),(14009,969,'iulianuss','realmedia@k.ro','','193.231.107.209','2008-01-28 14:26:13','2008-01-28 12:26:13','o caruÅ£Äƒ cu cinci roÅ£i frÃ¢nÄƒ de picior ÅŸi budÄƒ decapotabilÄƒ',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; .NET CLR 1.1.4322)','',0,0),(14011,969,'baghy','baghy83@lycos.it','http://www.baghy.info','78.12.1.110','2008-01-28 15:08:57','2008-01-28 13:08:57','le-ai zis-o',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(14017,965,'andreea m','andreea_molocea@yahoo.com','http://andreeamolocea.wordpress.com/','89.122.244.159','2008-01-28 15:45:41','2008-01-28 13:45:41','duoamne, eu femeia, care as fi invizibila in that society si as papa cu susan banii sotului alaturi de alelalte douzaci se nevste si surori ale mele, am ras de n-am mai putut...pt asta cer sa fiu batuta cu pietre! :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(14018,969,'mo','verde_poveste@yahoo.com','','194.126.220.20','2008-01-28 16:01:30','2008-01-28 14:01:30','\"o caruÅ£Äƒ cu cinci roÅ£i frÃ¢nÄƒ de picior ÅŸi budÄƒ decapotabilÄƒ\"\r\n\r\nmuahahahahahahahaha! votez propunerea asta oricand!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1)','',0,0),(13910,970,'julius constantinescu','julius@universitateacraiova.ro','http://www.7plus.ro','84.232.163.93','2008-01-27 18:34:07','2008-01-27 16:34:07','Groparule, deci luni apare textul ala, sa-ti decupezi monitoru\' si sa-l pui in rama :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(14193,971,'cepanamea','icgel@yahoo.com','http://www.cepanamea.ro','89.41.164.74','2008-01-29 22:16:49','2008-01-29 20:16:49','Lala, aveam si eu parere buna despre Groparele cum ii spui tu...doar ca emotia care l-a cuprins, la faptul ca-l citeste Ciutacu, ma face sa fiu doar circumspect si atat..il voi citi, fara probleme..',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(13811,970,'vizionarul','alinmiron_19@yahoo.com','http://vizionarul.wordpress.com','89.35.87.15','2008-01-26 23:16:58','2008-01-26 21:16:58','azi ierea ziua lu Ceausescu... ala de era cu moaca pe prima pagina in toate cartile si din cauza caruia si acum cand citesc carti, le incep deschid de la sfarsit la inceput.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648)','',0,0),(15159,980,'Mih_nea','mihnea_xxyahoo.com','','62.217.236.12','2008-02-06 09:22:39','2008-02-06 07:22:39','hai mah, ca nu esti singur... si eu sunt bolnav si am pierdut vr\'o mie de euroi la bursa in ianuarie... mama lor de americani cu criza lor...',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(15158,980,'natty','natty2277@yahoo.com','','86.106.49.165','2008-02-06 09:20:58','2008-02-06 07:20:58','super blog, dar astept urmatorul post ca asta m-a facut sa plang...',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(16125,989,'Stupid Cupid, stop takin&#8217; all my money! &laquo; Retoric','','http://adriancalarasu.wordpress.com/2008/02/14/stupid-cupid-stop-takin-all-my-money/','66.135.48.142','2008-02-14 13:31:03','2008-02-14 11:31:03','[...] Groparu si Julius au scris, Julica in 7Plus, Gropu la el pe site. Ei au scris, pentru ca nu intra sub incidenta nici unui articol din Codul Familiei, sunt la [...]',0,'1','Incutio XML-RPC -- WordPress/MU','pingback',0,0),(15431,985,'ametzitul','','http://ametzitul.wordpress.com','62.217.236.12','2008-02-08 09:43:49','2008-02-08 07:43:49','Cica prin 1940 Itzic si Shtrul treceau clandestin granitza din Germania in Elvetzia. Zice Itzic: \r\n - Bah nu mai face atata zgomot ca daca ne prind nemtzii ne fac sapun!\r\n - Ba sa fiu al dracu\' daca fac clabuc!',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(15991,990,'braveheart','andrei.apreutesei@yahoo.com','','193.239.218.9','2008-02-13 14:53:35','2008-02-13 12:53:35','adauga-ma te rog in ym',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(15424,983,'ametzitul','','http://ametzitul.wordpress.com','62.217.236.12','2008-02-08 09:03:08','2008-02-08 07:03:08','ne mai uitam noi urat unii la altzii, bucurestenii la moldoveni, ardelenii la regatzeni, mai stiu eu cine la olteni...\r\nda\' un lucru e universal valabil: tablagii sunt la fel de deshteptzi oriunde in tara te-ai afla. Ei sunt dovada vie a unitatzii neamului romanesc, de-a pururea in spatziul carpato-danubiano-pontic...\r\nIar cei de la rutiera, colegii astuia, sunt fruncea.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(16124,989,'dush','tirbushon@gmail.com','http://dushrece.blogspot.com','193.230.155.70','2008-02-14 13:12:28','2008-02-14 11:12:28','buey...deci treaba asta cu valentin la multi ani pe 14 e aberatie...atata vreme cat nu-stem musulmani, penticostali, d\'a shaptea zi, persani si alte d\'astiea cum le zice...ptiu ce-mi sta pe limba...no ziceti...catolici sau alte nebunii...la noi rumanii azi e ziua lu\' Auxentiu, Maron si Avraam; Sf. Filimon  deci nu o sa va dea nici un valentin de baut..SÃ®c!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(15310,981,'ametzitul','','http://ametzitul.wordpress.com','62.217.236.12','2008-02-07 11:20:05','2008-02-07 09:20:05','@nenea - nu, asa merge ea, mai saltat :)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(15744,984,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-02-11 15:27:39','2008-02-11 13:27:39','Deci in loc sa ma vindec de obsesiile mele erotice cu saitu asta, tot ce am reusit e sa strang in juru meu altii ca mine.\r\n\r\nVom cuceriiii lumea, aia-i clar.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(15746,984,'PhenoBarbieDoll','poisongirl94@yahoo.com','http://blog.360.yahoo.com/poisongirl94','193.230.230.101','2008-02-11 15:48:42','2008-02-11 13:48:42','deci io am lucrat la sex-shop',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(15975,990,'VforWhatever','stephanovendetta@yahoo.com','','89.37.114.51','2008-02-13 12:23:03','2008-02-13 10:23:03','duracell tata, duracell... inca d-elea alkaline, oricum... harem sau nu, io vreau sa vad cat o sa ajunga kilu de nisip cand raman astia fara petrol...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.6) Gecko/20040113','',0,0),(15977,990,'artistu','manea.andrei@gmail.com','http://artistu.voce.ro','82.76.6.184','2008-02-13 12:31:43','2008-02-13 10:31:43','Io zic sa se faca conscurs. Fiecare fata (din alea 270) sa fie pusa pe site si sa licitam! :D\r\nP.S. Asa-i gropare ca serverele alea inuntru tot alea vechi erau?\r\n;)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(14998,978,'Mih_nea','mihnea_xxyahoo.com','','62.217.236.12','2008-02-05 08:40:52','2008-02-05 06:40:52','corect, Julius, fara plangere nu se poate face nimic.\r\nda\' cu falsul in declaratii cum ramane? acolo de ce-i NUP?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(15001,978,'Hammer','hammer@alpinet.org','http://www.alpontos.wordpress.com','86.120.55.79','2008-02-05 08:58:51','2008-02-05 06:58:51','Declaratiile date in fata organelor de urmarire penala sunt una si declaratiile in presa sunt alta. Alea primele nu prea le-am vazut. Iar pentru falsul in a doua categorie de declaratii poate fi sanctionat moral sau eventual in cabina de vot:-)))',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(15002,978,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-02-05 09:11:01','2008-02-05 07:11:01','@ Julica: ba, sofer de apa dulce! Ia fa matale un mic accident (Doamneeee, feri! ca nu doresc la nimeni), si apai cara-te de-acolo si revino in 24 ore, si vezi ce se-ntampla. Da\' dupa aia sa nu vii hohotind de plans in brate la Gropar ca de ce legea se aplica intr-un fel daca te cheama Orb-an si in cu totu alfel daca te cheama - pardon de expresie - Julius!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(15003,977,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-02-05 09:15:56','2008-02-05 07:15:56','Hehe! Cartea de joc cu femei goale? ;))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(15372,983,'Buciuman','aaa@ggg.com','http://rezistenta.blogspot.com/','86.121.59.132','2008-02-08 00:26:55','2008-02-07 22:26:55','Ba eu zic ca daca se alege cu dosar penal tendintele homosexuale se vor dezprima!!',0,'1','Opera/9.25 (Windows NT 5.1; U; en)','',0,0),(15238,980,'Ureche Mare','','http://www.ju-jutsu.ro','86.127.20.214','2008-02-06 21:55:32','2008-02-06 19:55:32','Bre Groparule, asta cu nevoile speciale sa o spui matale alora cu Divanul Ad-Hoc, care fabrica publicitate! Nu de alta, dar ei zic ca \"fiecare client e important si are nevoi speciale\"...',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1)','',0,0),(15240,980,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.123.73.60','2008-02-06 22:05:52','2008-02-06 20:05:52','Ba Ureche!\r\n\r\nTe lej de sponsor???',0,'1','Mozilla/5.0 (Macintosh; U; Intel Mac OS X; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(15241,981,'s3my','chrmihai@gmail.com','http://s3my.blogspot.com','193.238.247.112','2008-02-06 22:35:06','2008-02-06 20:35:06','Mda, si uite 12: Daca te-ai servi pe tine , acest local ar avea mai mult succes. ^_^',0,'1','Opera/9.21 (Windows NT 5.1; U; en)','',0,0),(15242,981,'macabroo','raduccc@yahoo.com','http://rezistenta.blogspot.com','82.76.52.94','2008-02-06 22:36:35','2008-02-06 20:36:35','13. Esti un baiat de treaba, ia niste bacshis sa te mai razi.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; en-GB; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(15245,980,'BlindGirl','mihaelaoprisan@gmail.com','http://blind-girl.blogspot.com/','86.127.57.112','2008-02-06 22:51:59','2008-02-06 20:51:59','Gropareee.. daca nu ti-o trecut eu cred ca-i timpul de-o baie firbinte cu sare :))',0,'1','Mozilla/5.0 (Windows NT 5.2; U; en; rv:1.8.0) Gecko/20060728 Firefox/1.5.0 Opera 9.24','',0,0),(15251,980,'corneliii','cornelia_guju@yahoo.de','http://blog.360.yahoo.com/corneliaguju','92.81.158.111','2008-02-06 23:41:20','2008-02-06 21:41:20','BCR stie intotdeauna ce-ti doresti - o tona de stresuri, un raspuns, ve(i)cere: http://www.220.ro/Parodie_BCR-50162.html\r\n\r\n;-) heads up :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(15253,980,'Felix','felix.felix@gmail.com','','82.76.4.55','2008-02-07 00:17:51','2008-02-06 22:17:51','We wish you a lot of good head!',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; InfoPath.1)','',0,0),(15257,981,'Turambar','mirel@ccsb.ro','http://turambarr.blogspot.com','79.114.190.130','2008-02-07 00:38:16','2008-02-06 22:38:16','14. Don\'shoara, ce facetzi deseara, rogu-va? Ca vaz ca pe-aici nu prea facetzi nimic, prin crashma, doar statzi...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(15259,981,'baghy','baghy83@lycos.it','http://www.baghy.info','78.12.1.110','2008-02-07 01:08:56','2008-02-06 23:08:56','Ai ce ai cu supa si cu musca',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(15260,980,'','','','220.96.122.218','2008-02-07 01:25:23','2008-02-06 23:25:23','de urmat,...sa fii sigur ca ceva tot o sa urmeze.faza naspa e ca in momentele astea de criza si probleme,urmeaza...tot probleme.ca asa se intampla,cand vin,vin tati-odata.dar cum nici dracu` nu-i asa de negru,si cum dupa ploaie rasare soarele,fii bland..pana la urma toate se vor intoarce la normal.cateodata e binevenita o picatura de \"adrenalina\",sa te mai scoata din rutina.multa sanatate iti doresc,ca restul se rezolba.bila alba o primesti doar daca nu intri in panica.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; SIMBAR={6F0FD749-995D-45FA-868D-69ED48107126}; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(15263,980,'ascutita','michi.deli@gmail.com','','220.96.122.218','2008-02-07 01:27:24','2008-02-06 23:27:24','anonimu` de mai devreme eu am fost,dar am scris mai intai mesajul,si am uitat sa mai completez si restul',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; SIMBAR={6F0FD749-995D-45FA-868D-69ED48107126}; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(16181,989,'Muc','iordan12345@yahoo.com','http://mucgustos.blogspot.com/','92.82.51.135','2008-02-14 22:09:20','2008-02-14 20:09:20','oficial o fo` cea mai de cacat zi a anului 2008 ... pana acuma :p ... mai este timp sa fie intrecuta\r\n:D:D:D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(16175,989,'Andreea MKT','supergirgir@yahoo.com','','89.43.186.64','2008-02-14 21:00:34','2008-02-14 19:00:34','e zÃ¢ua ta, mÄƒ, trogÄƒre?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(16176,989,'zanetti','valy_alexe@yahoo.com','http://www.blogoperativa.com/zanetti','86.55.176.96','2008-02-14 21:03:01','2008-02-14 19:03:01','unde-i valantain sa-i fut una?\r\ngropare,cand e ziua ta de nastere?am o banuiala ca ai fost conceput in perioada asta a triunghiului :))',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; SIMBAR={6D4C1160-A44C-41C8-A9CA-57EAC9AD608C})','',0,0),(15718,984,'Andreea MKT','supergirgir@yahoo.com','http://marlahermina.deviantart.com/gallery/','82.77.126.254','2008-02-11 09:42:00','2008-02-11 07:42:00','deci tu iesi la beute cu clientii italieni la care le faci traduceri (mai ales orale)? Groparu, plm, in 2-3 ani de cariera translatoriceasca, eu nu am iesit veci cu un italian anche se io parlo l\'Italiano cosi come il Francese, con la diferenza che il Francese sux. Deci next time te rog sa imi dai macaronarii pe mana. Arabi nu vreau. Nu vreau ca eu sa am chef de sex si ei sa se tranteasca pe covorash sa se roage exact atuncia.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; InfoPath.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(15719,984,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-02-11 09:48:54','2008-02-11 07:48:54','Tu, little sex seeker (NOT)! Chiar vreai sa-ti incropeasca boyfrendu\' tau destul de americanofil o corectie destul de islamista? \r\n\r\nMai francieze sax tu.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(15721,984,'Andreea MKT','supergirgir@yahoo.com','http://marlahermina.deviantart.com/gallery/','82.77.126.254','2008-02-11 09:57:19','2008-02-11 07:57:19','Glumeam, no! Prietenul meu Wake me Up When September Ends citeste posturile tale ca pe Biblie (ca nu zic Versetele Satanice), deci te citeste ca pe Biblie si vede ce comentez si stie ce am in cap. Asa ca nu mi-e jena de ce comentarii bag aicia, mai ales ca am facut cunoscut ca italiana e limba mea preferata, franceza mea e buna dar franceza in genere sux,  iar eu sunt fideloida in viata reala si nebunateca pe posturile tale, mai ales cand vbim despre traduceri. Asa ca pe el il iubesc pana la moarte iar pe www.groparu.ro, pot sa imi iau alta identitate si sa scriu prostii. e gratis. si pot!!!',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; InfoPath.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(15988,990,'Turambar','mirel@ccsb.ro','http://turambarr.blogspot.com','82.76.108.17','2008-02-13 14:09:15','2008-02-13 12:09:15','Pai egzact pentru asta pledam shi eu, Andreea: doar fro 10 15. Un numar de bun simtz, pe care-l potzi cuprinde pe deshtele de la doo maini shi doo picioare shi care sa permita extensiei penile o bucurie de andurantza, sustenabila, neofilitoare. \r\n\r\nDoar fro 10 15. Simplu. Putzin. Clar. Same girl twice per month. Ce poate fi mai fara de cusur?\r\n\r\nSe inscrie cineva la preselectzie? \r\n\r\n<i>Gropare, stai cuminte! Ai barba shi par pe pept. Nu corespunzi criteriilor... </i>',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(15958,990,'Andreea','puistrulet2003@yahoo.com','http://n/a','81.196.150.196','2008-02-13 09:40:49','2008-02-13 07:40:49','Eu zic sa nu-ti fie ciuda...gandeste-te numai saracii de ei, is si urati (recunosc, opinie personala :) ), mai si vorbesc aproape tot timpul in consoane (oare ei fac febra musculara la limba?? ) si mai si tre sa poarte cearsafurile alea pe ei...\r\n\r\nDeci, trist pt ei... :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(15959,990,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-02-13 09:48:26','2008-02-13 07:48:26','@ ametzitul: da, si eu vreau sa ma marit cu asa unu.\r\n\r\n@ Andreea: dac-as avea ase, bani kklau, si mie mi-ar fi lene sa-mi mai pun pantalonii pe mine! Asa ca m-as imbraca in cearshafe, sa nu pierd timpu cu dezbracatu\' daca o vad pe viitoarea mea trei suta nevasta la mall, si vreu sa avad daca si presteaza la fel de bine pe cat arata :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(15724,984,'Turambar','mirel@ccsb.ro','http://turambarr.blogspot.com','79.114.190.130','2008-02-11 10:24:30','2008-02-11 08:24:30','Aha. Cum zicea Nirvana in albumul ei A Night with the Razors: It smells like sex spirit. Domnilor, doamnelor, va invit sa parasim incaperea. Aceste doo distinse identitatzi virtuale simt nevoia grabnica shi navalnica sa faca schimb de nishte lichide corporale. Sa nu-i impiedicam, ca-i mananca...\r\n\r\nAnd French does not suck. Only French girls do. Avec passion et levres moux. Et froides.\r\n\r\n:)  :p',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(16170,989,'','','','89.43.132.28','2008-02-14 20:09:14','2008-02-14 18:09:14','Continuare la ce a scris Innuenda care mi-a oferit o clipa de inspiratie :)\r\n\r\nMutunache mic, nu pot sa cred ca te iubesc la fel de mult dupa atatia ani; si acum imi vine in minte imaginea ta stand la calculator, cu o bere in mana, in timc ce ragai si te partai uitand-te cu jind la mine si gandind probabil ce sa-ti mai aduc din frigider(sac fara fund ce esti!!)  inconjurat de ambalaje de ciocolata, pungi goale de chipsuri si flacoane de suc + un rest de pizza de acum 5 zile :)\r\n\r\nCum sa nu te iubesc?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(16171,989,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2008-02-14 20:12:15','2008-02-14 18:12:15','@ Innuenda si Anonymous: deci =)) wespeeeect!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(15727,984,'Andreea MKT','supergirgir@yahoo.com','http://marlahermina.deviantart.com/gallery/','82.77.126.254','2008-02-11 11:39:56','2008-02-11 09:39:56','deci Turambar, watch your speak and watch your step. eu si groparu suntem colegi decentzi si prietenoshi. atata. el poate sa confirme. eu femeie la casa mea iar azi sunt imbracata ca bunica iubitului meu.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; InfoPath.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(15294,981,'nenea','nenea77@yahoo.com','http://www.nenea.ro/','81.181.209.170','2008-02-07 08:13:36','2008-02-07 06:13:36','domnisoara, aveti picioare de broasca?\r\nraspunsul ei il stiti, nu? :)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; IEMB3; IEMB3)','',0,0),(15993,990,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-02-13 15:13:11','2008-02-13 13:13:11','Te adaug!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(15199,980,'Felix','felix.felix@gmail.com','','213.233.122.144','2008-02-06 15:28:03','2008-02-06 13:28:03','in caz ca se nasoleste treaba mai rau decat acum, poti sa vinzi un rinichi. e numai bun, spalat cu bere. pana la faza aia poti sa cauti rinichiu altuia (btw, parca vroia sa vina cineva mirosind a sapun pe la tine pe\'acas\')',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(15513,966,'speedy','speedy_boy77@yahoo.com','','86.123.216.101','2008-02-08 23:27:03','2008-02-08 21:27:03','Pana Aici!!!\r\n\r\nScumpiti fratilor ce vreti dar nu berea!!! Dak scumpesc astia berea suntem morti :| Ce farmec mai are fotbalu? ce farmec mai au semintele?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(15061,979,'Fluture','fluture093@yahoo.fr','http://Fluture.friendlyfrog.ro','82.254.127.161','2008-02-05 17:49:00','2008-02-05 15:49:00','Sarkozy minte la fel ca Basescu... sa nu uitam ca Sarkozy a fost casatorit de 3 ori, deci declaratiile lui nu sunt chiar \"pe viata\".\r\n\r\nOricum, mult fum pentru nimic. 5 zile de stiri in presa, pentru o basina franco-romaneasca.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; fr; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(15999,990,'mirra','','','83.103.137.234','2008-02-13 15:41:07','2008-02-13 13:41:07','unde-i multa bogatie, e multa saracie....la minte!!! Astia is si multi si prosti,parerea mea!\r\n@Lorand R.Minyo: ai dreptate,la fel ca manelistii de la noi....',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(16001,990,'mirra','','','83.103.137.234','2008-02-13 15:46:00','2008-02-13 13:46:00','@groparu: nu toti cei parosi iti starnesc poftele oricat ar fi de futaciosi,altii reusesc sa-ti faca greatza cu atata par pe ei si peste tot!!!:))))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(15187,980,'maria','marysofian@yahoo.com','','167.3.92.199','2008-02-06 13:32:24','2008-02-06 11:32:24','haide domne ca eu cred ca se mai poate rezolva cate ceva pe ici, pe colo.\r\n\r\ndeci!\r\nziua de concediu medical ti-o poti recupera daca te mai vizitezi odata cu domn\' doftor, ii explici si ti-a da tzadula. \r\n\r\niar parintii n-au voie sa cumpere oale fara voia ta, nu asa scumpe. daca au facut-o, e treaba lor, sa le dea inapoi. si apoi nu le-o trebui taman 4000 de euroi sa traiesca pe luna februarie, noa!\r\n\r\niar cu masina de spalat, esti sigur ca n-ai uitat sa pui deterjent? ori nu cumva ai pornit masina azi si ai deschis usa poimaine? ca atunci n-are cum sa nu puta. maxim 12 ore de cand ai pornit masina, apoi macar deschide-i usa, apoi in cateva ore trebe scoase, fie si p\'un scaun, da scoase d\'acolo. ok. numai bine, pa tu!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; InfoPath.1; .NET CLR 3.0.04506.30)','',0,0),(15509,982,'Andreea MKT','supergirgir@yahoo.com','','89.43.186.64','2008-02-08 22:49:14','2008-02-08 20:49:14','bobocel',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(15479,986,'oedip','oedip74@gmail.com','http://oedip.blogspot.com','89.137.99.163','2008-02-08 17:16:57','2008-02-08 15:16:57','oh iubitule ce indurerat sunt :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(15480,985,'Andreea MKT','supergirgir@yahoo.com','http://marlahermina.deviantart.com/gallery/','82.77.126.254','2008-02-08 17:17:38','2008-02-08 15:17:38','deci groparu nu o auzit de Gogol Bordello si de Eugene Hutz!!!!',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; InfoPath.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(15481,985,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-02-08 17:22:32','2008-02-08 15:22:32','Ce tat vreai, tu, ce, tu ai auzit de Gica Hagi?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(15979,988,'oedip','oedip74@gmail.com','http://oedip.blogspot.com','89.137.99.163','2008-02-13 12:47:36','2008-02-13 10:47:36','bah wolfy, groapa nici in groapa nu se linisteste... :))\r\nlasa ca mai merg io cu el la bere sa-l rezolv...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(15303,981,'Andreea','puistrulet2003@yahoo.com','http://n/a','81.196.150.196','2008-02-07 10:03:29','2008-02-07 08:03:29','Neatza,\r\n\r\nCred ca ar trebui sa schimbi titlul cu \"Top 10 chestii care trebuie spuse unei chelnerite atunci cand ai parte de urmatorul tratament: se urneste atat de greu sa vina la masa (nu mai zic de mutra de martir sictirit intiparita pe fata) incat iti vine s-o iei si s-o dai cu capul de pereti/ vine la masa si te intreaba ofuscata ce doresti si tu tre sa joci jocul \'de-a adusul meniului\' si ea te priveste urat de tot ca mai tre sa faca un drum :)/ iti aduce mancarea sau bautura si ti-o pune pe masa in scarba de parca tu ai fi ultimul jegos/oasa pe care ea/el \'the mighty waiter/waitress\' tre s-o/sa-l serveasca/ s.a \".\r\n\r\nBtw cred ca mai multa concurenta le fac vanzatoarele din magazin (e o specie care nici cum nu vrea sa piara - sunt al naibii de rezistente- ca si gandacii :) ) mai ales cele din magazinele de haine...\r\n\r\nNu credeti?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(15997,990,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-02-13 15:33:43','2008-02-13 13:33:43','@ Turambar: mah, masculii paroÅŸi Ã®s futacioÅŸi, zice vorba din bÄƒtrÃ¢ni!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(15306,980,'WhiteWolf','contact@white-wolf.ro','http://white-wolf.ro','89.39.83.78','2008-02-07 10:41:04','2008-02-07 08:41:04','Exact cand ai zis ca ti-ai cumparat circ, ti-au murit piticii.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11 FireShot/0.32','',0,0),(15010,979,'katmai','katmai@keptprivate.com','http://512kbps.com','195.212.29.171','2008-02-05 10:16:52','2008-02-05 08:16:52','in final conteaza doar vodka ...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(15011,978,'mishu','mishu@doingtheartwork.com','http://www.doingtheartwork.com','82.77.126.254','2008-02-05 10:21:53','2008-02-05 08:21:53','nu comentez la subiectul asta, i-ar inchide situl lui groparu\'. da\' ca sa va facetz o idee de cum as trata eu problema politicienilor, click this: http://www.thecleverest.com/countdown.swf',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(15973,990,'Lorand R. Minyo','lorand.minyo@simpliq.com','http://www.lorandminyo.ro/','89.36.21.82','2008-02-13 11:56:11','2008-02-13 09:56:11','Radem si glumim, dar majoritatea arabilor (bogati) sunt mai rau ca manelistii de pe la noi. \r\n\r\nNu conteaza ca nu are nu stiu ce performante serverul ala, bling-bling sa aiba mult ca sa aiba ce sa arate la sheik. Ala o sa fie ciudos, o sa-si ia 100 de servere platinate si o sa arate si mai bine. Ca deh, un server 1U aurit arata ca un lingou de aur, nu? :)\r\n\r\nMa intreb ce o sa faca oamenii astia cand o sa se termine diamantele si aurul...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(15749,984,'RipaHoratiu','','','89.122.158.96','2008-02-11 16:16:16','2008-02-11 14:16:16','Ba frate, asta e coios? Coios e unu\' care luni dimineata se trezeste ca nu mai are slujba care oricum nu-i acoperea cele 1000 de credite, pe dupa-amiza tra sa se insoare ca intr-un moment de euforie alcoolica o cerut-o pe una de nevasta (nu-si mai aduce el aminte exact pe cine) si tocma i-or vandalizat masina. Si ca sa fie imaginea completa vecinu tocma asculta la radio, in asa fel incat sa beneficieze juma\' de cartier: \"Dimineata-nsorita, fii binevenita, ....\". Toate in aceeasi zi de luni, si urmeaza ziua de marti!',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.2; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(15751,974,'RipaHoratiu','','','89.122.158.96','2008-02-11 16:18:58','2008-02-11 14:18:58','... prietenii stiu pe cine si de ce',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.2; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(15974,990,'Turambar','mirel@ccsb.ro','http://turambarr.blogspot.com','79.114.190.130','2008-02-13 11:57:11','2008-02-13 09:57:11','Bineee, Andreea, binneee. Hai fie ca tine. Recalibram. 30. Na, asha e bine? \r\n\r\nGropare, da-le afara pe\'alea 270. Din ele facem o preselectzie riguroasa, noi ashtia apropiatzii tai online, le angajam de proba vreo luna doo si ne pastram shi noi partea shtremeleagului balcanic vreo 10 15. Ca noi nu avem andurantza clujenilor, tu, ci doar vremelnicia pustei sudice bantuite de tatari. Cum te prinde, cum se face numaru 16.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(15015,978,'nenea &raquo; Blog Archive &raquo; SÄƒ mÄƒ p**/c**/f** pe ea de Å£arÄƒ','','http://www.nenea.ro/?p=642','77.81.4.72','2008-02-05 11:13:19','2008-02-05 09:13:19','[...] mai scris: groparu, gramo si big.lazyadmin. [...]',0,'1','Incutio XML-RPC -- WordPress/2.1.3','pingback',0,0),(15018,977,'mo','verde_poveste@yahoo.com','','194.126.220.22','2008-02-05 11:36:14','2008-02-05 09:36:14','La naiba! Intru si io cu elan mare sa postez ca treaba cu barbatu\' fericit cu orice femeie e a lui Wilde si vad oameni (ahem-ahem, PhenoBarbieDoll) care freaca menta si posteaza pe sait la Groparu\' in loc sa isi faca lucrarea, cum ne-am inteles.... in shimbul de mailuri de azi..... ;)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1)','',0,0),(16023,990,'vizionarul','alinmiron_19@yahoo.com','http://vizionarul.wordpress.com','89.35.87.15','2008-02-13 19:17:10','2008-02-13 17:17:10','hp sux big taim... imprimantele is nasoale, scannerele slabe, si nu stiu sa lucreze nici macar cu imprimante hp, laptopurile sunt energofage daca n-ai un minireactor de cernavoda in geanta, serverele parca-s aeroterme... \r\niar unii araboci... ca unii romani... ie snobi.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648)','',0,0),(15023,977,'PhenoBarbieDoll','oana.gavrila@mediafax.ro','http://blog.360.yahoo.com/poisongirl94','86.120.236.133','2008-02-05 12:51:25','2008-02-05 10:51:25','aha, deci tu ejti mo! io cre\' ca tu ma urmaresti. si menta s-a frecat aseara, no, cand ieram in paoza! oricum, tre\' sa apreciezi ca vorbeam despre subiect, care, vorba Groparului, e pe punctul de a se transforma in predicat.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1)','',0,0),(15741,984,'Turambar','mirel@ccsb.ro','http://turambarr.blogspot.com','82.76.108.17','2008-02-11 15:04:00','2008-02-11 13:04:00','Si io glumeam, de fapt. Except sutienu taiat rondeluri sfarcuite. In asemenea subiecte I\'m deadpan serious and I always carry a pair of scissors with me. You know: just in case... \r\n\r\n:lol:   :rofl:',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(15964,990,'Andreea','puistrulet2003@yahoo.com','http://n/a','81.196.150.196','2008-02-13 10:37:44','2008-02-13 08:37:44','300? :)\r\nNu lua mai mult decat poti duce.. :) Partea cu sexul hai ca la inceput e ok, merge, dar dupa, ce faci cu 300 de moace care stau dupa fundul tau sa le duci in mol si sa le cumperi si aia si ailalta si daca uiti de una , aia se supara pe tine si apoi uiti inca de una si asa mai departe si te trezesti cu un mutiny de toata frumusetea pe capul tau??? Lor n-o sa le mai arda de secs dar o sa le arda de altceva :)\r\n\r\nSi sa stii ca tot in consoane o sa vorbesti (nu stiu cat de \"secsi\" suna in timpul actului...) adica no... zic si eu',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(15025,978,'julius constantinescu','julius@universitateacraiova.ro','http://www.7plus.ro/?arhiva=05/02/2008&#38;id=1803','84.232.160.209','2008-02-05 12:54:58','2008-02-05 10:54:58','@groparu: ma, unde dracu\' ai vazut tu ca a fugit ala, ca io l-am vazut pe caseta aia ca ninsese pe el la locul faptei pana ajunsese ca mos craciun. si doi, ca revin la codul rutier, pe care-l stiu ca pe Cutu\' schiop, daca nu era victima, nu vine nici o politie, te cari singur la sectie, in 24 de ore. si hai, gata cu consultatiile moca, ca n-am chef, dupa ce omorati pe careva, sa spuneti ca ati invatat sa conduceti online, de la mine :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(15962,990,'10MBC','alin.banc@gmail.com','','217.156.21.3','2008-02-13 10:30:48','2008-02-13 08:30:48','de cand hp-u face servere? :))\r\nOare de ce nu le-o pornit si sa se amuze de cat zgomot aiurea fac? il spanzura pe ala de la hp care le-o trimis?\r\n\r\nAuzi, groparele... ofer comision gras daca ma pui in legatura cu araboicii aia.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(15028,979,'tya','afrimtya@yahoo.com','http://afrim-tya.blogspot.com','82.77.126.254','2008-02-05 13:21:58','2008-02-05 11:21:58','Dictionar explicativ pt fetele care nu intelege nimic... da nimic nimic(sursa Wikipedia) :\r\nThe AMX-56 Leclerc = main battle tank (MBT) built by GIAT Industries of France.\r\nPentagon=headquarters of the United States Department of Defense\r\nThe Sukhoi Su-30 (NATO reporting name \"Flanker-C\") = agile military aircraft developed by Russia\'s Sukhoi Aviation Corporation and introduced into operational service in 1996.\r\nThe Mirage 2000 = French-built multirole fighter jet manufactured by Dassault Aviation\r\nPS: La suhoaie nu stiu la ce model te-ai gandit asa ca mno..mi-am dat cu presupusu..\r\nPS2: Pacat ca nu intelegi engleza ..dragu meu:P:P\r\nPS3: Stiu ca ma iubesti, si eu la fel.:DDDDDD',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(15809,988,'Dru','delia.adriana@gmail.com','','82.77.126.134','2008-02-12 09:20:50','2008-02-12 07:20:50','Intreb si eu: orice nevasta e un monstru cu sapte capete???????? \r\nDupa umila mea parere, nu.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(15737,984,'Andreea MKT','supergirgir@yahoo.com','http://marlahermina.deviantart.com/gallery/','82.77.126.254','2008-02-11 14:01:59','2008-02-11 12:01:59','io es de aicia, you are mothafuckingly insane si eu numa glumeam la faza cu arabii.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; InfoPath.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(15847,988,'Catzaua','','','81.180.173.61','2008-02-12 15:33:30','2008-02-12 13:33:30','@ Andreea MKT : s-ar marita femeile ca au o varsta ? suna a compromis. adica de la o anumita etate ai fi in stare sa stai si in desh\'tiu\' mic de la piciorul stang numa\' sa isi faca unu\' mila de tine sa nu ramai nemaritata? i shall be a spinster, then :) \r\nsi daca \"vor sa se marite ca sa fie sigure ca o sa tzina animalul langa ele si pe mai incolo. Si daca o sa aiba copil, sa se asigure ca animalul tot acolo va fi.\" nu sunt snoabe proaste, sunt doar proaste si atat. \r\n\r\n@ manole: nu mai bine face rost de alta, versiune imbunatatita si multilateral dezvoltata? eu una asa as proceda :D sau m-as baga la un curs de home-management',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(15835,988,'Felix','felix.felix@gmail.com','','213.233.122.144','2008-02-12 13:59:47','2008-02-12 11:59:47','o alta varianta economicoasa e sa iti iei caine de apartament, sa iti linga blidele. le da inapoi stralucinde, si il poti folosi si pe post de ceas desteptator.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(15031,974,'RipaHoratiu','','','89.122.158.96','2008-02-05 14:02:07','2008-02-05 12:02:07','Io am una parafrazata dupa o replica tot vestern, care ma urmareste de o vreme:\r\n\"Io omor pe oricine pentru o suma potrivita de bani, da\' pe tine, pen\'ca te-am cunoscut, sunt dispus sa te omor pe gratis\"',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.2; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(15739,82,'razvan','razvan_lumeaieseanului@yahoo.com','','195.64.178.143','2008-02-11 15:03:00','2008-02-11 13:03:00','esti tare, am ras de am crapat. nu ca as cunoaste personajele, dar mi-am adus aminte de un chef din C5, Codrescu Iasi, cand, pentru a face un chef, a trebuit sa o imbatam de tipa administrator. mult am mai regretat...avea chef de ...si nu avea cu cine...\r\nof doamne, studentie',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; SIMBAR={27366918-163F-4a9f-8D3A-450956B5F040})','',0,0),(15033,976,'RipaHoratiu','','','89.122.158.96','2008-02-05 14:07:09','2008-02-05 12:07:09','\"In adolescenta, daca intram la fete la buda pentru un pipi si ce mai gaseam pe acolo de facut cu putulica, eram eroul grupei mari.\r\nAcum, s-ar putea sa nu mai reusesc sa scap cu viaÅ£Äƒ din toaletÄƒ (da, too much sex can kill you!)\"\r\nToo much sex cu faianta, dragule, cu faianta. Ca de-acu\' nu te mai cauta nici fetele, nici indaratnicii prin bai. Acu\' stau sa ma gandesc ca tu erai ala de desenai chestii obscene pe peretii si usile de la buzile din firma...',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.2; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(15034,977,'mo','verde_poveste@yahoo.com','','194.126.220.22','2008-02-05 14:20:28','2008-02-05 12:20:28','Well, just because you\'re paranoid doesn\'t mean I\'m not after you...\r\nAsa ca teme-te si scrie (astept dedicatie pe lucrare :D)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1)','',0,0),(15733,984,'Turambar','mirel@ccsb.ro','http://turambarr.blogspot.com','82.76.108.17','2008-02-11 13:23:34','2008-02-11 11:23:34','Vad deja in oglinda mintzii o bunica emancipata, in dessou-uri negre, dantelate shi lucitoare, cu o biciushca neagra shi ciupitoare, cu ochelari de bunicutza pe varfu nasului si cu sutien decupat in jurul sfarcurilor. \r\n\r\nDa-i pe cocoasha, bunicutzo! Da-i! These boots are made for walking, That\'s what they gonna do, One of these days these boots Are gonna walk all over you\r\n\r\n:)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(15036,978,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-02-05 14:28:52','2008-02-05 12:28:52','Deci ba! Tu tii cu iel acuma?\r\n\r\nDa\' de ce-o mintit ca nu o facut accident? Si ca nu o lovit pe nimeni cu majina?\r\n\r\n(nu ti-i neam, nu?)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(15037,979,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-02-05 14:40:33','2008-02-05 12:40:33','Tya, ai ajuns pe saitul producatorilor rusi de avioane de vanatoare cautand retete de spanac pe google, nu?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(15038,977,'PhenoBarbieDoll','oana.gavrila@mediafax.ro','http://blog.360.yahoo.com/poisongirl94','86.120.236.133','2008-02-05 14:41:16','2008-02-05 12:41:16','declar sesiunea de autografe deschisa!',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1)','',0,0),(15039,979,'tya','afrimtya@yahoo.com','http://afrim-tya.blogspot.com','82.77.126.254','2008-02-05 15:01:16','2008-02-05 13:01:16','Actually the search word was \"aphrodisiac food\". Si evident ca ma gandeam la tine...',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(15810,988,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-02-12 09:23:25','2008-02-12 07:23:25','Nu, clar ca nu.\r\n\r\nAlea care nu au 7 capeÅ£i sunt pur si simplu Hidra din Lerna, cÄƒ cÃ¢nd crezi ca le-ai retezat unu\' mai apare trei(ÅŸpe)!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(15811,984,'Basty','basty@canvas.ro','http://basty.wordpress.com','82.77.126.21','2008-02-12 09:23:44','2008-02-12 07:23:44','@Groparu\r\nBina ai facut, mama lor de lenesi cu toata breasla lor care se crede mai dasteapta decat restul lumii ! De softisti adica spun. Sa nu generalizam finca nu-i frumos sa atentezi la imaculata moralitate a unora.',0,'1','Mozilla/5.0 (Macintosh; U; Intel Mac OS X; en) AppleWebKit/523.12.2 (KHTML, like Gecko) Version/3.0.4 Safari/523.12.2','',0,0),(15860,988,'WhiteWolf','contact@white-wolf.ro','http://white-wolf.ro','89.39.83.220','2008-02-12 17:41:57','2008-02-12 15:41:57','Orice ai hotarati si vei continua sa hotarasti, legat de destinul tau (af cors) esti perfect constient ca nu il poti fenta. Da ?\r\nInsa, de ce n-as recunoaste, sunt interesante (cel putin) tentativele tale de a incerca sa-i spui cate un :<b>bÃ£, destine, deci ne linistim: da ?\" </b> :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(15044,979,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-02-05 15:09:44','2008-02-05 13:09:44',':\"&gt;',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(15759,984,'mirra','','','83.103.137.234','2008-02-11 17:45:13','2008-02-11 15:45:13','voi nu sunteti normali,dar va iubesc!!!!! Fara voi viata mea ar fi la fel de chioara ca si inainte sa va descopar!!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(15046,978,'Victor Ciutacu','victor@ciutacu.ro','http://www.ciutacu.ro','82.76.75.160','2008-02-05 15:20:47','2008-02-05 13:20:47','@Groparu: e nasoala legea, tine cu banditii ai mari, nu-i asa? si viata-i cam curva...',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(15047,978,'julius constantinescu','julius@universitateacraiova.ro','http://www.7plus.ro/?arhiva=05/02/2008&#38;id=1803','84.232.160.209','2008-02-05 15:50:15','2008-02-05 13:50:15','@groparu: ma, nici tata n-avea Dacie cand eram mic, da\' io n-am ramas, totusi, cu sechele...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(15807,988,'ametzitul','','http://ametzitul.wordpress.com','62.217.236.12','2008-02-12 08:56:45','2008-02-12 06:56:45','hai mah ca la mine acasa era curat...\r\ncel putzin asha imi inchipuiam eu pana s-a mutat nevasta :(\r\nhabar n-aveam ca tre\' sa ridici canapeaua si sa aspiri pe sub ea...\r\nsi vase murdare nu se adunau, ca mancam mereu din aceleashi, dupa ce ma prefaceam ca le clatesc',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(15732,984,'PhenoBarbieDoll','poisongirl94@yahoo.com','http://blog.360.yahoo.com/poisongirl94','193.230.230.101','2008-02-11 13:19:07','2008-02-11 11:19:07','si bunica saraca cu ce e imbracata? ca stiu io ca femeile nu suporta sa fie imbracate la fel!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(15053,978,'mirra','','','83.103.137.234','2008-02-05 16:54:49','2008-02-05 14:54:49','Nu comentez la faza asta,ca e specific romaneasca si de  d\'astea romanesti m-am cam saturat! Da poate ca dupa ce-ti iei canetu\' o sa-ti schimbi parerea!\r\nAsta daca o sa-l iei vreodata in viatza asta!:))))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(15054,979,'Usim','mihaimitan@gmail.com','','195.189.142.180','2008-02-05 17:00:21','2008-02-05 15:00:21','Tya, Groparu n-a pomenit nimic in articol de Pentagon, ci de Hexagon, adica mai pe englezeste, France. :-)',0,'1','Opera/9.50 (J2ME/MIDP; Opera Mini/4.0.9751/256; U; en)','',0,0),(15055,960,'','','','86.122.44.17','2008-02-05 17:08:07','2008-02-05 15:08:07','of doaamne! cand vad traduceri din astea a la \"traducerea facuta brosurii Sibiu Capitala (in)culturala\" aproape ca mi\'e si jena sa recunosc ca fuck masterul in traductologie engleza.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(15057,979,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-02-05 17:13:41','2008-02-05 15:13:41','@ Usim: in  sfarsit unu care s-o prins!!! Wespect...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(16064,989,'WhiteWolf','contact@white-wolf.ro','http://white-wolf.ro','89.39.81.245','2008-02-14 02:52:13','2008-02-14 00:52:13','Si cum zici ? C\'ai fi din ceva spermatozoiji din aia campioni ? :D\r\nBre, dragostea-i lucru mare; da ?\r\nIn rest , fix la baska ma doare ca le ciufulesti ziua imperialistilor :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(15520,985,'Mo','verde_poveste@yahoo.com','','86.120.170.201','2008-02-09 00:54:56','2008-02-08 22:54:56','http://www.wizmovies.com/watch-Everything-Is-Illuminated.html\r\nNa, ca tz-am gas\'t link la film. Cu tat cu Eugene Hutz.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(16164,989,'innuenda','innuenda.innuenda@gmail.com','http://innuennda.blogspot.com','92.80.9.223','2008-02-14 19:24:31','2008-02-14 17:24:31','Åži ea sÄƒ-i rÄƒspundÄƒ aÅŸa:\r\n\r\n- EÅŸti unic pentru mine. Numai la tine a durat 3 minute cu tot cu preludiu.\r\n\r\n- MÄƒ gÃ¢ndesc la tine mereu. MÄƒ Ã®ntreb cÃ¢nd ajungi acasÄƒ, oare ai plecat deja de la serviciu, ce faÅ£Äƒ ai face dacÄƒ ai intra pe uÅŸa dormitorului chiar acumâ€¦chestii de astea.\r\n\r\n- AÅŸ vrea sÄƒ te port tot timpul cu mine. La cumpÄƒrÄƒturi mai ales. La Milano.\r\n\r\n- Iubesc felul tÄƒu discret de a fi. AtÃ¢t de discret cÄƒ dacÄƒ nu aÅŸ vedea Ã®n fiecare dimineaÅ£Äƒ pÄƒrul tÄƒu pe sÄƒpun nici n-aÅŸ ÅŸti cÄƒ ai trecut pe acasÄƒ.\r\n\r\n- Iubitule, Å£i-am luat de Valentineâ€™s Day o oglinjoarÄƒ Ã®n formÄƒ de inimÄƒ, sÄƒ-Å£i aducÄƒ aminte de mine, Ã®n nopÅ£ile cÃ¢nd, din cauza burÅ£ii, o sÄƒ Å£i-o priveÅŸti cu oglinda sÄƒ vezi dacÄƒ nu cumva Å£i s-a uscat ÅŸi-a cÄƒzut de cÃ¢nd n-ai mai folosit-o!\r\n\r\n-Hai, nu te supÄƒra, ursuleÅ£, tu ÅŸtii cÄƒ te iubesc. Uite, dacÄƒ nu mÄƒ crezi, o sÄƒ-Å£i dovedesc cÄƒ pot deschide ochii Ã®n timp ce facem dragoste, fÄƒrÄƒ sÄƒ mÄƒ mai sperii. Doar un wiskey-douÄƒ sÄƒ beau pentru curajâ€¦ce nu fac eu pentru tine!\r\n\r\n- Incredibil cum, dupÄƒ atÃ¢ta amar de ani, Ã®ncÄƒ sunt virginÄƒ!\r\n\r\n- DacÄƒ Å£ip prea tare Ã®n timp ce facem dragoste, sÄƒ ÅŸtii cÄƒ iar mi-ai agÄƒÅ£at cercelul cu verigheta, iar dacÄƒ tot nu mÄƒ opresc dupÄƒ ce Å£i-ai tras verigheta sÄƒ ÅŸtii cÄƒ e cineva Ã®n spatele tÄƒuâ€¦\r\n\r\n- Uite, te ajut sÄƒ Ã®mi descoperi buricul printre faldurile de grÄƒsime dacÄƒ-mi promiÅ£i cÄƒ nu o sÄƒ greÅŸeÅŸti ÅŸi de data asta gaura. ÃŽmi promiÅ£i?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(15063,977,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-02-05 18:10:33','2008-02-05 16:10:33','No ui, mah, altii care ajung la fornicaiala cetind saitu\' meu!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(15065,977,'PhenoBarbieDoll','oana.gavrila@mediafax.ro','http://blog.360.yahoo.com/poisongirl94','86.120.236.133','2008-02-05 18:32:33','2008-02-05 16:32:33','Gropare, saitu\' tau ii un fel de crajma satului.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1)','',0,0),(15359,983,'Blogosfera in pana de idei | ARHI','','http://www.arhiblog.com/blogosfera-in-pana-de-idei','74.54.41.98','2008-02-07 22:17:13','2008-02-07 20:17:13','[...] blogosferica romana. Adica, nu e normal, sa nu am ce citi nicaieri. Groparul bate campii cu nustiu ce chiloti. Clara lipsa de orice, nu doar de inspiratie. Gogu Kaizer face premii, care sunt niste [...]',0,'1','Incutio XML-RPC -- WordPress/2.3.1','pingback',0,0),(15212,980,'manole','mesterulmanole07@gmail.com','http://www.mesterulmanole.wordpress.com','89.32.123.108','2008-02-06 17:35:53','2008-02-06 15:35:53','ce faci, Gorparele? nu te-ai inpacat INCA cu Groparita? Pai ce, esti de capul tau!??',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; SIMBAR={6027D00E-CD16-11DC-9BA8-001B2FCE5715}; .NET CLR 1.1.4322)','',0,0),(15007,978,'Andreea','puistrulet2003@yahoo.com','http://n/a','81.196.150.196','2008-02-05 09:54:49','2008-02-05 07:54:49','Finca e  mai destepti decat noi, prostimea, de-aia...\r\n\r\nNUP - Nu Urmarim Penalii (Penalii = Ludovicimea Orbana)- suna funny :))\r\n\r\nSorry, no inspiration whatsoever this morning....:)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(15067,979,'baubau','urzicahoratiu@yahoo.com','','86.122.39.133','2008-02-05 19:07:52','2008-02-05 17:07:52','Sarko liuba for ever tara la dl goe cu cap gol pe dinauntru si pe  dinafara.Mariner multumit de tain.Revenim amanunte peste 50 ani, dupa desecretizare.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0b; Windows NT 5.1)','',0,0),(16012,990,'mirra','','','83.103.137.234','2008-02-13 17:35:02','2008-02-13 15:35:02','@groparu: cum ai aflat ieri? din proria experienta?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(15569,986,'Lorand R. Minyo','lorand.minyo@simpliq.com','http://www.lorandminyo.ro/','89.36.21.82','2008-02-09 11:50:01','2008-02-09 09:50:01','Dada, aia este.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(15460,985,'mo','verde_poveste@yahoo.com','','194.126.220.22','2008-02-08 13:58:08','2008-02-08 11:58:08','A, si unul din personajele principale e Eugene Hutz fara musteatza.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1)','',0,0),(15461,985,'nenea','nenea77@yahoo.com','http://www.nenea.ro/','81.181.209.170','2008-02-08 14:00:40','2008-02-08 12:00:40','poate ai fi avut noroc sa se traga linie sub tine pe lista lu\' Schindler. a, da stai, ca zici ca nu prea esti norocos :)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; IEMB3; IEMB3)','',0,0),(15209,980,'li','alina_livia_lazar@yahoo.com','http://www.alinalivialazar.blogspot.com','89.136.204.179','2008-02-06 17:09:47','2008-02-06 15:09:47','urmeazÄƒ ÅŸi io. the worst of all, ivitÄƒ brusc pe aicia sÄƒ Ã®Å£i zic: \r\n\r\nÃ®nsÄƒnÄƒtoÅŸire grabnicÄƒ, frumuseÅ£e! :)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(15315,981,'nenea','nenea77@yahoo.com','http://www.nenea.ro/','80.86.123.99','2008-02-07 11:51:15','2008-02-07 09:51:15','iegzact! nu e tare? :)',0,'1','Mozilla/5.0 (Macintosh; U; PPC Mac OS X; en) AppleWebKit/418 (KHTML, like Gecko) Safari/417.9.2','',0,0),(15438,985,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-02-08 10:27:31','2008-02-08 08:27:31','Hmmm... pai: in pat, supt duÅŸ, prin dulap, pe masa din bucÄƒtÄƒrie, in parc (cÃ¢nd mai dÄƒ cÄƒldura), Ã®n kimniÅ£Äƒ, Ã®n facultate, Ã®n lift, Ã®n holul blocului, la birou, Ã®n buda biroului, Ã®n piscinÄƒ, Ã®n maÅŸinÄƒ, pe CetÄƒÅ£uie, ba chiar - dupÄƒ cum am auzit pe la unele cupluri - chiar Ã®n fund!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(15074,978,'Laura','mars1953@web.de','','84.160.108.113','2008-02-05 19:47:19','2008-02-05 17:47:19','mai groparule, uite d-aia te citesc io: din cand in cand ai cate un articol demn de toata lauda, cum e asta. Pe un OM care inca nu si-o omorat constiinta il doare fraiereala asta. Un autor german zicea \"...indiferent de cum arata doamna Justitia nu va scapa niciodata de violatori...\" Dar macar avem o presa sau bloggeri care sa-i arate. \r\n\r\n@julius c.: legile-s facute din pacate, in cea mai mare parte, de juristi, nu de doctori, nici de psihologi sau economisti, asa ca incearca sa vezi umpic peste marginea farfuriei',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(15329,981,'WhiteWolf','contact@white-wolf.ro','http://white-wolf.ro','89.39.83.78','2008-02-07 15:26:32','2008-02-07 13:26:32','@life, lasa sefeurile :)\r\nEu am fost atat de prost inspirat incat, week-endu-ul trecut m-am cazat la un hotel din Sinaia. :D\r\nTare bine mi-ar fi prins decalogul asta, in avans, Gropare :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11 FireShot/0.32','',0,0),(15205,980,'mo','verde_poveste@yahoo.com','','194.126.220.22','2008-02-06 16:31:05','2008-02-06 14:31:05','Gropare, io-nteleg ca iti vine sa stai si sa urli la luna ca tate merg anapoda si asa mai departe, dar la o adica niik nu e de nerezolvat: pune sh tu mana pe o coada de lopata noua si da-i-o Groparitei, ca dara n-o avea inima bolovan si-o sa faceti cimitir bun iara , NU mai juca bani la bursa, ca doar nu esti nici proz si nici plictisit, pana mea de tantalau ce ai fost pe chestia asta, dar sa lasam, gazduieste-ti nasa si fumeaza sh tu un pachet de tigari intr-o sara, ca dara nu s-a face gaura in cer si in rezerva nationala de tabac (daca vrei iti trimit io unu\' prin fax). A, si la lucru in genere te calareste lumea  ca probabil dupa medicalu\' ala arati odihit ca o floricica (cu viroza respiratorie) si numa\' bun de aventuri erotice in cadru office :). Nu te mai miorlai cu banii - s-asa n-ai avea ce face luna asta cu o lopata de bani. Ce drecu\' sa mai cumperi in afara de rezerve strategice de bere inainte de scumpire? Aud? No vezi...',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1)','',0,0),(15078,980,'Nox','','','89.47.100.75','2008-02-05 21:10:05','2008-02-05 19:10:05','Gropare mama...e nasoale rau de tine, domle. Habar n-am cum te simti (si nici nu vreu sa aflu), k mi-s doar un copchil, dar cred ca raspunsul la intrebarea retorica din final ar fi : ANTIDEPRESIVE. :D',0,'1','Opera/9.25 (Windows NT 5.1; U; en)','',0,0),(15321,981,'life','topmariage@yahoo.com','http://www.sex-life.ro','89.35.29.17','2008-02-07 13:52:29','2008-02-07 11:52:29','daca e sa patesti toate chestiile care nu trebuiesc spuse..cam nasoala treaba. cai de la Protectia Consumatorului ar trebui sa isi faca simtita prezenta in secunda 2!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(15215,980,'ramonici','','','89.33.174.82','2008-02-06 17:46:12','2008-02-06 15:46:12','ce ai gropare cu fetele mici? (de inaltzime) :-w',0,'1','Opera/9.10 (Windows NT 5.1; U; en)','',0,0),(15216,977,'Usim','mihaimitan@gmail.com','','87.237.108.33','2008-02-06 17:54:19','2008-02-06 15:54:19','Aferim, PhenoBarbieDoll',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; .NET CLR 2.0.50727)','',0,0),(15368,983,'WhiteWolf','contact@white-wolf.ro','http://white-wolf.ro','89.39.83.43','2008-02-08 00:10:55','2008-02-07 22:10:55','NambÃ£r <b>sics</b> end nambÃ£r <b>eit</b> mi-au provocat un hohot demential. In total 2, amandoua absolut sanatoase si neprotejate :)\r\nDa\' mi-au fugeat potentialele concluzii. Iarta-ma !',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11 FireShot/0.32','',0,0),(15354,983,'julius constantinescu','julius@universitateacraiova.ro','http://www.7plus.ro/?arhiva=05/02/2008&#38;id=1803','84.232.169.13','2008-02-07 21:49:25','2008-02-07 19:49:25','Da, punctu\' 2 e superb, numa\' putin mi-o venit inapoi',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(15466,985,'Andreea','puistrulet2003@yahoo.com','http://n/a','81.196.150.196','2008-02-08 15:01:18','2008-02-08 13:01:18','Hello,\r\n\r\nNota 10* pt imaginatie Groparu\'-le :)\r\n\r\nDar daca erai evreu, erai nu doar mai bogat si mai \"dajtept\" ci si cu pielea mai alba si cu parul (din cap) mai cret (modelul standard).\r\n\r\nSpor',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(15081,980,'cepanamea','icgel@yahoo.com','http://www.cepanamea.ro','89.41.164.74','2008-02-05 21:18:59','2008-02-05 19:18:59','Deschide Gropare mormantuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuu',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(15082,980,'Laura','mars1953@web.de','','84.160.108.113','2008-02-05 21:28:34','2008-02-05 19:28:34','Io is in depline facultati mentale si totusi nu inteleg ce legatura are boala ta cu concediu de odihna?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(15083,980,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2008-02-05 21:38:47','2008-02-05 19:38:47','@ nox: anti-depresive, sau ante-depresive?\r\n\r\n@ Laura: doftoru\' nu mi-o dat concediu medical si pe vineri, 1 februarie, si acuma trebe sa justific ziua lipsa de la firma prin sacrificarea unei zile de concediu de odihna. Simplu.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(15085,980,'BlindGirl','mihaelaoprisan@gmail.com','http://blind-girl.blogspot.com/','86.127.57.112','2008-02-05 21:47:35','2008-02-05 19:47:35','ce-ar fi sa le zici si altora ce mult ii iubesti pe aia de la hvb sau pe altii care te-au suparat acu\', dupa ce te-ai mai descarcat pe blog, poate expui putintel dar argumentat si dai si notele la baieti? Pui un link la tine pentru continuare, cine vrea sa simta \"cu injuraturi cu tat tacamul\". :)  Intri pe http://www.eopinii.ro/? Poate ne ajuti ca altii sa nu pateasca ce-ai patit tu cu hvb sau cu altii..',0,'1','Mozilla/5.0 (Windows NT 5.2; U; en; rv:1.8.0) Gecko/20060728 Firefox/1.5.0 Opera 9.24','',0,0),(15086,980,'BlindGirl','mihaelaoprisan@gmail.com','http://blind-girl.blogspot.com/','86.127.57.112','2008-02-05 21:49:20','2008-02-05 19:49:20','ups... scoateti semnul intrebarii din adresa web, help?',0,'1','Mozilla/5.0 (Windows NT 5.2; U; en; rv:1.8.0) Gecko/20060728 Firefox/1.5.0 Opera 9.24','',0,0),(15087,980,'ics','i_uana@yahoo.com','','86.126.112.82','2008-02-05 21:59:49','2008-02-05 19:59:49','..of cos',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(15435,985,'Andreea MKT','supergirgir@yahoo.com','http://marlahermina.deviantart.com/gallery/','82.77.126.254','2008-02-08 10:01:14','2008-02-08 08:01:14','Groparu said: \"Vand maxim diamante din zone de conflict, care alimenteazÄƒ rÄƒzboaie de gherilÄƒ cu femei violate.\"\r\n\r\nAndreea MKT intreaba cu gura pana la urechi: \"Si UNDE is razboaiele alea??? Ca m-ar interesa...\"',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; InfoPath.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(15089,980,'Andrei Crivat','andrei@andreicrivat.ro','http://www.andreicrivat.ro','89.137.83.141','2008-02-05 22:05:08','2008-02-05 20:05:08','urmeaza niscaiva chefuri, prekine. d\'alea intre prekini, sa ne fie de bine.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(15095,980,'Nox','','','89.47.100.75','2008-02-05 22:43:24','2008-02-05 20:43:24','Ante-depresive?!....hmm...sa inteleg ca depresia \"is yet to come\"? Se poate si mai rau?',0,'1','Opera/9.25 (Windows NT 5.1; U; en)','',0,0),(15098,980,'totolici','fun4toto@yahoo.com','http://totolici.wordpress.com/','89.137.69.31','2008-02-05 22:57:52','2008-02-05 20:57:52','bun deci sarac, bolnav si vai de capu lui. daca mai esti si urat si betiv esti barbatul perfect pentru mine :)) . kiddin\' si un get well soon :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.0.7) Gecko/20060909 Firefox/1.5.0.7','',0,0),(15101,980,'totolici','fun4toto@yahoo.com','http://totolici.wordpress.com/','89.137.69.31','2008-02-05 23:28:16','2008-02-05 21:28:16','grasa hmm... tre sa recunosc k m\'am umflat , shtirba ... masele se pun? isterica cunoshti si tu sindromu premenstrual deci numa odata pe luna , mica de inaltime habar n\'am nu m\'am masurat demult crek is medie :)) ,injur si cand mi se face cinste beau :)). din pacate am un dezavantaj ma spal k na ajungi la un moment dat sa nu te suporti nici tu :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.0.7) Gecko/20060909 Firefox/1.5.0.7','',0,0),(15100,980,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2008-02-05 23:17:44','2008-02-05 21:17:44','Betiv am fo\' mereu, si de urat - tocmai am refuzat o propunere sa apar pe spreiurile anti-gandaci din noua generatie RAID, in postura de carabush de Colorado.\r\n\r\nZi-mi ca esti grasa, stirba, isterica, paroasa pe picioare, mirosi urat, esti mica de inaltime, injuri, bei, fumezi, nu faci dush si nici nu te speli pe dinti, iti miroase pasarica a alge putrezite, and we\'ll call it a match made in heaven.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(15357,983,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','92.82.49.31','2008-02-07 22:00:42','2008-02-07 20:00:42','Ba Julica! \r\n\r\nCica-s 2 tipuri de masculi: aia care dau limbi, si aia care nu recunosc! \r\n\r\nDeci...?',0,'1','Mozilla/5.0 (Macintosh; U; Intel Mac OS X; en-us) AppleWebKit/523.10.3 (KHTML, like Gecko) Version/3.0.4 Safari/523.10','',0,0),(15103,980,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2008-02-05 23:37:10','2008-02-05 21:37:10','Deci de la faza cu spalatu\' mi-am dat seama: ej fitzoasa.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(15104,980,'octavian','octavian.arnaut@gmail.com','http://www.yacana.ro/blog/','81.181.214.232','2008-02-05 23:39:31','2008-02-05 21:39:31','deci ca sa nu mai puta hainele dupa ce le scotz din masina ta, scoate dopu de sub ea si scurge apa cu jeg care sta in spatele lui ( dopului )\r\n\r\nsi sinucide-te odata!',0,'1','Mozilla/5.0 (Macintosh; U; Intel Mac OS X; en) AppleWebKit/523.12.2 (KHTML, like Gecko) Version/3.0.4 Safari/523.12.2','',0,0),(15105,980,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2008-02-05 23:44:01','2008-02-05 21:44:01','Ej nebun? sa viu dupe aia sa te bantui si sa rad de tine can\' te futzi???',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(15106,980,'totolici','fun4toto@yahoo.com','http://totolici.wordpress.com/','89.137.69.31','2008-02-05 23:46:14','2008-02-05 21:46:14','bine bine sunt fitzoasa recunosc imi place sapunul :(( :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.0.7) Gecko/20060909 Firefox/1.5.0.7','',0,0),(15382,983,'ascutita','michi.deli@gmail.com','http://ascutita.wordpress.com/','220.96.122.218','2008-02-08 01:44:24','2008-02-07 23:44:24','auzi,yo acu vazui ca-i de la rutiera...pai mai ajunge si el pe centura,si nefiind obisnuit sa plateasca,dar fiind genul caruia ii plac senzatiile tari,s-a gandit ca o recompenseaza pe o posibila don`soara agatata pe acolo cu o pereche de tangai...prezervativele,normal,sa-l protejese,ca mai are si nevasta si vreo 2 copii...o ramas saracu nesatisfacut... =((',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; SIMBAR={6F0FD749-995D-45FA-868D-69ED48107126}; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(15220,980,'gb','getbordea@yahoo.com','http://getbordea.blogspot.com','208.77.165.40','2008-02-06 18:43:17','2008-02-06 16:43:17','Americanii-s de vina, f*tu-i in gura sa-i f*t!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(15221,980,'Ciprian','ciprian.sorlea@it-exchange.ro','','81.196.150.96','2008-02-06 18:56:42','2008-02-06 16:56:42','Un moment bun sa incepi sa-ti monetizezi blog-ul. Poate mai amortizezi din inflatie ;)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(15383,983,'oedip','oedip74@gmail.com','http://oedip.blogspot.com','89.137.99.163','2008-02-08 01:50:42','2008-02-07 23:50:42','statcounter.com\r\n\r\nasta pt berea de aseara :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(15380,983,'ascutita','michi.deli@gmail.com','http://ascutita.wordpress.com/','220.96.122.218','2008-02-08 01:26:46','2008-02-07 23:26:46','nu,gropare,luase tanga cu imprumut,iar prezervativele le luase ca sa-si acopere \"minunatia\" sa nu ramana mirosul pe frumusetea de bikinei,si sa-i poata returna fara sa mai fie nevoit sa ii si spele...  ;)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; SIMBAR={6F0FD749-995D-45FA-868D-69ED48107126}; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(15342,983,'andys','adi_coaja@yahoo.com','','89.38.155.199','2008-02-07 18:56:02','2008-02-07 16:56:02','Politistul cu pricina nu era la furat cum a crezut toata lumea... el desfasura o complexa actiune sub acoperire... si cum acoperirea cu tanga nu este cea mai buna o fi simtit nevoia sa se protejeze!!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Maxthon; .NET CLR 2.0.50727)','',0,0),(15502,986,'Usim','mihaimitan@gmail.com','','87.237.108.33','2008-02-08 21:01:54','2008-02-08 19:01:54','Adica Boldog uj evet kivanok!/? (iertati evetuale greseli de ortografie)\r\nBuek = LMA',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; .NET CLR 2.0.50727)','',0,0),(14958,978,'julius constantinescu','julius@universitateacraiova.ro','http://www.7plus.ro/?arhiva=05/02/2008&#38;id=1803','84.232.163.34','2008-02-05 00:18:32','2008-02-04 22:18:32','Da\' sa mor daca aveti vreunul carnet sau, daca-l aveti, l-ati mai lua o data, da\' pe bune :D \r\nSub 10 zile de ingrijire medicala nu e penal, iti ia carnetu\' si sanatate. Peste 10 zile, e penal, da\' numa\' daca victima depune plangere. Iar legea ITI DA DREPTU\' (ba, dreptu\', plm, nu stiu daca intelegeti, ca e o notiune complicata de drept) sa te-ntelegi cu victima in termen de 60 de zile. \r\nLua-v-ar la tatzi carnetu\' si sa fiu io in comisie, la examen! Ce pulane in cap v-ati lua... :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(14959,977,'Greuceanu','','','195.149.72.105','2008-02-05 00:25:47','2008-02-04 22:25:47','baza!\r\n\r\nwe\'ve got a problem!',0,'1','Opera/9.25 (Windows NT 5.1; U; en)','',0,0),(14937,978,'','','','89.40.91.137','2008-02-04 21:09:04','2008-02-04 19:09:04','fiindca traim in RB Romania.\r\nLegenda RB= republica bananiera',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1)','',0,0),(15166,980,'Andreea','puistrulet2003@yahoo.com','http://n/a','81.196.150.196','2008-02-06 09:58:10','2008-02-06 07:58:10','No acuma ar trebui sa mergi pe zicala \"La tati ni greu\", nu?\r\n\r\nAdevarul e ca toti trecem intr-o mai mica sau intr-o mai mare masura prin asemenea situatii, care pe moment ni se par hopeless si te astepti la ce e mai rau (cum am fost eu duminica cand am asteptat toata ziua- paranoia din mine- sa ma sune seful din austria si sa-mi spuna ca nu e ok rezervarea de hotel facuta( long story in short), dar eu zic ca vei scapa curand de acest feeling(mai ales daca vei auzi o intamplare mai naspa decat a ta... :) )\r\n\r\nPS: e soare afara...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(14939,927,'ioneque','ioana_g_ro@yahoo.com','http://ioneque.wordpress.com','86.123.155.217','2008-02-04 21:13:13','2008-02-04 19:13:13','si probabil ai uitat de club monalisa care s\'a redeschis ca rambo. sau era invers?!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.11','',0,0),(14940,977,'PhenoBarbieDoll','oana.gavrila@mediafax.ro','http://blog.360.yahoo.com/poisongirl94','86.120.236.133','2008-02-04 21:13:43','2008-02-04 19:13:43','Io vreau s-o termin cu fairy tales.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1)','',0,0),(14941,978,'Razvan Antonescu','razvan.antonescu@gmail.com','http://idei-locale.blogspot.com','79.116.75.34','2008-02-04 21:13:45','2008-02-04 19:13:45','Bre atentie de cin\' te iei ca poa dispari din blogrolul unei anumite familii :D\r\nIo zic ca mai e o intrebare. Cand pana mea s-a hotarat legal si definitiv ca o dat cu prunca de pamant si ce zice bejetii aia cu vena plezninda la tampla ce aparau pa primu\' nevinovat al tarii?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071018 Firefox/2.0.0.8 Flock/1.0RC3 VRE Toolbar 1.42','',0,0),(14942,977,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2008-02-04 21:16:47','2008-02-04 19:16:47','...interpretare freudiana, sper!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(14943,978,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2008-02-04 21:19:43','2008-02-04 19:19:43','@Razvi: Nu-i bai, ca daca ma scoate Ciutacu, ma asterne Zoso in blogroll! :P (Doamneeee, apÄƒrÄƒ ÅŸi pÄƒzeÅŸte...)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(16008,990,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-02-13 17:09:00','2008-02-13 15:09:00','Da, apropos, stii care e sunetul care insoteste caderea unui fir de par pubian?\r\n\r\n\"Ptiu!\"\r\n\r\n(Veche, stiu, da\' nu conteaza, ca io numa ieri am aflat!)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(16010,988,'iulianuss','realvision@k.ro','','193.231.107.209','2008-02-13 17:17:22','2008-02-13 15:17:22','Ce lume ... Ã®n amintirea acelor vremuri am cumpÄƒrat ÅŸi io (singur-singuruc) 6 pahare de apÄƒ ordinare - modelul Äƒla Ã®n care era muÅŸtarul pÄƒ vremea mea - numa bune de lipÄƒit bere operativ. Da m-o pus naiba sÄƒ torn ceai fierbinte Ã®ntr-unul ÅŸi o puÅŸcat - Å£ÄƒndÄƒri,  m-o fript, am calcat Ã®ntr-un ciob pe gresie ÅŸi m-am trezit la realitate om Ã®nsurat fÄƒrÄƒ scÄƒpare...',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; .NET CLR 1.1.4322)','',0,0),(15185,980,'macabroo','raduccc@yahoo.com','http://rezistenta.blogspot.com','82.76.52.94','2008-02-06 13:28:24','2008-02-06 11:28:24','Plm Gropare, fi barbat! Putea fi mai rau: http://www.thelondonpaper.com/cs/Satellite/london/news/article/1157150303147?packedargs=aid%3D1157150303147%26suffix%3DArticleController  \r\nTe simti mai bine acum?!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; en-GB; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(16003,988,'mirra','','','83.103.137.234','2008-02-13 15:55:14','2008-02-13 13:55:14','daca s-au inventat: masina de spalat vase, masina de spalat rufe, cuptorul cu microunde si papusa gonflabila la ce sa-ti mai iei nevasta?!:))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(15494,986,'Lorand R. Minyo','lorand.minyo@simpliq.com','http://www.lorandminyo.ro/','89.36.21.82','2008-02-08 19:13:50','2008-02-08 17:13:50','\"Buek\" mai groparule? Aia e urare de an nou fericit la unguri :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(15181,980,'dush','tirbushon@gmail.com','http://dushrece.blogspot.com','193.230.155.70','2008-02-06 12:45:24','2008-02-06 10:45:24','haide dom\'le..unless raceala aia te-a lasat fara un roi de neuroni...you\'ll get over it...si la mama(mea) s-o inventat raspunsul ala...\"pisi, stii, n-am. cine dracu te-a pus sa iti iei oale??!\"(si io inca stau in casa cu ea...nu la 200km)... in rest..te poate durea in pix..ce depresie...bucurie mai mare...ma poate durea in dos de shefi..de banci de aia  care trimit acasa hartii cu ai de platit...is doar hartii care te indeamna..nu te obliga :D cand am, am..cand n-am scruiuall :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(15829,988,'manole','redtailanda@yahoo.com','http://www.mesterulmanole.wordpress.com','81.181.92.157','2008-02-12 13:20:43','2008-02-12 11:20:43','groparele, de unica folosinta, nu? :)\r\nsi in plus...chiar ti-am dat un sfat si BUN si SINCER!\r\nAdÄƒ fomeia inapoi!!! :)  :)  :)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows 98)','',0,0),(15178,980,'Turambar','mirel@ccsb.ro','http://turambarr.blogspot.com','79.114.190.130','2008-02-06 12:07:19','2008-02-06 10:07:19','We deeply sympathize with your plight. Please receive our most sincere token of...\r\n\r\nSigh. Sniff. Gropareeeee. Nu te duuu!\r\n\r\nAia cu gagica e nasoala. Cea mai nasoala dintre tati. \r\nAia cu bursa e nasoala. Dar trece. Faci altzii.\r\nAia cu nasha e nasoala. Cea mai nasoala dintre tati.\r\nAia cu creditele e a ta shi numai a ta, coane. Cin\' dracu te-a pus sa te inhami la jecmanitorii ashtia, nu shtiu. Acu taci si sufera. Fa bani. Omoara. Produ.\r\nAia cu boala si cu concedu? Shrug. Life is a bitch and then we die. Vezi si tu partea buna a paharului: tzi-o futut doar o zi din concedul al adevarat shi true shi de odihna.\r\nRestul e sudoare. La munca, nu la blogguit!\r\n\r\n=======\r\n<i>Dincolo de vorbe, shtii ca suntem alaturi de tine. Hai ca trece... :) </i>',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(15757,984,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-02-11 17:32:11','2008-02-11 15:32:11','Horatiu, iara te mariti???',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(15140,980,'manole','mesterulmanole07@gmail.com','http://www.mesterulmanole.wordpress.com','89.32.123.108','2008-02-06 07:11:49','2008-02-06 05:11:49','groparele, ai scapat de raceala? ai scapa!\r\nacuma, impaca-te cu gajica si gajica cu tine, primeste rudele de la Cluj si fa pe Omul cu ei, ca nu esti Dumnezeu restul...minore si nesimnificative. :)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; SIMBAR={6027D00E-CD16-11DC-9BA8-001B2FCE5715}; .NET CLR 1.1.4322)','',0,0),(15743,984,'Andreea MKT','supergirgir@yahoo.com','http://marlahermina.deviantart.com/gallery/','82.77.126.254','2008-02-11 15:14:21','2008-02-11 13:14:21','Nu e nici o suparare, dar am facut si eu un banc despre arabii care se roaga pe covorash si pac! peste 10 randuri se povesteste despre bunicutze-bondage si sex. me shocked. aia am zis. dar putem continua cu subiecte decente, de ex cura mea de slabire sau clientul lui josh.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; InfoPath.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(16015,990,'Andreea MKT','supergirgir@yahoo.com','','89.43.186.64','2008-02-13 18:11:16','2008-02-13 16:11:16','Deci eu sunt a 72-a virgina care ii asteapta pe arabi dupa moarte, aia cea mai grasa si cea mai scarpinatoare in fund, come and take me, My salamaleiku warrior!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(15491,986,'oceania','oceania_oceania@yahoo.com','http://www.literelibere.blogspot.com','84.232.161.15','2008-02-08 18:51:54','2008-02-08 16:51:54','am descoperit blogul lui groparu pe blogul lui turambar. de atunci ma distrez copios cand citesc postarile de pe aici.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; InfoPath.1)','',0,0),(15456,985,'mo','verde_poveste@yahoo.com','','194.126.220.22','2008-02-08 13:22:18','2008-02-08 11:22:18','Io evrei in familie n-am (cel putin nu stiu sigur), nici bancuri noi cu evrei nu-mi amintesc, dar vreau musai sa iti zic de un film oarecum la subiect in caz ca nu l-ai vazut: \"Everything is illuminated\".\r\nOk, povestea e cam cheesyda\' conversatiile in engleza ucrainiana sunt geniale :-)\r\nIo de cand am vaz\'t filmu\' ala citez replici cum casc gura. La dracu\'!\r\nhttp://www.imdb.com/title/tt0404030/quotes',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1)','',0,0),(14927,977,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2008-02-04 19:38:04','2008-02-04 17:38:04','The Ballad of Reading Gaol, always!\r\n\r\nIo asa am termenat-o p-a mea fuckulta.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(15162,979,'Hammer','hammer@alpinet.org','http://www.alpontos.wordpress.com','86.120.55.79','2008-02-06 09:40:41','2008-02-06 07:40:41','si pe wiki ce zicea de davai ceas, davai palton?\r\nsi peste 50 de ani desecretizarea va fi declarata neconstitutionala pentru a 24-a oara',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(14835,623,'Turambar','mirel@ccsb.ro','http://turambarr.blogspot.com','79.114.190.130','2008-02-03 22:51:56','2008-02-03 20:51:56','Great kids. Awful uncle. Noroc cu pufuletzii, ca mai salveaza din situatie.\r\n\r\nMo... :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(15827,988,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-02-12 12:31:49','2008-02-12 10:31:49','Chiar dublu apostolica, as zice! :D Jumate mai adÃ¢nc apostolicÄƒ decÃ¢t cealaltÄƒ.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(14966,977,'baghy','baghy83@lycos.it','http://www.baghy.info','78.12.1.110','2008-02-05 01:23:39','2008-02-04 23:23:39','cand scrii cartea?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(15428,985,'Andreea MKT','supergirgir@yahoo.com','http://marlahermina.deviantart.com/gallery/','82.77.126.254','2008-02-08 09:30:15','2008-02-08 07:30:15','am observat ca pe la 17-18 ani, toate prietenele mele cu \"dark issues\" imi ziceau ca or avut ceva neam evreiesc prin famlie si ca is evreice si ele, ergo. cu atat mai mult ca Jews are the only ppl who hate themselves. Io amu as zice ca americanii hate themselves si cum varu-meu Remus e la New York manager de restorant si cum pe barbatu-meu il keama yankee, cred ca sunt o americanca cu accent de sud care iti cumpara tie diamantele false, evreule.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; InfoPath.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(15429,985,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-02-08 09:35:17','2008-02-08 07:35:17','Io nu vand diamante calpe.\r\n\r\nVand maxim diamante din zone de conflict, care alimenteazÄƒ rÄƒzboaie de gherilÄƒ cu femei violate.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(14843,976,'Kissu','','','79.116.71.132','2008-02-04 00:24:56','2008-02-03 22:24:56','@Andreea MKT: Gro, deci cu ce gagica ma sarut luni de la firma?\r\n\r\nCu Carmen!?... ;))))))',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1)','',0,0),(14922,977,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2008-02-04 18:46:01','2008-02-04 16:46:01','@ mirra: Doamne, mirra, ui, tu fata, ce-o ajuns de tine, sa-ti placa cum scriu IO! parintii tai stie???\r\n\r\n@ Andreea: da, finca stim ca nu are nici un rost sa o cautam pe urmatoarea prin asternute!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(15967,990,'Mihai','mhangansv@yahoo.com','','81.196.150.96','2008-02-13 10:55:50','2008-02-13 08:55:50','Mda, nebanuite sunt caile cearshafului. :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(15981,990,'Andreea','puistrulet2003@yahoo.com','http://n/a','81.196.150.196','2008-02-13 13:04:48','2008-02-13 11:04:48','De ce nu mergeti pe calitate?\r\nIn loc de 270 sau 300 viitoare-foste neveste, mai bine 10-15 exemplare de o rara frumusete??',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(14924,977,'PhenoBarbieDoll','oana.gavrila@mediafax.ro','http://blog.360.yahoo.com/poisongirl94','86.120.236.133','2008-02-04 19:24:54','2008-02-04 17:24:54','Oscar place muuuult, numa\' ca io din cauza lui inca n-am terminat facultatea (care era due amu\' un an jumate) finca m-am gandit io sa-mi scriu lucrarea de diploma pe baza de dumnealui sh nu m-am putut limita la o singura chestie care sa mai fie si coerenta.\r\n\r\nPS: hugs @Batman',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1)','',0,0),(15167,980,'Hammer','hammer@alpinet.org','http://www.alpontos.wordpress.com','86.120.55.79','2008-02-06 10:01:47','2008-02-06 08:01:47','mah, itz dau o replica o tzar\' dadaista : http://www.cinearenorocare.ro/',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(14946,977,'PhenoBarbieDoll','oana.gavrila@mediafax.ro','http://blog.360.yahoo.com/poisongirl94','86.120.236.133','2008-02-04 21:28:35','2008-02-04 19:28:35','printre altele',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1)','',0,0),(14947,978,'Ne-am luat o piatra de pe inima at Gramo`s World','','http://gramo.ro/2008/02/04/ne-am-luat-o-piatra-de-pe-inima/','69.93.255.82','2008-02-04 21:35:49','2008-02-04 19:35:49','[...] A scris si Groparu aici.     Posturi vag inrudite:Gramo in Bucegi - the final cutSeara la Piatra ArsaVa place Harms? [...]',0,'1','Incutio XML-RPC -- WordPress/2.3.1','pingback',0,0),(16013,990,'Andreea','puistrulet2003@yahoo.com','http://n/a','81.196.150.196','2008-02-13 17:35:45','2008-02-13 15:35:45','Un singur sfat: epilareeeeeeee......(daca te tine ;) )',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(15161,978,'Hammer','hammer@alpinet.org','http://www.alpontos.wordpress.com','86.120.55.79','2008-02-06 09:38:09','2008-02-06 07:38:09','Singura chestie e ca el o asteptat saracu in ninsoare si n-a venit nimeni...iar in cazul nostru, nu mai apucai sa intri in statusul de asteptare...ca baietii erau deja calare pe situatie:-D',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(14913,977,'Andreea','puistrulet2003@yahoo.com','http://n/a','81.196.150.196','2008-02-04 16:51:35','2008-02-04 14:51:35','Puteam, dar ti-am cerut de-a stangu\' :) (mi s-a parut mai politicos... )\r\n\r\nDamn it...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(14950,977,'PhenoBarbieDoll','oana.gavrila@mediafax.ro','http://blog.360.yahoo.com/poisongirl94','86.120.236.133','2008-02-04 21:42:00','2008-02-04 19:42:00','hmmm, atunci putem incerca a new historicist approach, iar pe psihanalistii elvetieni ii trimitem la solar.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1)','',0,0),(14903,973,'top','topmariage2yahoo.com','http://www.topmariage.ro','89.35.29.17','2008-02-04 13:41:10','2008-02-04 11:41:10','acuma cica se lasa de droguri. s-a internat intr-o clinica. dar tot dependenta va ramane. pacat.,..',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 2.0.50727)','',0,0),(14904,977,'cronicaru\'','tzone_a@yahoo.com','http://cronicaru.blogspot.com/','193.230.230.101','2008-02-04 13:45:05','2008-02-04 11:45:05',':)) ba, nu esti normal. io cred ca esti un pic lesbian ca prea ravnesti la femeia alteia.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(14928,977,'darius f','darius2u@yahoo.com','http://desprepsd.wordpress.com/','82.79.52.137','2008-02-04 19:59:05','2008-02-04 17:59:05','Mosule desi e 8 seara si io, functionar public ce sunt, sunt inca la servici ai reusit sa-mi mai descretesti fruntea cu postarea asta. Daca vii la Satu Mare sa-mi amintesti sa dau un bax de bere.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(14918,977,'mirra','','','83.103.137.234','2008-02-04 17:44:12','2008-02-04 15:44:12','bine ca te-ai insanatosit ca ma apuca disperarea,ca nu mai avea gust cafeaua fara scrierile tale!Sa fi sanatos si sa nu se mai apropie virusii de tine!:)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(14944,977,'PhenoBarbieDoll','oana.gavrila@mediafax.ro','http://blog.360.yahoo.com/poisongirl94','86.120.236.133','2008-02-04 21:23:05','2008-02-04 19:23:05','Jungiana mai degraba ;)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1)','',0,0),(14945,977,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2008-02-04 21:26:43','2008-02-04 19:26:43','Deci e despre futut?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(14920,977,'Andreea MKT','supergirgir@yahoo.com','','82.77.126.254','2008-02-04 17:53:44','2008-02-04 15:53:44','Gropare, di ce tre sa ne luam talpashita un doi cum ne-ati f@?\r\n\r\nSi asa voi va scarpinatz in fund, va mirositi chilotzii si va intoarcetz pe partea ailalta cu sau fara noi.\r\n\r\nPhenobarbierdoll: love you. Batman.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1; .NET CLR 1.1.4322)','',0,0),(14916,977,'mirra','','','83.103.137.234','2008-02-04 17:41:41','2008-02-04 15:41:41','deci sa inteleg ca io pot sa vin  chiar daca n-am bere????:)))))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(14910,977,'IepurasulAtomic','praetorian21uk@yahoo.com','','192.100.130.7','2008-02-04 16:19:25','2008-02-04 14:19:25','Eu propun ca toti cei care avem probleme la servici si-n societate, sau ne pierdem slujbele, pentru ca recitam din Groparu\' sau ne aliem comportamentului sau total neadecvat pentru aceasta era, deci toti astia, care este, sa ne mutam la Groparu\' si sa lipitorim pe spatele lui. Nu vom lucra si nu vom aduce nici un fel de profit in casa decat atunci cand domnu\' Groparu\' se imbolnaveste mai mult sau mai putin mortal. Mai semneaza cineva petitia asta? Pana una alta Gropare, zi, eu unde dorm? Fa-mi culcush ca diseara ma prezint la tine. De care bere sa aduc....Pace p\'afara!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(14911,977,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-02-04 16:33:56','2008-02-04 14:33:56','@ Katmai: true det!\r\n\r\n@ Barbie: sh tie te gustas OscarilÄƒ? CÄƒ am terminat facultatea ÅŸi ÅŸi masteru\' pe baza a ceea ce o scris irlanghiezu\'!\r\n\r\n@ cronicaru: io nuz normal? :O:O:O\r\n\r\n@ Andreea: daca iti trebuia bani imprumut, puteai sa imi sa ceri de-a dreptu\'.\r\n\r\nSerios.\r\n\r\n@ Iepurila: mo, deci io nu pricep cum de nu pricepeti! La mine acasa masculii nu sunt bineveniti nici macar daca aduc numa bere si o lasa acolo. Decat daca aduc femei si bere si le lasa acolo. Atunci da, mai negocem!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(14909,977,'Andreea','puistrulet2003@yahoo.com','http://n/a','81.196.150.196','2008-02-04 15:27:51','2008-02-04 13:27:51','Buna,\r\n\r\nSuper postarea/rile... \r\n\r\nMersi mult :)...pentru pauzele de ras (am ras cu lacrimi la postarea cu mascota bucurestiului :)))...si eram la lucru :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(14949,977,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2008-02-04 21:39:56','2008-02-04 19:39:56','Hmmm! Grija mare la psihanalistii elvetieni: astia au picioare slabanoage prevazute cu o piele albÄƒ de iti face greaÅ£Äƒ, ÅŸi pe lÃ¢ngÄƒ asta nici nu-ÅŸi dau jos ciorapii cand... ÅŸtii tu!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(14784,623,'O poveste cu un Media Galaxy at Jurnal de noapte','','http://www.andreicrivat.ro/2008/02/03/o-poveste-cu-un-media-galaxy/','212.227.64.193','2008-02-03 11:16:38','2008-02-03 09:16:38','[...] perfect. ÃŽncepem, firesc, c-o pauzÄƒ de cafea la care ne-am Ã®ntÃ¢lnit cu Groparianu&#8216; È™i cu Greuceanu (sÄƒracii, ÄƒÈ™tia doi taaaaare mai aveau nevoie de cafea Ã®n dimineaÈ›a aia, of of), dupÄƒ care [...]',0,'1','Incutio XML-RPC -- WordPress/2.2','pingback',0,0),(14897,977,'katmai','katmai@keptprivate.com','http://www.512kbps.com','195.212.29.163','2008-02-04 12:31:54','2008-02-04 10:31:54','groparu loose. somebody stop him.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3','',0,0),(14898,977,'PhenoBarbieDoll','oana.gavrila@mediafax.ro','http://blog.360.yahoo.com/poisongirl94','86.120.236.133','2008-02-04 12:40:23','2008-02-04 10:40:23','Correction: deci aia cu barbatul poate fi fericit cu orice femeie, atata timp cat n-o iubeste e Oscar Wilde din The Picture of Dorian Gray. Tulai, no, ce desteapta si culta mi-s!',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1)','',0,0),(16238,989,'Andreea','puistrulet2003@yahoo.com','http://n/a','81.196.150.196','2008-02-15 09:05:23','2008-02-15 07:05:23','@Groparu - Anonymous am fost io ca am scris de acasa....:)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(16241,989,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-02-15 09:28:04','2008-02-15 07:28:04','Oricum, wezpectu\' meu se mentine chiar daca, uite, duci o viatza dubla, de Andree si si de anonima! (io stiu te imbraci prin haine feminine si te apuci sa omori prostituate noaptea pe bulevardurile rau famate!)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(16790,1009,'alienatu','eu@alienatu.com','','92.83.189.199','2008-02-23 10:30:05','2008-02-23 08:30:05','Esti genial maestre!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(16258,991,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-02-15 12:21:35','2008-02-15 10:21:35','(sunt gretzos, stiu)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(17001,1011,'ametzitul','','http://ametzitul.wordpress.com','62.217.236.12','2008-02-25 09:04:47','2008-02-25 07:04:47','hehe... lunea...\r\n\"intr-o zi o s-o iau razna shi-o sa va omor pe totzi... in ordine alfabetica\"\r\nun citat din marele Al Bundy :)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(17004,1011,'Catzaua','ana.man.fox@gmail.com','','81.180.173.61','2008-02-25 09:28:43','2008-02-25 07:28:43','grrrr... lunea, cand te trezeste un client cretin care isi incepe activitatea la ora 6 si nu ii trasneste prin cap ca tu incepi la 9 si te intreaba ceva ineptie despre care tu nici macar nu ai habar si iti vine sa-l injuri si nu poti, ca doara e client si trebuie sa faci frumos la telefon si sa-i explici jitei ca numai la 9 ajungi la job si ca sa-ti trimita un fax sa-ti explice ce anume pruna ma-sii ii trebuie cu noaptea in cap si n-o putut astepta 3 ore sa faci ochi, sa-ti bei cafeaua si sa te simti cat de cat ca un om normal intr-o luni dimineata cand nici iarba nu creste si iti vine sa dai cu cutzatu\'n ptiatra sa meri \'napoi sa te culci vreo 3 saptamani intr-una si sa nu te sexeze la melodie nici o bovina.\r\n\r\nthere, i said it. i feel better now :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(16893,1009,'cepanamea','icgel@yahoo.com','http://www.cepanamea.ro','92.80.7.234','2008-02-24 12:57:21','2008-02-24 10:57:21','Iertati-ma, despre ce era vorba? Doar despre neste bonuri de masa? Wow...m-ati dat pe spate cu subiectu\' asta..',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(16260,991,'Basty','basty@canvas.ro','http://basty.wordpress.com','82.77.126.21','2008-02-15 12:33:19','2008-02-15 10:33:19','Da\' cica e buna, plina de vitamine si minerale. 100% DZR',0,'1','Mozilla/5.0 (Macintosh; U; Intel Mac OS X; en) AppleWebKit/523.12.2 (KHTML, like Gecko) Version/3.0.4 Safari/523.12.2','',0,0),(16261,991,'irina','irinamimoza@yahoo.com','','86.121.21.108','2008-02-15 12:33:36','2008-02-15 10:33:36','daca vrei sa ne arati ceva pron cu tine nu tre sa astepti sa se faca extensia co.gro\'. poti fara probleme sa pui aicea, pe saitu tau, minunatie de filmulet si cred ca nimeni n-o sa se supere ca n-are domeniu dedicat.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(17063,1011,'zgura','','','79.116.97.227','2008-02-25 22:37:57','2008-02-25 20:37:57','Gropare te rog io sa zici de reclama cu Raifaisan:\r\n\"E timpul sa CERSITU un credit\"\r\nMama lor',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(16266,991,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-02-15 12:54:35','2008-02-15 10:54:35','Lol, ar fi o idee, sa-mi fac si io televiziune ca Arhi, da\' pe XXXe cu mine! Tre\' sa ma apuc sa fac un casting.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(16270,991,'Andreea','puistrulet2003@yahoo.com','http://n/a','81.196.150.196','2008-02-15 14:31:33','2008-02-15 12:31:33','DELETAT??????????\r\n\r\nSuna foarte mult cu \"DELECTAT\".... miam miam....\r\n\r\nPS: cata disperare in mesaj...i almost pissed my pants (aaargh!)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(17054,1011,'Andreea MKT','supergirgir@yahoo.com','','89.43.186.64','2008-02-25 20:12:27','2008-02-25 18:12:27','hropare, cine-i Catzaua? Mi se pare mijto nickul ei.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(16277,991,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-02-15 15:36:52','2008-02-15 13:36:52','\"I almost pissed my pants... luckily, my boss already did that!\"\r\n\r\n:|',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(17140,1013,'brasoveanca','dora.bacanu@yahoo.com','','86.122.94.196','2008-02-26 12:35:44','2008-02-26 10:35:44','dar parca primisei o leapsa careia trebuia sa i te conformezi si sa postezi poze cu tine cand erai mic... ne privezi de asa ceva?!?:(',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1)','',0,0),(16281,991,'Andreea MKT','supergirgir@yahoo.com','http://marlahermina.deviantart.com/gallery/','82.77.126.254','2008-02-15 16:21:51','2008-02-15 14:21:51','Doamne, tu si partzoaga, berbeci suntetz!',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; InfoPath.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(16283,991,'Andreea','puistrulet2003@yahoo.com','http://n/a','81.196.150.196','2008-02-15 16:45:17','2008-02-15 14:45:17','@Groparu: ???',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(17037,1011,'MaTr3o','matr3o@gmail.com','http://matr3o.com','86.126.92.113','2008-02-25 16:34:30','2008-02-25 14:34:30','da, si mie imi plac iepurasii....\r\n\r\n\r\nhttp://cgi.ebay.com/Light-AK47-Gun-For-Nintendo-Wii-Remote-Nunchuk_W0QQitemZ110226922772QQihZ001QQcategoryZ147176QQssPageNameZWDVWQQrdZ1QQcmdZViewItem\r\n\r\npuschi puschi bang bang',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(16290,991,'Usim','mihaimitan@gmail.com','','87.237.108.33','2008-02-15 18:39:28','2008-02-15 16:39:28','\"Placenta cu varza\"?????  LLLLLLLLLLLLLOOOOOOOOLLLLLLLLLLLLLL\r\n\r\nAm spus si o mai zic si ma mai minunez: Mare ti-e gradina Doamne, dar ce-i bese Groparelui mintea depasete si realitate si imaginatie si combinatia lor impletita-n opt!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; .NET CLR 2.0.50727)','',0,0),(16291,991,'Usim','mihaimitan@gmail.com','','87.237.108.33','2008-02-15 18:40:50','2008-02-15 16:40:50','Oare varza a la Cluj o fost inventata de vreun stramos al Groparului? La ce s-o fi gandit in momemtul ala?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; .NET CLR 2.0.50727)','',0,0),(17000,1011,'Andreea','puistrulet2003@yahoo.com','http://n/a','81.196.150.196','2008-02-25 08:59:49','2008-02-25 06:59:49',':)))))) super tare, dar io zic ca trebuia sa faci urmatoriul scenariu ca sa bagi cu adevarat spaima in sef : sa te apropii de el, tintuindu-l mereu cu o privire din aia senina (aka the crazy look) si sa ii spui tot speech-ul ala la vreo 1.5 cm de moaca lui... atunci sa vezi fete :))))\r\n\r\nSpor,\r\nAndreea',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(16941,1009,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','92.82.51.243','2008-02-24 21:27:58','2008-02-24 19:27:58','OK... faptul ca nemtii NU le folosesc nu e argument suficient de viabil?\r\n:D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(16299,991,'ania','ania@wip.ro','http://aniakhaki.blogspot.com','92.82.48.159','2008-02-15 19:56:39','2008-02-15 17:56:39','numa sa nu iti stearga contu de iahu ca acu ai pus pe blog si o aflat prea multa lume =))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(16970,992,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','92.81.153.148','2008-02-25 02:32:33','2008-02-25 00:32:33','Cozmose.\r\n\r\nSa-mi fut una.\r\n\r\nEsti demential.\r\n\r\nJUR!!!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(16664,1001,'dan','dan.radu1965@yahoo.com','','79.112.1.81','2008-02-20 11:51:30','2008-02-20 09:51:30','bai moshule, ejti nemaipomenit...duminica am citit vreo cinci ore blogul tau, ca abia atunci am dat de el din gresala. m-am cracanat de ris si cracanat am ramas. am sunat si citva preteni sa le zic sa se benocleze la ce zmingileste matele acilea. creca ar trebui sa te gindesti sa faci si niste bani cu scriitura si umorul tau, ca tot tragi multe rate dupa tine.\r\napropo de tiganiada: am vreo 7 pretini cu care fac, de vreo zece ani, ceva asemanator, da noi ii zicem \"dacie\" - de la dacii liberi, carevasazica. si exista doua dacii - una de primavara si una de toamna. si fiecare dureaza 3 zile si nu stie nevestele si pretinele unde mergem, ca-i sicret. si locul se schimba in fiecare an - oricum e la munte, prin bucovina, noi sintem ieseni. si aceste dacii au si \"micile jocuri atletice dacice\", care dupa cum le spune si numele sint mici, ca nu tre sa te ridici din cur ca sa le joci si nici sa lasi bericioaica din  mina - aruncarea cutitului, skanderbeg si, un vechi joc dacic, dus de legiunile romane tocma in britania - darts. asa ca nu cred c-ar fi rau sa facem o tiganiada-dacica impreuna, da tre sa ne intlinim la mijloc, adicatelea pe valea birgaului, pe undeva. hai noroc si bine ca egzisti.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(16663,1001,'IepurasulAtomic','praetorian21uk@yahoo.com','','192.100.130.7','2008-02-20 11:26:18','2008-02-20 09:26:18','Bah, hai sa va fac un mic update din interior. Compania se cheama Saudi Telecom si apartine intr-adevar printului arabiei(evident, daca intr-adevar vorbim despre compania asta, poate printul are mai multe :)). Si pen\' ca sunt intim cu reteaua arabilor, da\' nu in sensu\' ala veneric, va pot spune ca e najpa. E execrabila, dezastruoasa, oripilanta, oribila...si alte asemenea adjective. Gropare, preia cuvantu\' ca la astea te pricepi mai bine ca mine. \r\n\r\nIn alta ordine de idei, nush unde PLM au astia servere placate cu aur si diamante. Stiu colegi care au fost in marele lor centru de date din Riyadh (ca asha ii zice: data center) si n-o vazut asha ceva. Alea le-or fi luat fix pentru uzul personal al printului.\r\n\r\nCam atat, pentru moment. Pace p\'afara!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(17030,1011,'IepurasulAtomic','praetorian21uk@yahoo.com','','192.100.130.7','2008-02-25 15:23:52','2008-02-25 13:23:52','Vand AK47 la pret avantajos. Gloantele menite sefilor, colegilor sacaitori si prietenilor bagaciosi sunt gratis. Estimez ca nu tre\' sa cumperi decat arma...',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(17032,1011,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-02-25 15:41:08','2008-02-25 13:41:08','Arma o am, stai un pic sa verific... da, ii exact acolo unde-o lasasem, pitita prin chiloti.\r\n\r\nE un pic somnolenta acum.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(16659,1001,'Buciuman','aaa@ggg.com','http://rezistenta.blogspot.com/','86.121.53.95','2008-02-20 10:28:23','2008-02-20 08:28:23','@Dani Mocanu - Cum ii zice la telefonu ala :D ?',0,'1','Opera/9.25 (Windows NT 5.1; U; en)','',0,0),(15812,988,'Basty','basty@canvas.ro','http://basty.wordpress.com','82.77.126.21','2008-02-12 09:31:41','2008-02-12 07:31:41','Hai no ! Serios ? La naiba ! Credeam ca doar putzulica mea face asa ! *\r\n\r\n*Fapt nedocumentat stiintific fiindca nemernicii aia de la Discovery cica e \"prea ocupati\" :|',0,'1','Mozilla/5.0 (Macintosh; U; Intel Mac OS X; en) AppleWebKit/523.12.2 (KHTML, like Gecko) Version/3.0.4 Safari/523.12.2','',0,0),(15783,984,'Turambar','mirel@ccsb.ro','http://turambarr.blogspot.com','79.114.190.130','2008-02-11 23:32:21','2008-02-11 21:32:21','Cum ar zice olteanu din Sighetu Marmatziei: ah, ce ne-om futat shi azi, tulai tu Doamne... :)\r\n\r\nAlta zi, therefore alt act secsual ratat. Inapoi la viatza de zi cu noapte. Nevasta, unde mi-eshti, tulai tu domnitza tu, vina tu sa-tzi povestesc asemanarile shi deosebirili dintri virtual shi realitate, tu striparitza domestica, tu... Jos tzoalele, sus panzele! Copii, stingetzi lumina. We really mean business now.\r\n\r\n:p  :p  :p',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(15762,984,'Turambar','mirel@ccsb.ro','http://turambarr.blogspot.com','82.76.108.17','2008-02-11 18:54:49','2008-02-11 16:54:49','Gropare, m-ai intzeles greshit: eu nu sunt opsedat de sex. Doar imi place. Asta-i tot. The rest is grannies and scissors.\r\n\r\n:lol:',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(15874,988,'Muc','','http://mucgustos.blogspot.com/','92.81.138.155','2008-02-12 19:58:38','2008-02-12 17:58:38','Manca mah cu dejtele dak tot ejti asa burlac :p',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(15765,984,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2008-02-11 19:54:19','2008-02-11 17:54:19','...and handcuffs, I hope!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(15768,984,'Andreea MKT','supergirgir@yahoo.com','','89.43.186.64','2008-02-11 20:52:40','2008-02-11 18:52:40','Deci mah opsedatzilor:\r\n\r\ngagicu meu e campion la counterstrike si va baga mortu in casa mah, daca mai scrietzi prostii. Ai prajtia mea, mah! \r\n\r\nAm doua comentarii despre 2 persoane:\r\n\r\nDeci Turambar pe care il proslavesc pt. pasiunile cultivate la el pe site, de ex cateva chestii culturale, filme noir si sani in borcan, e un opsedat sexual mai ceva ca groparu. De ce? Fiinca se leaga de mine desi Groparu i-a zis ca am gagic care btw e campion la counterstrike si diploma de cs o contat cand s-o angajat, asa o zis aia de la Resurse Umane.\r\n\r\nApoi Pheno barbie Doll, cunostinta veche de a mea, e cea care m-a vazut beata ca pushca la Sighisoara 2004 in timp ce ii aratam ceva pe cer despre Batman. Apoi am mers s-am beut intr-un bar din Bucuresti numit Silentio unde un dijei o pus A perfect Circle si noi am povestit despre baietzii cu sex dubios si gene intoarse. Mi-e dor de Pheno barnie Doll si povestim ziua pe Mess despre cum vrem sa ne maritam si nu avem cereri.\r\n\r\nRipaHoratiu, just wanted to say kiss and hi.\r\n\r\nGroparu, vad ca iti fac trafic prea mare. Ma intorc la 360 yahoo unde scriu bloguri de copii, nu asa de inteligente, dar mult mai serioase:)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(15822,984,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-02-12 11:45:25','2008-02-12 09:45:25','Pai,... daca dixit, apai dixit!!!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(15819,988,'PhenoBarbieDoll','poisongirl94@yahoo.com','http://blog.360.yahoo.com/poisongirl94','193.230.230.101','2008-02-12 11:10:23','2008-02-12 09:10:23','deci io mai am farfurii de plastic de la revelion, pentru urgente :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(15820,988,'Kissu','','','82.77.126.254','2008-02-12 11:17:48','2008-02-12 09:17:48','@ Andreea MKT \"Unele vor sa se marite ca sa fie sigure ca o sa tzina animalul langa ele si pe mai incolo. Si daca o sa aiba copil, sa se asigure ca animalul tot acolo va fi.\"\r\n\r\nDraga Andreea... vezi tu?... De-aia s-a inventat divortzul! ;;) Dragoste cu sila nu se poate. Iti spun eu din propria-mi experienta. :p',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; InfoPath.1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648)','',0,0),(15821,984,'Altar','stefan_grebla@yahoo.com','http://showyourfist.blogspot.com','86.123.139.103','2008-02-12 11:42:06','2008-02-12 09:42:06','Ai de cucu` meu, mah Gropare, da` numa` oameni unu` si unu` ai pe aici. Si chiar si femei!\r\nDe-acu` tre` sa recunosc si io ca te citesc zilnic si plang mai ceva ca la Titanic atunci cand nu scrii o zi, si vreau (si merit, ca-s bautor fruntas si io) sa particip onorific la Tiganiada (desi sunt cam blond) si musai cand mai trec prin Cluj, te ispitesc cu o naveta de bere (sau Stalinkaya).\r\nDixit!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(15772,984,'Basty','basty@canvas.ro','http://basty.wordpress.com','86.106.51.128','2008-02-11 21:27:23','2008-02-11 19:27:23','Hm. Za link to the legeneral is not si anume working. Which is rather sad, for I was curious like a little monkey.',0,'1','Mozilla/5.0 (Macintosh; U; Intel Mac OS X; en) AppleWebKit/523.12.2 (KHTML, like Gecko) Version/3.0.4 Safari/523.12.2','',0,0),(15786,988,'julius constantinescu','julius@universitateacraiova.ro','http://www.7plus.ro/?arhiva=12/02/2008&#38;id=2088','84.232.162.164','2008-02-11 23:47:00','2008-02-11 21:47:00','Gropare, esti inca in faza romantica a burlaciei - pentru ca iubesti libertatea, pana si gandacii de bucatarie iti par niste animalute simpatice, cu care te-ai juca toata ziua. Da\' cand o sa devii un burlac profesionist (d-asta care o scapat de cel putin 3 nunti care pareau inevitabile), o sa incepi sa pacalesti femei sa vina la tine sa-ti mai faca o mancare si ceva curat, sub pretextul ieftin ca vrei sa faci sex cu ele. Asculta si tu de oameni mai in varsta, ca nu-s gretos din ala care-ti vrea binele.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(15824,988,'Sfaturi (fara acordeoane impuse) catra marele cneaz de Hermannstadt','lucasfolk@gmail.com','','81.181.42.248','2008-02-12 12:15:56','2008-02-12 10:15:56','apostolicÄƒ ... 12 plate....12 adÃ¢nci',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.12) Gecko/20080201 Dealio Toolbar 3.1 Firefox/2.0.0.12','',0,0),(15789,988,'Victor','vick_redhound@yahoo.com','','89.43.11.130','2008-02-12 00:03:36','2008-02-11 22:03:36','Cata dreptate ai omule, cata dreptate ai!',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; .NET CLR 1.1.4322)','',0,0),(15790,988,'ascutita','michi.deli@gmail.com','http://ascutita.wordpress.com/','220.96.122.218','2008-02-12 00:33:57','2008-02-11 22:33:57','ai uitat sa precizezi si ca:\r\n- salariul obtinut dupa atata truda iti ramane in totalitate tie,spre deosebire de cei casatoriti ale caror neveste impart banii si in stanga si in preapta,de voie,de nevoie,util sau inutil;\r\n- nu mai esti obligat sa memorezi anumita date \"importante\" ce va leaga,la care inevitabil ar fi trebuit sa-i aduci \"o mica atentie\";\r\n- nu esti obligat sa megi la cumparaturi si sa te ingramadesti plin de sacose,cutii sau carucioare prin multimea vesnic agitata si nemultumita;\r\n-nu are cine sa-ti ceara parerea la \"cum sa ma imbrac azi?\"...\"iim sta bine asa?\"...\"crezi ca mai bine o cumpar pe aia albastra?\"\r\n-nu are importanta cate super/hypermarket-uri s-au mai deschis;....\r\nsi toate aspectele pot continua.eu m-am referit in special la partea financiara pentru ca de obicei,printre altele,asta ce ceea ce le intereseaza pe fete.oare ma insel?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; SIMBAR={6F0FD749-995D-45FA-868D-69ED48107126}; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(15791,988,'baghy','baghy83@lycos.it','http://www.baghy.info','78.12.16.50','2008-02-12 00:47:06','2008-02-11 22:47:06','sper ca le-ai spalat pe astea noi',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(15817,988,'10MBC','alin.banc@gmail.com','','217.156.21.3','2008-02-12 10:53:17','2008-02-12 08:53:17','hmm... ma consider 100% burlac',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(15793,959,'nu pot sa cred&#8230; &laquo; Ascutita&#8217;s Weblog','','http://ascutita.wordpress.com/2008/02/12/nu-pot-sa-cred/','66.135.48.187','2008-02-12 02:14:31','2008-02-12 00:14:31','[...] de ras cand citeam cum se lupta ea cu &#8220;monstrul&#8221;, dar observai intre timp ca nici groparelnu e mai prejos, sa inteleg ca mi-a venit [...]',0,'1','Incutio XML-RPC -- WordPress/MU','pingback',0,0),(15785,988,'Turambar','mirel@ccsb.ro','http://turambarr.blogspot.com','79.114.190.130','2008-02-11 23:42:37','2008-02-11 21:42:37','Aha! Gata. Acum intzeleg obsesiile tale localizate in zona medial ventrala a existentzei. \r\n\r\nInsa aici intervine intrebarea incuietoare: bine bine, tu intzeleg de ce eshti opsedat secsual, din lipsa prezentzei absentzei. Insa eu, Doamne, eu cu ce am greshit? Eu de ce mi-s opsedat?\r\n\r\n// <i>aici Turambar se ghemuieshte artistic pe burta si adopta postura de Homer Simpson care se zvarcoleshte pe jos in cerculetze estetice, ca gandacelu, batand cu pumnii in ecranu calculatorului. cine n-a vazut episodu, nu shtie ce-a pierdut :p</i> //',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(15776,984,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2008-02-11 22:33:47','2008-02-11 20:33:47','Anume I gave the link pen\' ca nu merge bicoz in toata firma aia de softisti nimeni nu stie sa suie pe fetepeu un sait! :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(15831,988,'dush','tirbushon@gmail.com','http://dushrece.blogspot.com','193.230.155.70','2008-02-12 13:24:57','2008-02-12 11:24:57','dom\'le..\r\nca sa scapi de spinoasa problema a vaselor..s-o inventat masina de spalat vase...le face luna si nu tre sa dai bani pe farfurii la 2 luni, tre doar sa catadicsesti sa deschizi usa bagi farfuria astepti sa se stranga si gata - desi e mai secsi asa..sa le omori pe alea vechi si sa le inlocuiesti..zici ca a picat chiuveta odata cu ele si party grecesc tata pentru vecini ;))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(15832,988,'Bogdan','aloneman_ct@yahoo.com','','194.102.139.216','2008-02-12 13:27:04','2008-02-12 11:27:04','FRATELE MEU... ESTI MARE!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(16963,1011,'ramonici','','','89.33.174.82','2008-02-25 01:43:02','2008-02-24 23:43:02','shi mie mi se mai pare cate intr-o dimineatza ca o voce cam furioasa imi spune ca o sa intarzii pe undeva... shi mereu imi spun ca o sa o potolesc! niciodata nu reushesc... e mama',0,'1','Opera/9.10 (Windows NT 5.1; U; en)','',0,0),(16964,1009,'marius','mariusparciu@yahoo.com','http://parciu.blogspot.com/','79.112.95.60','2008-02-25 01:45:09','2008-02-24 23:45:09','nu credeam ca pot rade atat la citirea un post despre bonurile de masa :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(16652,1001,'ametzitul','','http://ametzitul.wordpress.com','62.217.236.12','2008-02-20 08:34:15','2008-02-20 06:34:15','cre\' ca mai interesant ar fi sa fii nu arabul bogat, ci cetatzean in tzara lui - ce-i drept, sunt si partzi najpa - nu mai vezi tu bere decat in concedii prin Ioropa :)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(16948,1009,'Laura','mars1953@web.de','','84.160.113.21','2008-02-24 22:47:12','2008-02-24 20:47:12','No, io cand muncesc vreau bani, cand ma fut un orgasm, cand beau o bere tra sa fie proaspata si rece si cu doua degete spuma...',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(16949,992,'nenea cosmos','domnu_cosmos@yahoo.com','http://www.nenea.wordpress.com','92.80.17.109','2008-02-24 22:52:21','2008-02-24 20:52:21','Deoarece azi m-am lÄƒsat iar de fumat este evident cÄƒ nu am fÄƒcut cÄƒcuÅ£Äƒ de dimineaÅ£Äƒ, Ã®n buna tradiÅ£ie cosmicÄƒ. Caz Ã®n care caca a stat Ã®n mine, am fost Ã®mpreunÄƒ peste tot, am fÄƒcut Ã®mpreunÄƒ ÅŸi nani dupÄƒ amiazÄƒ. A venit la un moment dat momentul sÄƒ ne despÄƒrÅ£im dar cum ne-a fost aÅŸa bine Ã®mpreunÄƒ caca a lÄƒsat Ã®n urmÄƒ o putoare de rÄƒmas bun, putoare care a infectat Ã®ntregul apartament ÅŸi nu vroia sÄƒ pÄƒrÄƒseascÄƒ incinta cu toate Ã®ncercÄƒrile de aerisire ÅŸi Ã®mprÄƒÅŸtiere cu parfumurile prin casÄƒ. ParcÄƒ mai rÄƒu se amesteca cu orice, parcÄƒ intrase Ã®n haine ÅŸi Ã®n covoare (perdele nu mai am de cÃ®nd m-am cÄƒcat prima datÄƒ). ÃŽnÅ£elegÃ®nd cÄƒ lui CÄƒcuÅ£Äƒ Ã®i este dor de mine am plecat la plimbare, mergÃ®nd pe lÃ®ngÄƒ canalizare ÅŸi fÄƒcÃ®nd pa-pa cu mÃ®na la fiecare canal. Ajung lÃ®ngÄƒ marea canalizare unde toÅ£i cÄƒcÄƒÅ£eii se aruncÄƒ Ã®n marea cÄƒlÄƒtorie finalÄƒ cÄƒtre oceanul planetar, fac cu batista, vÄƒrs o lacrimÄƒ, asta e. ÃŽntr-un final mÄƒ Ã®ntorc acasÄƒ, deschid uÅŸa la apartament, a ce credeÅ£i voi cÄƒ mirosea Ã®n casÄƒ? A plÄƒcintÄƒ de brÃ®nzÄƒ cu stafide.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(16134,989,'alex - recensamantul bloggerilor','alex@roblogs.info','http://www.roblogs.info','89.41.217.109','2008-02-14 14:40:27','2008-02-14 12:40:27','corecte toate 10 ;)\r\n\r\nP.S.  \"complemente\" ai scris voit?',0,'1','Opera/9.25 (Windows NT 5.1; U; en)','',0,0),(16771,1010,'john_doe','dintz_best@yahoo.com','','81.180.170.53','2008-02-23 00:26:49','2008-02-22 22:26:49','Ma gropare,ca tot veni vorba de bancuri la care nu rade nimeni.Ia aci:\r\nO mama isi dojeneste fiul: \r\n- Aha, deci in Spania nu vrei sa te duci, in Italia nu vrei sa te duci, fotbal nu stii sa joci......\r\nBina ma, atunci da la facultate.......sa ajungem de rasul blocului!',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; SIMBAR={0512FC83-A428-4DE2-9157-B0DF1A476D4B})','',0,0),(16655,1001,'Dani Mocanu','mocanudi@yahoo.com','http://www.danimocanu.net/','92.80.119.172','2008-02-20 09:53:17','2008-02-20 07:53:17','Bere nu mai vezi.. dar daca ai si un ungur cu tine iti faci o painca din portocale sub pardosea... de mai mare dragu\'...\r\n\r\nCat despre telefonie... dupa ce incepe productia la Cluj a telefonului mioritic Buciumul Carpatilor... io zic sa le facem cadou vreo cinci mii, sa rezolvam problema cu fidelizarea',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(16132,989,'artistu','manea.andrei@gmail.com','http://artistu.voce.ro','82.76.6.184','2008-02-14 14:15:16','2008-02-14 12:15:16','Frumoasa sarnbatoare \"marketing-istica\" si Sain Valentinu\' asta!\r\nHai sa fim cumparatori... ca doar de aia a fost facuta! Sa luam toti flori, maimutzoi, excursii si alte asemenea!\r\n:(',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(16606,995,'Catzaua','ana.man.fox@gmail.com','','81.180.173.61','2008-02-19 13:18:54','2008-02-19 11:18:54','..asta fusa ca de la o Ana veche pentru Ana cea noua :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(16768,1009,'Andreea MKT','supergirgir@yahoo.com','','89.43.186.64','2008-02-22 23:02:52','2008-02-22 21:02:52','deci eu nu cred ce probleme avea colegu cipicao...auzi...ca is urate bonurile...doamne, mare e gredinaaaa...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(16591,995,'koyrosh','a@a.com','','82.77.126.254','2008-02-19 10:17:42','2008-02-19 08:17:42','deocamdata experimenteaza pe ea leacu\' contra bashinilor si se pare ca are efect invers: cand trozneste cate una, muta patutzu\', ca e pe role',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(16675,1001,'Andreea','puistrulet2003@yahoo.com','http://n/a','81.196.150.196','2008-02-20 16:18:02','2008-02-20 14:18:02','@Julius\r\n\r\nMa lipsesc cu drag de asemenea \"noroc\" :)....\r\nNu de alta dar s-ar putea sa nu fac fata la atata fericire...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(16091,989,'natty','natty2277@yahoo.com','','86.106.49.165','2008-02-14 08:38:46','2008-02-14 06:38:46','asta e discriminare! le-ai facut \"complimente\" mai mult fetelor grase...\r\nce noi astea mai slabute nu meritam:)?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(16092,989,'ametzitul','','http://ametzitul.wordpress.com','62.217.236.12','2008-02-14 08:51:49','2008-02-14 06:51:49','textul asta tre\' dat nevestelor/prietenelor sa-l citeasca, poate asha ne vor aprecia mai mult :)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(16605,994,'julius constantinescu','julius@universitateacraiova.ro','http://www.7plus.ro/?arhiva=18/02/2008&#38;id=2324','84.232.163.225','2008-02-19 13:16:30','2008-02-19 11:16:30','@tya: deci porcu\' asta de Groparu mi-o zis ca la voi la firma nu exista femeie sub 90 de kile si fara par pe piept. in consecinta, va rog sa-l zgariati pe mitocan cu unghiile, sa-i scuipati in cafea si sa raspanditi, cu discretia cuvenita, zvonul ca o luat blenoragie.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(16530,992,'Andreea','puistrulet2003@yahoo.com','http://n/a','81.196.150.196','2008-02-18 16:45:31','2008-02-18 14:45:31','De fapt povestea ta are o morala nu?\r\n\r\nRezistenta romanilor la factorii externi si ostili :)\r\n\r\nNo, bine ca am lamurit-o...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(16096,989,'Andreea','puistrulet2003@yahoo.com','http://n/a','81.196.150.196','2008-02-14 09:16:14','2008-02-14 07:16:14','Crezi ca numai tu Gropare poti fi fauritor de \"complimente\" de Valy Day?\r\n\r\nEa(emotionata):\r\nN-ai idee ce mult insemni pentru mine, apreciez atat de multe lucruri pe care le faci pentru noi.....!!!Te iu... Si mai lasa naibii jocul ala, tu nu esti atent la ce iti spun????\r\nEl: Haaa??? What??Mai zi odata ca n-am auzit.... Si cand mergi in bucatarie nu-mi faci si mie un sendvis? Thx\r\nEa:\r\n!!!!!1111!!!!!111!!!!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(16508,992,'Turambar','mirel@ccsb.ro','http://turambarr.blogspot.com','79.114.190.130','2008-02-18 10:19:36','2008-02-18 08:19:36','Nu spun nimic. Nici macar n-am citit postu asta. Eu sunt un om serios, dedicat muncii si comunitatii, orientat spre productivitate, decentza, politetze, subiecte grele, semnificative, care pot sa contribuie la imbunatatzirea calitatzii vietzii shi a respectului intre popoare. Nu pot sa citesc. Ochii ma doare / Drept intre picioare / Unde-i grija mare.\r\n\r\nI therefore \r\n\r\nPROTESTEEEEZZZZ! \r\n\r\nSa vina mujahedinii sa-l beleasca prin belire pe acest degraba cartitoriu si pervertitoriu de suflete nevinovate shi bezmetice care citeshte la dansu pe blog despre toate spurcaciunile pamantului shi ale fiintzei cele pagane si vandute diavolului. Sa vina parintele popa sa-i faca o molifta de primenire a sufletului, sa-l exorcizeze shi sa scoata dracii dintr-insul shi sa-i curetze mintea, sufletu, gura shi burta de otraveala cea smintita.\r\n\r\nMama voastra de scarboshi... :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(16934,1009,'Laura','mars1953@web.de','','84.160.113.21','2008-02-24 20:19:17','2008-02-24 18:19:17','Si faza asta cu bonurile de masa ar trebui depasita. Epoca trocului o trecut demult!',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(16935,1009,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','92.81.150.68','2008-02-24 20:22:13','2008-02-24 18:22:13','Apai nu, tu Laura... pana si frantujii le folosesc.\r\n\r\nIs parte din ceia ce se kiama \"fringe benefits\" - si bag sama ca daca firma nu ne poate da tuturor telefoane, macar sa ne deie ceva dupa care sa ne cumparam tigari si beutura de la chiosc, cand nu mai avem $ de bare! De baruri, pardon.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(16680,1001,'andys','adi_coaja@yahoo.com','','89.38.155.199','2008-02-20 18:51:57','2008-02-20 16:51:57','Bre Gropare, am si io o intrebare... pot sa te parafrazez un pic? Adica... sa zic si eu ca tine, dar in loc de Nascut din spermatozoizi campioni sa zac Nascut din hemoroizi campioni?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Maxthon; .NET CLR 2.0.50727)','',0,0),(16672,1001,'Andreea','puistrulet2003@yahoo.com','http://n/a','81.196.150.196','2008-02-20 14:46:47','2008-02-20 12:46:47','@Julius\r\n\r\nIoi tulai si io care mai merg pe acolo ca am o pretena care-i fix din Prund....\r\nOare cand am mers eu ei aveau liber de la joc? Sau ii tineau prietenele si mamele acasa cu forta???? :)\r\n\r\nPS: nu stiam ca ii spune Las Vegas... bine de stiut si de bagat la tartacuta :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(16632,1001,'baghy','baghy83@lycos.it','http://www.baghy.info','78.12.16.50','2008-02-20 01:37:04','2008-02-19 23:37:04','cum se numeste compania?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(16582,992,'WhiteWolf','contact@white-wolf.ro','http://white-wolf.ro','89.32.115.18','2008-02-19 07:53:32','2008-02-19 05:53:32','[\"V-a impuiat capul cu nunti, botezuri, zile de nastere si betzii monstruoase, il concureaza cu un real succes pe nenea Cosmos in ceea ce priveste <a href=\"http://www.white-wolf.ro/?p=557\" rel=\"nofollow\">apologia cacatului si a beshinilor demiurgice</a> ...\"]',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(17010,1011,'katmai','katmai@keptprivate.com','http://512kbps.com','195.212.29.179','2008-02-25 10:30:21','2008-02-25 08:30:21','weh ... daca fac si eu asta la work ... ajung sigur la nr9, si ofcourse nu ma mai angajez eu pana-i ...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(17134,1013,'ametzitul','','http://ametzitul.wordpress.com','62.217.236.12','2008-02-26 11:46:25','2008-02-26 09:46:25','totzi shefii sunt la fel, fie ei shi hermafroditzi :(\r\nshi bautura-i pentru uichend, domnu\'...',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(16752,1009,'mishu','mishu@doingtheartwork.com','http://www.doingtheartwork.com','82.77.126.254','2008-02-22 16:06:46','2008-02-22 14:06:46','Spune-ne exact cum s-a intamplat ce ti-am scris eu pe foaie :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(16753,1009,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-02-22 16:27:10','2008-02-22 14:27:10','Faza aia legata de maica-mea?\r\n\r\nNu.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(16938,1009,'Laura','mars1953@web.de','','84.160.113.21','2008-02-24 21:03:33','2008-02-24 19:03:33','o fi mai groparule, dar io muncesc pentru bani si daca primesc nishte fringe... care-s scutite de impozite ok, dar io n-as munci sa-mi dea in loc de bani bonuri de masa si sa fiu obligata sa ma duc la magazinul X sa cumpar. Asta o vad ca o ingradire a libertatii si ca o fraiereala. \r\n\r\nSi ca si frantujii le folosesc nu-i un argument pentru mine.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(16710,1008,'Dani M','mocanudi@yahoo.com','http://danimocanu.net','92.80.119.172','2008-02-21 18:59:55','2008-02-21 16:59:55','Fidel e mort de vreo trei patru ani.... dar numai acuma a avut curajul sa recunoasca...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; ro; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(16711,1008,'Buciuman','aaa@ggg.com','http://rezistenta.blogspot.com/','86.121.53.95','2008-02-21 19:00:39','2008-02-21 17:00:39','printre alti dictatori puteai sa incluzi pe Marc Anthony si Jean-Paul Gaultier',0,'1','Opera/9.25 (Windows NT 5.1; U; en)','',0,0),(16575,992,'oli','prea_real@yahoo.cm','','89.122.238.248','2008-02-19 04:47:34','2008-02-19 02:47:34','Da\' io tot nu stiu: A fost fasaita sau cu rupere de buci?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(16705,1008,'Dani M','mocanudi@yahoo.com','http://danimocanu.net','92.80.119.172','2008-02-21 11:24:26','2008-02-21 09:24:26','Ma... io am incredere ca nepoata lu\' Mussolini o sa si-o traga la un moment dat cu Vadim. Si ce-o sa ias de acolo.. valeu... ca o sa planga toti comunistii. Si pe ala micu l-as trimite in Kosovo... numa\' asa ca-mi plac mie filmele lui Kusturica.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; ro; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(16620,995,'catalin','catalin_heghes@yahoo.com','http://sec.ablog.ro','82.78.160.91','2008-02-19 19:31:08','2008-02-19 17:31:08','urmatorul pas pe care ana trebuie sa-l faca, daca e asa cum zici tu, e sa-si proclame independenta.',0,'1','Mozilla/5.0 (Windows; U; Win 9x 4.90; en-GB; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(16714,542,'Nascut din spermatozoizi campioni &raquo; Blog Archive &raquo; Nasii mei la Cluj','','http://www.groparu.ro/?p=1010','82.103.137.253','2008-02-21 21:48:24','2008-02-21 19:48:24','[...] Nasii mei, dupa cum va ziceam intr-o postare anterioara, or venit la Cluj. Cum care nasii mei? Astia. [...]',0,'1','Incutio XML-RPC -- WordPress/2.1.2','pingback',0,0),(16570,994,'julius constantinescu','julius@universitateacraiova.ro','http://www.7plus.ro/?arhiva=18/02/2008&#38;id=2324','84.232.168.129','2008-02-19 03:23:34','2008-02-19 01:23:34','@Tya: La multi ani!\r\n@Gropare: N-ai scris nimic in seara asta. Sigur a dat Tya de baut si tu ai fost porcu\' firmei, te-ai imbatat clanta si-ai povestit ceva asa de dragut, ca te-a luat unu\' in spate si te-a carat dracu\' acasa, iar acu\' zaci pula de beat in pat, incaltat in bocancii tai interzisi de Conventia de la Geneva. Dumnezeu sa-i apere pe gandacii care traiesc cu tine in aceeasi camera!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(16740,1010,'CÄƒlÄƒ','acalarasu@gmail.com','http://adriancalarasu.wordpress.com','62.217.241.242','2008-02-22 10:52:13','2008-02-22 08:52:13','naspa!\r\nda\' e ok, bine ca nu a zis ca esti... de incredere! sau mai rau, dragutz, o dulceatza, o bomboana de baiat!!!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(16716,1010,'WhiteWolf','contact@white-wolf.ro','http://white-wolf.ro','89.39.81.213','2008-02-21 22:26:06','2008-02-21 20:26:06','Poate ca, intre timp, nash\'ta si nevasta lu\' nash\'to so facut mai mare balzaciana decat iel. Asa, ca sa ramaie la conducere.\r\nSh\'atunci, cre\' ca te intrebi dejaba. Ii o dilema la care nici nas\'to n-ar putea gasi solutia optima. Sau justa\r\nDepinde cum te simti la momentul lecturii.\r\n Corolar; pana (inca) te mai pomeneste familia, insamna ca nici nu esti singur pe lumea asta (cruda) sh nici n-ai pornit spre plaiurile alea vesnice ale vanatorii\r\n<b>Las\' ca merge</b> :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(16717,1010,'cepanamea','icgel@yahoo.com','http://www.cepanamea.ro','92.80.35.199','2008-02-21 22:57:31','2008-02-21 20:57:31','Lasa, omule, nimeni nu-i perfect!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(16368,991,'OTV','otvteleviziunea@yahoo.com','','86.122.63.217','2008-02-16 14:48:43','2008-02-16 12:48:43','Acum avem si Blog OTV, Forum OTV **************.blogspot.com Un blog util si la obiect, stiri in fiecare zi\r\n\r\n\r\nGroparu dixit: Baaaaa, Cioaca, dispai!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(16538,994,'tya','afrimtya@yahoo.com','http://www.afrim-tya.blogspot.com','82.77.126.254','2008-02-18 17:47:41','2008-02-18 15:47:41','Merci de wish-peesh si de filmuletz si de toate minunatiile alea nascocite de fabuloasa-ti minte ( plina de gandaci si capuse si mizerie sub unghii si...toate scarbosenile din lumea asta) pe care de altfel noi o iubim.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(16534,992,'Kissu','','','82.77.126.254','2008-02-18 17:18:37','2008-02-18 15:18:37','@ Andreea: \"Eu cred totusi ca Groparu a exagerat cand a descris magnitudinea efectului produs de stim noi ce; daca ar fi fost chiar asa cum spune el, nu cred ca ar fi stat in preajma lui tocmai victimele, daramite sa mai si povesteasca nu?\"\r\n\r\nDraga Andreea... TRUST ME! CHIAR asa e! EU stiu!... :(( Si Diana stie si ea! Amandoi suntem VICTIMELE \"holocaustului groparian\".',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; InfoPath.1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648)','',0,0),(16373,989,'Carmen','daftpact@yahoo.com','http://carmenbogdan.blogspot.com','84.232.184.67','2008-02-16 16:07:11','2008-02-16 14:07:11','Super tare. :)):)))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(16739,1010,'IepurasulAtomic','praetorian21uk@yahoo.com','','192.100.130.8','2008-02-22 10:50:10','2008-02-22 08:50:10','Asa nu pricepe unii oameni ca facerea de bine nu-i musai facuta din marinimie de suflet, ci din mustrare de constiinta. Cum, nu-i nici o diferenta? Si io m-am pricopsit pe cap cu matusa-mea, care fix tot la Onco o fo\' si tot asha ca tine s-o operat. Sa speram ca se face bine bine...si matusa mea, si nasa ta. Sanatate maxima, sau macar medie ori mediocra! Ca-i mai bine decat deloc, nu?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(16552,989,'MARIANSSENN&#8230;.si guess who? &raquo; Arhiva blogului &raquo; V&#8217; day','','http://eblogs.ro/marianssenn/2008/02/18/v-day/','85.234.150.220','2008-02-18 21:05:07','2008-02-18 19:05:07','[...] ce cadouri sunt potrivite si ce dreaq sa mai fii. Eu ma intreb nu poti fi in fiecare zi asa?  Groparu are cateva sugestii din alea care sa nu fii. Altu a zis urmatoarea chestie si a zis bine. Cu ceva [...]',0,'1','Incutio XML-RPC -- WordPress/wordpress-mu-1.2.5','pingback',0,0),(16596,994,'tya','afrimtya@yahoo.com','http://www.afrim-tya.blogspot.com','82.77.126.254','2008-02-19 11:20:21','2008-02-19 09:20:21','@julius: Sar\'na, nenea.\r\n S-a imbatat cu salata de fructe omu nostru ca i-au fermentat fructele instantaneu cand au dat de sucu lui gastric! Ce bine il cunosti:))).\r\n@Andreea: Papucii aia merg singuri si eu m-am simtit beton in ziua aia..dar ai dreptu sa nu-ti placa. Devenea plictisitor sa-mi tot zici ce mult iti place cum ma imbrac!:P. Pupici.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(16597,995,'dush','tirbushon@gmail.com','http://dushrece.blogspot.com','193.230.155.70','2008-02-19 11:35:43','2008-02-19 09:35:43',':)) sa le traiasca dom\'le....da se pare ca fata asta s-o nascut sa faca bine numa barbatilor... oricum...sa scada si pretu\' la bere si la vin ca al\'fel nu e d\'a casei...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(16567,992,'catalin','solo@xsolo.biz','http://xsolo.biz','190.16.112.9','2008-02-19 02:36:53','2008-02-19 00:36:53','Dupa cum zicea Ali G: \"Respek. West side.\" sau south side...nu stiu cum sa definesc zona mea :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(17135,1013,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-02-26 11:54:53','2008-02-26 09:54:53','Pai da, si ieri sarÄƒ n-o fo weekend?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(16551,994,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','92.81.133.145','2008-02-18 20:59:15','2008-02-18 18:59:15','Teoretic, nu: e creatia lu maica-mea, care e autoarea autorului!!!!!',0,'1','Mozilla/5.0 (Macintosh; U; Intel Mac OS X; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(16544,994,'Andreea MKT','supergirgir@yahoo.com','','89.43.186.64','2008-02-18 19:03:47','2008-02-18 17:03:47','dar tot te-ai imbracat aiurea in ziua aia, iarta-ma te rog:)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(16545,992,'Andreea MKT','supergirgir@yahoo.com','','89.43.186.64','2008-02-18 19:09:11','2008-02-18 17:09:11','ej scarbos, mah...mai trebe sa ne esplici cum ca in nu stiu care antichitate, lungimea la faeces reprezenta masculinitatea masculului. si uite tot asa, cu aceleasi chestii, ne impresionatzi voi de 3000 de ani, nu vatz skimbat deloc.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(16553,992,'baghy','baghy83@lycos.it','http://www.baghy.info','78.12.16.50','2008-02-18 22:16:34','2008-02-18 20:16:34','si vrei sa zici ca noua nu ne place?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(16760,1009,'Andreea','puistrulet2003@yahoo.com','http://n/a','81.196.150.196','2008-02-22 18:03:32','2008-02-22 16:03:32','Legat de subiect\r\n\r\nHmmm f interesanta atitudinea... oare chiar au inceput sa se educe vanzatorii si provider-ii de servicii?\r\n\r\nEu astept ziua in care o sa vad intr-un magazin alimentar din asta normal (lipitori de bloc le zic eu) o vanzatoare care sa imi zambeasca si sa multumeasca pt bani si ah, sa nu uit, sa nu-mi mai dea rest guma si bomboane :)\r\n\r\nCand am facut io faculta era un magazin in Obs care ii zicea Grajduri (acuma nu mai e) si acolo erau cele mai afurisite vanzatoare ever; no pe alea vreau sa le vad reeducate :)) ca m-as bucura tare mult sa ma port io naspa cu ele.. mwhahahaha !!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(16549,994,'saliery','alexblana2003@yahoo.co.uk','http://saliery.ablog.ro','86.127.94.222','2008-02-18 20:49:35','2008-02-18 18:49:35','buna..e creatie proprie?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 2.0.50727)','',0,0),(16595,995,'.marius','marius@perijoc.com','http://marius.wirelessisfun.com','79.116.79.145','2008-02-19 11:01:15','2008-02-19 09:01:15','Si dimineata mea incepuse atat de anost incat am crezut ca voi muri de plictiseala! \r\n\r\nStai ca nu se mai aude bormasina vecinului de la cum behaiam eu de ras aici...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9b3) Gecko/2008020514 Firefox/3.0b3','',0,0),(16594,995,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-02-19 10:54:01','2008-02-19 08:54:01','Tre sa refac poza :D in a minute...!(or 200)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(15621,983,'CARHANT','WWW.CARHANT.YAHOO.COM','','88.158.8.106','2008-02-10 00:57:31','2008-02-09 22:57:31','MA NU MESC DOAMNA CARHANT\r\nDECE VB ASA CEVA PE INTERNET  VB FF URAT  DAR CE POLITIST A MIROSIT CHILOTI\r\n?\r\nPENTRU CA EI SANT NISTE OAMENI DE CACAT AR TR ARESTATI CA EI NU FAC CE TREBUIE CA POLITISTI FAC NU MAI BELELE\r\nMULTUMESC',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; SIMBAR={7536B004-A8B7-48CF-9C5B-22690C1D3B80})','',0,0),(16707,1008,'baghy','baghy83@lycos.it','http://www.baghy.info','78.12.16.50','2008-02-21 16:20:10','2008-02-21 14:20:10','Pai daca ai zis de prietena Stalinskaya ne-ai spus parerea ta',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(16928,1009,'Laura','mars1953@web.de','','84.160.113.21','2008-02-24 19:38:25','2008-02-24 17:38:25','Cand dupa mai multi ani m-am hotarat sa beau si eu o bere intr-un bar  in Sibiu, am facut un soc portmone-iesc. O bere, pe centru in Sibiu mult mai scumpa decat o bere in centru in Stuttgart. Apoi numai beri din alea la care de-abia poti sa le zici pe nume, nu tu un Trei Stejari, nu tu o Balea, Doamne feri sa fie vre-un produs romanesc. De parca n-am avea si noi apa limpede de izvor, hamei si toate celeâ€¦ Draga mea Romanica scumpa mai estiâ€¦\r\n\r\n@Cipicao si Mishu: RESPECT',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(16522,992,'Andreea','puistrulet2003@yahoo.com','http://n/a','81.196.150.196','2008-02-18 15:04:41','2008-02-18 13:04:41','@Turambar:\r\n\r\nExorcizare pentru flatulenta? Asta e noua... :)\r\nEu cred totusi ca Groparu a exagerat cand a descris magnitudinea efectului produs de stim noi ce; daca ar fi fost chiar asa cum spune el, nu cred ca ar fi stat in preajma lui tocmai victimele, daramite sa mai si povesteasca nu? Hai Gropare, spune ca ai cam inflorit povestea, nu de alta, dar uite ca s-a ajuns la proteste si cine stie de ce or mai fi unii in stare... :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(16117,989,'manole','redtailanda@yahoo.com','http://www.mesterulmanole.wordpress.com','81.181.92.157','2008-02-14 12:01:29','2008-02-14 10:01:29','Vad ca suntem destui care -ti uram pe aici, Happy Valentine\'s Day, fiecare prin prezenta! Da\' EA, e? \r\n\r\nDaca oi fi Valentin, atunce: Sa traiesti! Daca n-oi fi Valentin, atunce tot : Sa traiesti! :)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows 98)','',0,0),(16100,989,'PhenoBarbieDoll','poisongirl94@yahoo.com','http://blog.360.yahoo.com/poisongirl94','193.230.230.101','2008-02-14 09:48:07','2008-02-14 07:48:07','deci pentru necunoscatori, pe Groparu il cheama si Vali, asa ca putem sa-i facem urari :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(16101,989,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-02-14 09:49:49','2008-02-14 07:49:49','Minciuna!!!\r\n\r\nMa cheama chiar Valentin, da? Da\' numele de familie nu e Sfantu\', aia-i clar, of cos.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(15679,983,'raluca','','','89.137.11.203','2008-02-10 21:11:50','2008-02-10 19:11:50','Gropare, nu ai informatzii complete! Politzistul era la ciordit cu nevasta-sa, ceea ce da o cu totul alta perspectiva povestii, mai ales ca se apropie Valentines-ul. Un fel de natural born killers... De asemenea, in unele ziare, pe langa tanga si prezervative, se zice ca ar mai fi furat si lubrifiant sau dupa caz, un aparat de tuns. Deci baiat finutz. Cand a fost prins, s-a folosit de legitimatia de politist. Probabil ca era o operatiune undercover :))  merita un sequel',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1)','',0,0),(16709,1008,'saliery','alexblana2003@yahoo.co.uk','http://saliery.ablog.ro','86.127.14.178','2008-02-21 18:54:46','2008-02-21 16:54:46','Fidel a stiut cand sa se retraga, ca sa nu fie hulit de lume. Desi unii nu-l suporta si a fost prieten cu tatuca Hrusciov, a si ajutat Cuba;) Oricum ii respect pentru politica care o au fata de S.U.A.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 2.0.50727)','',0,0),(16674,1001,'julius constantinescu','julius@universitateacraiova.ro','http://www.7plus.ro/?arhiva=20/02/2008&#38;id=2420','84.232.163.28','2008-02-20 15:59:11','2008-02-20 13:59:11','@Andreea: asa e la las vegas, mai ai si ghinion. io zic sa mai incerci, nu se poate ca intr-o zi sa nu-ti zambeasca norocul.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(16113,989,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-02-14 11:33:04','2008-02-14 09:33:04','Ba blogatu, io nu pot sa dau linku\' la nimeni, ca daca raman fara iel io ce ma fac???',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(16523,992,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-02-18 15:31:30','2008-02-18 13:31:30','Deci Andreea: daca fÄƒceam aÅŸa ceva Ã®n Europa occidentalÄƒ, la slÄƒbanii Äƒia, rÄƒdeam o Ã®ntreagÄƒ civilizaÅ£ie, pÃ¢nÄƒ atunci Ã®nfloritoare. Dar romÃ¢nii moare mai greu! Io ce sa le fac?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(16592,995,'pliscu','pliscu@gmail.com','http://pliscu.blogspot.com','89.137.100.118','2008-02-19 10:42:12','2008-02-19 08:42:12','hey, unde dispÄƒru ÅŸarada?? :(',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(16590,56,'Nascut din spermatozoizi campioni &raquo; Blog Archive &raquo; Ana are Coprea - ceeeeee numeeee simpluuuuu&#8230;.','','http://www.groparu.ro/?p=995','82.103.137.253','2008-02-19 10:07:51','2008-02-19 08:07:51','[...] ultima vreme, cei doi programatori de sex opus, iaca! s-au Ã®nmulÅ£Ã¢t, sÄƒ trÄƒiascÄƒ, [...]',0,'1','Incutio XML-RPC -- WordPress/2.1.2','pingback',0,0),(16471,992,'Buciuman','aaa@ggg.com','http://rezistenta.blogspot.com/','86.121.53.95','2008-02-18 00:22:33','2008-02-17 22:22:33','Intrebarea este au sarit ele oripilate s-au le-a impins musonul?',0,'1','Opera/9.25 (Windows NT 5.1; U; en)','',0,0),(16478,992,'julius constantinescu','julius@universitateacraiova.ro','http://www.7plus.ro/?arhiva=18/02/2008&#38;id=2324','84.232.168.30','2008-02-18 01:37:16','2008-02-17 23:37:16','Groparule, tu ai face cariera in orice armata din lume. Pentru basina asta, cel putin unde am facut io armata, la a IV-a Transilvania, primeai Virtutea Militara, plus ca, atunci cand era zi de fasole, iti dadeau doua portii, ca la noi se incuraja performanta, nu ca la alte unitati.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(16531,994,'Andreea','puistrulet2003@yahoo.com','http://n/a','81.196.150.196','2008-02-18 16:50:50','2008-02-18 14:50:50','No Laaaa Muuulti Aaaani !!!\r\n\r\nSms (si multa sanatate) :) (ca asa e frumos)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(16111,989,'blogatu','ovydiucraiova@yahoo.com','http://blogatu.blogspot.com','82.79.216.239','2008-02-14 11:22:10','2008-02-14 09:22:10','Salut. As vrea sa facem schimb de linkuri. Poti sa ma contactezi pe mail sau pe messenger, la ID-ul ovydiucraiova',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; SU 3.011; SIMBAR={8098D235-586E-4EC8-AD49-C0267BF28868}; InfoPath.2)','',0,0),(16110,990,'VforWhatever','stephanovendetta@yahoo.com','','89.37.114.51','2008-02-14 11:06:33','2008-02-14 09:06:33','@andreea... nu e vina noastra, a estia parosilor si virilicoshilor ca femeia a indurat pe putin 2000 de ani de chinuri pentru frumusete (faza cu matriarhatul pica din start, ca tine de fratii grimm...) si ca defapt si de drept este doar corect sa devenim toti metrosexuali si sa ne tundem berbile de pe pept, sa mergem la manichiuuuuuura si pedichiuuuuura, sa ne facem freze de-mpietreste berzele pe stalpi si-ngheatza de nu mai decoleaza-n tarile calde... eu inteleg ca nu mi-ar place sa vad o femeie cu blana pe picioare, perfect corect... dar unei femei, dupa cate stiu eu, inafara de unele exceptii extraordinare, nu-i creste paru balai asa vartos ca unui barbat... oricum, pacat de trendu ala din \'70...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.6) Gecko/20040113','',0,0),(16033,989,'iulianuss','realvision@k.ro','','193.231.107.209','2008-02-13 20:39:02','2008-02-13 18:39:02','Am dat o raitÄƒ prin prÄƒvÄƒlii numa de kiki. CredeÅ£i cÄƒ erau pline de domniÅŸori ÅŸi domni cu portofelu la ei? Nem! \r\nErau in patrulare echipe de dumnea-ele cu ochii-girofar la CE LI SE CUVINE de pe rafturi!  \r\nDeci hepi-hepi dar ceva concret  bÄƒieÅ£ici, cÄƒ complementele nu Å£i le vede nime ! Åži pÃ¢nÄƒ la 1 martie e o veÅŸnicie, tu ...',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; .NET CLR 1.1.4322)','',0,0),(16668,1001,'julius constantinescu','julius@universitateacraiova.ro','http://www.7plus.ro/?arhiva=20/02/2008&#38;id=2420','84.232.163.28','2008-02-20 13:07:54','2008-02-20 11:07:54','@gropare, @dane: daca vreti sa jucati jocuri de societate, incercati cu incredere Prundul Bargaului, acest Las Vegas al judetului Bistrita. Numai acolo, fiii satului se aduna pe marginea drumului si se distreaza demential aruncand cu pietre in masini. Cel mai misto e sa fii in masina - cu alte cuvinte, indiferent de pagube, e recomandabil sa nu cobori din ea sub nici un motiv. Din acesta cauza, viteza de croaziera recomandata pe raza localitatii Prundu Bargaului este de aproximativ 240 km/h. Bafta!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(16035,989,'saliery','alexblana2003@yahoo.co.uk','http://saliery.ablog.ro','86.127.13.85','2008-02-13 20:44:35','2008-02-13 18:44:35','Imi place articolul tau :D Arunci un ochi si aici? http://saliery.ablog.ro/2008-02-11/motive-sa-fii-anti-valentine-s-day.html',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 2.0.50727)','',0,0),(16255,991,'katmai','katmai@keptprivate.com','http://512kbps.com','195.212.29.187','2008-02-15 12:12:34','2008-02-15 10:12:34','noroc ca n-am mancat nika de dimineata, altfel faceam show pe aici cand am ajuns la papam placenta.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(16256,991,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-02-15 12:21:07','2008-02-15 10:21:07','Ho, ba, ca am zis mancat, nu dat limbi!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(16107,989,'PhenoBarbieDoll','poisongirl94@yahoo.com','http://blog.360.yahoo.com/poisongirl94','193.230.230.101','2008-02-14 10:48:10','2008-02-14 08:48:10','da ma, stiu, da\' mi-o fo\' lene sa scriu tat numele ala lung. oricum, daca ejti cuminte, poate te canonizam sa te cheme si Sfantu\' (amu, daca te duci au ba, ii treaba ta)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(16604,995,'Catzaua','ana.man.fox@gmail.com','','81.180.173.61','2008-02-19 13:15:43','2008-02-19 11:15:43','ana mica, ana noua,\r\nana scumpa esti cat doua,\r\nana dulce, ana faina,\r\nai venit la ceas de taina.\r\n\r\nana mica, ana tare,\r\nana iti fac acum urare,\r\nana dulce, sa traiesti\r\nca la toti ne trebuiesti.\r\n\r\nana mica tu sa ai \r\nsanatate si parai\r\nana dulce tu sa fii\r\ncu IQ de genii tri\'\r\n\r\nana mica si voioasa\r\nsa aduci lumina\'n casa, \r\nana dulce sa n-ai baiuri,\r\nnici aci, nici p\'alte plaiuri.\r\n\r\nla multi ani cu pupaturi domoale din corazon.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(16528,992,'ics','i_uana@yahoo.com','','86.126.112.82','2008-02-18 16:42:30','2008-02-18 14:42:30','fain cadou pt ziua mea ce ai scris tu aici ma Gro\'...mersi :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(16039,989,'katmai','katmai@keptprivate.com','http://512kbps.com','89.176.173.78','2008-02-13 21:13:03','2008-02-13 19:13:03','oh ... that is so sweet :) groparu intotdeauna ma atinge la inima. uf!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(16537,992,'Andreea','puistrulet2003@yahoo.com','http://n/a','81.196.150.196','2008-02-18 17:45:39','2008-02-18 15:45:39','No priveste partea buna: sunteti supravietuitori... :)\r\n\r\nCa in filmul ala \"I am legend\" (in loc de vampiri sau ce naiba erau, voi ati tinut piept unui factor exterminator mult mai parsiv.... MIROSUL)\r\n\r\nDeci, respect ! :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(16833,1009,'Emaginatoru','e_magist@yahoo.com','','79.116.82.32','2008-02-24 01:23:54','2008-02-23 23:23:54','Cum! S-au desfiintat \"Grajdurile\" ?\r\n\r\n@Gro\r\nMaestre, dvs. merjetz la birou shi culejetz intamplari osebite shi le facetz (pintru noi) DEOSEBITE.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(16524,991,'koyrosh','a@a.com','','82.77.126.254','2008-02-18 16:03:13','2008-02-18 14:03:13','adeca de fapt si de drept io am vint cu ideea de placenta cu varza; amu am ratat treaba, ca nartzoaga mica deja o aparut pe planeta de doo zile (aprox). poci a mai zice ca daca ar avea ma-sa 4 tzatze, poate s-ar satura aia mica',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(16521,994,'angel','elena.siriteanu@yahoo.com','http://angel.saltwaterc.net','62.231.91.66','2008-02-18 15:02:44','2008-02-18 13:02:44','Sa!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(15691,984,'Turambar','mirel@ccsb.ro','http://turambarr.blogspot.com','79.114.190.130','2008-02-11 01:42:50','2008-02-10 23:42:50','Which reminds me: maine adica azi e luni adica incepe saptamana si e doo noaptea si eu nu am terminat raportu shi nu e raport secsual baga-mi-ash extensia penila in el de raport non-secsual. \r\n\r\nAuzi, bre, daca mai zici o data sa nu ne plangem ca e luni, vin la Cluj si te fac martzi.\r\n\r\n:(  :rant:',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(15818,988,'Andreea MKT','supergirgir@yahoo.com','http://marlahermina.deviantart.com/gallery/','82.77.126.254','2008-02-12 11:01:14','2008-02-12 09:01:14','Mah, deci unele femei s-ar cam marita ca au o varsta si voi stati si fluieratzi a paguba. Deci nu toate femeile e niste snoabe proaste care vor haine, cosmetica si se schimonosesc in oglinda. Unele vor sa se marite ca sa fie sigure ca o sa tzina animalul langa ele si pe mai incolo. Si daca o sa aiba copil, sa se asigure ca animalul tot acolo va fi.\r\n\r\nEu nu cer sfatul la outfituri.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; InfoPath.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(15781,988,'Usim','mihaimitan@gmail.com','','87.237.108.33','2008-02-11 23:17:37','2008-02-11 21:17:37','Gura pacatosului adevar graieste! Dar si urechea (ochiul) cititorului de \"glob\" groparesc se regaseste in aceste cuvinte care ne doare.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; .NET CLR 2.0.50727)','',0,0),(15814,988,'Andreea','puistrulet2003@yahoo.com','http://n/a','81.196.150.196','2008-02-12 10:12:40','2008-02-12 08:12:40','Salut Groparule,\r\n\r\nVin cu un sfat: foloseste Cif Active :), daca vrei sa recuperezi ceva din vase...\r\n(rezolva problema de la radacina, vasele noi, cumparate de tine vor ajunge la fel de rau in 2 luni ca cele de acum);\r\n\r\nBtw, nu ar trebui sa consideri ca papara cu ceapa e o mancare exclusiv a burlacului (nu-i fair, sau Fairy :) ), ce daca si mie imi place papara?\r\n\r\nO zi faina iti doresc si remember, Cif Active.....',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(15815,988,'li','alina_livia_lazar@yahoo.com','http://www.alinalivialazar.blogspot.com','89.136.204.179','2008-02-12 10:20:47','2008-02-12 08:20:47','io nu Ã®nÅ£eleg de ce de la o vreme Ã®ncoace Ã®i faci reclamÄƒ lui Oedip (nu Äƒla cu mÄƒmica). adicÄƒ, te vÄƒd om serios ! :)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(15659,986,'nenea &raquo; Blog Archive &raquo; Filmul in care mi-ar placea sa traiesc','','http://www.nenea.ro/?p=651','77.81.4.72','2008-02-10 13:15:08','2008-02-10 11:15:08','[...] mearga mai departe leapsa la Groparu, DeMaio, Adelaida, [...]',0,'1','Incutio XML-RPC -- WordPress/2.3.3','pingback',0,0),(15778,984,'Veverita','web.resort@yahoo.it','http://doipedoi.com','89.123.3.9','2008-02-11 23:07:11','2008-02-11 21:07:11','super tare :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(17160,1013,'cepanamea','icgel@yahoo.com','http://www.cepanamea.ro','92.80.32.118','2008-02-26 16:51:50','2008-02-26 14:51:50','Offfff, bautura asta bat-o vina! E buna cand o bei si asa de rea cand o lasi... Trezeste-te, domnule Gropar, ca avem treaba...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(17248,1002,'ametzitul','','http://ametzitul.wordpress.com','62.217.236.12','2008-02-27 08:38:06','2008-02-27 06:38:06','yes, u can piss (peace,man...) :)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(17249,1002,'nenea','nenea77@yahoo.com','http://www.nenea.ro/','81.181.209.170','2008-02-27 08:48:15','2008-02-27 06:48:15','refill al cutiei cu raspunsuri afirmative',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; IEMB3; IEMB3)','',0,0),(17365,1002,'Turambar','mirel@ccsb.ro','http://turambarr.blogspot.com','84.232.191.214','2008-02-28 09:59:44','2008-02-28 07:59:44','Pe mine ma strigau ASAP cand eram mic. Ma miscam cu viteza luminii stinse. Ma duc eu sa ridic premiu. ASAP.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(17163,1013,'mirra','','','83.103.137.234','2008-02-26 17:16:21','2008-02-26 15:16:21','lasa ca tot ii buna si postarea asta,macar stim ca esti bine si ca nu ne-ai uitat!\r\n:)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(17343,1002,'julius constantinescu','julius@universitateacraiova.ro','http://www.7plus.ro/?arhiva=28/02/2008&#38;id=2928','84.232.169.56','2008-02-28 03:04:09','2008-02-28 01:04:09','Am stiut din capul locului ca-i manarit concursul.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(17344,1002,'julius constantinescu','julius@universitateacraiova.ro','http://www.7plus.ro/?arhiva=28/02/2008&#38;id=2928','84.232.169.56','2008-02-28 03:07:22','2008-02-28 01:07:22','@george: mori!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(17199,1013,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2008-02-27 00:28:51','2008-02-26 22:28:51','Apai, mo Usime... dupa cum s-arata finantele, nu prea degraba! Ca tre sa gat prima data scoala de soferi, mah, si-apai sa ma hotarasc ce fac cu viata mea: sa o fac lunga si fericita, sau si mai lunga si si mai groasa?\r\n\r\nDeocamdata stai sa dea coltu ierbii ;;)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(17202,1002,'cezar','bivolaru_cezar@yahoo.com','','86.55.226.135','2008-02-27 00:52:41','2008-02-26 22:52:41','alianta DA, sa te pisi pe ea',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(17206,1002,'octavian','octavian.arnaut@gmail.com','http://www.yacana.ro/blog/','81.181.214.232','2008-02-27 01:19:49','2008-02-26 23:19:49','YES',0,'1','Mozilla/5.0 (Macintosh; U; Intel Mac OS X; en) AppleWebKit/523.12.2 (KHTML, like Gecko) Vienna/2.2.2.2212','',0,0),(17216,1002,'ramonici','','','89.33.174.82','2008-02-27 02:49:39','2008-02-27 00:49:39','ala-i Base cand era un pic mai tanar?',0,'1','Opera/9.10 (Windows NT 5.1; U; en)','',0,0),(17306,1013,'Usim','mihaimitan@gmail.com','','87.237.108.33','2008-02-27 18:27:04','2008-02-27 16:27:04','Pai sa vii si-o sa unim neste uichend-uri.\r\n\r\nMai mult: in Bucuresti ierba deja a iesit. Berea ie de la mine. Si nici carnet nu tre\' sa ai ca Matizu\' poate fi condus si de prietena mea. S-a mai intamplat!\r\n\r\nAsa ca nu mai ai motive de intarziere.......\r\n\r\nCat despre viata, de lunga poate fi cat de groasa, de suptire sa nu fie prea scurta.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; .NET CLR 2.0.50727)','',0,0),(17301,1002,'WhiteWolf','contact@white-wolf.ro','','89.32.115.105','2008-02-27 16:51:49','2008-02-27 14:51:49','<b>Give Piss A Chance</b> featuring Groparu :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(17299,1002,'IepurasulAtomic','praetorian21uk@yahoo.com','http://iepurasulatomic.weblog.ro','192.100.130.7','2008-02-27 16:34:58','2008-02-27 14:34:58','Tu chiar nu puteai sa treci peste ziua de astazi fara sa te iei de mediocritatea mea? De la 12.03 de cand George o nimerit raspunsu\' plang. De fapt nu, fie de la 12.07 de cand l-ai declarat castigator, fie de la 12.36 cand o acceptat sa-si ridice premiu\' \"ASAP\". Sau la 12.07 mi s-o umezit putin ochii si la 12.36 am inceput sa bocesc cu lacrimi de dinozaur extinct. Ni, vezi ce mi-ai facut?! Nici nu mai stiu ce-i cu mine. Sa-tz fie rusine.\r\n\r\nPS: Cine-i ASAP asta care tre\' sa ridice premiu\' in locu\' lu\' George? Acuma is gelos pe toti, sper ca-i evident.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(17180,1013,'Usim','mihaimitan@gmail.com','','87.237.108.33','2008-02-26 21:30:47','2008-02-26 19:30:47','Da\' in Bucuresti, in care uichend vii sa bem, ca-i tot promis?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; .NET CLR 2.0.50727)','',0,0),(17263,1002,'dush','tirbushon@gmail.com','http://dushrece.blogspot.com','193.230.155.70','2008-02-27 10:59:27','2008-02-27 08:59:27','ei se pipileaza cumulativ pe votul meu da?:D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(17268,1002,'cilu','','','80.97.64.238','2008-02-27 11:37:10','2008-02-27 09:37:10','E o reclama la mazare la badoc (peas/piss).',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(17270,1002,'george','reallyinsane@gmail.com','','193.138.195.202','2008-02-27 12:03:03','2008-02-27 10:03:03','YES we CAN!\r\nObama and stuff...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(17271,1002,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-02-27 12:07:26','2008-02-27 10:07:26','And the beer goes to...\r\n\r\nGeorge!!!\r\n\r\nFelicitari! Da, e Yes, we(e) can! Wee wee - pishu mic. \r\n\r\nName the place and the weekend;)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(17276,1002,'george','reallyinsane@gmail.com','','193.138.195.202','2008-02-27 12:36:37','2008-02-27 10:36:37','Deci consider ca am fost lasat sa castig, sarada era suspect de evidenta.\r\nPremiul insa il voi revendica ASAP. Poate chiar undeva pe teren neutru, in Oltenia (?!) maybe',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(17286,1002,'Andreea MKT','supergirgir@yahoo.com','http://marlahermina.deviantart.com/gallery/','82.77.126.254','2008-02-27 14:32:54','2008-02-27 12:32:54','deci era prea inteligenta imaginea',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; InfoPath.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(17287,1002,'octavian','octavian.arnaut@gmail.com','http://www.yacana.ro/blog/','89.238.208.10','2008-02-27 14:36:59','2008-02-27 12:36:59','cine-i george?',0,'1','Mozilla/5.0 (Macintosh; U; Intel Mac OS X; en) AppleWebKit/523.12.2 (KHTML, like Gecko) Vienna/2.2.2.2212','',0,0),(17293,1002,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-02-27 15:24:44','2008-02-27 13:24:44','Apai, ca sa zic asa, George e un dÄƒjtept!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(17378,1002,'cronicaru\'','tzone_a@yahoo.com','http://cronicaru.blogspot.com/','193.230.230.101','2008-02-28 12:58:40','2008-02-28 10:58:40','e yes-man-ul de cioroianu?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(17444,1014,'ametzitul','','http://ametzitul.wordpress.com','62.217.236.12','2008-02-29 10:14:44','2008-02-29 08:14:44','bine ca mi-ai amintit...\r\no incurcam :)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(17445,1014,'mo','verde_poveste@yahoo.com','','194.126.220.22','2008-02-29 11:06:45','2008-02-29 09:06:45','Nush de ce primavara se practica obiceiurile cele mai sinistre. Se taie mieii, care n-au alta vina decat ca sunt foarte buni, mai ales stropiti cu vin in cuptor, se dau martisoare dintr-alea cu floricele uscate trase in plastic sau trandafiri facuti din sarma si plasa de ciorap de un leu si in Ardeal se agreseaza gagicile olfactiv cu apa de colonie stropita in cap..... care-i treaba cu obiceiu\' asta? \r\nSa fie aluzii de genu\': \"fa dush, tu!!\" sau \"am venit cu deratizarea, sa starpesc tat ce misca sub soare de secs feminin\" sau \"ui aftershave, ca si-asa stiu ca iti razi mustata\" sau \"in gradina am o floare, da\' o dau cu shprei si moare\" sau......?!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1)','',0,0),(17399,1002,'sorana','soranacindrea@yahoo.com','','92.84.16.147','2008-02-28 17:32:37','2008-02-28 15:32:37','Off rapid concurs :(( dar imaginea este bestiala: diferenta dintre bere si pishare este de 5 minute!!! orice legatura cu personalitatiile in viata este pur intamplatoare si fantasmagorica:))',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1)','',0,0),(17400,1009,'sorana','soranacindrea@yahoo.com','','92.84.16.147','2008-02-28 17:46:03','2008-02-28 15:46:03','Are dreptate Laura!! Si apoi au si tupeul sa le schimbe forma asta ca sa nu mai fie grad de commparatie intre ele si berea orgasmata! Sa producem portofele domne\'! pe post de moartea pasiunii mama ei de gulareala:D',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1)','',0,0),(17453,1014,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-02-29 14:01:35','2008-02-29 12:01:35','Iti spun io cum vine faza cu femeile!\r\n\r\nOrice le-ai face, cat de rau - merita. Mai ales daca le duci flori, te caÅ£eri pe ele, le sufoci cu pupÄƒceli si le dai voie sa te care acas\' din crajma unde te-or dibuit ca bei fara ele (the last one is my personal favorite).',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(17455,1015,'ametzitul','','http://ametzitul.wordpress.com','62.217.236.12','2008-02-29 15:13:57','2008-02-29 13:13:57','ia-tzi consoarta...\r\nda\' ai grija sa nu fie shi ea o rata in plus :)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(17458,1015,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-02-29 15:26:56','2008-02-29 13:26:56','Stii vruna cu dobanda mica? ;;)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(17459,1015,'ametzitul','','http://ametzitul.wordpress.com','62.217.236.12','2008-02-29 15:37:27','2008-02-29 13:37:27','o gaseshti intre sfantu\' graal shi piatra filosofala :)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(17461,1014,'mirra','','','83.103.137.234','2008-02-29 16:48:26','2008-02-29 14:48:26','si pt ca in anii bisecti se dau martisoare barbatilor,pt tine un pachet de tigari!!!! si un jnur impletit rosu cu alb legat de o sticla de tzuica!!!:)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(17462,1014,'mirra','','','83.103.137.234','2008-02-29 16:51:22','2008-02-29 14:51:22','@mo: chestia cu stropitul e doar de fatada, de fapt ideea e sa intri in casa omului  sa mananci si sa bei moca!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(17463,1016,'mirra','','','83.103.137.234','2008-02-29 16:56:04','2008-02-29 14:56:04','Sa traiasca \"La multi ani!\"/ Sa aiba mereu multi bani!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(17470,1016,'Marieana','gmariana_s@yahoo.com','','81.24.23.5','2008-02-29 18:05:36','2008-02-29 16:05:36','MULTUMESC, sunt f impresionata mai ca plang!\r\nImportant e ca tu sa ne ramai asa de tanar cum esti si creativ ca tatzi scorpionii pe care ii stiu si sa o iubesti tu pe aia mica!\r\nDe aia te iubesc eu pe tine!\r\nTe pup dulce!\r\nMarieana',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(17472,472,'banalu','ra_macovei@yahoo.com','','79.112.40.141','2008-02-29 18:14:30','2008-02-29 16:14:30','totolotzi - aceleasi bobitze uscacioase.\r\n\r\nciuprucotzele - manushi pentru suflecat trabucul.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(17479,979,'Miss Bates','nesciovos@yahoo.com','','194.102.120.59','2008-02-29 19:55:46','2008-02-29 17:55:46','Hai, mai , nene Groparule, crezi ca fetele au interzis la citit Sven Hassel &amp; comp. si ca n-au voie de la primarie sa se intereseze si de altceva dacat funtitze roz si bigudiuri ? Tzzz, ma dezamagesti, nu te credeam misogin..',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.9','',0,0),(17481,1015,'Laura','mars1953@web.de','','84.160.114.151','2008-02-29 20:37:36','2008-02-29 18:37:36','Balzac nu numai ca lasa lumii 130.000 de franci datorii, ci si o femeie care le plati...',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(17382,1013,'Constantin','bigzander@yahoo.com','http://pescuitvrancea.ro','195.245.88.200','2008-02-28 13:48:53','2008-02-28 11:48:53','Pai eu am auzit de niste sefi care erau si unul si alta ! \r\nSa fie adevarat?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(17541,1016,'Acidalia','acidalia@gmail.com','','85.121.122.151','2008-03-01 10:39:41','2008-03-01 08:39:41','Din groapa intelepciunii tale ;)) ai scos un martisor care sa te scuteasca de orice cheltuiala;))...de aceea te-am si recompensat cu-n sut in fund pe lista finala a roblogfest-ului ;) \r\nSper sa te revansezi fata de mine;) sa-i dai de baut prietenului meu si lui Aia Mica ( cu ea te-ai scos, ca nu stie sa bea;)), care m-a adus in menajeria ta;)) si sa nu uiti de teoria evolutionismului a lui Darwin sau de conceptiile teologice ale creationismului...asta pentru ca se apropie postul si sunt sigura de incercarea ta de a-ti chinui iar matul;))...nu este numai atat;) De la o vaca poti beneficia de mai multe avantaje decat de la un om;))...totusi, nu sunt pe aceasi scara evoultiva:( ... tu stii asta, deci nu mai incuraja tineretul in actiuni pagubitoare lui :D \r\nIti doresc atat tie cat si lui Marieana o primavara care sa va umple de Lumina si sa cresteti odata cu ea:)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(17387,1002,'candid','adi.covaci@jumpeye.com','http://www.aicarteaiparte.ro','85.186.103.6','2008-02-28 15:06:11','2008-02-28 13:06:11','Iti dau eu berea numa sa vii la baute! :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(17391,1002,'andreea m','andreea_molocea@yahoo.com','http://andreeamolocea.wordpress.com/','89.122.244.159','2008-02-28 16:34:01','2008-02-28 14:34:01','aaah, eu aveam doua idei in capusor. \r\n1: bere la conserva. O bei si apoi faci pipi mult.\r\n2: cu cat esti mai tanar cu atat ai tinta mai buna.\r\n\r\nps: Trebea sa mai lasi o zi concursul, nu c-as fi castigat si pt fun.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(18068,1025,'Basty','sebastian@centre-roumain.fr','http://basty.wordpress.com','82.77.43.102','2008-03-11 11:41:25','2008-03-11 09:41:25','Asigura-te ca-l strici la loc pentru vizita de miercuri ( dupa ora 18:00 ). Sa nu vie baietii degeaba ca nu e frumos.\r\n\r\nA. Si sa-i astepti cu cozonaci cu lapte. Am inteles ca le place.',0,'1','Mozilla/5.0 (Macintosh; U; Intel Mac OS X; en) AppleWebKit/523.12.2 (KHTML, like Gecko) Version/3.0.4 Safari/523.12.2','',0,0),(18069,1025,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-03-11 11:45:50','2008-03-11 09:45:50','Ma gandeam sa iau neste reviste de la Martorii lu Jehova si sa ma apuc sa le impart!!! N-ar fi tare? (plus ca stau la 4, si vor trebui sa urce dijaba)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(18011,1025,'ametzitul','','http://ametzitul.wordpress.com','62.217.236.12','2008-03-11 08:48:37','2008-03-11 06:48:37','pune mana p-o carte, mah...\r\nfa un poker, un whist... ceva :)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(17716,1012,'ametzitul','','http://ametzitul.wordpress.com','62.217.236.12','2008-03-03 08:27:38','2008-03-03 06:27:38','a trecut, sari la cadouri de 8 martie :)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(18014,1025,'oedip','oedip74@gmail.com','http://oedip.blogspot.com','89.137.99.163','2008-03-11 09:32:50','2008-03-11 07:32:50','auz mah, de cand are modemu tau buton pauar? ce pauar?! unde vezi tu pauar?!!\r\n\r\nPAUAR TU DA PIPAL!!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(17589,1015,'catalin','','','201.231.166.3','2008-03-01 21:34:36','2008-03-01 19:34:36','ai cumnat neamt, sora e in germania...dece nu te lipesti la un credit 4% acolo si lichidezi tot in romania si platesti ratele la nemti si gata?!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(17790,316,'Maineblog','','http://http:/mymaine-vacations.info','75.33.205.230','2008-03-04 22:40:39','2008-03-04 20:40:39','<strong>Come Visit Maine...</strong>\n\nInformation on Vacationing in Maine...',0,'1','','trackback',0,0),(17784,1019,'O doamna care este','plenarapitici@yahoo.com','','86.122.8.188','2008-03-04 18:24:39','2008-03-04 16:24:39','Multumesc frumos de urari. Sa ne fii prieten cel putin pana-n toamna :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(17788,1019,'catalin','solo@xsolo.biz','http://xsolo.biz','201.231.166.3','2008-03-04 22:10:37','2008-03-04 20:10:37','Iti mai lipseste sa faci si o manea si gata.... :-)) mai Giovani Groparu Grandiosu :-)))))))))))))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(17772,1018,'retoric','acalarasu@gmail.com','http://adriancalarasu.wordpress.com','62.217.241.242','2008-03-04 14:21:58','2008-03-04 12:21:58','corec!\r\n:))',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(17773,1018,'baghy','baghy83@lycos.it','http://www.baghy.info','78.12.11.42','2008-03-04 15:09:59','2008-03-04 13:09:59',':)))))))))) are u sure?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(17776,1017,'WarSongu','stygos@yahoo.com','http://www.warsongu.wordpress.com','86.104.198.22','2008-03-04 15:37:07','2008-03-04 13:37:07','tare chitara, nui genu eu de muzica, dar tare rau pe chitara omu. brava!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; .NET CLR 2.0.40607)','',0,0),(17778,1018,'banalu','ra_macovei@yahoo.com','','79.112.40.148','2008-03-04 15:48:05','2008-03-04 13:48:05','m-am uitat si pe Yahoo weather si pe gugal earth si pe site la Romica Jurca, am citit in stele, am dat in boghi si in argint viu, am citit in oroscop, da\' de-a dracu tot o fo frig si innourat (cu doi de n :p) de baba mea. adica az.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(17779,1018,'psaico','blog@psaico.info','http://www.psaico.info','89.137.126.168','2008-03-04 16:03:55','2008-03-04 14:03:55','eu imi aleg babeul (beibul) anul asta :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(17781,1018,'mirra','','','83.103.137.234','2008-03-04 16:29:22','2008-03-04 14:29:22','eu intotdeauna fac asta!:)\r\nsi nu m-am inselat niciodata!:)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(17805,1019,'ametzitul','','http://ametzitul.wordpress.com','62.217.236.12','2008-03-05 08:28:42','2008-03-05 06:28:42','sa-i traiasca!!!',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(17794,1018,'macabroo','raduccc@yahoo.com','http://rezistenta.blogspot.com','82.76.52.94','2008-03-05 02:01:32','2008-03-05 00:01:32','Daca va alegeti mos anu\' asta, verificati daca mai sunt disponibili cu Rolls in Pipera.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; en-GB; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(17763,1017,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-03-04 09:49:30','2008-03-04 07:49:30','@ macabroo: deci claro ca am sa preiau leapsa, finca io - printre multe altele  - fusai si ghid geografic, si nu numai de geografie anatomica femenina!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(17764,1017,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-03-04 09:50:36','2008-03-04 07:50:36','...atata numa ca zilele astea - ui, is coplesit de munca, si nu mai am vreme sa si gandesc; da\' estimesc ca imi revin la parametri normali in vo 2 zile, asa.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(17737,1017,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-03-03 14:18:48','2008-03-03 12:18:48','Tu! Voi! Ca va stiu io pe voi cum sunteti!!!\r\n\r\nMeseriasi, claro.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(17911,637,'ulise','','http://www.ullise.wordpress.com','172.164.65.172','2008-03-07 23:06:52','2008-03-07 21:06:52','felicitari, mai marfa decat Cartarescu esti, dar el a fost primul cu ideea, nu ma pot hotara care din voi doi e mai tare :)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; SLCC1; .NET CLR 2.0.50727; Media Center PC 5.0; .NET CLR 3.0.04506)','',0,0),(17915,1024,'alex','','','89.43.103.44','2008-03-08 02:57:14','2008-03-08 00:57:14','precine, te-ai cam nasolit.... nu mai esti ce ai fost si ne-ai dezamagit in tm.... pcat. trebe sa mai vii la un rehab ca nu se mai poate cu tine... BEST WHISES. U KNOW WHO, THE 2 OF US',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(17923,1024,'Andreea MKT','supergirgir@yahoo.com','','89.43.186.64','2008-03-08 10:25:43','2008-03-08 08:25:43','dragoste faci in postul Pastelui?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(18044,1024,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-03-11 10:45:24','2008-03-11 08:45:24','Deci daca nu pescuiesti, e clar: ai nevast fain!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(18159,1021,'ametzitul','','http://ametzitul.wordpress.com','62.217.236.12','2008-03-12 08:40:59','2008-03-12 06:40:59','mda... e de tzinut minte asta cu meteosensibilitatea :)\r\nbine ca nu locuiesc in Norvegia... or fi ei mai bogatzi, da\' e cam umezeala...',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(19952,1045,'M@riansky','mariankee4@yahoo.com','http://mariansky.dubios.ro/','86.122.94.221','2008-03-28 17:03:35','2008-03-28 15:03:35','Omu\' s-a dus dar ce-a facut ramane :!:',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; InfoPath.2)','',0,0),(19273,1034,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-03-20 14:38:54','2008-03-20 12:38:54','Deci post de ala TINETI VOI.\r\n\r\nCa io NU.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19833,1041,'ametzitul','','http://ametzitul.wordpress.com','62.217.236.12','2008-03-26 08:39:25','2008-03-26 06:39:25','nu mah... culmea \"dentismului\" e sa-tzi scoata o masea laparoscopic, cu intrare prin fund :)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(19834,1040,'Hammer','hammer@alpinet.org','','81.196.168.118','2008-03-26 08:40:04','2008-03-26 06:40:04','Ce mod delicat de a spune \"nu, multumesc\":-)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(19910,1043,'Dru','delia.adriana@gmail.com','','82.77.126.134','2008-03-27 18:45:42','2008-03-27 16:45:42','Soia sucks. BIG time.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(19837,1040,'Flamandu\'','staulalucru@yahoo.com','','82.77.193.186','2008-03-26 09:20:25','2008-03-26 07:20:25','no, lasa, gasasc io altu cu care sa ma pretinesc si sa dea un pui la rotizor.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(18500,1028,'natty','natty2277@yahoo.com','','86.106.49.165','2008-03-15 09:36:57','2008-03-15 07:36:57','da\' el, el te iubeste pe tine?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(18501,1028,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2008-03-15 09:43:51','2008-03-15 07:43:51','Cand am inceput sa urlu ieri la el s-o facut mic. Sper sa nu ia facaletzu data viitoare cand vin la el tarziu si mirosind a beutura, cu urme de ruj pe guler!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(18158,1021,'Hammer','hammer@alpinet.org','','81.196.168.118','2008-03-12 08:15:22','2008-03-12 06:15:22','Singurul lucru mai crancen decat un sef e secretara lui...si sefii au intotdeauna secretare. \r\nFiziologic este imposibil sa strigi mai tare decat un sef. \r\nSeful e vrajitorul ala care te transforma instant in diplomat, actor, politician, utilaj, carpa de sters pe jos, butoi cu pulbere, canal de stiri si, de ce nu, baiatu\' care aduce pizza. Daca e un sef bun, te transforma in toate astea simultan!',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(17898,1023,'PhenoBarbieDoll','poisongirl94@yahoo.com','http://blog.360.yahoo.com/poisongirl94','193.230.230.101','2008-03-07 10:33:51','2008-03-07 08:33:51','ah, crama lu Titi... memories...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(17809,1012,'iohonney','redhotbiglips@yahoo.com','http://iohonney.blogspot.com','86.121.108.242','2008-03-05 10:11:36','2008-03-05 08:11:36',':)))...romantism 100%..macar ai incercat..sunt curioasa  ce urari ai pregatite pentru 8 martie..:D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(17810,1018,'ira','iry62002@yahoo.com','','79.112.105.52','2008-03-05 10:55:57','2008-03-05 08:55:57','Hai ca asta e tare:))A mea e maine si de-al draq nu ma uit la vreme:P',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; SIMBAR={4ED7BADF-F5DB-4808-8EBB-36A73D02F00C}; .NET CLR 1.1.4322)','',0,0),(17903,1023,'Brigitte','briqo_o@yahoo.com','','82.77.126.254','2008-03-07 14:11:33','2008-03-07 12:11:33','poi mai gropare nu mi te lauzi ca organizezi chefuri babane pt omuleti dragi...de voie de nevoie? ;;)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; FDM; .NET CLR 1.1.4322; .NET CLR 3.0.04506.648; .NET CLR 3.5.21022)','',0,0),(17870,1023,'Turambar','mirel@ccsb.ro','http://turambarr.blogspot.com','79.114.190.155','2008-03-06 18:46:21','2008-03-06 16:46:21','Stai asha, sa intzeleg: concluzia emisiunii este ca Sibiul este in Cluj, langa Intorsura Buzaului, cu iesire la mare, in Bulgaria. Si are un pod al mincinosilor. In portul Manastur, presupun.\r\n\r\nAha. Gata. Am intzeles. Saptamana viitoare vin la Cluj, si vroiam sa stiu daca-mi iau colacu cu mine. O Ardeeeeaaaal, O Ardeeeeeaaal, tuuuuuu poooort iubiiiit. Tu Ardeeaaaaal Tu Ardeaaaal Pamant bulgariiiiitttt.... \r\n\r\n:p',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(17858,1023,'.marius','marius@perijoc.com','http://marius.wirelessisfun.com','89.36.21.79','2008-03-06 13:01:21','2008-03-06 11:01:21','Stii ce ar merge bine cu postul tau? niste zama de muraturi... daca ma intelegi...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9b3) Gecko/2008020514 Firefox/3.0b3','',0,0),(17859,1020,'.marius','marius@perijoc.com','http://marius.wirelessisfun.com','89.36.21.79','2008-03-06 13:03:18','2008-03-06 11:03:18','Io cred ca a descris posesoru de dacie... dar deja e semantica...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9b3) Gecko/2008020514 Firefox/3.0b3','',0,0),(17860,1019,'.marius','marius@perijoc.com','http://marius.wirelessisfun.com','89.36.21.79','2008-03-06 13:04:40','2008-03-06 11:04:40','Multumim pentru pizza doamna crivatz ;-)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9b3) Gecko/2008020514 Firefox/3.0b3','',0,0),(17861,1023,'Flavius','flaviusb@gmail.com','','212.93.158.146','2008-03-06 13:09:43','2008-03-06 11:09:43','Desteptule, schimba pluralul din \"Nascut din spermatozoizi campioni\"! Ovulul in majoritatea cazurilor este fecundat de un singur spermatozoid. Google it!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(17862,1023,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-03-06 13:15:50','2008-03-06 11:15:50','Io-te tezauru\' de IQ!\r\n\r\nPoate asa-i la voi, la oameni.\r\n\r\nIo nuz om.\r\n\r\nIoz dÄƒjtepÅ£i!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(17867,1019,'Aceeasi doamna care este','plenarapitici@yahoo.com','','86.122.8.188','2008-03-06 17:47:54','2008-03-06 15:47:54','Sa va fie de bine! :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(17864,1023,'FlamÃ¢ndu\'','','','82.77.193.186','2008-03-06 15:02:07','2008-03-06 13:02:07','Io numa ontrebare vreau sa pui. Mai ezista in Sibiu rotiseria aia de la podu\' mincinosilor?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(17865,1023,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-03-06 15:06:23','2008-03-06 13:06:23','Hmmm... mo, deci in ce parte a Podului? Unde e crama lu Titi si Mielu Alb, sau pe partea cu Casa Luxemburg? Sau zici de elelalte doua, una de langa Muzeu\' Farmaciei si cealalta langa fosta redactie Evenimentul Sibian (unde am prestat si eu, cu oroare)?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(17866,82,'lia','','','129.20.192.236','2008-03-06 15:24:40','2008-03-06 13:24:40','copile, esti demential! sunt  la lucru ca altfel m-as tavali pe jos ca sa pot rade linistita. continua pe aceeasi linie! apropo, stau in franta de cativa ani, cred ca ai facut turul gafelor care nu trebuie facute cu un francez. mai lipsea poate sa te iei de-un om politic faimos (gen mitterand) si era gata! oricum, ai talent deci da-i bataie in continuare! ciao',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; fr; rv:1.8.0.4) Gecko/20060508 Firefox/1.5.0.4','',0,0),(17873,1023,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2008-03-06 19:49:50','2008-03-06 17:49:50','Vii la Cluj mah??? Tre\' sa bem! Aia-i clar.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(17849,53,'Nascut din spermatozoizi campioni &raquo; Blog Archive &raquo; Ce am mai patit in ultima vreme','','http://www.groparu.ro/?p=1023','82.103.137.253','2008-03-06 09:46:47','2008-03-06 07:46:47','[...] slaid de PowerPoint, Cluj-Napoca o apÄƒrut, mÄƒi frate, aÅ£Äƒ lÃ¢ngÄƒ Burgas!!! Burgas care, ultima datÄƒ cÃ¢nd am verificat, era fix, daâ€™ fix la graniÅ£a cu Marea [...]',0,'1','Incutio XML-RPC -- WordPress/2.1.2','pingback',0,0),(17885,1023,'Turambar','mirel@ccsb.ro','http://turambarr.blogspot.com','79.114.190.155','2008-03-06 22:44:54','2008-03-06 20:44:54','Sambata si duminica viitoare. Vin sa fac niste focus grupuri si sa va izbavesc de iluzii. Ne auzim sapt viitoare, sa vedem cum dam unul de altul si unde si cat bem :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(17815,1020,'ametzitul','','http://ametzitul.wordpress.com','62.217.236.12','2008-03-05 13:25:04','2008-03-05 11:25:04','vine de la Sandelu, da\' n-au shtiut francezii cum sa scrie...\r\nn-a vazut ca shi pe Eugen Ionescu l-au scris Ionesco?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(17817,1020,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-03-05 14:07:32','2008-03-05 12:07:32','...asta ca sa nu mai zicem nimic de Sioran!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(17818,1020,'Hammer','hammer@alpinet.org','http://alpontos.wordpress.com','86.120.55.79','2008-03-05 14:09:53','2008-03-05 12:09:53','Schimba cam des astia identitatea vizuala a Daciei :-( Pacat, in umila mea speranta speram sa invatam ceva de la cehi si cum au stiut ei sa valorifice traditia marcii lor.\r\nNah, o sa fim tovarasi de suferinta si in mod clar o sa ai despre ce scrie:-) Te pomeni ca blandareshti si pe forum? :-))',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(17819,1020,'Hammer','hammer@alpinet.org','http://alpontos.wordpress.com','86.120.55.79','2008-03-05 14:14:53','2008-03-05 12:14:53','Pai si denumirile care le dau modelelor sunt si alea jenante. Puteau sa ii zica Dacia Ilarion sau Nastafa...le suna bine si strainilor, eh? Oricum le rebranduim noi: Solnitza, Golanul si Sandelul:-)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(17881,1020,'Ionut','ioau@yahoo.com','','89.34.225.25','2008-03-06 22:06:20','2008-03-06 20:06:20','Eu cred ca au vrut sa-l faca cat mai greu de furat :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(17879,1023,'nenea cosmos','domnu_cosmos@yahoo.com','http://www.nenea.wordpress.com','193.231.82.119','2008-03-06 21:13:24','2008-03-06 19:13:24','deci nemtalaii au probleme cu hartile. de aici trag concluzia ca ei au supraestimat costurile unei calatorii koln - cluj dat fiind ca clujul pe care il stiu ei e pe la dunare, deci in realitate se va ieftini si mai tare biletul ieftin la cursele ieftine. norocosilor, o sa mergeti la koln cu banii de gogosi. iar nemtii o sa vina in cluj in slapi si slip si o sa caute litoralul. ii intimpinati la aeroport cu aloha si ii dati cu pluta pe somes pina se satura.\r\n\r\nieftine rau cursele alea...',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; InfoPath.1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648)','',0,0),(17826,1019,'psaico','blog@psaico.info','http://www.psaico.info','89.137.126.168','2008-03-05 18:50:56','2008-03-05 16:50:56','poet te faci ma, gropare :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(17850,1023,'ametzitul','','http://ametzitul.wordpress.com','62.217.236.12','2008-03-06 09:59:27','2008-03-06 07:59:27','ce faci mah, te balbai? sau n-ai apucat sa editezi? :)\r\nshi eu mai scriu posturi acsa shi le pun la job, shi mai greshesc la copiere...',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(17839,1020,'baghy','baghy83@lycos.it','http://www.baghy.info','78.12.11.42','2008-03-06 00:46:12','2008-03-05 22:46:12','ai descris perfect posesorl de Sandero',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(17852,1023,'ametzitul','','http://ametzitul.wordpress.com','62.217.236.12','2008-03-06 10:09:14','2008-03-06 08:09:14','doar daca l-ai inventat tu :)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(17851,1023,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-03-06 10:05:31','2008-03-06 08:05:31','Ce, ba, ce! E vina mea ca pana si wordpressu\' ii mai prost ca mine? ;;)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(17642,1015,'ovi66','ovidiulechintan@yahoo.com','http://ovidiu666.wordpress.com/','79.116.89.91','2008-03-02 11:50:47','2008-03-02 09:50:47','ai rate, esti un important sustinator al capitalismului. banii e facuti sa circule, ca circuitul apei in natura. ;)\r\nasta ti-o spune un alt impatimit al ratelor. pana si viata mea e luata in rate! :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(17652,761,'rocsalana','','','192.129.3.137','2008-03-02 14:09:27','2008-03-02 12:09:27','Bine fratilor ca nu vreti sa reparati relatiile romano-romane, adica Romania-Basarabia, la nivel politco-economic si nu sexual....',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Maxthon; SIMBAR={E0F56E5D-1698-4A0F-8280-01CD46F1F4BF}; .NET CLR 1.1.4322)','',0,0),(17657,578,'banalu','ra_macovei@yahoo.com','','79.112.40.176','2008-03-02 15:32:34','2008-03-02 13:32:34','An perioada an care a-m lucrt pentru compania Ics, am realizat valori banesti an dolars si lei an valoare mare, care a ajutat compania Ix sa andeplineasca contrcte ghem, miez si in special cool cu alte compani an acelas domeniu de activitati comerciale.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(17712,1002,'lilith','marcu_luiza@yahoo.com','http://www.aberatiuni.blogspot.com','83.103.128.60','2008-03-03 07:50:26','2008-03-03 05:50:26','ASAP = as soon as possible! nik nu jtiti, trebe sa va invat io... eeee\r\nsi daca as fi fost in locul lui george i-as fi dat cu ursusu in cap groparelui si-as fi cerut un guiness la halba in le general!',0,'1','Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.1.11) Gecko/20061201 Firefox/2.0.0.11 (Ubuntu-feisty)','',0,0),(17691,1016,'marius','mariusparciu@yahoo.com','http://parciu.blogspot.com/','79.112.88.213','2008-03-03 00:09:29','2008-03-02 22:09:29','Visul oricarei femei?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(17892,1023,'IepurasulAtomic','Praetorian21uk@yahoo.com','http://Iepurasulatomic.weblog.ro','62.217.242.121','2008-03-07 01:24:58','2008-03-06 23:24:58','Stiti ce-am observat eu azi, c-am schimbat prefixu\' si-s in drum spre Bucale?Ca astazi(sau ieri, dak tineti musai sa fiti tipicari),prins in propriile probleme si atentia exagerata ce-am primit-o,deci io caine marsav si aproape iepure, n-am apucat sa vizitez saitu\' cel mai de cultura si mai favorit in toate:groparu.ro. Acu\' c-am remediat greseala vreu sa-ti spun Gropare(si tie Turambare) ca va ganditi numa\' la alcoale si sa va fie rusine si sa va tina Dumnezau naravu\'.Groparule,de nemtzai tai nu spun nika, ca\'s pe tren in conditii europene,insa exagerat de scumpe.Si articolu\' tau numa mi-o amintit ca-s asa de tantalau incat in loc sa zbor 45 de min cu avionu\',am ales sa merg 9 ore cu trenu pentru aceiasi bani.Ave Iepurasu, ca pute prostia in el ca si gangu\' din gara.',0,'1','Mozilla/5.0 (SymbianOS/9.1; U; en-us) AppleWebKit/413 (KHTML, like Gecko) Safari/413 es61i','',0,0),(17749,1012,'cepanamea','icgel@yahoo.com','http://www.cepanamea.ro','92.80.52.27','2008-03-03 22:49:11','2008-03-03 20:49:11','Am incercaaaaaaaaaaaaaaaaaaaat...si mi-a spart ochelariii!!! Unde te gasesc sa-mi cumperi altii noi!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(17750,1017,'macabroo','raduccc@yahoo.com','http://rezistenta.blogspot.com','82.76.52.94','2008-03-03 23:34:26','2008-03-03 21:34:26','Pentru ca vad ca oricum postul asta a alunecat in discutii despre noi profit cu nesimtire: Stimate domnule Groparu\', ati fost invitat de catre Membrii Rezistentei Urbane sa raspundeti la urmatoarea provocare: aveti pe cap un turist strain pentru o zi, numiti cel putin 7 obiective din orasul dvs. pe care i le-ati recomanda respectivului. Mai multe informatii <a href=\"http://rezistenta.blogspot.com/2008/03/un-te-as-duce-mielule.html\" rel=\"nofollow\">aici</a>. Foarte sorry de off-topic.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; en-GB; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(17751,1017,'banalu','ra_macovei@yahoo.com','','79.112.40.2','2008-03-04 00:44:02','2008-03-03 22:44:02','Grozav canticu. Merge numa de-o luni noaptea cat sa uiti de marti dimineata.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(17731,1017,'macabroo','raduccc@yahoo.com','http://rezistenta.blogspot.com','82.76.52.94','2008-03-03 12:42:30','2008-03-03 10:42:30','Da, dar la personal, cine crezi ca e Groparul nostru favorit :D(blushing)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; en-GB; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(17896,1018,'totolici','fun4toto@yahoo.com','http://totolici.wordpress.com/','89.137.69.31','2008-03-07 09:30:10','2008-03-07 07:30:10','eu nu mi-am ales babÄƒ cÄƒ nu-mi plac babele. Au chelea zbÃ¢rcita si miros ciudat.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.0.7) Gecko/20060909 Firefox/1.5.0.7','',0,0),(17723,1017,'james crissilv','jamescrissilv@weblog.roj','http://jamescrissilv.weblog.ro','82.76.149.33','2008-03-03 11:23:42','2008-03-03 09:23:42','daca moare femeile asta e. bravo lui.\r\no zi minunata iti doresc',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(17724,1017,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-03-03 11:44:41','2008-03-03 09:44:41','Vai, deci multumesc la fel! ;)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(17728,1017,'Buciuman','aaa@ggg.com','http://rezistenta.blogspot.com/','86.121.55.92','2008-03-03 12:01:23','2008-03-03 10:01:23','Oau efectul ala standard de apstelat exprima atat de multe. Apropo, felicitari pt robofest pana acum bai.',0,'1','Opera/9.25 (Windows NT 5.1; U; en)','',0,0),(17729,1017,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-03-03 12:03:28','2008-03-03 10:03:28','Taj mah! Sa faceti bine sa castigi!!!\r\n\r\nCa de nu...! Exact.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(18535,912,'titzuka','titzuka@gmail.com','','62.217.213.161','2008-03-15 17:27:17','2008-03-15 15:27:17','noa ce treaba...vaz io aici ca tu esti sibian, spre deosebire de mine care sunt sibianca :D \r\nam trait lovilutia pe viu langa fostul comisariat militar major (ala din Piata Armelor), in curtea mea se perindau de aia cu cagule negre care vroiau sa ajunga la tunelurile de care cica nu stie nimeni si care se afla fix in gradina lu\' tata din spatele casei..pff...acum imi aduc aminte ca spaima de aia n-am tras in viata mea, la un moment dat cand am avut curajul sa iesim din casa (prin 28-29 decembrie) ne-am apucat de curatenie..am aruncat gramezi de cartuse goale din curte, din peretii exteriori ai casei...\r\nsi vaz aci la comentarii si pe Zulea, tot clujean naturalizat (ma, cum ia Cluju\' asta tat ce-i din bucata de creier)\r\nnuma\' bine, Gropare, te-am descoperit tarziu, da\' tot ii bine si-asa rau',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(18536,1021,'nenea cosmos','domnu_cosmos@yahoo.com','http://www.nenea.wordpress.com','193.231.82.119','2008-03-15 17:44:42','2008-03-15 15:44:42','pe sefi ii ai asa cum ii cresti!',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; InfoPath.1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648)','',0,0),(18163,1021,'broodwar','broodwar7@gmail.com','','193.90.144.66','2008-03-12 09:23:03','2008-03-12 07:23:03','io mi-s prin norvegia. ÅŸi cam aÅŸe-i cÄƒ ploua des, da des de tot.\r\nDa aici n-am vÄƒst ÅŸefi, da deloc. Pe ci chiar am vÄƒst numa manajeri.',0,'1','Opera/9.26 (Windows NT 5.1; U; en)','',0,0),(18008,1025,'manole','redtailanda@yahoo.com','http://www.mesterulmanole.wordpress.com','81.181.92.157','2008-03-11 08:25:34','2008-03-11 06:25:34','Ha, ha! nu esti singurul...sau nu sunt singura??? :P',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows 98)','',0,0),(18009,1024,'Turambar','mirel@ccsb.ro','http://turambarr.blogspot.com','84.232.187.240','2008-03-11 08:33:41','2008-03-11 06:33:41','Aha: pescuit. E clar: dai de baut. Aceasta specie numita pescari trebuie abuzata, uzata si percolata cu toata puterea fiintzei noastre de non-pescari naprasnici. O specie care trebuie starpita de mica, sa nu se chinuie. Am avut un shaf pescar, mare om, mare caracter, si el tot banatzan de ardelean de-al vostru de prin Oradea, de la unguri de\'acolo, care era omu painea lu Dumnezeu, nemernicu naibii, ca ma punea sa muncesc, except for one small thing: era pescar. A incercat sa ma convinga si pe mine, dar i\'am zis: pana aici! Am si eu demnitatea mea. Nu o sa ma vezi pe mine pe balta, cershind indurare de la nishte peshti uzi, mici si mai urati decat aia din galantar de la Gostat.\r\n\r\nDupe cum vezi, m-am intors. In Cluj o sa stau doar o zi: sambata. Sosesc dimineata, plec seara, pe la 11 noaptea (cu trenul, sa ma pot odihni). Fac doo focus grupuri. Trebuie therefore sa ne calibram cu egzactitate locatzia, sa putem s-o strecuram in acest program incarcat de mitic ragatzan bicisnic, care vine, fu... pardon, face fegeurile, pune intrebari, mai fu.. mai face unul, sta de vorba si cu clientul si apoi pleaca. Speedy Gonzales, bre, Speedy Gonzales.\r\n\r\n:)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(17965,1023,'danezia','danezia@gmail.com','http://daneziafilme.blogspot.com/','193.231.140.66','2008-03-09 21:12:39','2008-03-09 19:12:39','Unde nu or rataci nemtalaii cluju pe la moldova, ce numai ardealul sa se bucure de zboruri ieftine...?\r\n\r\nahh... da... de fapt nu prea au unde sa aterizeze baietii, poate pe camp, prin porumb!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(18093,1025,'andreea m','andreea_molocea@yahoo.com','http://andreeamolocea.wordpress.com/','89.122.244.159','2008-03-11 12:48:10','2008-03-11 10:48:10','Nu au 4 milioane, call-centeritele. Au 300 euro + bonuri de masa. Minim si din pacate.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19686,1038,'Catzaua','ana.man.fox@gmail.com','','81.180.173.61','2008-03-24 13:44:18','2008-03-24 11:44:18','Irina mama, daca esti, citez, \"bucuresteaca (bleah!)\" cu accent pe \"bleah!\", de ce mai stai acolo, mama draga?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19687,1038,'ametzitul','','http://ametzitul.wordpress.com','62.217.236.12','2008-03-24 13:47:54','2008-03-24 11:47:54','eshti sigur ca verdele ala nu-i muschi, alge sau mucegai? :)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(19688,1038,'WhiteWolf','contact@white-wolf.ro','http://white-wolf.ro','89.39.83.190','2008-03-24 13:49:47','2008-03-24 11:49:47','Tocmai am aflat ca exista (niste) unii care umbla liberi, printre noi, cu faiantza si gresia in cap ? Care se dau si poate ca si sunt alienshi (semnd distinctiv, VERDELE) intre romanashi ?\r\nSau am inteles eu gresit Q.E.D.-ul tau, Gropare ?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19689,1032,'V_for_Whatever','stephanovendetta@yahoo.com','','89.37.114.51','2008-03-24 13:51:37','2008-03-24 11:51:37','In numele populatiei masculine as dori sa multumesc preastralucitului si ilustrului conducator gropar pt. linkuri, si timid, as dori sa-i sugerez in numele progresului si productivitatii, cate o sugestie de site nou in fiecare saptamana, pt. scaderea stresului si stimularea cresterii roadelor muncii.  (bineinteles, interpretabil strict ca factor vizual...in sens estetic...lipsit de orice manifestare corporala ulterioara sau instantanee...pe bune :D)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.6) Gecko/20040113','',0,0),(19430,1036,'hadean','contact@adihadean.com','http://www.adihadean','79.113.58.92','2008-03-21 23:21:43','2008-03-21 21:21:43','call of duty? a spus cineva call of duty?numarul 4 l-am facut in 5 ore consecutive ca aveam deadline.nu am dormit toata noaptea, am vazut numa\' liniute, gloante, trasoare si basinute(astea cred ca erau totusi de la fasole).\r\noricum, de atunci n-am mai jucat nici macar super collapse pe messenger, ca era musai sa ma limpezesc la bibilica.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19804,1041,'hadean','contact@adihadean.com','http://www.adihadean.com','79.113.58.24','2008-03-25 20:41:04','2008-03-25 18:41:04','in copilatia mea antediluviana culmea sexului era sa futzi o tranta si sa ramana gravida.nu stiu azi cum e..',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19935,1045,'IepurasulAtomic','praetorian21uk@yahoo.com','http://iepurasulatomic.weblog.ro','192.100.130.7','2008-03-28 13:03:28','2008-03-28 11:03:28','Nu pot fi de acord cu moartea unui om. Da\' nu pot spune ca m-am dat peste cap de admiratie. Avea el o idee despre cum sa protejeze dulchili nostru grai...romanesc, nu moldovinesc, insa era o idee cam drastica si ushor exagerata. Opinia mea, care este...hac...Dumnezeu sa-l Odihneasca!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(19122,1031,'ametzitul','','http://ametzitul.wordpress.com','62.217.236.12','2008-03-19 08:41:21','2008-03-19 06:41:21','io prefer nea Caisa, cand nu tzin minte nr. de identificare :)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(18388,1021,'ametzitul','','http://ametzitul.wordpress.com','62.217.236.12','2008-03-14 08:33:53','2008-03-14 06:33:53','ba sa shtii ca shefii tai s-ar putea sa citeasca. Io-te cum au ajuns unii ieri la mine:\r\n despre shefi wordpress   2\r\npoate postarea ta o cautau :)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(19304,1035,'hadean','contact@adihadean.com','http://www.adihadean.com','79.113.58.8','2008-03-20 18:40:29','2008-03-20 16:40:29','ioi tu jigmund froida mnicÄƒ ce ieÅŸti:-)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19401,1036,'WhiteWolf','contact@white-wolf.ro','http://white-wolf.ro','89.32.115.80','2008-03-21 17:03:20','2008-03-21 15:03:20','Daca te-ai trezit indignat inseamna ca n-ai visat degeaba sau fara rost :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19391,1036,'Cristina','cristinaaniro@yahoo.fr','','80.221.246.254','2008-03-21 14:28:12','2008-03-21 12:28:12','salu!!!!!\r\nlong time no see!!!! ma bucur sa dau de tine, chiar si asa virtual! ma uitam pe bloggul colegei mele Tya si am dat de tine.\r\nsi sa nu-ti fi zis groparu cred ca tot imi dadeam seama ca esti tu! stilul inconfundabil te da de gol ;)\r\nsalutari din nordul indepartat si toate cele bune!\r\ncristina ani\r\n(vecina din XIV)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; SLCC1; .NET CLR 2.0.50727; .NET CLR 3.0.04506)','',0,0),(18317,1027,'julius constantinescu','julius@universitateacraiova.ro','http://www.7plus.ro/?arhiva=13/03/2008&#38;id=3445','84.232.160.239','2008-03-13 17:51:00','2008-03-13 15:51:00','Asa o patit si sor-mea cu scrisorile nigeriene, or anuntat-o cu durere ca o crapat unchiul nostru, celebrul petrolist Tim Andrapitic :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(18280,1021,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-03-13 09:46:50','2008-03-13 07:46:50','Deci aceasta postare nu se referea nici pe departe la sefii mei!!!\r\n\r\nSefu\' meu, de exemplu, ii pita lu\' Dumenzau, si stiu ca nu va ceti comentariu asta, deci nu-i dau limbi.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(18054,1024,'anonim','princesshgabriela@yahoo.com','','80.97.216.138','2008-03-11 11:19:08','2008-03-11 09:19:08','O sa tii postul si anul asta, nu avea nici o grija.\r\nA trecut doar un an, nu ai imbartanit deloc.\r\nDar cu atatea mancaruri apetisante, e foarte greu de tinut un post o perioada asa indelungata. Succes!',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648)','',0,0),(18055,1025,'iulianuss','realvision@k.ro','','193.231.107.209','2008-03-11 11:20:02','2008-03-11 09:20:02','Pfuai mÄƒ, ai pierdut o escursie la protecÅ£ia consumatorului... Pentru tine trebe inventat modemu fÄƒrÄƒ prizÄƒ ÅŸi aragazu cu lemne.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; .NET CLR 1.1.4322)','',0,0),(17995,1024,'mirra','','','83.103.137.234','2008-03-10 19:55:40','2008-03-10 17:55:40','http://www.youtube.com/watch?v=FQt-h753jHI',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(17987,1024,'anonim','princesshgabriela@yahoo.com','','80.97.216.138','2008-03-10 12:06:02','2008-03-10 10:06:02','Sper ca ai avut un weekend in care te-ai distrat pe cinste.\r\nSi e foarte bine ca tii post. Dar e greu de rezistat tentatiei la atatea mancaruri bune care nu se mananaca in post.\r\nSi nu e frumos sa iti consideri prietenii dobitoci. Buni, rai, sunt prietenii tai. Accepta-i asa cum sunt, mai magarule!\r\nNumai bine si noroc la tinut postul. Nu o sa fie usor, dar daca l-ai tinut pe tot anul trecut, ai vointa, nu gluma.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648)','',0,0),(18121,1025,'banalu','ra_macovei@yahoo.com','','79.112.40.169','2008-03-11 15:49:12','2008-03-11 13:49:12','E de poveste treaba. E legendara, chiar. Dupa ani de chinuri, am constatat ca merge mult mai bine daca: introduci mufa/jack-ul, apesi butonul, bagi in priza, pui baterii, strangi surubul, misti maneta, adaugi apa, aprinzi ochiul la aragaz si inca multe alte operatiuni complexe greu de invatat si inca si mai greu de pus in practica.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(18227,1025,'Zappy','zappy_mica@yahoo.co.uk','http://ar16zpy.blogspot.com','86.121.108.82','2008-03-12 23:08:52','2008-03-12 21:08:52','Nuuu...Doamne Fereste....nu asta insinuam. Voiam doar sa subliniez incompetenta UPC.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(18414,1028,'Ionut','ioau@yahoo.com','','89.34.225.25','2008-03-14 13:55:46','2008-03-14 11:55:46','Nici acum nu ai terminat scoala? :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(18138,1021,'IepurasulAtomic','Praetorian21uk@yahoo.com','http://Iepurasulatomic.weblog.ro','62.217.213.161','2008-03-11 22:07:52','2008-03-11 20:07:52','Acum pricep uai Gropare di ce\'s io asha meteosensibil,de m-am trezit dimineata cu un junghi in spate.Pai ma,orice manager cand are un junghi in spate se uita in oglinda sa vada daca nu iese vreun maner de cutit din el,ca si mine.Traiasca managerii!Nu vii sa lucrezi pt mine...in Canada,ca acolo urmeaza sa fiu inscaunat!?:))\r\n\r\n&gt;&gt;Cala',0,'1','Mozilla/5.0 (SymbianOS/9.1; U; en-us) AppleWebKit/413 (KHTML, like Gecko) Safari/413 es61i','',0,0),(18139,1021,'IepurasulAtomic','Praetorian21uk@yahoo.com','http://Iepurasulatomic.weblog.ro','62.217.213.161','2008-03-11 22:10:27','2008-03-11 20:10:27','@Cala: Tie ti-ar conveni sa fii lider in Romania?Ai sfarsi ca Braveheart, doar ca mult mai repede.',0,'1','Mozilla/5.0 (SymbianOS/9.1; U; en-us) AppleWebKit/413 (KHTML, like Gecko) Safari/413 es61i','',0,0),(18269,1021,'marius','mariusparciu@yahoo.com','http://parciu.blogspot.com/','79.112.92.101','2008-03-13 07:54:08','2008-03-13 05:54:08','bine ca nu toti sefii se comporta ca sefii \"tai\"',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(18430,1027,'Brigitte','briqo_o@yahoo.com','','82.77.126.254','2008-03-14 15:46:51','2008-03-14 13:46:51','=))',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; FDM; .NET CLR 1.1.4322; .NET CLR 3.0.04506.648; .NET CLR 3.5.21022)','',0,0),(18354,1025,'Turambar','mirel@ccsb.ro','http://turambarr.blogspot.com','84.232.187.240','2008-03-14 01:16:48','2008-03-13 23:16:48','Eu cred ca trebuie sa scoatem in evidentza nu incompetentza UPC, ci naivitatea groporala. Lasa, bre, ca punem mana de la mouse sa te trimitem la un workshop de aprins aparatele electrice prin apasare de boton.\r\n\r\nHo, stai nu urla: lasa-ma sa termin. Workshopu este tzinut de nishte workshoperitze faine, care se potrivesc cu clima si ambientu, trase fatucele la nishte tzatzoshenii de-alea de push-up bengoase si la nishte fustitze minuscule, de marimea cablajului imprimat. Si ele te invatza sa apeshi pe boton prin aplecare larga si generoasa, pana la botonul aflat la nivelu solului, si atunci nivelu creshte. Si daca invetzi apasarea pe boton, apai se practica strip-tease drept bonus de pricepere. Si pe urma...\r\n\r\nSi pe urma...\r\n\r\nVezi, bre, ce inseamna sa nu stii sa apeshi pe boton? Life is an electric bitch and then we lift the skirts and we ride the tide.\r\n\r\n:)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(18931,1029,'Zappy','zappy_mica@yahoo.co.uk','http://ar16zpy.blogspot.com','86.121.108.70','2008-03-17 17:53:04','2008-03-17 15:53:04','Eu sunt din Ar si si la noi e plin de ungurei...dar nu am auzit sa fie mari conflicte. Cred ca majoritatea conflictelor sunt in partea de Est unde lumea nu stie ca ungureii sunt de treaba :). Si la noi chestia asta cu biletele se practica la greu, cand cobori lasi biletu pe scaun. \r\n\r\nEu maghiara o aud asa: Tecterecterectectec...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(18646,1029,'hadean','contact@adihadean.com','http://www.adihadean.com','86.125.33.40','2008-03-16 18:57:25','2008-03-16 16:57:25','Azi am beut cu doi prieteni italieni in cinstea ungurilor a caror zi o fost ieri ,inclusiv in cintea feciorului care o fo batut de bagabontii romani. Si in cinstea mea, care am fo si io batut , la cap ii drept, de alti bagabonti, tat romani, ca ungurii n-o avut treaba cu mine in veci. No, revenind la beutura, pantru ca nu am avut un steag unguresc pa care sa-l cinstim corespunzator, am abuzat de ala italian, care-i aproape la fel da un pic pa dos. \"O fo fain, cam cum ar be niste unguri in cinstea noatra cinstind steagu\' Ciad-ului, care-i aproape ca a\' nost\'. Cat despre doamna cu biletu, sa-i deie Isten numa sanatate ca nu te-o lasat descoperit si pa mana bulgarilor de controlori.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro-RO; rv:1.7.8) Gecko/20050511 Firefox/1.0.4','',0,0),(19254,1034,'CÄƒlÄƒ','acalarasu@gmail.com','http://adriancalarasu.wordpress.com/','62.217.241.242','2008-03-20 12:30:52','2008-03-20 10:30:52','Gropule, hai lasa vrajeala,  zi cu postu\' ala cum e?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(19255,1034,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-03-20 12:38:04','2008-03-20 10:38:04','Mah... greu! Ma gandeam ca daca nu tin o zi post, si raman cu restanÅ£Äƒ o zi, atunci se cheamÄƒ cÄƒ sunt post-restant!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19256,1032,'','','','82.77.126.157','2008-03-20 12:40:40','2008-03-20 10:40:40','da de une.... ca sa-ti cer un autograf pe un servetel',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19139,1032,'hadean','contact@adihadean.com','http://www.adihadean.com','194.102.126.6','2008-03-19 12:26:30','2008-03-19 10:26:30','Io mi-s PavÄƒl djin BÄƒnat\r\nPavÄƒle, PavÄƒle\r\nÅžÃ¢ pÄƒ Gropar l-am banat\r\nPavÄƒle, PavÄƒle\r\n\r\nDraji mi-s mie miss-Äƒle\r\nPavÄƒle, PavÄƒle\r\nCÃ¢nd le vÄƒd bucuÅ£Äƒle\r\nPavÄƒle,PavÄƒle\r\n\r\nLa Gropar i-aÅŸ da \"djezban\"\r\nPavÄƒle, PavÄƒle\r\nDa mi-s fÄƒlos bÄƒnÄƒÅ£an\r\nPavÄƒle, PavÄƒle\r\n\r\nÅžÃ¢ nu pot da Ã®napoi\r\nPavÄƒle, PavÄƒle\r\nNiÅŸi dÄƒ n-are oamini goi\r\nPavÄƒle, PavÄƒle\r\n\r\nDa poace Ã®l djezban mÃ¢ne\r\nPavÄƒle, PavÄƒle\r\nCÄƒ le zÃ¢ÅŸe tere bine\r\nPavÄƒle, PavÄƒle',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12','',0,0),(19140,1032,'Andrei Crivat','andrei@andreicrivat.ro','http://www.andreicrivat.ro','89.137.83.141','2008-03-19 12:27:46','2008-03-19 10:27:46','nu se referea la faptul ca ai avea tu pe site pornache. ioi, ma Gropariene, tulai, ca nimic nu pricepi\r\n\r\nSe referea la faptul ca TU esti asa, cam pornache, ma pricepi ?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19141,1032,'Catzaua','ana.man.fox@gmail.com','','81.180.173.61','2008-03-19 12:31:47','2008-03-19 10:31:47','Groparu-porn sau porn-Groparu. pfuai ce imagini imi trajnesc in scafarlie. [din seria \"n-am priceput nimic, da\' sa-mi traiasca imaginatia!\" ]',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(18326,1027,'hadean','contact@adihadean.com','http://www.adihadean.com','79.113.56.132','2008-03-13 19:21:33','2008-03-13 17:21:33','Am un prekin, vorba lu\' matale, jodokan de performaÅ£a. ÃŽntr-o excursie Ã®n scop de bÄƒtut alÅ£i judokani la Kiev, Ã®l apucÄƒ pe Äƒsta miÅŸtocÄƒreala cu kievenii pÄƒ stradÄƒ, sÄƒ rÃ¢dÄƒ cu prietenii lui de cÃ¢t pot fi de deÅŸtepÅ£i romÃ¢nii peste hotare. FÄƒrÄƒ preaviz Ã®ncepe el sÄƒ le ureze oamenilor \"bunÄƒ ziua\" Ã®n limba porno pÃ¢nÄƒ ajunge la unu\' ÅŸi-l Ã®ntreabÄƒ \"cÃ¢t Ã®i ceasu bÄƒ #ulÄƒ?\".La care kievezu bagÄƒ o privire cruntÄƒ la ceas ÅŸi un la fel de cruntÄƒ la prietenu meu ÅŸi-i zice \"zece jumate bÄƒ #ulÄƒ\".',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(18428,1028,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-03-14 15:36:23','2008-03-14 13:36:23','@ Ametitu: ii din seria \"sefi carora le pot sparge dintii fara represalii\" :D\r\n\r\n@ Andreea: Da, asta il enerveaza si pe instructoru meu la mine! Si nu mi se par enormal.\r\n\r\n@ Dush: As pune la o masina un schimbator de viteze in forma de sfarc. Atunci negresit ca ase m-as mai concentra, de oioioi!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(18425,1028,'dush','tirbushon@gmail.com','http://dushrece.blogspot.com','193.230.155.70','2008-03-14 15:14:23','2008-03-14 13:14:23','io zic ca doar esti antitalent, nestimulat corespunzator de pedalele profesorului...iti imprumut io pe nea ala de m-o facut shofer cu acte-n regula? numa tre sa apari la bv...comentariul nostru favorit cat eram la stop - iarna ca asa am facut scoala - era sa ghicim cat poarta la sutien fumeile care treceau strada si alte nebunii d\'astea misogine...si deh..luat cu brio..tot :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(18217,1021,'hadean','contact@adihadean.com','http://www.adihadean.com','79.113.86.18','2008-03-12 21:35:05','2008-03-12 19:35:05','Dude, vestile proaste nu inceteaza sa vina.Cica pana la 2015 vommai avea inca 2 milioane de sefi pe piata, ca se angajeaza absolventii scolilor de sefi. Cat despre subalterni, ei deja isi cam baga picioarele si incep  sa devina proprii lor sefi prin Spania, Italia si alte tari in care nu-i musai sa fii mai aspru decat cel de langa tine.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(18423,1028,'Andreea','puistrulet2003@yahoo.com','http://n/a','81.196.150.196','2008-03-14 14:44:58','2008-03-14 12:44:58','Ah ce amintiri am eu... Eu cu instructoru meu am fost BFFs pana cand m-am prins ca ma cam trage in chept cu banii si i-am spus; since then no mo\' BFFs; \r\nsi dupa aia eu am ineput sa fiu bitchy si l-am schimbat (adica pot sa spun ca i-am dat papucii???? cred ca da... :) )\r\n\r\nBTW ce ma deranja pe mine la instructoru meu era ca ii mirosea gura :( si masina (a mancare naspa)...ah si inca o chestie, nu stia deloc sa explice...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(18190,1025,'Zappy','zappy_mica@yahoo.co.uk','http://ar16zpy.blogspot.com','86.121.108.82','2008-03-12 16:37:29','2008-03-12 14:37:29',':)) hahah am un mic deja-vu. Exact asa un post am scris si eu, tot cu UPC, tot cu conversatia la telefon redata intocmai...hai ca e buna :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(18191,1025,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-03-12 16:42:10','2008-03-12 14:42:10','Deci in sfarsit cineva s-o prins ca Groparu e un plagiator mizerabil.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(18421,1028,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-03-14 14:27:21','2008-03-14 12:27:21','Ohooo... daca s-ar vedea injuraturile, ti-as zicea ca n-ai vazut nimic inca!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(18075,1025,'natty','natty2277@yahoo.com','','86.106.49.165','2008-03-11 11:59:35','2008-03-11 09:59:35','si mie mi-o picat azi dar am sunat la upc si mi-au zis ca e avarie in zona si stau linistita ca se rezolva repede. la care eu intreb cat de repede (10 min-juma de ora)? ei zic nu, dar azi sau cel tarziu maine sigur!\r\npoate stam in aceeasi zona:)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(18339,1027,'totolici','fun4toto@yahoo.com','http://totolici.wordpress.com/','89.137.69.31','2008-03-13 21:50:15','2008-03-13 19:50:15','funny',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.0.7) Gecko/20060909 Firefox/1.5.0.7','',0,0),(18340,1021,'marius','mariusparciu@yahoo.com','http://parciu.blogspot.com/','79.112.89.243','2008-03-13 22:09:23','2008-03-13 20:09:23','cand am zis \"ai tai\", ma refeream la cei descrisi in text, nu la cei din birou',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(18420,1028,'julius constantinescu','julius@universitateacraiova.ro','http://www.7plus.ro/?arhiva=14/03/2008&#38;id=3491','84.232.169.54','2008-03-14 14:24:20','2008-03-14 12:24:20','gropare, la cat injuri tu, ar putea aia sa-ti dea direct licenta de taximetrist :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19252,1033,'Pandora','bluemotogirl@yahoo.com','http://cutiapandorei.blogspot.com/','86.122.9.173','2008-03-20 12:21:16','2008-03-20 10:21:16','daca e cine cred eu colega aia mica de statura, numa defavorizata nu e. n-ai primit un shut intre picioare sau ceva, gropare?:D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(18419,1028,'hadean','contact@adihadean.com','http://www.adihadean.com','194.102.126.6','2008-03-14 14:21:32','2008-03-14 12:21:32','Cred cÄƒ nu erai mai nÄƒcÄƒjit nici dacÄƒ fÄƒceai ÅŸcoala cu Yoda. Åži ai vÄƒzut cÄƒ Äƒla micu enervant poate sÄƒ fie el cÃ¢nd vrea.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12','',0,0),(18167,1021,'worlds_pain','worlds_pain@yahoo.com','http://welcome.haipa.ro','86.126.41.130','2008-03-12 10:36:57','2008-03-12 08:36:57','vad ca ai implinit un an de blogging: La multi ani!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(18416,1028,'ametzitul','','http://ametzitul.wordpress.com','62.217.236.12','2008-03-14 14:11:53','2008-03-14 12:11:53','asta-i tot din seria \"despre shefi\" ?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(18415,1028,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-03-14 14:11:10','2008-03-14 12:11:10','U must never understimate the power of stupidity.\r\n\r\nDeci - nu.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(18135,1021,'Andreea','puistrulet2003@yahoo.com','','217.214.73.148','2008-03-11 21:07:17','2008-03-11 19:07:17','Cum se spune? Sefi, sefuti, f---ti... si p---mea :))  (mereu rad ca proasta la zicala asta :) )\r\n\r\nSalutari din Suedia...\r\n\r\nAndreea',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 2.0.50727)','',0,0),(18136,113,'Paul Hodorogea','paulhodorogea@gmail.com','http://paul.ziarulstrazii.com','86.106.247.211','2008-03-11 21:21:17','2008-03-11 19:21:17','Domnu gropar..\r\n\r\nrespect :D:D\r\n\r\neu demult nu am cetit aÅŸe stil!\r\n\r\nmi-aduce aminte de vaculovski',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19169,1032,'ametzitul','','http://ametzitul.wordpress.com','62.217.236.12','2008-03-19 17:14:01','2008-03-19 15:14:01','@julius: mah, razbelul de 100 de ani a inceput in 1337 :)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(19170,1032,'julius constantinescu','julius@universitateacraiova.ro','http://www.7plus.ro/?arhiva=19/03/2008&#38;id=3663','84.232.160.238','2008-03-19 17:24:14','2008-03-19 15:24:14','@ametzitul: asa e, dar razboiul rece incepuse mai demult :D eduard III si filip (al VI-lea, cred) se injurau deja de mama si-si promitea: \"ba, daca te prind, iti sparg fata si tie, si la toata armata ta de cacat!\"',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19171,1032,'Andreea','puistrulet2003@yahoo.com','http://n/a','81.196.150.196','2008-03-19 17:26:32','2008-03-19 15:26:32','Deci careva sa zica Webwasheru o zis ceva ceva de genu: \"mwhahahaha!!!! s-o crezi tu ca cetesti azi bloguri!!! Back to work slave :) !!!!\"\r\n\r\nNu?...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19172,1032,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-03-19 17:33:17','2008-03-19 15:33:17','Sau: \"Your bosses\' pyramids need to be ERECTED!!!\"',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19972,1044,'Ionut','ioau@yahoo.com','','89.34.225.25','2008-03-29 00:44:03','2008-03-28 22:44:03','Legat de counter-strike, eu cunosc om de 40 de ani care joaca pe server cu fiul de 15 si cu fata de 8 ani :)\r\n\r\nSi legat de travian: \"	bha omuleee....u nu evzi ca ai aliantra cu noi? u chiar esti turc??? u chiar vrei sa tabar pe tine???jok travian de 3 ani stiu cu ce se mananca...\"',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(18133,1021,'Emaginatorul','','','193.231.29.1','2008-03-11 20:04:21','2008-03-11 18:04:21','Dupa asta chiar ca nu iti mai mareste leafa. Si tu ai gantzonera de platit bueey! Si vreai sa iei sh dacie!\r\nMane tre scris o postare sa-tz mai spele din pacate.',0,'1','Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.1.1) Gecko/20061208 Firefox/2.0.0.1','',0,0),(18125,1021,'CÄƒlÄƒ','acalarasu@gmail.com','http://adriancalarasu.wordpress.com/','62.217.241.242','2008-03-11 16:56:03','2008-03-11 14:56:03','Daca-i place soarele e clar ca-i planta.\r\n\r\nIn Romania avem foarte multi sefi, foarte putini manageri, si leaderi pu*a!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(18082,1025,'julius constantinescu','julius@universitateacraiova.ro','http://www.7plus.ro/?arhiva=28/02/2008&#38;id=2928','84.232.160.140','2008-03-11 12:12:42','2008-03-11 10:12:42','Gropare, cand mai ramai fara net, suna la Urgente Sprite. Nici aia nu ti-l repara, da\' macar iti lasa impresia ca le pasa de tine.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(18124,1025,'oedip','oedip74@gmail.com','http://oedip.blogspot.com','89.137.99.163','2008-03-11 16:45:31','2008-03-11 14:45:31','plm de ce n-ai zis mai iute ca-t dadeam io un sac, ieri le-am tzapat la bena... dar cred ca nu s-o dus gunoiu deci le mai poti cauta :PP',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(18084,1023,'Flamandu\'','','','82.77.193.186','2008-03-11 12:15:35','2008-03-11 10:15:35','Deci cum veneai de sub pod, era in stanga. Daca veneai din ai mare peatsa, era in dreapta. Si la doi pui primeai o butelie de vin. 16 tsatse. Pe Titi si pe Mielu nu\'i stiu, is beutori? Ca rotisatii aia i\'am mancat can eream tiner, prin 95-96. De atunci numa la tv am mai vazut sibiu. Da smor io daca nu can aud de sibiu numa la pui si 16 tsatse ma gandesc.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(18319,1027,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-03-13 18:03:10','2008-03-13 16:03:10','Deci sor-ta nu mai e un nigerian negru???',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(18311,1027,'ametzitul','','http://ametzitul.wordpress.com','62.217.236.12','2008-03-13 16:40:35','2008-03-13 14:40:35','pai era mail standard, mah...\r\nsau or fi crezut ca insemna \"salutari din Croatzia\"... if iu nau uat i miin :)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(18307,1021,'Hammer','hammer@alpinet.org','','81.196.168.118','2008-03-13 15:26:25','2008-03-13 13:26:25',':-D Shefu\', despre ai cui shefi vorbeai? :-)))',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(18184,1014,'ilea','','','217.10.200.10','2008-03-12 15:41:12','2008-03-12 13:41:12','*10\r\nceea ce te facea invizibil in Arabella era de fapt pelerina lui Rumburak. inelu\' doar! iti indeplinea orice dorinta. inca imi mai doresc inelul...',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(19908,1043,'Greuceanu','','','89.46.104.35','2008-03-27 17:25:18','2008-03-27 15:25:18','asha e mah.... asha e.... de cate ori imi vine sa ma cac pe mine de foame, stau si ma gnadesc \"ca de unde dreaku\' sa ma kak\' daca n-am mancat\"?! imi aduk amuinte de delikatesea asta scumpa ce-o caut amu in fiece supermarket la raionu\'\"articloe de post\", ca nici macar nu ie mancare.,  + de asta, de aia l-am urat pe Ceausescu, ca ne dadea salam cu soia! na amu\'-i binie?! numa\' soia\'i ok?!\"',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(19932,1045,'Catzaua','ana.man.fox@gmail.com','http://catzaua.wordpress.com','81.180.173.61','2008-03-28 10:19:59','2008-03-28 08:19:59','when you gotta go, you gotta go. it\'s not like you have a choice or anything, is it? ..',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19014,1029,'Lush','copilurau@yahoo.com','http://www.blogulucostel.blogspot.com','193.231.18.7','2008-03-18 01:36:14','2008-03-17 23:36:14','De fapt ii kekeremekere..sau cel putin asa am inteles eu:D!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19048,1030,'ametzitul','','http://ametzitul.wordpress.com','62.217.236.12','2008-03-18 12:51:56','2008-03-18 10:51:56','mah pe mine m-ai convins...\r\nacu\' trimite-mi bani de bilet sau zi de unde-l descarc gratis, ca-s prea zgarcit sa dau bani shi prea lenesh sa caut :)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(19050,1030,'','','','89.33.174.82','2008-03-18 13:10:04','2008-03-18 11:10:04','deci... cel mai prost film pe care l-am vazut in ultima vreme. am ras de numa.. atata SF incat iti vine rau. si nici nu m-am putut uita la tot ca m-am plictisit. faza e ca am vazut trailerul pe imdb shi am zis ca e taaare bun filmu. cand l-am scos dp retea (caci asa am facut!) si m-am pus sa ma uit, mirare! filmu de cacat! sorry, da asta e parerea mea \r\nma bucur sa aud ca nu sunt singura careia i s-a parut asa. ;)',0,'1','Opera/9.26 (Windows NT 5.1; U; en)','',0,0),(19051,1030,'ramonici','mum_2_us@yahoo.com','','89.33.174.82','2008-03-18 13:12:18','2008-03-18 11:12:18','noah bine c-am uitat sa ma semnez mai sus :P',0,'1','Opera/9.26 (Windows NT 5.1; U; en)','',0,0),(19052,1030,'hadean','contact@adihadean.com','http://www.adihadean.com','194.102.126.6','2008-03-18 13:26:11','2008-03-18 11:26:11','Suna interesant,n-am mai vazut un film despre superioritatea rasei albe asupra universului cunoscut redata prin metafore de Hollywood(subtiri adica) de la...ultimul film pe care l-am vazut. Nu cumva aia de fugareau mamutii erau si americani?Ca asta le-ar explica pe toate...\r\nOricum, din povestea ta pare destul de kktor incat sa merite o punga de 100 de grame seminte de dovleac. Asa ca incerc sa-l vad.Si daca nu-mi iese faza cu semintele la cinema, sa ma simt si eu ca imbecilul de Borcea cand ii scuipa unui amarastean seminte in cap la meci, gasesc eu pe cineva (un vecin,un nash, ca doamna mi-o respect mai mult decat Base pe ale lui) care sa vina la mine si sa stea jos langa pat pana vad filmul/termin semintele. la un film de milioane nu poti sa te comporti decat ca un milionar, ce palaria mea!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12','',0,0),(19053,1029,'Constantin','bigzander@yahoo.com','http://pescuitvrancea.ro','195.245.88.200','2008-03-18 13:30:04','2008-03-18 11:30:04','Faine comentariile aistea!\r\nLe-or citi si ei?!\r\n\r\nNem tudom!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(18171,1025,'Sweeper','ak70g2@gmail.com','http://360.yahoo.com/profile-uvnl.F8wcPFgZTDuDeY-?cq=1','92.81.242.56','2008-03-12 12:25:03','2008-03-12 10:25:03','Gropareeeeee... Ma omori tu pa mine.... Sa moara soacra!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(18282,1021,'mishu','mishu@doingtheartwork.com','http://www.doigntheartwork.com','82.77.126.254','2008-03-13 10:06:20','2008-03-13 08:06:20','Ahahhaha, drept zisu-ai mai putin la faza cu nu dau limbi. Ca asa se vede d-aici :D\r\n\r\nSalutari din biroul cestalant!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(17980,1024,'ametzitul','','http://ametzitul.wordpress.com','62.217.236.12','2008-03-10 08:46:47','2008-03-10 06:46:47','io i-am zis mariei sale turambarr ca-l invidiez... azi in Lisboa, maine la Cluj, unde oamenii (poate chiar shi groparu) inca shtie sa bea...\r\nda\' postu\' asta nu-i pt. oameni serioshi, mah...\r\nmi-a zis socru\' meu, care de fapt e un popa :)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(18000,1024,'oedip','oedip74@gmail.com','http://oedip.blogspot.com','89.137.99.163','2008-03-10 23:50:47','2008-03-10 21:50:47','t-am scris un post de love :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(18001,1025,'SIBILLA','sibilla_poesis@yahoo.com','http://sfinx667.wordpress.com','89.123.42.190','2008-03-11 02:41:35','2008-03-11 00:41:35','mare smenar esti..mare de tot...rad de jumate de ora de nebuna pe aci...adica... multam fain mai omule ca mi-ai ridicat moralul, inca unul dintr-o bucata care o patit ca mine..nu-i bai, noi sa fim sanatosi, si daca e musai, apoi cu placere sa fie :)\r\nsucces in continuare iti doresc si o primavara zambitoare ca tine si bogata in impliniri, sanatate si putere si ani..cat sa apuci sa-ti ingropi toti dusmanii, si ca bonus inca o suta de la mine, ca esti neam de geto-dac LIBER!\r\nrespecte,\r\nSIBILLA\r\nDoamne Ajuta!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; SIMBAR={5E84BDD4-ACDC-11DC-8BCA-001A4D8E0E14})','',0,0),(17983,1024,'Groparu','groparu_ro@yahoo.com','http://','82.77.126.254','2008-03-10 10:19:05','2008-03-10 08:19:05','@ Andreea: nu, da\' de futut tot ma fut!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,1),(17988,1024,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-03-10 14:23:09','2008-03-10 12:23:09','@ anonim: l-oi tinea, desi anu\' asta ii mai greu ca anu\' trecut, c-am mai imbatranit si mi-s si mai sus-pus greselii ca ina\'nte!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(17989,1024,'Mile','','http://milecarpenisan.wordpress.com/','86.123.241.86','2008-03-10 15:40:48','2008-03-10 13:40:48','Gropare nu te mai caca pe tine ca stim toti ca nu esti anost niciodata. Esti chiar fain. Drept e ca atunci cand bei te balbai mai putin dar imi imaginez pentru ca pot ca la Orlat nu te-ai balbait deloc zilele astea. Ah, da, si imi imaginez ca si daca o plouat cu spume, tu, varu si Greuceanu tot ati bagat si ceva la gratarul din curte si CrÃ¢vatzul a fost fortat sa stea acolo si inainte ati izolat fetele intr-o camera. Una peste alta post usor si postari multe frate.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; SIMBAR={A7F3C004-B2DD-4145-98BD-0344DDF9CD6E}; .NET CLR 2.0.50727)','',0,0),(19143,1032,'Basty','sebastian@centre-roumain.fr','http://basty.wordpress.com','82.77.126.21','2008-03-19 12:43:36','2008-03-19 10:43:36','Ieu zic cÄƒci aceastÄƒ postare este despre o situaÅ£iune fictivÄƒ. ÃŽn spatele motivelor se aflÄƒ de fapt doar un pretext pentru a prezenta linkurile acelea pÄƒcÄƒtoase. Cu ocazia acestui gest care invitÄƒ la preacurvire, stimate domn Gropar , vÄƒ transmit un cÄƒlduros  \r\n   \r\n  MULÅ¢UMESC ! \r\n   \r\n  ( Disclaimer: linkurile menÅ£ionate vor fi folosite doar pentru o ...ÄƒÄƒÄƒÄƒÄƒÄƒ... cercetare ÅŸtiinÅ£ificÄƒ asupra Internetului ÅŸi nu pentru satisfacerea retinalÄƒ semnatarului.  True story. )',0,'1','Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_4_11; en) AppleWebKit/525.13 (KHTML, like Gecko) Version/3.1 Safari/525.13','',0,0),(19144,1032,'ametzitul','','http://ametzitul.wordpress.com','62.217.236.12','2008-03-19 12:43:46','2008-03-19 10:43:46','- Ce vrei tu?\r\n- Noi? Buna pace...\r\nShi de n-o fi cu banat\r\nSpunetzi \"adio groparu!!!\"\r\nPen\'ca suntem cap de... frunce\r\nL-am banat shi in Banat...\r\n\r\nAcest text constituie o gluma shi trebuie interpretat ca atare. Daca persista incruntarea adresatzi-va celui mai apropiat chelner sau barman.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(19148,1032,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-03-19 13:10:30','2008-03-19 11:10:30','BAAA, CETITORILOR!!\r\n\r\nDA\' CHIAR TOTI SUNTETI MAI DAJTEPTI CA MINE???',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19149,1032,'Andrei Crivat','andrei@andreicrivat.ro','http://www.andreicrivat.ro','89.137.83.141','2008-03-19 13:13:47','2008-03-19 11:13:47','vorba lu\' nastase: cititorii tai sunt mai destepti decat scriitorii altora.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(18932,1029,'Usim','mihaimitan@gmail.com','','87.237.108.33','2008-03-17 17:55:38','2008-03-17 15:55:38','@ Andreea\r\n\r\n\"Befele in clasa\" s-ar traduce cu aproximatie \"ia luati-o voi spre clasa\".\r\nExpresia completa ar fi \"Befele az osztalybo\". S-ar putea sa fi scris-o gresit, cu scrisu\' nu le prea am in ungureste.\r\n\r\nViszont latasra!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; .NET CLR 2.0.50727)','',0,0),(19974,1044,'Ionut','ioau@yahoo.com','','89.34.225.25','2008-03-29 00:48:49','2008-03-28 22:48:49','Scuze pt limbaj :p',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(18920,1029,'ametzitul','','http://ametzitul.wordpress.com','62.217.236.12','2008-03-17 16:16:37','2008-03-17 14:16:37','@Andreea MKT: era demult un banc, cu legiunile romane care ajung la Sarmisegetusa, nu vad pe nimeni, bat in poarta shi iese o baba care le zice chestia asta d-o zici tu prietenului :)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(18904,1029,'timur','antifa_haha@yahoo.com','','194.117.242.3','2008-03-17 14:56:34','2008-03-17 12:56:34','da, merci ca m-ai luminat! daca nu stiam povestea asta muream prost. eu zic sa o bagam in cartea de istorie, in loc de cateva capitole, pentru ca groparu le stie pe toate...lasa-ne mai nene cu penibilitatile tale!',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; InfoPath.1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(19131,1031,'pliscu','pliscu@gmail.com','http://pliscu.blogspot.com','89.137.100.118','2008-03-19 10:51:27','2008-03-19 08:51:27','iar te-au dus colegii cu forta la fotbal? (uimeste-ma si zi-mi ca mergi in fiecare marti :P )',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19132,1031,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-03-19 10:56:02','2008-03-19 08:56:02','E a doua oara cand ma duc martea.\r\n\r\nA fost si prima data cand am dat 4 (patru) goluri. \r\n\r\nDat viitoare sper sa trag neshte tunuri, nu goluri, sa ma pot si eu retrage linistit in Maldive, calare pe un purcoi de euro si iubit de o gasca de maldivence, care sa ma placa pentru ceea ce sunt eu de fapt, nu pentru garsoniera mea si-a bancii!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19133,1031,'anonymul','graffitiuncas@yahoo.com','','194.102.126.6','2008-03-19 11:07:44','2008-03-19 09:07:44','Acum 10 ani (sau asa ceva) am dezvoltat o relatie bazata pe sex aproape intamplator, cu o fata destul de gentila si discreta. Au trecut doua saptamani de amor in multe locuri si pozitii, schimb de fluide si ...in fine. Cam pe la finalul celor doua saptamani vine si intrebarea:\"auzi, da\' macar stii cum ma cheama?\". La asa intrebare nu puteam da decat un singur raspuns: \"hai, nu fi prostuta, sigur ca stiu\". \r\nDupa alte doua saptamani am aflat cumva \"cu manta\" cum o cheama. Ea s-a maritat, si nu cu mine. Ma intreb daca barabt-su stie cum o cheama sau asteapta al doilea copil ca sa afle..',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12','',0,0),(18908,1029,'mo','verde_poveste@yahoo.com','','194.126.220.22','2008-03-17 15:18:54','2008-03-17 13:18:54','@ timur: numa-ncet, timur baci, ca vremea e inca tanara pentru facut scandal. ia sh manca pranzu\', ca ti-a luat-o razna glicemia.\r\n\r\nNo, bun, cu ziua ungurilor am inteles cum sta treaba, da\' nici un post de ziua lu sfantu\' Patrick, in cinstea alora de ne-au dat Wilde si Guinness?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1)','',0,0),(19157,1032,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-03-19 15:15:35','2008-03-19 13:15:35','@ Julache: deci tz-am furat expresia \"pornache\" in detrimentul expresiei folosite de mine in mod curent, \"pornet\". Si nu mi-ai zis daca iti plac primele trei saite enumerate de mine!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19158,1030,'sepukku','s3pukku@gmail.com','','85.121.22.118','2008-03-19 15:20:25','2008-03-19 13:20:25','filmu asta sare peste cateva mii de ani de evolutie. de la corturi si vreascuri la piramide cu varfu de metal...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.0; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19167,1032,'julius constantinescu','julius@universitateacraiova.ro','http://www.7plus.ro/?arhiva=19/03/2008&#38;id=3663','84.232.160.238','2008-03-19 16:55:14','2008-03-19 14:55:14','@Gropare, iarta-ma, nu stiu de unde ai inteles tu ca eu as intra vreodata pe asemenea site-uri nerusinate. Ochelarii mei sunt de la citit Kant si Schopenhauer, nu de la ... Doamne, iarta-ne si izvabeste-ne de Cel Pervers.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19310,1035,'ioana','ioana_g_ro@yahoo.com','http://ioneque.wordpress.com','84.232.148.227','2008-03-20 19:49:38','2008-03-20 17:49:38','apai asta\'i banc de e adaptat in fiecare zona. mi mi l\'o spus un oltean si la ei poanta era: \"si? te cacasi?\"',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.11','',0,0),(19191,1032,'Mo','verde_poveste@yahoo.com','','86.120.170.201','2008-03-19 20:55:20','2008-03-19 18:55:20','@ Basty: pe mame, pe fiice, pe bunici, pe ce iti incanta tie globii oculari ;)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19187,1032,'nenea cosmos','domnu_cosmos@yahoo.com','http://www.nenea.wordpress.com','193.231.82.119','2008-03-19 20:09:36','2008-03-19 18:09:36','cred ca sperma(tozoizii) e de vina... keyworduri, alea alea...',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; InfoPath.1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648)','',0,0),(19188,1031,'nenea cosmos','domnu_cosmos@yahoo.com','http://www.nenea.wordpress.com','193.231.82.119','2008-03-19 20:11:30','2008-03-19 18:11:30','cu *TÄƒticu* n-am greÅŸit niciodatÄƒ!',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; InfoPath.1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648)','',0,0),(19192,1032,'','','','92.81.132.196','2008-03-19 21:31:23','2008-03-19 19:31:23','iei masa la agape?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19262,1033,'PhenoBarbieDoll','poisongirl94@yahoo.com','http://blog.360.yahoo.com/poisongirl94','193.230.230.101','2008-03-20 13:18:51','2008-03-20 11:18:51','tulai, ce noroc ai ca nu lucri cu mine, recte o persoana micuta de statura, c-asa-ti luai un sut pe la inaltimea la care ajung io cel mai bine de-ti ieseau pe nas nu mucii, ci oole',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19194,1032,'Turambar','mirel@ccsb.ro','http://turambarr.blogspot.com','84.232.187.240','2008-03-19 21:35:23','2008-03-19 19:35:23','Mai un singur dor:\r\nLa TV Lemnaru\r\nSa-l vad pe Ramaru\r\nTzatza lu Groparu\r\nSi sa rad pana mor.\r\n\r\n:)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19196,1032,'Andreea MKT','supergirgir@yahoo.com','','89.43.186.64','2008-03-19 21:51:43','2008-03-19 19:51:43','Mah, cine e Catzaua, ca imi place de mor numele iei?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19258,1032,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-03-20 13:07:57','2008-03-20 11:07:57','Dau mai ales pe sÃ¢niÅŸori, ioi, ce-mi place sÄƒ dau pe sÃ¢niÅŸori!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19259,1030,'Maria','fireangee@gmail.com','http://fireangee.blogspot.com','80.128.2.87','2008-03-20 13:09:13','2008-03-20 11:09:13','Groparule, m-am inscris, ca am contagiat de boala rasului si cica e molipsitoare.\r\nAsadar scrie in continuare si te citesc cu drag!\r\n(fireangee@gmail.com)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(19204,1033,'hadean','contact@adihadean.com','http://www.adihadean.com','79.113.58.8','2008-03-19 23:58:51','2008-03-19 21:58:51','ioi ma hatru esti.amu am tendinta sa fiu la fel de destept ca tine si singuru lucru care-mi vine in minte e sa fiu intelept si sa bag cornu in perna.poate visez un muc cu muc.sau un semn de mama cu alunite.sau poate visez ca mi-am tatuat o zula mare pe zula asta mica.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19205,1033,'Catzaua','ana.man.fox@gmail.com','','89.34.72.93','2008-03-20 00:07:53','2008-03-19 22:07:53','Gropare, Gropare... trajnitz-ar talentu\', crejtetz-ar salaru\', fitz-ar naravu\', mancatz-as spiritu\' tau ala bengos si intelijentza nerusinata. Pai binie mah.. ii kosher mah sa te iei de aia defavorizatz de mama natura mah de i-o scos mah de pe linia de productie mah ca pentru tzarile din lumea a 3a, mah?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(18670,1029,'Lush','copilurau@yahoo.com','http://www.blogulucostel.blogspot.com','193.231.18.7','2008-03-17 01:46:27','2008-03-16 23:46:27','Eu eram in anul 1 si am fost dat afara din chirie de un ungur, care cand venea la noi, desi stia ca suntem romani, la dracu is din botosani, ne cerea chiria numai in ungureste! Unde esti tu funar doamne:))?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(18672,1029,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2008-03-17 02:12:59','2008-03-17 00:12:59','Da, bÄƒ, da\' ÅŸi voi il discriminaÅ£i, pun pariu! Recunoaste, asa-i ca vorbeaÅ£i cu el numa\' in botoÅŸenezÄƒ?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19100,1031,'Turambar','mirel@ccsb.ro','http://turambarr.blogspot.com','92.80.22.181','2008-03-19 01:28:59','2008-03-18 23:28:59','Nothing beats Gogu. \r\n\r\nIt\'s a paradigm. It\'s an uber-rose. E o uvedenroda onomastica. \r\n\r\nEu pe totzi care-i prind ii goguiesc. Auzi, mai Gogule, ia zi-mi matale acishilea. Sau Ce faci, Gogule?\r\n\r\nE in loc de What\'s up, Doc? Shi bineintzeles ca molfai cu scarba din morcov, proptit in cot si cu o privire shukar-shagalnica. \r\n\r\nI love the smell of Gogu in the morning.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19090,1027,'URITU','atilibela@gmail.com','http://www.groparu.ro','89.44.39.253','2008-03-18 23:17:30','2008-03-18 21:17:30','No coment.Le-ai nimerit la fix.Adevar mult contin compozitiile tale.BELA',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19071,1030,'Alexandra','alex.groza@gmail.com','http://www.alexis-design.info','89.43.196.103','2008-03-18 17:49:23','2008-03-18 15:49:23','il cel mai prost film ce l-am vazut in ultimii ani. ala de a scris scenariul avea probleme mari si i se rupea filmu cam des. actorii joaca si ei cum pot avand in vedere stupizenia scenariului. \r\n\r\nmai are cateva faze la care razi da is mai tampite decat alea din tom si jerry',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(20011,1044,'oedip','oedip74@gmail.com','http://oedip.blogspot.com','89.137.99.163','2008-03-29 17:24:04','2008-03-29 15:24:04','mah groapa pacat ca n-am salvat si io cateva ca erai in stare de soc deja... asa ma distrau... dar ce ratezi tu de departe e ca joci pe server .ro\r\ncand esti pe .com ai parte de chestii de astea intr-o engleza de te caci cu spume, scuza-ma de limbaj :))), si-ti dai seama imediat ca tipul e mitic de cucuietii din deal! e tare, oricum!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(19161,1032,'mo','verde_poveste@yahoo.com','','194.126.220.22','2008-03-19 15:48:16','2008-03-19 13:48:16','Apai daca filteru\' ii setat pe cuvinte specifice legate de secs ori de aaa, pornache :), inseamna ca ti-au dat ban la spermatozoizii din titlu, oricat de campioni ar fi.... \r\nCu alte cuvinte, e clar o chestie personala daca iti dau ban la dreptu\' de a exista, \'tu-le muma lor!!!!!!!!!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1)','',0,0),(19162,1032,'Basty','sebastian@centre-roumain.fr','http://basty.wordpress.com','82.77.126.21','2008-03-19 15:56:06','2008-03-19 13:56:06','@mo:  MÄƒ scuzaÅ£i, nu vreau sÄƒ rup concentrarea unui asemenea avÃ¢nt pioneresc spre mume, dar eu m-aÅŸ Ã®ndrepta spre fiice, se aprobÄƒ ? \r\n   \r\n  MulÅ£umesc anticipat ÅŸi Ã®ncÄƒ o datÄƒ Ã®mi cer iertare pentru intervenÅ£ie.',0,'1','Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_4_11; en) AppleWebKit/525.13 (KHTML, like Gecko) Version/3.1 Safari/525.13','',0,0),(19156,1031,'Andreea','puistrulet2003@yahoo.com','http://n/a','81.196.150.196','2008-03-19 14:58:12','2008-03-19 12:58:12','E ciudata chestia asta cu uitatul numelui la 1 min dupa ce victima s-a prezentat dar nu e ceva iesit din comun (everybody does it :) ) dar......e penibil (si asta mi s-a intamplat mie)  atunci cand tu mergi batos/oasa sa introduci pe cineva cuiva si te trezesti in mijlocul prezentarii pompoase ca nu stii cum o/il cheama pe om (Deci draga mea/dragul meu, acesta/aceasta este....aaaaa?????aa???.... (fuck) ) si atunci se pot intampla 2 chestii: \r\n\r\n1. tipul/ tipa se prinda ca esti mototolit si se prezinta singur (si iti arunca apoi un zambet superior)\r\n2. cel/cea caruia ii prezinti persoana nu asteapta pana molfai tu discursul si se prezinta singur/singura\r\n\r\nPS: eu nu mai stiu cum ii cheama pe fostii mei prieteni(in schimb prietenele mele stiu :) :)))))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19095,87,'Nascut din spermatozoizi campioni &raquo; Blog Archive &raquo; Cine mai tine minte numele celor cu care a facut cunostinta?','','http://www.groparu.ro/?p=1031','82.103.137.253','2008-03-19 00:07:57','2008-03-18 22:07:57','[...] Deci finca io is super mega plin de mine, nu prea tin minte numele celor cu care fac cunostinta. Daca ma intrebi cum il cheama pe personul care tocmai mi-a fost prezentat, ai sanse 9 din 10 sa auzi nume de fata, mai ales daca respectivul e baiat. In afara de cazu&#8217; in care e vorba de nume cu adevarat memorabile. [...]',0,'1','Incutio XML-RPC -- WordPress/2.1.2','pingback',0,0),(19311,87,'ioana','ioana_g_ro@yahoo.com','http://ioneque.wordpress.com','84.232.148.227','2008-03-20 19:52:34','2008-03-20 17:52:34','wow. mortal! eu am avut un coleg in camin pe care il cheama velcu istocescu. nici in ziua de azi nu stiu care e numele si care e prenumele... noi il strigam teo.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.11','',0,0),(19249,1032,'cronicaru\'','tzone_a@yahoo.com','http://cronicaru.blogspot.com/','193.230.230.101','2008-03-20 12:10:51','2008-03-20 10:10:51','Grapare, poate nu uiti de pornoshaguri, un termen la fel de intelept',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(19155,1032,'julius constantinescu','julius@universitateacraiova.ro','http://www.7plus.ro/?arhiva=19/03/2008&#38;id=3663','84.232.160.238','2008-03-19 14:55:50','2008-03-19 12:55:50','Ce mizerie! Tu esti un tip educat, finut, civilizat, e clar ca te-a lucrat cineva. Afla cine si fute-l in cur.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19082,1030,'','','','89.43.132.28','2008-03-18 20:33:34','2008-03-18 18:33:34','M-or prins niste colegi azi la lucru razand ca proasta in fata calcului si m-or luat la rost ca de ce rad??? No iata de ce(cititi mai jos)\r\n\r\n\"SÄƒ le spuneÅ£i elefanÅ£ilor care nu pot galopa nici mÄƒcar deloc cÄƒ strÄƒmoÅŸii lor fuserÄƒ cu mult mai coioÅŸi, ÅŸi cÄƒ ÅŸi-or fÄƒcut neamuâ€™ pachidermilor de toatÄƒ groaza.\"\r\n\r\nGropare is prea detaliate descrierile tale si io nu ma mai joc ca rad tot timpul...si colegii deja ma privesc cam ciudat si lung...\r\n\r\nSeara faina :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(18633,1029,'marisilvla','marisa.flutursh@gmail.com','http://www.viatzadescolar.wordpress.com','84.232.212.209','2008-03-16 16:12:14','2008-03-16 14:12:14','dragutza tanti!!!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(19102,1031,'hadean','contact@adihadean.com','http://www.adihadean.com','79.113.57.129','2008-03-19 01:58:10','2008-03-18 23:58:10','Se pare ca-s macar la fel de plin de mine ca(de tine era sa zic, la dracu\', ar trebui sa ma culc ca-i tarziu) tine, tiu minte cele mai multe nume ale noilor abia de la a doua auditie.Da nu uit fetzele, parca as fi un criminal involuntar bantuit, un fatzau nu uit, ca-i delicat sau grosolan. Si am citit si io prostia aia cu \"nu te intereseaza persoana, de aia nu-i tii minte numele\".Cred in continuare ca-i o prostie pentru ca m-am urmarit in cateva randuri si m-am surprins uitand in trei minute sau mai putin numele unor persoane chiar interesante.De unde am tras concluzia ca:\r\n1)am o boala psihica sau macar o dereglare\r\n2)cei care au scos chestia asta din ei au o boala psihica sau macar o dereglare\r\n3)toti suntem sanatosi dar subconstientu meu e mai tare decat sabia lui Zorro si taie ce vrea\r\nApoi, pentru ca nu m-am hotarat la o singura concluzie am renuntat sa-mi mai bat capu\'.Ma bucur ca nu-s singuru\' ingamfat de pe planeta albastra.\r\nSi am una si mai tare da pe aia o dau anonima dupa cateva alte posturi, sa nu mi-o iau pe cocoasa intr-o buna zi.Sa-mi aduceti aminte mai spre ziua daca nu am spus-o.V-am pupat ma cicoflenderilor, noapte-n straita.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(18911,1029,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-03-17 15:34:37','2008-03-17 13:34:37','@ mo: apoi... aflati, drajii moasei, ca intre irlandezi si romani diferenta principala ii ca eia beau whiskey, si noi bem palinca - in rest, cam acelasi neam de ratangii. \r\n\r\nA, si daca faci masteru\' de Studii Irlandeze, la Litere, afla ca poti sa ti-l pici daca nu prea mergi la cursuri. Am patit-o, bag shutu\', finca-s expert in eÅŸece!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19954,1045,'WhiteWolf','contact@white-wolf.ro','http://white-wolf.ro','89.39.82.207','2008-03-28 17:29:14','2008-03-28 15:29:14','\"ALTERNATIVA FATALISTÄ‚\r\n<b>Ori cu toÅ£ii sÄƒ muriÅ£i, ori cu toÅ£ii sÄƒ scÄƒpÄƒm!\"</b>\r\nSi tocmai el nu a respectat propria regula :-(\r\nPacat.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(19955,1044,'Lavi','kali_lavy@yahoo.com','','151.82.14.157','2008-03-28 17:47:51','2008-03-28 15:47:51','pfua si eu am jucat vreo 6 luni travian si m`am lasat prin octombrie...da eu eram pur si simplu obsedata de joc...ma trezeam noaptea sa mai dau comezi sa mai creasca populatia,armata,lvl`u la cladiri etc :))\r\nnoroc ca m`am vindecat destul de repede d joc chiar daca in prima sapt simteam ca tremur daca nu intru macar sa ma uit ce se mai int cu aliantza :)))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; it; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(19246,1034,'hadean','contact@adihadean.com','http://www.adihadean.com','194.102.126.6','2008-03-20 11:24:11','2008-03-20 09:24:11','Am pÄƒÅ£Ã¢t Äƒn tinÄƒreaÅ£Äƒle mele una fainÄƒ cu Ã®ntÃ¢rzÃ¢ietu\'. Am avut \"o ÅŸedinÅ£Äƒ\" ÅŸi am dormit la ea pÄƒstÄƒ noapte.Normal, de la 6 dimineaÅ£a aveam matinal la radio. Normal, nu m-am dus. Anormal, ma suna ÅŸefu\'pe la opt. Dormeam ÅŸi ca prin vis ridic receptorul de la capÄƒtul patului ÅŸi, senin ca-n prima zi a vieÅ£ii mele, Ã®mi iese rÄƒspunsul standard de dimineaÅ£Äƒ \"radio X matinal,bunÄƒ dimineaÅ£a\". Åžeful meu, incantat probabil de faptu cÄƒ ÅŸi-n vis visam tot radio m-a iertat. Åži de gentleman ce era nici nu m-a intrebat de ÅŸedinÅ£Äƒ.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12','',0,0),(19299,1035,'Andreea','puistrulet2003@yahoo.com','http://n/a','81.196.150.196','2008-03-20 17:56:51','2008-03-20 15:56:51','@hadean: Trebuie sa recunoastem, intrebarea era perfect legitima, si denota o sinceritate a personajului principal si  inseamna ca el se simtea suficient de confortabil cu persoana de sex opus incat sa abordeze subiecte atat de intime.\r\nPudicii sa se abtina :)...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19752,1039,'ametzitul','','http://ametzitul.wordpress.com','62.217.236.12','2008-03-25 08:31:56','2008-03-25 06:31:56','mda, vazusem shi io p-un site tot felul de explicatzii despre originea unor cuvinte pe care noi le credeam dacice chiar :) era tare shi aia cu pogaschen... dac-asha se scria.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(19754,1039,'VÄƒraru','spargvaluri@yahoo.com','http://vararu.blogspot.com','79.119.221.181','2008-03-25 08:41:08','2008-03-25 06:41:08','ÃŽn francezÄƒ e mai fainÄƒ traducere la damigeanÄƒ, dame-jeanne :&gt;\r\nSau Ã®n engleza la derutÄƒ, give me eyelash.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(18884,1029,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-03-17 11:58:34','2008-03-17 09:58:34','@ Ametitul: dap. Da\' si unguroici, tuca-le-ar tata!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(18883,1029,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-03-17 11:58:12','2008-03-17 09:58:12','Mo,.. asa-i. \r\n\r\nIo nu le pre am cu limbile, daca ma-ntelegi, d-aia fac gafuri. Adica gafe.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(18882,1029,'Basty','sebastian@centre-roumain.fr','http://basty.wordpress.com','82.77.126.21','2008-03-17 11:48:29','2008-03-17 09:48:29','Imaginea ta despre limba maghiara mi se pare discriminatorie. Ea nu se limiteaza la â€œkekerekerekekrreekree!â€ . \r\n\r\nO reprezentare mai exacta ar fi â€œ kekerekerekekrreekree.... ioi ! â€',0,'1','Mozilla/5.0 (Macintosh; U; Intel Mac OS X; en) AppleWebKit/523.12.2 (KHTML, like Gecko) Version/3.0.4 Safari/523.12.2','',0,0),(18879,1029,'ametzitul','','http://ametzitul.wordpress.com','62.217.236.12','2008-03-17 11:22:13','2008-03-17 09:22:13','Mah... ieste oameni shi oameni. Shi unguri :) Glumeam...',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(19125,1031,'iohonney','redhotbiglips@yahoo.com','http://iohonney.blogspot.com','86.121.108.70','2008-03-19 09:53:22','2008-03-19 07:53:22','eu in 4 ani de liceu am nimenit numele colegei de langa mine de vreo 3-4 ori.stiam ca e colega mea,uneori imi aduceam aminte ca numele ei incepe cu \"A\" dar de cele mai multe ori ma uitam tamp la ea pana se intorcea spre mine si abia atunci ii spuneam ce aveam de spus.\r\nam mai patit sa ii spun unei persoane in loc de Petronela,Izabela.o strigam si pe strada asa.mi se parea ca e mai potrivit decat numele ei.  :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19060,1030,'hadean','contact@adihadean.com','http://www.adihadean.com','194.102.126.6','2008-03-18 14:49:33','2008-03-18 12:49:33','Apoi noah, io Å£-oi spune tu  Andree, domnucÄƒ  dragÄƒ, cÄƒ numa din cÄƒrÅ£ de colorat nu faci brÃ¢nzÄƒ ,ca de la naturÄƒ, noah. O ca din sÄƒmÃ¢nÅ£Äƒ. SÄƒ nu-Å£ mai spui ce fain Ã®i sÄƒ faci miÅŸtou de alÅ£Ã®Ã®, mai ales dacÄƒ Ã®s mai tolomaci aÅŸe, da\' iei tÄƒt susÅ£Äƒn cÄƒ noi suntem. Noah.Bine? CÄƒ amu mÄƒ inervez, cÄƒ  aud la cela ni Ã®n gurÄƒ cÄƒ maimuÅ£Ã®Ã® au numa un milion de peri pÄƒ cap, ÅŸi io ÅŸtiu cÄƒ au mai mulÅ£.\r\nÅži mai ÅŸtiu cÄƒ ocÅ£identalii ÄƒÅŸtia numa Ã®ÅŸ proiecteazÄƒ spaimele ÅŸi fustÄƒrile pÄƒ care le trÄƒiesc cÄƒ-s dobitoci, Ã®n tÄƒte epocile ÅŸi filmele, cÄƒ nu mai te poÅ£ uita la un film fÄƒrÄƒ teroriÅŸti, turbance ÅŸi albi mai tari ca negrii o mÄƒcar conducÄƒtori da\' maleabili.Ioi cÄƒ mÄƒ ie cu hepticÄƒ ÅŸi mÄƒ lÄƒs de scris amu,mÄƒ duc sÄƒ ascut Å£Äƒruza.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12','',0,0),(18912,1029,'Andreea MKT','supergirgir@yahoo.com','http://marlahermina.deviantart.com/gallery/','82.77.126.254','2008-03-17 15:36:10','2008-03-17 13:36:10','@mo: fecking dog.\r\n\r\n@gro: cea mai tare propozitie in maghiara este \"meny haza huligan!\"o folosesc zilnic cand iubitul meu imi cere de mancare. si nici macar nu e ungur.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; InfoPath.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(19960,1045,'catalin','catalin_heghes@yahoo.com','http://heghes.blogspot.com','84.232.142.163','2008-03-28 19:14:05','2008-03-28 17:14:05','io cred ca decesul domniei sale nu este constitutional, deci trebuie sesizata curtea, deisgur, constitutionala',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1)','',0,0),(18955,1029,'Mo','verde_poveste@yahoo.com','','86.120.170.201','2008-03-17 18:45:44','2008-03-17 16:45:44','@ Andreea MKT: cam scotian accentu\', da\' daca asa se saluta pe blogu\' asta nu ma pot opune :)\r\n\r\nAM dat acuma un search pe gugal ca sa aflu mai multe diferente intre mai sus-numitele neamuri de ratangii si tre sa declar ca irlandezii is si mai luzari decat noi, nu din cauza ca si-o tot iau la caca de la engleji, da\' din cauza ca cica de ziua nationala manca pireu amestecat cu varza. \r\nPai sa vina la noi de 1 decembrie, sa bage un mega-gulas ori ciolan cu fasole, sa vezi dup-aia cum se imblanzesc...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19945,1044,'Andreea','puistrulet2003@yahoo.com','http://n/a','81.196.150.196','2008-03-28 15:23:23','2008-03-28 13:23:23','@Groparu\', bjetu de tine esti victima unor jucatori (carora probabil nu le-o cazut casu de la bot) care sufera de-a dreptu cand cyber - copchiii lor is atacati de alde ca tine si dezvoltand acele sentimente paterne is dispusi sa mearga pana acolo incat sa te scoata din lumea lor ca pe un nevrednic ce esti. Nu meriti sa pasesti virtual si sa papi mancarica lor virtuala!!!Asa-i Gropare?  \r\nIi de admirat totusi ca pot avea asemenea sentimente de apartenenta la un grup si ii inteleg ca si io am jucat rpg-uri de-astea dar chiar pe bune, in fata blocului cu alti copchii numai ca pe atunci moacele jucatorilor erau chiar moacele noastre :) .....Traiasca copilaria',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(19677,1038,'hadean','contact@adihadean.com','http://www.adihadean.com','194.102.126.6','2008-03-24 12:47:10','2008-03-24 10:47:10','io am colegi in birou care au mult mai mult spatiu verde pe dinti decat un bucurestean pe cap de locuitior.no!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12','',0,0),(19678,1038,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-03-24 12:48:11','2008-03-24 10:48:11','Spanacu\'?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(18965,1029,'Andreea MKT','supergirgir@yahoo.com','','89.43.186.64','2008-03-17 19:35:27','2008-03-17 17:35:27','@Mo, Gro, andreea si ametitul: Cica irlandezii beau o bere neagra, slab alcoolizata, bautura care unita cu vremea lor cetoasa, ploioasa si de cacat, i-ar face sa spuna ceva de genu \"cu vremea asta, ce mi-e cam is beat, ce mi-e ca is treaz, totuna e\"\r\n\r\n@Tot voi: Irlandezii l-au dat pe al mai gay si mai mijto barbat din istorie, Oscar Wilde, care avea multe dume in program (Groparu le-a invatat pe toate si ne mai da un citat din Wilde in pauza de tigara). Si Oscar Wilde asta a zis sumedenie de dume, printre care ceva cu stele si cu mocirla si cu uitatul in sus, chestie care depaseste iq-ul meu cu mult.\r\n\r\n@Tot voi: adanc, mai adanc, ioi...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(18967,1029,'Andreea MKT','supergirgir@yahoo.com','','89.43.186.64','2008-03-17 19:39:02','2008-03-17 17:39:02','@Tot voi: irlandezii is pentru englezi un fel de \"fratii de pisti Prut\"',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19065,1030,'hadean','contact@adihadean.com','http://www.adihadean.com','194.102.126.6','2008-03-18 16:00:44','2008-03-18 14:00:44','Ioi mulÅ£am, Å£ucu-te:-)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12','',0,0),(19066,1025,'yesterdayman','yesterdayman@gmail.com','http://blog.patratel.ro','81.12.172.54','2008-03-18 16:19:34','2008-03-18 14:19:34','Ciudat... si io am patzit la fel... si la fel am facut, am sunat la UPC, mi-a zis tanti ca vine interventzia... dupa care am apasat pe acelasi buton.\r\nDrept pentru care nu ma pot opri sa nu remarc urmatoarele:\r\n1. nu mergea netu\'\r\n2. sunat la UPC\r\n3. spus ca vine interventia maine sau poimaine\r\n4. apasat butonu pauar\r\n5. multa lume a patzit-o\r\n\r\ndrept pentru care io zic ca tot merita sa-i reclamam p-astia de la UPC: sigur au bagat ceva in modemuri de se intampla la atata lume treaba asta!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(19062,1030,'Andreea','puistrulet2003@yahoo.com','http://n/a','81.196.150.196','2008-03-18 15:45:36','2008-03-18 13:45:36','No numa nu te ienerva ca n-am dat cu paru\' (sau bata preistorica :) ) \r\nNici mie nu-mi plac mesajele \"subtile\" transmise de americani in filmele lor, mai ales cand stiu ca is o natie \"not very bright\" (si e bine ca au si ei un George Carlin care mai face misto de ei- which is good btw); da ce sa faci daca is si multi, au si o groaza de bani si la ei filmele ies pe banda rulanta... si le mai si place sa isi zgandare orgoliu cu astfel de filme... tot ce putem sa facem e sa nu le acceptam (sa nu le vedem, corect?)\r\nSi ca sa te imbunez da tot uite iti recomand un film care sper sa-ti placa daca nu l-ai vazut cumva: Into the wild...\r\n\r\nSpor',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19284,1034,'Andreea','puistrulet2003@yahoo.com','http://n/a','81.196.150.196','2008-03-20 15:31:59','2008-03-20 13:31:59','No auzi aci Gropare (asta am primit-o pe mess)\r\n\r\n\"Presedintele Statelor Unite ne-a cerut sa ne unim pentru o cauza comuna tuturor: combaterea terorismului. Este bine stiut ca musulmanii se opun consumului de alcool si considera vederea unei femei dezbracate (alta decat nevasta sa) drept un pacat. Din aceasta cauza lansam un apel pentru ca timp de o saptamana, ZILNIC, la ora 13.00, toate femeile sa se dezbrace complet si sa alerge prin birouri, iar toti barbatii sa le urmeze cu o bere in mana. Aceasta ne va ajuta sa detectam teroristii care se ascund la noi in firma. Statele Unite va sunt recunoscatoare pentru efortul facut impotriva terorismului. Colaborati! Trimiteti acest mesaj tuturor colegilor de la serviciu si tuturor firmelor partenere! \"\r\n\r\nAm doo intrebari:\r\n\r\nTu ai initiat spamu asta?\r\n\r\nsi daca nu\r\n\r\nCe-ti place mai mult din idee, berea in mana sau femeia goala in fuga? :) :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19129,1031,'broodwar','broodwar7@gmail.com','','193.90.144.66','2008-03-19 10:24:14','2008-03-19 08:24:14','evident ca nu tin niciodata minte numele prezentate\r\ndar avand un nume usor de tinut minte (ha ha), sper sa isi aduca aminte ceilalti, si eu sa nu mai am neoie',0,'1','Opera/9.26 (Windows NT 5.1; U; en)','',0,0),(19057,1030,'Andreea','puistrulet2003@yahoo.com','http://n/a','81.196.150.196','2008-03-18 14:15:21','2008-03-18 12:15:21','De ce sunteti rai? \r\nBjetu om s-o chinuit sa deseneze si sa coloreze paserile si maimutii cu ajutorul unei armate de oameni, deci ar trebui sa merite ceva mai mult decat un \"hai sictir\" si un pachet de seminte de dovleac...\r\n\r\nSpor la critici,\r\nAndreea',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(18629,1021,'eu','ioana_g_ro@yahoo.com','','84.232.144.83','2008-03-16 15:39:54','2008-03-16 13:39:54','de fapt acum poate sa le citeasca proasta dracului ca si asa tot aia e! zi\'le gropare zi\'le mama lor de comunisti in gujet si simtiri. manageri my ass... si cei care vin manageri se transforma mai ceva ca in power rangers in sefi...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.11','',0,0),(18899,1029,'hadean','contact@adihadean.com','http://www.adihadean.com','194.102.126.6','2008-03-17 14:18:53','2008-03-17 12:18:53','@ Paszti:Ioi, ultima data cand am trecut prin Budapesta a fost noapte si eram la cateva sute de metri deasupra orasului benocland dup[ un aeroport(mi-au placut luminile, totusi). Poate apuc pana la vara sa fac o excursie acolo.La Debrecen si Gyula stiu ca-i fain tare. Si Rozsika de la crasma la care am mancat inainte de Beretujfa..cumva(nu stiu a scrie, nu vreu a poci) e faina si ea, tucu-i bobgulyasu astazi si data viitoare. Apoi no, salutam cu onor drapelu\' Budapestei si chiar putem bea si in cinstea lui ca legile fizicii care asigura curgerea functioneaza si aci ca la Buda si la Pesta.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12','',0,0),(18628,1021,'eu','ioana_g_ro@yahoo.com','','84.232.144.83','2008-03-16 15:38:17','2008-03-16 13:38:17','si voi nu va doriti sa o cunoasteti pe directoarea mea ... hmmm... postul asta parca e scris pentru ea... cu dedicatie... si sper sa nu ajunga sa citeasca niciodata comentariile :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.11','',0,0),(19154,1031,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-03-19 14:51:44','2008-03-19 12:51:44','@ anonimul: =))=))=))=))=))=))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(18895,1029,'Paszti','pasztorjozsef@yahoo.com','','81.12.230.166','2008-03-17 13:54:27','2008-03-17 11:54:27','@hadean\r\n\r\nNu trebe drapelul Ciadului ci al Budapestei, care este rosu-galben-albastru.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727)','',0,0),(18610,1029,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2008-03-16 11:58:05','2008-03-16 09:58:05','Da!\r\n\r\nMa bucur ca in sfarsit cineva a inteles cum sta problema cu ungurii, si cum submineaza ei si groparii regia autonoma - singura regie din Romania care nu e semnata Sergiu Nicolaescu.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(18891,1029,'Basty','sebastian@centre-roumain.fr','http://basty.wordpress.com','82.77.126.21','2008-03-17 13:10:08','2008-03-17 11:10:08','@Groparu: EÅŸti prea modest. Gafuri e corect. Precum e corect ÅŸi umbreli, ÅŸezlongi sau pipilicuri. \r\n\r\nUMBRÃ‰LÄ‚, umbreli, s.f. Obiect alcÄƒtuit dintr-o pÃ¢nzÄƒ care se poate strÃ¢nge sau Ã®ntinde (Ã®n forma unei calote sferice) prin intermediul unor spiÅ£e metalice fixate radial pe un baston, destinat sÄƒ apere de ploaie sau de soare. â€“ Din fr. ombrelle (dupÄƒ umbrÄƒ). \r\n\r\nÅžEZLÃ“NG, ÅŸezlongi, s.n. Scaun pliabil pe al cÄƒrui schelet de lemn sau de metal este montatÄƒ o pÃ¢nzÄƒ ÅŸi al cÄƒrui spÄƒtar mobil se poate Ã®nclina dupÄƒ preferinÅ£Äƒ. â€“ Din fr. chaise-longue. \r\n\r\nPÃPI, pipilicuri s.m. (Fam.) UrinÄƒ. [Acc. ÅŸi: pipÃ­] â€“ Din fr. pipi.',0,'1','Mozilla/5.0 (Macintosh; U; Intel Mac OS X; en) AppleWebKit/523.12.2 (KHTML, like Gecko) Version/3.0.4 Safari/523.12.2','',0,0),(18621,1029,'baranykaa','birtalan.csanad@gmail.com','http://baranykaa-ro.freeblog.hu','92.82.50.223','2008-03-16 13:58:08','2008-03-16 11:58:08','20 lei costa un bilet cu suprataxa...\r\ndaca aveti chef sa cititi si acest articol... tot despre RATUC:\r\n\r\nhttp://baranykaa-ro.freeblog.hu/archives/2008/03/15/Ce_drepturi_are_un_ofer_RATUC/',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(18608,1029,'ovi66','ovidiulechintan@yahoo.com','http://ovidiu666.wordpress.com/','79.116.89.105','2008-03-16 11:50:22','2008-03-16 09:50:22','deci pana si ungurii (in colaborare cu romanii) trag in piept transportul local! :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(18918,1029,'Andreea','puistrulet2003@yahoo.com','http://n/a','81.196.150.196','2008-03-17 16:13:32','2008-03-17 14:13:32','@ Andreea MKT: super tare expresia :)))).\r\nMi-am adus aminte de vremea cand eram copchil la camin cu sortuletul albastru vesnic patat cu suc de galbenele (ca ne tavaleam ca porcii in iarba) si eram impartiti pe 2 grupe: noi si ungurii; si mereu la unguri le strigam \"befele in clasa\" care naiba stie ce inseamna (da stiu ca suna funny :))))); si de atunci stiu ca erau rasboaie de guerilla intre noi si copchii unguri (foarte trist dar adevarat) - rasboaiele astea se soldau mai mereu cu vanatai si zgarieturi suferite de grupu lui frate-meu, care era o javra si amu ii softist si grupu lor (de care nu stiu daca is softisti sau nu ...); n-am stiut niciodata cine detinea suprematia leaganelor...\r\nDar sa se stie ca mie imi plac mult maghiarii, am o prietena f buna care-i juma unguroaica (si morosanca pe deasupra) si cel mai bun tort(miam miam) l-am mancat la vecina mea, tanti Haraszti....Ah si instructoarele mele de la sala is unguroaice....Need to say more?\r\n\r\nSzerusz (nus daca am scris corect da intentia conteaza)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(18613,1029,'you wanna...','','','92.82.38.244','2008-03-16 12:44:41','2008-03-16 10:44:41','da stie cineva cat costa un bilet cu suprataxa? pe ratuc?ca scrie in regulamentu lor ca daca esti de acord sa platesti bilet cu suprataxa atunci nu ti se mai face nici proces-verbal, nu mai capeti nici amenda si trebe sa ti dea controlorul si chitanta\r\nART. 13. ÃŽn cazul Ã®n care contravenientul care a circulat fÄƒrÄƒ legitimaÅ£ie valabilÄƒ Ã®n mijlocul de transport achitÄƒ pe loc agentului constatator aparÅ£inÃ¢nd personalului R.A.T.U.C. contravaloarea unui bilet cu suprataxÄƒ, nu se mai Ã®ncheie proces verbal ÅŸi orice urmÄƒrire Ã®nceteazÄƒ. Plata amenzii se face pe baza unei chitanÅ£e eliberatÄƒ de R.A.T.U.C. prin agentul constatator.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19318,1034,'WhiteWolf','contact@white-wolf.ro','http://white-wolf.ro','89.39.82.130','2008-03-20 20:54:36','2008-03-20 18:54:36','Daca shepu\' ala al tau (cu solzi) si viforos pe vreme de ploae mai aude multe chestii de genul asta, risti sa trezesti cin\' stie ce invidii din alea nasuoale prin el. Si daca il determini sa se simtzÃ£ atacat la horgoliul de mascul shef de turma si dominant care se crede - ca altfel nu il puneau el lider maximo- se prea poate sa inceapa sa se zbarleassca mai ales cand aude astfel de explicatii.\r\nRiscant, asadar, jocul tau :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19930,1045,'hadean','contact@adihadean.com','http://www.adihadean.com','194.102.126.6','2008-03-28 10:15:48','2008-03-28 08:15:48','jos ÅŸapoul Ã®n faÅ£a lu\' domnia sa. nu-s tomna de acord cu faza asta pe care ne-o facut-o da nu prea te poÅ£i pune...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12','',0,0),(19328,1032,'SIBILLA','sibilla_poesis@yahoo.com','http://sfinx667.wordpress.com','89.123.57.36','2008-03-20 22:30:42','2008-03-20 20:30:42','adica, intru io pra blogu lu Groparu da pasnica cie mi-s , cu ganduri bunie, sa cier scuza in numilii banatanilor ca narodu, \" traznil-ar\" sa puschiel mama padurii l-o banat pe omu asta al fain... si.. ce sa vezi pra asi... iacata unii care zac urat de mumilii si maicilii si mamilie noastrie...pra cuvantu vostru ca va tznie sau numa zacieti sa voi...???\r\nstai cumincie Groparule ca Banatu cie iubiescie, ala o fii ca-i vro uscatura, vinitura, no fii da pra la noi d-asiia..., da, cum aflu cieva cum cie anunt musai si il pun sa-ti cumpirie si o rachie, ca sa-ti spiele rusania si lui nu-i dau nici o pivo sa-si spielie pacacilii, bata-l mama lu Dumnizau sa-l mancie tarpia da vinicic cum nie facie el da mir in lumie...\r\ncie tzuca banatanii mei cu drag, sa traiesci ma omule, casci tarie fain\r\nzdravo sa sa nu cii supiri pra noi toti,\r\nmaica Sibilla ( da pra la Rasita)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; SIMBAR={5E84BDD4-ACDC-11DC-8BCA-001A4D8E0E14})','',0,0),(19294,1034,'Andreea','puistrulet2003@yahoo.com','http://n/a','81.196.150.196','2008-03-20 17:05:34','2008-03-20 15:05:34','E nu ma-ntarzii niciodata :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19295,1035,'hadean','contact@adihadean.com','http://www.adihadean.com','79.113.58.8','2008-03-20 17:20:58','2008-03-20 15:20:58','unu\' ave un pretin mai tÄƒntÄƒlÄƒu aÅŸe,no, Ã®nÅ£Äƒleji. aÅŸe de tÄƒntÄƒlÄƒu cÄƒ numa nu sÄƒ pute aproptie de o gajicÄƒ, nimnica-n lume.no, apoi Äƒsta care nu iera aÅŸe tÄƒntÄƒlÄƒu Ã®i zÃ¢ce la Äƒlalalt:\r\n-bÄƒ tu ejti cam prost, aÅŸe-i?\r\n-aÅŸe\r\n-bÄƒ Å£Ã¢ie Å£Ã® ruÅŸine sÄƒ vorbeÅŸti cu iele,aÅŸe-i?\r\n-aÅŸe\r\n-apoi o sÄƒ fuÅ£ tu cÃ¢nd zbura porcu ca fluturii din stomac de la ceie de mai sus dacÄƒ nu facem ceva.fii atent, bagÄƒ-Å£ minÅ£Ã¢le-n cap, traje aier Ã®n foale ÅŸi scoate-o pÄƒ una Ã®n oraÅŸ la film cÄƒ acolo nu-i de vorbit mult, o mozoleÅŸti bine, mereÅ£ acasÄƒ ÅŸi vÄƒ fuceÅ£.bine? ÅŸi dacÄƒ nu-Å£ iesÄƒ mÄƒ suni pÄƒ celular ÅŸi te Ã®ndrum.ochei?\r\n-ochei no.\r\ntrec aÅŸe o doi ani de la discuÅ£ia asta pÃ¢nÄƒ Ã®ÅŸi ie mutalÄƒu inima-n dinÅ£, o scoate pÄƒ maricica la film, acolo nici on mozol cÄƒ Äƒsta era cam no, nu vorbesc nimnic pÃ¢nÄƒ-i gata filmu.apoi la urmÄƒ Äƒsta zÃ¢ce:\r\n-tu, merem la mecdonalds la restaorant sÄƒ bÄƒgÄƒm ceva la maÅ£?\r\n-ihÃ¢, zÃ¢ce ie jentil ÅŸi burghez\r\nno, dupÄƒ o jumate de ceas de tÄƒcere la mecdonalds cu proastu acela care sÄƒ holba la ii doi, fata sÄƒ scuzÄƒ un pic sÄƒ margÄƒ la un piÅŸu o ceva.Äƒsta micu pune mÃ¢na repide pÄƒ telefon, Ã®l sunÄƒ pÄƒ dejdeÅ£atu de pretinu-so:\r\n-bÄƒ, Ã®s moale ca fÃ¢nu, Ã®s cu asta la mecdonalds ÅŸi nu am scos o vorbÄƒ Ã®n puii mei, ce dracu sÄƒ fac_\r\n-bÄƒ, fii atent, nu te pterde cu sÃ¢njele, cÃ¢nd vine fata de la cabine o Ã®ntrebi ceva ÅŸi apoi stai sÄƒ-Å£ rÄƒspundÄƒ.apoi sÄƒ ÅŸtii tu cÄƒ astea cÃ¢nd sÄƒ dau la vorbÄƒ le cam dezvoltÄƒ, Å£-a lÄƒsa vreme bucÄƒtÄƒ sÄƒ-i mai pregÄƒteÅŸti o Ã®ntrebare.cÃ¢nd gatÄƒ de rÄƒspuns la prima o baji pÄƒ a doua ÅŸi din trii Ã®ntrebÄƒri simpl gata sara, mereÅ£ acasÄƒ ÅŸi vÄƒ fuceÅ£.bine?\r\n-bine no, hai taci din gurÄƒ cÄƒÅ£ Ã®nchid, cÄƒ ni, vinie.\r\napare fata, sÄƒ aÅŸazÄƒ la masa aia frumoasÄƒ de la mecdonalds, sÄƒ uitÄƒ la iel cu zglibanii umezi de la aeru conduiÅ£ionat ÅŸi iel aruncÄƒ Ã®ntrebarea:\r\n-NO, CUM ÃŽI, TE-AI CÃ‚CAT?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19291,1034,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-03-20 16:27:46','2008-03-20 14:27:46','Si? Ti-ai venit, sau ti-ai intarziat?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19289,1034,'Andreea','puistrulet2003@yahoo.com','http://n/a','81.196.150.196','2008-03-20 16:20:28','2008-03-20 14:20:28','Ma asteptam...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19286,1033,'ametzitul','','http://ametzitul.wordpress.com','62.217.236.12','2008-03-20 15:56:39','2008-03-20 13:56:39','Nu te lua de d-astea mici, ca daca s-apleaca un pic poate da cu capu\' exact unde doare mai tare :) cap in cap, adica ;)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(19271,1034,'Andreea','puistrulet2003@yahoo.com','http://n/a','81.196.150.196','2008-03-20 14:21:58','2008-03-20 12:21:58','Deci n-ai voie sa faci nimic in post? Deloc? Atatea saptamani?????????????\r\n\r\nNu ma mai joc...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19272,1034,'Catzaua','ana.man.fox@gmail.com','','81.180.173.61','2008-03-20 14:23:13','2008-03-20 12:23:13','bag de sama ca groparu\' nost compenseaza la greu privatiunile auto-impuse cu prilejul postului printr-o \"curvoada\" cat se poate de placuta [si a draq de frecventa].\r\n\r\nvezi sa nu te stafidesti :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19185,1032,'galatzi','road2h3ll@yahoo.com','http://www.nuamblog.ro','78.96.200.177','2008-03-19 19:58:34','2008-03-19 17:58:34','gropare, fi-le-ar filtrele de tot rasuâ€™â€¦. Nici eu nu pot sa te citesc :(\r\n\r\nDe unde pornografie la groparu\' ??? De unde ??? Sa fie de vina faptul ca esti pornografic de bun ... Tu ala care esti pentru blogosfera ca si Jenna Jameson, Alina Sugaru si Sandra Romain (la un loc) pentru aia mici si cu bataturi in palme ;)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19177,1032,'IepurasulAtomic','praetorian21uk@yahoo.com','http://iepurasulatomic.weblog.ro','192.100.130.7','2008-03-19 18:17:11','2008-03-19 16:17:11','Azi bag sama ca s-a foit Pilif in mormant (fie-i tzarana ushoara), ca cenzura si-a facut de cap azi. Semn clar ca CNA-ul nu doarme niciodata. A vrut un prieten sa-mi comenteze o postare si primea o eroare de \"validare\". El credea ca nu-i valideaza codu\' ala bleg anti-spam, da\' nu era asha. Nu-i valida comentariul, ca scrisese \"piz*a\" fara stelutza, asha cum invatzase de la scoala. Abia astept sa moara pudicii astia carora le transpira timpanele cand aud pornashuri.\r\n\r\nVreau si eu sa ma alatur comitetului care-ti multumeste pentru linkuri si tin sa-ti spun ca le voi folosi in scop medical. Este o vorba: \"Constipated people don\'t give a shit; Impotent people don\'t give a fuck!\"',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(19178,1032,'IepurasulAtomic','praetorian21uk@yahoo.com','http://iepurasulatomic.weblog.ro','192.100.130.7','2008-03-19 18:19:07','2008-03-19 16:19:07','Am zis azi de 2 ori?! Ce bou is...ma rog, iepurash cu coarne?! Dap, am cacofonit-o, nu va mai zburlitzi asha!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(19181,1031,'Totolica','fun4toto@yahoo.com','http://totolici.wordpress.com/','89.137.69.31','2008-03-19 19:34:58','2008-03-19 17:34:58','nenea da\' na eu Ã®nÅ£eleg cÄƒ ai probleme cu memoria dar totuÅŸi cam cÃ¢t ziceai cÄƒ ai vreo 50, 60? :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.0.7) Gecko/20060909 Firefox/1.5.0.7','',0,0),(19201,1032,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2008-03-19 23:34:24','2008-03-19 21:34:24','@ Anonymous: azi da, maine - cine stie?\r\n\r\nDa\' di ce intrebi, si tu vrei sa imi dai in gura?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19190,1032,'dannydagoat','dannydagoat@yahoo.com','','89.137.112.116','2008-03-19 20:53:23','2008-03-19 18:53:23','Mersic de linkurile alea Gropareeee, e toate unul si unul. Cat despre porno, cre\' ca aia stiu la ce te gandesti tu de fapt cand scrii... zic si io...',0,'1','Opera/9.24 (Windows NT 5.1; U; en)','',0,0),(19184,1032,'galatzi','road2h3ll@yahoo.com','http://www.nuamblog.ro','78.96.200.177','2008-03-19 19:56:14','2008-03-19 17:56:14','gropare, fi-le-ar filtrele de tot rasu\'.... Nici eu nu pot sa te citesc :-',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19180,1031,'hadean','contact@adihadean.com','http://www.adihadean.com','79.113.86.26','2008-03-19 18:32:49','2008-03-19 16:32:49','@groparu:ma bucur ca te-ai ras,io era cat pe ce sa apar in ziar pe pagina cu bobbit:-))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19973,1044,'Ionut','ioau@yahoo.com','','89.34.225.25','2008-03-29 00:47:36','2008-03-28 22:47:36','Iti mai bag cateva :)\r\n\r\n\"S. a scris: auzi eu sunt nou in joc si am si eu o nelamurire....dupa ce o sa ma dezvolt am vazut ca in casa de cultura pot sa fac mica petrecere....si daca la petrecere se inbata invitatii si se fut nu mi creste populatia ca doar femeile raman gravide nu\"\r\n\r\n\r\n\"\"un forumist\" s-a suparat tare pe un tip care il catapulta si i-a raspuns cum se pricepea mai bine... Am primit de la el discutia urmatoare (mh-ii nu au primit-o, din cate stiu, deci nu a fost banat):\r\n\r\n \r\n\r\nda..atunci treaba cu contul asta s`a termiant si de acum incep cu injuraturi pt ca nu mai am nimic de pierdut asa ca: o fut pe mata\r\ndar rau de tot\r\npana o las gravida\r\nataci fmm de boul draq fara motiv..am beciuri? si ce vrei sa fiu ferma? O AM PE MATA IN BECI!\r\nraporteazama la mh...imi bag pula in tine si in mh\r\nma doar undeva\r\npoti sa catapultezi\r\niar ma doare undeva\r\ndute draq de bou\r\nde inapt\r\nde jegos\r\nde cretin\r\nn`ai nici un motiv\r\nti`ar placeea ca un idiot sa vina si sa te catapulteze , pe langa ca esti farmat de 3 si sa iti zica senin \"pt ca ai beciuri\"\r\nce in beciurile alea am futut`o pe mata si a iesit un copil muist ca tine\r\ndute draq\r\ninca odata\r\nnu mai suport\r\nnu cred ca intelegi\r\ndaor n`ai creier\r\nsi ce ca am beciuri? fii calm nu se fac violuri acolo\r\nce vrei sa fiu farmat?\r\n`ten mm de bou\r\nsa las pe altii sa`mi ia resursele?\r\nfmm\r\nnici nu gandeste\r\nde spiculant ce esti\r\nesti un rahat cu ochi\r\nsi nu ai cum sa scpati de contul asta\r\nesti doar un ***\r\nfmm de bouuuuu\r\nde cretin\r\nde idiot\r\nNU MAI SUPORT\r\nai atacat fara un motiv real\r\ndoar vrei sa distrugi munca unu om\r\nde 1 luna\r\nm`am chinuit sa ajung aici\r\ncu atatia care ma farmau\r\nsi tu vii ca o pula retardata\r\nsi ma atacci\r\nSITI SE PARE NORMAL???\r\nce ti`e ciuda ca am beciuri? fa si tu copil retartat ce esti\r\ndute draq inca odata si spor la catapultat\r\nfac alt cont..total diferi\r\nsa nu stii ca`s eu\r\ndar oricum\r\nte tin minte ca cel mai mare rahat in care am calcat in viata mea...\r\nsper sa patesti ce am patit eu pe serverul asta\r\nsi sa ai maini scurte si bube la cur sa nu te poti carpina\r\nadio si dute draq a 999 oara\"',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(19471,1036,'Ascutita&#8217;s Weblog','','http://ascutita.wordpress.com/2008/03/22/94/','72.232.131.32','2008-03-22 09:09:02','2008-03-22 07:09:02','[...] as vrea sa vad si raspunsurile lui xul , groparul si akitainu. &#8220;Intrebarile&#8221; sunt cele de culoare [...]',0,'1','Incutio XML-RPC -- WordPress/MU','pingback',0,0),(19978,1044,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2008-03-29 02:10:40','2008-03-29 00:10:40','Ionutz!\r\n\r\nAm ras de m-am cacat pe mine - si tu scuza-ma de limbaj ;;)\r\n\r\nMai hai p-acilea cu asemenea commenturi!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(19846,1042,'L3ST','webmaster@l3st.com','http://www.l3st.com/','89.34.247.119','2008-03-26 14:28:45','2008-03-26 12:28:45','Cert e ca daca a auzit, data viitoare nu va mai lista acolo :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(19845,1041,'mo','verde_poveste@yahoo.com','','194.126.220.22','2008-03-26 13:59:39','2008-03-26 11:59:39','Nu mai glumiti pe chestii morbide....io chiar az\' am programare la dintar si incerc sa nu ma cac pe mine (I suck, da\' mi-i frica de mor :) ) pe chestia asta.\r\nIn alta ordine de idei, daca in dintii cariati nestuiesc resturi de mancare, intr-un bluetooth cariat ce nestuieste?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1)','',0,0),(19882,1043,'Je_?!','florina_audochii@hotmail.com','','194.102.139.9','2008-03-27 09:34:39','2008-03-27 07:34:39','You\'re one sick puppy!\r\nIn a good way ;)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(19883,1043,'IepurasulAtomic','praetorian21uk@yahoo.com','http://iepurasulatomic.weblog.ro','192.100.130.7','2008-03-27 10:18:50','2008-03-27 08:18:50','Eu n-am putut crede ca te gandesti la ce vroiai tu sa crezi ca noi credem ca tu te gandesti, decat daca ai fi fost fecioara. Si ultima oara cand te-am vazut in slipi(la Strand ma, hopsedatilor), ereai barbat. Pen\' ca n-aveai tzatze, nu te gandi la altceva. Da\' de compus ai compus-o misto, si eu clar nu mi-am dat seama despre ce-i vorba pana la final. Da\' pe de alta parte, n-am fost niciodata laudat pentru intelijenta mea.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(19774,1040,'ametzitul','','http://ametzitul.wordpress.com','62.217.236.12','2008-03-25 13:15:10','2008-03-25 11:15:10','Pai fa shi tu ca-n liga lu\' mitica:\r\nin fiecare an unii promoveaza, altzii retrogradeaza.\r\naduna mai multe cereri de aderare shi trage la sortzi :)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(19587,720,'Maya','amarylis_23@hotmail.com','','193.226.7.11','2008-03-23 16:17:14','2008-03-23 14:17:14','As vrea sa iau legatura cu tine.Te-as ruga sa-mi lasi o adresa de mail.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(19422,1036,'macabroo','raduccc@yahoo.com','http://rezistenta.blogspot.com','82.76.52.94','2008-03-21 21:49:34','2008-03-21 19:49:34','Lasa Call of duty-ul gropare...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; en-GB; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19382,1035,'ametzitul','','http://ametzitul.wordpress.com','62.217.236.12','2008-03-21 12:34:33','2008-03-21 10:34:33','mah... a mancat shi ea ce i-a ieshit lui din gura :)\r\ns-a mascarit singur.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(19406,1036,'ametzitul','','http://ametzitul.wordpress.com','62.217.236.12','2008-03-21 17:26:19','2008-03-21 15:26:19','\"ich bin ein berliner\" itzi spune ceva? :)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(19285,1034,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-03-20 15:53:41','2008-03-20 13:53:41','Deci la prima intrebare nu raspund, numa la a doua:\r\n\r\nDa!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19239,1034,'Andreea','puistrulet2003@yahoo.com','http://n/a','81.196.150.196','2008-03-20 09:44:46','2008-03-20 07:44:46','A fost nesimtit.. trebuia sa te intrebe:\"Si a fost bine?\" :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19880,1043,'ametzitul','','http://ametzitul.wordpress.com','62.217.236.12','2008-03-27 08:28:33','2008-03-27 06:28:33','lasa mah postul asta...\r\nori innebuneshti, ori ajungi poet :)\r\nuna n-o exclude pe cealalta...\r\nP.S.: sau ajungi sa scrii pt. plaiboi sau penthaus...',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(19674,1037,'Catzaua','ana.man.fox@gmail.com','','81.180.173.61','2008-03-24 12:24:28','2008-03-24 10:24:28','*woof* like a ..aia, ce ai zis matale',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19897,1043,'candid','adi.covaci@jumpeye.com','http://www.aicarteaiparte.ro','85.186.103.6','2008-03-27 14:07:08','2008-03-27 12:07:08','Interesant delir, mi-a placut!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(19898,1043,'Turambar','mirel@ccsb.ro','http://turambarr.blogspot.com','92.80.16.6','2008-03-27 14:26:40','2008-03-27 12:26:40','Daca te-ai gandit la ce nu ne-am gandit noi, satz fie rushine, violator mic shi oral!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(19664,1037,'hadean','contact@adihadean.com','http://www.adihadean.com','194.102.126.6','2008-03-24 11:18:34','2008-03-24 09:18:34','why my brain is so fucked up?\r\nbecause there is nothing left on the right side and there is nothing right on the left side.i guess.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12','',0,0),(19665,1037,'Catzaua','ana.man.fox@gmail.com','','81.180.173.61','2008-03-24 11:20:02','2008-03-24 09:20:02','good one, hadean. *chapeau*',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19666,1037,'hadean','contact@adihadean.com','http://www.adihadean.com','194.102.126.6','2008-03-24 11:41:04','2008-03-24 09:41:04','ha?fac o clijjÄƒÄƒÄƒ amuuu dÃ¢n dÃ¢n..\r\nmerci mademoiselle Biatch',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12','',0,0),(19484,285,'maria','maria_canatzuli@yahoo.com','','78.97.5.83','2008-03-22 13:24:22','2008-03-22 11:24:22','am vazut ca postarea e de aproape vreun an...nici nu stiu exact cum am dat peste ea...dar am ras cu lacrimi...\"judy\"...=))..=))..fan groparu:P',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; SIMBAR={A2177257-7B50-4BA2-8091-39F0A82935BB})','',0,0),(19912,1043,'manole','mesterulmanole07@gmail.com','http://www.mesterulmanole.wordpress.com','89.32.123.108','2008-03-27 20:11:48','2008-03-27 18:11:48','la asa detaliu...ai ceva experientza cu postul! :)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; SIMBAR={6027D00E-CD16-11DC-9BA8-001B2FCE5715}; .NET CLR 1.1.4322)','',0,0),(19902,1043,'hadean','contact@adihadean.com','http://www.adihadean.com','194.102.126.6','2008-03-27 16:20:25','2008-03-27 14:20:25','ioi pantru o clipa am crzut cÄƒ faci pe dominatrixu\' cu mine dupÄƒ care mi-o picat fisa la chow zun cel.huh.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12','',0,0),(19903,1043,'hadean','contact@adihadean.com','http://www.adihadean.com','194.102.126.6','2008-03-27 16:20:40','2008-03-27 14:20:40','yun, no',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12','',0,0),(19904,1043,'Catzaua','ana.man.fox@gmail.com','http://catzaua.wordpress.com','81.180.173.61','2008-03-27 16:41:38','2008-03-27 14:41:38','@hadean: i didn\'t taste you yet. your food, i mean :D abia pe urma o sa decid daca are rost sa ma obosex sa te dominatricesc sau nu. :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19393,1036,'Andrei','andreibaban@gmail.com','http://andreibaban.wordpress.com/','82.77.126.7','2008-03-21 14:48:55','2008-03-21 12:48:55',':))\r\nTe-ai lasat de fumat? Poi klar ca de aia visezi din astea. \r\nSi io m-am lasat de 3 luni... dar incep sa cred ca ii foarte nesanatoasa miscarea ;)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19680,1038,'Catzaua','ana.man.fox@gmail.com','','81.180.173.61','2008-03-24 12:56:39','2008-03-24 10:56:39','fungus..?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19681,1038,'Catzaua','ana.man.fox@gmail.com','','81.180.173.61','2008-03-24 12:58:24','2008-03-24 10:58:24','Q: stelele verzi-verzi vizibile cel putin de doua ori pe zi pe suprafete de cel putin 20 mp pe baza de stres cauzat la job.. se pun?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19682,1038,'Irina','irina_stresina@yahoo.com','','193.230.183.29','2008-03-24 12:59:28','2008-03-24 10:59:28','Da\' daca io-s bucuresteanca (bleah!) si am baia verde, se pune?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727)','',0,0),(19442,1036,'macabroo','raduccc@yahoo.com','http://rezistenta.blogspot.com','82.76.52.94','2008-03-22 01:35:13','2008-03-21 23:35:13','Dupa cum spuneam \"somnul prietenelor naste monstri\":D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; en-GB; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19399,1036,'IepurasulAtomic','praetorian21uk@yahoo.com','http://iepurasulatomic.weblog.ro','192.100.130.7','2008-03-21 16:19:14','2008-03-21 14:19:14','Ma, eu de vineri dimineata am visat ca rulam un sul de hartie igienica alba. Jur ca nu mint. Au fost mai multe chestii, da\' pe asta mi-o amintesc perfect. Atunci am stiut ca ziua de astazi(adeca vineri) va fi cacacioasa rau de tot. Nu m-am inselat, pana acum...',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(19400,1036,'julius constantinescu','julius@universitateacraiova.ro','http://www.7plus.ro/?arhiva=21/03/2008&#38;id=3751','84.232.169.91','2008-03-21 16:55:06','2008-03-21 14:55:06','Da, ma, si pe mine ma enerveaza visele astea. Is supercompetent in orice, stiu limbi straine la greu, umblu cu gagici numa\' de la Claudia Schiffer in sus, am bani de ma-nerveaza, cateodata iau si Nobelul... Nu-ti zic cum bate Craiova in vis la Milan si Barcelona ca la fasole... Pe de alta parte, cred ca-i mai bine decat sa fiu Bill Gates in realitate si sa am noaptea cosmaruri ca-s Julica... Plm, nu m-as odihni deloc.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19376,1035,'10MBC','alin.banc@gmail.com','','217.156.21.3','2008-03-21 11:28:12','2008-03-21 09:28:12','vroia sa treaca direct la fapte dure si s-a asigurat inainte',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19924,1044,'hadean','contact@adihadean.com','http://www.adihadean.com','194.102.126.6','2008-03-28 08:36:55','2008-03-28 06:36:55','Am vazut copil de 8 ani jucand counterstrike cu tata-so. am vrut sa-l frag-uiesc pe tata(de-a dreptul) si sa-l pedepsesc aspru pe copil pe cale materna cumva.nu s-o putut nici una nici alta. Nu stiu cum poate arata jocul asta de zici tu despre el da stiu ca ar trebui clar facute niste teste de imbecilitate inainte de a fi lasat omu\' sa procreeze. La 12 ani n-ai ce sa joci mai mult de Tetris.Hai, Super Mario.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12','',0,0),(19409,1036,'Andreea','puistrulet2003@yahoo.com','http://n/a','81.196.150.196','2008-03-21 18:19:52','2008-03-21 16:19:52','@ Groparu: eu ma bucur pt tine ca ti-ai adus aminte de ce anume ai visat (atatea detalii :) ) - it\'s very nice- insa sa stii ca mie mi-a spus cineva mai demult ca daca razi in somn, a doua zi o sa plangi ... :D\r\n\r\nDeci ia zi Gropare, o smiorcaiala ceva pe ziua de azi?\r\n\r\nAndreea \r\n\r\nPS: io chiar am patit-o....',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19384,1036,'hadean','contact@adihadean.com','http://www.adihadean.com','194.102.126.6','2008-03-21 13:20:45','2008-03-21 11:20:45','no, ÅŸez cuminte cÄƒ nu ieÅŸti numa tu defect Ã®n vis.amu cÃ¢teva nopÅ£ (n-am zÃ¢s la nime Ã®ncÄƒ) m-am visat cu bil gheÅ£ de la maicrosoft care o plecat de acolo.ÅŸi io vorbem americana la perfecÅ£ie ÅŸi ÅŸtiam ÅŸi zofturi de computator ÅŸi tÄƒt dumnezÄƒuu.ÅŸi el vorbe romÃ¢neÅŸte la perfecÅ£ie, ÅŸi ne Ã®nÅ£Äƒlejem noi doi, aÅŸe, fiecare-n limbÄƒ la celÄƒlalt(no, nu vÄƒ gÃ¢ndiÅ£ la sodomniÅ£).ÅŸi pÄƒ cÃ¢nd sÄƒ pregÄƒte treaba sÄƒ devinÄƒ profitabilÄƒ pÃ¢nt-on ÅŸtimb de experienÅ£Äƒ , ma clateÅŸte doamna me:\r\n-mÄƒ tu nu auz cÄƒ sunÄƒ ceasu\'?\r\n-i beg your pardon? zÃ¢c io\r\n-beji tu pÄƒ dracu\'.miÅŸcÄƒ la lucru, cÄƒ blujii Ã®Å£ place cÃ¢nd Å£Ã¢-i spÄƒl ÅŸi sÄƒ bei cu pretinii pÃ¢nÄƒ la dimineaÅ£Äƒ ÅŸi mÄƒ iei pÄƒ mine cu limbi strÄƒine cÃ¢nd nici pÄƒ a ta nu o stÄƒpÃ¢neÅŸti cum trebe',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12','',0,0),(19370,1035,'baghy','baghy83@lycos.it','http://www.baghy.info','78.12.11.42','2008-03-21 09:56:37','2008-03-21 07:56:37','ha ha ha ha :))) Tu ce ai mancat GRopare ? :))',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(19385,1036,'CÄƒlÄƒ','acalarasu@gmail.com','http://adriancalarasu.wordpress.com/','62.217.241.242','2008-03-21 13:31:18','2008-03-21 11:31:18','e din cauza ca ti-ai fi dorit foarte mult sa fi fost giurnalist - reporter de razboi\r\nsau ai vazut de curand filmul ala cu richard gere care era reporter de razboi\r\nsau ai citit prea mult sven hassel\r\nsau ai jucat CS aseara (vz ca nu e bine sa omori in post oameni, fie ei si bootzi)\r\nsau te-ai uitat la stiri aseara\r\nsau, sau, sau e doar lack of nicotine...',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(19652,1037,'Catzaua','ana.man.fox@gmail.com','','81.180.173.61','2008-03-24 10:02:40','2008-03-24 08:02:40','ze pootzah\'s attachment...?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19653,1037,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-03-24 10:03:18','2008-03-24 08:03:18','Yap. The neck that supports the brain.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19654,1037,'Catzaua','ana.man.fox@gmail.com','','81.180.173.61','2008-03-24 10:04:55','2008-03-24 08:04:55','no, those are ze wimin. cre\' ca tocma\' am dat-o la fileu pentru o discutie taaaare interesanta pe tema who\'s who =))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19656,1037,'ametzitul','','http://ametzitul.wordpress.com','62.217.236.12','2008-03-24 10:20:08','2008-03-24 08:20:08','i\'m always left... alone :) c-altfel ma uit urat...',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(19940,1045,'Sweeper','ak70g2@gmail.com','http://360.yahoo.com/profile-uvnl.F8wcPFgZTDuDeY-?cq=1','92.81.228.119','2008-03-28 14:15:54','2008-03-28 12:15:54','http://www.youtube.com/watch?v=uK4niyFhERs&amp;feature=related',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(19878,1043,'hadean','contact@adihadean.com','http://www.adihadean.com','194.102.126.6','2008-03-27 08:02:54','2008-03-27 06:02:54','Fii Radu Anton Roman-ul nostru! ÃŽn viaÅ£Äƒ, dacÄƒ-i posibil...:-)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12','',0,0),(19856,1042,'IepurasulAtomic','praetorian21uk@yahoo.com','http://iepurasulatomic.weblog.ro','192.100.130.7','2008-03-26 18:02:56','2008-03-26 16:02:56','Bag seama ca tie ti-i dor sa fii somer :)! Da\' la ratele tale, care te asteapta cu drag in fiecare luna, nu te gandesti? Vrei sa ramana si ele somere, pe drumuri? Grija mare, da? :)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(19607,124,'akita','politika_es@yahoo.com','http://akitainu.wordpress.com/','86.125.92.17','2008-03-23 22:02:41','2008-03-23 20:02:41','Ai mai nu fiti rai cu Dan Brown o scris si el o carte ptr amercani. Nu astia au facut criza cand la radio so anuntat ca vin extraterestrii? Tot ei cumparau buncare pe timpul Crizei cubaneze. Asa ca mere sa iei toate documentele de-ti pica sub mana si teoriile conspirative , le amestec le pui la oala si la sfarsit iese una buna tocanita de idei cat sa devii putred de bogat. (Asimov e mai realist desi recunostea ca scrie carti SF). Nu mai vorbim ca apoi incurajezi si industria maculaturii si dai locuri de munca la pleiada de critici/autori care publica variante dupa Da Vinci Code gen Decriptarea codul lui Da Vinci, adevarul despre codul lu D Vinci, realitatea, mitul , povestea, femeile, Fecioara Maria, Maria Magdalena etc din Codul lu\' D Vinci. No cum sa nu fi fericit? Traiasca ecnomia de piata.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19895,1043,'Catzaua','ana.man.fox@gmail.com','http://catzaua.wordpress.com','81.180.173.61','2008-03-27 13:16:03','2008-03-27 11:16:03','@hadean: vrei sa te marai? :)) fa bine si prepara ceva yummy-bun si low-fat pentru Catzaua ta preferata :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19896,1043,'hadean','contact@adihadean.com','http://www.adihadean.com','194.102.126.6','2008-03-27 13:48:18','2008-03-27 11:48:18','low fat?chow yun fat merge?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12','',0,0),(19847,1042,'hadean','contact@adihadean.com','http://www.adihadean.com','194.102.126.6','2008-03-26 14:38:47','2008-03-26 12:38:47','asta-i ca aia pe care am comis-o acum 10 ani ÅŸi mai bine cÃ¢nd am afirmat cu glas tare la birou ca nu-mi plac Å£Ã¢Å£ele Ã®n formÄƒ de parÄƒ, ba chiar susÅ£ineam cÄƒ-s destul de jenante aÅŸa, ca aspect ÅŸi ergonomie.dacÄƒ eram numai noi, gibonii Ã®n Ã®ncÄƒpere era cum era, dar mai era ÅŸi o colegÄƒ de faÅ£Äƒ, posesoarea unei mandreÅ£i de perechi de Å£Ã¢Å£e Ã®n formÄƒ de parÄƒ(am aflat ulterior, ÅŸi nu pentru cÄƒ ne-ar fi arÄƒtat acolo, tuturor) ÅŸi care s-a ruÅŸinat ÅŸi amÄƒrÃ¢t sÄƒraca.bine, pÃ¢nÄƒ la urmÄƒ am Ã®nvÄƒÅ£at cÄƒ Å£Ã¢Å£ele sunt benefice indiferent de formÄƒ atÃ¢ta vreme cÃ¢t se mai pot Ã®mpotrivi gravitaÅ£iei ÅŸi cÄƒ ergonomia lor Å£ine ÅŸi de bÄƒrbat.probabil Ã®n scurtÄƒ vreme voi Ã®nvÄƒÅ£a cÄƒ Å£Ã¢Å£ele sunt benefice ÅŸi dupÄƒ ce au pierdut bÄƒtÄƒlia cu gravitaÅ£ia.asta e, ne adaptÄƒm la vremuri...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12','',0,0),(19794,1041,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-03-25 16:45:20','2008-03-25 14:45:20','Ioi, mah, ce m-am spariet ca pentru mine era prima!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19810,1041,'G.','g@gmail.com','','89.32.80.151','2008-03-25 22:35:36','2008-03-25 20:35:36','Culmea chirurgiei: Sa-i scoti femeii pula din cap!',0,'1','Opera/9.26 (Windows NT 5.1; U; en)','',0,0),(19851,1042,'mo','verde_poveste@yahoo.com','','194.126.220.22','2008-03-26 15:51:30','2008-03-26 13:51:30','Poti fi sigur ca era v\'un shaf, ca dara omu\' amarat are rate la frijider, masina de spalat, masina de condus, calculator, etc. si nu-i arde de luat credit pentru dezdoirea nasului sau intinderea pchelii pana la ceafa.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1)','',0,0),(19884,1043,'Catzaua','ana.man.fox@gmail.com','http://catzaua.wordpress.com','81.180.173.61','2008-03-27 10:27:55','2008-03-27 08:27:55','mi-ai facut pofta =))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19885,1043,'sweeper','ak70g2@gmail.com','','89.122.203.71','2008-03-27 10:35:23','2008-03-27 08:35:23','Mustar cu hrean, Gropare? Moments by Maggi?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1)','',0,0),(19886,1043,'hadean','contact@adihadean.com','http://www.adihadean.com','194.102.126.6','2008-03-27 10:46:56','2008-03-27 08:46:56','@catzaua:tu fatÄƒ, ÅŸezi cuminte cÄƒ dacÄƒ-Å£i vede careva imaginea de pÄƒ fruntspicu blogului nu pupchi crenvuÅŸÅ£ cu muÅŸtar nici cu botniÅ£a ataÅŸatÄƒ:+))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12','',0,0),(19887,1043,'dur;;dur','last','http://yahoo','89.136.67.135','2008-03-27 10:48:43','2008-03-27 08:48:43','simpatic',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(19888,1043,'zgura','','','81.196.150.96','2008-03-27 10:51:57','2008-03-27 08:51:57','http://www.youtube.com/watch?v=gg4Qg0vC79Y',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(19900,1043,'Catzaua','ana.man.fox@gmail.com','http://catzaua.wordpress.com','81.180.173.61','2008-03-27 15:15:29','2008-03-27 13:15:29','@hadean: in my bed! :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19933,1045,'broodwar7','broodwar7@gmail.com','','193.90.144.66','2008-03-28 10:34:07','2008-03-28 08:34:07','era ghine sa mai traiasca\r\npunct',0,'1','Opera/9.26 (Windows NT 5.1; U; en)','',0,0),(19859,1042,'Andreea MKT','supergirgir@yahoo.com','','89.43.186.64','2008-03-26 19:29:34','2008-03-26 17:29:34','ma baietzi, cine e Catzaua?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19894,1043,'Catzaua','ana.man.fox@gmail.com','http://catzaua.wordpress.com','81.180.173.61','2008-03-27 13:15:00','2008-03-27 11:15:00','@Andreea MKT: i\'m one click away.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19853,1042,'iulian n.','realvision@k.ro','','193.231.107.209','2008-03-26 16:20:10','2008-03-26 14:20:10','DacÄƒ io aÅŸ lucra la voi la fermÄƒ, mi-aÅŸ trage o amantÄƒ urÃ¢Å£icÄƒ ÅŸi i-aÅŸ face cadou o operaÅ£ie brici, aÅŸa cum scrie la imprimantÄƒ.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(19552,1036,'SIBILLA','sibilla_poesis@yahoo.com','http://sfinx667.wordpress.com','89.123.10.185','2008-03-23 06:17:16','2008-03-23 04:17:16','Sper si bat matanii, ma inchin si fac mii de rugaciuni... mai omule numa sa nu afle cumva Mihnea Georgescu de... cifre... caci adio inca o saptamana ( asta e in stare sa se \" initieze\" si in numerologie, ca deh, dupa atata dat in gropi cu tainele literelor si numelor si mai stiu eu ce naiba ii mai trazneste prin cap.... pfff cifre... io sincer nu te vad bine cu visul asta... adica mai erai si indignat, si  opozant la ordinele primite, adica sa nu te invidieze bietu om.. el ramane cu eforturile sustinute si tu ai totul.... tu iti dai seama in cativa ani, MG razand flegmatic in fata lui AN..\" bei asta, io-s initiat\" ( si, in gand, batute-ar, ca multe am patimit eu din cauza ta..)...acuma na, sa nu te-mbeti cu ...vise, ca-ti plateste drept de autor pt asta... tu esti groparu , el..\"initiatul\"\r\npostarea ta e \' divina\", sa nu ma mascaresti ca zic prea multe, da zau ca ma inspira... nu putusi sa te trezesti nu indignat, ci multamit ca ai ( in)groparu macar vre-o doi trei initiati d-astia...\r\nfain textul, fain rau, rau, rau de...buuuuuuuuuuuuuunnn, pe onoarea mea de romanca zmincita...\r\nrespecte,\r\nSIBILLA',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19650,1037,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-03-24 10:01:58','2008-03-24 08:01:58','Who am I to know the ways of the pootzah?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19849,1042,'ametzitul','','http://ametzitul.wordpress.com','62.217.236.12','2008-03-26 15:02:43','2008-03-26 13:02:43','mah... le-a stricat surpriza de ziua ta ;)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(19648,1036,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-03-24 09:40:03','2008-03-24 07:40:03','@ innuenda: deci tu iti dai seama cat de in pantalonii goi ma simpt io amu, din moment ce stii atatea despre mine? (apropos, chiar am un mini-cosh pe nas, da\' s-o retras cu demnitate). Mi-i si frica amu sa mai scriu pe blog, ca te miri ce tendinte homosexuale reprimate, lipsa figurii tatalui si voci prin cap mai descoperi ca am!!!\r\n\r\n@ sibilla: cine-i george mihnescu?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19649,1037,'Catzaua','ana.man.fox@gmail.com','','81.180.173.61','2008-03-24 09:56:33','2008-03-24 07:56:33','deci mica, zbarcita si intotdeauna musai pe dreapta, indiferent de anotimp. riiiiight?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19715,1036,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2008-03-24 19:15:15','2008-03-24 17:15:15','Te-ntaleg perfect, ca si mama d-aia m-o trimes la scoale, ca sa aibe tata sa bea din bursa mea!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19791,1041,'john_doe','dintz_best@yahoo.com','','81.180.170.53','2008-03-25 16:34:02','2008-03-25 14:34:02','Mah Gropare ma ,da ia spune la taica. Stii care-i culmea nepotrivirii sexuale?......\r\nha?! stii???\r\nSa te masturbezi si sa-ti dai seama ca nu esti genul tau',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; SIMBAR={0512FC83-A428-4DE2-9157-B0DF1A476D4B})','',0,0),(19792,1041,'john_doe','dintz_best@yahoo.com','','81.180.170.53','2008-03-25 16:36:24','2008-03-25 14:36:24','mai am una tare pt tine .Special pt tine :\r\nCulmea indemanarii : sa scoti apa din fantana cu o pompa funebra :)))',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; SIMBAR={0512FC83-A428-4DE2-9157-B0DF1A476D4B})','',0,0),(19770,1040,'catalin','catalin_heghes@yahoo.com','http://heghes.blogspot.com','84.232.142.163','2008-03-25 12:20:39','2008-03-25 10:20:39','cum ar veni... te-ai certat cu lista de iahu? noah asta da...',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(19772,1039,'hadean','contact@adihadean.com','http://www.adihadean.com','194.102.126.6','2008-03-25 12:42:43','2008-03-25 10:42:43','si beÅ£Ã¢vii din limba in italianÄƒ care-i patria lor tÄƒt damijanÄƒ zÃ¢c, numa cÄƒ cu gia nu cu ja, ca noi.ÅŸi cu doi de n pÄƒ undeva unde la noi Ã®i numa unu.no, ei au de unde cÄƒ-i plin alfabetu\' de n uri.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12','',0,0),(19773,1040,'hadean','contact@adihadean.com','http://www.adihadean.com','194.102.126.6','2008-03-25 12:45:25','2008-03-25 10:45:25','no vezi ce miÅŸto-i sÄƒ n-ai prekini?dacÄƒ te ignore lumea barem te aÅŸtepÅ£i.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12','',0,0),(19786,1038,'james crissilv','jamescrissilv@weblog.roj','http://jamescrissilv.weblog.ro','82.76.149.33','2008-03-25 15:14:23','2008-03-25 13:14:23','la asa argumente nu am contraargumente. nu imi ramane decat sa te felicit.\r\no zi minunata iti doresc',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(19730,1038,'Turambar','mirel@ccsb.ro','http://turambarr.blogspot.com','92.80.16.6','2008-03-25 00:08:38','2008-03-24 22:08:38','Miros o lucratura ardeleneasca cu iz legionar. Propun organelor abilitate sa ia masurile (in inchi, tzoli shi kilograme / secunda la patrat) de rigoare. Nu ne vindem tzara!!! Jos cu organele verzi. Traiasca \r\n\r\nTraiasca. Am obosit. Nu mai scriu. :(',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19717,1038,'Mo','verde_poveste@yahoo.com','','86.120.170.201','2008-03-24 19:54:00','2008-03-24 17:54:00','Avand in vedere ca locuiesc in Biucarest simt nevoia sa clarific treaba cu 2,5 metri(iiii) patrati - (*ia o gura de aer poluat si incepe:) teoretic beneficiez de ei da\' daca ma duc in parc si vreau sa stau ca bou\' in iarba sub copac vine un jandarm dejtept care zice ca nu-i voie sa stai pe spatiu\' pudic, desi pe rspectivul spatiu oricum dorm noaptea boschetari, isi plimba diversi indivizi cainii rasati ai caror cacati nu se deosebesc de nici o culoare de cacatii de maidanezi (asta cand nu-i plimba mandri pe bulevard langa Universitate, sa vada tata lumea ca si-au hranit bine cainii si ui\' ce rezultat maret si aburind!) si zac diverse ambalaje, sticle si  vreo juma de kil de praf.\r\nUite-asa benefciez eu de 2.5 metri patrati de spatiu verde-maro-gri-bej chistoc-albastru LeMe etc.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19891,1043,'Andreea MKT','supergirgir@yahoo.com','http://marlahermina.deviantart.com/gallery/','82.77.126.254','2008-03-27 12:45:39','2008-03-27 10:45:39','Cine e Catzaua?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; InfoPath.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(19525,1036,'dislecsiliaq','dislecsiliaq@gmail.com','','82.237.111.42','2008-03-22 23:57:21','2008-03-22 21:57:21','kinda off topic...\r\n\r\nda ni ma cje poza, sj pe bun ca-i reala. la oestereish\r\n\r\nhttp://bp2.blogger.com/_r5H5YlOxD9M/R6s_K0IquHI/AAAAAAAAACw/0dWufsBWRV4/s1600-h/fucking.jpg',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; fr; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19709,1038,'hadean','contact@adihadean.com','http://www.adihadean.com','79.113.58.24','2008-03-24 18:01:31','2008-03-24 16:01:31','verde de brad, verde ca coniferu\'.pardon,scuzati',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19708,1038,'Un bucurestean','acalarasu@gmail.com','http://adriancalarasu.wordpress.com/','80.96.53.9','2008-03-24 17:35:38','2008-03-24 15:35:38','Erau odata niste neni pe care-i chema sex pistols si care aveau drept motto espresia \"noi nu ne spalam pe dinti, de aceea ei sunt verzi.\"\r\nA se intelege ca dintii galbeni sunt decat un caz intermediar, un caz fericit, ca sa zic asa?\r\nDa\' totusi cat de verzi? Verzi verzi?! Si iarna?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(19703,1038,'hadean','contact@adihadean.com','http://www.adihadean.com','194.102.126.6','2008-03-24 16:14:57','2008-03-24 14:14:57','din fericire femeile din biroul meu se spala pe dinti.imi pare ca si barbatii.problema e ca detertrajul li se pare unora \"soluÅ£ia imoralÄƒ\" o nu ÅŸtiu ce mama sÄƒrÄƒcii de nu apeleazÄƒ Ã®n veci la operaÅ£iune. care nu-i la fel deplacutÄƒ ca sexul de buna seama dar e macar la fel de beneficÄƒ pentru starea de bine a organismului.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12','',0,0),(19704,1038,'Andreea','puistrulet2003@yahoo.com','http://n/a','81.196.150.196','2008-03-24 16:22:25','2008-03-24 14:22:25','@hadean: bine zici...solutia? mesaje motivationale mwhahahaha (sau poze cu  brusturi intre colti) si sa-i vezi cum or sa cate oglinda dupa ce papa salata verde si or sa faca coada la baie sa foloseasca pretiosul instrument (stiu ei care :) )\r\nZpor 2',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19706,1038,'.marius','marius@perijoc.com','http://marius.wirelessisfun.com','89.36.21.79','2008-03-24 16:53:24','2008-03-24 14:53:24','Eu lucrez ntr-un loc PLIIIIIIN de verdeatza... cand vii pe la mine pe la birou, iti in orice parte te-ai uita, numa verde vezi...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9b4) Gecko/2008030714 Firefox/3.0b4','',0,0),(19925,1045,'ametzitul','','http://ametzitul.wordpress.com','62.217.236.12','2008-03-28 09:12:12','2008-03-28 07:12:12','nici io nu-s, da\' nici solutzie n-am.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(19926,1045,'Catzaua','ana.man.fox@gmail.com','http://catzaua.wordpress.com','81.180.173.61','2008-03-28 09:13:55','2008-03-28 07:13:55','did he really? in lumea mea canina nu ajung prea multe stiri.. [ca le marai si pastreaza distanta]',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19783,1038,'Bogdan P','bogdan.parlea@smartm.ro','http://bogdanparlea.blogspot.com/','89.43.113.219','2008-03-25 14:31:11','2008-03-25 12:31:11','Tare, inseamna ca daca ne vopsim toti verde in casa scapam de broblema spatiului verde in Bucuresti :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19927,1044,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-03-28 09:56:39','2008-03-28 07:56:39','\"Tata e cu mine la calc, mama e cu un nene in debaraua de langa bucatarie!\"',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(19719,1038,'Diana','dee_dee_dia@yahoo.com','http://dee-dee-dia.blogspot.com','79.113.5.85','2008-03-24 20:30:34','2008-03-24 18:30:34',':)))) Imi place ca ai simtul umorului!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19702,1038,'Andreea','puistrulet2003@yahoo.com','http://n/a','81.196.150.196','2008-03-24 16:09:08','2008-03-24 14:09:08','@hadean: chestia aia verde de care zici tu imi aduce aminte de un film de-a lui nenea Pixar care ii spune \"The Emperor\'s New Groove\" si in filmu ala e o tanti pe care o cheama Izma si care are mii de ani si este o secventa in film in care ii face zoom pe dantura si se vede verzosala  respectiva (scena e super si btw filmu nu e numai pt copchii ca sa nu sariti ca inca ma cred cu suzeta intre dinti)\r\nDeci hadean cate Izma aveti voi la lucru daca nu ti-e cu suparare si oricare ar fi raspunsul recomand ata dentara si colegi simtiti care sa-ti spuna cand ai ditamai frunza de brusture intre colti :)\r\n\r\nZpor...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19806,87,'Fluture','fluture093@yahoo.fr','http://Fluture.friendlyfrog.ro','86.55.147.11','2008-03-25 21:46:59','2008-03-25 19:46:59','Bei, Gropare, noi avem prieteni comuni:)) Pai sa tot fie vreo 15 ani cand StÃ¢nisoara alerga dupa mine prin Apuseni, mai precis la GÃ¢rda:) No, bine ca nu ne-am cuplat, cine stie ce Fluturus zamisleam impreuna:)) Ioi, ce mica-i lumea.\r\n\r\nIn rest, nici nu mai zic ce prenume stiu eu, ca m-ai luat de departe cu prietenii tai \"ciudati\":p',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; fr; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19696,1036,'innuenda','innuenda.innuenda@gmail.com','http://innuennda.blogspot.com','92.80.61.106','2008-03-24 15:33:09','2008-03-24 13:33:09','nuu, mÃ¢nca-l-ar mama, nu le ham io cu fineÅ£uri d\'astea! ÅžtiinÅ£a mea nu e dÄƒ carte, cÄƒ n-a avut pÄƒrinÅ£ii mei bani sÄƒ mÄƒ deie pe  la ÅŸcoli, frumosule. ÅžtiinÅ£a mea e huna hancestralÄƒ. DÄƒ la mama mare a lu\' mama mare a\' lu tata mare. Ia sÄƒ Ã®ntrebi tu de mine prin BucureÅŸti, da sÄƒ nu zÃ®ci de Innuenda, cÄƒ Äƒia nu mÄƒ ÅŸtiu decÃ¢t de Mama Obida. Na, cÄƒ iar am rÄƒcit, cre\'cÄƒ as\'noapte pe baltÄƒ!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19695,1038,'hadean','contact@adihadean.com','http://www.adihadean.com','194.102.126.6','2008-03-24 15:04:37','2008-03-24 13:04:37','gropare, as vrea eu sa fie spanac...\r\nnu in sensul ca l-as recolta ciin sensul ca ar mai fi o speranta',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12','',0,0),(19720,1036,'Diana','dee_dee_dia@yahoo.com','http://dee-dee-dia.blogspot.com','79.113.5.85','2008-03-24 20:34:11','2008-03-24 18:34:11','Da...ai visat, deci ai dormit. Eu nu cred intr-o anumita semnificatie a viselor...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19697,1038,'Catzaua','ana.man.fox@gmail.com','http://catzaua.wordpress.com','81.180.173.61','2008-03-24 15:34:59','2008-03-24 13:34:59','@ hadean: credeam ca vrei sa-l gatesti. pe \'mnealui spanacul. :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19698,1038,'hadean','contact@adihadean.com','http://www.adihadean.com','194.102.126.6','2008-03-24 15:46:23','2008-03-24 13:46:23','mai bine frig o japiÅ£Äƒ decÃ¢t spanacul dintre dinÅ£ii cuiva, oricui:-)))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12','',0,0),(19700,1037,'Andreea','puistrulet2003@yahoo.com','http://n/a','81.196.150.196','2008-03-24 16:00:32','2008-03-24 14:00:32','@ Groparu:  Da cine te-o intrebat?(ca i-o mi-s curioasa :) )\r\n\r\nApoi ala nu stia cu cine vorbeste? Ia spune Gropare asa-i ca nu te-ai prezentat?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19691,1038,'pliscu','pliscu@gmail.com','http://pliscu.blogspot.com','89.137.100.118','2008-03-24 14:32:55','2008-03-24 12:32:55','WhiteWolf: nem tudom :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19692,1038,'V_for_Whatever','stephanovendetta@yahoo.com','','89.37.114.51','2008-03-24 14:35:52','2008-03-24 12:35:52','faza asta cu 2,5 m patrati de spatiu verde/varza de bucurestean mie imi suna cam asa... pe langa faptu ca si-asa cui ii fuckig pasa ( sincer pe mine m-ar interesa mai mult un studiu asupra frecventei cu care se voteaza pentru colegul din stanga si colegul din dreapta, sau, mult mult mai interesant, cate % din femei beau bere/ beau bere din sticla/ cel mai tare, beau bere tinand sticla de gat)...eu interpretez cam asa acest studiul statistic...deci noi, provincialii, si-asa nu stim sa numaram pan\' la 2.5, cat ca avem destul spatiu verde ca doar santem \"la tzara\"... si de-aia, in nepriceperea naiva si ignoranta a noastra proprie pe persoana fizica, nu putem sa fatam si noi un studiu de hhhenu...una mano\'a la cabbbesssa...da nu-i nimic, ca m-apuc io sa numar copacii si papadiile din cj...oricum, un studiu mult mai interesant ar fi cam cati metri cubi de maidanez/ cap de locuitor sant in orasele din tara...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.6) Gecko/20040113','',0,0),(19711,1038,'dislecsiliaq','dislecsiliaq@gmail.com','','82.237.111.42','2008-03-24 18:30:16','2008-03-24 16:30:16','mie nu mi se pare o chestie buna asta cu spatsiu verde. less is more for me. \r\n\r\nio cre\' ca daca fac economie la spatsiu verde in viatsa asta, o sa am parte de mai mult pe lumea ailalta . si cand mi o canta mie popa \"..la loc cu verdeatsa..\", la mine o sa zica \"la loc cu extra verdeatsa\". ceea ce poate fi un fapt bun in sinea lui. mai tre\' sa ma gandesc numa\' de ce.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; fr; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(19531,1036,'innuenda','innuenda.innuenda@gmail.com','http://innuennda.blogspot.com','92.80.59.243','2008-03-23 01:48:09','2008-03-22 23:48:09','Booon. SÄƒ sÄƒrim cu o interpretare, ÅŸtiinÅ£ificÄƒ, la groparele nÄƒscut din spermatozoizi campioni :)\r\nExistÄƒ Ã®n viaÅ£a ta ceva ce vrei sÄƒ faci, culmea, ca sÄƒ fii la fel cu ceilalÅ£i (ceilalÅ£i pot fi ÅŸi unii anume, identificaÅ£i de tine), dar nu eÅŸti deplin convins cÄƒ ai putea. Faptul ca te-ai visat Ã®n armatÄƒ sugereazÄƒ cÄƒ simÅ£i nevoia sÄƒ te organizezi mai bine, sÄƒ-Å£i asumi sarcini precise, sÄƒ urmezi un plan, sÄƒ fii mai disciplinat. \r\nDar tu nu rÄƒspunzi bine la ideea de autoritate, de regulÄƒ care sÄƒ-Å£i fie impusÄƒ, chiar dacÄƒ Å£i-ai impune-o tu. De aceea, Ã®n vis, toÅ£i rÄƒspundeau la comanda drepÅ£i, numai tu nu. \r\nÅžtiind cÄƒ nu rigurozitatea e punctual tÄƒu forte, Ã®ncerci sÄƒ-Å£i evaluezi capacitÄƒÅ£ile. CauÅ£i alte modalitÄƒÅ£i, personale, de a obÅ£ine ceea ce toÅ£i ceilalÅ£i obÅ£in prin respectarea unora ÅŸi aceloraÅŸi reguli. ÃŽÅ£i cauÅ£i calitÄƒÅ£i care sÄƒ reprezinte chei pentru orice fel de uÅŸi.\r\nPrima la care te gÃ¢ndeÅŸti este umorul tÄƒu. Realizezi cÄƒ strÃ¢nge o grÄƒmadÄƒ de oameni Ã®n jurul tÄƒu. Dar, Ã®n acelaÅŸi timp, te temi cÄƒ sunt anumiÅ£i oameni la care nu va fi suficientÄƒ comunicarea ÅŸi abordarea cu umor. \r\nNu ÅŸtiu cine-s oamenii ÄƒÅŸtia ÅŸi de ce sunt ei atÃ¢ta de importanÅ£i de nu te lasÄƒ sÄƒ dormi noaptea, dar visul Ã®mi aratÄƒ cÄƒ e vorba despre oameni cu care te temi sÄƒ intri Ã®n contact, neÅŸtiind dacÄƒ ai limbaj comun cu ei, dacÄƒ eÅŸti suficient de bun pentru ei. Tu crezi cÄƒ ai ÅŸanse, dar nu eÅŸti foarte sigur, ÅŸi atunci te temi de un eÅŸec. Cel mai mare eÅŸec pe care Å£i-l poÅ£i tu imagina este sÄƒ fii ridicol. Åži oamenii sÄƒ rÃ¢dÄƒ de tine.\r\nCuloarea uniformei aratÄƒ cÄƒ vrei sÄƒ te potriveÅŸti, Ã®n sensul de fit in, sÄƒ te adaptezi. Ori poate doar sÄƒ te pierzi Ã®n mulÅ£ime, sÄƒ fii asemeni celorlalÅ£i, sÄƒ treci neobservat. Aici aÅŸ zice cÄƒ e cheia intregului vis: ceva-ul acela din viaÅ£a ta, pe care tu-l percepi ca pe un punct slab, te face sÄƒ ieÅŸi Ã®n evidenÅ£Äƒ Ã®ntr-un mod Ã®n care tu nu Ã®Å£i doreÅŸti. Ai scÄƒpa bucuros de acest ceva care, momentan, ai tu impresia cÄƒ te evidenÅ£iazÄƒ negativ.\r\n\r\nMÄƒ, gropare, sper numa\' cÄƒ nu-i vorba numai de coÅŸul Äƒla care Å£i-a ieÅŸit pe nas, cÄƒ mi-ar pÄƒrea rÄƒu sÄƒ ÅŸtiu cÄƒ mi-am dat ÅŸtiinÅ£a pe atÃ¢ta lucru! :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12','',0,0),(20000,1044,'hadean','contact@adihadean.com','http://www.adihadean.com','79.113.56.86','2008-03-29 14:14:13','2008-03-29 12:14:13','m-as putea lauda cu ceva activitate in presa de gaming(online si pe hartia) deci si cu oarece joace in portofoliu.na, ca am si facut-o.dar nu despre asta-i vorba.e vorba ca nu as putea sa ma ating de un  joc a carui durata depaseste  speranta de viata in africa(si chiar in unele tari din europa).nici sa ma pusti.asadar, travian, pavian cu chiloti de celofan, wow, blow si altele ma lasa  distant si rece.partea nasoiala e ca daca un adult (presupunem) ca e responsabil, mare si n-are decat sa-si traiasca viata in ce lume vrea el, tot mai multi  prunci se pierd in virtual. asta n-are decat sa ne defecteze specia si mai rau si sa o imputineze, ca dintr-o labuta trasa in fata unei elfe de foc nu ies prunci.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(20124,1045,'florentina','florentinastoian@gmail.com','http://despre-toate-si-despre-nimic.blogspot.com','89.32.181.57','2008-03-30 23:28:34','2008-03-30 21:28:34','Domnu\' Groparu :), nu te cunosc, nu ma cunosti, da\' tzia-am pasat o leapsha la mine pe blog. Nu stiu daca te ocupi cu chestii din-astea neserioase :)), da\' esti la mine in blogroll - ca te citesc si ma amuz (in genere, ma amuz, la faza cu Pruteanu, nu m-am amuzat deloc, dar, pana la urma, cine s-a amuzat?!) - asa ca am zis trimit leapsha si pe-aci... Vezi daca te coafeaza :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(20449,1050,'ametzitul','','http://ametzitul.wordpress.com','62.217.236.12','2008-04-02 07:45:19','2008-04-02 05:45:19','corect... pÃ¢nÄƒ ÅŸi alea de pe TAB-uri sunt de 14,5...\r\ndar fiind cu Å£eva lisÄƒ, mai mult ca sigur e anticÄƒ - in zilele noastre doar alea de vÃ¢nÄƒtoare mai sunt aÅŸa ;) \r\nDar mai jos zici ca e ghintuitÄƒ... m-ai bagat Ã®n ceaÅ£Äƒ...',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(20777,1050,'Ionut','ioau@yahoo.com','','89.34.225.25','2008-04-04 23:30:15','2008-04-04 21:30:15','Nu traduceam aia nici din romana in romana :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(20369,1048,'Acetona','mada_rock2001@yahoo.com','','85.120.149.55','2008-04-01 19:08:54','2008-04-01 17:08:54','Gropare,eu sunt o fata pentru care orice individ care trecut de 18 ani ar face puscarie (sau ar trebui)ar face, din cate am auzit,daca ar vrea sa se incurce cu mine. Si vreau sa zic ca astia ca tine is motivul pentru care noi (sau unele din noi) nu se iau cu toti pampalaii astia de-o varsta cu noi. Atata numa\' ca nu toate au rabdare sa faca 18 ani sa cunoasca un barbat bine si inca vreo 2 ani sa se si ia cu el. rezulta de-aici ca mare parte din populatia feminina a tarii da cu picioru\' in soarta aia buna si se marita repede si toarna doi plozi si raman toti astia buni burlaci . Punct si o-mbratisare.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(20444,1050,'sweeper','ak70g2@gmail.com','','89.122.203.71','2008-04-02 07:26:16','2008-04-02 05:26:16','Pai hotaraste-te, in pana me: e ghintuita sau lisa in interior flinta aia? Nu de alta, da\' calibru\' 17,6 nu se mai foloseste de prin 1780... Peste ce piesa de muzeu ai dat nene? Vreau si io!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1)','',0,0),(20595,1051,'hadean','contact@adihadean.com','http://ww.adihadean.com','194.102.126.6','2008-04-03 07:14:34','2008-04-03 05:14:34','Ã®i pre dimineaÅ£Äƒ sÄƒ fiu deÅŸtept Ã®n scris aÅŸe cÄƒ o sÄƒ fiu un pic deÅŸtept Ã®n rÃ¢s.da poate mai trecmai tÃ¢rzÃ¢u.servus!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12','',0,0),(20155,1045,'Flamandu\'','staulalucru@yahoo.com','','82.77.193.186','2008-03-31 09:03:41','2008-03-31 07:03:41','Io creca florentina te place. Cheam\'o la un ceai. Sau la un travian.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(20153,1046,'ametzitul','','http://ametzitul.wordpress.com','62.217.236.12','2008-03-31 08:33:20','2008-03-31 06:33:20','chiar era bancul ala cu teroristul care pleaca speriat din Romania :)\r\nii furasera mashina-capcana, bani, tot...',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(20395,1049,'Ladystarlight','mail_aniri@yahoo.com','http://pilulele.blogspot.com','85.204.114.160','2008-04-01 23:00:07','2008-04-01 21:00:07','eu mÄƒ Ã®ntreb, de ce anume obiect sau lucru ar putea sÄƒ buÅŸeascÄƒ ÄƒÅŸtia Å£ara? de vecini? de unguri?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12','',0,0),(20376,623,'','','','89.123.109.247','2008-04-01 19:57:21','2008-04-01 17:57:21','nu mi place',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(20149,1046,'hadean','contact@adihadean.com','http://www.adihadean.com','194.102.126.6','2008-03-31 07:13:28','2008-03-31 05:13:28','ÅŸi dacÄƒ deturneazÄƒ ceva sÄƒ sÄƒ prÄƒvale-n caza boboruli, aboi acel ceva o sÄƒ fie un deltaplan, cel mult, sau o parapantÄƒ cÄƒ-i plinÄƒ Å£ara de ele.n-am scos-o io da\' crd cÄƒ-i drept:la Å£arÄƒ de kkt, numa atentate de kkt sÄƒ pot produce. hait!numa sÄƒ nu punÄƒ careva o bombicÄƒ la caza boborului cÄƒ e ditamai vidanja ÅŸi clar ne umple pe toÅ£i de mirozne negative.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12','',0,0),(19990,1045,'dracu','lucrac2006@yaho.com','http://new.ablog.ro/','62.212.236.195','2008-03-29 11:59:19','2008-03-29 09:59:19','decesul lingvistului si omului de cultura Pruteanu ma lasa destul de rece. nefiind implicat in treaba cu limba, si nefiind foarte cult de felul meu.\r\n\r\ndecesul politicianului G. Pruteanu ma bucura. \r\nun oportunist, si la fel de mare nisimtit si marlan ca si colegii lui. o lichea in minus.\r\nSlava Domnului ca mai pune din cand in cand Al de Sus mana pe ranga, si le da la cap. ca altcineva oricum nu ii poate ajunge.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; InfoPath.1; .NET CLR 3.0.04506.30)','',0,0),(20179,1046,'Andreea','puistrulet2003@yahoo.com','http://n/a','81.196.150.196','2008-03-31 13:05:41','2008-03-31 11:05:41','@gabigreen: haha very funny :)\r\n\r\n@groparu\': tulai ca ai dreptate, da cata imaginatie...io nu m-as fi gandit la carnea de porc/purcel/ghita... :) Neveeeerr!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(20072,1045,'lizard','','','79.113.120.255','2008-03-30 10:45:44','2008-03-30 08:45:44','poti alege cand sa mori???..of cors....dar nu poti alege sa trimiti \"moartea la bere\" atunci cand vine..',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(20348,1049,'Flamandu\'','staulalucru@yahoo.com','','82.77.193.186','2008-04-01 14:38:43','2008-04-01 12:38:43','deci despre soferie sa vorbeasca numa aia care are in dotare carnetu.\r\ntu crezi ca\'i asa usor sa\'nvarti de covrigu ala? mai ales daca pe partile necarosabile circula donsuarele care e blonde, brunete, roscate, decoltoase, buricoase, etece. e meserie grea, n\'ai habar cat de greu e. sa stai la semafor sa te uiti la donshuara cu matizu, sau la bunoaca aia cu  69 gia, apoia mai vezi si fetele care se imparte cu flyerele din dotare...te fura, te fura peisagiu. si-l stim pe nea chiorel, asa, mai fasnet, ca\'i fuge ochiu..nu-i greu sa uiti ca ai picioru pe acceleratie.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(20598,1051,'ametzitul','','http://ametzitul.wordpress.com','62.217.236.12','2008-04-03 07:41:37','2008-04-03 05:41:37','adevÄƒrat,multe ai vÄƒzut, mÄƒ domnule... \r\nÅŸi acum ai ÅŸi material sÄƒ-Å£i faci fabricÄƒ de lumÃ¢nÄƒri :)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(20167,1046,'mo','verde_poveste@yahoo.com','','194.126.220.22','2008-03-31 11:07:25','2008-03-31 09:07:25','Io cred ca nici un terorist nu se poate descurca in Bucuresti fin\'ca:\r\n1. n-are cum sa ajunga cu masina/ unde parca pe traseu\' summitului ca sa isi lase bomba-n plic sau ce prastia lui o mai fi improvizat daca n-ar spaga serioasa in euroi,\r\n2. la metrou sigur va fi strans intre doua buci muncitoresti vanjoase incercand sa ajunga la o scara rulanta mai mult ca sigur blocata, \r\n3. pe strazi e plin de caca de cutu boschetar, deci ar fi nedrept sa lase o boamba a dreptatii acolo \r\n4. in casa poporului ori se pierde ori va darama fix 3 camere din alea o mie cate sunt.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1)','',0,0),(20168,1046,'gabigreen','gabigreen2000@yahoo.com','http://stumblingin.blogspot.com/','89.122.243.134','2008-03-31 11:25:30','2008-03-31 09:25:30','acesta-i bancul la care se face referire. m-am gandit ca va poate inveseli si pe voi, asa cum s-a intamplat la noi in birou....\r\n\r\n\r\nPOVESTE CU ARABI\r\n\r\nNoi suntem in masura sa mai linistim populatia deoarece am interceptat un alt mesaj trimis catre organizatia centrala de un membru al unei celule teroriste aflate in tara noastra:\r\n\r\nâ€œSalutam cu rezbect, jefuâ€™.\r\nAderizat la Romania cu bomba la valiza ascuns bine; dragut fara problem control aerobort, fiindca mai gasit un bagaj pierdut pe drum. Pastrat dolar american blestemat, pentru construit aigea bomba noua; dat jumadate la daxi, jumadate furat tigan din buzunar. Indilnit frate Ahmed, patron magazin, ajudat la mine. Discutat cu el la cafenea plan bomba, consumat egler proaspat, intoxicat zalmonel, noi ajuns spital, doctor roman durut la cur. Jefuâ€™, gu bomba praf antrax nu putut facut la Romania, deci ingergat plan bomba cu bum-bum!\r\nMutat apartament frate Ahmed, adus mult frumos aminde tara mia, fara apa la robinet. Urmarit emiziuni explozia camion azotat, facut frica la mine. Astia romani are tupeu nu gluma! Trebuie recrutati, jefu!\r\nBomba cu azotat mare efect aveam!\r\nâ€¦\r\nInderesat pilotat avion pentru lovit gladire la roman; vazut delevizor aparat zbor MIG prabusit singur in ogorul taranului, plus roman stricat singur gladire, adormit beat, tigara aprinsa, murit zoagra, facut chef mare la ei.\r\nâ€¦\r\nDraga jefuâ€™, gineva furat la mine gas pastrat bentru bus la bomba, iar azeara, gind iesit cumparat baglava, exblodat budelie la parter. Aicia la Romania, mult cretin! Zberiat, zguibat la zin cacat pe mine de frica! Jefu, ma indorg agaza!\r\nAsta romani nu are nevoie de terrorism, face singur treaba noastra.â€',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1; .NET CLR 1.1.4322)','',0,0),(20257,1046,'baghy','baghy83@lycos.it','http://www.baghy.info','78.12.10.164','2008-03-31 23:13:11','2008-03-31 21:13:11','cu parizeru m-ai dat gata :)))',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(20170,1047,'Kissu','','http://www.pacurar.net','82.77.126.254','2008-03-31 12:04:25','2008-03-31 10:04:25','La multi ani, surioaro! Tot ce e mai bun, numai pentru tine! ;) Iar tu Gropare, eshti tare! 10x.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(20215,1042,'Ce vor muierile','asdwdwdw@yahoo.com','http://ce-vor-femeile.blogspot.com','213.157.188.71','2008-03-31 17:23:52','2008-03-31 15:23:52','apoi mo, numa shefii isi permit chirurgii dinastea de fitze ;)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(20310,1048,'ametzitul','','http://ametzitul.wordpress.com','62.217.236.12','2008-04-01 07:48:14','2008-04-01 05:48:14','e 1 aprilie...io nu te cred :)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(20218,1044,'Ionut','ioau@yahoo.com','','89.34.225.25','2008-03-31 17:48:00','2008-03-31 15:48:00','http://youtube.com/watch?v=Sgfp8ypHbBo',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6','',0,0),(20374,1048,'Tot Acetona','mada_rock2001@yahoo.com','','85.120.149.55','2008-04-01 19:46:13','2008-04-01 17:46:13','fara \"ar face\" de dupa prima paranteza. hopa, scuze!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(20352,1048,'Dru','delia.adriana@gmail.com','','82.77.126.134','2008-04-01 15:18:24','2008-04-01 13:18:24','@julius .... : Impacat cu sticla sau paharul... cu lumea nu :-))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(20353,1048,'florentina','florentinastoian@gmail.com','http://despre-toate-si-despre-nimic.blogspot.com','89.39.248.19','2008-04-01 15:22:59','2008-04-01 13:22:59','Da. Asta a facut din tine liceul de fete, facultatea de fete si masteratele de fete... Cat am citit postu\' asta, am crezut ca o sa ma ia dracu, de atata invazie de fete si de chestii legate de fete :)) Important e, evident, \"eleiesbiruitoare\"... partile tale esentiale :) Gata, te consider achitat de leapsa. Si-o sa am grija, data fiind seriozitatea, sa mai trimit lepse p-acia :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(20090,1045,'mirra','','','83.103.137.234','2008-03-30 14:30:10','2008-03-30 12:30:10','nici eu nu sunt de acord,dar cine ma ia in seama?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(20793,1052,'UnCopilutz','uncopilutz@yahoo.com','http://www.uncopilutz.haipa.ro','79.116.79.156','2008-04-05 02:25:13','2008-04-05 00:25:13','CÃ¢teva corecturi, dacÄƒ-mi permiteÅ£i, domnule Gropar:\r\n\r\n PrimÄƒria Cluj-Napoca\r\n- a impus vopsirea tuturor maÅŸinilor nu Ã®n galben, ci Ã®n alb ÅŸi doar de la mijloc Ã®n sus;\r\n- a impus tariful maxim de 2 lei pe kilometru ziua ÅŸi 3 lei pe kilometru Ã®n timpul nopÅ£ii;\r\n- ultima gÄƒselniÅ£Äƒ, a impus ca toate cupolele taximetrelor sa aibÄƒ inscripÅ£ii identice, cu \"TAXI\" simplu, dar firmele le poÅ£i dibui de pe portierele din faÅ£Äƒ, de pe abÅ£ibild.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(20213,1046,'IepurasulAtomic','praetorian21uk@yahoo.com','http://iepurasulatomic.weblog.ro','192.100.130.7','2008-03-31 17:17:44','2008-03-31 15:17:44','Eu vad totusi o portita de scapare pentru pofta lor de atentat. Deci esti arab, vii in Romania si vezi sa esti inconjurat de femei bune, da\' curve(dupa conceptia generala a barbatilor) si zici asha: \"daca fac adendad la mine acasa, o sa fiu intampinat in RAI de 70 de virgine d-ale mele, care-s cam uratzele, grasutze si vai mama lor, si cam put putin. Daca fac mai jihad atentat aici, apai voi fi inconjurat de curvistinili aiestea misto, care si iubeste la mine, da\' virgine. Sa fiu zeu\' lor pana la judecata de apoi(daca au asha ceva). Pai, tre\' sa dtzin minde sa dedonez de la distantz, sa nu murdaresc la mine de Cristim.\" (stiu, dupa accent e cam confuz arabu\' asta: si ardelean, si arab si o tzara moldovean.) \r\n\r\nEu zic sa belim ochii la teveu, ca poate vedem schije.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(20225,1045,'florentina','florentinastoian@gmail.com','http://despre-toate-si-despre-nimic.blogspot.com','89.39.248.19','2008-03-31 18:54:43','2008-03-31 16:54:43','Mai trec p-aici sa verific :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(20226,1047,'\"surioara\"','firsttonico@yahoo.com','','86.105.125.6','2008-03-31 19:00:35','2008-03-31 17:00:35','scuza intarzierea. da\' am primit si o viroza de ziua mea.\r\nMULTAM FAIN!! sint onorata si am umplut de emotie pe mine (merci hadean). atita\'s de incantata ca te voi purta vesnic pe buze si adinc in decolteul meu, si ai al mai de lux locsor in sufletul meu. fac si cinste daca ma tin maine pe picioarele bunese. tucu-te-as gropare ce m-ai imbucurat!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 2.0.50727)','',0,0),(21362,1058,'yourblogsfan','totmea@yahoo.com','','89.123.70.219','2008-04-10 13:07:07','2008-04-10 11:07:07','aiasta numa finca ai fierea sucita si lenesa.  :-)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Zango 10.3.36.0)','',0,0),(20331,1048,'julius constantinescu','julius@universitateacraiova.ro','http://www.7plus.ro/?arhiva=01/04/2008&#38;id=4140','84.232.162.69','2008-04-01 11:32:03','2008-04-01 09:32:03','Gropare, treci printr-o perioada mai grea a vietii tale. Incearca sa tratezi bautura si femeile ca pe doua placeri distincte. Cu timpul, vei vedea, bautura va ocupa locul central in viata ta. Te vei simti echilibrat si impacat cu lumea. Noroc!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(21430,1058,'Catzaua','ana.man.fox@gmail.com','http://catzaua.wordpress.com','92.82.45.226','2008-04-11 08:14:19','2008-04-11 06:14:19','fost la bendea. amu\', dintre cei doi [iancu si nicu] nu stiu care-i bendea, da\' nicu a rupt malu\'.. desi am inteles de la connaisseuri ca n-a fost a\' mai buna prestatie a lui, pe mine m-a incantat total. si am ras pana am ramas fara aer. deci fu fain.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(20333,1049,'SIBILLA','sibilla_poesis@yahoo.com','http://sfinx667.wordpress.com','89.123.45.65','2008-04-01 11:38:42','2008-04-01 09:38:42','.... da cine a zis ca-i lasa... gata, e semn clar ca trebuie sa se odihneasca de prea multe fumuri ce le atarna pe limbile necugetate...\r\nsubscriu cu drag...\r\nrespecte,\r\nSIBILLA',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(20098,1045,'SIBILLA','sibilla_poesis@yahoo.com','http://sfinx667.wordpress.com','92.82.237.174','2008-03-30 17:34:15','2008-03-30 15:34:15','una peste alta, se vede treaba ca moartea fu cea care ne dezlega limbile tuturor... mare curaj, mare... in rest, ma abtin, din modestie si de apolitica,na:\r\nDumnezeu sa-l odihneasca !\r\nrespecte,\r\nSIBILLA',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(20184,1047,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-03-31 13:43:29','2008-03-31 11:43:29','HÄƒdene, rulezi!\r\n\r\nAtÃ¢t am avut de zis. Restu\' - in scris.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(20185,1045,'florentina','florentinastoian@gmail.com','http://despre-toate-si-despre-nimic.blogspot.com','89.39.248.19','2008-03-31 13:44:08','2008-03-31 11:44:08','Am banuit eu ca e o leapsha ratata din start, dar asa am primit instructiuni, sa dau leapsa la inca opt indivizi din blogroll. si te-ai nimerit sa fii pe-acolo, si de, de cele mai multe ori ma amuza blogul tau. Nu stiu daca e asta scopul lui, dar... Asa... si as fi pus leapsa in alta parte, nu la postul despre Pruteanu, dar nu mai era alt post, azi noapte cand am lepsuit\r\n\r\n@Gica Contra, a se citi explicatia de mai sus, funny si cu moartea omului n-are nicio legatura cu discutia.\r\n\r\n@Flamandu - ma scuzati ca ma bag, da\' ce e ala travian?\r\n\r\n@Groparu - o sa mai trec oricum pe-aci, cu sau fara leapsa',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(20163,1046,'SIBILLA','sibilla_poesis@yahoo.com','http://sfinx667.wordpress.com','89.123.10.205','2008-03-31 10:11:06','2008-03-31 08:11:06','ca bine zici \" ce jihadu nostru... \", vin americanii si daca vin ce... ne scutura pe noi de prostie sau ne trezesc din adormire, pai vorba ta, daca nu ne trezim singuri, dijiaba...\r\nce naiba de atentate ne mai trebuie, ca oricum ramanem cu curatenia de dupa si cu recuperarea cheltuielilor, la noi posturile sunt lungi si de durata, ca nu ne mai saturam de lins blide occidentale...\r\nconcluzia e ca pana si teroristilor le e mila de noi, numai noi ne alintam inca cu apa de ploaie si ne rasfatam cu amintiri, cica am fost candva ( Dacia ) Leaganul Suprem al Spiritualitatii....uitaram???.... vai de steaua noastra, un popor care-si vande sufletul va fi terfelit si batjocorit, respectat niciodata, dar ne trebuie bag seama cate o maciuca fiecaruia din noi in parte la mansarda, doar ne luminam...\r\nfelicitari pentru obiectivitate si atitudine, mai luam cate o tema de cugetare, mai realizam cat un bob de grau... ehhh... s-o indura Dumnezeu de noi, ca noi ne uitaram si e grav si trist;\r\nrespecte,\r\nSIBILLA',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(21088,1053,'vitalie','sprinceana@mail.md','http://spranceana.blogspot.com/','87.255.64.202','2008-04-07 10:41:29','2008-04-07 08:41:29','vinde-te ca sclav.. te cumpar si din banii aia ai putea motai o vreme... altfel, basa si tu un adsense ca oamenii, sa-ti daruim cate 2-3 euro zilnic..e un inceput bun. pentru ceva beri e suficient',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ru; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(21090,1053,'Changagriel','nu@sunt.eu','http://changagriel.wordpress.com/','86.120.149.45','2008-04-07 11:19:50','2008-04-07 09:19:50','Era o vorbÄƒ, cÄƒ sunt douÄƒ moduri de-a face bani rapid: ori jefuieÅŸti o bancÄƒ, ori Ã®Å£i deschizi una. DacÄƒ Å£i se pare prea mult, iei cÃ¢t Ã®Å£i trebuie. ;)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(20545,1050,'saliery','alexblana2003@yahoo.co.uk','http://saliery.ablog.ro','79.117.15.149','2008-04-02 21:44:07','2008-04-02 19:44:07','te cred ca atunci cand o traduci ti-o si imaginezi ..goala, seducatoare si ucigatoare. In toata splendoarea ei cum luceste...pusca,nu?:)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727)','',0,0),(20176,1047,'hadean','contact@adihadean.com','http://www.adihadean.com','194.102.126.6','2008-03-31 12:54:16','2008-03-31 10:54:16','Ioi Dora tu fata, cand am vezut poezel de la Gropar, am umplut de emoÅ£ie pe mine, aÅŸe fain zice iel. no, nu te cunosc, da la mulÅ£i ani io la Å£ie zic ÅŸi pe MeÅŸe te dedic:\r\nMeÅŸe\r\nElment Fet Frumos un datÄƒ\r\nPÃ¢n la Ilonko-n poiatÄƒ\r\nEden meg o sived dragÄƒ\r\nGhiere ghiorÅŸon facem treaba\r\nIlonko spus \"nem birok, ious smeu case, papa tot\"\r\nD-apoi Ilonko spus la iel cÄƒ-i drag,\r\nFÄƒt-szep scos kozepÅŸolab\r\nDat jucat cu jucaria\r\nEÅŸ meg varat la jmecheria(pardonez ortografia)\r\nPeste-un ceas, ious zmeu case\r\nIlonka spus \"ghirÅŸon, lase\"\r\nBe ious Zmeu Ã®n bÄƒtÄƒturÄƒ\r\nEÅŸ meg ghiorÅŸon fix la ÅŸurÄƒ(fÄƒsut adulemecÄƒturÄƒ)\r\n-Ki voult ide?BudoÅŸ tare!\r\n-Åženki drago, Å£Ã¢ sÄƒ pare\r\nZmeu vede mayo, gatyo, pe fÄƒt szep Ã®n fÃ¢n meglato\r\n-Ki ez?mondiod el cu-amar\r\n-Te nu vede, ez magÄƒr!\r\n-Ez nem szomar, asta-i om, lovam spÃ¢nnzoram de pom!\r\n-Szomar von te, hodiod be ki, niz meg mi o fasz von ne ki!\r\nZmeu stat ÅŸi dat cu zaru..\r\n\"Ember este sau mÄƒgaru?\"\r\n\"Ember estem dupÄƒ cap\r\nSzomar la kozepÅŸolab\"\r\nGondoltot, uitat la zar, \r\nSpus la urmÄƒ: \"Ã®i mÄƒgar\"\r\nÅži scÄƒpat FÄƒt Szep la coadÄƒ\r\nKeis povestea, servus dragÄƒ!\r\n\r\nNo, variantul complect ide!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12','',0,0),(20189,1045,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-03-31 14:10:28','2008-03-31 12:10:28','@ Florentina: apai te-oi loa de leapsha, da\' deocamdata mai am, dupa cum se vede, niscai subecte de epuizat!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(20206,2,'kamil','','http://www.maroma.pl/index.php/pl/home','212.76.37.182','2008-03-31 16:23:35','2008-03-31 14:23:35','<strong>konstrukcje spawane...</strong>\n\nOstatnio szukalem firmy w warszawie ktora zajmuje sie spawaniem konstrukcji metalowych i znalazlem firme maroma. Nie wiem czemu firma na stronie nie chwali sie zbytnio tym ze oferuje konstrukcje spawane, ale po kontakcie z nimi dowiedzialem sie ze bard...',0,'1','','trackback',0,0),(20187,1047,'hadean','contact@adihadean.com','http://www.adihadean.com','194.102.126.6','2008-03-31 13:56:54','2008-03-31 11:56:54','senqiu verimaci',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12','',0,0),(20188,1045,'florentina','florentinastoian@gmail.com','http://despre-toate-si-despre-nimic.blogspot.com','89.39.248.19','2008-03-31 14:01:29','2008-03-31 12:01:29','@Flamandu - m-am lamurit cu tarvianu, nu te mai obosi',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(20159,1045,'Gica Contra','gica@contra.ro','','86.125.129.145','2008-03-31 09:47:30','2008-03-31 07:47:30','R u trying to be funny? Pe moartea omului?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(20161,1045,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-03-31 10:00:14','2008-03-31 08:00:14','Does this look funny to you?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(20535,1048,'bradu','cobrasaki@yahoo.com','','12.174.51.8','2008-04-02 20:08:53','2008-04-02 18:08:53','ma tu esti nebun de legat si io stiu cu siguranta ptr. ca daca nu as fi si eu nu ash stii... sa-ti dea dzeu numa femele pe care sa gifii ca o camila in deshert... si sa nu ne mai abureshti pe noi cu comentarii ... de genu...  vai doamne.... ca noi nu suntem calugarite, ca daca am fii, am lua un fel de intelegere cu al de sus sa putem sa ne intindem osemintele in variante nedescrise in biblia veche...\r\nbai gropare de bine sau nu, sunt de plins in viata asta paminteana, da cind te-am citit am zis ca, uite, una la mina asta care face gropi ma face sa ma pish pe mine de ris, doua, acu trebe sa ma duc sa ma schimb ca m-am pishat pe mine, si nici nu sunt biat, ca daca as fi biat m-as complace in caldurica susurata prin buzunare si m-as culca intr-un fin santz sa ma linga maidanezii si sa ma incalzeasca cu pipi lor autohton ca tare mie dor\r\n\r\n\r\nba ia da si tu un reply la e-mailu asta  \"cobrasaki@yahoo.com\" ca avem de schimbat ceva vorbe si nu te teme ca te abdica yahoo messengeru ca ala e numa ptr. paminteni... ceea ce noi nu suntem\r\n\r\nsa va dea dzeu ce-o vrea....',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(20344,1049,'hadean','contact@adihadean.com','http://www.adihadean.com','194.102.126.6','2008-04-01 13:49:17','2008-04-01 11:49:17','amu sÃ¢ncer, dacÄƒ geoanÄƒ o buÅŸit-o pÄƒntru cÄƒ-i tolomac, o prostÄƒnac, cum Ã®i iel, cred cÄƒ bÄƒse o buÅŸit-o organizat. una la mÃ¢nÄƒ cÄƒ pre iute o fo tenbelizorista de la realitatea la iel acolo ÅŸi douÄƒ la mÃ¢nÄƒ cÄƒ s-o tomnit tomna-n titiriÅŸca sereiului, fachindizastÄƒr, sÄƒ vez tu.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12','',0,0),(20320,1046,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-04-01 09:14:04','2008-04-01 07:14:04','Asa-i, baghy, parizeru\' meu face minuni!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(20319,1048,'hadean','contact@adihadean.com','http://www.adihadean.com','194.102.126.6','2008-04-01 09:09:34','2008-04-01 07:09:34','ioisupercalifragilisticexpiralisoucieuscezicituaicivirgulasubscriucamiliniutaailuatvorbadingurapunct',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12','',0,0),(20377,1049,'','','','89.123.107.93','2008-04-01 20:10:33','2008-04-01 18:10:33','da',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(20657,1051,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2008-04-03 21:35:15','2008-04-03 19:35:15','Mah, sa stii ca bine zici, finca dupa chestia asta mi-o venit ciclu\'! Si le-am cerut colegilor sa se legitimeze.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(20741,1052,'IepurasulAtomic','praetorian21uk@yahoo.com','http://iepurasulatomic.weblog.ro','192.100.130.8','2008-04-04 15:36:05','2008-04-04 13:36:05','Cre\' c-au pus in practica astia treaba cu ceafa de scafandru bulgar. Am luat un taxi mai devreme si-am incercat sa intru si eu in vorba cu nenea, sa-l intreb cum e treaba cu schimbarea asta...Cre\' ca si un cimpanzeu spunea mai multe :). Da\' avea ochelari Dolce&amp;Gabana, fake, evident. Poate de aia nu putea sa schimbe povesti cu unu\' ca mine :).',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(21432,1057,'Sweeper','ak70g2@gmail.com','http://360.yahoo.com/profile-uvnl.F8wcPFgZTDuDeY-?cq=1','92.82.96.11','2008-04-11 09:49:06','2008-04-11 07:49:06','Nene Gropare! \r\n\r\n1. Buna concluzie! Esti un bun crestin, aplicand cinstit si pioniereste doctrina biblica \"crestetzi si va inmultzitzi\". Deci da.\r\n\r\n2. De avioanili lu arata romana mi se rupe. Vand bajetzii la Belgrad niste tzevi de irigat super mijto, 9K32 Strela le zice, le pui pe umar si te chiorasti dupa avion... Cand strangi mai bine maneru\' (si tragaciu\'), pleaca o chestie si ala se apuca sa imite MiGu\'... Adica ara terenu\' tzaranului! Ieri era 55k euro una, la mercurialu\' pietzei, cu livrare la Timisoara (btw, frumoz oras si ala). \r\n\r\n3. De armata romana mi se rupe. Imi iau frumoz CZ-u\' meu cehesc (de la febletzea mea Sylvia Saint) model 750 Varmint (adica-i pt daunatori), si-i iau la bucata. Un reload ma costa 1.2 RON. Ieftin ca braga.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(20739,1052,'Andreea','puistrulet2003@yahoo.com','http://n/a','81.196.150.196','2008-04-04 15:18:48','2008-04-04 13:18:48','@Groparu: completare:\r\n\r\n-  sa aiba toti acelasi miros de imputit+huse nespalate de mii de ani\r\n- sa le miroasa la toti gura ingrozitor (asa cum i-o mirosit la un taximetrist gura odata de am crezut ca face competitie cu airfresher-u agatat de bord- de fapt castigase ca nu mai miroseam altceva... :( );\r\n- sa fumeze toti cu geamu inchis (mama lor de cretini) si sa nu te intrebe daca \"fa, ti-i curent???\"\r\n- sa te duca mereu pe cel mai lung traseu posibil :)\r\n\r\nPS: aceste exemple sunt experiente din relatia speciala pe care o am cu acesti \"amarati ai soartei\" cum le place lor sa spuna... :)\r\n\r\n@Mioritsa: n-o sa uit veci cand am ajuns in Aeroportul din Bucuresti noaptea la 12:00 si am iesit de la bagaje si erau vreo 5 mahari tip \"criminal in serie\" care te ocheau si mai ca nu te tarau de par la ei la masina \"Undhe mergeti domnishora???\" Ioi tulai ca am crezut ca dau in balbaiala....si acuma am fiori la cat mi-ar fi cerut pana in Berceni.... :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(20567,1047,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2008-04-03 02:01:15','2008-04-03 00:01:15','Tzuca-te-ar Groparu!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(21188,1055,'curioasa','totmea@yahoo.com','','89.123.115.226','2008-04-08 09:37:01','2008-04-08 07:37:01','greu...greu de tot... ai putea incerca si o repezentare grafica, te rog?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Zango 10.3.36.0)','',0,0),(20572,1051,'SIBILLA','sibilla_poesis@yahoo.com','http://sfinx667.wordpress.com','89.123.36.200','2008-04-03 02:50:17','2008-04-03 00:50:17','nu zic decat atat \" nascut din spermatozoizi campioni \"....  fain zici, mi-a placut mult :)\r\nstima si respecte,\r\nSIBILLA',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(21194,1055,'anonim','princesshgabriela@yahoo.com','','80.97.216.138','2008-04-08 11:35:54','2008-04-08 09:35:54','Toati oamenii au defecte si calitati. \r\nNu mai fii asa de critic cu tine. \r\nPerfectiunea nu exista, asa ca noile generatii nu vor fi perfecte.\r\nDar ei reprezinta viitorul si speram sa fie bine.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648)','',0,0),(21372,1058,'no_name','bad_boy_mir@yahoo.com','','78.41.22.210','2008-04-10 14:48:20','2008-04-10 12:48:20','Catzaua am impresia ca latrii cam mult la luna cateodata....esti \"putin \"agresiva desi nu cred ca ai avea motive....La munca nu la scris Bloguri nu de alta dar poate mai vii si tu cu ceva mai interesant.respect groparu\'',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(21369,1058,'Catzaua','ana.man.fox@gmail.com','http://catzaua.wordpress.com','89.123.127.34','2008-04-10 13:55:23','2008-04-10 11:55:23','@ania: una e reclama [pt aia e sufitzienta o postare], alta e sa te incluza in blogroll. intunecate si cu scazuta vizibilitate sunt caile Groparelui :) [o fi din cauza meseriei? *marait a cujetare profonda*]\r\nio zic sa nu te nacajesti. ca si daca te bagi singura in seama iti intra oamenii pe blog. daca ii faci curiosi, evident. sau daca scrisele tale instiga sau fac pohta de mai mult. deci... e mai degraba up to you :) \r\nasa ca la munca,  nu la intins mana! :) [nu ma lua prea in serios, it\'s more of a playfull tone]',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(21367,1058,'Catzaua','ana.man.fox@gmail.com','http://catzaua.wordpress.com','89.123.127.34','2008-04-10 13:29:09','2008-04-10 11:29:09','onorata si stimabila fana, ma gandeam mai degraba sa inmoi labuta dreapta in tus si sa aplic \"stampila\" pe unieva. de capsat numa\' la fanii indaratnici. si inca nu ni s-au prezentat asemenea fenomene, prin urmare, deocamdata nu prestam asemenea actiuni belicoase. *woof*',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(21368,1058,'ania','ania@wip.ro','http://aniakhaki.com','92.82.35.235','2008-04-10 13:44:13','2008-04-10 11:44:13','n-are a face cu crapatu sau din astea... da daca tot zice ca is scumpa macar sa imi faca si mie reclama...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(21366,1058,'yourblogsfan','totmea@yahoo.com','','89.123.70.219','2008-04-10 13:25:13','2008-04-10 11:25:13','daca-i sub forma de capsare cu coltii.....NU. las ca te cetesc linistita...din umbra.  ;-)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Zango 10.3.36.0)','',0,0),(21185,1048,'oedip','oedip74@gmail.com','http://oedip.blogspot.com','89.137.99.163','2008-04-08 09:20:22','2008-04-08 07:20:22','deci ... nu-i corect ... ca si io \"tz-am dat-o\"!!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(20623,1044,'Gez','gez@reactieinlant.ro','http://www.reactieinlant.ro','78.96.149.177','2008-04-03 12:37:23','2008-04-03 10:37:23','Da asta o stiai:\r\n\r\nText personal\r\nUnder construction!\r\nDefetead, but not giving up!\r\n\r\nNu cuceriti sate pe langa mine, fara acordul meu! Nu sunt megaloman, doar ca am prieteni, aliati si protejati si nu mi-ar placea sa vad ca au disparut de langa mine.\r\nNu-mi mai trimiteti mesaje cu \"Nu ma ataca!\"\r\nNu atacati nici un SCIT de langa mine, voi lua asta ca pe un afront personal.\r\n\r\n\r\nAh, la naiba, cum am putut sa uit???\r\n~Aliati personali:~\r\n\r\n1. Cat de stupid poti sa fii sa ti-i treci in profil?\r\n2. Oare daca il scriu aici pe tipul de pe locul 1 nu ma mai va ataca nimeni, niciodata?\r\n3. Si ce naiba inseamna aliat personal? E tipul cu care ies la bere si bea cot la cot cu mine? Sau e tipul care imi da zapada din fata blocului cu lopata?\r\n\r\n\r\n~Dusmani personali:~\r\n\r\nAsta e si mai amuzant:\r\nTOTI!!! VA URASC!!! MURITI!!!\r\nO sa aflu unde stati si o sa vin dupa voi sa va bat!\r\nMuahahahahhahaaa!\r\n\r\nGlumeam, evident!\r\n\r\n\r\n.................................................\r\n\r\nIn rest, toate bune si frumoase... Ma rog, ar merge si un Jack!â„¢\r\n\r\noricum asta nu e de pe Travian ci de pe Triburile ... si mai rau :) De asta sa nu te apuci ever!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(20771,967,'Groparu','groparu.ro@gmail.com','http://','89.137.109.142','2008-04-04 22:17:36','2008-04-04 20:17:36','...pe asta si mizez! :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,2),(20499,1050,'IepurasulAtomic','praetorian21uk@yahoo.com','http://iepurasulatomic.weblog.ro','192.100.130.8','2008-04-02 15:09:53','2008-04-02 13:09:53','Cred si eu ca te umezesti. Si eu ash transpira la asemenea efort intelectoal. Adjectivu\' ala \"lisa\" e antonim pentru neteda, sau vroiai sa scrii ca tzeava e linsa la interior, intersectand inca o perversiune de-a ta in textele serioase ale oamenilor?!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(20601,1051,'Ureche Mare','h_gheorghe@yahoo.com','http://www.ju-jutsu.ro','79.117.8.110','2008-04-03 08:15:32','2008-04-03 06:15:32','Multe ai vazut si multe o sa mai auzi de azi inainte...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(20735,1052,'Basty','sebastian@centre-roumain.fr','http://basty.wordpress.com','82.77.126.21','2008-04-04 14:23:42','2008-04-04 12:23:42','Pupa-i-ar tata de destoinici ÅŸi viteji ! SÄƒ-i vÄƒd eu pe toÅ£i dÃ¢nd 12 examene printre care ÅŸi cel de igienÄƒ corporalÄƒ !',0,'1','Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_4_11; en) AppleWebKit/525.13 (KHTML, like Gecko) Version/3.1 Safari/525.13','',0,0),(20679,793,'xxx','xxx@yahoo.com','','79.116.68.132','2008-04-04 01:24:14','2008-04-03 23:24:14','\"Ne mai tii mult in stand by?\"\r\n\r\nNu in \"stand up\"?',0,'1','Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.1) Gecko/20061023 SUSE/2.0-30 Firefox/2.0','',0,0),(20883,1050,'Livius','','','81.242.254.21','2008-04-06 00:47:24','2008-04-05 22:47:24','Nema shansa, Gropare, matalutza o sa scazi \'n-ochii mei cand o sa scada temperatura in Iad, recte la fix doua secunde dupa ce imi voi contempla propria ceafa la Calendele Grecesti care se vor suprapune in acel an cu Pastele Cabalin. Si zic asta din megalomanie si narcisism, fii pe pace, adicatelea fiindca ceea ce-am citit la tine concorda in mod inspaimantator cu outlook-ul meu [si nu ma refer la clientul de mail de la Bill Gates - da chiar, gorobetele asta de ce si-a numit sistemul de operare Windows, cand putea folosi numele lui, un termen mult mai puternic, care ne-ar fi facut la fiecare bug sa il injuram de stranepoti si veri de plop direct pe el, fara sa trebuiasca sa trecem sudalmile prin intermediari precum O.S.-ul. A. Da. Good point. QED]. Ok, elucubratia-mi fu longer than expected. Multam din nou pt elucidare si ura si la groapa, astaaa, gara.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(21359,1057,'voluntara','totmea@yahoo.com','','89.123.70.219','2008-04-10 12:55:07','2008-04-10 10:55:07','eu sint a Romaniei . hotarita. astept chemarea la arme. big grin.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Zango 10.3.36.0)','',0,0),(21360,1058,'Catzaua','ana.man.fox@gmail.com','http://catzaua.wordpress.com','89.123.127.34','2008-04-10 12:55:47','2008-04-10 10:55:47','@ania: nu te scanci, ca nici io nu\'s in blogrollu\' lui musiu da\' inca nu mi-o crapat fierea din cauza asta :P [si nici nu prevad sa se intample asa ceva] :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(20614,1051,'julius constantinescu','julius@universitateacraiova.ro','http://www.7plus.ro/?arhiva=03/04/2008&#38;id=4226','84.232.162.158','2008-04-03 10:46:47','2008-04-03 08:46:47','Groparule, stiu ce urmaresti! Profiti de faptul ca e summit-ul NATO aci ca sa-ti faci reclama, sa vada aia ce competent esti si sa-si spuna: \"Bai frate, tipul asta ar fi un sergent extrem de priceput! Ia sa-l angajam\".',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(21364,1058,'Catzaua','ana.man.fox@gmail.com','http://catzaua.wordpress.com','89.123.127.34','2008-04-10 13:20:29','2008-04-10 11:20:29','mno, si? cum ii turcu\' si pistolu\', cum ii Catzaua si fierea dansei. d\'oh. ne asortim ;;) in biutiful biutiful harmony. comentezi ? :))) [i have a fan, omg!!! vrei un autograf? ;;) ]',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(21365,1057,'Catzaua','ana.man.fox@gmail.com','http://catzaua.wordpress.com','89.123.127.34','2008-04-10 13:23:35','2008-04-10 11:23:35','@voluntara: *even bigger grin* de unde tastezi? daca esti pe dincolo o sa-ti ia cam mult sa ajungi la baza.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(21358,1056,'Turambar','mirel@ccsb.ro','http://turambarr.blogspot.com','92.80.16.6','2008-04-10 12:42:01','2008-04-10 10:42:01','Waw. I mean uau. \r\n\r\nWaw.\r\n\r\nThat\'s one helluva post, mate. Poetry in motion. Limbajul la maxima sa putirintza, onirica shi erotica shi ecspresiva shi lamuritoare. \r\n\r\nBa Gropare ba, mata chiar shtii sa scrii, bre.\r\n\r\nAnd, incidentally, you just made my day. Although it\'s a bloody clumsy crowded professional day.\r\n\r\nSa ne traieshti, poete! Si dupe ce le futzi cu BeeMVe-ul, fa-le pachet shi DeHasheLuieshte-le shi catre poftele noastre balcanice, aici pe malul garlei dambovitzene. Le ashteptam cu entuziasmul tare.\r\n\r\n:)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(21197,1055,'hadean','contact@adihadean.com','http://www.adihadean.com','194.102.126.6','2008-04-08 12:38:59','2008-04-08 10:38:59','daca tu ii vez pÄƒ Äƒia mici ca cum ar fi perfecÅ£ adicÄƒ opusu\' lu tu care ieÅŸti defect, cÃ¢nd te vez Ã®n oglindÄƒ defect nu te tai cu lama?cÄƒ io ÅŸi cÃ¢nd mÄƒ vÄƒd bine mÄƒ tau. Ã®i drept, io nu-s pre Ã®ndemÃ¢natic.ÅŸi dupÄƒ comentariu Äƒsta de mai bine Ã®l tÄƒcem, Ã®ncep sÄƒ mÄƒ Ã®ndoi ÅŸi de intelijenÅ£a me. ni mÄƒ cÄƒ ai dreptate.apoi viitoru ori o fi perfect ori n-o fi. deloc.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12','',0,0),(20510,1048,'.marius','marius@perijoc.com','http://marius.wirelessisfun.com','89.36.21.108','2008-04-02 16:04:19','2008-04-02 14:04:19','@dan calin: trebuie sa iti impartasesc un secret: De fapt groparele a facut liceu/facultate/mastere numa la distanta, si a stat inchis in casa, si a intalint doar pe mama lui si 3 matusi, si le iubeste (evident platonic) de aia nu stie nimic... \r\n\r\nPe de alta parte, nu vrem sa ne legam de orientarile tale sexuale, Dane... daca nu iti plac femeile, sunt cluburi special facute pentru asta. Cred ca primul a fost YMCA. ;-)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9b4) Gecko/2008030714 Firefox/3.0b4','',0,0),(20609,1051,'Turambar','mirel@ccsb.ro','http://turambarr.blogspot.com','79.114.190.16','2008-04-03 09:47:27','2008-04-03 07:47:27','Da, ai vazut, dar nu ai shi mancat. \r\n\r\nAi incercat macar?\r\n\r\n:)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(21082,1053,'hadean','contact@adihadean.com','http://www.adihadean.com','194.102.126.6','2008-04-07 09:36:55','2008-04-07 07:36:55','nu mÄƒ ispiti cÄƒp amu-Å£ deschid un cont...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12','',0,0),(20412,1048,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2008-04-02 02:04:32','2008-04-02 00:04:32','Deci bicoz of girlz like you I wasn\'t getting any when I was your age!!!!\r\n\r\n:D\r\n\r\nOr my age, for that matter.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(20729,1052,'Adi Ciubotaru','adrian.ciubotaru@gmail.com','http://adrian.filozofie.ro','80.97.185.211','2008-04-04 12:43:10','2008-04-04 10:43:10','Citand corect din memorie taximetristul clujean:\r\n- Eu as pune pasaport la Carpati!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(20736,1052,'hadean','contact@adihadean.com','http://www.adihadean.com','194.102.126.6','2008-04-04 14:35:24','2008-04-04 12:35:24','12 teste? apoi aci Ã®s bucuroÅŸi dacÄƒ trec de crash test...\r\niarÄƒ miortzÄƒ fata noastÄƒ, sa stii tu cÄƒ la london ezistÄƒ ÅŸi taxie din acelea un pic mai leznÄƒ, cÄƒ alea de care zÃ¢ci tu ezistÄƒ da-s de clasÄƒ superioarÄƒ.oricum, au numa douÄƒ feluri.adicÄƒ alea negre care aratÄƒ de pÄƒ vremea lu pazvanti ÅŸi alealalte. norocu tÄƒu cÄƒ n-ai plÄƒtit, oricum.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12','',0,0),(20475,1050,'conia21','','','193.226.17.210','2008-04-02 11:12:45','2008-04-02 09:12:45','Ce noroc cu muzeul, mai pun o rata pentru garsoniera....',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1)','',0,0),(20673,1052,'Kissu','','http://www.pacurar.net','79.116.71.23','2008-04-04 00:50:51','2008-04-03 22:50:51','Mai trebuie ca toate taxiurile sa aiba acelasi numar de inmatriculare... ;)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(20676,1052,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2008-04-04 01:05:11','2008-04-03 23:05:11','Dap! cj-69-sex.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(20474,1050,'retoric','acalarasu@gmail.com','http://adriancalarasu.wordpress.com','80.96.53.9','2008-04-02 11:09:10','2008-04-02 09:09:10','no, credeai ca pacalesti asa pe oricine?\r\nacuma vezi ce cetitori dajtepti ai, ma?????',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(20672,1050,'Livius','','','81.241.198.122','2008-04-04 00:43:51','2008-04-03 22:43:51','Nene Gropare, ego si un prekin avem o disputa [amandoi translators in anii nostri de glorie], si ma freaca la melodie pragmatica asta, bat-o vina si narocu. Amu, ilumineaza-ne, rogu-te, spala-ti-as parbrizu de la bitza: textul postat e textul sursa sau textul tinta? Ca tare mi-i ca fac o figura de 2,5 lei aici, dar asta e, tre\' sa stiu. You know how they say, end dÄƒ truf ÅŸel set iu fri. Multam fain in avans.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(20469,1050,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-04-02 10:34:45','2008-04-02 08:34:45','Apai cica banii nu se castiga asa usor, mah, cica tre sa muncesti pt ei. Mult, uneori. Prea mult, bag shutu\'!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(21357,1058,'ania','ania@wip.ro','http://aniakhaki.com','86.122.8.232','2008-04-10 12:34:49','2008-04-10 10:34:49','daca sunt asa de scumpa de ce nu apar la tine in blogroll? eu nu merit reclama? :(',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(21087,1052,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-04-07 10:39:24','2008-04-07 08:39:24','@ mioritsa: da\', da\' taximetrijtii eia netranspirati vorbesc orice limba! corec?\r\n\r\n@ copilutz: nu ai putea avea mai multa dreptate nici dac-ai vrea. Domnu\' copil snteti cumva domnu\' Boc...?\r\n\r\n@ Victor: da, cu tot cu discount de tonomat.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(21080,1053,'ametzitul','','http://ametzitul.wordpress.com','62.217.236.12','2008-04-07 09:30:18','2008-04-07 07:30:18','exact...\r\nai o grÄƒmadÄƒ cititori, pune-te pe reclame :)\r\no sÄƒ fie aspectul un pic mai naÅŸpa da\' scoÅ£i banu\', mÃ¢ncaÅ£-aÅŸ...',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(20453,1050,'hadean','contact@adihadean.com','http://www.adihadean.com','194.102.126.6','2008-04-02 07:59:59','2008-04-02 05:59:59','Eu ma zbat de o luna cu corectura \"de specialitate\" (bucatareascÄƒ specialitate) pentru niÅŸte cÄƒrÅ£i cu reÅ£ete  traduse de unguri din englezÄƒ Ã®n romÃ¢nÄƒ. ÃŽncearcÄƒ sÄƒ-Å£i Ã®nchipui ce-i la gura din dotare-mi cÃ¢nd dau peste \"albuÅŸe\", \"gÄƒlbenuÅŸe\", \"carne bÄƒtutÄƒ de vacÄƒ\", \"stropiÅ£i cu puÅ£inÄƒ zahÄƒr\",\"cacauÄƒ\", \"peÅŸtele monkfish nu are nici un os de peÅŸte pe fileu\" ÅŸamd.Ioooooi!Dumnezooooooooooooooooooo!!!!!!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12','',0,0),(20454,1050,'vizionarul','serviceitab@gmail.com','http://vizionarul.wordpress.com/','82.208.146.10','2008-04-02 08:21:21','2008-04-02 06:21:21','CÄƒ cÃ®nd traduci asemenea tecste ai orgasme intelectuale aÅŸa-i? Cunosc senzaÅ£ia foaarte bine, cÄƒ la fel pÄƒÅ£esc ÅŸi eu cÃ¢nd din mintea mea bolnavÄƒ ies algoritmi buni. :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(20492,1049,'Dan Calin','desertu.realitatii@gmail.com','http://www.deserturealitatii.wordpress.com','89.34.203.50','2008-04-02 14:00:36','2008-04-02 12:00:36','Vrei sÄƒ spui cÄƒ tu ca ÅŸofer nu ai fÄƒcut niciodatÄƒ un accident? Perfectule!!! Eu am avut vreo 4 tamponÄƒri pÃ¢nÄƒ acum. AÅŸa cÄƒ ÅŸtiu ce Ã®nseamnÄƒ trafic, mai ales Äƒsta din BucureÅŸti. Trebuie sÄƒ conduci ca o femeie dacÄƒ vrei sÄƒ nu ai evenimente ÅŸi tot nu cred cÄƒ scapi.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(20461,1050,'ametzitul','','http://ametzitul.wordpress.com','62.217.236.12','2008-04-02 09:30:47','2008-04-02 07:30:47','ÅŸi mai schimbÄƒ mÄƒ ora, cÄƒ tocmai mÄƒ Ã®ntrebam ce cÄƒutam la birou aÅŸa devreme :)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(20494,1048,'Dan Calin','desertu.realitatii@gmail.com','http://www.deserturealitatii.wordpress.com','89.34.203.50','2008-04-02 14:04:26','2008-04-02 12:04:26','Zici cÄƒ ai Ã®ntÃ¢lnit foarte puÅ£ine femei care sÄƒ nu merite a fi iubite. Cred cÄƒ ori ai Ã®ntÃ¢lnit extrem de puÅ£ine femei Ã®n viaÅ£Äƒ, ori trÄƒieÅŸti Ã®n niÅŸte medii interesante. Varianta a doua mise pare foarte puÅ£in probabilÄƒ.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(20458,1050,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-04-02 08:45:03','2008-04-02 06:45:03','M-ati prins, vrajitorilor!\r\n\r\nDa, is doua pusti diferite una de alta, da\' am luat numai partile mai condimentate din descrierea exponatelor :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(21346,1057,'ametzitul','','http://ametzitul.wordpress.com','62.217.236.12','2008-04-10 07:28:07','2008-04-10 05:28:07','da\' comisionu\' ?comisionu\' cÃ¢t e comisionuuu\'...',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(21381,1058,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-04-10 16:23:56','2008-04-10 14:23:56','@All: organizam o bataie in pieile goale in namol??? yyessss!!! :D\r\n\r\n@ Ania: Tu, Ania, sa stii ca blogrollu\' meu or fost toti amantele mele! Este proba decisiva ca sa intri la blogroll la Groparu. Are you up to the challenge?\r\n\r\n@Nelu: mo, deci in gustu omului chiar nu te poci c***! Ioz fan Bendea si-l ascult zilnic la radio, si omu\' ruleaza, pe Groparu-l minuneaza, fruntea i-o descretzeaza. Si avand in vedere ca desara o sa aibe mai multi spectatori decat am io cetitori creca ii suficient de graitor.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(21345,1057,'hadean','contact@adihadean.com','http://www.adihadean.com','194.102.126.6','2008-04-10 07:17:56','2008-04-10 05:17:56','apoi de bunÄƒ samÄƒ armata romÃ¢nÄƒ cu forÅ£ele aviatice din dotare cercÄƒ sÄƒ mÄƒ asigure cÄƒ n-o fo prost Äƒla care o zÃ¢s cÄƒ \"doar pÄƒmÃ¢ntul e mai sus decÃ¢t noi\". poi dupÄƒ mig-urile cÃ¢rpite cu gumÄƒ turbo de ruÅŸi dupÄƒ afganistan (afganistanu  Äƒla cu rambo) vre sÄƒ cumpere efÅŸaiÅŸpeurile cÃ¢rpite cu chicken mcnugheÅ£urile americÄƒneÅŸti? aÅŸ zÃ¢ce cÄƒ-i naÅŸpa.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12','',0,0),(20629,1051,'fotoghin','mad_p3@yahoo.com','','193.231.18.12','2008-04-03 13:48:16','2008-04-03 11:48:16','te-ai uitat atent? io crek era o bucata din creeru ala imens pe care il ai:D muuuult prea mare sa stea doar in capshor :&gt;',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; ro; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(21198,1055,'ametzitul','','http://ametzitul.wordpress.com','62.217.236.12','2008-04-08 12:39:24','2008-04-08 10:39:24','hochei, domnu\'...\r\natunci ia pun-te pe treabÄƒ ÅŸi viziteazÄƒ toatÄƒ Å£ara, ca sÄƒ expui cÃ¢t mai mulÅ£i minori contra-influenÅ£ei tale benefice... :)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(21384,1058,'ania','ania@wip.ro','http://aniakhaki.com','92.82.35.235','2008-04-10 17:32:52','2008-04-10 15:32:52','nu mai vreau la tine in blogroll :&gt;',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(21350,1057,'Emaginatoru','e_magistatyahoo.com','','79.116.83.156','2008-04-10 08:12:48','2008-04-10 06:12:48','Armata romana nu face nimic. Mai merg 20 de zoldatz sa mentzie pacea cu fortza. Moare unu-doi si restu vin acasa. Da pen\' aia 20 armata ia banii cu galeata, se pensioneaza la 45 de ani cu pensii uriase si mai si traiesc inca 45 dup-aia.\r\nNu avem inamici da pompam fonduri in Armata. In schimb cu bolile si lipsa de educatie ne luptam zilnic si nu sunt bani de spitale si scoli, de salarii, de dotari, de educare. Si culmea toti sunt bugetari. \r\n\r\nDeci nu se pune problema daca ne trebuie F16 sau Eurofighter. Cate spitale s-ar putea renova de banii aia?!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(21351,1057,'Catzaua','ana.man.fox@gmail.com','http://catzaua.wordpress.com','89.123.127.34','2008-04-10 08:16:14','2008-04-10 06:16:14','bine ca nu iau messerschmitturi de prin \'40-\'50. de fapt, nu si le-ar permite ca pret la ora asta, ca-s antichitati deja. de ce nu fac avioane din hartie? usor si simplu. si asa traim intr-o vreme in care toata lumea pretinde [pretindem ca ne pasa, pretindem ca muncim, pretindem ca avem o tarisoara promitatoare care in curand va fi pantre hele mai cu coae din raion] asa ca ieftin, usor si cu un pic de imaginatie, trantim o flota d\'aia de avioane [nu-i musai sa fie d\'alea origami, da\' ar iesi mai artistice] si ne-am scos.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(21389,1058,'','','','86.121.196.40','2008-04-10 19:33:07','2008-04-10 17:33:07','@Groparu \r\nSa intelegem ca i-ai pus in blogroll dupa cum au performat?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(21390,1058,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2008-04-10 20:27:23','2008-04-10 18:27:23','Dap.\r\n\r\nAlfa-betic.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(21077,1053,'pliscu','pliscu@gmail.com','http://pliscu.blogspot.com','89.137.100.118','2008-04-07 09:25:40','2008-04-07 07:25:40','apelezi la Google Adsense? :) sau nu te intinezi in halul ala?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(21427,1024,'davesslave','shaggyqwomen@gmail.com','http://nikkinova-in-school-girl-outfit.cakefake.nx.cn/','62.213.66.153','2008-04-11 07:43:25','2008-04-11 05:43:25','Wow! Cool news!Sounds a little weird, but interesting anyway. what do you guys think about it?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; es-ES; rv:1.7.6) Gecko/20050321 Firefox/1.0.2','',0,0),(20727,1052,'Andrei','andreibaban@gmail.com','http://andreibaban.wordpress.com/','82.77.126.7','2008-04-04 12:40:51','2008-04-04 10:40:51','Stii faza aia ca te intreaba unu ce taxiuri sa iau in orash? Io iam zis ca oricare da sa scrie ceva firma, sa nu scrie numa taxi... si numa ieri am observat marea schimbarea :|',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(20718,1052,'Dani Mocanu','mocanudi@yahoo.com','http://www.danimocanu.net/','92.80.112.120','2008-04-04 10:38:09','2008-04-04 08:38:09','Corectie pentru Bucuresti: \r\n- sa fie toti taximetristii din acelasi trib de rromi;\r\n- sa aibe bara din fata patat de sangele aceluiasi maidanez;\r\n- sa refuze cu totii drumurile pana\'n Dristor la ora 3 noaptea (f***-le muma-n c**)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(20701,1052,'hadean','contact@adihadean.com','http://ww.adihadean.com','194.102.126.6','2008-04-04 07:16:50','2008-04-04 05:16:50','Bag samÄƒ cÄƒ la Cluj Napoca sÄƒ militazÄƒ (ba sÄƒ ÅŸi lucreazÄƒ) pÃ¢ntru Taximetrul Unic. Ioi, nu vreu sÄƒ mÄƒ gÃ¢ndesc ce bÄƒtaie-i la uÅŸa lui cÃ¢nd ploaie afarÄƒ (nu, Ã®nÃ®untru no ploaie de tata asta).Åži apoi, dupÄƒ ce sÄƒ atinje acest deziderat al primÄƒriei, sÄƒ face ÅŸcoalÄƒ de taximetriÅŸti cum sÄƒ face ÅŸcoalÄƒ de majordomi Ã®n anglia numa cÄƒ invers, Ã®n loc sÄƒ-i Ã®nveÅ£Äƒ bune maniere Ã®i Ã®nvaÅ£Äƒ sÄƒ suduie de morÅ£Ã¢Ã¢ cui vre ii ÅŸi Ã®n loc de lecÅ£ii de ÅŸoferie fac lecÅ£ii de tamponare. Åži cÃ¢nd Ã®i gata ÅŸcoala, tÄƒÅ£ taximetriÅŸtii fac poÅŸtÄƒ Taxiu Unic, adicÄƒ ii sÄƒ schimbÄƒ, numa iel rÄƒmÃ¢ne. No, aÅŸ putea continua cu utopia asta da cre cÄƒ taximetria mÄƒ paÅŸte dacÄƒ nu mÄƒ duc sÄƒ lucru un pic. Nu mult, num aÅŸa, la derutÄƒ. CÄƒ vini vorba, nu ÅŸtiÅ£ un job Ã®n Cluj?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12','',0,0),(21178,1053,'vitalie','sprinceana@mail.md','http://spranceana.blogspot.com/','87.255.64.202','2008-04-08 08:08:44','2008-04-08 06:08:44','apropo, mai e o posibilitate: unchi, rude in nigeria, angola, etc..imi vin zilnic scrisoari, cu multe zerouri...sa fac forward message?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ru; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(20734,1052,'Mioritsa','mioritsa@gmail.com','','213.146.172.146','2008-04-04 14:13:09','2008-04-04 12:13:09','Eu am o simpatie maaare pentru taximetristi clujeni, pe care am capatat-o abia  dupa ce m-am mutat in Bucuresti. Am descoperit acolo cu oroare, ca teximetristii sunt o specie de mercenar-bijnitar (nu chiar toti, Doamne-ajutaâ€¦.), care asteapta un bacsis de aproximativ 20-25.000, pe care daca nu-l primesc, striga dupa tine â€œDaca stiam nici nu va luaaaam!â€. Daca nu ai bani marunti, se fac ca nu au rest, au o dispozitie oribila, si in general au un aer de delicvent care stie cum sa stoarca un ban in plus de la client â€¦ mai ales daca are accent de Ardeal.\r\n\r\nApropo de miscarea de unificare a taxiurilor â€¦ sa va zic cum e in Londra. Un singur tip de masina (care nu e de vanzare pe piata, e folosita doar pt taximetrie, si arata arhaic, dar misto si e super incapatoare), de o singura culoare (neagra, fara exceptie). Ca sa devii taximetristi trebuie sa studiezi 34 (!) de luni si sa treci aproximativ 12 examene, in urma carora obtii â€œThe Knowledgeâ€ (suna ca un ritual de obtinere a certificatului de Mason, dar chiar asta e denumirea oficiala). Examenul asta se pare ca e cel mai greu din lume in domeniul taximetriei si regulamentul asta a fost infiinta prin 1800 si ceva, dar inca mai e in vigoare. Si asta in ciuda faptului ca toate taxiurile au SatNav si in principiu s-ar putea descurca si fara The Knowledgeâ€¦\r\n\r\nAstea fiind spuse, n-am luat taxiul decat de 2 ori, ca era urgenta-urgenta si nu plateam eu. E atat de scump incat daca nu esti Kate Moss, Amy Winehouse sau angajat de banca, nu-ti prea arde. Partea cu angajatii bancilor insa nu stiu cat o sa mai dureze, ca au cam sfeclit-o bancile pe aiciâ€¦hahaâ€¦\r\n\r\nDeci in concluzie tot taximetristi de Cluj sunt cei mai tari!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; BCIE6SP1; SV1; .NET CLR 1.1.4322; InfoPath.1; .NET CLR 2.0.50727; .NET CLR 1.0.3705)','',0,0),(20704,1051,'Turambar','mirel@ccsb.ro','http://turambarr.blogspot.com','79.114.190.16','2008-04-04 08:22:21','2008-04-04 06:22:21','Din benefiiciile destuparii la creer. You\'ve just unearthed your true hidden nature. \r\n\r\nAnd your true hidden nature is yellow and sticky.\r\n\r\n:)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(20721,1052,'Basty','sebastian@centre-roumain.fr','http://basty.wordpress.com','82.77.126.21','2008-04-04 12:03:41','2008-04-04 10:03:41','Stimate Gropar, ideea nu e ca-s prea putin taximetristi reglementati. Ideea e ca-s foarte multi ( prea multi, daca ma intrebi pe mine ) dar nu ies pe traseu decat noaptea, cand e tariful maxim.',0,'1','Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_4_11; en) AppleWebKit/525.13 (KHTML, like Gecko) Version/3.1 Safari/525.13','',0,0),(20706,1052,'marz','mariusrott@yahoo.com','','81.12.163.178','2008-04-04 08:30:41','2008-04-04 06:30:41','Las, cÄƒ dupÄƒ ce primeÅŸti permisul de cÄƒlcat pietonii (nu Ã®n sensul galinaceelor, ci cu masina) aflaÅ£i pe carosabil Ã®n afara locurilor special marcate pentru traversare, o sÄƒ Ã®i privesti cu alÅ£i ochi... pe ei, pe taximetriÅŸti. \r\nMie, spre exemplu, de fiecare data cÃ¢nd Ã®i vÄƒd opriÅ£i pe marginea drumului - Ã®n sensul de unde li se Ã®nvÃ¢rtoÅŸeazÄƒ ÅŸtrumeleagul - Ã®mi vine sÄƒ fac pe vÃ¢ntul divin (sau kamikaze, pentru cititorii japonezi).',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(20710,1052,'mosh Califar','t_mit_60@yahoo.com','http://moshcalifar.wordpress.com/','86.107.217.170','2008-04-04 08:59:05','2008-04-04 06:59:05','Compania  \" DobiBoc  Taxi \" :) Oh, mea culpa ,acu\' vazui ca numele primarului par-avion  era tabu...Las\' ca vine Champions League si o sa aveti alt subiect de mandrie patriotica.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; .NET CLR 2.0.50727)','',0,0),(20753,967,'etenah','','','77.81.49.193','2008-04-04 18:26:42','2008-04-04 16:26:42','pariu ca Dumnezeu are simtu\' umorului si te iarta?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(20712,1048,'.marius','marius@perijoc.com','http://marius.wirelessisfun.com','89.36.21.108','2008-04-04 09:36:38','2008-04-04 07:36:38','I think someone has a date :) \r\n\r\nSa nu uitati de lumanari baieti ;-)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9b4) Gecko/2008030714 Firefox/3.0b4','',0,0),(20870,1050,'Groparu','groparu.ro@gmail.com','http://','89.137.109.142','2008-04-05 22:43:06','2008-04-05 20:43:06','@ Livius: mah, sincer, nici io nu mai stiu!\r\n\r\nAmu pe bune, ii textu sursa. Na\', amu am scazut bine in uachii matale?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,2),(21301,1056,'Mari63','mari_birza63@yahoo.com','','92.84.25.199','2008-04-09 19:56:55','2008-04-09 17:56:55','Am ajuns sa te citesc in fiecare zi....de cand cu ziua Denisei.\r\nMa intrebam azi daca ai reusit ce ti-ai propus,,Iâ€™m gonna fuck a really vulgar woman.....,,(curiozitatea...bat-o vina!!)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; FunWebProducts; SIMBAR={B0ED66A2-B664-484A-B27A-540317E2EBB8})','',0,0),(21399,1058,'ania','ania@wip.ro','http://aniakhaki.com','92.82.35.235','2008-04-11 00:10:33','2008-04-10 22:10:33','nu te-am vazut la bendea :| de ce oare? :&gt;',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(21308,1056,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2008-04-09 21:49:13','2008-04-09 19:49:13','Apai nu, ca si dupa elea umbla alti cerbi mai cerbi ca mine!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(21097,1053,'ics','i_uana@yahoo.com','','86.126.99.7','2008-04-07 14:05:29','2008-04-07 12:05:29','pai si doar cu o fisa botswaneza te multumesti tu, Gropare ? m-asteptam la mai mult :-',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(20947,1052,'Victor Ciutacu','victor@ciutacu.ro','http://www.ciutacu.ro','82.76.75.160','2008-04-06 12:14:20','2008-04-06 10:14:20','Tot 53.000 costa cursa de oriunde pana oriunde?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(21102,1054,'hadean','contact@adihadean.com','http://www.adihadean.com','194.102.126.6','2008-04-07 14:52:16','2008-04-07 12:52:16','ioi ca singura poieziea care imi vine amu Ã®n capu-mi e prea porno pentru a putea sta sub poeyia pentru denisa.motiv pentru care o pÄƒstrez pÃ¢nÄƒ bajiun apÄƒntru un inamic. pentru denisa doar\r\ndeniso ne veselim\r\ncÄƒ ca tine nu gÄƒsim\r\nnici salam de la cristim\r\nla anu si la multi ani\r\nce vreti bÄƒ, Äƒsta-i haiku!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12','',0,0),(21103,1052,'tutov','valy_alexe@yahoo.com','http://www.psihopompul.wordpress.com','86.55.176.111','2008-04-07 14:55:04','2008-04-07 12:55:04','eu i-as propune lu boc sa va vopseasca toate taxiurile in rosu galben si albastru',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(21288,1056,'milanesta','ana_stefanaaa@yahoo.com','','79.116.104.61','2008-04-09 16:44:23','2008-04-09 14:44:23','Am crezut ca de Raluca Badulescu vorbesti =))',0,'1','Opera/9.25 (Windows NT 5.1; U; en)','',0,0),(21254,1056,'hadean','contact@adihadean.com','http://www.adihadean.com','194.102.126.6','2008-04-09 07:13:09','2008-04-09 05:13:09','amu Å£-oi spune, cÄƒ pÃ¢ntru iel bistoÅŸ cadÃ¢na iera ceva egzotic nici cÃ¢tuÅŸ de puÅ£Ã¢n vulgar. ÅŸi oricum, tÄƒt Ã®i bine cÄƒ nu Å£-o spus \"gou tu bulgaria\" o ,mai rÄƒu, \"gou tu vulgaria\", ceea ce, dacÄƒ iera american, sÄƒ putea ÅŸi Ã®ntÃ¢mpla.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12','',0,0),(21111,1054,'Brigitte','','','82.77.126.254','2008-04-07 16:24:18','2008-04-07 14:24:18','La muuuulti ani draga de Deni :X:X:X',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; MAXTHON 2.0)','',0,0),(21112,1054,'Butterflyralu','raluk_152003@yahoo.de','http://butterflyralu.blogspot.com','82.77.126.254','2008-04-07 16:29:42','2008-04-07 14:29:42','That\'s my mom! :d',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; FunWebProducts; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(21233,1055,'Andrei','andreibaban@gmail.com','http://www.andreibaban.ro','89.137.114.254','2008-04-08 22:57:05','2008-04-08 20:57:05','jumate din viitorii copii romani se vor naste in spania. Cealalta jumate in italia. Partea buna ii ca in o suta de ani nu o sa mai fie asa aglomerat dimineata',0,'1','Mozilla/5.0 (iPhone; U; CPU like Mac OS X; en) AppleWebKit/420.1 (KHTML, like Gecko) Version/3.0 Mobile/4A93 Safari/419.3','',0,0),(21318,1056,'baghy','baghy83@lycos.it','http://www.baghy.info','78.12.10.164','2008-04-10 00:53:41','2008-04-09 22:53:41','la Cluj nu sunt dinastea?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(21247,1055,'SIBILLA','sibilla_poesis@yahoo.com','http://sfinx667.wordpress.com','89.123.37.90','2008-04-09 04:11:12','2008-04-09 02:11:12','mi-e draga ironia ta  atunci cand vorbesti tu cu tine, cati pot face asta, au puterea sa o accepte sau...\r\ncopiii din noi, inca zambesc, si, zic ca e ine, maturii, musai sa se mai hodineasca... e primavara...\r\nrespecte,\r\nSibilla',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(21377,1058,'Catzaua','ana.man.fox@gmail.com','http://catzaua.wordpress.com','89.123.127.34','2008-04-10 15:11:36','2008-04-10 13:11:36','SIGHISOARA. n-ai citit ce si cum trebuie pe blog :P am moaca de Catza care se oftica si pune botu\' din orice? :)) iar n-ai citit ce si cum trebuie. :) te mai astept pe la mine.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(21282,1056,'!?_Je_?!','florina_audochii@hotmail.com','','194.102.139.9','2008-04-09 14:58:05','2008-04-09 12:58:05','Huh, m-ai prins!!\r\nShhh, nu mai spune la nimenea :D',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(21122,1054,'Mari63','mari_birza63@yahoo.com','','92.84.25.199','2008-04-07 18:58:41','2008-04-07 16:58:41','Mai are loc si comentariul meu?...Nu sunt in masura sa-ti ,,analizez ,,poezia dar sunt in masura sa-ti confirm ca Denisa merita toate urarile tale...si cine gandeste in felul asta despre Deni nu poate sa fie decat..un minunat!!',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; FunWebProducts; SIMBAR={B0ED66A2-B664-484A-B27A-540317E2EBB8})','',0,0),(21374,1058,'Nelu','nelu@nelui.nl','http://www.nelu.com','194.117.242.3','2008-04-10 15:03:57','2008-04-10 13:03:57','Un om mai sec decat Bendea mai rar gasesti. Nu ca ar fi prost, dar n-are simtu ridicolului si nu isi da seama ca nu e suficient sa vrea sa fie pontos. N-are talent si ii p-nal. Totusi e preten cu toti, asta nu e un motiv sa ii facem reclama.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(21375,1058,'Catzaua','ana.man.fox@gmail.com','http://catzaua.wordpress.com','89.123.127.34','2008-04-10 15:04:13','2008-04-10 13:04:13','no_name, nu iti contest inteligenta, valoarea si spiritul critic obiectiv, de buna seama, dar zic ca mai bine te apuci sa-ti cauti un nume cat de cat acolo, sa stiu dupa cine marai. :))\r\nesti in criza de lecturi? am un blogroll, foloseste-l cu incredere. aia-s intr\'adevar oameni interesanti. \r\n[pliiiiiz stop yappin\' :) thank you :D ]',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(21376,1058,'no_name','bad_boy_mir@yahoo.com','','78.41.22.210','2008-04-10 15:09:12','2008-04-10 13:09:12','Catzaua am citit si de la tine din blogroll si e destul de interesant dar esti putin cam agresiva cu ceilalti....poate ca nu sunt de acord cu asta....oricum e klar ca esti sibianca dupa felul in care vb si apropo e mai intersant asa,de ce miar trebuii un nume de scena gen catelul?:P\r\nscuze daca am fost rau:))',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(21317,1057,'Ciprian','ciprian@it-exchange.ro','','89.137.124.1','2008-04-10 00:45:11','2008-04-09 22:45:11','Mai Gropare, era sa-mi trezesc nevasta - am ras de unul singur -  la 2 noaptea, dupa ce am cetit ce ti-o mai nascocit mintea ta de Gropar campion. \r\n\r\nAsa logica si asa fir epic... mai rar.:))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US) AppleWebKit/525.13 (KHTML, like Gecko) Version/3.1 Safari/525.13.3','',0,0),(21278,1056,'!?_Je_?!','florina_audochii@hotmail.com','','194.102.139.9','2008-04-09 14:43:10','2008-04-09 12:43:10','He, he!\r\nDaca\'ai stii tu cu cata dedicatie te \'citeste\' unii/unele ... like there\'s no 2morrow!\r\nLas\' ca vin si zile mai bune, ai sa vezi!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(21286,1056,'Andreea','puistrulet2003@yahoo.com','http://n/a','81.196.150.196','2008-04-09 16:27:03','2008-04-09 14:27:03','@!?_Je_?!: maa, trebuia sa te faci ca ploua.... :)\r\n\r\nNoi toti care scribalim pe aici suntem oameni smecheri care fac multitasking, nu Gropare? :) \r\nHai zi ceva frumos si de noi....take away the guilt.. :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(21277,1056,'Andreea','puistrulet2003@yahoo.com','http://n/a','81.196.150.196','2008-04-09 14:04:20','2008-04-09 12:04:20','@Groparu; tulai doamne da tu unde le gasesti???? Io n-am atata spiritoi de observatie :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(21275,1056,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-04-09 13:31:48','2008-04-09 11:31:48','...running out of brain cells, I am! :D\r\n\r\nwespect ca ai tinut minte, ca io, la 500 de postari cate am, deja cam derapez, dupa cum bine se vede ;;)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(21269,1056,'gb','getbordea@yahoo.com','http://getbordea.blogspot.com','208.77.165.40','2008-04-09 12:09:51','2008-04-09 10:09:51','@Emaginatoru\r\nBerile si caldura asfaltica ajuta procesului de autoeducare.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(21270,1056,'mo','verde_poveste@yahoo.com','','194.126.220.22','2008-04-09 12:25:52','2008-04-09 10:25:52','Si la a cata bere zici ca ai remarcat gagica? :-)\r\n\r\nDaca ar fi sa dau crezare unui tip care a stat in Londra vreo 4 ani, sunt multe gagici vulgare pe acolo, rotunde, intolite aiurea si mereu bete seara. Nu ma pot hotari daca asta e un lucru bun sau rau...',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1)','',0,0),(21379,1052,'UnCopilutz','uncopilutz@yahoo.com','http://www.uncopilutz.haipa.ro','82.77.73.73','2008-04-10 16:07:00','2008-04-10 14:07:00','Desi c-o sepcuta cu elice-n varful capului i-ar sta bine s-ai zice ca-i copil, deci, ca-s io, totusi nu, nu-s Boc.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(21219,1055,'lo','','','69.131.163.151','2008-04-08 18:34:59','2008-04-08 16:34:59','sau sa procreeeze groparu\', tzucu-l-as :) aia da romani fericiti :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; ro-RO; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(21273,1056,'!?_Je_?!','florina_audochii@hotmail.com','','194.102.139.9','2008-04-09 13:29:38','2008-04-09 11:29:38','No, parca ai mai pomenit de chestia asta....\r\nNtzz, ntzz ....\r\nRunning out of inspiration, Mr. Groparele?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(21263,1056,'Emaginatoru','','','79.116.82.163','2008-04-09 10:20:51','2008-04-09 08:20:51','Maestre, respect pentru putirinta de a placea o asa un exemplar. Eu nu pot sa ma autoeduc in acest sens.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(21279,1056,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-04-09 14:47:07','2008-04-09 12:47:07','Or sa vie zile mai bune, aia-i clar, da\' inke n-am de gand sa mor, ma-ntelegi.\r\n(paradoxal, amu la radio canta Queen - who wants to live forever)\r\n\r\nMersi ca ma cetesti, inseamna ca si tu ai un job in care nu faci nimic toata ziua si mori de plictiseala! :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(21280,1056,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-04-09 14:47:57','2008-04-09 12:47:57','@ Andreea: they\'re everywhere. Intr-o vreme erau si prin baia si patul meu, da\' intre timp nici p-elea nu le-am mai putut combina!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(28672,1119,'Kidha','kidha_flo@yahoo.com','http://kidha7.blogspot.com','89.39.184.236','2008-06-09 17:02:30','2008-06-09 15:02:30','Nu stiu pentru tine, dar pentru mine e o adevarata oroare sa apar in acelasi FHM ca si diva de Andreea Balan. :P\r\nCongrats, suntem aprope celebri',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(32348,1149,'hadean','contact@adihadean.com','http://www.adihadean.com','79.113.87.77','2008-07-02 20:14:03','2008-07-02 18:14:03','beku, dipinghe ghe zona folcloricÄƒ Ã®n care o pÄƒscut vaca :-)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.15) Gecko/20080623 Firefox/2.0.0.15','',0,0),(28939,1126,'Turambar','mirel@ccsb.ro','http://turambarr.blogspot.com','79.114.190.228','2008-06-11 21:14:26','2008-06-11 19:14:26','Cine\'i mai inteligent in toata bulibasheala asta? Ca nu prea am intzeles egzact. I feel slightly intellectually challenged...\r\n\r\n:blink:',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(26760,1104,'dunec','the_dun3@yahoo.com','http://dunec.wordpress.com/','92.81.174.58','2008-05-25 21:12:04','2008-05-25 19:12:04','dude... nu pot sa cred.. mancam aceiasi pufuleti... sau... ma rog... \"aceiasi firma\" :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9) Gecko/2008051206 Firefox/3.0','',0,0),(28699,1119,'hadean','contact@adihadean.com','http://www.adihadean.com','80.97.31.146','2008-06-09 21:29:47','2008-06-09 19:29:47','deci cand ii apare in \"cutezatorii\" sau \"formul as\" (nu ass) mai vorbim.\r\ncum cine o aparut? mihai constantinescu, respectiv decoctu de ciubotica cucului.cred ca poti si tu. no.bine?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1) Gecko/20061010 Firefox/2.0','',0,0),(33679,1155,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','79.116.96.71','2008-07-17 01:08:22','2008-07-16 23:08:22','@ felix: planurile mele de viitor se marginesc la a ma juca cu plozii cand ei are chef sa ii zambeasca la unchiu\', nu la a-i si - cum sa-ti zic - creste ca si cand numai nevoile lor ar fi pe pamant!\r\n\r\n@ Roza: Apai tu, Rozi, io stiam ca daca n-am ovare, dijaba ma tat chinui sa am copkii! Plus ca nij nu pot importa din China, ca m-am interesat. Cat despre matusica, o zis ca nu se poate pune vorba deocamdata, ca atata-s de sireac de bani si de duh ca nij carnet de sofer n-am. Plus ca-i si minora, n-are decat 14... oooops! Uita ca am zis ceva :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.16) Gecko/20080702 Firefox/2.0.0.16','',0,0),(32345,1149,'Beku','vasihojda@yahoo.com','','78.97.165.34','2008-07-02 19:14:52','2008-07-02 17:14:52','@ hadean\r\n FiÅŸior, groÅŸtioru nu-i lapte strÃ¢cat, cÄƒ-i smÃ¢ntÃ¢nÄƒ de ai\' mai bunÄƒ;)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9) Gecko/2008052906 Firefox/3.0','',0,0),(23123,1079,'anyone','','','89.136.15.224','2008-04-27 16:23:53','2008-04-27 14:23:53','nu e rau dar inavtza sa scrii in romaneste totusi',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(21501,1058,'ania','ania@wip.ro','http://aniakhaki.com','92.82.35.235','2008-04-11 21:32:35','2008-04-11 19:32:35','nicu e bendea ;)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(25167,1085,'iulianuss','realvision@k.ro','','193.231.107.209','2008-05-12 16:25:11','2008-05-12 14:25:11','Berea instant! CÄƒ m-am sÄƒturat de lÄƒzile trÃ¢ntite zilnic sub geamul meu...',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(28923,1126,'hadean','contact@adihadean.com','http://www.adihadean.com','86.125.34.195','2008-06-11 16:50:27','2008-06-11 14:50:27','amu dupÄƒ una ca aiasta, crekÄƒ numa dacÄƒ Ã®i fi cetat pÄƒ o cruce din cimitiru vesel din sÄƒpÃ¢nÅ£a, zis ÅŸi temeteu, mÄƒ mai poÅ£i surprinde. nu-i bai cine-i su cruce, numa tu sÄƒ nu fii. nici n-ai cum batÄƒ-mÄƒ, cÄƒz doarÄƒ tu eÅŸti groparu. no, m-am liniÅŸtit io sÃ¢ngur (cÄƒ tÄƒt zÃ¢ce omu de armatÄƒ, cÃ¢nd numa sÃ¢ngur te putei liniÅŸti).',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(28810,1121,'mack','cherokee_lane@yahoo.com','','92.80.37.236','2008-06-10 15:23:22','2008-06-10 13:23:22','da\' poate le meriÅ£i, mÄƒi, gropÄƒre, asta Ã®ntrebatu-te-ai? ;)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(28811,1121,'V_for_Whatever','stephanovendetta@yahoo.com','','89.136.50.177','2008-06-10 15:25:07','2008-06-10 13:25:07','dom\'le, este imposibil/extrem de greu sa prea-curvesti...@maaaaaah\r\n\r\nAcest termen este inscris in cele 10 pacate mortale tocmai pentru ca noi barbatzii, de cand ne nashtem si pana cand murim incercam sa ajungem la acest record... A preacurvi este ca un fel de YOU WON!GAME OVER!... Mie mi-a luat 14 ani sa ajung in primul stagiu al jocului (fara coduri!!!)...desigur, unii oameni joaca corect...alti oameni gasesc cheaturile si din cand in cand isi mai sporesc scorul cu puncte valorificate banesc...desigur, avem si reguli pentru joc si de fiecare data cand se constata o abatere de genul, numita in acest caz prostitutie, ea este sanctionata si de-obicei se prevad pedepse in care esti scos din joc temporar...ca un fel de GO TO JAIL al monopoly-ului...Intreaga noastra viatza avem preocuparea de a termina si a obtine un punctaj cat mai mare...este in sangele nostru, in gandire s.a.m.d...unii dintre noi, cate-odata, raman la acelasi punctaj...natura lor ii indeamna din cand in cand la cate un punct temporar, care nu poate fi insa valorificat...altii dintre noi, din diferite considerente, vor sa se opreasca din acest joc, alegand o viatza monahala...in unele cazuri, punctajele temporare in acest caz ar putea constitui adevarate recorduri daca ar fi valorificate oficial...\r\n Unele tactici murdare de joc au fost dezvoltate de-alungul timpului de catre fruntasii clasamentului, in dorinta de a-si mentine pozitia si de a se distantza de \"pluton\". Cel mai intalnit concept de acest fel, care in mod crud si total lipsit de fairplay restrictioneaza jucatorul sau in cel mai bun caz il intarzie considerabil este conceptul de \"casnicie\"... Odata lansat in lume, odata incarcat in constiinta colectiva impreuna cu conceptul de \"monogamie\", s-a constatat o reducere impresionanta a jucatorilor care ajung efectiv la terminarea acestui joc...nu intelegeti gresit, exista intr-adevar niste high scoruri considerabile, demne de admiratie, dar statisticile arata ca prea-curvia, daca pana la momentul inscrierii in tablitzele lui Moise era un moment culminant in dinamica acestui joc si implicit a vietzii menkind-ului, ulterior a cunoscut un declin vertiginos, ajungand in ziua de astazi o raritate. Istoria scrisa se pare ca a \"uitat\" ultima consemnare a unei preacurviri in sensul \"YOU WON, GAME OVER!\"...desi pe parcurs apar unele documente care inregistreaza high scoruri, ca si GIACOMO CASANOVA de exemplu...In concluzie, tot ce putem face este sa incercam sa ne apropiem de un high-score admirabil, cu sperantza preacurvirii in suflet si cu gandul la un sfarsit regulamentar, cu zambetul pe buze...cel putin io asa as vrea sa mor :D -DISCLAMER - ESTE FOARTE IMPORTANT CA ACEST TEXT SA FIE PRIVIT CA O GLUMA, ORICE ASEMANARE CU REALITATEA ESTE PUR INTAMPLATOARE. IDEILE EXPRIMATE MAI SUS NU CORESPUND CU REALITATEA IN NICI UN MOD, PERSONAL CRED IN IUBIRE, DRAGOSTE SI CRED CA, CASATORIA ESTE CONSFINTIREA UNEI RELATII MONOGAME PRIN CARE ELOGIAZA DRAGOSTEA SI PUNE BAZELE FAMILIEI, FIIND DE O IMPORTANTZA INESTIMABILA.   \r\np.s indiferent ce spune o persoana de sex feminin in legatura cu chestia asta de mai sus, sant complet de-acord si mai mult decat atat sant indignat cum de unii barbatzi pot gandi in acest mod...',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; .NET CLR 2.0.50727; InfoPath.2; Seekmo 10.0.424.0)','',0,0),(28779,1119,'Turambar','mirel@ccsb.ro','http://turambarr.blogspot.com','92.80.54.150','2008-06-10 11:58:24','2008-06-10 09:58:24','Nasol. Ai ajuns person public. Acum trebe sa incepi sa vorbeshte corect. Therefore s-a dus dracu toata farmecu tau. Therefore you\'re about to get nashpa. Therefore you should start drinking. \r\n\r\nHeavily.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(31166,1144,'Sinzi','fata_cu_par_verde@yahoo.com','','86.123.76.106','2008-06-25 09:16:21','2008-06-25 07:16:21','sau un RATS sucevean :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(28758,1121,'maaaaaah','totmea@yahoo.com','','89.123.77.194','2008-06-10 09:27:37','2008-06-10 07:27:37','vezi daca preacurvesti!!!  :-)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; SIMBAR={3523AA32-EC48-4B99-902E-C5F036C0464E}; Zango 10.3.36.0)','',0,0),(28759,1121,'maaaaaah','totmea@yahoo.com','','89.123.77.194','2008-06-10 09:29:19','2008-06-10 07:29:19','si nu numa\'!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; SIMBAR={3523AA32-EC48-4B99-902E-C5F036C0464E}; Zango 10.3.36.0)','',0,0),(28762,1121,'ameÅ£itul','','http://ametzitul.wordpress.com/','82.76.123.238','2008-06-10 09:39:40','2008-06-10 07:39:40','evident , aici ieste o conspiraÅ£ie...',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(28763,1119,'WhiteWolf','laskmerge@gmail.com','http://white-wolf.ro','79.118.187.170','2008-06-10 09:42:09','2008-06-10 07:42:09','Daca e sa judeci cati dau si bani pe FHM si cati vin pe aici sa beie si sa se rÃ zÃ£ pe gratis, zau, ar cam trebuie sa-si umfle pieptul FeHasheM-ii ca au aparut pe groparu punct ro.\r\nPe Gogu nu-l platesc destul pentru a continua sa le tina tirajul anonim in viata cu popularizari pe bloguri :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(28771,1121,'mo','verde_poveste@yahoo.com','','194.126.220.240','2008-06-10 11:11:27','2008-06-10 09:11:27','Io-s sigura ca toacla o fugit singura din chimnita, jignita de atata nefolosinta. In afara de bita si de pterodactilgainat, tate celelalte se rezolva: ia da tu pe la o firma care vinde corturi si-ai sa vezi ca au bare de sustinere  si chituri de reparat materialu\'  - ace, ata (grandma not included) si lipici pentru uameni intreprinzatori da\' nepriceputi intr-ale insailatului (ca mine, de exemplu). \r\nA, si apropo de uameni intreprinzatori, io zic ca un schimbat de bec si de baterie de dus nu sunt un sfarsit de lume, asa ca la treaba, Groparele, pana nu ajungi din armasar mandru o zebra emo (cu dungi de jeg sau fata-n dungi).',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1)','',0,0),(28770,1121,'gb','getbordea@yahoo.com','http://getbordea.blogspot.com','208.77.165.40','2008-06-10 11:08:41','2008-06-10 09:08:41','Nu imi dadeam seama de ce imi merge asa bine in ultima perioada. Se distreaza cu un gropar!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(31180,1144,'Cristian Ungur','cristian.ungur@utopium.ro','http://cristianungur.blogspot.com','85.186.103.54','2008-06-25 11:05:19','2008-06-25 09:05:19','De mult n-am mai fo cu troleu in Cluj. Da nu mi-i ase dor...',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(28921,1126,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-06-11 16:25:09','2008-06-11 14:25:09','OMG!!! Deci de-aia mi-o zis mie vocea... stii ce mi-o zis? Zice \"Ricky ala de respira greu... stii cine era? Era ta-su, mah...\"',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(31217,1144,'WhiteWolf','laskmerge@gmail.com','http://white-wolf.ro','79.118.187.139','2008-06-25 15:56:28','2008-06-25 13:56:28','Si daca ar fi fost scurte era (de mai putin) rau ?\r\nCa partea asta chiar n-am inteles-o :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(33128,1154,'DeBlog','gogu.samsung@gmail.com','http://www.de-blog.net','84.232.176.216','2008-07-10 16:23:19','2008-07-10 14:23:19','Apoi banuiesc ca doar nu munciti la firma aia. Io zic sa il puneti pe unu sa faca plantoane cu ochii pe masini...  Dupa aia, distractie :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.9) Gecko/2008052906 Firefox/3.0','',0,0),(26883,1105,'ramonici','mum_2_us@yahoo.com','http://www.ramonaa.deviantart.com/','89.33.174.82','2008-05-26 13:27:16','2008-05-26 11:27:16','cat ai fost plecat ai pierdut o tura de bungee jumping si un concert phoenix :P',0,'1','Opera/9.26 (Windows NT 5.1; U; en)','',0,0),(28795,1121,'catalin','catalin_heghes@yahoo.com','http://heghes.blogspot.com','84.232.142.163','2008-06-10 13:33:51','2008-06-10 11:33:51','suspect!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(28796,1119,'yesterdayman','yesterdayman@gmail.com','http://blog.patratel.ro','195.42.116.1','2008-06-10 13:38:37','2008-06-10 11:38:37','si io care cand am vazut titlu\' am crezut ca ai aparut in FHM tu in deplinatatea fizicului tau... Ma pregateam sa ma-mprumut de bani sa cumpar revista, ca sa cer si io un autograf de la o celebritate in viatza shi sa ma-mbogatzesc vanzandu-l pe un milion de iepuroi dupa ce dai coltzu\'...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(26888,1105,'ameÅ£itul','','http://ametzitul.wordpress.com/','82.76.123.238','2008-05-26 13:55:04','2008-05-26 11:55:04','aÅŸteptÄƒm mÄƒcar relatarea, atunci... :)\r\npiticul tot cu alcoolice trece ;)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(28803,1121,'seliman','ionut.seliman@gmail.com','http://ionutu.wordpress.com','213.157.171.107','2008-06-10 13:56:22','2008-06-10 11:56:22','DacÄƒ Ã®i sÄƒ mÄƒ Ã®ntrebi, io aÅŸ zÃ®ce cÄƒ DumniezÄƒu Ã®i fie o femeie Ã®ntre doo vÃ®rste menopauzatÄƒ prematur, ÅŸi atunci Ã®i esplicabil, fie Ã®i un moÅŸuleÅ£ sadic ÅŸi senil, caz Ã®n care Ã®i ÅŸi mai nasol de noi..ar mai hi o variantÄƒ, ÅŸi anume aia Ã®n care, ÅŸtim cu toÅ£ii cÄƒ Iel Ã®i aspaÅ£ial ÅŸi un veac pentru Iel Ã®i cÃ®t o secundÄƒ pentru noi, deci varianta Ã®n care nu s-o trezit Ã®ncÄƒ din beÅ£ia prilejuitÄƒ de facerea lumii... ;)\r\nOps, iar am vorbit Ã®n deÅŸert. :D',0,'1','Opera/9.27 (Windows NT 5.1; U; en)','',0,0),(31449,1145,'mo','verde_poveste@yahoo.com','','194.126.220.240','2008-06-26 15:35:03','2008-06-26 13:35:03','Neeeeh, daca nu s-au facut nazisti pana acum din cauza porcilor albi de la periferiile sudice ale continentului, nu stiu nu stiu.... Bine, parca si gagica aia, Charliza Theron e din Africa de Sud, asa ca daca toate albinoasele de acolo arata asa, pai se explica multe :D',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1)','',0,0),(25161,1085,'hadean','contact@adihadean.com','http://www.adihadean.com','86.125.34.195','2008-05-12 15:22:58','2008-05-12 13:22:58','bere antitetanos si antirabie.ar trece, pun pariu:-)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(25163,1085,'pliscu','pliscu@gmail.com','http://pliscu.blogspot.com','89.137.100.118','2008-05-12 15:29:34','2008-05-12 13:29:34','cu ideile astea bune, nu m-ar mira sÄƒ primeÅŸti un telefon de genul:\r\n\r\n\"BunÄƒ ziua, domnule Groparu, de la <a href=\"http://www2.tvr.ro/arenaleilor/\" rel=\"nofollow\">Arena Leilor</a> vÄƒ deranjÄƒm. AÅ£i dori sÄƒ participaÅ£i la emisiunea noastrÄƒ?\"\r\n\r\n:P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(25164,1085,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-05-12 15:32:12','2008-05-12 13:32:12','Da! Si eu sa ii intreb: care va fi contributia dvs. la afacere? Numai 4 mil coco??? That\'s it, no soup for you!!! You\'re FIRED!!!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(29857,1136,'catalin','catalin_heghes@yahoo.com','http://heghes.blogspot.com','84.232.142.163','2008-06-17 16:53:18','2008-06-17 14:53:18','mai corect era utc, pcr, fsn. ca fsn a fost tata si mama clasei politice romanesti.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(33127,1154,'nebuloasa','nebuloasablonda@yahoo.com','http://nebuloasa.wordpress.com/','193.194.130.37','2008-07-10 16:13:00','2008-07-10 14:13:00','Nu unieva, Gropare, ci intr-un loc cu precizie stabilit..',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727)','',0,0),(31436,1145,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-06-26 14:21:52','2008-06-26 12:21:52','Facem Nello.groparu.ro ?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(31437,1145,'Nello','','','194.117.242.3','2008-06-26 14:28:50','2008-06-26 12:28:50','Absolutamente (sau chiar groparu_mananca_numa_de_la_alacluj.blogspot.com) fara reclama mascata caci e pe fatza;) \r\n\r\nPS daca s-ar manca si la Generalu, il puneam si pe dÃ¢nsul pe blog',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(21646,1058,'Catzaua','ana.man.fox@gmail.com','http://catzaua.wordpress.com','89.34.72.93','2008-04-12 12:46:30','2008-04-12 10:46:30','sa ne traiasca. he\'s funny :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(31441,1145,'Uca','','','86.34.167.172','2008-06-26 14:47:05','2008-06-26 12:47:05','Sa moara toti nazisti de ciuda ca io am auzit ca in cateva sute de ani populatia lumii va arata ca o mare ciorba babiloniana in care diferente rasiale vor disparea. Toti oamenii vor fi un fel de mulatrii iar gena blonda va fi istorie, ca e recesiva. \r\n..si atunci bancurile cu blonde se vor transforma in bancuri cu brunete :)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1; .NET CLR 2.0.50727; .NET CLR 1.0.3705; .NET CLR 1.1.4322)','',0,0),(26902,1105,'WhiteWolf','contact@white-wolf.ro','http://white-wolf.ro','79.115.97.21','2008-05-26 16:26:51','2008-05-26 14:26:51','Asadar, claro, ranitzi au fo\' :)\r\nMai au rasinarenii ghiboli ? Da\' varza ? :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(21533,1056,'zgura','','','79.116.97.97','2008-04-12 00:57:21','2008-04-11 22:57:21','Aha, as vrea sa subliniez un aspect mai subtil al acestui post, si anume pentru toate femeile pe care Groparu le-a:\r\nputeti dormi linistite, Groparu nu va considera ca fiind niste femei foarte vulgare. Si asta ar putea fi chiar complement de 8 martie',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(25155,1085,'alin62','alin62@yahoo.com','','86.55.176.81','2008-05-12 13:03:09','2008-05-12 11:03:09','fiecare cu ce-l doare\r\nbere cu viagra',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(29842,1136,'julius','julius@universitateacraiova.ro','http://www.7plus.ro/?arhiva=17/06/2008&#38;id=7060','84.232.163.49','2008-06-17 15:32:08','2008-06-17 13:32:08','N-am inteles nimic din postul asta. Daca n-ai vrut sa zici nimic, atunci ai fost coerent :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(27047,1107,'Cristian Ungur','cristian.ungur@utopium.ro','http://cristianungur.blogspot.com','85.186.103.54','2008-05-27 12:19:40','2008-05-27 10:19:40','Scriam ceva despre \"ce cauta lumea pe net\" si ma uitai la tine in trafic la \"cuvinte cheie\". Doamne feri! \r\n\r\nPS. La multi ani Alinului si ma scuzati ca-s pe langa subiect.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(25154,1085,'','','','194.102.139.9','2008-05-12 12:50:40','2008-05-12 10:50:40','Berea anti-(nesimtire si/sau prostie), se poate, d-l Gropar?!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(28934,1126,'calarasu','acalarasu@gmail.com','http://adriancalarasu.wordpress.com','91.203.96.22','2008-06-11 20:15:07','2008-06-11 18:15:07','hahahahaha, te-a avut Groparu, bai Julica, nici eu nu puteam sa ti-o trag asa de bine!',0,'1','Opera/9.50 (J2ME/MIDP; Opera Mini/4.1.11355/524; U; en)','',0,0),(28935,1126,'julius','julius@universitateacraiova.ro','http://www.7plus.ro/?arhiva=11/06/2008&#38;id=6786','84.232.162.174','2008-06-11 20:17:47','2008-06-11 18:17:47','@Cala: stii cum se spune, ca aia mai slabi se aliaza intotdeauna impotriva celui mai puternic (sau mai inteligent, nu mai tin minte exact :D)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(31280,1139,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','79.116.96.236','2008-06-25 21:48:50','2008-06-25 19:48:50','Groparu\r\n\r\nluvz\r\n\r\nFagaras\r\n\r\n!!!!\r\n\r\n\r\n(4\r\n\r\n\r\never)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(31279,1139,'baghy','baghy83@lycos.it','http://www.baghy.info','78.12.11.8','2008-06-25 21:45:39','2008-06-25 19:45:39','Gropare te-ai apropiat cam tare de zona mea. Ai grija baiete',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; it; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(21732,956,'kleine Eule','','','79.112.88.32','2008-04-12 20:41:09','2008-04-12 18:41:09','asta le bate pe toate.dovada vie ca o data pe an au si barbatii suflet.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 2.0.50727; InfoPath.1)','',0,0),(29675,1119,'Groparu','groparu_ro@yahoo.com','http://','79.116.97.175','2008-06-16 23:13:53','2008-06-16 21:13:53','Oare eu am publicat commentu\' asta?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,1),(31108,1144,'Nox','','http://s3my.blogspot.com/','89.47.100.75','2008-06-24 15:18:39','2008-06-24 13:18:39','uneori se intampla sa nu fie chiar asa de lipicioase. dar asta e fenomen rar, ce apare numai in autobuzele noi-noute. :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(23134,1079,'baghy','baghy83@lycos.it','http://www.baghy.info','78.12.10.158','2008-04-27 21:44:19','2008-04-27 19:44:19',':)))))))))))) Sarbatori fericite Gropare',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(32117,1148,'Greuceanu','','','89.46.104.35','2008-07-01 22:13:46','2008-07-01 20:13:46','la asha o blondoaka...... da-o dreaku de mashina.... + ca n-ai precizat daca jip-u si A6-le erau de CJ',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(33666,1156,'Roxa','roxatrutza@rdslink.ro','http://fascination-street.ro/','79.119.221.43','2008-07-16 22:39:42','2008-07-16 20:39:42','Noah deci rabda acolo, ca merita, si plezneste si gingia ceia sa-si tina durerile pentru ea.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(29667,40,'Groparu','groparu_ro@yahoo.com','http://','79.116.97.175','2008-06-16 22:33:11','2008-06-16 20:33:11','Poza o am acasica, la Sighie, si trebe scanata.\r\n\r\nDa\' se face.\r\n\r\nMai incolo :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,1),(31107,1139,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-06-24 14:35:24','2008-06-24 12:35:24','Mooo!!!\r\n\r\nDeci io ziceam de zona aia a lu Gadjo Dilo ca fiind a\' mai faina, da\' nu in sensu ala in care Copsa Mica e cel mai frumos oras din Romania.\r\n\r\nVarfu\' Slanina itz zice ceva?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(28655,1119,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-06-09 14:04:09','2008-06-09 12:04:09','Ba, burlac atacat de mirosuri: vezi ca pt din aia ca tine is saituri cu pornache gratis, nu tre\' sa mai dai 10 lei pe un revist care nu-i in stare nici sa o dezveleasca pe Andreea Balan cum trebuie!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(25196,1026,'macabroo','raduccc@yahoo.com','http://rezistenta.blogspot.com','82.76.52.94','2008-05-12 23:17:15','2008-05-12 21:17:15','Bine ca esti tu destept! Acum mi-e pofta si de bere si de tichila. Si de zapada.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; en-GB; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(25198,1026,'pliscu','pliscu@gmail.com','http://pliscu.blogspot.com','89.137.112.21','2008-05-12 23:25:46','2008-05-12 21:25:46','@macabroo: de o <i>Alba-ca-zapada</i>? :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(28640,1119,'PhenoBarbieDoll','oana.gavrila@mediafax.ro','','193.230.230.101','2008-06-09 11:27:49','2008-06-09 09:27:49','Tzuca-l-ar mama pe el de Gropar vedet care este!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(33784,1157,'normancboy','normancboy@yahoo.com','','212.201.44.30','2008-07-17 22:38:26','2008-07-17 20:38:26','Lasa bre fata ca probabil aveau un ONG handarcavar de invatat muste sa inoate.\r\n\r\nIntrebarea intrebacioasa daca v-o bagat musca pe nota de plata? Ca asa puteati sa ii acuzati de proxenetism cu muste si le spulberati mitu de ongisti pacifisti.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9) Gecko/2008052906 Firefox/3.0','',0,0),(28648,1119,'julius','julius@universitateacraiova.ro','http://www.7plus.ro/?arhiva=09/06/2008&#38;id=6711','84.232.160.62','2008-06-09 12:31:49','2008-06-09 10:31:49','Ce prost esti, Gropare. Pai ideea nu e sa apari tu in FHM, ci gagica-ta. Atunci da, esti un tip tare :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(25199,1026,'macabroo','raduccc@yahoo.com','http://rezistenta.blogspot.com','82.76.52.94','2008-05-13 00:04:05','2008-05-12 22:04:05','Nu stiu ce vrei sa insinuezi. Dar orice-ai fi auzit nu e adevarat. ;)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; en-GB; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(31058,1139,'julius','julius@universitateacraiova.ro','http://www.7plus.ro/?arhiva=24/06/2008&#38;id=7367','84.232.161.95','2008-06-23 21:56:55','2008-06-23 19:56:55','Bai, aia cu nimfa lacului a fost geniala. Sper ca te-ai impreunat cu ea, sa le dam peste nas la arogantii aia din Loch Ness cu monstrul nostru, peste 9 luni.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(33223,1152,'hurri','hurri_canne@yahoo.com','http://hurrionline.net','89.137.58.105','2008-07-11 17:18:32','2008-07-11 15:18:32','fain la Sibiu.Sa vii cu post-uri de acolo. :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.9) Gecko/2008052906 Firefox/2.0.0.14;MEGAUPLOAD 1.0','',0,0),(33217,1152,'nebuloasa','nebuloasablonda@yahoo.com','http://nebuloasa.wordpress.com/','193.194.130.37','2008-07-11 16:15:01','2008-07-11 14:15:01','Uei, Gropare, spune-i un \"servus\" la Sibiul cela de la mine. Distractie placuta!',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727)','',0,0),(33219,1154,'Sinzi','fata_cu_par_verde@yahoo.com','','86.123.76.106','2008-07-11 16:22:46','2008-07-11 14:22:46','si nu l-a \"indesat\" nimeni inapoi de unde numa mama l-a scos?!?!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.15) Gecko/20080623 Firefox/2.0.0.15','',0,0),(31372,1139,'Emi','emi.cristea@floaredecolt.org','http://emi.floaredecolt.org','79.114.196.90','2008-06-26 07:20:49','2008-06-26 05:20:49','Cand zici betoana, te gandesti la betonata ... nu !? :))',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.648; .NET CLR 3.5.21022; InfoPath.1)','',0,0),(33190,1152,'seliman','ionut.seliman@gmail.com','http://ionutu.wordpress.com','213.157.171.107','2008-07-11 11:38:44','2008-07-11 09:38:44','Gropare dacÄƒ era bloaggÄƒ erea la menopauzÄƒ, fiind blogg Ã®i la andropauzÄƒ. Meri\' cu Alah!',0,'1','Opera/9.27 (Windows NT 5.1; U; en)','',0,0),(31418,1137,'lizard','iri_irinuka@yahoo.com','','79.119.126.131','2008-06-26 12:20:09','2008-06-26 10:20:09','cica banc..de ce nu am inscris cu olanda?   Piturca: trage Mutule!!   Mutu: nu pot ca m-am lasat !   =))',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(28573,1118,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','79.116.97.92','2008-06-08 23:49:48','2008-06-08 21:49:48','Il stii pe Vali Greavu, fost securist? (intrebare pe bune, nu stiu cum sa dau de el, ca mi-o fost prieten)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(31051,1135,'ovidiu666','ovidiulechintan@yahoo.com','http://ovidiu666.wordpress.com','79.116.96.179','2008-06-23 20:34:05','2008-06-23 18:34:05','deci... daca ai orgasm cand vezi pestii holbandu-se la tine de pe tava plina de gheata alba fugi la real,- pt multiple orgasm! sa vezi ce te-apuca tremuriciu\' cand privesti in ochi caracatita sau vreun peste spada! :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(23146,1078,'cipoc','cipoc2003@gmail.com','http://2mpx.ablog.ro/','194.176.166.54','2008-04-28 01:33:43','2008-04-27 23:33:43','ar fi chemat`o cherida:P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(32104,1148,'alin62','alin62@yahoo.com','','86.55.176.66','2008-07-01 21:05:00','2008-07-01 19:05:00','a invatat si groparu sa minta...\r\nsa vedeti ce patanii o sa aiva el de acum  cu tot felul de bunaciuni...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(31573,1139,'mo','verde_poveste@yahoo.com','','194.126.220.240','2008-06-27 11:30:44','2008-06-27 09:30:44','Apropo de poza erotica de mai sus - tata lumea are cicatrici pe dejtu\' aratator de la mana stanga? Am si io, mai am un prieten cu cicatrice fix acolo, asa ca ori suntem toti intr-o asociatie atat de secreta ca habar n-avem ca suntem membri(iiiiiiiii), ori am fost toti tolomaci incercand la un moment dat sa taiem paine/slana/castraveti/cabluri/etc.\r\nWhich is it?!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1)','',0,0),(31555,1146,'Cristian Ungur','cristian.ungur@utopium.ro','http://cristianungur.blogspot.com','85.186.103.54','2008-06-27 08:56:11','2008-06-27 06:56:11','Io as fi vrut sa castige turcii cupa. Poate se imbatau de bucurie si ne dadeau inapoi sabia lu Stefan cel Mare.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(31560,1146,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-06-27 09:41:46','2008-06-27 07:41:46','Cati vrei? Ca mai am vreo 20 de bani ramasi prin buzunare. Tz-ajung?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(28967,1122,'iovan','','http://blogu.lu/iovan','85.186.139.81','2008-06-12 04:54:20','2008-06-12 02:54:20','orange e de fapt romtelecomu clonat, care striga \"kill me\", ca in Alienu lu Jeunet.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 2.0.50727)','',0,0),(31575,1139,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-06-27 11:32:54','2008-06-27 09:32:54','Mo... la mine destiu\' ala este \"extra ribbed, for their pleasure\"!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(31574,1146,'mo','verde_poveste@yahoo.com','','194.126.220.240','2008-06-27 11:32:33','2008-06-27 09:32:33','Asa, Groparele, negociaza la sange! :D',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1)','',0,0),(28976,1122,'Turambar','mirel@ccsb.ro','http://turambarr.blogspot.com','84.232.187.226','2008-06-12 06:54:13','2008-06-12 04:54:13','Si ca sa continuam pasentza logica, draga Gropare, ce ne indeamna pe noi natura, Doamne Doamne, Biblia shi presiunea sociala sa facem cu fomeilie? \r\n\r\nAi? Aud? Hint: are de\'a face cu lichidele corporale.\r\n\r\nMama ei de Orange...\r\n\r\n:)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(28979,1122,'Ancuta','','','195.245.251.18','2008-06-12 07:29:05','2008-06-12 05:29:05','Daca te saruta data viitoare?!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(28980,1126,'un om','paul_bv@yahoo.com','','82.79.251.239','2008-06-12 07:35:57','2008-06-12 05:35:57','la partea aia cu iubiti si cainii vagabonti... plecam deja sa caut formularul de aderare... cand am vazut ca-i pentru intellectualy challenged... am zis musai tre sa ma inscriu si io...\r\n\r\ndar totusi... cine-i tata la cine?',0,'1','Opera/9.27 (Windows NT 5.1; U; en)','',0,0),(25227,1026,'Andrei Crivat','andrei@andreicrivat.ro','http://www.andreicrivat.ro','89.137.83.141','2008-05-13 07:32:19','2008-05-13 05:32:19','bah, n-ai mai scris asta mai demult ?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.9b4) Gecko/2008030714 Firefox/3.0b4','',0,0),(25229,1026,'ameÅ£itul','','http://ametzitul.wordpress.com','62.217.236.12','2008-05-13 07:46:57','2008-05-13 05:46:57','trebuia sÄƒ bei pe datorie, mÄƒ...\r\nai fÄƒcut masculii mioritici de rÃ¢s Ã®n faÅ£a Äƒlora de erau faine de picai... :)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(27175,1007,'ameÅ£itul','','http://ametzitul.wordpress.com/','82.76.123.238','2008-05-28 08:27:18','2008-05-28 06:27:18','bÄƒ ce-Å£i place sÄƒ Å£ii lumea Ã®n suspans...',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(28991,1126,'Andrei Crivat','andrei@andreicrivat.ro','http://www.andreicrivat.ro','89.137.83.141','2008-06-12 09:25:05','2008-06-12 07:25:05','@un om: ce n-ai inteles ? Mihai Constantinescu e tata lu\' Ricky Dandel, care e tata lu\' julius, si groparele e tata lor.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.9) Gecko/2008052906 Firefox/3.0','',0,0),(28992,1122,'Andrei Crivat','andrei@andreicrivat.ro','http://www.andreicrivat.ro','89.137.83.141','2008-06-12 09:27:35','2008-06-12 07:27:35','@Ancuta: nu-l saruta, ca n-are cascaval ca al lui',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.9) Gecko/2008052906 Firefox/3.0','',0,0),(27188,1007,'anonim','princesshgabriela@yahoo.com','','80.97.216.138','2008-05-28 10:14:41','2008-05-28 08:14:41','Ce ati facut la tiganiada si cu cine ai fost?\r\nV-ati batur, imbatat, etc?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648)','',0,0),(29005,1132,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-06-12 11:13:13','2008-06-12 09:13:13','Permisie primita!\r\n\r\nFinca si io port tricou d-asta, da\' pe interior, pe supt piele. Pe acolo, pe la organele sensibile.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(26544,316,'malaysia airline','airline@hotmail.com','http://groups.google.us/group/ztickets','66.99.246.227','2008-05-24 15:51:29','2008-05-24 13:51:29','dsgdfsg gdsfgdsf gdsfgdsfgds gdsfgdsf <a href=\"http://groups.google.us/group/ztickets \" rel=\"nofollow\">first class cheap last minute airline ticket</a>',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(29006,1132,'seliman','ionut.seliman@gmail.com','http://ionutu.wordpress.com','213.157.171.107','2008-06-12 11:19:39','2008-06-12 09:19:39','mulÅ£am\' lui matale! ;)\r\no sÄƒ-l imprim pe faÅ£Äƒ modelu\' cÄƒ mÄƒ ajutÄƒ ÅŸi burta, iarÄƒ pe spate, undeva subt ceafa-mi are sÄƒ scrie \"PouÄƒrd bai haÅŸtetepePunctGroparupunctRo\".. ;)',0,'1','Opera/9.27 (Windows NT 5.1; U; en)','',0,0),(29017,1132,'EvRa','oc.paul@yahoo.com','','79.112.116.133','2008-06-12 12:30:18','2008-06-12 10:30:18','De unde pot cumpara si eu un tricou din asta ? \r\nThumbs up for this blog btw ;)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(29018,1132,'Turambar','mirel@ccsb.ro','http://turambarr.blogspot.com','92.80.1.157','2008-06-12 12:37:42','2008-06-12 10:37:42','LATER EDIT: On second thought, si Stuyvesant e scris gresit.\r\n\r\nen.wikipedia.org/wiki/Peter_Stuyvesant\r\n\r\nMama mama, ce carcotash mi-s... :(',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(29015,1132,'Turambar','mirel@ccsb.ro','http://turambarr.blogspot.com','92.80.1.157','2008-06-12 12:29:28','2008-06-12 10:29:28','Mishto ideea. Pacat ca au scris Gauloises greshit. Gramatika, frate, gramatika!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(25247,583,'9','iu','http://t','89.45.147.147','2008-05-13 11:38:23','2008-05-13 09:38:23','la la la\\]\r\nnu mai vreau\r\nsa stau\r\ncine deranjeaza ii dau ig\r\nnu  vreau nimic \r\nde la cine vine numele porcn\r\nsi ce rasa de om esti\r\ncuminte vasile aport\r\nsunt electrocutat\r\nnumi place fr',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1)','',0,0),(29012,1132,'dush','tirbushon@gail.com','http://dushrece.blogspot.com','82.77.41.201','2008-06-12 12:18:53','2008-06-12 10:18:53','si un locshor de cumparatulea ca ie de mare angajament electoral tricoul?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(29013,1118,'nonick','agentuzerozeroopt@yahoo.com','','82.77.201.94','2008-06-12 12:24:25','2008-06-12 10:24:25','Nu-l ÅŸtiu, suntem mai multe spiÅ£e de Greavu fÄƒrÄƒ legÄƒturÄƒ Ã®ntre noi: din Ocna, din TopÃ¢rcea, din Lisa (lÃ¢ngÄƒ FÄƒgÄƒraÅŸ) etc.',0,'1','Opera/9.25 (Windows NT 5.1; U; en)','',0,0),(25249,1085,'enhobby','','','92.80.196.38','2008-05-13 12:12:45','2008-05-13 10:12:45','Berea antiprostie, berea antihotie, berea antilene, berea antispaga...Daca o bagati pe piata o sa vedeti mai toata natia romanesca gata sa intre in coma alcoolica.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(27209,1007,'Andreea MKT aka Zana Carabina','supergirgir@yahoo.com','http://marlahermina.deviantart.com/gallery/','82.77.126.254','2008-05-28 13:49:13','2008-05-28 11:49:13','deci e clar ca studiul ala ce arata ca \"blogerii is oameni mai stresati decat media ca tre sa updateze publicu si sa chio in taci\", faza e f adevarata.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; InfoPath.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(31028,1139,'raudemusca','raudemusca@gmail.com','','92.82.77.40','2008-06-23 15:13:07','2008-06-23 13:13:07','no mÄƒ, ptiu, mi s-o parut mie cÄƒ te-am vÄƒst... zÃ® drept, ai fo\' cu gipu\'?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14 ImageShackToolbar/4.4.3','',0,0),(31564,1146,'Uca','','','86.34.167.172','2008-06-27 10:10:46','2008-06-27 08:10:46','Sau ai putea sa ne ceri tu bani sa te citim. Ai avea si cititori mai putini si bani mai multi.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1; .NET CLR 2.0.50727; .NET CLR 1.0.3705; .NET CLR 1.1.4322)','',0,0),(28997,1122,'oedip','oedip74@gmail.com','http://oedip.blogspot.com','89.137.99.163','2008-06-12 10:16:07','2008-06-12 08:16:07','ai vrut cumva sa spui: orange e o curva proasta? (dar t-o fo jena castiuce obraz finutai!)\r\n\r\n:)))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(25242,1026,'james crissilv','jamescrissilv@weblog.roj','http://jamescrissilv.weblog.ro','82.76.149.33','2008-05-13 10:08:49','2008-05-13 08:08:49','am ras cu pofta. deci in final doar o bericica mititica...\r\no zi minunata iti doresc',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(29003,1122,'seliman','ionut.seliman@gmail.com','http://ionutu.wordpress.com','213.157.171.107','2008-06-12 11:06:32','2008-06-12 09:06:32','Orange e de fapt sora geamana a lu Vodafone, iar mama lor e Romtelecom care s-o frecat cu Cosorom(care dupe ghivorÅ£i e pe numele de fatÄƒ Cosmote) iarÄƒ io nu mai Ã®nÅ£eleg nimicÄƒ, pe sistemul care e tata lu Riki DandÄƒl, a lu\' Mihai Constantinescul care de fapt tata lor e Groparele.. :)...:D',0,'1','Opera/9.27 (Windows NT 5.1; U; en)','',0,0),(29004,1132,'seliman','ionut.seliman@gmail.com','http://ionutu.wordpress.com','213.157.171.107','2008-06-12 11:09:18','2008-06-12 09:09:18','ntzzz...cÄƒ n-o pus ceafa dÄƒ porc.. :D\r\ndarÄƒ Ã®n schimb poci a-Å£i cere aprobare ca sÄƒ salvez o imajine dupe care sÄƒ-mi imprim ÅŸi io un trecou? ;)',0,'1','Opera/9.27 (Windows NT 5.1; U; en)','',0,0),(28999,1126,'seliman','ionut.seliman@gmail.com','http://ionutu.wordpress.com','213.157.171.107','2008-06-12 10:51:02','2008-06-12 08:51:02','si dar atuncea AnastasÃ®ia aia a lu\' Lazariuc a cui mamÄƒ-i? Åži cine-i norocosu\' frate dÃ®n incest cu soaÅ£ia lu I.I. Å¢iriacele? :D',0,'1','Opera/9.27 (Windows NT 5.1; U; en)','',0,0),(29001,1122,'aha!','totmea@yahoo.com','','89.123.81.70','2008-06-12 11:00:23','2008-06-12 09:00:23','de-aia i-ai zis tu asa de usor DA, la oferta. s-amu ti-o iei....',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; SIMBAR={3523AA32-EC48-4B99-902E-C5F036C0464E}; Zango 10.3.36.0)','',0,0),(25244,1085,'mirmetal','','','89.122.173.2','2008-05-13 10:33:39','2008-05-13 08:33:39','BEREA anti Bere. Cu cat bei mai multa, cu atat te lasi mai usor de baut bere...  hmm. Putem extinde si la fumat ?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.2; .NET CLR 1.1.4322)','',0,0),(25233,1026,'mo','verde_poveste@yahoo.com','','194.126.220.22','2008-05-13 09:12:51','2008-05-13 07:12:51','Mda. Se putea si mai rau....de exemplu, sa tina fetele astea mortis sa refaca scena cu vrajitoarele din \"4 rooms\". ;)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1)','',0,0),(25235,1026,'iulianuss','realvision@k.ro','','193.231.107.209','2008-05-13 09:35:55','2008-05-13 07:35:55','PÄƒcat cÄƒ nu aveai la tine un pÃ®rÅ£ cu sarmale sÄƒ calmezi atmosfera, fire-ar naibii techilele lor.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(27187,1007,'Turambar','mirel@ccsb.ro','http://turambarr.blogspot.com','79.114.190.107','2008-05-28 10:01:26','2008-05-28 08:01:26','Ba taman se gata, hadeane. Taman se gata, mama ei de vreme si de timp. Si io mi-s in aceeasi situatie, si cu sigurantza mai sunt si altii. :(\r\n\r\nLa munca, mama noastra de proletari, nu la intins de tastatura!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(25255,1026,'Retoric','acalarasu@gmail.com','http://adriancalarasu.wordpress.com','80.96.53.9','2008-05-13 13:51:08','2008-05-13 11:51:08','Astfel, inca odata s-a dovedit ca romanul, desi ar avea potential, de cele mai multe ori este incapabil sa-si depaseasca conditia, purtand stigmatul adanc tatuat in codul lui genetic si etic: mana de lucru ieftina :))',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(29026,119,'Ala Micu\'','dj.steve@yahoo.com','','79.116.216.76','2008-06-12 14:21:05','2008-06-12 12:21:05','NTFS, FAT32, stf, pnm, plm, CIA, FBI, SRI, HTML, PHP, JAVA, jenti de aluminiu cu spinnere, turbocharger, faruri xenon, garda mica la sol, girofar, sirena........',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(27216,1107,'Alinul','','','213.157.188.71','2008-05-28 14:32:41','2008-05-28 12:32:41','Hopa si Alinul trezit in sfarsit din mahmureala \"de dupa\".\r\nMultzam Gropare de urari. Si de cadou, la care ai contribuit, de asemenea :))',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; InfoPath.2; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 1.1.4322; .NET CLR 3.0.04506.648)','',0,0),(29027,1132,'iulianuss','realvision@k.ro','','193.231.107.209','2008-06-12 14:44:48','2008-06-12 12:44:48','Dizaineru crecÄƒ viseazÄƒ sÄƒ il plateascÄƒ la centimeter pÄƒtrat fiecare dintre producÄƒtorii pomeniÅ£i pÄƒ burtoi... \r\nTu eÅŸti Äƒl mai clonÅ£os, deci tu tre sÄƒ negocezi drepturili de panotaj!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(32059,1148,'Adrian','adi.covaci@jumpeye.com','http://www.papuravoda.ro','85.186.103.6','2008-07-01 17:40:35','2008-07-01 15:40:35','Groparule frumoase utopii traiesti!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(29029,1132,'Teniescu','contact@teniescu.com','http://teniescu.com','89.137.144.96','2008-06-12 15:08:44','2008-06-12 13:08:44','Destul de sugestive tricourile :/',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(29032,1132,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-06-12 15:39:07','2008-06-12 13:39:07','@ raduku: stiu, si lui ii pare rau, ca mi-o zis, da\' deja e prea tarziu... ',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(29030,1132,'raduku','radu3u@yahoo.com','','79.116.96.59','2008-06-12 15:23:53','2008-06-12 13:23:53','Pacat d tine Gropare,imi esti vecin aci in Cluj,esti biat d treaba,ti-am citit blogul 2 zile la rand,da nu stiam k esti pretin cu Ciutacu.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14;MEGAUPLOAD 1.0','',0,0),(25260,1026,'oceania','oceania_oceania@yahoo.com','http://www.literelibere.blogspot.com','84.232.169.83','2008-05-13 15:14:07','2008-05-13 13:14:07','tare de tot postul asta. de cate ori intru pe blogul asta mor de ras :).',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; InfoPath.1)','',0,0),(25261,1026,'catalin','catalin_heghes@yahoo.com','http://heghes.blogspot.com','84.232.142.163','2008-05-13 15:16:56','2008-05-13 13:16:56','de ce nu te-ai Ã®narmat ÅŸi tu cÃ¢nd te-ai dus Ã®ncolo cu niÅŸte tequila de bihor ÅŸi sÄƒ le rogi ÅŸi tu pe cosÃ¢nzenele daneze sÄƒ te lase sÄƒ le faci un bodi-dinÄƒla...',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(25269,1026,'ics','i_uana@yahoo.com','','86.126.99.7','2008-05-13 17:12:25','2008-05-13 15:12:25','esti booooolnaaaav! :)) da nu albinos [-x',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(27232,1007,'dunec','the_dun3@yahoo.com','http://dunec.wordpress.com/','89.122.135.112','2008-05-28 16:40:38','2008-05-28 14:40:38','iti dau eu niste timp... numai nu pleca',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(21822,881,'kleine Eule','','','79.112.89.162','2008-04-13 16:57:29','2008-04-13 14:57:29',':-?ala de plecase in noua zeelanda era fan stapanul inelelor sau cum?:)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 2.0.50727; InfoPath.1)','',0,0),(25277,1026,'Ea','','','79.116.82.79','2008-05-13 18:00:17','2008-05-13 16:00:17','deci NUUUU!!!si eu care credeam ca-s cea mai originala in unicitatea-mi (fiind  nascuta cu o pata de par blond in spate la cap pe par). n-oi fi nici cea mai frumoasa? sau macar cea mai desteapta? fuck!!!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(29059,1132,'raduku','radu3u@yahoo.com','','79.116.97.153','2008-06-12 21:34:47','2008-06-12 19:34:47','@ raduku: stiu, si lui ii pare rau, ca mi-o zis, daâ€™ deja e prea tarziuâ€¦\r\n:)))))\r\nEsti mortal omule ,tine-o tata ase!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14;MEGAUPLOAD 1.0','',0,0),(23184,1079,'ÅžuKÄƒRiT','Eu@Yahoo.com','','89.40.120.239','2008-04-28 17:49:44','2008-04-28 15:49:44','Cristos a Ã®nviat!\r\n\r\n P.S. De ce eÅŸti rÄƒu?  :))',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(33822,1157,'un om','paul_bv@yahoo.com','','82.79.251.239','2008-07-18 07:31:55','2008-07-18 05:31:55','la ce scoala... o invatat musca?',0,'1','Opera/9.50 (Windows NT 5.1; U; en)','',0,0),(25287,1026,'macabroo','raduccc@yahoo.com','http://rezistenta.blogspot.com','82.76.52.94','2008-05-13 21:01:37','2008-05-13 19:01:37','Phaaaa. Ma tem ca planurile tale s-au ruinat. Acum va trebui sa meri la facultate gen. Ca sa nu vorbim de alte lucruri si mai infricoshatoruri.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; en-GB; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(32027,1148,'Uca','','','86.34.167.172','2008-07-01 14:46:59','2008-07-01 12:46:59','hm.. eu am vazut si mamici supleâ€¦',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1; .NET CLR 2.0.50727; .NET CLR 1.0.3705; .NET CLR 1.1.4322)','',0,0),(32023,1148,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-07-01 14:35:28','2008-07-01 12:35:28','@ adi: nu mai stau in Grigo, era prea curat cartierul, si cand am plecat de acolo s-o triplat media de varsta a zonei! A, si or crescut preturile la apartamente, nush cum dreq.\r\n\r\n@ Seliman: da\' pe trotineta, ca JEG.ro, nu le-ar sta ghini?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(26493,316,'ghost ringtone','ringtone@hotmail.com','http://groups.google.us/group/ringtonesz','82.114.160.33','2008-05-24 09:33:40','2008-05-24 07:33:40','fasdfasd fdasfasdfas fasdfasdf asfdfsd f<a href=\"http://groups.google.us/group/ringtonesz \" rel=\"nofollow\">make ringtone</a>',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(31985,1148,'hadean','contact@adihadean.com','http://www.adihadean.com','86.125.34.195','2008-07-01 11:37:04','2008-07-01 09:37:04','no mai dÄƒ-i Ã®n p(/%a mÄƒ-sii!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(29069,1132,'Sorin Vasilescu','eu@sorinvasilescu.ro','http://blog.sorinvasilescu.ro','89.34.254.31','2008-06-13 00:12:36','2008-06-12 22:12:36','Mane, bagi si tu un link pe mail sau ceva cu indivizu care poa sa-mi dea un  .ai sau un .cdr cu ala ca sa nu-l mai refac eu o data? E chiar super idee. Bag si copiright pe el undeva, chiar vreau sa ma duc la baietzi sa mi-l faca pentru un preten de-al meu care.. fits the profile.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(26458,1104,'Sibilla','sibilla_poesis@yahoo.com','http://sfinx667.wordpress.com','89.123.30.40','2008-05-24 03:47:16','2008-05-24 01:47:16','No, daca-i musai, meri... bafta si vrem poze multe :)\r\nsa zici si ziveli, cand inchinati :))\r\nUn sfarsit de saptamana bogat in impliniri,\r\nSibilla',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(33614,1155,'Adi','adriana.argeseanu@gmail.com','http://aboutnothingsro.blogspot.com/','78.96.200.199','2008-07-16 11:13:20','2008-07-16 09:13:20','he he he...si nu te-ai inarmat si tu cu nimic? niste mazare de la congelator, o bata de baseball sa parezi bombele de orez...nimic?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9) Gecko/2008052906 Firefox/3.0','',0,0),(25307,1089,'ameÅ£itul','','http://ametzitul.wordpress.com','62.217.236.12','2008-05-14 07:35:52','2008-05-14 05:35:52','trebuia sÄƒ le dea sÄƒ ia acasÄƒ, la pachet :)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(21866,1060,'hadean','contact@adihadean.com','http://www.adihadean.com','194.102.126.6','2008-04-14 07:11:56','2008-04-14 05:11:56','io de cÃ¢nd tÄƒt zÃ®c ce bine-i cÃ¢nd are omu\' lucru\' lui Ã®n ogradÄƒ!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12','',0,0),(30853,1138,'Uca','','','89.38.26.43','2008-06-22 23:55:57','2008-06-22 21:55:57','Eu cred ca doar experimenteaza. Stai linistit ca maine isi revine :)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1)','',0,0),(21870,1060,'ameÅ£itul','','http://ametzitul.wordpress.com','62.217.236.12','2008-04-14 07:49:49','2008-04-14 05:49:49','aprob pozitiv!!!\r\nnici io n-am treabÄƒ cu alcoolul, cÄƒ am vin ÅŸi Å£uicÄƒ din via strÄƒmoÅŸeascÄƒ...\r\npe aceastÄƒ cale, mai propun sÄƒ ÅŸi lansÄƒm petiÅ£ia \"Apa - numai pentru uz extern!!!\"',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(25308,1089,'Turambar','mirel@ccsb.ro','http://turambarr.blogspot.com','79.114.190.23','2008-05-14 09:12:15','2008-05-14 07:12:15','Si atunci au facut o toneta mobila de Camembert. Si au vandut fericitzi Cacamembert pan la adanci batranetzi, in bun spirit capitalizdo-consumerizd. Si-am incalecat pe cacapu veceului si v-am spus povestea-asha.\r\n\r\n:)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(25312,1089,'hadean','contact@adihadean.com','http://www.adihadean.com','86.125.34.195','2008-05-14 10:49:09','2008-05-14 08:49:09','ioi mÄƒ domnule dragÄƒ, pauza de masÄƒ nu mi-o fo nicicÃ¢nd mai dragÄƒ ca azi.no, dÄƒ-i sÄƒ putÄƒ!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(31973,1148,'','','','194.102.139.9','2008-07-01 09:33:22','2008-07-01 07:33:22','No, io emigrez in Cluuuj... acu\'',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(29134,1127,'Buciuman','aaaa@ggg.com','http://rezistenta.blogspot.com/','86.121.55.108','2008-06-13 13:04:39','2008-06-13 11:04:39','Frate vedeti ca e concert cu DJ Salinger.',0,'1','Opera/9.27 (Windows NT 5.1; U; en)','',0,0),(29135,1127,'mo','verde_poveste@yahoo.com','','194.126.220.240','2008-06-13 13:05:43','2008-06-13 11:05:43','Hmm.. razbunare? A iesit asa de naspa?! Fin\'ca sincer ma distrase doar expresia si m-am pus pe aberat..... :D',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1)','',0,0),(29136,1127,'Andreea','puistrulet2003@yahoo.com','http://n/a','81.196.150.196','2008-06-13 13:12:49','2008-06-13 11:12:49','@ mo : :) nu mai, nu tie iti era adresat comment-ul... ! era pt Groparu (no, e vina mea ca n-am specificat)\r\nLa comment-ul tau n-am nimic de zis, iti mere mintea laa..... adica ai imaginatie :)\r\n\r\nNo pa, \r\nA.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(29127,1127,'adi','adi@ucluj.ro','','79.116.74.188','2008-06-13 11:56:54','2008-06-13 09:56:54','Ioai!!! Groparu has a gilfriend, Groparu has a girlfriend...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.9) Gecko/2008052906 Firefox/3.0','',0,0),(21873,1060,'SIBILLA','sibilla_poesis@yahoo.com','http://sfinx667.wordpress.com','89.123.49.198','2008-04-14 10:32:26','2008-04-14 08:32:26','faina rau di tat povestioara ta, musai felicitari si apoi musai si o slibovita ca mere bine dupa o portie de zambete pe masura...\r\ndragu mi-i romanu, si gospodar si \" inventiv \"... :)\r\nfelicitari,\r\nSibilla',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(29131,1127,'mo','verde_poveste@yahoo.com','','194.126.220.240','2008-06-13 12:27:44','2008-06-13 10:27:44','Intrebari legate de aerul de prospetime:\r\n1. I se sugereaza ceva subtil Groparelului? (e singur in birou, nimeni nu sta langa el mai mult de 2 minute, etc.)\r\n2. Dl. Ionescu asta face reclama ascunsa la Rexona, ca au astia lately niste campanii agresive de numa-numa?!\r\n3. Metafora cu aer proaspat trimisa la adresa GROPARU.ro se vrea ironica sau a iesit involuntar amuzanta?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1)','',0,0),(29129,1127,'mo','verde_poveste@yahoo.com','','194.126.220.240','2008-06-13 12:12:39','2008-06-13 10:12:39','....but will not give up chasing random pussies, aaaa, asta, kitties din fata blocului! :D',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1)','',0,0),(29138,1127,'PhenoBarbieDoll','oana.gavrila@mediafax.ro','','193.230.230.101','2008-06-13 13:23:23','2008-06-13 11:23:23','tu mo, sh tu te plictisesti la cooperativa?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(23260,1080,'ameÅ£itul','','http://ametzitul.wordpress.com','62.217.236.12','2008-04-29 13:13:25','2008-04-29 11:13:25','deci aÅŸadar, recunoÅŸti cÄƒ viciile ajutÄƒ la limpezimea minÅ£ii...\r\ndezlegaÅ£i, dezlegaÅ£i ÅŸi iar dezlegaÅ£i :)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(23262,1080,'Adrian','office@andanapan.ro','http://www.andanapan.ro','86.34.218.251','2008-04-29 13:53:10','2008-04-29 11:53:10','Desigur, in situatii ca aceasta, singuru inconvenient e ca te trezeshti abia azi si-tzi dai seama ce bine-a fost ieri :)) dar... si maine-i o zi...  tot ce-i bun pe gat merge:) ciao.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(29149,1127,'PhenoBarbieDoll','oana.gavrila@mediafax.ro','','193.230.230.101','2008-06-13 14:44:49','2008-06-13 12:44:49','radem, glumim, da\' bietu\' Bregovic o cazt din pom si si-o busit spinarea\r\nhttp://www.mediafax.ro/life-inedit/goran-bregovic-si-a-fracturat-o-vertebra-cazand-dintr-un-copac.html?4728;2706710',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(25331,1089,'Retoric','acalarasu@gmail.com','http://adriancalarasu.wordpress.com','80.96.53.9','2008-05-14 15:24:13','2008-05-14 13:24:13','ee. lasa ca nici cu telemeaua de oaie de Sibiu incinsa un pic in soare nu ne e rusine.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(25329,1089,'daniel','lil_daniel.stephan@yahoo.com','http://-','92.82.61.106','2008-05-14 15:12:03','2008-05-14 13:12:03','te admir gropare...(nu in sensul gay al cuvantului:))))\r\nnuma` bine',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SIMBAR={BAA46282-D93E-1CFA-9557-101111111111})','',0,0),(23267,1080,'ics','i_uana@yahoo.com','','86.126.99.7','2008-04-29 15:53:19','2008-04-29 13:53:19','Never mind the rest of it, fraza cheie ramane : \"Am vrut numaâ€™ sa va zic ca am revenit [...]\" \r\nhallelujah ^:)^',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(32401,1150,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-07-03 09:45:37','2008-07-03 07:45:37','Ba cum nu!\r\n\r\nStai numa sa-mi scot curu\' din putulica zilei de azi :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.15) Gecko/20080623 Firefox/2.0.0.15','',0,0),(32400,1150,'Adi','adriana.argeseanu@gmail.com','http://aboutnothingsro.blogspot.com/','78.96.200.199','2008-07-03 09:38:06','2008-07-03 07:38:06','nu-i asa ca-ti faci un pic de mila de cineva care duce mult de tot dorul unei muzici ca asta si mai pui niste piese?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9) Gecko/2008052906 Firefox/3.0','',0,0),(33834,1158,'angel','','http://zebeu.blogspot.com/','195.114.125.74','2008-07-18 09:28:31','2008-07-18 07:28:31','ba..! ai inebunit? ma mut la \"Cluuuuuj\"',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; InfoPath.2; .NET CLR 2.0.50727)','',0,0),(33835,1158,'un om','paul_bv@yahoo.com','','82.79.251.239','2008-07-18 09:36:30','2008-07-18 07:36:30','io raman acasa ca aici nu se strica tzajile...',0,'1','Opera/9.50 (Windows NT 5.1; U; en)','',0,0),(21898,1060,'WhiteWolf','contact@white-wolf.ro','http://white-wolf.ro','89.39.83.107','2008-04-14 17:27:17','2008-04-14 15:27:17','Uite ca nu puteai sa-ti erectezi sfÃ rcu\' far\' de franci. Tze sa dziiicc.....\r\n<b>Sasu\' care nu-i prost si n-are pantaloni scurtzi nu-i sas !</b> Da ?\r\nTe rog frumos, nu mai da prafuri ieuropene la adictzii de blogu\' asta',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(23272,1080,'Nox','','','89.47.100.75','2008-04-29 18:26:20','2008-04-29 16:26:20','Hail Gropare! Deja ma gandeam ca patisi ceva de nu mai postai nica. Welcome back. :)',0,'1','Opera/9.27 (Windows NT 5.1; U; en)','',0,0),(33581,1155,'','','','86.55.176.111','2008-07-15 22:01:00','2008-07-15 20:01:00','si n-a fost bine ? apai, ma Gropare ...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.15) Gecko/20080623 Firefox/2.0.0.15','',0,0),(33582,1155,'Turambar','mirel@ccsb.ro','http://turambarr.blogspot.com','84.243.86.8','2008-07-15 22:18:53','2008-07-15 20:18:53','In trei zile mergem si noi la Sibiu, to rejoin our beloved mother and wife, care se workshopuieste pe meleagurile alea pline de tzafna saseasca. O sa vin vineri cu doo fete, de trei si de sapte ani, si o sa-mi aduc aminte cum ai curatzat grajdurile lui Augias. \r\n\r\nPentru ca si eu o sa fac fics acelashi lucru... :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9) Gecko/2008052906 Firefox/3.0','',0,0),(33583,1155,'','','','89.123.131.50','2008-07-15 22:21:16','2008-07-15 20:21:16','cool dupa dracu nu i-ai bagat in cusca cu botnita si doua lese facute din lanturi groase de fintina si din cand in cand ,atunci cand tipetele lor te asurzesc sa ai mai curentezi cu bateria de la lanterna pe limba pentru a tine guritele zgomotoase inchise?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.9) Gecko/2008052906 Firefox/3.0','',0,0),(33584,1155,'Nox','','http://s3my.blogspot.com/','89.47.100.75','2008-07-15 22:25:57','2008-07-15 20:25:57','Noh, matale ai dezvoltat foarte bine principalul motiv pentru care mie NU imi plac copiii si pentru care eu NU voi face vreodata copii. Fereasca-ma de asa ceva!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.15) Gecko/20080623 Firefox/2.0.0.15','',0,0),(27420,1007,'ics','i_uana@yahoo.com','','86.126.99.7','2008-05-29 21:18:25','2008-05-29 19:18:25','e joi seara :-w. mai ai 24 de ore',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(23284,1080,'nenea cosmos','domnu_cosmos@yahoo.com','http://www.nenea.wordpress.com','92.80.38.145','2008-04-29 21:56:57','2008-04-29 19:56:57','gropare, pe sefi ii ai asa cum ii cresti. si am si sefi, si subalterni, deci stiu ce spun!',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(21933,1062,'JimmY','jimmyredbull@yahoo.com','http://www.jimmy.ro','86.123.121.37','2008-04-14 22:37:52','2008-04-14 20:37:52','Da, le-am cam cumparat toate masinile Euro 3 si Euro 4! Cel putin pe Mobile.de se dau ca painea calda!',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727)','',0,0),(25349,1090,'macabroo','raduccc@yahoo.com','http://rezistenta.blogspot.com','82.76.52.94','2008-05-14 23:35:33','2008-05-14 21:35:33','In filme in situatiile de genul asta rolul alexandrionului il joaca o prostituata moarta. Deci se poate!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; en-GB; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(23290,1080,'baghy','baghy83@lycos.it','http://www.baghy.info','78.12.10.158','2008-04-29 23:41:47','2008-04-29 21:41:47','Ba Gropare chiar ai postit?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(26355,1104,'eu','ripahoratiu@yahoo.com','','80.97.64.151','2008-05-23 14:07:16','2008-05-23 12:07:16','Babaza , io tot spui ca nu-i nimic original in chestia asta cu tiganiada. O traim cu totii in fiecare zi. Io in locu\' tau as organiza o cestie numita \"civilizatziada\" si mi-as pedepsi prietenii cu ea... \r\nD\'alea cu: faci dusul anual, te barbieresti; iti iei costumu\' ala de te duci la nuntzi de familie, pe care ti l-au luat parintii sa nu-i faci de rusine; tre\' sa vorbesti neaparat politicos, cu dumneavoastra si alte marafeturi; tra\' sa discuti intelectual, despre carti si evenimente culturale si filosofie iara nu de tzatzele+posteriorul bom(bard)at a lu\' Xa; si sa bei ce nu bei toata ziua, adicatelea zemuri \'eftine, ci numa si numa vinuri de peste 15 roni, zaraze de 7 astri (ca doar stii cine-i Kafka, carele evident ca nu e fotbalist ceh, joaca la slovaci, in atac, pe stanga); cumperi flori la pretena si speli vasele in locu\' ei si neaparat te dai cu autobuzu\' numa\' ca sa poti ceda locul unei femei mai in varsta. Asta ar fi cu adevarat ceva iesit din comun(a).',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648; .NET CLR 3.5.21022)','',0,0),(25358,1090,'Gusti','hahahah@yahoo.com','','85.204.6.103','2008-05-15 01:48:46','2008-05-14 23:48:46','super tare. sincer, cred ca au uitat nenea de ea :P',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; SIMBAR={B2CFE3DE-B8CA-41A9-BB5F-70D0C1F53221})','',0,0),(33742,1157,'Greuceanu','','','89.46.104.35','2008-07-17 13:57:39','2008-07-17 11:57:39','i-auz\' prtentzii! da\' ch-avea mo muzca?! ejti extremist xenofob si iredentist?! ori tz-o fo\' frica ca nu era proas-pata?!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9) Gecko/2008052906 Firefox/3.0','',0,0),(33496,1154,'prodan','mihai.prodan@gmail.com','http://prodan.wordpress.com','79.116.83.134','2008-07-14 20:01:18','2008-07-14 18:01:18','deci domnu groparu, Ã®nainte sÄƒ ne pui sÄƒ rezonÄƒm cu tine, avem nevoie de neÅŸte detalii, cum ar fi ce fÄƒceau domnii colegii dumitale cu maÅŸinile. erau parcate Ã®n locuri special amenajate (caz Ã®n care Ã®mi exprim regretele)? erau parcate pe spaÅ£iul verde / trotuar (caz Ã®n care mÄƒ bucur cÄƒco legii tÄƒi or luat-o-n frezÄƒ ÅŸi sper sÄƒ se Ã®nveÅ£e minte data viitoare)?\r\n\r\nvorba lu uncopilutz, ia, mai circule ÅŸi cu bicicletele.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.15) Gecko/20080623 Firefox/2.0.0.15','',0,0),(30048,1133,'bani pe net','ioana_luiza_valiza@yahoo.com','http://bani-pe-net.ro','92.81.140.39','2008-06-18 11:52:34','2008-06-18 09:52:34','la care ea spune \"ce face?? planeta care mah?! auzi eu am vorbit frumos cu tine!?\" :))',0,'1','Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.1.6) Gecko/20071008 Ubuntu/7.10 (gutsy) Firefox/2.0.0.6','',0,0),(30049,1132,'bani pe net','ioana_luiza_valiza@yahoo.com','http://bani-pe-net.ro','92.81.140.39','2008-06-18 11:53:17','2008-06-18 09:53:17','ce bestial e tricou!!! unul pentru fiecare roman!!!!',0,'1','Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.1.6) Gecko/20071008 Ubuntu/7.10 (gutsy) Firefox/2.0.0.6','',0,0),(33850,1158,'seliman','ionut.seliman@gmail.com','http://ionutu.wordpress.com','213.157.171.107','2008-07-18 12:14:49','2008-07-18 10:14:49','Asta-mi sunÄƒ a nepotism. Crunt! :D',0,'1','Opera/9.27 (Windows NT 5.1; U; en)','',0,0),(33851,1158,'hadean','contact@adihadean.com','http://www.adihadean.com','86.125.34.195','2008-07-18 12:22:34','2008-07-18 10:22:34','nu ma, suna a parintism.care-i mult mai bengos.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.16) Gecko/20080702 Firefox/2.0.0.16','',0,0),(29209,1132,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','79.116.97.192','2008-06-14 04:21:42','2008-06-14 02:21:42','Apai nu se vede, ca e acoperita de saruturi, sireaca!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(23340,1081,'vrei sa fim prietene?','totmea@yahoo.com','','92.82.51.17','2008-04-30 12:18:58','2008-04-30 10:18:58','si dupe \"nu-s\" e semnul exclamarii, adica tre\'ia sa fie \"nici lezbiana nu-s!!\"\r\npardon.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Zango 10.3.36.0)','',0,0),(23308,1080,'Sibilla','sibilla_poesis@yahoo.com','http://sfinx667.wordpress.com','89.123.45.63','2008-04-30 04:39:45','2008-04-30 02:39:45','rusine sa-mi fie, mascariti-ma si ocarati-ma, da io nu ma abtin ca nu vreu, subscriu...mai mult luai si notite...si, ca sa-l citez pe geniul in cauza... no Tulai Doamnie, mainie ce-si primesc... si dava vedeti ca nu mai revin, apoi e claro..ca bine nu mi-o fo....\r\nunie pun plicu cu bani pantru fraza prima... ca faina-i ...\r\nrespecte, \r\nSibilla',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(25390,1090,'stupid behavior','stupid@yahoo.com','http://www.bari.ro','62.231.94.204','2008-05-15 12:01:16','2008-05-15 10:01:16','Sunt un om dintr-o bucata. Una de creier ; si aia tii pe duca imi pare rau la felul cum vb si scri si nu numai atat dar ceea ce ne spui sunt banalitati, Enjoy the Rest of Your Life',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Stardock Blog Navigator 1.1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; eSobiSubscriber 2.0.4.16)','',0,0),(23332,1079,'Andreea','puistrulet2003@yahoo.com','http://n/a','81.196.150.196','2008-04-30 10:46:01','2008-04-30 08:46:01','@ Groparu\'- tuali ce am ras!!!! Mi-am adus aminte ca asa a fost si cand am mers eu sa ma spovedesc (sambata trecuta, la 5 dimineata :( ) numai ca la mine pt prima data m-a lasat el sa vorbesc (pana acum ma intraba- ai facut aia, ailalta si era usor sa spun \"da\" la toate ca asa sunt facute intrebarile sa spui da la toate); si m-am blocat ca nu stiam cu ce sa incep....??? anyway trecand peste momentul penibil,  in noapte de inviere la Zalau (de unde sunt eu) dar [probabil si in alta parte e treaba cu la 12:00 noaptea la Inviere se ia lumina de la Preot (sau ma rog asa am vazut eu) si bineinteles ca atunci ca a iesit preotul toata ENORIASELE s-au inurcat in fuste sa ajunge \"prima!!\" la lumina (n-am priceput de ce nu au rabdare ca asta e o virtute mare ;) ); si eu am asteptat sa termine si sa ia ele lumina ca eu ma gandeam la metoda \"da mai departe\" ele iau si apoi impart la restul sa nu ne inghesuim ca prostii acolo la altar... Ete na, ca am nimerit fix pe cea mai ENORIASA dintre ENORIASE (adica tipa e wasted)  care mi-a spus \"Nu de la mine, de la Preot\" :( ; tuuulaii si i-am si spus \"In inghesuiala astaaaa??????\"\r\n\r\nLectia de morala: trebuie rabdare in orice cu orice...  :); chiar si cu prostii',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(25385,1090,'Cristian Ungur','cristian.ungur@utopium.ro','http://cristianungur.blogspot.com','85.186.103.54','2008-05-15 10:18:46','2008-05-15 08:18:46','E groasa treaba. O fi vazut omu\' ca si pe Becali l-o prins DNA-ul...',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(21985,1062,'ameÅ£itul','','http://ametzitul.wordpress.com','62.217.236.12','2008-04-15 07:33:03','2008-04-15 05:33:03','bine cÄƒ suntem celebri...\r\nl-aÅ£i pocnit pe intelijent?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(27496,1007,'Greuceanu','','','89.46.104.35','2008-05-30 08:54:02','2008-05-30 06:54:02','mo,\r\n\r\nasta e vrajeala ca te-o facut muierea.... cu chestii de jenu\':\"da?! da sa stai toata sara pe cacatu\' ala de site plin de admiratoare potzi, hugh?! sa scrii toate porcariile tale despre pretenii betzivani shi gandurile tale perverse shi launtrixce ai vreme! da\' sa ma duci sara la film..... nuuuuu, n-ai vreme, ca trebe sa-tz faci treaba si sa plateshti ratele ca n-ai bani! da sa cherzi camera de unshpe\' milioane ai bani!\"',0,'1','Opera/9.25 (Windows NT 5.1; U; en)','',0,0),(33464,1154,'Vla$','','http://www.coadademaimutza.ro','89.123.79.150','2008-07-14 12:29:49','2008-07-14 10:29:49','ma dispera anunturile umanitare!!! pamant!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.2)','',0,0),(25376,1090,'Turambar','mirel@ccsb.ro','http://turambarr.blogspot.com','79.114.190.23','2008-05-15 08:46:23','2008-05-15 06:46:23','Eu cred ca RARistul a intzeles ca la el in portbagaj.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(25382,1026,'oedip','oedip74@gmail.com','http://oedip.blogspot.com','89.137.99.163','2008-05-15 09:42:53','2008-05-15 07:42:53','deci bah... literalule... io stiu ca e Tequila Body Shot!!!\r\nhttp://en.wikipedia.org/wiki/Body_shot\r\n\r\nclar?!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(25381,1090,'pliscu','pliscu@gmail.com','http://pliscu.blogspot.com','89.137.100.118','2008-05-15 09:26:12','2008-05-15 07:26:12','sigur nu mai era o sticla de <i>altceva</i> in portbagaj?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(33455,1154,'Anunt Umanitar','r4r3s@yahoo.com','http://www.mihaipopescu.com','79.117.160.130','2008-07-14 10:31:36','2008-07-14 08:31:36','Mihai Popescu are 24 de ani, din Timisoara si are nevoie urgenta de 40 000 de euro pt o operatie pe creier in Germania pt a extirpa o tumora. Intra pe site-ul sau www.mihaipopescu.com si citeste poveste luiâ€¦ Haideti sa-l ajutam! www.mihaipopescu.com',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.8.1.15) Gecko/20080623 Firefox/2.0.0.15','',0,0),(23324,1080,'hadean','contact@adihadean.com','http://www.adihadean.com','194.102.126.6','2008-04-30 09:28:46','2008-04-30 07:28:46','hop te zsiga! ioi uelcombec pÄƒ blogu tÄƒu!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12','',0,0),(21996,1062,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-04-15 09:25:32','2008-04-15 07:25:32','L-o pocnit destul soarta facandu-l neamtz! Romanii pe care-i stiu io nu dau in cei cazuti la pamant, in afara de un mic shut in dinti.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(21997,1062,'hadean','contact@adihadean.com','http://www.adihadean.com','194.102.126.6','2008-04-15 09:47:06','2008-04-15 07:47:06','io zic cÄƒ pateu\' pÄƒ jerunÅ£ Ã®i pedepsÄƒ bugÄƒt. nu avea ÅŸi gÄƒlbÄƒnuÅŸ pÄƒ pept?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12','',0,0),(23330,1080,'anonim','princesshgabriela@yahoo.com','','80.97.216.137','2008-04-30 10:34:03','2008-04-30 08:34:03','Felicitari ca ai tinut postul!\r\nNu te mai enerva atat cu sefii.\r\nTrateaza-i cu indiferenta.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648)','',0,0),(23338,1081,'vrei sa fim prietene?','totmea@yahoo.com','','92.82.51.17','2008-04-30 12:17:40','2008-04-30 10:17:40','tie tzi greu? si io simtesc ezact precum tine, dar ui\' la mine ghinion: eu sint femeie si nici lezbiana nu-s? no. te-am luat! iar simt nevoia sa fiu consolata.....',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Zango 10.3.36.0)','',0,0),(30077,1132,'mircea','sever_mircea@yahoo.com','','87.237.110.53','2008-06-18 15:03:10','2008-06-18 13:03:10','ai avut vreo legaturÄƒ cu treaba asta de pe langÄƒ Sibiu?\r\nhttp://www.adevarul.ro/index.php?section=articole&amp;screen=index&amp;rss=1&amp;id=356199',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9) Gecko/2008052906 Firefox/3.0','',0,0),(32432,1150,'mea','totmea@yahoo.com','','89.123.90.118','2008-07-03 14:51:40','2008-07-03 12:51:40','ce ghiers! iar mi-ai produs fluturi in stomac. ma, io te iubesc!\r\nio-s o saisprezecime rusoaica. mai e ceva de zis? ;-)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Zango 10.3.36.0)','',0,0),(34323,1160,'Lorand R. Minyo','me@lorandminyo.ro','http://www.lorandminyo.ro/','89.36.21.82','2008-07-22 10:27:51','2008-07-22 08:27:51','Am papat de cateva ori de la ei. Mancare buna, nu foarte putina, dar total nesarata pentru gustul meu. Preturi foarte decente (si cred ca asta din cauza ca nu prea folosesc ei multe ingrediente originare din India, in afara de mirodenii).\r\n\r\nPer ansamblu e foarte ok insa, cand nu am chef sa-mi gatesc eu mancare indiana, marocana, chinezeasca sau sushi comand take away. Merge mai repede si e mai cheap.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.9.0.1) Gecko/2008070208 Firefox/3.0.1','',0,0),(34332,1160,'catalin','solo@xsolo.biz','http://xsolo.biz','77.75.167.238','2008-07-22 11:32:31','2008-07-22 09:32:31','inca un motiv sa apar in cluj in august, doar ca indieniiiiiiiii tai frate sint subtiri de tot la desert: doar un produs?! si nu au nici lassi, te rog mult vb cu el poate baga si lassi in menu.in jur de 14 august esti acasa?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.16) Gecko/20080702 Firefox/2.0.0.16','',0,0),(34325,1160,'moimeme','getaples@gmail.com','http://nope','85.186.68.70','2008-07-22 10:55:24','2008-07-22 08:55:24','Sclipirea de inteligenta o refuzat sa vina astazi din cafea, asa ca, rogu-te, lamureste creieru\' meu adormit, acest mult laudat restaurant indian are si o locatie fizica, inde te poti prezenta pentru rasfatu\' culinar, sau e numai cu livrare le domiciliu? Stomacul meu curios iti multumeste anticipat.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9) Gecko/2008052906 Firefox/3.0','',0,0),(34326,1159,'raudemusca','raudemusca@gmail.com','','92.84.1.165','2008-07-22 10:58:55','2008-07-22 08:58:55','Io da !',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.16) Gecko/20080702 Firefox/2.0.0.16 ImageShackToolbar/4.5.0','',0,0),(33853,316,'Apnitmcw','aumrbvic@pugogzpi.com','http://sites.google.com/site/analcreampiemovies1/Home/all-anal-galleries','122.18.49.207','2008-07-18 12:45:58','2008-07-18 10:45:58','Preved webmastero4ki, http://sites.google.com/site/analcreampiemovies1 anal flash game,  %PPP,',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(33852,1158,'seliman','ionut.seliman@gmail.com','http://ionutu.wordpress.com','213.157.171.107','2008-07-18 12:30:49','2008-07-18 10:30:49','@Adi\r\ndacÄƒ mÄƒ gÃ®ndesc bine, tu ai dreptate..;) E mai tare pÄƒrinÅ£ismu\' decÃ®t nepotismu\'. :D',0,'1','Opera/9.27 (Windows NT 5.1; U; en)','',0,0),(32422,1062,'','','','86.55.11.10','2008-07-03 13:13:28','2008-07-03 11:13:28','yaaaaaaaaaaaaaaaa',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; FunWebProducts-MyWay; SIMBAR={2E23FDC8-309C-11DD-B09D-000FEAFAF54E}; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(32423,1062,'','','','86.55.11.10','2008-07-03 13:13:57','2008-07-03 11:13:57','ce fulga esti!!!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; FunWebProducts-MyWay; SIMBAR={2E23FDC8-309C-11DD-B09D-000FEAFAF54E}; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(22015,1062,'marcel','marcelbmi@yahoo.com','','89.32.147.43','2008-04-15 12:35:25','2008-04-15 10:35:25','Mda .. norocu lui ca Arielu scarmana binie nadragu si referitor la ce-i 150.000 de km... io cred ca-i un chin pantru mashina aia sa mai suporte si euro 4 . :)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; SIMBAR={CBE66610-F4C9-11DC-B9A7-000AE67ABA75})','',0,0),(22020,1060,'Flamandu\'','staulalucru@yahoo.com','','193.231.247.180','2008-04-15 13:24:58','2008-04-15 11:24:58','alcoolu\' ca alcoolu, da cum afumau sasii slanina si toate celea..si cum nu te chema Fritz in chimnitsa sa se laude cu ce\'avea pe acolo...si cum te inghia la sorbit din turburel...mai un muschiulets afumat, mai un borcan de mustar, mai doua feliute de muschiulet, mai trei borcane de turburel\r\nsi ajungeai acasa muci. Si\'am crescut si io mai mare ca sa pot sta oblu cu ei in chimnitsa taman cand or plecat toti sasii din medias.Asa ca am plecat si eu, ca mi-era urat fara Fritz.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(25394,1090,'PhenoBarbieDoll','oana.gavrila@mediafax.ro','http://phenobarbiedoll.blogspot.com','193.230.230.101','2008-05-15 14:00:31','2008-05-15 12:00:31','Tii, Gropare ce tzo (apropos, salutari Tzo) zisa! Deci in cre\' ca nu-i place cum \"vb si scri\" finca folosesti multe de-alea, cum le zice, virguli',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(23352,1080,'Mile','','http://milecarpenisan.wordpress.com','79.114.27.159','2008-04-30 13:58:09','2008-04-30 11:58:09','Welcome back my friend in the sin world',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; SLCC1; .NET CLR 2.0.50727; Media Center PC 5.0; .NET CLR 3.0.04506; InfoPath.2)','',0,0),(22026,1062,'SIBILLA','sibilla_poesis@yahoo.com','http://sfinx667.wordpress.com','89.123.62.64','2008-04-15 14:08:19','2008-04-15 12:08:19','moamaaaa....am nimerit intre ardeleni faini... masini, chestii...nimic nu pricep de aci, tulvai mai oameni buni da nu-i bai, musai tineti minte, daca-l prindetipe neamt, nu-l mascariti de pomana, ca-l zgudui io in dulcele grai mioritic din sud-vest zamislit...\r\nrespecte daco-gete,\r\nSibilla',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(23358,1080,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-04-30 14:52:04','2008-04-30 12:52:04',';;) \r\n\r\nAnd the penetration back into this world has just begun!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(32279,548,'','','','89.121.210.3','2008-07-02 11:03:53','2008-07-02 09:03:53','cine canta piesa asta cu scrum de tigara????',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(22034,1062,'De ailalta','z@yahoo.com','http://de-aia.blogspot.com/','213.157.188.71','2008-04-15 15:05:35','2008-04-15 13:05:35','mo, ai grija sa nu fie turc. si ai grija sa nu iti dea masina \"doar pt export\" :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9b5) Gecko/2008032620 Firefox/3.0b5','',0,0),(30092,1137,'','','','86.34.167.172','2008-06-18 16:46:10','2008-06-18 14:46:10','bravo olandejilor! au fost mai buni.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1; .NET CLR 2.0.50727; .NET CLR 1.0.3705; .NET CLR 1.1.4322)','',0,0),(34398,1159,'Bila','alexandruvladila@gmail.com','http://billiasin.wordpress.com/','84.232.246.5','2008-07-22 23:49:22','2008-07-22 21:49:22','Cine ar putea avea o asa aripa sensibila, daca nu musca? :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1) Gecko/20061010 Firefox/2.0','',0,0),(34399,460,'Nascut din spermatozoizi campioni &raquo; Blog Archive &raquo; Una scurta cu Gunther, da&#8217; destul de groasÄƒ','','http://www.groparu.ro/?p=1161','92.114.98.151','2008-07-22 23:53:22','2008-07-22 21:53:22','[...] ei, cÃ¢nd vin Ã®n Sibiu, adÄƒsteazÄƒ la SÄƒliÅŸte, Ã®n inima MÄƒrginimii, care-i lÃ¢ngÄƒ TiliÅŸca, unde se deschide berea cu [...]',0,'1','Incutio XML-RPC -- WordPress/2.1.2','pingback',0,0),(23370,1081,'hadean','contact@adihadean.com','http://www.adihadean.com','79.113.86.75','2008-04-30 16:02:22','2008-04-30 14:02:22','apoi nuÅŸtiu, femeia din mine face ce face ÅŸi tomna cÃ¢nd am nevoie de ie nu-i.ba mere la coafor ÅŸi vine cu pÄƒru plin de permament multe ceasuri mai tÃ¢rzÃ¢u, ba mere la ptiaÅ£ pÄƒ la 9 dimineaÅ£a ÅŸi vine la 9 sara, ba sÄƒ sfÄƒdeÅŸte cu femeia DE LÃ‚NGÄ‚ MINE, cÄƒ douÄƒ muieri Ã®nt-o casÄƒ greu sÄƒ Ã®nÅ£Äƒleg. no, ÅŸi de aia nu poci sustina cÃ®nd mÃ® uit la anatomia lu\' grei, numa mÄƒ rÃ¢d ca dobitocu\' la doctor haus.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(22040,1062,'ania','ania@wip.ro','http://aniakhaki.com','92.82.33.14','2008-04-15 15:56:51','2008-04-15 13:56:51','de care golf? :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(30771,1137,'mishu','mishu@doingtheartwork.com','http://www.doingtheartwork.com','92.82.37.86','2008-06-22 00:16:28','2008-06-21 22:16:28','Mai draga\r\nTu scrii cu-atata shaga\r\nDe lucruri care doare\r\nC-aveam echipa tare.\r\nDar ei au si mai tare.\r\nSi Rusia e MARE :)\r\nI-a trimis la plimbare\r\nLe-a dat-o unde-i doare.\r\n\r\nAdicatelea in poarta.\r\n\r\nDeci asa, de curiozitate la care faze ale noastre s-au entuziasmat olandezii? Ca sincer sa fiu eu nu le-am vazut sau poate la liga era meciul de la Constantza in reluare. \r\n\r\nPS: de frica ca iau bataie de la romani as saluta si \"Io in viata n-am noroc\" cu salutul nazist si m-as entuziasma peste asteptari :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9) Gecko/2008052906 Firefox/3.0','',0,0),(23389,1081,'Andreea MKT','supergirgir@yahoo.com','','89.43.186.64','2008-04-30 17:59:52','2008-04-30 15:59:52','te inteleg, in mine zace un barbat de 25 de ani cu ochi caprui si foarte obraznic. acest barbat ma facea sa fac pipi la buda firmei unde lucrez (nu cunosti firma) si colegii barfeau suparator ca de ce fac asta. iata de ce! mi se parea normal sa fac pipi acolo. eram atrasa de buda barbatilor asa cum obezul e atras de fastfood si pitzipoancele de bani.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(23380,1081,'gb','getbordea@yahoo.com','http://getbordea.blogspot.com','208.77.165.40','2008-04-30 17:08:30','2008-04-30 15:08:30','Femeia din tine te intreaba daca o iubesti sau daca a mai slabit?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(25404,1090,'Usim','mihaimitan@gmail.com','','87.237.108.33','2008-05-15 17:58:28','2008-05-15 15:58:28','Io zic k alora krora nu le plce cum vb si scri este liberi sa nu ctste.\r\nSa-si enjoiasca restul vietii citind banalitatile altora ca este free world, care este.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648)','',0,0),(23390,1081,'Andreea MKT','supergirgir@yahoo.com','','89.43.186.64','2008-04-30 18:03:15','2008-04-30 16:03:15','era de fapt buda mea!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(32256,1149,'Turambar','mirel@ccsb.ro','http://turambarr.blogspot.com','79.114.190.111','2008-07-02 09:28:03','2008-07-02 07:28:03','No ghin,e ma, ca vorbitzi voi mai ashe, mai altminterea, mama voastra da regionali dialectali carele nu vretzi sa invatzatzi, ma, limba lu Neagoe Basarab sh\'a lu Shtefan cel Mare sh\'a lu Nicolae Gutza, ma, sh\'a lu tot neamu alora carele or inventat, ma, limba de la Campulung Muscel, numa buna da cronicari shi da manele da buric shi ibric shi ilic, mama voastra de daci da peste munte. Da peste muntzi shi tzari, ma. Tulai Doamne, ca numa numa ashe\'mi vine cateodata a ma face filolog d\'antropolog, sa iau notitze shi sa bat la talpi, ma. Cu reportofonu, ma.\r\n\r\nMai mai..',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9) Gecko/2008052906 Firefox/3.0','',0,0),(23395,1081,'artistu','manea.andrei@gmail.com','http://artistu.voce.ro/','92.80.48.153','2008-04-30 18:35:22','2008-04-30 16:35:22','Misto femeia asta din tine, asa teoretic. Insa daca s-ar intampla sa apara cred ca ar fi rea si naspa!\r\nP.S. Io zic sa faci un bine omenirii si sa o sinucizi, asa poate devina eroina vreunui roman, decat prizoniera ta!   :d',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(25413,1091,'Andita','nofuturehousewife@yahoo.com','','86.122.228.135','2008-05-15 20:36:08','2008-05-15 18:36:08','man, mie ardelenii. defel. imi sunt simpatici, da nu ma gandeam sa ajung sa i indragesc chiar asa de tare:)))uite de asta merg la faculta la Timisoara..chit ca 10 ore o sa ma lipesc de scaunu autobuzului...Traiasca Ardealu..regiunea oamenilor manierati si de duh...si care beau bine!!!',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; SLCC1; .NET CLR 2.0.50727; Media Center PC 5.0; .NET CLR 3.0.04506; InfoPath.2)','',0,0),(25418,1091,'','','','92.81.151.92','2008-05-15 21:48:32','2008-05-15 19:48:32','@Andita:doara sci ca Cimisoara nu-i in Argeal?! Ori,ba.  :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(25446,1090,'etenah','onceawee_doomed@yahoo.com','','81.12.225.226','2008-05-16 10:26:17','2008-05-16 08:26:17','omu\' o fost jignit de faptul ca i-au dat un alexandrion si nu ceva mult mai scump. ca doar era treaba multa la omologatu, ce-stii-tu-ce-i-mai-face-ul masinii. io propun sa mai incerce o data, cu o beutura mai de rasa (cel putin). daca tot nu o ia... atunci \"deci - se poate\" :)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(29338,1092,'cosmin','makee_robert2005@yahoo.com','','90.193.16.107','2008-06-15 01:37:02','2008-06-14 23:37:02','si tequila.............',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(33641,1155,'www.mihaipopescu.com','r4r3s@yahoo.com','','79.117.157.234','2008-07-16 18:29:46','2008-07-16 16:29:46','Salveaza-l pe Mihai! are 24 ani, e din Timisoara si trebuie sa stranga 40 000 de euro pt o operatie pe creier, in Germania pt a extirpa o tumora craniana. Intra pe mihaipopescu.com pt mai multe detalii si poate pt a face si o donatie care ii poate salva viata : mihaipopescu.com',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.8.1.15) Gecko/20080623 Firefox/2.0.0.15','',0,0),(31866,1147,'seliman','ionut.seliman@gmail.com','http://ionutu.wordpress.com','213.157.171.107','2008-06-30 14:54:26','2008-06-30 12:54:26','N\'apÄƒi io cred cÄƒ Groparu nu are maÅŸinÄƒ proprie ÅŸi personalÄƒ, ÅŸi de aceea foloseÅŸte RATUC pe post de mijloc de transport Ã®n comun. Cum bicicleta i-a fost ÅŸi aia subtilizatÄƒ, iar mersul pe jos nu mai e de mult sÄƒnÄƒtos Ã®n oraÅŸe precum Cluj, BraÅŸov, IaÅŸi, etc. din cauzÄƒ de trafic intens, Ã®nlocuiri borduri, cÄƒlduri mari, troleul e o obÅ£iune. Io propun sÄƒ punem toÅ£i (ÄƒÅŸtia vizitatori groparieni) mÃ®nÄƒ de la mÃ®nÄƒ ÅŸi sÄƒ-i luÄƒm o biÅ£Äƒ noo. Sau dacÄƒ nu se strÃ®ng suficienÅ£i arjenÅ£i, sÄƒ-l ducem pe braÅ£e la uzina de lucru.. :D',0,'1','Opera/9.27 (Windows NT 5.1; U; en)','',0,0),(31867,1147,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-06-30 15:21:41','2008-06-30 13:21:41','Nu se poate ca, daca tot ma duceti pe brate cu cortegiul de fecioare virgine si neincepute, sa nu ma duceti la lucru, ci la iubit?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(29429,1127,'ania','ania@wip.ro','http://aniakhaki.com/','89.123.113.72','2008-06-15 15:25:55','2008-06-15 13:25:55','genial :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(25440,1090,'ameÅ£itul','','http://ametzitul.wordpress.com/','82.76.123.238','2008-05-16 07:58:37','2008-05-16 05:58:37','evident, portbagajul era Ã®ncuiat cu trei lacÄƒte :)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(33684,1156,'WhiteWolf','laskmerge@gmail.com','http://white-wolf.ro','79.118.187.179','2008-07-17 02:06:20','2008-07-17 00:06:20','Ti-o fo\' rushine sa o baji pe aia cu \"sfÃ nta polÃ£\" de o dai pe mataranji ?\r\nSau esti in perioada aia prelungita de \"no shit, no sex\" pe blog :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.16) Gecko/20080702 Firefox/2.0.0.16','',0,0),(28630,1119,'seliman','ionut.seliman@gmail.com','http://ionutu.wordpress.com','213.157.171.107','2008-06-09 10:12:31','2008-06-09 08:12:31','SÄƒ vinÄƒ scanuuu\'!!! SÄƒ vinÄƒ scanuuuu\'!!! Cine\'i Ã®n iel este Groparuuuu!! SÄƒ vinÄƒ scanuuuu\' !!! .... :D :D :D',0,'1','Opera/9.27 (Windows NT 5.1; U; en)','',0,0),(28624,1119,'Andrei Crivat','andrei@andreicrivat.ro','http://www.andreicrivat.ro','89.137.83.141','2008-06-09 09:14:15','2008-06-09 07:14:15','deci vorbele n-are nici o valoare, manca-ti-as, fara poze, ma pricepi ? baga scan, daca tot ai dat banii pe revista.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.9) Gecko/2008052906 Firefox/3.0','',0,0),(28629,1119,'Gogu Kaizer','satuldefoame@yahoo.com','http://kaizergogu.blogspot.com','141.85.252.73','2008-06-09 10:10:39','2008-06-09 08:10:39','Pai am cautat si eu o ceva de contact, un mail, astea, dar n-am gasit :( Sa imi fie cu iertare, asadar, daca am dezamagit :(',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(31844,1147,'Kissu','','http://www.pacurar.net','82.77.126.254','2008-06-30 10:09:32','2008-06-30 08:09:32','Daca tot o venit sa stea pe capul meu, o s-o pun pe soacra-mea sa se dea cu RATUC-ul si sa verifice cu limba daca nu-s prea reci barele din autobuz. ;))',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; InfoPath.1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648)','',0,0),(31841,1147,'Roza','popescu.onita@yahoo.com','','79.117.166.224','2008-06-30 09:37:53','2008-06-30 07:37:53','Bucura-te lipiciosule! :)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(31845,1147,'mo','verde_poveste@yahoo.com','','194.126.220.240','2008-06-30 10:36:37','2008-06-30 08:36:37','No, da-i cald tare in Cluj - vad ca azi n-ai chef de niika si nu te poti uita mai departe de lungu\' barei de autobuz si de rinichii vanduti la negru. :(\r\nC\'mooon..... sari cu o postare mai de vineri, asa.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1)','',0,0),(31852,1147,'PhenoBarbieDoll','oana.gavrila@mediafax.ro','','193.230.230.101','2008-06-30 12:29:22','2008-06-30 10:29:22','mo, lasa bietul Gropar sa-si planga soarta si raspunde-mi la mail. I know u\'re there!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(33552,664,'gfgfg','yahoo@yahoo.es','','84.120.26.184','2008-07-15 13:51:32','2008-07-15 11:51:32','zxfdgdgfdgdgdgdgdgdgdg',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; es-ES; rv:1.8.1.15) Gecko/20080623 Firefox/2.0.0.15','',0,0),(33553,664,'gfgfg','yahoo@yahoo.es','','84.120.26.184','2008-07-15 13:51:48','2008-07-15 11:51:48','baaaaaaa\r\nci faceti',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; es-ES; rv:1.8.1.15) Gecko/20080623 Firefox/2.0.0.15','',0,0),(33554,1154,'Andreea MKT','supergirgir@yahoo.com','','89.43.186.64','2008-07-15 14:21:48','2008-07-15 12:21:48','da ce, la noi in firma e 6 masini?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.15) Gecko/20080623 Firefox/2.0.0.15','',0,0),(25453,1091,'Nelu','nelu@nelui.nl','http://www.nelu.com','194.117.242.3','2008-05-16 11:46:14','2008-05-16 09:46:14','Timisora-i in Banat si Banatu e un judet de pe Marte. No, tat in Ardeal ii ! Si tati ominii de bun simt din tata lumea asta is ardeleni,no\r\n\r\n@Andita... Ceva imi spune ca nu doar betiile ardelenesti te entuziasmeaza intr-atat incat sa ne imbratisezi ci si niste brate zdravene de ardelean cinas !',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(32145,1147,'Groparu','groparu_ro@yahoo.com','http://','79.116.97.254','2008-07-02 00:20:15','2008-07-01 22:20:15','Mo, deci numai daca e o tiganca cu un tupeu pe ea!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,1),(31863,1147,'Andreea','puistrulet2003@yahoo.com','http://n/a','81.196.150.196','2008-06-30 14:18:05','2008-06-30 12:18:05','Lipiciul ca licipiul, hai te speli pana te simti curat (si la constiinta) dar ce faci cu socurile vizuale si olfactive? Alea nu trec asa de usor....:)))\r\n\r\n\r\nSoc vizual: tanti la 30-35 ani, super mega fardata cu albastru si 3 straturi de pudra din piata(ruby rose or some shit) vara, caldura mare si cu top fara maneci cu vedere la buricul paros si la padurea neagra de la subrat???E, ce zici de asta? I still have nightmares.. :((\r\n\r\nSoc olfactiv: nene pe la 40 de ani, transpirat(se lipeste camasa pe el si ii vezi gulerul murdar ca e a 3-a zi de purtare) si care miroase a mii de sosete imputite, miros amestect cu mancare- preferabil ceva ceapa cu zama de fasole si pe deasupra ii pute gura a ceva ce numai filmele horror gen the eye pot exemplifica vizual.. :)))))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(33664,1155,'Roza','popescu.onita@yahoo.com','','79.117.161.91','2008-07-16 22:30:44','2008-07-16 20:30:44','Gropare,sa-ti traiasca nepotii,sa fie sanatosi,sa creasca mari,frumosi si mintosi , la fel ca unchiul lor! :)\r\nAvand in vedere postul de mai sus(la care nu indraznesc a comenta) iti zic si eu,ca ar fi bine sa ii cadorisesti cat de curand cu o matusica mumoasa,laptoasa si devreme acasa si cu niste verisori asemanatori cu ei,cei atat de dragi tie,nepotei! :)\r\nCrede-ma s-ar bucura mult de tot ,ar fi cel mai super cadou pe care l-ai putea oferi lor si mamei lor,dar si mamei tale! :)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(31876,1147,'seliman','ionut.seliman@gmail.com','http://ionutu.wordpress.com','82.78.189.109','2008-06-30 17:08:13','2008-06-30 15:08:13','ÃŽncercÄƒm, Ã®ncercÄƒm..',0,'1','Opera/9.50 (Windows NT 5.1; U; en)','',0,0),(28637,1119,'seliman','ionut.seliman@gmail.com','http://ionutu.wordpress.com','213.157.171.107','2008-06-09 10:56:31','2008-06-09 08:56:31','MulÅ£Äƒmim, nenea Groparele! :)',0,'1','Opera/9.27 (Windows NT 5.1; U; en)','',0,0),(30030,1136,'Adi','adriana.argeseanu@gmail.com','http://aboutnothingsro.blogspot.com/','78.96.200.199','2008-06-18 10:22:38','2008-06-18 08:22:38','nu s-a amanat, doar tinea de fusul orar. de la 8 aseara a fost disponibil.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9) Gecko/2008052906 Firefox/3.0','',0,0),(33829,1157,'mo','verde_poveste@yahoo.com','','194.126.220.240','2008-07-18 08:47:00','2008-07-18 06:47:00','Ufff, situatiile de genu\' asta mi s-au parut intotdeauna foarte frustrante. \r\nDeci am o musca-n blid - cum procedez? \r\nAnunt chelnerita? \r\nVorbesc rastit sau bland? \r\nDaca tip imi scuipa in supa, daca zambesc probabil mere dupa usa, scoate musca cu dejtele si o aduce inapoi pe masa.... \r\nIti dai seama cat de norocos ai fost ca ai vazut extragerea in direct, facuta cu o lingura de plastic?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1)','',0,0),(24898,1087,'Andreea','puistrulet2003@yahoo.com','http://n/a','81.196.150.196','2008-05-09 10:26:13','2008-05-09 08:26:13','Tu ai ce ai cu bancile :))...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(24899,1087,'Andreea','puistrulet2003@yahoo.com','http://n/a','81.196.150.196','2008-05-09 10:27:17','2008-05-09 08:27:17','BTW ai fost printre cei cu carduri Millenium -BCR??? :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(24900,1087,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-05-09 10:29:43','2008-05-09 08:29:43','M-o ferit dracu\'! Sau Dumnezau. E vro diferenta?\r\n\r\nNormal ca ie, ce, ej copkil, Gropare?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(28499,1118,'Turambar','mirel@ccsb.ro','http://turambarr.blogspot.com','79.114.190.107','2008-06-08 11:34:43','2008-06-08 09:34:43','Si totushi, carele este cel de-a doua chestie care miroase a peshte?\r\n\r\nDamn. Me and my stiupid naivety. Ashtept raspunsul in FHM, impreuna cu un full frontal al lui Groparu pipaindu-l prin mamelizare inmanushata pe hadean, aplecat peste gratar.\r\n\r\nThe pain. The horror...\r\n\r\n:blink:',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(33220,1152,'Sinzi','fata_cu_par_verde@yahoo.com','','86.123.76.106','2008-07-11 16:29:16','2008-07-11 14:29:16','pune copii sa scrie niste entry-uri groparesti :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.15) Gecko/20080623 Firefox/2.0.0.15','',0,0),(30050,1122,'bani pe net','ioana_luiza_valiza@yahoo.com','http://bani-pe-net.ro','92.81.140.39','2008-06-18 11:54:29','2008-06-18 09:54:29','ai adus cascavalu\' la tine? \r\nsau reclama cu tipa care face strip \"iti place cascavalu?\" :)))=))',0,'1','Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.1.6) Gecko/20071008 Ubuntu/7.10 (gutsy) Firefox/2.0.0.6','',0,0),(32412,1150,'mo','verde_poveste@yahoo.com','','194.126.220.240','2008-07-03 11:25:27','2008-07-03 09:25:27','Foarte kusturicesc episodu\' asta... o singura data am patit ceva vag asemanator in copchilarie. Eram cu familia intr-un tren personal najpa si stateam pe langa usa, murind de plictiseala ca trenu\' se misca cu viteza luminii sub patura. In vagon mai erau si vreo 8 tigani si tiganci care vorbeau tare tiganeste si hahaiau, enervand lumea. No, la un moment dat unu\' care banuiesc ca era mai bulibashe a zis ceva, dupa care s-au ridicat toti si au iesit in anticamera vagonului (:P) sau cum naiba i-o mai fi zicand si s-au apucat sa cante si sa danseze. \r\nIo ca si copchil nu mai auzisem sau vazusem prin sticla de la usa ceva mai fain pana atunci - barbatii asezati cantau si bateau ritmul muzicii din palme si cu talpile, iar femeile chuiau si dansau invartindu-si fustele. Muzica aia nu suna a nimic din ce auzisem pana atunci la radio sau la teveu\' lu\' Ceasca, se canta din gura si din pocnete din palme si din fuste invartite, muzica era verde, alba, rosie, inflorata, sau cel putin asa mi-o amintesc. Acum, cand mi se intampla sa ascult muzica tiganeasca, ma apuca nabadaile - parca lipseste ceva si nu poci nicicum a spune ce.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1)','',0,0),(28302,1118,'catalin','solo@xsolo.biz','http://xsolo.biz','84.62.5.40','2008-06-06 11:06:36','2008-06-06 09:06:36','daca mergi la metro nu mai bine iei 1-2-3.... kg de carne argentiniana si faci \r\n\"parilla verdadera\"? oricum daca ai scapat de credit inseamna ca banu e pe la tine prin casa ;-)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(28303,1118,'Andreea','puistrulet2003@yahoo.com','http://n/a','81.196.150.196','2008-06-06 11:17:18','2008-06-06 09:17:18','@ Groparu: si ce ti-o zis Gropare? \"BU!!!!!!!!!!!!!!\" sau \"Fuck...not again!!!!\" :)))\r\n\r\nA.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(26169,1104,'Andreea','puistrulet2003@yahoo.com','http://n/a','81.196.150.196','2008-05-22 10:50:37','2008-05-22 08:50:37','Hai noroc Gropare.... :)\r\nPetrecere frumoasa si sa te si intorci, nu lasi fan-clubul fara \"worship-er\"....\r\n\r\nPS: sa strangeti dupa voi cand ati terminat, nu lasati pet-uri si alte shit-uri prin poiana, da :) ? (no sper ca nu te-ai suparat...dar no stii si tu povestea cu codru care ii frate...)\r\n\r\n No pa, \r\nAndreea',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(28335,1118,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','79.116.97.165','2008-06-06 20:23:37','2008-06-06 18:23:37','Deci mo nonick, da, asa ie, mai ales ca Ocna e locu\' care m-o scapat pe mine de raceli. Amu-s foarte fierbinte, ca sa ma-ntelegi. \r\n\r\nDa\' auzi: tu, din Ocna, al cui Nonick esti tu?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(24794,1086,'julius constantinescu','julius@universitateacraiova.ro','http://www.7plus.ro/?arhiva=08/05/2008&#38;id=5432','84.232.160.8','2008-05-08 01:45:01','2008-05-07 23:45:01','Da\' tu iti dai seama cat de smecher e Dumnezeu, daca pana si lu\' Jiji ii mai scapa cate o palma si badigarzii nu zic nimic???',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(24818,1086,'sepukku','s3pukku@gmail.com','','193.151.30.75','2008-05-08 08:41:24','2008-05-08 06:41:24',':)))))))))))))))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.0; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(24823,1086,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-05-08 10:01:31','2008-05-08 08:01:31',':))))\r\n\r\nCe i-o fraierit Dumnezeu si pe securistii aia!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(24824,1086,'james crissilv','jamescrissilv@weblog.roj','http://jamescrissilv.weblog.ro','82.76.149.33','2008-05-08 10:11:21','2008-05-08 08:11:21','pai vrea si el din cand in cand cate o vacanta ca prea il inabunim cu rugamintile.\r\no zi minunata iti doresc',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(31878,1147,'Roza','popescu.onita@yahoo.com','','79.117.159.52','2008-06-30 17:24:22','2008-06-30 15:24:22','Gropare,tu parca ai fi ala cu :\"Muieti-s posmacii!\",din povestea lenesului,de Ion Creanga!  :)\r\nAdicatelea daca te-am duce frumusel pe brate la lucru nu prea ti-ar conveni...nu si nu ....tu ai vrea la iubit si numa\' la iubit!\r\nPai noi vrem sa vii cat mai des la lucru,adica la scris...pentru ca le zici frumos acileasha pe blogu\' matale!\r\nIar noi suntem datori  sa iti aducem osanale,pentru ca ne binedispui!!!!!\r\nPentru asta...sar\'naaaaa!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(24729,1084,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-05-07 10:05:07','2008-05-07 08:05:07','Hait!!! La asta nu m-am gandit!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(24730,1084,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-05-07 10:11:09','2008-05-07 08:11:09','Pai inainte de a merge ei, ma duc io. Pariu ca tot de la mine va mirosi mai preponderent?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(25497,1091,'ove','ovidiu.zolti@yahoo.com','','86.123.150.66','2008-05-16 19:38:53','2008-05-16 17:38:53','multam, varu, va asteptam',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(24726,1084,'iulianuss','realvision@k.ro','','193.231.107.209','2008-05-07 09:48:58','2008-05-07 07:48:58','AÅŸa, ÅŸi daca eerdeeÅŸu vrea la budÄƒ, Ã®l laÅŸi ?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(33580,1155,'Dragos','www.laladragos@yahoo.com','http://inlalashead.blogspot.com','92.84.56.177','2008-07-15 21:44:48','2008-07-15 19:44:48','No chiar imi pare rau de tine dar n-ai cei face, asa\'s kopkii!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SIMBAR={AB2F2D52-9362-4A8A-9B32-13DBFC83E768}; AntivirXP08; .NET CLR 2.0.50727)','',0,0),(31913,1147,'mirra','jo75free@yahoo.com','','213.233.101.122','2008-07-01 00:05:49','2008-06-30 22:05:49','Gropare draga, foloseste taxiul daca vrei sa nu te lipeshti de bari.Asta in cazul in care nu-ti iei masina!Apropos,cum stai cu scoala de soferi????Gata,gata? Sau urmeaza sa te lipesti si de volan???',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(26164,1104,'mack','cherokee_lane@yahoo.com','http://mackerelfish.weblog.ro','86.121.28.111','2008-05-22 09:41:16','2008-05-22 07:41:16','ÅŸi-n farfuriul Äƒla? Ã®n farfuriul Äƒla de lÃ®ngÄƒ pufuleÅ£i, ce-i?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(34208,1154,'alanegru','ady_rr2000@yahoo.com','','85.186.182.97','2008-07-21 15:29:27','2008-07-21 13:29:27','noa, sa cheama ca omu o avut spor.  tu crezi ca-i ushor sa bagi tcheia in 6 (sase!!!) mashini si sa nu te vada nime? las ca si io tat ase am patzit, shi tat in cluj. si tat de-a randu. asta ii ,,in serie\", sau is mai multi ,,in paralel\"?!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(34210,1157,'alanegru','ady_rr2000@yahoo.com','','85.186.182.97','2008-07-21 15:32:09','2008-07-21 13:32:09','tz-o trebit tzie maimuta, in loc sa meri la varzarie (daca mai sa exista). le bagai sh-un vargabeles pe gat shi ziceau multzam.\r\n@turambar, multam de sfat. esti patzit?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(24711,1084,'ameÅ£itul','','http://ametzitul.wordpress.com','62.217.236.12','2008-05-07 07:34:51','2008-05-07 05:34:51','io zic sÄƒ te razi ÅŸi pe piept :)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(34213,1159,'Mariana Ciutacu &raquo; Lecturi din blogroll','','http://www.mana.ciutacu.ro/2008/07/21/lecturi-din-blogroll/','208.97.183.17','2008-07-21 16:07:53','2008-07-21 14:07:53','[...] n-o È™tiÈ›i? Cea cu jumÄƒtÄƒÈ›ile de sferÄƒ&#8230; È˜i sÄƒ nu vÄƒ lÄƒsaÈ›i induÈ™i Ã®n eroare de Groparu, el doar aparent abordeazÄƒ acelaÈ™i subiect&#8230; Sau&#8230; mai È™tii? Ä‚la o fi animÄƒluÈ›ul? [...]',0,'1','Incutio XML-RPC -- WordPress/2.3.1','pingback',0,0),(30650,1138,'WhiteWolf','contact@white-wolf.ro','http://white-wolf.ro','79.118.187.160','2008-06-21 10:45:03','2008-06-21 08:45:03','De-asta e plin de neinsurati.\r\nMai ales din cauza de prea multe babe si biserici. Mai apoi,m din cauza ca nu in fiecare an iasa vinul si rachiul aproape de perfectiune',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(34186,1159,'mirey','vatu.mirela@yahoo.com','http://monblog-mirey.blogspot.com','79.117.159.51','2008-07-21 12:08:59','2008-07-21 10:08:59','Primul paragraf mi-a placut mult de tot,frumos,la sentiment,\"romantios\" chiar...:D\r\nCu al doilea insa...m/atz facut praf domnule Groparu! :(',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(32110,1132,'Fabrica de tricouri','office@fabricadetricouri.ro','http://www.fabricadetricouri.ro','86.121.163.83','2008-07-01 21:49:13','2008-07-01 19:49:13','Designerul e invitat sa-si faca un cont pe site-ul din semnatura si sa ma contacteze; poate scoate ceva bani din fiecare vanzare; le realizam noi, el doar ia banii dupa incasare. \r\nAvem si sistem de afiliere pentru ceilalti cu blog dar fara talente artistice.\r\nLa mai mare!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9) Gecko/2008052906 Firefox/3.0','',0,0),(29658,1119,'brey','geezer.oy@gmail.com','http://na','86.105.226.242','2008-06-16 21:36:40','2008-06-16 19:36:40','deci cum ziceam: brey, lasa ca eu te iubesc mai mult decat pe gogukaizer desi pe el il stiu de mai demult decat pe tine. deci esti no1 pt mine si el e no2, da? \r\npoop si tranchilaiz ca ie de bine.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(33603,1155,'Sorinelu\'','','','210.150.186.60','2008-07-16 06:19:01','2008-07-16 04:19:01','ioi ce fain. abie astept ca fatuca mea sa-si dezvolte intelectul si manutele in directia asta. :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.15) Gecko/20080623 Firefox/2.0.0.15','',0,0),(32057,1148,'Sinzi','fata_cu_par_verde@yahoo.com','','86.123.76.106','2008-07-01 17:35:47','2008-07-01 15:35:47','ca-i fain la cluj stiam da ca-i \"taramul fagaduintei\" pentru micii \"infractori\" n-aveam idee. Acuma...un singur Garcea de treaba am intalnit si eu pe la 14 cand m-o gasit la vreo 2 noaptea in Cetate cu un crai mioritic care culmea era si de la seminar....noi saracii nu faceam mare lucru da cica ei , ORGANELE , trebuiau musai sa stie cine-i suspect de viol :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(32058,1148,'Sinzi','fata_cu_par_verde@yahoo.com','','86.123.76.106','2008-07-01 17:36:22','2008-07-01 15:36:22','*pe la 14 ani',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(33610,1155,'seliman','ionut.seliman@gmail.com','http://ionutu.wordpress.com','213.157.171.107','2008-07-16 08:01:41','2008-07-16 06:01:41','Copii veriÅŸoarei mele ce-mi sunt mie? Un soi de nepoÅ£i? Deci un weekend din Äƒsta cu Å£Ã®nci zgubilitici prin preajmÄƒ, Ã®Å£i Ã®ncarcÄƒ bateriile complet. Åži veriÅŸoara are 3 bÄƒieÅ£i. Care la Ã®nceput stau toÅ£i cuminÅ£i lÃ®ngÄƒ mÄƒ-sa. DacÄƒ Ã®i bagi Ã®n seamÄƒ, you\'re history! Mie Ã®mi place sÄƒ dau Ã®n mintea lor. De aia mÄƒ iubeÅŸte soacrÄƒ-mea! ;)',0,'1','Opera/9.27 (Windows NT 5.1; U; en)','',0,0),(32013,1148,'adi','adi@ucluj.ro','http://blog.ucluj.ro','86.35.201.235','2008-07-01 13:51:34','2008-07-01 11:51:34','Sa-nteleg ca stai in Grigorescu, Groparele care esti, tu, unicul, minunatul? Ca io doar acolo am vazut un Garcea respectat si disparitii subite de biciclete...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.9) Gecko/2008052906 Firefox/3.0','',0,0),(23644,412,'clujean','dm42@k.ro','','80.97.64.202','2008-05-02 08:38:29','2008-05-02 06:38:29','bre, sa-i zici mersi lu ceasca finca i-a adus pe nespalati cu turma in oras si lu boc cel mic ca le-a dat la penziusi liber pe harabaiele ratucului!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.0; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(22248,1025,'vlad','vladyandrei@yahoo.com','http://www.blablabla.com','92.81.69.96','2008-04-17 09:22:03','2008-04-17 07:22:03','haha aja am facut si io :)) mai aveam putin si\'l aruncam de la fereastra :))',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(32012,1148,'kittynel','kittynel@gmail.com','','213.208.242.81','2008-07-01 13:48:34','2008-07-01 11:48:34','vad ca lumea a inceput sa vorbeasca \"gropariceste\". \r\n\r\nbicicleta \"noo\" , \"io\", \"poa\' \" etc etc... \r\n\r\npe cand un dictionar de termeni \"groparicesti\" ?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9) Gecko/2008052906 Firefox/3.0','',0,0),(32015,1045,'Wo kann ich filme downloaden? Danke','','http://de.answers.yahoo.com/question/index?qid=200706208339AAFKFKv','213.239.234.42','2008-07-01 14:00:17','2008-07-01 12:00:17','<strong>coole www usenext filme downloaden...</strong>\n\nWo kann ich filme downloaden?...',0,'1','','trackback',0,0),(31994,1148,'KillerINC','webmaster@bcdentalab.ro','http://killerinc.voce.ro','79.118.237.209','2008-07-01 12:30:12','2008-07-01 10:30:12','eu stau cam la 500 de km de tine, mai exact in Pitesti, dar as renunta oricand la tot ce am aici ca sa ma mut la cluuuujjjj',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.9) Gecko/2008052906 Firefox/3.0','',0,0),(29580,1127,'Greuceanu','','','89.46.104.35','2008-06-16 13:14:33','2008-06-16 11:14:33','si io-s spammer in ochiu\' tau!\r\n\r\ndaca are adresa expeditorului, e trimis manual si nu automat si daca are optiune de dezabonare nu E SPAM!  daca vrei sa citeshti legea, zi-mi sh tz-o dau sus! sau jos!\r\n\r\n\r\nSpamming (sau spam) este procesul de expediere a mesajelor electronice nesolicitate, de cele mai multe ori cu caracter comercial, de publicitate pentru produse ÅŸi servicii dubioase, practicatÄƒ Ã®n industria e-marketingului ÅŸi de proprietarii de situri pornografice. Spam-ul se distinge prin caracterul agresiv, repetat ÅŸi prin privarea de dreptul la opÅ£iune\r\n\r\n\r\nLegea 506 - 2004 ART. 12\r\nComunicÄƒrile nesolicitate\r\n(1) Este interzisÄƒ efectuarea de comunicÄƒri comerciale prin utilizarea unor sisteme automate de apelare care nu necesitÄƒ\r\nintervenÅ£ia unui operator uman, prin fax ori prin poÅŸta electronicÄƒ sau prin orice altÄƒ metodÄƒ care foloseÅŸte serviciile de\r\ncomunicaÅ£ii electronice destinate publicului, cu excepÅ£ia cazului Ã®n care abonatul vizat ÅŸi-a exprimat Ã®n prealabil\r\nconsimÅ£ÄƒmÃ¢ntul expres pentru a primi asemenea comunicÄƒri.\r\n(2) FÄƒrÄƒ a aduce atingere prevederilor alin. (1), dacÄƒ o persoanÄƒ fizicÄƒ sau juridicÄƒ obÅ£ine Ã®n mod direct adresa de poÅŸtÄƒ\r\nelectronicÄƒ a unui client, cu ocazia vÃ¢nzÄƒrii cÄƒtre acesta a unui produs sau serviciu, Ã®n conformitate cu prevederile Legii nr.\r\n677/2001, persoana fizicÄƒ sau juridicÄƒ Ã®n cauzÄƒ poate utiliza adresa respectivÄƒ, Ã®n scopul efectuÄƒrii de comunicÄƒri\r\ncomerciale referitoare la produse sau servicii similare pe care acea persoanÄƒ le comercializeazÄƒ, cu condiÅ£ia de a oferi Ã®n\r\nmod clar ÅŸi expres clienÅ£ilor posibilitatea de a se opune printr-un mijloc simplu ÅŸi gratuit unei asemenea utilizÄƒri, atÃ¢t la\r\nobÅ£inerea adresei de poÅŸtÄƒ electronicÄƒ, cÃ¢t ÅŸi cu ocazia fiecÄƒrui mesaj, Ã®n cazul Ã®n care clientul nu s-a opus iniÅ£ial.\r\n(3) ÃŽn toate cazurile este interzisÄƒ efectuarea prin poÅŸtÄƒ electronicÄƒ de comunicÄƒri comerciale Ã®n care identitatea realÄƒ a\r\npersoanei Ã®n numele ÅŸi pe seama cÄƒreia sunt fÄƒcute este ascunsÄƒ sau Ã®n care nu se specificÄƒ o adresÄƒ valabilÄƒ la care\r\ndestinatarul sÄƒ poatÄƒ transmite solicitarea sa referitoare la Ã®ncetarea efectuÄƒrii unor asemenea comunicÄƒri.\r\n(4) Prevederile alin. (1) ÅŸi (3) se aplicÄƒ Ã®n mod corespunzÄƒtor ÅŸi abonaÅ£ilor persoane juridice.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(22270,1062,'','','','62.217.213.177','2008-04-17 13:51:31','2008-04-17 11:51:31','Gropare sa inteleg ca ti-ai luat carnetul....si cauti masini pe la Jermanica? Asta ar insemna ca stii ca se apropie vara si te pregatesti de Muntenegru :)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; SIMBAR={CB08DE91-79D4-4CB0-B9F3-C79683434EB1}; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(22272,1062,'Mile','','','62.217.213.177','2008-04-17 13:53:42','2008-04-17 11:53:42','aoleo am uitat sa ma prezint ....ce vaca sunt....\r\n\r\nMile',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; SIMBAR={CB08DE91-79D4-4CB0-B9F3-C79683434EB1}; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(28313,1118,'seliman','ionut.seliman@gmail.com','http://ionutu.wordpress.com','213.157.171.107','2008-06-06 14:30:39','2008-06-06 12:30:39','ApÄƒi dacÄƒ-i cu dezlegÄƒciune la feÅŸte, io sunt fanul hamsiei Äƒleia Ã®mpuÅ£ite de la mare...aia care pute de\'Å£i mutÄƒ pifometrul, da\' dupe care intrÄƒ bine vo\' 5 beri reci, la umbrÄƒ..\r\nÅži cu dorada sÄƒ-Å£ zic o poantÄƒ: pe viitoarea-mi consoartÄƒ, o chiamÄƒ Dora pe numele ei..deci Dora, da? ieri la piaÅ£Äƒ..(fÄƒrÄƒ diacritice):Dora dorada luÄƒm? :)',0,'1','Opera/9.27 (Windows NT 5.1; U; en)','',0,0),(22280,488,'Nascut din spermatozoizi campioni &raquo; Blog Archive &raquo; Tocmai am pierdut cea mai the best partida de insuratoare ever','','http://www.groparu.ro/?p=1066','82.103.137.253','2008-04-17 15:35:48','2008-04-17 13:35:48','[...] Radio Romania Actualitati. Da&#8217; s-o intamplat, de exemplu, sa raman fara grai cand s-o nascut Medeea din clanul Greucenilor, careia i-am dedicat randurile de mai sus - de o sinceritate cu atat mai [...]',0,'1','Incutio XML-RPC -- WordPress/2.1.2','pingback',0,0),(28296,1118,'Andreea','puistrulet2003@yahoo.com','http://n/a','81.196.150.196','2008-06-06 09:46:47','2008-06-06 07:46:47','@ Groparu; da io cred ca pestele nu-i innebunit dupa tine.....Ii innebunit...de spaima....pe langa Groparu ar trebui sa puna si un aka \"Spaima pestilor/pestioicilor/\"tacutilor\"/solzosilor/purtatorilor de coada de peste\" and the list could go on... :))))\r\n\r\nNu zic bine?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(26073,1097,'candid','adi.covaci@jumpeye.com','http://www.aicarteaiparte.ro','85.186.103.6','2008-05-21 17:28:00','2008-05-21 15:28:00','Ma da rau esti tu, oricum mi-am dezvoltat o paranoia cu mancarea chinezeasca, mai pui si tu pe foc! \r\n\r\nNu ti s-a intamplat sa manci chinezarii bune si sa te trezesti ca au un miros ciudat?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(26074,1104,'LP','pufime@yahoo.co.uk','','79.113.197.228','2008-05-21 17:36:47','2008-05-21 15:36:47','Si eu vreau pufuleti.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(22288,1066,'Tudor','tudor@inbox.com','','89.137.175.170','2008-04-17 17:22:25','2008-04-17 15:22:25','Chiar, tu cÃ®Å£i ani ai?',0,'1','Opera/9.27 (Windows NT 6.0; U; en)','',0,0),(33660,1155,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','79.116.96.71','2008-07-16 21:02:20','2008-07-16 19:02:20','Daca nu atasezi si diagnosticul medical scanat, cu bilete de internare si ghi tatie, ghe unie crezi tu ca iti pot da bani?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.16) Gecko/20080702 Firefox/2.0.0.16','',0,0),(27722,1007,'Victor','vick_redhound@yahoo.com','','79.115.9.41','2008-06-01 18:48:54','2008-06-01 16:48:54','Gropare, e duminica frate si tu nu ti-ai tinut promisiunea sa ne informezi :D Hai ca pana acu\' te-ai fi trezit tu (daca nu cumva ai sarbatorit si post-tiganiada) La mai bine si la mai multe postari!',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; .NET CLR 2.0.50727; .NET CLR 1.1.4322)','',0,0),(22300,1064,'zgura','','','79.116.97.209','2008-04-17 18:57:56','2008-04-17 16:57:56','Maaa, deci daca ma rogi frumos iti zic care e cel mai tare instructor din Cluj. A doua oara.\r\nP.S.: Pun si o pila, gratis',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(22302,1066,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2008-04-17 19:22:41','2008-04-17 17:22:41','Chiar, cati imi dai?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(22304,1066,'ove','ovidiu.zolti@yahoo.com','','86.123.150.8','2008-04-17 19:50:35','2008-04-17 17:50:35','cu suspendare ?????',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(22308,1064,'trafiik','','','79.116.228.153','2008-04-17 20:37:44','2008-04-17 18:37:44','Inceraca sa dai drumu\' la toate o data sa vezi ce iese! :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(30629,1138,'jospehine','fake@yahoo.com','','58.38.27.44','2008-06-21 06:37:20','2008-06-21 04:37:20','Credeam ca te insori si vrei sa ne-o prezinti pe viitoarea nevasta intr-o lumina buna, cu o introducere misterioasa... Se pare ca era numai o gluma :O',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(34159,1159,'seliman','ionut.seliman@gmail.com','http://ionutu.wordpress.com','213.157.171.107','2008-07-21 07:27:05','2008-07-21 05:27:05','ÃŽncepusem sÄƒ cred cÄƒ Groparele o dat lovitura, cÄƒ are o formÄƒ de viaÅ£Äƒ sensibilÄƒ, supÅ£ire, frumoasÄƒ, de o inteligenÅ£Äƒ superioarÄƒ nouÄƒ, bÄƒrbaÅ£ilor, cÄƒ aveai aceastÄƒ femeie subt ochii tÄƒi ÅŸi descriind-o, implicit subt ochii noÅŸtri, dar cÃ®nd colo, trebuia sÄƒ nu te dezminÅ£i tu! Cred cÄƒ niciodatÄƒ n-am mai vÄƒzut o asemenea descriere pentru o muscÄƒ. :D',0,'1','Opera/9.27 (Windows NT 5.1; U; en)','',0,0),(34176,1159,'Radu','ratradu@gmail.com','http://ratradu.blogspot.com','87.237.110.53','2008-07-21 09:37:02','2008-07-21 07:37:02','Citesc cu atentie blogul pentru a depista o urma firava de prezenta feminina in viata Groparelui, in afara de maica-sa (care e o doamna), si am crezut ca am gasit-o. Dar de fapt, la saliva verzuie pe perna s-a dat de gol ca fiind el personajul principal si ca de fapt e vorba doar de o biata musca, cea care ii da tarcoale',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.0.1) Gecko/2008070208 Firefox/3.0.1','',0,0),(22310,1066,'r','rbef@gmail.com','','66.15.61.199','2008-04-17 20:51:13','2008-04-17 18:51:13','31, 32 in nov',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(22313,1066,'Laura','mars1953@web.de','','84.160.93.248','2008-04-17 21:26:24','2008-04-17 19:26:24','cum zicea Zorba Grecul \r\nâ€žTot ce e bun in lumea asta e nascocit de diavol: muierile frumoase, primavara, purcelul prajit, vinul, in toate astea e mana Diavolului. In vreme ce bunul Dumnezeu i-a facut pe calugari, posturile, ceaiul de musetel si muierile urate, pfui!â€',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(34160,1159,'seliman','ionut.seliman@gmail.com','http://ionutu.wordpress.com','213.157.171.107','2008-07-21 07:29:59','2008-07-21 05:29:59','Recitind pasajul, constat cÄƒ de fapt personajul central al operei eÅŸti chiar tu. :D\r\nDe, dacÄƒ m-am beÅ£ivit asearÄƒ!',0,'1','Opera/9.27 (Windows NT 5.1; U; en)','',0,0),(32138,1147,'','','','79.117.41.215','2008-07-01 23:57:09','2008-07-01 21:57:09','Si totusi, parca e un \"nu\" pus aiurea \r\n\r\n\"sansele sÄƒ nu mai plece ca proastele cu contracte de dansatoare prin Kosovo ÅŸi sÄƒ Ã®ÅŸi doneze pe-acolo rinichii sunt inexistente\"\r\n\r\nGropare, daca si nu-ul s-a lipit de propozitie cu aceeasi naclaiala, eu zic sa pui o tiganca nespalata sa o rosteasca cu voce tare, ca ma gandesc ca tot asa te dezlipesti si de bari, cu disperarea pe care ti-o da dorinta de a fugi unde vezi cu ochii de minoritatea conlocuitoare.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.9) Gecko/2008052906 Firefox/3.0','',0,0),(32148,1148,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','79.116.97.254','2008-07-02 00:28:03','2008-07-01 22:28:03','@ alin62: ia vezi postarea de azi :D\r\n\r\n@ Greuceanu: gipu si A6-le erau de BeiuÅŸ (unu) ÅŸi de FiliaÅŸi (celÄƒlalt)\r\n\r\nOF CORS CÄ‚ ERAU DE CLUJ! CÄ‚ DOARÄ‚ NU EREAU DE APAHIDA!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(27800,1109,'julius constantinescu','julius@universitateacraiova.ro','http://www.7plus.ro/?arhiva=02/06/2008&#38;id=6440','84.232.162.26','2008-06-02 16:09:09','2008-06-02 14:09:09','Groparu, zi drept: tu vrei sa te lipesti de invitatii dese la inmormantari, parastase si pomeniri, sa crapi in tine moca. Nu?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(27801,1109,'julius constantinescu','julius@universitateacraiova.ro','http://www.7plus.ro/?arhiva=02/06/2008&#38;id=6440','84.232.162.26','2008-06-02 16:15:28','2008-06-02 14:15:28','PS: recunoaste, porcule!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(32225,1149,'hadean','contact@adihadean.com','http://www.adihadean.com','79.113.87.77','2008-07-02 06:58:25','2008-07-02 04:58:25','ÅŸi nici nu Å£o trecut pÃ¢ntre bucile creierului sÄƒ faci ÅŸtimb de aidiuri cu havaiana, sÄƒ ne povesteÅŸti amu cum o fo cu ie la on suc apoi la o savarinÄƒ, sÄƒ alimentezÅŸi fantasmile noaste de oamini fÄƒrÄƒ noroc la ocazie, aÅŸei? (fÄƒrÄƒ noroc cÄƒ de fiecare datÄƒ numa nane cu straiÅ£ cu cantalauÄƒ de groÅŸtior o stat cu mine la stop).',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(22326,1060,'baghy','baghy83@lycos.it','http://www.baghy.info','78.12.10.158','2008-04-18 00:02:04','2008-04-17 22:02:04','astept aia cu bodyguardul din chillout :))',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(25728,1092,'ameÅ£itul','','http://ametzitul.wordpress.com/','82.76.123.238','2008-05-19 10:10:48','2008-05-19 08:10:48','tare nuntÄƒ... puÅ£ulica aia, dacÄƒ o inventezi, fÄƒ-o cu multe asperitÄƒÅ£i. De ce? Pentru cÄƒ meritÄƒ :)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(22330,1066,'Usim','mihaimitan@gmail.com','','86.105.53.203','2008-04-18 01:00:39','2008-04-17 23:00:39','In noiembrie pe 13 :-)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; SIMBAR={DD244015-18CD-46A1-A16E-DBA123A57D2F})','',0,0),(22333,1064,'Usim','mihaimitan@gmail.com','','86.105.53.203','2008-04-18 01:11:34','2008-04-17 23:11:34','Gropare, melodia nr. 3 este a lui Katie Melua care nu este americanca ci georgianca emigrata in UK. Detalii, biografie si discografie pe www.katiemelua.com.\r\nSuper voce are si io mi-s fan.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; SIMBAR={DD244015-18CD-46A1-A16E-DBA123A57D2F})','',0,0),(27802,1109,'hadean','contact@adihadean.com','http://www.adihadean.com','86.125.34.195','2008-06-02 16:15:44','2008-06-02 14:15:44','pfoai!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(29765,1135,'seliman','ionut.seliman@gmail.com','http://ionutu.wordpress.com','213.157.171.107','2008-06-17 08:53:04','2008-06-17 06:53:04','Nu ÅŸtiu alÅ£ii cum sÃ®nt dar mie mi-e dor de pieÅ£ele pline de Å£Äƒrani (ÅŸi produse 100% naturale) ÅŸi de talciocuri, bÃ®lciuri, de Å£Ã®ganii care vindeau cocoÅŸei pe bÄƒÅ£ ÅŸi gumÄƒ Turbo cu surprize (alea cu maÅŸini).. :D\r\nAcu dacÄƒ ai odraslÄƒ ÅŸi intri cu ea la hipermarket, te ea dreq dacÄƒ treci pe lÃ®ngÄƒ rafturile cu jucÄƒrii.\r\nBtw, chiar s-o dÄƒrÃ®mat acoperiÅŸu\' lu\' Iulius Mall Cluj? Sau exagerau fÄƒtucili?',0,'1','Opera/9.27 (Windows NT 5.1; U; en)','',0,0),(22358,1064,'hadean','contact@adihadean.com','http://www.adihadean.com','194.102.126.6','2008-04-18 07:04:23','2008-04-18 05:04:23','no, amu mi-ai tras o buna dimineata, propun sa traiesti.bine?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12','',0,0),(22359,1066,'hadean','contact@adihadean.com','http://www.adihadean.com','194.102.126.6','2008-04-18 07:08:45','2008-04-18 05:08:45','no miÅŸto! sÄƒ trÄƒiascÄƒ ÅŸi sÄƒ te Å£Ã¢ie sÄƒnÄƒtos ÅŸi Ã®n dilemÄƒ Ã®ncÄƒ un veac.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12','',0,0),(22362,1066,'ameÅ£itul','','http://ametzitul.wordpress.com','62.217.236.12','2008-04-18 07:43:47','2008-04-18 05:43:47','pÄƒi cu niciuna, cÄƒ probabil nu va fi legal :)\r\ntot Ã®n post, a? admir consecvenÅ£a, nu ÅŸi ideea :)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(29783,1135,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-06-17 10:32:16','2008-06-17 08:32:16','@ mo: asternutu il schimb cand apuc sa-l dezlipesc de mine, ca tot umblu cu el la serviciu, si ma tot mir de ce ma evita pana si gunoierii.\r\n\r\n@ seliman: sa te fereasca D-zo sa intri in piata de lactate din Sibiu! Daca iesi de acolo nebelit de mÄƒrgineni vei avea eternul meu respect. Nu ca alfel nu l-ai avea...\r\n\r\n@ Crivat, Andrei Crivat: am trecut noi prin clipe mult mai grele prin Padis, nu?\r\n\r\n@ anonim: asa-i! plus ca o lenjerie nu pune frana brusca.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(29784,1135,'hadean','contact@adihadean.com','http://www.adihadean.com','86.125.34.195','2008-06-17 10:36:53','2008-06-17 08:36:53','Ã®n acelaÅŸ spirit: asarÄƒ mÃ¢ndra mi sÄƒ plÃ¢nje cÄƒ are un gust amar de o cÃ¢teva zÃ¢le. io, ca omu, presupun cÄƒ nu-i de la viaÅ£a Ã®n comun cu mine (no, asta mÄƒ coafeazÄƒ sÄƒ cred) ÅŸi zÃ¢c \"hai la apoticÄƒ sÄƒ lovÄƒm on ceai de sunÄƒtoare\".\r\nie zÃ¢ce: da de ment\'Äƒ nu iei, cÄƒ pÄƒ poliÅ£Äƒ nu mai avem decÃ¢t de muÅŸeÅ£Äƒl ÅŸÃ¢ Äƒla nu-i bun de bÄƒut cÃ¢ Ã®m aduce aminte de grupa micÄƒ. ioi, d-apoi cum sÄƒ obliji fimeia sÄƒ beie muÅŸeÅ£Äƒl, iei mentÄƒ de bunÄƒ samÄƒ. io la apoticÄƒ:\r\n- aveÅ£ ciai de sunÄƒtoare?\r\n-ighen\r\n-da de mentÄƒ?\r\n-perse\r\nda dacÄƒ le amesteci nu-i bai? sÄƒ facÄƒ ca cola cu bomboanele cu aier, sÄƒ puÅŸcÄƒm pÃ¢n tÄƒtÄƒ casa ca cavitu\' de pÄƒ vremuri?\r\n-ioi nem, noghion iou impreunÄƒ.\r\n-hat atuncea o troacÄƒ din fiecare\r\n\r\najung acasÄƒ\r\n-ni dragÄƒ, amu om be ÅŸi ne trece gustu, om fi numa mentÄƒ ÅŸi sunÄƒtoare ÅŸi ni-om pute Å£uca Ã®n sfÃ¢rÅŸit.\r\n-da menta ta sÄƒ face din muÅŸeÅ£Äƒl?\r\n-iooooooi lovam spÃ¢nzuram de pom pÄƒ apoticÄƒreasÄƒ, io cer mentÄƒ ie dei muÅŸiÅ£el la mine. iÅŸ io inche tolomac, cÄƒ mÄƒ Ã®ncred Ã®n tÄƒt ce spun babele care nu vorbesc romÃ¢neÅŸte nici pÃ¢nÄƒ la uÅŸÄƒ ÅŸi nu mÄƒ it pÄƒ troacÄƒ.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(27786,1109,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-06-02 13:39:03','2008-06-02 11:39:03','Exact!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(27790,1109,'hadean','contact@adihadean.com','http://www.adihadean.com','86.125.34.195','2008-06-02 14:18:35','2008-06-02 12:18:35','mie sÄƒ-mi spuneÅ£i clar care dintre voi Ã®s, sÄƒ ÅŸtiu cum mÄƒ aÅŸez.no, bine?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(27791,1109,'gb','getbordea@yahoo.com','http://getbordea.blogspot.com','208.77.165.40','2008-06-02 14:26:06','2008-06-02 12:26:06','Nu te mai satura \'mnezo de trafic buey gropare!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(33747,1157,'fotoghin','','','92.82.47.128','2008-07-17 14:44:06','2008-07-17 12:44:06','vorba ceea ,,,la pretu asta ce vrei? sharon stone?!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; ro; rv:1.8.1.16) Gecko/20080702 Firefox/2.0.0.16','',0,0),(27793,1109,'nelamurita','totmea@yahoo.com','','89.123.75.30','2008-06-02 14:49:07','2008-06-02 12:49:07','hadean. sint martori cum ca tu esti tu. deci ramane ca eu sint unul din el.\r\ndintr-o data nu-mi suna a bine....',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; SIMBAR={3523AA32-EC48-4B99-902E-C5F036C0464E}; Zango 10.3.36.0)','',0,0),(26056,1104,'ameÅ£itul','','http://ametzitul.wordpress.com/','82.76.123.238','2008-05-21 16:08:21','2008-05-21 14:08:21','baftÄƒ, domnu...\r\nabia aÅŸtept relatarea ÅŸi pozele :)\r\natenÅ£ie la rugby-ul Äƒla cu sticla, dezbrÄƒcaÅ£i...',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(24591,1083,'hadean','contact@adihadean.com','http://www.adihadean.com','86.125.34.195','2008-05-06 15:57:26','2008-05-06 13:57:26','uite care-i treaba:marimea nu conteaza, da micimea conteaza foarte tare!iara \"durata vizitei\" nu trebuie sa devina mai importanta decat \"scopul vizitei\", si anume, sa ne samtam bine.cred io.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(26057,1104,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-05-21 16:09:58','2008-05-21 14:09:58','Mersi, mo!\r\n\r\nAnu asta nush pe care sa-l schilodesc, ca anu trecut l-am trecut pe Greuceanu aka Rramon la palmares:D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(27770,598,'Una','lavinia.ciuca@yahoo.com','','89.122.221.54','2008-06-02 09:44:40','2008-06-02 07:44:40','Care este diferenta dintre un barbat si un apendice inflamat? Niciuna. Amandoua dor si abia cand te scapi de ele iti dai seama ca nici n-ai avut nevoie de ele.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(27784,1109,'nelamurita','totmea@yahoo.com','','89.123.75.30','2008-06-02 13:10:46','2008-06-02 11:10:46','acuma....io am vazut pe-aici mai multa lume, si intreb: io-s a patra persoana ori sint una din cele trei tu?\r\nsa ma simtesc ciudat????...sa nu ma simtesc???',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; SIMBAR={3523AA32-EC48-4B99-902E-C5F036C0464E}; Zango 10.3.36.0)','',0,0),(29802,1135,'hadean','contact@adihadean.com','http://www.adihadean.com','86.125.34.195','2008-06-17 12:05:02','2008-06-17 10:05:02','gropare, bun sfat\r\nmo: dacÄƒ Å£Ã¢ so urÃ¢t cu binile te poftesc sÄƒ-i dai tu lu gajica me cu traoca Ã®n cap, o sÄƒ vez cÄƒ iesÄƒ oarice pÄƒ sistemu:\r\n-bÄƒ ce eÅŸti plin de sÃ¢nje pÄƒ meclÄƒ?\r\n-apoi cÄƒ mÄƒ tÄƒt lovesc cu bumerangu, no\r\n-da\' Å£Ã®pÄƒl dracului\r\n-da Å£Ã¢pÄƒl tu!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(32297,1149,'seliman','ionut.seliman@gmail.com','http://ionutu.wordpress.com','213.157.171.107','2008-07-02 12:40:38','2008-07-02 10:40:38','@dora\r\nno..nu :)',0,'1','Opera/9.27 (Windows NT 5.1; U; en)','',0,0),(32299,1147,'cris','plattamon@yahoo.com','http://crisdreams.blogspot.com','89.136.54.77','2008-07-02 12:51:04','2008-07-02 10:51:04','I deftera ine i agapimeni mera mou...asa ca va rog frumos.:))',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(25635,1090,'Cristian Ungur','cristian.ungur@utopium.ro','http://cristianungur.blogspot.com','79.113.42.48','2008-05-18 13:18:58','2008-05-18 11:18:58','Stupid behavior? Tu singur ti-ai ales numele asta?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(27769,598,'Dana','lavinia.ciuca@yahoo.com','','89.122.221.54','2008-06-02 09:42:13','2008-06-02 07:42:13','Ce mai circula pe mailuri!!!!!    \r\n\r\nRazbunarea fetelor pentru toate bancurile misogine...\r\n\r\nCe i se intampla unui barbat daca i se taie penisul?\r\nAutomat capul preia comanda...\r\n\r\nCum se defineste sotul perfect?\r\nUn tip cu o limba de 25 de centimetri care poate sa respire pe urechi...\r\n\r\nCare-i asemanarea dintre un barbat si un soarece?\r\nAmandoi trag la gaura\r\n\r\nCe este un sot?\r\nUn amant care si-a fortat prea mult norocul.\r\n\r\nCare este asemanarea dintre un barbat si o telecomanda?\r\nAmbii sunt simpli, usor de folosit si de obicei ii gasesti pe langa televizor.\r\n\r\nDe ce ce sunt barbatii ca zapada?\r\nNu stii cand vin(e), nu stii cati centimetri vei avea, si nu stii nici cat va dura...\r\n\r\nCe isi zice mireasa dupa noaptea nuntii?\r\nDoamne-ajuta ca nu am aruncat inca vibratorul.. .\r\n\r\nDe ce sunt barbatii ca si cabinele telefonice?\r\nOri sunt \"ocupate\" ori e \"telefonul\" defect...\r\n\r\nCum se numeste un barbat aratos, inteligent, atent si sensibil?\r\nBasm...\r\n\r\nDe ce sunt barbatii ca ceapa?\r\nDaca dai jos invelisul iti vine sa plangi...\r\n\r\nDe ce poseda barbatii un cromozom mai putin decat porcul?\r\nCa sa nu li se spiraleze penisul...\r\n\r\nDe ce sunt barbatii imuni la boala vacilor nebune?\r\nPentru ca sunt porci...\r\n\r\nDe ce exista barbati?\r\nPentru ca vibratoarele nu aduc bani in casa...\r\n\r\nCare e diferenta dinte barbati si \"Pedigree\"?\r\nPedigree exista si cu creier...\r\n\r\nCe are o femeie cu doua oua in mana?\r\nAtentia totala si nepartinita a barbatului.. .\r\n\r\nDe ce barbatii sunt ca si betele de chibrit?\r\nDaca ii aprinzi isi pierd capul...\r\n\r\nCe are 6 picioare, un IQ de 100 si miroase a bere?\r\nTrei barbati in fata televizorului la meciul de fotbal...\r\n\r\nCum se numeste un barbat cu un IQ de 50?\r\nDotat...',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(22370,1066,'Greuceanu','','','89.46.104.35','2008-04-18 09:38:59','2008-04-18 07:38:59','mo,\r\n\r\nn-am cuvinte! nu am! daca nu am, de unde mah sa dau?! de un-de!?z! de UN-DE!?\r\n\r\ndar mi-e teama sa nu-tz plesneasca vreo vena cand iti vezi propriul bebelush!, c-apoi trebe sa-l cresc io cu nevasta-ta cu tot....',0,'1','Opera/9.25 (Windows NT 5.1; U; en)','',0,0),(22371,1064,'Hammer','hammer@alpinet.org','','81.196.168.118','2008-04-18 09:44:26','2008-04-18 07:44:26','Gropare, asculta piesa asta O DATA :-) Doi baieti din Ucraina:-)\r\nhttp://www.youtube.com/watch?v=Q09mPKTAI70',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(32284,1149,'un om','paul_bv@yahoo.com','','82.79.251.239','2008-07-02 11:35:58','2008-07-02 09:35:58','ai sÃ¢ rÄƒmÃ®i trÄƒsnit cÃ¢ o parti din cuvintili purtate mai adesea prin Moldova Ã®È™i au rÄƒdÄƒÈ™ini prin graiul aÈ™ela moÈ›Äƒiesc È™Ã® nu-s chiar grieu di Ã®nÈ›Äƒles\r\n\r\nda poate din cauzÄƒ cÄƒ io stau la mijloc È™i le-am prins pe ambele...',0,'1','Opera/9.50 (Windows NT 5.1; U; en)','',0,0),(29789,1135,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-06-17 11:02:00','2008-06-17 09:02:00','@ Hadean: Da! Tre\' sa meri inapoi sa le zici la alea \"baga-mi-as strumeleagul in toate prezervativele din farmacia voastra!!!\"',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(27831,1115,'julius constantinescu','julius@universitateacraiova.ro','http://www.7plus.ro/?arhiva=03/06/2008&#38;id=6499','84.232.162.192','2008-06-02 23:33:42','2008-06-02 21:33:42','Daca-mi ziceai acum cateva zile ca ai 8.000 de euro, cash, puteai deveni fara probleme cel mai bun prieten al meu. Da\', cum nu-i mai ai, mersi frumos: cunosc destui sarantoci, am de unde alege.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(29850,1136,'seliman','ionut.seliman@gmail.com','http://ionutu.wordpress.com','82.78.189.109','2008-06-17 16:19:01','2008-06-17 14:19:01','Io cÃ®nd eream la liceau ieram gecelist sau gcl-ist..adicÄƒ membru Ã®n Gruparea ColegialÄƒ LiberalÄƒ..adicÄƒ viitor pnl-ist. Da Ã®ntre timp am crescut. Åži pnl-ist nu m-am putut face cÄƒ prea aveam spirit de gcl-ist.. :D',0,'1','Opera/9.50 (Windows NT 5.1; U; en)','',0,0),(26026,1097,'de pe alta lume','totmea@yahoo.com','','92.82.51.34','2008-05-21 12:17:30','2008-05-21 10:17:30','fara nici o legatura. totusi. mah, estia de pe aici, ziceti repede terase si baruri, cluburi faine, de iesit seara in cluj. c\'-amu m-o luat un chef....nebun!!!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Zango 10.3.36.0)','',0,0),(26038,1094,'mo','verde_poveste@yahoo.com','','194.126.220.22','2008-05-21 14:06:52','2008-05-21 12:06:52','groparele, io am stat in doua case cu erdeesh, si vreau doar sa te avertizez sa nu iti pui decat daca e trasa tzava de sticla optica pana la resedinta ta, altfel mori cu modemu\' de gat de frustrare..... (asa cum fac io amu\', grrrrrrrrrrrrr )',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1)','',0,0),(26046,1095,'aaaaa','aaa@aa.com','','90.194.153.83','2008-05-21 15:00:58','2008-05-21 13:00:58','SUPER!!!  ce faina e fetita!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; en-GB; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(26044,1094,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-05-21 14:54:15','2008-05-21 12:54:15','Deci mo,\r\n\r\nMie imi mere OK, si il am de vreo 3 saptamani.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(26050,1097,'gb','getbordea@yahoo.com','http://getbordea.blogspot.com','208.77.165.40','2008-05-21 15:19:53','2008-05-21 13:19:53','Ce tragedie! Ma duc sa plang singura ca nu mai pot sa comand pui Sichuan...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(26053,1088,'pamfilie','pamfilie.moldovan@gmail.com','','87.255.64.202','2008-05-21 15:33:16','2008-05-21 13:33:16','Slava domnului ca ai pus poezia asta. M-ai lecuit de complexul inferioritatii :)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; FunWebProducts; InfoPath.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(22403,1066,'Andreea MKT','supergirgir@yahoo.com','http://marlahermina.deviantart.com/gallery/','82.77.126.254','2008-04-18 17:01:28','2008-04-18 15:01:28','ma, o fetita nu poa sa aiba 4 kile 80 de grame! o fetita are 3,2 kile, in nici un caz greutatea de pepene pe care ai scos-o tu! Draga de aimeea! puteau sa ii puie nume aimeea-andreea.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; InfoPath.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(24530,1083,'julius constantinescu','julius@universitateacraiova.ro','http://www.7plus.ro/?arhiva=06/05/2008&#38;id=5351','84.232.162.62','2008-05-06 09:59:02','2008-05-06 07:59:02','Spune-i lu\' Grauceanu (sau, cum spuneti voi la Cluj, la Grauceanu) ca-mi place cum gandeste. Stii vorba aia: decat mult si fara rost, mai bine putin si prost.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(28195,1117,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-06-05 11:17:24','2008-06-05 09:17:24',':))) Vezi ce idei bune avem impreuna?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(26017,1097,'george','reallyinsane@gmail.com','','193.138.195.202','2008-05-21 11:10:39','2008-05-21 09:10:39','Awesome!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9) Gecko/2008051206 Firefox/3.0','',0,0),(29893,1136,'Kissu @ catalin','','http://www.pacurar.net','79.116.70.125','2008-06-17 19:52:43','2008-06-17 17:52:43','Si sa nu uitam de faimosul CPUN... futu-i mama lui ! ;)))))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(27826,1109,'hadean','contact@adihadean.com','http://www.adihadean.com','79.113.57.11','2008-06-02 22:30:51','2008-06-02 20:30:51','CBR?BRRC?BM!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(23988,1081,'Emaginatoru','e_magistatyahoo.com','','79.116.84.89','2008-05-03 23:08:07','2008-05-03 21:08:07','Schimba subtitlul blogului.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(30452,1138,'Altar','teo.iorga@yahoo.com','','89.120.195.75','2008-06-20 08:20:46','2008-06-20 06:20:46','Mno, mo Groparele, io zic asa cu mintea mea ca tu esti cam masochist sau nu te-ai invatat minte inca si vrei sa pirzi si pedalele alea ce ti-au ramas rezerva de la bicicleta, si snuru` de la camera foto pierduta la Tiganiada, sa iti mai apara de platit inca doo credite in locu` aluia ce tocmai l-ai lichidat si sa fii si nevoit sa lucrezi la servici si/sau sa emigreze toate fecioarele cu tot cu tzatzele din dotare din Cluj in Canada.\r\nCe crezi tu ca se face primavara cu un post de paste?\r\nPlus ca sa stii si tu, eu nu vorbesc cu babele iar ala micu` al meu petrecea cam mult timp cu baietii.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(34177,1159,'idolatra','totmea@yahoo.com','','92.82.57.69','2008-07-21 09:50:09','2008-07-21 07:50:09','fa-ma D-ne musca!!!   :-D',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Zango 10.3.36.0)','',0,0),(30450,1138,'seliman','ionut.seliman@gmail.com','http://ionutu.wordpress.com','213.157.171.107','2008-06-20 07:58:32','2008-06-20 05:58:32','Mno..de lÄƒudat, te-am lÄƒudat ÅŸi io oÅ£Ã®r acolo..darÄƒ sÄƒ nu fie cu bÄƒnat.. ;)\r\nCÃ®t despre opservaÅ£ia lui Nox, chiar conteazÄƒ? Io sÄƒ fiu sincer, aici o vÄƒz pentru prima datÄƒ, poanta.',0,'1','Opera/9.27 (Windows NT 5.1; U; en)','',0,0),(26003,1096,'zgura','','','79.116.97.255','2008-05-21 08:18:15','2008-05-21 06:18:15','Daca ar bombarda in China ar fi si mult mai eficienti',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(27810,1109,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','79.116.97.20','2008-06-02 19:09:17','2008-06-02 17:09:17','@ Hadean: tu esti ala, mah, ala cu crieru\'! Ce, tu nu citesti ce fain scrii?\r\n\r\n@ gb: dap. Si sa vezi tu numa\' ce de bani am facut pana acuma de la trafic!\r\n\r\n@ Julius Mulius: Bueeey, mÄƒgÄƒriciule! Viatza mea insasi e o mormantare, asa cum vom vedea in cele ce urmeaza. Noroc cu bocitoarele mele, pentru care un ochelarist furios ca tine (care mi-i si drag, culmea!) nu poate decat sa ma invidiasca pana si-ar clantani toate plombele de la scrashnit, finca-s plombe din elea eftine, puse prin scoala generala &gt;:D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(27813,1109,'hadean','contact@adihadean.com','http://www.adihadean.com','79.113.57.11','2008-06-02 19:41:17','2008-06-02 17:41:17','ioi ce bei? da de mÃ¢ncat, ce mÄƒnÃ¢nci?:-)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(27822,1109,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','79.116.96.98','2008-06-02 21:51:16','2008-06-02 19:51:16','BR!!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(27824,1109,'Usim','Mihaimitan@gmail.com','','195.189.142.43','2008-06-02 22:22:25','2008-06-02 20:22:25','BR, BR numa\' RC sa fie!',0,'1','Opera/9.50 (J2ME/MIDP; Opera Mini/4.1.11355/514; U; en)','',0,0),(32361,1150,'alhambra','mihdana@yahoo.com','http://www.alhambra-bijoux.blogspot.com','89.120.204.80','2008-07-02 23:57:55','2008-07-02 21:57:55','numa tu puteai sa ai norocu asta, altuia i s-ar fi oprit dinainte fo rapciugoasa de mertzan cu negri de-ai nostri, auzi, costum, asta ai bagat-o sa uitam de lipicioasele tale :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(27829,1109,'Today&#8217;s 10 Blogoshpere Quickies : INconstantIN.ro','','http://inconstantin.ro/2008/06/03/todays-10-blogoshpere-quickies/','89.42.110.18','2008-06-02 23:07:28','2008-06-02 21:07:28','[...] Groparu nu muare, daâ€™ nici nu se preda Recomandat! [...]',0,'1','Incutio XML-RPC -- WordPress/2.5.1','pingback',0,0),(27833,1115,'Arhi','admin@arhiblog.com','http://www.arhiblog.com','79.117.63.21','2008-06-02 23:57:51','2008-06-02 21:57:51','ai naibii parliti:))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(33797,1157,'Lush','copilurau@yahoo.com','http://www.blogulucostel.blogspot.com','89.137.171.47','2008-07-18 00:32:44','2008-07-17 22:32:44','pai tu ai invatat-o l ascoala! aoleu!!! Si eu obisnuiam sa mananc acolo!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9) Gecko/2008052906 Firefox/3.0','',0,0),(23996,1081,'Groparu','groparu.ro@gmail.com','http://','89.137.109.142','2008-05-04 00:31:39','2008-05-03 22:31:39','Di cie, mah?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,2),(27838,1115,'Turambar','mirel@ccsb.ro','http://turambarr.blogspot.com','79.114.190.107','2008-06-03 01:23:11','2008-06-02 23:23:11','Noi pe moment nu avem nici un credit la banca, insa nu putem sa nu fim in asentimentul nobilelor idei exprimate atat de plastic si de retoric mai sus si sa nu dorim, impreuna cu o cohorta semnificativa de clienti asemenea noua, ca institutiile avute in vedere sa beneficieze periodic, cu o frecventa zilnica pe cat posibil, de o bogata infuzie brusca de lichid seminal proaspat, translucid, stralucitor si bogat in proteine.\r\n\r\nM-am exprimat destul de simplu sau mai trebuie sa mai repet inca o data din nou?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(22440,1060,'','','','89.41.209.30','2008-04-19 00:54:37','2008-04-18 22:54:37','Nu se pune virgula inainte de \"etc\". (doar in engleza)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(25926,1093,'Laura','mars1953@web.de','','84.160.115.226','2008-05-20 19:46:20','2008-05-20 17:46:20','Italienii aia platesc muncitoarele numa\' cu o mana de euro, ca barbatele lor nu se ocupa de italieni sa le plateasca mai mult, ci asteapta sa vina taticu\' de stat sa-i puna pe italieni la punct... da\' macar groparu are umpic de mila de muncitoare...',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(30355,1137,'Tudor Oarecare','tudor@inbox.com','','89.137.175.11','2008-06-19 20:43:45','2008-06-19 18:43:45','EÅŸti idolul meu. AÅŸa, ca fapt divers...',0,'1','Opera/9.50 (Windows NT 6.0; U; en)','',0,0),(24424,1082,'Dan','dan.2001@gmail.com','','86.121.134.30','2008-05-05 20:28:16','2008-05-05 18:28:16','Am ras, team pus la bookmark. Mai trece la socoteala un fan',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(30367,1137,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','79.116.97.209','2008-06-19 21:50:06','2008-06-19 19:50:06','Asa-i, dar deci: ne potolim?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(30368,1138,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','79.116.97.209','2008-06-19 21:51:35','2008-06-19 19:51:35','@ laudacii: deci ne potolim?\r\n\r\n@ Turambarr: m-o batut Dumnezo suficient cand o lasat sa mi se fure bicicleta:|',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(24435,1082,'WhiteWolf','laskmerge@gmail.com','http://white-wolf.ro','79.115.97.13','2008-05-05 21:14:29','2008-05-05 19:14:29','Zi-le la toti ca ereai plin de bere si presiunea la macsim cand ai zis de pikurat\r\nCa sa nu afle chiar tot nimeritul din greseala pe aici, din prima, cat ejti de blonav si incurabil.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(24443,1081,'andreea','dyadea@yahoo.com','http://andreeabotez.blogspot.com/','213.233.101.11','2008-05-05 21:53:19','2008-05-05 19:53:19','Am impresia ca femeia asta din tine e femeia din femeie pe care noi femeile nu vrem sa o recunoastem. Pun pariu cu orice femeie, pentru ca sunt femeie! :)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(25944,16,'JaneDoe','arietiss@yahoo.com','','86.125.180.61','2008-05-20 22:08:13','2008-05-20 20:08:13','hehe..inseamna ca e faina viata de camin :D ... fiind fata ma gandesc ca experientele nu sunt aceleasi ..din aceasta cauza oscilez intre camin si chirie.. :-s',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; SIMBAR={59B99702-1009-49f4-A496-1445C11C9DDF})','',0,0),(28178,1117,'Catzaua','ana.man.fox@gmail.com','http://catzaua.wordpress.com','213.233.101.135','2008-06-05 08:35:43','2008-06-05 06:35:43','ye, funny... sort of... numa\' vez\' ca data viitoare cand vii cu faze d\'astea niegre ca Copsa Mica s-ar putea sa o iau de buna. si te zvant in bataie. deci ne potolim si nu parasim incinta, da? :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(27854,1109,'josephine','fake@yahoo.com','','202.120.39.241','2008-06-03 06:33:08','2008-06-03 04:33:08','Ha ha, super! Deci te-ai dedublat si de fapt este totul ca un fel de Matrix, eu sunt tu, tu esti eu cand eu sunt la tine pe blog...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(27855,1115,'un om','paul_bv@yahoo.com','','82.79.251.239','2008-06-03 07:08:17','2008-06-03 05:08:17','muhaha... mie mi-or pus comision pe virarea salariului in contul curent...\r\nsi le-am zis ca schimb banca... si asa de mielusele s-or facut... vorba ceea cu recalcularea si asezonarea... daca-mi mai sustrag si luna asta o bere din salariu.... plec si-mi deschid banca mea singurel... in parc',0,'1','Opera/9.27 (Windows NT 5.1; U; en)','',0,0),(27902,1115,'hadean','contact@adihadean.com','http://www.adihadean.com','79.113.86.64','2008-06-03 19:00:30','2008-06-03 17:00:30','unde dracu (doamne iartÄƒ pliz) Ã®s zÃ¢lile Ã®n care puneai bani la cec cÄƒ altceva nu aveai ce face cu ei? \r\nno, oricum, bine cÄƒ ai rupt cÄƒtuÅŸele, tu porumbel al pÄƒcii financiare care eÅŸti. io mÃ¢ni dau o turÄƒ pÄƒ la tÄƒte bÄƒncile cu care am avut relaÅ£ii fÄƒrÄƒ prezervativ sÄƒ-mi anulez cardurile Ã®n plus cÄƒ alfel mÄƒ pomenesc Ã®ntr-o bunÄƒ zÃ¢uÄƒ cÄƒ nu mÄƒ pot Ã®ndatora din cauzÄƒ la o datorie de 0,3 euro pe care nu i-am avut pÄƒ un card cÃ¢nd m-am uitat sÄƒ mÄƒ asigur cÄƒ mi-am bÄƒut tÄƒÅ£ banii.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(24155,1081,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2008-05-04 19:27:57','2008-05-04 17:27:57','@ ics: nici io nu-l prea suport pe Groparu astalant: injura, bea, se bate... si mai e si tantalau si n-are timp de blog.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(32515,1151,'Roza','popescu.onita@yahoo.com','','79.117.161.112','2008-07-04 07:38:08','2008-07-04 05:38:08','Tat romanu\' e gheavol,da\' nu vrea sa recunoasca! :D',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(32386,1150,'Roza','popescu.onita@yahoo.com','','79.117.161.70','2008-07-03 05:49:24','2008-07-03 03:49:24','Faine ghiersuri...:)\r\nNo amu imi pare mie ca-s venite ghe pe o alta lume!\r\nParerea me si tin la e! :)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(32387,1150,'hadean','contact@adihadean.com','http://www.adihadean.com','79.113.87.77','2008-07-03 05:59:47','2008-07-03 03:59:47','da\'....\"hop te zsiga\" ai? (mÄƒ inervez mÄƒ cÄƒ tÄƒt pÄƒÅ£ÄƒÅŸti Ã®ntÃ¢mplÄƒri miÅŸteaux)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.15) Gecko/20080623 Firefox/2.0.0.15','',0,0),(27862,1115,'seliman','ionut.seliman@gmail.com','http://ionutu.wordpress.com','213.157.171.107','2008-06-03 09:01:38','2008-06-03 07:01:38','bancile e cu adevarat de porc! Io dupa ce le-am achitat un credit mi-au spus ca nu-mi pot lichida contul pana ce nu le platesc si vo 17 lei, nush ce comision. Am zis ca le crap capu\'.. da dupa aia mi-am zis ca tanti de la ghiseu, n-are nicio vina..asta e!',0,'1','Opera/9.27 (Windows NT 5.1; U; en)','',0,0),(27863,1115,'stiuta','totmea@yahoo.com','','89.123.75.30','2008-06-03 09:03:57','2008-06-03 07:03:57','divort standard: ea insista, \"mai incearca\", promite, se tanguie, se supara, se consoleaza (ca sint altii destui) - el impasibil si nesimtit, da muie, ca oricum are altele. ce facusi mah???? unde-i spectaculosul? nu ma asteptam de la tine   :-D',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; SIMBAR={3523AA32-EC48-4B99-902E-C5F036C0464E}; Zango 10.3.36.0)','',0,0),(22468,1060,'Groparu','groparu.ro@gmail.com','http://','89.137.109.142','2008-04-19 07:22:51','2008-04-19 05:22:51','Asa ie! Ca doara \"et\", in latina, insamna tot si! \r\n\r\nDar limba romana m-a rugat pe mine in mod special sa o violez.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,2),(33832,1157,'alienatu','contact@alienatu.com','','89.123.136.30','2008-07-18 09:09:00','2008-07-18 07:09:00','Groparu - \"AÅŸa cÄƒ d-ra pleacÄƒ, ÅŸi revine cu altÄƒ zamÄƒ, cred.\"\r\n\r\nmo - \"Iti dai seama cat de norocos ai fost ca ai vazut extragerea in direct, facuta cu o lingura de plastic?\"\r\n\r\ndeci mda.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9) Gecko/2008052906 Firefox/3.0','',0,0),(33830,1158,'Ovi','ovidiu@sirb.net','http://sirb.net','89.35.223.105','2008-07-18 08:59:23','2008-07-18 06:59:23','O mica notÄƒ: decolteul acela se numeÅŸte, popular, vangÄƒ sau linia vieÅ£ii.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.9.0.1) Gecko/2008070208 Firefox/3.0.1','',0,0),(33831,1158,'cezar','cezariordache@gmail.com','http://www.cezars.info','82.137.53.187','2008-07-18 09:06:30','2008-07-18 07:06:30','Bai...mor ce civilizatie e la voi.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.9) Gecko/2008052906 Firefox/3.0','',0,0),(33843,1158,'clujeana','totmea@yahoo.com','','92.82.63.29','2008-07-18 10:47:52','2008-07-18 08:47:52','da-ne si noua numarul lui parintele lui Tibby.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Zango 10.3.36.0)','',0,0),(32399,1150,'mirra','jo75free@yahoo.com','','213.233.101.224','2008-07-03 09:17:29','2008-07-03 07:17:29',':)No comment!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.15) Gecko/20080623 Firefox/2.0.0.15','',0,0),(24049,1081,'ics','i_uana@yahoo.com','','86.126.99.7','2008-05-04 09:10:28','2008-05-04 07:10:28','Pentru ca era mai fain alalt, Gropare, asta vroia sa spuna domnu\' .',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(32404,1149,'Sagi','mail@constantablog.net','http://www.2creative.ro','62.231.95.98','2008-07-03 09:53:23','2008-07-03 07:53:23','Da io-s mai is curios cum injura ardelenii in engleza :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.15) Gecko/20080623 Firefox/2.0.0.15','',0,0),(33839,1158,'nebuloasa','nebuloasablonda@yahoo.com','http://nebuloasa.wordpress.com/','193.194.130.37','2008-07-18 10:16:24','2008-07-18 08:16:24','no ce fain..io n-am baia 100% functionala tocmai pentru la la timisoara instalatorii fac exact asa cum se stie :D',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727)','',0,0),(33840,1157,'Andreea','puistrulet2003@yahoo.com','http://n/a','81.196.150.196','2008-07-18 10:33:13','2008-07-18 08:33:13','Deci io daca eram in locul tau faceam f urat....deci putea sa vina cu lingura de aur la mine si tot o faceam albie de porci...Si cand te gandesti ca Moima Plangatoare e vazut drept un restaurant destul de scumput... (4 musculite a la Bursucu Gastric a  lui Catavencu)... Hmm...inca asa nu am patit ...Dar am patit-o la Athena la terasa cand la o prietena i-a adus un Garrone cu sare(stiu e penal ca fac chestia aia cu gura paharului plina de zahar, mie personal nu-mi place) si biata fata a baut ...S-a prins numai la a 3 -a inghititura :))); deci daca mergeti acolo aveti grija ce anume cereti...sa n-aveti suprize...\r\nA',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.16) Gecko/20080702 Firefox/2.0.0.16','',0,0),(27867,1115,'V_for_Whatever','stephanovendetta@yahoo.com','','89.136.50.177','2008-06-03 10:09:58','2008-06-03 08:09:58','Ask, and it shall be given you; seek; and you shall find; knock and it shall be opened unto you and kick you in the balls. For every one that asketh receiveth; and he that seeketh findeth; and to him that knocketh, he shall be sore, but it will be opened... for it is hard for thee to kick against the pricks. And in a bad hair day, God created Credit.  (C.P, art. 205, paragraph 1-4)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; .NET CLR 2.0.50727; InfoPath.2)','',0,0),(27865,1109,'Altar','stefan_grebla@yahoo.com','','89.120.195.75','2008-06-03 09:22:51','2008-06-03 07:22:51','Mah, io tot nu am inteles, tricourile ude sunt pe trupuri de fecioare gingase sau de baicari parosi?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(27873,1115,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-06-03 11:40:48','2008-06-03 09:40:48','Trebia sa-i zici in cea mai pura frantuzeasca pe care o cunosc, ca odata am si citit o carte in franceza intreaga: vafanculo!!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(27869,1115,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-06-03 11:03:28','2008-06-03 09:03:28','=))\r\ntareeeee!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(28131,1115,'gadjodillo','gajadilla@yahoo.com','http://gadjodillo.wordpress.com','86.105.71.22','2008-06-04 23:57:18','2008-06-04 21:57:18','Din commenturi deduc eu ca lucrul cu bancile e o chestiune individuala: ca nu exista regula, nici de comision si probabil, nici de dobinda. Si daca stau bine sa ma gindesc, am si eu o povestioara, da\' dintr-o vreme cind erau putine banci si mult mai rigide ca acum. aproape frigide, I might add.\r\nBagasem eu, cu ceva lacomie pentru dobinda, niste bani la banca, da\' direct pe trei luni. Pe atunci dobinzile erau mai mari decit cresterea din imobiliare. Si m-am trezit dupa o luna ca-mi trebe banii, ca-mi iesise cadastrul pentru o tranzactie. M-am dus frumusel la banca... m-am gindit... si le-am scris o scrisorica. asa, de mina. Le propuneam un tirg: sa le mai dau eu timp de vreo doua saptamini-o luna o suma dubla decit aia din banca, fara pretentii la dobinda, iar cind ii scot pe toti, sa nu-mi taie dobinda pentru primii bani (in mod normal, as fi primit pe ei dobinda ca pentru cont \"la vedere\", nu ca pentru \"depozit\". Au acceptat!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12','',0,0),(25952,1095,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','79.116.96.102','2008-05-20 23:03:40','2008-05-20 21:03:40','Deci mo, cata vreme Sorinelu nu trimite buzduganu din Japan (ca acolo adasteaza el acuma) intru pedepsirea Groparelui, Äƒsta, prostu\' (ca-l stiu) ui ca-si permite sa scrie tot felu\' despre oameni respectabili!\r\n\r\nNush pe voi, da\' pe mine asa ma nerveaza, mah...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(33859,1158,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-07-18 14:18:42','2008-07-18 12:18:42','Cata vreme e cur de dama, fac orice!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.16) Gecko/20080702 Firefox/2.0.0.16','',0,0),(27930,81,'Andrei C','arckpi@yahoo.com','http://aercek.blogspot.com/','141.85.0.116','2008-06-03 22:53:57','2008-06-03 20:53:57','Fain tare si textul asta.',0,'1','Opera/9.25 (Windows NT 5.1; U; en)','',0,0),(25738,1092,'Retoric','acalarasu@gmail.com','http://adriancalarasu.wordpress.com','80.96.53.9','2008-05-19 13:30:04','2008-05-19 11:30:04','Gropare, mai lasa petrecerile si vino la Bucuresti urgent!\r\nA venit Demi Moore, ma!!!',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(24085,1081,'PhenoBarbieDoll','oana.gavrila@mediafax.ro','http://phenobarbiedoll.blogspot.com','193.230.230.101','2008-05-04 13:26:19','2008-05-04 11:26:19','Pai noah, ui\', pentru cand iti schimbi supttitlul, propun \"Nobody knows I\'m a lesbian\".',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(27919,1115,'Andrei C','arckpi@yahoo.com','http://aercek.blogspot.com/','141.85.0.116','2008-06-03 21:58:55','2008-06-03 19:58:55',':)) Fain, fain!',0,'1','Opera/9.25 (Windows NT 5.1; U; en)','',0,0),(25751,1092,'VÄƒraru','spargvaluri@yahoo.com','http://www.vararu.ro','79.119.221.183','2008-05-19 15:51:57','2008-05-19 13:51:57','Ä‚la Ã®n care rromul Ã®l pÄƒcÄƒleÅŸte pe ÅŸÄƒfu\' romÃ¢n Ã®l ÅŸtii?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(27871,1115,'Andreea','puistrulet2003@yahoo.com','http://n/a','81.196.150.196','2008-06-03 11:19:08','2008-06-03 09:19:08','Raurate ce esti ... :) \r\nAi ce ai cu bietele functionare... :))\r\n\r\nNici nu vreau sa ma gandesc cat sughita ele de cand le tot pomenesti...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(27872,1115,'dislecsiliaq','dislecsiliaq@gmail.com','','82.232.236.132','2008-06-03 11:33:36','2008-06-03 09:33:36','bancile e la fel, ele , in sinea lor, peste tat! \r\n\r\nadicatelea, io aicea pe meleaguri frantzuzesti, proaspat iesita din incubatoru\' universitar, muncesc pe catziva euro. ei e putini euro astia, ca sunt doar in internship.\r\n\r\nnoa, si salariu\' mi-l da nenea shafu direct in frumos cont (si de obicei cam gol) frantzuzesc. numa\' ca, o capiat banca, i s-o stricat sistemu\' de racire o ceva si ii supraincalzita, ca nu-mi mai merge cardu\'. da io bani de-o bagheta si o branza imputzita am in cont. \r\n\r\nzic io buuun, lasa ca-mi iau io rendez-vous la banca sa vad care-i treaba. doar ca am asteptat o saptamana ca primesc confirmarea. intre timp zic merg sa scot cash din cont, sa aiba si eu ce sa manca. la banca ma prezint eu cu buletinu\', pasaportu\' si carrdul de membru al miscarii de integrare spirituala in absolut. se uita madmoazela la ele, zice ca nu e bune ca imi trebe cec. (?!?)\r\n\r\nio: da io-s, ni madmoazel! si zic, scot si fake ID-urile, ca poate o conving cu alea.\r\n\r\nmadmoazel: non,non! c\'est pas possible! tre\' sa-ti scrii tu tie un cec!\r\n\r\nio:sa-mi scriu io mie un cec ca sa scor bani cash din propriu-mi cont, bani muncitz (saua sa ceva) de propria-mi persoana?\r\n\r\nmadmoazel insista ca asa se face.\r\n\r\nio zic, da\' nu mai am cecuri, in cat timp pot avea un carnet de cec nou? \r\n\r\nmadmoazel: aaa, pai cel mai devreme in zece zile.\r\n\r\nio: si pana atuncj io ce fac? n-o s amai am nij tigari pana atuncjea..\r\n\r\nmadmoazel: nous sommes dÃ©solÃ©s...\r\n\r\napai si io-s dezolata si subscriu urarii groparului catre banci. catre toate bancile din lumea asta!!!!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; fr; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(33858,1158,'eu','ripahoratiu@yahoo.com','','81.196.156.83','2008-07-18 14:08:31','2008-07-18 12:08:31','Bah campeonule, tu ai o problema cu decolteu\' ala... Cre\'ca ce te deranjeaza cu adevarat nu e pur si simplu faptul ca-l vezi ci ca e plin de celulita si cosuri si nu se potriveste cu gustu tau pentru c...uri, pentru ca se stie, Groparu face si asta. :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.16) Gecko/20080702 Firefox/2.0.0.16','',0,0),(33856,1157,'eu','ripahoratiu@yahoo.com','','81.196.156.83','2008-07-18 14:02:31','2008-07-18 12:02:31','1. Io cre\'ca era tot zama aia, da\' cu musca estrasa dupa coltz si-un scuipat in plus.\r\n2. Esti un nemernic si-un sovin ca ai vazt ca musca era verde si repede, repede, te iei de unguri cu tot felu\' de mesaje subliminale.\r\n3. Da\' l-ai intrebat prima data pe englez sau ce stiu io ce alta natie, daca nu-i place cu musca? Poate la ei asa e traditional... Sau la noi o fi traditional?\r\n4. Bah, la egiptzieni scarabeii e animale sfincte, aia nu-l invata pe scarabei sa inoate in supa ci ia culcat cand apare, da cu ABS-u la masina cand traverseaza strada s-alte cestii. Daca venea careva cu scarabeu\' plutind prin zama, il mancau pe chelner si pe bucatar, si din ce ramanea puneau de-o piramida cu mumiile aferente, c-asa e la ei....',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.16) Gecko/20080702 Firefox/2.0.0.16','',0,0),(27924,1115,'Jorjet','httpgetbordea.blogspot.com','','86.121.196.43','2008-06-03 22:26:42','2008-06-03 20:26:42','Gropare, tu ori ai beut atÃ¢ta la Å¢iganiadÄƒ cÄƒ nici nu mai Å£ii minte cum te-ai distrat, ori a plouat aÅŸa de mult cÄƒ numa ai stat Ã®n cort ÅŸi te-ai gÃ¢ndit cum sÄƒ molestezi bÄƒnci!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(27884,1115,'Elisa','','','92.81.35.101','2008-06-03 14:22:12','2008-06-03 12:22:12','Nu stiu cum is bancile din alte lumi da stiu cum is astea de pe la noi,autohtone,ca dupa 90,na...o venit si la buticu din colt cuptoare cu microway si era o nimica toata avansul,rata tot asa,iar eu nestiutoare in ale bancilor zic...hop,ca bine zice sora mea...de ce nu-ti imbunatatesti tu viata??asa zicea ea.\r\nSi iau cuptorul si dupa vo cateva rate,constat ca ce zic ei pe foaia aia de mi-o dadea napoi sa stiu cat mai am de dat,nu coincide cu ce zic eu,care calculasem acasa.Si ma iau si ma duc la banca si ma prezint la inspectoru,tot o ea ...si-mi zice sa revin,ca trebuie sa verifice.Na bine tu,gandi eu,ce-o fi asa de greu cu compu,sa verifici??!!de nu poti pe loc!!\r\nConcluzia e ca ei imi pusesera 2 rate in plus si o zis ca-i pare rau,dar o sa rectifice,la care eu i-am spus sa nu se mai oboseasca ,ca achit tot acum.Si asa am facut si de atunci n-am mai luat in rate nimica.Cu banii jos,ca nu i-am gasit.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(32433,1150,'Usim','mihaimitan@gmail.com','','87.237.108.33','2008-07-03 14:53:12','2008-07-03 12:53:12','Da\' neste peripetii de la ocazie spre Bucuresti cand ne vei povesti? Ca de asta toamna tot promiti ca bem!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648)','',0,0),(32434,1150,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-07-03 14:59:15','2008-07-03 12:59:15','Ioi, Usime, deci iti jur ca vin la Bucale si te pun sa ma cazezi!\r\n\r\nBerea io o dau, aia-i clar, sa nu falimenteze onor gazdele mele viitoare, din domeniul bancar actual.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.15) Gecko/20080623 Firefox/2.0.0.15','',0,0),(32442,1150,'Usim','mihaimitan@gmail.com','','87.237.108.33','2008-07-03 16:58:40','2008-07-03 14:58:40','Gazare asigurata, of cos! Ol inclusiv, ca doara altfel nu ma bagam in seama!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648)','',0,0),(27891,1115,'Dax','xadlove@yahoo.com','','195.212.29.187','2008-06-03 17:00:30','2008-06-03 15:00:30','Daca te linisteste cu ceva: in Cehia bancile sunt much much worst decat in romania, stiu ca suna a Blasfemie !!! dar e 100 % corect ce iti zic , am luat credit(sa imi acopar gaurile)  in ordine pentru : baut, curvalit, euro2008 si urmatorul nu stiu pt ce draq loi lua dar sigur pentru un scop nobil.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4','',0,0),(27897,1109,'PhenoBarbieDoll','oana.gavrila@mediafax.ro','','86.120.236.133','2008-06-03 18:05:16','2008-06-03 16:05:16','Re:PS: Cum zicea prekinu nostru comun si irlanghez: \"I never travel without my diary. One should always have something sensational to read on the train!\"',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1)','',0,0),(24149,1079,'io','io@io.com','http://io.com','89.123.114.46','2008-05-04 19:10:55','2008-05-04 17:10:55','a-nviat ?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(30122,1137,'seliman','ionut.seliman@gmail.com','http://ionutu.wordpress.com','82.78.189.109','2008-06-18 19:47:11','2008-06-18 17:47:11','De acord cu tine. Io cred ca am si adormit la jumatatea celei de-a dooa reprize.',0,'1','Opera/9.50 (Windows NT 5.1; U; en)','',0,0),(30325,1137,'mizeria_inumana','adi_coaja@yahoo.com','http://mizeriainumana.blogspot.com/','89.38.155.199','2008-06-19 16:22:12','2008-06-19 14:22:12','Frate... da pe tine te-a marcat rau scoru asta... Lasa ca mai ne calificam si peste vreo 8 ani, si atunci sa vezi daca-ti mai permiti suparari... ca la ce boli de inima o sa avem...',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; Maxthon; .NET CLR 2.0.50727)','',0,0),(32458,1151,'seliman','ionut.seliman@gmail.com','http://ionutu.wordpress.com','82.78.189.109','2008-07-03 20:55:01','2008-07-03 18:55:01','Mno, apoi aÅŸa-i romÃ®nu: gazdÄƒ primitoare ÅŸi veselÄƒ, sau nemesisu\' sÄƒu numit de alÅ£ii, pe bune dreptate, ÅŸi curvÄƒ. AdicÄƒ romÃ®nu\' ÅŸtie sÄƒ fie ÅŸi curvÄƒ. DacÄƒ tu ereai curvÄƒ cu ei ÅŸi c-o mÃ®nÄƒ Ã®i omeneai ÅŸi cu alt(ele)a le furai bujiile la Citroen sau bemolu\' de la instrumente, oare te gÄƒzduiau la ei la Hamsterdam? :D',0,'1','Opera/9.50 (Windows NT 5.1; U; en)','',0,0),(32463,1151,'Usim','mihaimitan@gmail.com','','87.237.108.33','2008-07-03 21:43:42','2008-07-03 19:43:42','Mai lasa-i in colo de olandejii ingrati Gropare si zi-mi cand sa te astept in gara/aerogara/autogara/portu\' Tomis din Herastrau. \r\n\r\nAmu\' daca vii cu ocazia, cre\'ca asteptatu-n aerogara cade.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648)','',0,0),(32477,1151,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','79.116.97.49','2008-07-04 01:07:53','2008-07-03 23:07:53','@ Seliman: ezac! asta o sa aflu dupa ce voi da coltzu\' - posibil f. curand :D ca-n ritmu asta... \r\n\r\n@ Usim: tre\' sa-mi ieu carnetu, si pt asta am de vb cu jde clienti carora le trebe traduceri de azi pe ieri. Da\' o rezo\' noi cunva! Suntem rumani, or what???\r\n\r\n@ Turambarr: dupe cum am mai zis, si daca nu am mai zis, ma repet, tu o sa ai ban pe saitu asta, finca ej mai dajtept ca mine. Si io, asta, deci virgula, nu toleresc!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.15) Gecko/20080623 Firefox/2.0.0.15','',0,0),(32471,1151,'Turambar','mirel@ccsb.ro','http://turambarr.blogspot.com','79.114.190.67','2008-07-03 23:36:47','2008-07-03 21:36:47','La naiba cu olandezii sburatori. Eu ce am retzinut din propozitzie este ca nu ai succes la femei. \r\n\r\nDintr\'o data, cazut din sfera divina, eshti uman. Eshti de\'al meu. Suntem de\'o seama si\'o simtzire. Prietene! Da sa te pup! Tzoc tzoc. Si\'nc\'o data: tzoc tzoc tzoc tzoc. Ca rushii, cu patima. Hai sa bem... Sa bem! Sa uitam!\r\n\r\nPa dracu. De unde sa beau, cand eu sunt pe Ampicilina, cu o gaura intr-o masea cat casa, cu sticla de Laphroaig care se uita dojenitor la mine de pe masa, ca nu am mai bagat-o in seama de doo seri?\r\n\r\nLife is a bitch and then we meet beautiful inaccessible women :(',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9) Gecko/2008052906 Firefox/3.0','',0,0),(24206,35,'Dan','dan.2001@gmail.com','','86.121.134.73','2008-05-04 23:29:52','2008-05-04 21:29:52','La mine e 12:29...la fel..fara adjective. \r\nUltimul paragraf m-a lovit pe neasteptate.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(27945,1115,'Usim','mihaimitan@gmail.com','','87.237.108.33','2008-06-04 01:01:23','2008-06-03 23:01:23','Gresesti foarte mult Gropare sa te exprimi in halul asta!\r\n\r\n\r\n\r\n\r\n\r\nCorect este: \"MUIE bancilor\" si nu \"Muie la banci\". :-)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648)','',0,0),(30129,1137,'Kissu','','http://www.pacurar.net','79.116.70.125','2008-06-18 20:28:45','2008-06-18 18:28:45','\"...si te ia la cafteala pe tine si pe copiii vostri, futu-ti gura matii de proasta, cu cine m-am insurat io. Daâ€™ am zis ca las adulteÅ£ea sÄƒ Ã®l Ã®nveÅ£e asemenea mistere.\r\n\r\nOricum, sunteti de acord cu mine ca a fost un meci de toata **** (nu voi fi mai explicit, finca mi-am propus, in plm, sa nu mai injur pe blog)\"\r\n\r\n=))))))))))))))) Eshti tare!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.9) Gecko/2008052906 Firefox/3.0','',0,0),(33889,1154,'mishu','mishu@doingtheartwork.com','http://www.doingtheartwork.com','92.82.35.147','2008-07-18 23:13:55','2008-07-18 21:13:55','add si prodan, dragilor, va doresc decat tot binele din lume cu un singur amendament (e pacat, stiu, dar Dumnezeu e mare si iarta): sa va luati mashina noua si sa v-o zgarie unu ca sa isi faca loc sa treaca cate 3 unul pe langa altul pe trotuar nu numai doi. Va pup cu ranga.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; .NET CLR 2.0.50727)','',0,0),(33890,1154,'mishu','mishu@doingtheartwork.com','http://www.doingtheartwork.com','92.82.35.147','2008-07-18 23:14:58','2008-07-18 21:14:58','si mai e ceva! Bag pula in Boc si locurile lui de parcare special amenajate lipsa pe strada Pitesti',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; .NET CLR 2.0.50727)','',0,0),(33891,1154,'mishu','mishu@doingtheartwork.com','http://www.doingtheartwork.com','92.82.35.147','2008-07-18 23:16:11','2008-07-18 21:16:11','si inca ceva! mergeti voi cu bicicleta! ui ca lui groparu i-o furat-o cu tot cu alarma si inchiderea centralizata. am zis!',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; .NET CLR 2.0.50727)','',0,0),(22540,1060,'Turambar','mirel@ccsb.ro','http://turambarr.blogspot.com','79.114.190.23','2008-04-19 23:41:28','2008-04-19 21:41:28','Astemptam gang rape-ul cu virgula dintre subect si predicat. Pana atunci, si deoarece e nevoie de o virgula uneori inainte de si, sa punem capat acestei sfarcuieli. \r\n\r\nE un fals neadevarat. Vrem sa vedem dovada. Arata sfarcu. Te sfidam, virgula, si, sa ne, virgula si, aratzi, sfarcu.\r\n\r\nVirgula, si.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(32481,1151,'Turambar','mirel@ccsb.ro','http://turambarr.blogspot.com','79.114.190.67','2008-07-04 01:37:55','2008-07-03 23:37:55','Aha. Gata. Am intzeles: vrei sa-mi dai un ban pentru ca\'s mai dajtept dacat tine. Aha. Gata. Logic. Mi se pare normal: inteligentza se plateshte. Un leu doi lei. Trei tigri. Patru capre. \r\n\r\nPlatesti pe post sau pe numar de cuvinte?\r\n\r\nAaaaargh! Sunt dajtept shi lumea ma plateshte pentru asta. Ce cool sunt ursul...\r\n\r\n:)  :)  :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9) Gecko/2008052906 Firefox/3.0','',0,0),(33928,1158,'Blogosfera Gateste','blogosferagateste@yahoo.com','http://blogosferagateste.wordpress.com','89.137.58.105','2008-07-19 07:21:09','2008-07-19 05:21:09','Nu e Cluuuuuuujul de vina ca ai tu pile la instalatori. :) :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.9) Gecko/2008052906 Firefox/2.0.0.14;MEGAUPLOAD 1.0','',0,0),(25908,1093,'un fan','unfan@maimultifani.ro','http://n-am','79.116.73.184','2008-05-20 17:43:07','2008-05-20 15:43:07','Nu prea scriam pe forum decat foarte rar dar citeam cam tot ce se discuta pe acolo. Vroiam doar sa-ti transmit (in ca ca esti tu) un gand de bine care sper sa-ti pice bine. Cien credea ca imi voi putea exprima sentimentele pentru tine (daca esti tu) in curte la groparu\'?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.9) Gecko/2008051206 Firefox/3.0','',0,0),(25862,1093,'Andrei Crivat','andrei@andreicrivat.ro','http://www.andreicrivat.ro','89.137.83.141','2008-05-20 11:52:21','2008-05-20 09:52:21','cum bre duamna sa vin cu tine la concert, cand io munceam pe plaiuri tgmuresene la gratare si cate si mai cate beri ? a ?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.9b4) Gecko/2008030714 Firefox/3.0b4','',0,0),(28026,1117,'ameÅ£itul','','http://ametzitul.wordpress.com/','82.76.123.238','2008-06-04 12:02:29','2008-06-04 10:02:29','inspirat din viaÅ£a realÄƒ, sau banc?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(28027,1117,'kittynel','kittynel@gmail.com','','213.208.242.81','2008-06-04 12:03:53','2008-06-04 10:03:53','NOT FUNNY!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9) Gecko/2008051206 Firefox/3.0','',0,0),(28028,1117,'oedip','oedip74@gmail.com','http://oedip.blogspot.com','89.137.99.163','2008-06-04 12:06:14','2008-06-04 10:06:14','bah, tu vb serios? ce pana mea-i patit iar?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(32552,1149,'eu','ripahoratiu@yahoo.com','','81.196.156.83','2008-07-04 14:13:32','2008-07-04 12:13:32','Noa, amu\' sa nu-ti fuck your mother\'s gati.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.15) Gecko/20080623 Firefox/2.0.0.15','',0,0),(28040,1117,'hadean','contact@adihadean.com','http://www.adihadean.com','86.125.34.195','2008-06-04 13:11:07','2008-06-04 11:11:07','io m-am prins cÄƒ-i banc pÃ¢ntru cÄƒ ÅŸtiu cÄƒ smurdu nu duce oamini la spitalu de zuzi:-) nici pÄƒ jos nici cu elicopteru. no, amu m-am rÃ¢s, oricum.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(25851,1093,'andreanum','andreanum@andreanum.org','http://andreanum.org','217.10.208.22','2008-05-20 09:59:56','2008-05-20 07:59:56','are pe dracu intelect. Nu de la intelect era, privirea mea langurasa era asa de la curentul din tren, care a facut sa-mi infloreasca genele si sa mi se injecteze ochii, ca si cum as fi venit dupa un lung efort intelectual. Nu estem cazul. Ba eu am ris la glumele groparesti si chiar mi-a placut cu voi, mai ales ca aveam doar 70 de lei la mine si am mincat de 90 si nimeni nu s-a suparat :D\r\nDa n-ati venit la concert la mine, desi va pastrasem invitatii si niste beri gratis, ca sa-mi fac loc in nobilimea clujeana. Da las ca vin din nou in august si fac io cinste cu niste pastravi la gilau.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9) Gecko/2008051206 Firefox/3.0','',0,0),(32529,1151,'Cristian Ungur','cristian.ungur@utopium.ro','http://cristianungur.blogspot.com','85.186.103.54','2008-07-04 10:54:52','2008-07-04 08:54:52','Tulai faina muzica. Si faina si viata asta de trubadur. A lor, adica, nu a me ca io tastez amu.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(30279,1137,'Elisa','elivasu@yahoo.com.au','http://elisagradinameadevis.blogspot.com/','92.81.138.58','2008-06-19 10:25:05','2008-06-19 08:25:05','Si eu am auzit de la cineva care este acolo ,la ei si zice ca beau ca porcii pana se ...pe ei.Ma rog,au si ei loazele lor...sa nu generalizam,ca nici eu nu fac parte dintre ....manelisti   :lol:',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(24301,1032,'iulianuss','realvision@k.ro','','193.231.107.209','2008-05-05 10:27:41','2008-05-05 08:27:41','Aceste lucruri trebe sÄƒ se Ã®nceteze!\r\nspermatozoizi = porno, ce mai coace-colo!\r\nNici io nu mai poci sÄƒ citesc la serviciu pencÄƒ pensionabilii lui peÅŸte zice cÄƒ mÄƒ uit la prostii...',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(25894,1094,'10MBC','alin.banc@gmail.com','','86.122.9.207','2008-05-20 15:34:45','2008-05-20 13:34:45','FYI: aa, daca iti pica netu... un router normal tzine cam 5 minute pana se reconecteaza. Asta, da, ai dreptate, fara downtime.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(28076,1117,'WhiteWolf','laskmerge@gmail.com','http://white-wolf.ro','79.118.187.156','2008-06-04 15:55:07','2008-06-04 13:55:07','Gropare, daca tu te-ai ras, zau, restu\' chiar nu conteaza.\r\nDa\' nu-l mai supara pe omu\' ala cu Crivatz(u) ca te sare de la papa bun cand nu te astepti :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(25870,1093,'andreanum','andreanum@andreanum.org','http://andreanum.org','217.10.208.22','2008-05-20 12:17:40','2008-05-20 10:17:40','nu tu, frac-tu gropar, ca el parea mai insetat :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9) Gecko/2008051206 Firefox/3.0','',0,0),(25893,1094,'10MBC','alin.banc@gmail.com','','86.122.9.207','2008-05-20 15:33:04','2008-05-20 13:33:04','Cablu- UPC e ok la tv analogic, nu are dighital inca. Digi mere cand ii vreme faina afara si mere bine. cand nu... poti sa uiti. Domnii de la DIGI o venit acasa mi-o intors antena pe toate partile si .. esec technic pentru ca nu au suport sa o bage cum trebe pa pozitie.\r\n\r\nInternet- o sa primesti prima veste buna--- PPPOE de la rds (daca ai router o sa fie ok, daca nu.. TZAPA) vezi ca nu mere cu orice router. UPC, aa, OK\r\n\r\nTelefon? o mare **ba trista si pentru rdsh si pentru upc. pe cand ti se incalzeste linia mai bine incep delay-urile de-ti vine sa-ti bagi ... nu conteaza. treaba valabila si la rdsh si la upc.\r\nGroparule... Suceesuri',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(24306,1082,'WhiteWolf','laskmerge@gmail.com','http://white-wolf.ro','79.115.97.21','2008-05-05 10:37:38','2008-05-05 08:37:38','Imi place ca ejti din ce in ce mai implicat si angajat in alea mari si grele ale lumii si televiziunilor fara exces de publicitate. \r\nSi mai imi placa ca , singur, asa, de nebun si cu propriu-ti (ce de al shaselea ) simt te cam prinzi cum vine chestiunea in cea mai de baza celula a societatii.\r\nChip ap zÃ£ gud uork.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(32551,1148,'eu','ripahoratiu@yahoo.com','','81.196.156.83','2008-07-04 14:05:20','2008-07-04 12:05:20','Io am luat amenda dupa cum urmeaza:\r\nFac io dreapta aiurea, ca de-aia sunt semne, sa nu ma uit io la ele. Politaiu ma trage pe-o rana si zice: \"Buna ziua, gradu si numele, ati cotit-o si n-aveati voie. Actele va rog\". Io ca un bastinas de Cluj ce sunt i-am zis: \"Dom\'le, am gresit, platesc asta e. Da\' actele nu sunt la mine, ca le-am uitat acasa.\"\r\n\"Aoleu, zice politistu\', pai daca le adun pe toate se fac fo 6-7 milioane.\" Acu\' calculati si voi cate beri eram gata sa dau statului, deci m-am inverzit pe buna dreptate. \"Da\' hai ca facem sa fie bine, va dau amendez numa pentru parcare aiurea + ca n-avet buletin, ca aia e numa un milion jumate si 2 puncte, zice el\". Case closed. Nu mai sunt nici politaii ce-au fost ... Sau li s-o trage de la Cluj?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.15) Gecko/20080623 Firefox/2.0.0.15','',0,0),(28034,1117,'Andrei Crivat','andrei@andreicrivat.ro','http://www.andreicrivat.ro','89.137.83.141','2008-06-04 12:38:03','2008-06-04 10:38:03','@seliman: da\' daca te ia deltaplanu\' SMURD-ului, ti se mai pare amuzant ? :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.9) Gecko/2008051206 Firefox/3.0','',0,0);
INSERT INTO `wp_comments` VALUES (32544,1151,'seliman','ionut.seliman@gmail.com','http://ionutu.wordpress.com','213.157.171.107','2008-07-04 13:10:12','2008-07-04 11:10:12','Da\' poa\' sÄƒ zicÄƒ ÅŸi placa cu plecatu\'n lume ca Jeg ÅŸi atuncea ajunge pe de\'a moaca Ã®n HerÄƒstrÄƒu cu ocolire prin Vama Veche via portu\' Tomis cu Ã®ntoarcere prin Odessa ÅŸi staÅ£ionare Ã®n Pipera..baÅŸca mai primeÅŸte ÅŸi bani ca dariusu :D',0,'1','Opera/9.27 (Windows NT 5.1; U; en)','',0,0),(30292,1137,'Andreea','puistrulet2003@yahoo.com','http://n/a','81.196.150.196','2008-06-19 11:30:01','2008-06-19 09:30:01','Cum se face ca suntem campioni la a imita pe altii, dar numa nu reusim sa imitam si chestia asta care se cheama....stai ca-mi scapa.......ah da... civilizatie!!!! :))\r\n\r\nio am primit pe mail niste filmulete cu \"cum ar fi trebuit sa joace olandezii ca noi sa castigam\"..si era o faza cu unu care is dadea singur cu mingea in cap :))) aia o fost beton si exemplifica perfect ceea ce noi refuzam sa acceptam: ca suntem doar niste amatori...si numai in fata retardatilor am avea ceva sanse sa parem cat de cat ok; trist este ca pe langa ca suntem puturos de prosti (sorry da asta-i adevarul) mai suntem si fuduli (uite-asa se umfla orezu\'n noi daca faceam 0-0 cu Olanda- pui pariu :)))\r\n\r\nUra si la taiat frunze la caini, A.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(25845,1093,'WhiteWolf','laskmerge@gmail.com','http://white-wolf.ro','79.115.97.11','2008-05-20 08:57:33','2008-05-20 06:57:33','\"...ea are mult intelect, de care se foloseste fara scrupule....\"\r\n<b>Asta-i cum ? De bine sau de rau ?</b> :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(24284,1082,'hadean','contact@adihadean.com','http://www.adihadean.com','194.102.126.6','2008-05-05 08:48:33','2008-05-05 06:48:33','Apoi da, ai tu dreptate, da bÄƒrbaÅ£ilor bag de samÄƒ cÄƒ le place poziÅ£ia patrupedÄƒ mult mai mult, de unde ÅŸi zÄƒbovitu\' la cÃ¢rciumÄƒ ÅŸi doggy style. Cred, dupÄƒ cum cred cÄƒ amu\' regretÄƒ rÄƒu cÄƒ nu o stat sÄƒ-i pape tigru cu dinÅ£ lunji ÅŸi tÄƒtÄƒ lumea sÄƒ aÅŸteaptÄƒ sÄƒ-i vadÄƒ umblÃ¢nd numa pÄƒ picioarele din urmÄƒ.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12','',0,0),(32519,1151,'Adi','adriana.argeseanu@gmail.com','http://aboutnothingsro.blogspot.com/','78.96.200.199','2008-07-04 08:25:41','2008-07-04 06:25:41','In primul rand saru\'mana nenea pt muzica, ca daca nu eram la birou acum acompaniam muzica asta si cu un MAAAARE pahar de vin rosu!:D (dar momentan ma multumesc cu apa plata).\r\n\r\nacum revenind la olandejii tai... eu cred ca le-a placut atat de mult de tine, dar atat de mult, incat au zis ca daca te mai si gazduiesc nu te mai lasa sa pleci acasa, si cred ca au facut asta pentru binele tau si al mamei tale care probabil ca vrea sa te mai vada si ea din cand in cand',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9) Gecko/2008052906 Firefox/3.0','',0,0),(32518,1045,'Philo','auroraeborat@yahoo.com','','77.127.11.243','2008-07-04 08:01:50','2008-07-04 06:01:50','Nici io nu-s de accord cu mierltu\' domnului in cauza, dar fie vorba intre noi: mare xenofob mai era. Si calare si pe gios. Adica si asa si pe dincolo. Mai bine zis, are niste mesajele xenofobe de mai mare dragu la acel forumel infect al lui.\r\nPeReMe-ul i se potrivea ca o proteza dentara de otel.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; SV1; .NET CLR 2.0.50727)','',0,0),(32521,1151,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','79.116.97.49','2008-07-04 08:37:10','2008-07-04 06:37:10','...si care, de fapt, e-o doamna, Aiai-i clar! Da\' clar.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.15) Gecko/20080623 Firefox/2.0.0.15','',0,0),(24270,1082,'ameÅ£itul','','http://ametzitul.wordpress.com','62.217.236.12','2008-05-05 07:48:06','2008-05-05 05:48:06','iote antropologu\' lu\' peÅŸte...\r\nda\' e ceva adevÄƒr Ã®n ce spui :)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(28002,1115,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-06-04 08:40:57','2008-06-04 06:40:57','Usim, ca de obicei, ai dreptate (parca ai fi nevasta, mo! &gt;:D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(25848,1093,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-05-20 09:34:42','2008-05-20 07:34:42','Exact!!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(32528,1151,'Roza','popescu.onita@yahoo.com','','79.117.168.144','2008-07-04 10:21:00','2008-07-04 08:21:00','Of,vad bine ca iar am dat cu bata in balta.Tot ce pot sa mai fac este sa incerc a drege busuiocul si sa imi retrag cuvintele.Pentru ca generalizarile nu sunt bune niciodata,reformulez:unii dintre romani au un mic sambure de diavol in ei(subscriu),dar printre ei plutesc cu aripi de inger fluturasii sperantei omenesti(si romanesti),poate e cam neclar,dar esentialul se subintelege.Promit ca atunci cand ma va mai manca buricul degetelor sa scriu rautati,mai bine le musc si nu mai supar lumea!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(30277,1137,'kittynel','kittynel@gmail.com','','213.208.242.81','2008-06-19 10:09:31','2008-06-19 08:09:31','daaaaaaaaaa... .foarte civilizati.. sa-i vezi pe aici (aici in tara lor civilizata) cum sunt dupa meci la p*$#&amp;lele de bete ..  si urla si injura, toti imbracati in femei portocalii, cu peruci si vopsele pe ei si numa la \"civilizati\" nu ma pot gandi... si a doua zi suna la servici ca-s bolnavi si nu pot pentru ca sa vie...  mai da-i in p&amp;*#$%!@$la lor de olandeji!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9) Gecko/2008052906 Firefox/3.0','',0,0),(24314,1082,'CÄƒlÄƒ','acalarasu@gmail.com','http://adriancalarasu.wordpress.com','80.96.53.9','2008-05-05 11:21:13','2008-05-05 09:21:13','da\' videnii si bocii de ce se chinuie sa stea pe doua, ce motiv au? da\' funarii si vadimii?!?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(28035,1117,'Andrei','','','193.231.34.2','2008-06-04 12:42:57','2008-06-04 10:42:57','Intuneric... intr-un cimitir.. un gropar blazat sapa o groapa... noaptea, (ca ziua era prea alcolizat sa poata munci). Un schelet iese dintr-un mormint vecin si incearca sa-l sperie.. omu` scarbit.. mait trage doua fumuri din Carpati si-si vede de treaba.. Scheletul tot mai insistent .. nu renunta .. il ia prin invaluire.. si iar sare sa-l ingrozeasca.. Groparu` nimic.. .. scheletul .. dezamagit.. se indeparteaza si da sa sara gardul cimitirului.. Groparul pune mina pe lopata si-i da  una de-l darima de pe gard... \"Ridem, glumim.. da\' nu parasim incinta, da...?!\"',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.9) Gecko/2008051206 Firefox/3.0','',0,0),(28036,1117,'Mile','','http://www.milecarpenisan.ro','79.114.35.198','2008-06-04 12:43:12','2008-06-04 10:43:12','Deci Gropare nu esti cu toate tiglele pe casa',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; SIMBAR={1469FFC6-4066-45F3-9E54-32485EA6B220}; SLCC1; .NET CLR 2.0.50727; Media Center PC 5.0; .NET CLR 3.0.04506; InfoPath.2)','',0,0),(25865,1094,'Lorand R. Minyo','me@lorandminyo.ro','http://www.lorandminyo.ro/','89.36.21.82','2008-05-20 12:07:47','2008-05-20 10:07:47','Stai linistit, asa vor face de acum incolo. La mine acasa au trimis un \"domn\" care a incercat sa-mi faca o oferta \"pe care nu o pot refuza\".\r\n\r\nTrebuie sa-si pastreze si sa-si creasca user base-ul, altfel nu au ce sa mai vanda la Orange in toamna :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(25866,1094,'WhiteWolf','laskmerge@gmail.com','http://white-wolf.ro','79.115.97.11','2008-05-20 12:08:47','2008-05-20 10:08:47','Lojik ca numa\' bine n\'are sa\'tz fie pana nu inalti satelitu\' groparesc de unde sa\'tz vina tzava direct in cazanu\' de acas\'.\r\n Ca se fac ca-tz dau, te lasa sa te bucuri o vreme (oricum ai semnat pe niste ani si ai o clauza de reziliere faina) dupa care incep sa se ridice la pret. Si cu pretentii suplimentare, si cu alt si alt si alt aditional care mareste factura si cu servicii la fel de proaste da\' la preturi noi\r\nMusai sa manifestezi si sa intrebi pe oricare raspandac de va veni cu pliantu electoral care\'i ala de face wireless metropolitan acolo, in tara ceterashilor\r\nAsa si numai asa ai sa votezi in cunostiinta de cauza :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(32542,1151,'mo','verde_poveste@yahoo.com','','194.126.220.240','2008-07-04 12:47:47','2008-07-04 10:47:47','Io zic ca n-ai bani de drum spre Usim poti cere oricand sa faca o cheta serioasa tati bucurestenii care te citesc si se rezolva!\r\nCare se baga? Io ies curajos la inaintare cu zece mii (pana iua salariul) si astept cu interes sa plusez cu o conserva de peste in sos tomat!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1)','',0,0),(28032,1117,'seliman','ionut.seliman@gmail.com','http://ionutu.wordpress.com','213.157.171.107','2008-06-04 12:33:53','2008-06-04 10:33:53','si mie mi se pare amuzant! :) :) :)\r\nAj vrea sa vaz cum e si cu submarinul, sau cu deltaplanu...chiar..oare cand zbori cu deltaplanul poti vorbi la celular? chiar daca ti-ai uitat handsfree-ul acasa? :)',0,'1','Opera/9.27 (Windows NT 5.1; U; en)','',0,0),(28046,1117,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-06-04 13:27:03','2008-06-04 11:27:03','Deci da, mo, ce v-ati spariet cu totii, ati sarit ca babele la mostenire...!!!\r\n\r\nVa multumesc din ventricole pentru ca va pasa!!!! Parca ati fi banca mea, jur.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(25877,1094,'ics','i_uana@yahoo.com','','86.126.99.7','2008-05-20 13:36:05','2008-05-20 11:36:05','ma, nush cum e cu UPCu\', da clar nu mai prost ca RDSu\' finca asa ceva nu egzista.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(28050,1117,'seliman','ionut.seliman@gmail.com','http://ionutu.wordpress.com','213.157.171.107','2008-06-04 13:46:10','2008-06-04 11:46:10','@Andrei Crivat\r\nda\' SMURD-ul n\'are deltaplan! :) si tot amuzant mi s-ar parea..\r\n@Groparu\r\ngroparele draga, io ma ofer voluntar sa ÅŸed Äƒn front-office la matale\'n bancÄƒ. ÅŸi sÄƒ oferim credite Ã®n anti-bani. :) Care anti-bani sÄƒ hie cu moaca lu\' Darius (JEG.RO) Groza, mare globe-troter cu trotineta..:) l-am sparge pe mustÄƒcios, zic..(Å¢iriacele).. :)',0,'1','Opera/9.27 (Windows NT 5.1; U; en)','',0,0),(25904,1090,'Cutest babes','email@peugen.net','http://cutestbabes.net','89.34.104.217','2008-05-20 17:04:39','2008-05-20 15:04:39','Se poate, dar aÅ£i verificat sÄƒ fie tot prin maÅŸinÄƒ? Roata de rezervÄƒ mai este, casetofonul are doar faÅ£a ÅŸi atÃ¢t? E suspect rÄƒu!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(25920,1095,'Tiki','tiki2134@yahoo.com','','85.186.0.185','2008-05-20 19:00:29','2008-05-20 17:00:29','I\"ll be the first to say it....and I\'m a guy.\r\n\r\nHere it goes....\r\n\r\n\r\n\r\nReady?...\r\n\r\n\r\n\r\n\r\nTHAT\'S SO CUUUUUUUUTTTTTTTTEEEEEEEEE!!!!!!!!!!!!!!!!!!!!!!!!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(25886,1093,'un fan','unfan@maimultifani.ro','http://n-am','86.35.201.235','2008-05-20 14:50:02','2008-05-20 12:50:02','Curiozitate proprie: Andreanum e aceeasi cu cea care modera forumu\' lu\' Andrei Gheorghe pe vremuri? Eu eram indragostit de ea. Daca e ea, transmite-i c-o iubesc. Daca nu e ea, spune-i ca ar fi putut fi!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.9) Gecko/2008051206 Firefox/3.0','',0,0),(25882,1084,'This is why I don&#8217;t like ClickNet | .marius rANTing away','','http://marius.wirelessisfun.com/2008/this-is-why-i-dont-like-clicknet/','193.203.205.12','2008-05-20 14:25:33','2008-05-20 12:25:33','[...] Gropare, s-au si descaltat oamenii cand au intrat in [...]',0,'1','Incutio XML-RPC -- WordPress/2.5','pingback',0,0),(28065,1117,'darius f','darius2u@yahoo.com','http://desprepsd.wordpress.com/','82.79.52.137','2008-06-04 14:53:12','2008-06-04 12:53:12','Kids...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(25887,1093,'andreanum','andreanum@andreanum.org','http://andreanum.org','217.10.208.22','2008-05-20 14:53:46','2008-05-20 12:53:46','fanule... daca imi zici cum te numeai pe forum iti spun daca eu eram :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9) Gecko/2008051206 Firefox/3.0','',0,0),(34172,1159,'oceania','oceania_oceania@yahoo.com','http://www.literelibere.blogspot.com','84.232.160.199','2008-07-21 09:09:48','2008-07-21 07:09:48','taaaareeee de tot! domnule, esti fantastic.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; InfoPath.1)','',0,0),(30322,1137,'eu','ripahoratiu@yahoo.com','','80.97.64.151','2008-06-19 16:14:29','2008-06-19 14:14:29','Acu\' in ce conditii bateam noi Olanda, si cum e cu suporterii mi se cam drapeleaza in mod cu totul si cu totul mioritic. M-am hotarat sa nu vars nimic, de la lacrima pana la cina de-aseara, pentru handicapatii astia, ca, oriscat, or primit salaru\' meu de-aci pana-n anu\' 10 de pensie pentru demonstratia de ratati pe care ne-au oferit-o. Ce ma gandesc io e ca ar trebui sa li se ridice dreptul de a behai imnu\', poate nu-si dau astia seama ca sunt din Romania.\r\nDa\' ca sa ma intromisionez de fapt in subiect, ca de fapt asta de mai sus era o divagatie, si chiar si asta e o divagatie in care explic divagatia de mai sus, deci:\r\nUat da fac e plm-u\' ala de-i promisesi sa nu mai injuri? Project Lifecycle Management?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(30323,1138,'ics','i_uana@yahoo.com','','86.126.99.7','2008-06-19 16:17:57','2008-06-19 14:17:57','si ashe ma incearca pe mine gandu ca batranica asta era ceva ruda cu tine. ruda de sange poate ?hmmm...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(30324,1138,'eu','ripahoratiu@yahoo.com','','80.97.64.151','2008-06-19 16:18:20','2008-06-19 14:18:20','Asta e din ciclu\' \"Nu postati pe blog dupa ce ati baut apa (sfintita)?\".\r\nTe-ai lovit la cap si n-am fost acolo sa ma bucur si io?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(24379,1082,'Andreea','puistrulet2003@yahoo.com','http://n/a','81.196.150.196','2008-05-05 16:48:15','2008-05-05 14:48:15','@Groparu: eu zic ca au invatat sa se ridice in labele din spate(deci am zis labe nu picoare, deci nu is inca \"humans\"-vezi Startrek Next Generation, aia mici si urechiosi care se numeau Ferenghi parca :)) ) pentru ca au zis la un moment dat: Fuck it !!! io nu mai pun botu\' jos(la propriu)..... Daca e sa ma pape, inseamna ca nu merita sa traiesc!! si uite asa s-a nascut zicala \"a pune botu\" si norocul....\r\n\r\nSubscriu si eu la ce a scris Whitewolf adica bravos si la mai multe postari...\r\nAndreea',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(24383,1081,'ics','i_uana@yahoo.com','','86.126.99.7','2008-05-05 17:10:10','2008-05-05 15:10:10','Partea  rea e ca injura, bea, se bate...si nu scrie nimic despre asta pe blog.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(25906,1094,'Lorand R. Minyo','me@lorandminyo.ro','http://www.lorandminyo.ro/','89.36.21.82','2008-05-20 17:21:14','2008-05-20 15:21:14','@10MBC e normal sa nu-ti mearga telefonia daca iti folosesti mai toata banda. Pana la urma tot VoIP este si merge pe aceeasi teava :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(32581,1151,'Tudor Oarecare','tudor@inbox.com','','89.137.175.11','2008-07-04 18:13:56','2008-07-04 16:13:56','Am ascultat de cel puÅ£in 5 ori fiecare melodie. Unde pot sÄƒ mai ascult sau cum pot sÄƒ cumpÄƒr un album? Ia zi! :D',0,'1','Opera/9.51 (Windows NT 6.0; U; en)','',0,0),(30339,1138,'shoc','rtfmn@gmail.com','','66.15.61.199','2008-06-19 18:23:11','2008-06-19 16:23:11',':))))) incredibil ce iti poate fata mintea; esti tare! \r\n100% de acord cu seliman, de asta te citim zilnic :)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(30342,1138,'Ionut','iong002@yahoo.com','','89.34.225.25','2008-06-19 18:47:10','2008-06-19 16:47:10','Ba chiar si in subiectele de BAC :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(30344,1138,'Elisa','elivasu@yahoo.com.au','http://elisagradinameadevis.blogspot.com/','92.81.138.58','2008-06-19 18:47:50','2008-06-19 16:47:50','Io zic numa ca postezi prea rar...  :lol:',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(24396,1082,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-05-05 18:29:54','2008-05-05 16:29:54','Deci clar ca la asemenea comentarii favorabile m-am umezit tot, si am si pkicurat un pkik!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(25918,1094,'etenah','lazuli_cs@yahoo.com','','86.120.75.254','2008-05-20 18:37:56','2008-05-20 16:37:56','is de-acord cu ics. rds-u\' sucks big time. mai gropare, mai... de ce nu ne ceri noua parerea inainte sa faci asemenea schimbari? ca doar noi iti vrem binele... :)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; SLCC1; .NET CLR 2.0.50727; Media Center PC 5.0; .NET CLR 3.0.04506; InfoPath.2)','',0,0),(30373,1138,'Nox','','http://s3my.blogspot.com/','89.47.100.75','2008-06-19 22:17:40','2008-06-19 20:17:40','noh, n-as vrea sa fiu eu vrajitoarea cea rea, dar eu am mai auzit pe undeva faza asta. daca nu ma insel era chiar un banc vechi cu acelasi final si cu partea de inceput contrasa. acu\' cine a plagiat pe cine?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(30366,1138,'Turambar','mirel@ccsb.ro','http://turambarr.blogspot.com','79.114.190.88','2008-06-19 21:47:22','2008-06-19 19:47:22','Tulai, Doamne, ca faine tzatze itzi trec prin cap, tu, slobodule shi iredentistule shi bezmeticule shi blasfemiatorule.\r\n\r\nAlo, Domnu? Un fulger mic shi puternic in zona Clujului, por favor! Are nevoie cineva de doi douazeci prin sinapse, sa se pocaiasca in regim de urgentza...\r\n\r\n:)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(25935,1094,'Arhi','admin@arhiblog.com','http://www.arhiblog.com','79.117.95.245','2008-05-20 21:07:30','2008-05-20 19:07:30','10mbc astea sunt legende de cacat. eu am rds, merge struna de 3 ani, am si router, a mers si fara router la fel de bine, merge si wireless, si sa vezi faza, routerul se conecteaza imediat. ce va place sa raspanditi legende de astea cacacioase, ceva de speriat',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(30376,1138,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','79.116.97.209','2008-06-19 22:43:08','2008-06-19 20:43:08','Daca-mi gasesti pe internet bancu\' (de care io n-am auzit), io sterg postarea asta.\r\n\r\nFair enough?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(25945,1095,'WhiteWolf','contact@white-wolf.ro','http://white-wolf.ro','79.115.97.42','2008-05-20 22:37:03','2008-05-20 20:37:03','Io tot nu inteleg cum poti respecta doamnele si totusi sa-ti pastrezi pozitia de presedinte al misoginilor in acelasi timp :)\r\nDoamna nevasta omului stie de \"putinul ajutor\" ? :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(25954,1094,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','79.116.96.102','2008-05-20 23:26:09','2008-05-20 21:26:09','Mo!\r\n\r\nArhi fiinteaza in Constanta.\r\n\r\nGroparu fiinteaza in Cluj.\r\n\r\nAltii fiinteaza in alte orase.\r\n\r\nRetelele RDS din orase diferite merg diferit! Retelele RDS din acelasi oras merg diferit. Si retelele RDS din aceeasi retea merg diferit. Depinde cum ai norocu\'. Da\' la mine pe blog, in afara de mine, nu cre\' ca mai minte careva!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(24485,1082,'Sibilla','sibilla_poesis@yahoo.com','http://sfinx667.wordpress.com','89.123.13.10','2008-05-06 03:15:41','2008-05-06 01:15:41','mai, daca zici tu....esti cumsecade, asa-i no :))\r\nrespecte,\r\nSibilla',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(28165,1117,'V_for_Whatever','stephanovendetta@yahoo.com','','89.136.50.177','2008-06-05 06:17:45','2008-06-05 04:17:45','tare...asta-i din ciclul \" Bunicule, de ce fuge bunica in zig zag? / Taci si da gloantze.\" sau \" Bunicule, mai avem mult pana la bunica? / Taci si sapa.\"?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; .NET CLR 2.0.50727; InfoPath.2)','',0,0),(34022,1158,'10mbc','alin.banc@gmail.com','','78.97.213.251','2008-07-20 08:04:05','2008-07-20 06:04:05','Ba da, asa e la Cluj...\r\nGropare, da-mi si mie idu de mess al instalatorului ca am de schimbat toate bateriile si jumate din tevile din baie. Fiind tatal fiulului lui Xulescu si eu fiind clujan autentic poate imi face si mie fara plata. Si nu-mi da numaru de tel ca n-am centi. Ah.. sa nu uit.. tevile au fost puse anul trecut de un instalator \"asa cum se stie\".',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.9.0.1) Gecko/2008070208 Firefox/3.0.1','',0,0),(26005,1095,'Altar','stefan_grebla@yahoo.com','','89.120.195.75','2008-05-21 08:32:39','2008-05-21 06:32:39','Mah Groparele, io tot nu inteleg o treaba ca te si citesc mereu si mai nimic nu inteleg oricum, da` ceva e dubios, ca m-am uitat: cum se face ca toti prekinii lu` matale la care s-o inmultit famelia, s-o inmultit cu alte femei, de parca una nu era de ajuns sa-i faca omului zile fripte. Ce va pun astia in apa acolo la Cluj, mah tata? E un complot al femeilor care vor sa cucereasca lumea, iti spun eu, vor matriarhat (macar de s-ar duce la munca in locu` nostru).',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(22667,1076,'ameÅ£itul','','http://ametzitul.wordpress.com','62.217.236.12','2008-04-21 07:38:21','2008-04-21 05:38:21','ahaaaa!!! deci ai renunÅ£aaat la post... :)\r\nsau asta a fost mai de demult?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(24518,1083,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-05-06 08:41:14','2008-05-06 06:41:14','Da! Si mai ales, ce grosime?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(24517,1083,'broodwar7','broodwar7@gmail.com','','193.90.144.66','2008-05-06 08:39:25','2008-05-06 06:39:25','Napai la mine daca e mai putin de 25 de minute e naspa, simt ca n-am facut nimic.\r\nSi partea proasta i ca mi-s mascul.\r\nDa hai sa zicem ca am o scuza: am de abia 25 de ani.\r\nAlta intrebare pentru azi: daca mie la 25 imi trebe minim 25, cat ii trebuie unuia la 40?',0,'1','Opera/9.27 (Windows NT 5.1; U; en)','',0,0),(24521,1083,'un om','paul_bv@yahoo.com','','82.79.251.239','2008-05-06 08:48:49','2008-05-06 06:48:49','25 de minute cutot cu preludiu? atunci se pune...',0,'1','Opera/9.27 (Windows NT 5.1; U; en)','',0,0),(24522,1083,'Vla$','','http://www.coadademaimutza.ro','92.82.38.96','2008-05-06 08:50:28','2008-05-06 06:50:28','pamant la servici! ca tre sa ma ascund sa postez un comment la lauda care o primesc! CEEEE?!?!no ies ca vine mon patron!\r\nmai comentez io\r\npa',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.2)','',0,0),(22674,1076,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-04-21 09:00:48','2008-04-21 07:00:48','Posturile mele, ca si luptele din Fight Club, continue as long as they have to!\r\n\r\nNu, n-am renuntat la post, finca-s mai tare (a se citi mazochist) decat tentatiile care se urca pe trupul meu puternic precum iedera pe turnurile de aparare ale cetatii din Heidelberg!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(24532,753,'juego de poker en espaÃ±ol','','http://url','91.145.206.147','2008-05-06 10:12:30','2008-05-06 08:12:30','<strong>juego la ruleta...</strong>\n\nAn cash loan payday quick poker torneos gratis...',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','trackback',0,0),(26013,1097,'un om','paul_bv@yahoo.com','','82.79.251.239','2008-05-21 10:27:09','2008-05-21 08:27:09','that was nashpa!!!',0,'1','Opera/9.27 (Windows NT 5.1; U; en)','',0,0),(28191,988,'alexnicolae','alexnicolae@gmail.com','http://alexnicolaeblogspot.com','62.180.224.130','2008-06-05 10:41:07','2008-06-05 08:41:07','Sunt seturi de farfurii de carton. Iei un set iti ajung 2 luni. Tacamuri de plastic. Pahare de plastic. Cutitele le stergi bine pe paine dupe ce le folosesti. Io asa!',0,'1','Mozilla/4.0 (compatible; MSIE 5.01; Windows NT 5.0; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(24535,1083,'ania','ania@wip.ro','http://aniakhaki.com/','92.82.47.66','2008-05-06 10:29:42','2008-05-06 08:29:42','concureaza cu sleepwalking :D care e realizat de dragostea vietii mele. si eu tocmai ii fac reclama la gropar in curte :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(24541,1081,'deci,totodatÄƒ...','costelush70@yahoo.com','','92.83.108.75','2008-05-06 11:13:07','2008-05-06 09:13:07','adÃ®ncÄƒ ÅŸi-ncurcatÄƒ treabÄƒ mÄƒ gropare,ce sÄƒ-Å£i zÃ®c,cÄƒ Å£-aÅŸ zÃ®ce da mi-e cÄƒ o sÄƒ-mi zÃ®cÄƒ toÅ£i ailanÅ£Ã® cÄƒ sÃ®nt muiere...mÄƒi plÃ®ng ÅŸi io beat,mÄƒi ÅŸi suspin,da hai,gata,nu mÄƒi zÃ®c nimic,cÄƒ ÅŸi-aÅŸa...',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(26023,1095,'','','','92.81.43.166','2008-05-21 11:59:25','2008-05-21 09:59:25','No...,io cand nu am alte motive de ras,trec pe aici si rad cu copilasii astia,dar nu ca proasta...  :lol:  ,sau poate ,da??  :(',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(34053,1158,'brosky','brosky@gmail.com','http://blog.101net.ro','79.116.64.8','2008-07-20 14:02:57','2008-07-20 12:02:57','da auzi, gura nu-i mirosea ?\r\nCa la instalatorul meu, nu stiam cum sa-l fac sa ia un mentos , ca atunci cand vorbea cu mine, ma facea sa-mi caut geanta verde cu masca de gaze :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9) Gecko/2008052906 Firefox/3.0','',0,0),(28218,1117,'Andreea','puistrulet2003@yahoo.com','http://n/a','81.196.150.196','2008-06-05 15:21:31','2008-06-05 13:21:31','Deci tu erai ieri survoland Gheorgheniul :)))))...\r\n\r\nMa mir ca nu i-ai convins pe elicopter-men sa puna banner cu reclama la bere pe coada elicopterului...that would have been your distinctive mark :))))))\r\n\r\nAndreea',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(30504,1138,'IepurasulAtomic','praetorian21uk@yahoo.com','http://iepurasulatomic.weblog.ro','99.246.65.253','2008-06-20 15:12:27','2008-06-20 13:12:27','Tu-i ceapa ma-sii ma Gropare. Eu atata vreau: daca tot pacatuiesti si se intampla ce zice Altar, pacatuieste si tu mai repede, sa se umple Canada cu fecioare din Romania si cu tzatzele lor cu tot. \r\n\r\nCat despre plagiatiuni, atata am de zis: eu cand fac glume, am impresia ca te plagiez pe tine, Vacanta mare, Doru Octavian Dumitru, pe Charlie Sheen(sau cum dracu\' se scrie) din Two and a half Men si tat serialu\' M.A.S.H. Asha ca daca te da careva in judecata pentru plagiatiuni si pierzi procesu\', sa vii sa-ti dau si eu niste bani, ca sigur te-am plagiat macar odata in viata mea. Fara sa vreu, da\' ce mai conteaza?! Ce-i important e ca eu nu sterg nik :).',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; InfoPath.1; MS-RTC LM 8; .NET CLR 3.0.04506.30)','',0,0),(26054,1097,'de pe alta lume','totmea@yahoo.com','','92.82.51.34','2008-05-21 15:43:41','2008-05-21 13:43:41','ua! secretosilor!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Zango 10.3.36.0)','',0,0),(26061,1104,'pliscu','pliscu@gmail.com','http://pliscu.blogspot.com','84.253.11.229','2008-05-21 16:26:28','2008-05-21 14:26:28','DacÄƒ vine viitura, musai sÄƒ faceÅ£i fight-club subacvatic!! \r\n\r\nAvelo bahtalo!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(28229,1115,'Dozy','arotat@yahoo.com','http://turnuldesomn.wordpress.com','89.137.96.218','2008-06-05 18:28:29','2008-06-05 16:28:29','RelaÅ£ia cu banca e halucinantÄƒ. ÃŽÅ£i dÄƒ impresia cÄƒ Å£i-o suge, dar de fapt Ã®Å£i sparge rozeta.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(26067,1097,'','','','58.38.16.209','2008-05-21 17:00:23','2008-05-21 15:00:23','habar n-aveam ca exista si pui Sichuan... Cred ca au cate un pui pentru fiecare provincie. Pui Shanghai, ratza Pekin... (desi asta nu e pui)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(24618,1083,'gb','getbordea@yahoo.com','http://getbordea.blogspot.com','208.77.165.40','2008-05-06 17:55:18','2008-05-06 15:55:18','Conteaza sau nu conteaza marimea, trebuie sa te descurci cu ce ai, pentru ca marfa nu se poate nici schimba nici returna. Cel putin vizitele pot fi variate ca sa mai omori din plictis. Mai scurte, mai lungi, mai dese sau mai rare ca sa ti se faca dor, important e sa servesti cu ceva dulce pe musafir. \r\n\r\nDin cate am auzit eu oaspetii stau mai mult daca le dai de baut.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(28234,1115,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','79.116.97.193','2008-06-05 19:57:24','2008-06-05 17:57:24','Ideea e ca amandoi gafaim de fericire.\r\n\r\nCine la ce capat al putulicii se afla - asta deja chiar ca nu mai e chiar asa de important.\r\n\r\nSau e??? :O',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(28235,1117,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','79.116.97.193','2008-06-05 20:00:09','2008-06-05 18:00:09','Ereau prea ocupate elicopteritzele sa imi faca respiratie buÅŸon la buÅŸon.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(28236,1117,'UnCopilutz','uncopilutz@yahoo.com','http://www.uncopilutz.haipa.ro','78.97.221.106','2008-06-05 20:00:41','2008-06-05 18:00:41','No, asta-o poanta geniala!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; es-ES; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(30573,1090,'super tare!','hadar_aurelian@yahoo.com','','85.204.37.151','2008-06-20 20:26:07','2008-06-20 18:26:07','Am citi tot blogul de la coada pana aici. Nu am mai stat asta de mult pe net decand faceam cybersex cu exa pe messenger. E super tare. Putini oameni au talentul sa ilustreze situatile cu atat umor. Am mai dedus ca esti si de prin SIBIU (me 2).  Spor in continuare!',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1)','',0,0),(24623,1082,'deci,totodatÄƒ...','costelush70@yahoo.com','','92.83.108.75','2008-05-06 18:20:04','2008-05-06 16:20:04','MamÄƒ mamÄƒ,pe-aci e lume care-mi place! Ce gÃ®nduri,ce existenÅ£ialism,ce profunzimi... DÄƒdui de voi ÅŸi-mi plÄƒcurÄƒÅ£i tare! N-am nimic de zÃ®s,da\" sÃ®mÅ£Ã®i cÄƒ trebe sÄƒ vÄƒ dau bunÄƒ zÃ®ua. BunÄƒ zÃ®ua!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(26085,1104,'chevantonje','','','86.121.173.64','2008-05-21 19:31:29','2008-05-21 17:31:29','Noroc bun si sa ne povestesti cu mare pofta dupa, ce si cum o fo\' la Tziganiada. Pana atunci, pentru ca stiu ca multa lume te citeste si vreau sa-i ajut pe cei care cauta un job cu adevarat deosebit recomandarea mea nu poate fi decat asta : \r\n\r\nhttp://www.bestjobs.ro/top-locuri-de-munca-plm-consultant-f-m/97884/2.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(26083,1104,'Ureche Mare','h_gheorghe@yahoo.com','http://www.ju-jutsu.ro','79.117.11.110','2008-05-21 19:19:59','2008-05-21 17:19:59','Bre Gropare, am auzit io din fotografia alaturata, ca Steven Seagal si-a schimbat emoÅŸÄƒn ciartul de cand l-ai eclipsat cu anuntul plecarii la Tiganiada (din nou).',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(24635,1080,'trafiik','','','79.116.229.132','2008-05-06 19:22:41','2008-05-06 17:22:41','Pe seful meu il cheama Andy Capatos si cred ca e ruda cu Dan Capatos de la TV.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(28240,1115,'Dozy','arotat@yahoo.com','http://turnuldesomn.wordpress.com','89.137.96.218','2008-06-05 20:34:05','2008-06-05 18:34:05','ÃŽn afara orgasmului nimic nu are importanÅ£Äƒ:)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(34115,1159,'baghy','baghy83@lycos.it','http://www.baghy.info','78.12.17.190','2008-07-21 00:54:28','2008-07-20 22:54:28','banuiam eu ca e ceva putred la sfarsit',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(34094,1158,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','79.116.97.60','2008-07-20 22:25:10','2008-07-20 20:25:10','@ Sorina: pai da, numai tu esti.\r\n\r\nCredeai bine.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.16) Gecko/20080702 Firefox/2.0.0.16','',0,0),(34096,1158,'prodan','mihai.prodan@gmail.com','http://prodan.wordpress.com','79.116.83.234','2008-07-20 22:42:39','2008-07-20 20:42:39','io tot la cluuuuj m-am fript cu un instalator care mi-o loat la bani de numa ÅŸi s-o ÅŸi prefÄƒcut cÄƒ nu-mi poate da chitanÅ£Äƒ, dic.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.16) Gecko/20080702 Firefox/2.0.0.16','',0,0),(24649,1081,'Laura','lauraciuci@yahoo.com','','89.41.218.173','2008-05-06 21:59:16','2008-05-06 19:59:16','Da\' de ce zici \"zace\"? Mie nu mi se pare ca zace. Ii chiar activa tanti :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(24650,1083,'WhiteWolf','laskmerge@gmail.com','http://white-wolf.ro','79.115.97.48','2008-05-06 22:03:08','2008-05-06 20:03:08','Am inteles.\r\nNu numa\' ca ejti rapsod popular din ala de o da pe cantece si poiezie cu trenuri si lanturi cand ajunge la universitatile de tip Jilava da il mai si promotionezi pe unu. Care, de fapt, ie mai multz\' da\' tot dejaba ca tare mai ie pacat fara (de) JniÅ£Äƒl. Si pÃ n\' la urma te priveste srikt ca te-ai decis sa impacetezi tot promoushiÃ£nu\' in chestii despre care numa\' vorbeste lumea si stiinta nu aproba; a se retine ca ce kÃ kat mÃ ncÃ£ cercetatorii arondati ziarelor Li9bertatea si Can-Can nu-i stiinta.\r\n No, bun.\r\nFÃ£ bine si-mi zi, daca tot vrei sa votez; pana la urma putza de bacterie ie de bine sau de rau pentru aia de umbla pe picioarele din spate ? A ?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(24653,1079,'Laura','lauraciuci@yahoo.com','','89.41.218.173','2008-05-06 22:19:04','2008-05-06 20:19:04','Si de ce ma rog popii spovedesc asa, cu noaptea in cap? Eu mi-s atee si asa oi si ramane, mama lor de sarlatani!!! (nu neaparat de aia ca-s asa matinali, ci ca-s ei cum is, ca o fost atat de amabil unu de i-o schimbat lu bunica-mea o hartie de 2 milioane in doua de 10 lei si una de 5) Mamaliga lor!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(34102,1159,'KillerINC','webmaster@bcdentalab.ro','http://killerinc.voce.ro','79.118.237.214','2008-07-20 23:25:03','2008-07-20 21:25:03','GENIAL !!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.9.0.1) Gecko/2008070208 Firefox/3.0.1','',0,0),(28297,1118,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-06-06 09:48:44','2008-06-06 07:48:44','@ hadean: promit ca daca totusi te pipai, te pipai cu manusa din aia portocalie de bucatarie, de la Cora!\r\n\r\n@ Andreea: dap! Mai ales ca odata am prins si o ditamai stiuca in Delta, de pe fundul lotcii lu ghidu\' nostru, of cors.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(28298,1118,'hadean','contact@adihadean.com','http://www.adihadean.com','86.125.34.195','2008-06-06 09:50:22','2008-06-06 07:50:22','no, bine-i ÅŸi aÅŸa :-)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(34161,1159,'Ancuta','delcisor_m@yahoo.com','','195.245.251.18','2008-07-21 07:35:17','2008-07-21 05:35:17','O fi ea musca, da\' ce?! N-are si ea dreptul la o descriere poetica?! Ce stiti voi ... ce inseamna viata de musca!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(34173,1159,'Turambar','mirel@ccsb.ro','http://turambarr.blogspot.com','62.217.213.169','2008-07-21 09:26:35','2008-07-21 07:26:35','Sshhhh. Sa parasim discret acest blog. Este indragostit. Sshhhtt. Step gently, unless you disturb the passion.\r\n\r\nHmpf! Hmpf! Hmpffff! BzzzzzzzzzzzZZZZZZZZZZZ [<i>asta e orgasm de musca, pentru cine nu intzelege suptilitatzile forumistice</i>]',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9) Gecko/2008052906 Firefox/3.0','',0,0),(28287,1118,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-06-06 08:57:33','2008-06-06 06:57:33','Maaaaaaa... cand ajung sa devin mai zoso decat zoso cu blogu\' meu, te angajez bucatareasa mea personala!!!!! Acciepti??? (zi da! zi da!!)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(28284,1118,'hadean','contact@adihadean.com','http://www.adihadean.com','86.125.34.195','2008-06-06 08:26:57','2008-06-06 06:26:57','dorada la gratar Ã®i muult mai bunÄƒ decat somnul la gratar (bine, aci intervin ÅŸi gusturile personale) daaaar, dacÄƒ te hotÄƒrÄƒÅŸti sÄƒ rÃ¢mÃ¢i la somn Ã®Å£i propun sÄƒ-l  Ã®mbraci mai Ã®ntÃ¢i Ã®n cozi de ceapÄƒ verde ÅŸi oarice rozmarin apoi Ã®n folie de staniol. ÅŸi Ã®l laÅŸi aÅŸa peste cÄƒrbuni cam un sfert de ceas. dupÄƒ care Ã®l dezveleÅŸti ca pÄƒ statuia lu\' proasta aia de venus ce ieÅŸea din mare, din cauzÄƒ la tÄƒt peÅŸtele miroase a peÅŸte (cu grijÄƒ, sÄƒ nu te frigi) ÅŸi condimentezi cu un pic de sare ÅŸi cu niÅŸte piper. apoi pui peÅŸtele gol pÄƒ grÄƒtar, sÄƒ vezi muiere de limbÄƒ (asta nu-i pornoÅŸag). ÅŸi dacÄƒ mai Å£Ã®pi pÄƒ iel o aiturÄƒ frecatÄƒ numa din usturoi ÅŸi oloi de mÄƒsline, plus douÄƒ porodici Å£apine tÄƒiete mici, aÅŸe ceva nu sÄƒ poate, Ã®Å£ spui io!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(34179,1159,'cristi','ghiucristi@yahoo.com','','89.137.162.21','2008-07-21 11:00:39','2008-07-21 09:00:39','mie-mi place partea cu motorul diesel =))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.16) Gecko/20080702 Firefox/2.0.0.16','',0,0),(28307,1118,'maaaaaah','totmea@yahoo.com','','89.123.86.97','2008-06-06 12:49:35','2008-06-06 10:49:35','ametitule! cum dreq sa te intelegi bine cu celalalt.....aia-i boala curata. ua! ca nimica nu stitzi. dar asta e bine de fapt. inseamna ca n-ati avut ocazia. :-)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; SIMBAR={3523AA32-EC48-4B99-902E-C5F036C0464E}; Zango 10.3.36.0)','',0,0),(24715,1084,'!?_Je_?!','florina_audochii@hotmail.com','','194.102.139.9','2008-05-07 08:31:18','2008-05-07 06:31:18','..... and don\'t forget the buttocks :D',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(28290,1118,'hadean','contact@adihadean.com','http://www.adihadean.com','86.125.34.195','2008-06-06 09:15:32','2008-06-06 07:15:32','dacÄƒ promiÅ£i sÄƒ nu mÄƒ pipÄƒi cÃ¢nd mÄƒ aplec sÄƒ aprind focu Ã®n cuptiori, da. de bunÄƒ samÄƒ',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(28291,1118,'hadean','contact@adihadean.com','http://www.adihadean.com','86.125.34.195','2008-06-06 09:16:50','2008-06-06 07:16:50','*mai sus : din cauzÄƒ la care tÄƒt peÅŸtele miroase a peÅŸte (mÄƒ mai ieu dejitile pÄƒ dinainte)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(22737,1076,'IepurasulAtomic','praetorian21uk@yahoo.com','http://iepurasulatomic.weblog.ro','82.77.123.64','2008-04-22 08:34:14','2008-04-22 06:34:14','Postarea asta mi-a smuls o lacrima de ras, asha de dimineata :). Multam de zambete, da\' am o problema. Pot sa-ti trimit tricou\' sa mi-l speli, ca mi l-am patat de cafea cand m-a busit rasu\', si masina mea de spalat ii stricata. Ce zici, ma ajuti?! Cand il mai vezi pe Greuceanu, sa-i transmiti un \"Sar\'na Parinte\" din partea mea!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(22739,1077,'Greuceanu','','','89.46.104.35','2008-04-22 09:33:02','2008-04-22 07:33:02','pai mah! se vede ca nu ai avut de-a face cu cu SC nasteri SRL, aici se factureaza pe baza de discount!  adika cu retinere la sursa prin impozitare forfetara.  deci, dupa ce iti refaci calculele, cauta comisionu\'!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(22741,1077,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-04-22 09:34:07','2008-04-22 07:34:07','ComisIon Iliescu!:D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(26172,1104,'anonim','princesshgabriela@yahoo.com','','80.97.216.138','2008-05-22 11:37:30','2008-05-22 09:37:30','Ce frumos birou ai!\r\nVa imbatati , va luati la bataie sau jucati rugby?\r\nCum va petreceti timpul?\r\nSucces!',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648)','',0,0),(22744,1077,'hadean','contact@adihadean.com','http://www.adihadean.com','194.102.126.6','2008-04-22 10:26:16','2008-04-22 08:26:16','mÄƒ, sÄƒ mor io, Ã®Å£ mere mintea! ÅŸÃ® lu\' Äƒstalalt, trÃ®i-i-ar pruncii!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12','',0,0),(24738,1084,'Turambar','mirel@ccsb.ro','http://turambarr.blogspot.com','92.80.17.90','2008-05-07 11:14:56','2008-05-07 09:14:56','Mai concasant. Mai inevitabil. Mai concupiscent.\r\n\r\nMai extraveralic.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(28305,1118,'ameÅ£itul','','http://ametzitul.wordpress.com/','82.76.123.238','2008-06-06 11:46:52','2008-06-06 09:46:52','io peÅŸtele dacÄƒ-l mÄƒnÃ¢nc Ã®l arÄƒt apoi comesenilor, da\' cu celÄƒlalt lucru mirositor mÄƒ Ã®nÅ£eleg mai bine ;)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(34196,1159,'oana','oanastanculescu@yahoo.com','','89.123.144.131','2008-07-21 13:57:21','2008-07-21 11:57:21','mai, sa fie! povestea de dragoste dintre om si insecta e traita si retraita de la inceputul lumii...si totdeauna e sublima si surprinzatoare! si eu ii traiesc si retraiesc fiorul in fiecare noapte, decat ca musca mea e tantar. si nu e unul, ci mai multi, deci s-ar putea spune ca e cam ...in grup.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(22755,1077,'katmai','katmai@keptprivate.com','http://www.512kbps.com','195.212.29.163','2008-04-22 12:46:40','2008-04-22 10:46:40','1 - cine e greuceanu?\r\n2 - de ce cafeaua mea are gust de sosete?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(22757,1077,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-04-22 13:51:16','2008-04-22 11:51:16','Da!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(22758,1076,'CÄƒlÄƒ','acalarasu@gmail.com','http://adriancalarasu.wordpress.com','80.96.53.9','2008-04-22 13:54:04','2008-04-22 11:54:04','Ma, voua ar trebui sa vi se puna un ordin d-ala de restrictie, sa nu va apropiati mai mult de 1 km. Unul de altul! Ca prea rele faceti cand va intalniti, prea petreceti ca sarbii lui Kusturica. Si nu ca as avea probleme cu acceptarea genului de manifestare, da\' mor de invidie!!!',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(24753,1084,'deci,totodatÄƒ...','costelush70@yahoo.com','','92.83.108.75','2008-05-07 15:22:49','2008-05-07 13:22:49','pÄƒ ce dracu mÄƒnÃ®nci,mÄƒ?!?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(24754,1084,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-05-07 15:31:38','2008-05-07 13:31:38','Pe fatza de masa!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(22764,1077,'katmai - Unplugged, Unmatched, Unleashed &raquo; Ce se intampla in blegosfera azi?','','http://www.512kbps.com/2008/04/22/ce-se-intampla-in-blegosfera-azi/','208.98.1.85','2008-04-22 15:17:54','2008-04-22 13:17:54','[...] Groparu - e secsi si abereaza ca de obicei. wanna feel free ? take a bite of groparu. [...]',0,'1','Incutio XML-RPC -- WordPress/2.5','pingback',0,0),(22765,1077,'Andreea','puistrulet2003@yahoo.com','http://n/a','81.196.150.196','2008-04-22 15:23:20','2008-04-22 13:23:20','Oau, ce-ti mere mintea la profit!!! Dar oare va fi la fel cand o sa ai si tu Gropareii tai? :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(28322,1118,'nuca','nuka21u2@yahoo.com','','195.182.212.244','2008-06-06 17:38:26','2008-06-06 15:38:26','si cealalta chestie care miroase a peste care e?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; .NET CLR 2.0.50727; .NET CLR 1.1.4322; .NET CLR 3.0.04506.30)','',0,0),(26208,1104,'Kissu','','http://www.pacurar.net','82.77.126.254','2008-05-22 16:51:52','2008-05-22 14:51:52','Pufuletii sunt inca pe birou la ora asta, dar la intoarcere N-O sa-i mai gasesti... :p ;)) Nu de alta, dar maine-i vineri...',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; InfoPath.1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648)','',0,0),(22771,1044,'Bogdan','','','193.226.58.175','2008-04-22 17:03:56','2008-04-22 15:03:56','Nu inteleg cum draq ii atrag pe multi jocurile astea online de kkt... nu castigi nimic !!!Cred ca o se ajunga sa se si omoare unii...',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1)','',0,0),(26216,1104,'ics','i_uana@yahoo.com','','86.126.99.7','2008-05-22 17:47:14','2008-05-22 15:47:14','Gropare, neaparat tre\' sa raspunzi la intrebarea : ce e in farfuria aia langa pufuleti ???\r\n\r\napoi,  cat timp te lafai in cortul ala al  tau luxos si surfezi pe valurile de bere si  acolo la tiganiada, sa tii minte ce-ti spun eu acum :  gather , plan, write, verify si nu in ultimul rand, redo.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(30712,1138,'psaico','blog@psaico.info','http://www.psaico.info','85.186.1.100','2008-06-21 18:16:28','2008-06-21 16:16:28','asta a fost adanca :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9) Gecko/2008052906 Firefox/3.0','',0,0),(30713,1132,'psaico','blog@psaico.info','http://www.psaico.info','85.186.1.100','2008-06-21 18:18:38','2008-06-21 16:18:38','gropare, cum a zis si brosky, un .cdr la download si nu m-as supara ;)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9) Gecko/2008052906 Firefox/3.0','',0,0),(28327,1118,'nonick','agentuzerozeroopt@yahoo.com','','84.232.144.193','2008-06-06 18:59:31','2008-06-06 16:59:31','Cealalta chestie care miroase a peste are gust de pui :)\r\n\r\nGropare, suntem conjudeteni la origine sa inteleg? Ocna nu-i departe tare...',0,'1','Opera/9.02 (Windows NT 5.1; U; en)','',0,0),(22777,1077,'candid','adi.covaci@jumpeye.com','http://www.aicarteaiparte.ro','79.113.44.208','2008-04-22 20:36:56','2008-04-22 18:36:56','Daca imi permiti, vis-a-vis de subiect, uite aici o lista de preturi care se practica in maternitate :\r\n\r\nhttp://www.papuravoda.ro/penibilul-romanesc/cum-sta-treaba-cu-maternitatea-spital-de-maternitate-spaga/',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 UGA6P/2.2.366.1 Firefox/2.0.0.14','',0,0),(24773,1086,'Greuceanu','','','89.46.104.35','2008-05-07 21:20:12','2008-05-07 19:20:12','pi\' cat de jmeker e Dumnezeu sau cat de tantalau ejti tu!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(24774,1086,'hadean','contact@adihadean.com','http://www.adihadean.com','79.113.58.92','2008-05-07 21:21:32','2008-05-07 19:21:32','ntz, celÄƒlalt ne convinge cÄƒ dumnezeu nu existÄƒ, convingÃ®ndu-ne mai Ã®ntÃ¢i cÄƒ el(celÄƒlalt)nu existÄƒ, ÅŸi, prin urmare nu-i nevoie nici de dumnezeu. io aÅŸa cred.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(24775,1086,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','79.116.96.88','2008-05-07 21:40:37','2008-05-07 19:40:37','@ Greucica: poi tu stii, mah, ce pola te mai intrebi!\r\n\r\n@ Hadean, deci nu ma dezamagi!;;) Deci: pai nu?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(34252,1158,'Lush','copilurau@yahoo.com','http://www.blogulucostel.blogspot.com','89.137.171.47','2008-07-22 00:15:54','2008-07-21 22:15:54','Eeeee, uite ca mi-e mi s-a intamplat cam acelasi lucru in Botosani!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.0.1) Gecko/2008070208 Firefox/3.0.1','',0,0),(24778,1086,'hadean','contact@adihadean.com','http://www.adihadean.com','79.113.58.92','2008-05-07 22:22:48','2008-05-07 20:22:48','pÄƒi io ce zic?:-)))deci?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(24779,1086,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','79.116.96.88','2008-05-07 22:23:47','2008-05-07 20:23:47','Deci da!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(26253,1104,'Kissu @ ics','','http://www.pacurar.net','79.116.71.23','2008-05-22 22:27:09','2008-05-22 20:27:09','In farfurie ERA o bucata de tort \"unsa\" bine cu niÅŸte dulceaÅ£Äƒ de trandafiri sau ceva de genul Äƒsta... Era de la una dintre Sf. Elena ;) L-am implorat sa mi-o dea mie, dar zgÃ¢rcitul de el n-a vrut!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(22780,1077,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2008-04-22 22:21:21','2008-04-22 20:21:21','Util! Util :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(33888,1158,'Sorina','contact@plentyoffood','http://community.plentyoffood.net/','89.34.86.80','2008-07-18 23:05:54','2008-07-18 21:05:54','Si eu care credeam ca numai eu sunt o atractie pentru tampiti',0,'1','Opera/9.51 (Windows NT 6.0; U; en)','',0,0),(22783,720,'fleshcaitu','','','92.84.4.192','2008-04-22 23:12:43','2008-04-22 21:12:43','Uai ce chipuri faine! Mai ales ala cu ozeneuri.',0,'1','Opera/9.26 (Windows NT 5.1; U; en)','',0,0),(30781,1138,'baghy','baghy83@lycos.it','http://www.baghy.info','78.12.11.8','2008-06-22 01:31:54','2008-06-21 23:31:54','Aplauze pentru maestru. Acum serios. Ba Gropare la atatea calitati cum nu gasesti o femeie de treaba?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; it; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(30794,1138,'Lucas','lucasfolk@gmail.com','http://folk4noi.wordpress.com/','81.181.42.248','2008-06-22 05:17:53','2008-06-22 03:17:53','hotarat lucru, nu mai stie lumea pastra un secret...http://www.interesulpublic.ro/20-06-2008/Groparu-cu-ochii-pe-o-batranica-la-biserica.html',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.9) Gecko/2008052906 Firefox/3.0','',0,0),(33866,1158,'eu','ripahoratiu@yahoo.com','','81.196.156.83','2008-07-18 16:33:00','2008-07-18 14:33:00','deh, d-aia faci msauratori prin decolteele de instalatori, las ca te stiu io... Te si suspectez cum ca fericirea pe care-l emana blogu\' asta n-ar fi tocma pe baza de baterie de baie...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.16) Gecko/20080702 Firefox/2.0.0.16','',0,0),(30088,1132,'Groparu','groparu_ro@yahoo.com','http://','82.77.126.254','2008-06-18 16:22:14','2008-06-18 14:22:14','Dap.\r\n\r\nPrea multa bere era acolo in cizterna, si prea putin alcool! Da\' am zis ca o sa vars si un camion cu covrigei sarati, sa nu li se aplece la sibieni de la atata Bergenbier verde.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,1),(33861,1158,'Roza','popescu.onita@yahoo.com','','79.117.158.99','2008-07-18 15:31:41','2008-07-18 13:31:41','Ce instalator cumsecade!\r\nNorocos,Groparele,norocos te poti numi! :)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(30083,1137,'hadean','contact@adihadean.com','http://www.adihadean.com','86.125.34.195','2008-06-18 15:50:50','2008-06-18 13:50:50','apoi io Ã®Å£ spui cÄƒ am bÄƒut vin roÅŸu, care-i sculÄƒu de la naturÄƒ, asta Ã®n timpu meciului. ÅŸi cu tÄƒt cÄƒ l-am bÄƒut, nu mi-o crescut pulsu inimii nici un Å£enti, atÃ¢ta de fÄƒrÄƒ sare ÅŸi chiperi o fo. crecÄƒ numa de ÅŸedeu mojicii Äƒia de olandeji cu spinarea la a noÅŸti tÄƒt timpu Ã®i putem bate, o poate nici atunci. da nu-i bai, cÄƒ data viirtoare pote merem la rÄƒzboi operaÅ£ de papÄƒlÄƒptealÄƒ ÅŸi facem o figurÄƒ fainÄƒ, cum o zÃ¢s domu piÅ£i. Äƒsta sÄƒ ne fie mai mare nÄƒcazu. no, despre ÅŸters stiagu de pÄƒ obraz, poate coptilu era supÄƒrat pÄƒ jilet ÅŸi de aia o dat culorile jos, cÄƒ sÄƒ tÄƒt bÄƒrbire ÅŸi tÄƒt acolo le afla. o poate nu. mi-am adus aminte amu ce o zÃ¢s o datÄƒ dijei dani, un pretin cu care am lucrat la radio, dupÄƒ ce i-am caftit pÄƒ alÅ£ pretini la peintbol: bulaaaan, i-am bÄƒtut, sÃ¢ntem echipa neÃ¢nvingÄƒtoareeee!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(24805,1086,'un om','paul_bv@yahoo.com','','82.79.251.239','2008-05-08 05:37:07','2008-05-08 03:37:07','mah da cine-i Nenea asta? pen\'ce partid candideste...',0,'1','Opera/9.27 (Windows NT 5.1; U; en)','',0,0),(22801,1077,'candid','adi.covaci@jumpeye.com','http://www.aicarteaiparte.ro','85.186.103.6','2008-04-23 08:06:26','2008-04-23 06:06:26','Ma bucur ca ti-a placut  ;)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(24819,1086,'CÄƒlÄƒ','acalarasu@gmail.com','http://adriancalarasu.wordpress.com','80.96.53.9','2008-05-08 09:05:16','2008-05-08 07:05:16','Fix pe faza asta a scapat un nene de la mine din bloc, penticostal asa de felul lui si n-o pun peiorativ ca tine, Gropare.\r\nPe faza asta, ziceam, a scapat odata cand l-au luat securistii ca sa-l convinga ca nu exista Dumnezeu, el le-a zis: Pai daca nu exista atunci eu ce caut aici, de ce ma retineti?\r\nDa,si-au zis \"corec\" si i-au dat drumul ma, daca-ti vine-a crede!',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(34320,1160,'Turambar','mirel@ccsb.ro','http://turambarr.blogspot.com','62.217.213.177','2008-07-22 09:56:43','2008-07-22 07:56:43','Ma, te-a platit indianu sa cantzi slave de lauda, mai ceva ca\'n Cantarea Cantarilor. Ma, te\'a mituit indianu cu nishte papa buna de curry carele nu sgarie cu ghearele sale de pisica niscaiva partzi inecsprimabil-necuvantoatoare.\r\n\r\nMa, te lashi mituit. Tz tz tz. Bloggerii ashtia si standardele lor valorice pe zi ce trece mai comestibile...\r\n\r\nTz tz tz. Si cand te gandeshti ca in Telega nu\'i nici un restaurant, nici mongol, nici romanesc, nici indienesc, sa ma mituiasca si pe mine cineva. Poate doar tzatza Leana, cu un kil de lapte proaspat, daca ii vorbesc de bine pe blog despre vaca dumisale. \r\n\r\nDar ce vaca? V\'am povestit ce vaca are tza...\r\n\r\nStai ca nu\'i bine. Nu aici. Pe blog la mine trebuie sa cant despre vaca tzatzei Leana.\r\n\r\n:blink:',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9) Gecko/2008052906 Firefox/3.0','',0,0),(30805,1138,'Greuceanu','','','89.46.104.35','2008-06-22 09:49:14','2008-06-22 07:49:14','mah!  inainte itz lipsea o doaga! acuma am impresia ca numa\' una tz-o ramas!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(33847,1158,'Uca','','','86.34.167.170','2008-07-18 11:45:58','2008-07-18 09:45:58','Era sa te intreb cum de nu a plecat din tara pana acum. Dar la sfarsit am inteles â€“ Cluuuuuujul trebuie sa fie una din destinatiile preferate de emigranti.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1; .NET CLR 2.0.50727; .NET CLR 1.0.3705; .NET CLR 1.1.4322)','',0,0),(30041,1136,'darius f','darius2u@yahoo.com','http://desprepsd.wordpress.com/','82.79.52.137','2008-06-18 11:23:46','2008-06-18 09:23:46','Huo!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(24840,1086,'candid','adi.covaci@jumpeye.com','http://www.aicarteaiparte.ro','85.186.103.6','2008-05-08 16:24:45','2008-05-08 14:24:45','Jongland cu topicul:\r\n\r\n\"Voi va dati seama cat de jmeker este el (groparul) daca uneori aproape ca ne convinge ca nu exista Dumnezeu?\r\n\r\nCine este Groparu? Asta iara este o enigma. Caci dupa cum se stie ceea ce intentionezi tu sa fii, nu va fi cu necesitate ceea ce vei fi perceput ca fiind, deci cine esti tu?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(33844,1158,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-07-18 11:02:55','2008-07-18 09:02:55','Cred ca poarta 42!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.16) Gecko/20080702 Firefox/2.0.0.16','',0,0),(28385,1118,'Adi','adil@yahoo.com','','86.121.116.131','2008-06-07 14:30:12','2008-06-07 12:30:12','Gropare ai ajuns in FHM...fetelor,parca e mai frumos deja,este?',0,'1','Opera/9.27 (Windows NT 5.1; U; en)','',0,0),(28386,1115,'Sweeper','ak70g2@gmail.com','','86.107.192.53','2008-06-07 14:39:27','2008-06-07 12:39:27','\"Trebia sa-i zici in cea mai pura frantuzeasca pe care o cunosc, ca odata am si citit o carte in franceza intreaga: vafanculo!!!!\"\r\n\r\nGropare, aia e macaronara de balta. Nu se pupa cu frantzuza mucegaita.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; .NET CLR 2.0.50727)','',0,0),(22812,1064,'M@riansky','mariankee4@yahoo.com','http://mariansky.dubios.ro/','86.122.94.221','2008-04-23 14:21:06','2008-04-23 12:21:06','Da v-aÅ£i Ã®mbolnÄƒvit rÄƒu cu leapÅŸa asta nu glumÄƒ...',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; InfoPath.2)','',0,0),(22813,1061,'george','reallyinsane@gmail.com','','193.138.195.202','2008-04-23 14:32:23','2008-04-23 12:32:23','La multi ani tuturor celor care isi serbeaza astazi onomastica de nume sau de tip nascator!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9b5) Gecko/2008032620 Firefox/3.0b5','',0,0),(22814,1061,'M@riansky','mariankee4@yahoo.com','http://mariansky.dubios.ro/','86.122.94.221','2008-04-23 14:34:45','2008-04-23 12:34:45','Dar sÄƒ pui aici ÅŸi un logo cu poza de carnet &amp; stop eating that ciainiz ÅŸit cuz cats eat rats u know...',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; InfoPath.2)','',0,0),(22816,1061,'!?_Je_?!','florina_audochii@hotmail.com','','194.102.139.9','2008-04-23 15:02:11','2008-04-23 13:02:11','Don\'t worry!!!\r\nNu esti singurul care sufera de boala asta!!!\r\nMai sunt si altii (io, cel putin) si iti oferim tot suportu\'...... moral, desigur (io, cel putin)!!\r\n\r\nP.S. Io am perceput aceasta postare ca pe un strigat de ajutor, de bagat in seama, asa ca nu aruncati cu rosii stricate, cartofi sau mai stiu io ce :P',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(22817,1061,'ameÅ£itul','','http://ametzitul.wordpress.com','62.217.236.12','2008-04-23 15:26:13','2008-04-23 13:26:13','deci Ã®n curÃ¢nd un nou pericol public pe strÄƒzi?\r\nÃ®n momente ca Äƒsta mÄƒ bucur cÄƒ nu locuiesc Ã®n Cluj... :)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(24838,1086,'tutov','valy_alexe@yahoo.com','http://www.psihopompul.wordpress.com','86.55.176.66','2008-05-08 15:47:57','2008-05-08 13:47:57','Dumnezeu e mai multi.am vazut eu cel putin 3 la otv.de sexe diferite.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(22819,1061,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-04-23 15:40:45','2008-04-23 13:40:45','Nu, nu strigam dupa ajutor, maxim fluieram dupa gajici!\r\n\r\n@ ametitul: te aflu io, nu-i stress:D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(22820,1061,'!?_Je_?!','florina_audochii@hotmail.com','','194.102.139.9','2008-04-23 15:59:57','2008-04-23 13:59:57','Mai fluiera, poate, poate aude cineva :D',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(24841,1086,'ove','ovidiu.zolti@yahoo.com','','86.123.146.168','2008-05-08 16:28:04','2008-05-08 14:28:04','Cine esti? cine esti? .....',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(24842,1086,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-05-08 16:47:04','2008-05-08 14:47:04','N-am chef sa spun \"eu nu sunt eu\"\r\nSi nu am chef ca altii sa mi-o spuna!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(24847,1086,'WhiteWolf','laskmerge@gmail.com','http://white-wolf.ro','79.115.97.41','2008-05-08 17:19:21','2008-05-08 15:19:21','Ceea ce tocmai ai comis nu inseamna ca vrei sa ne determini sa credem ca ne-am trage din alienshi; nu ? :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(22827,1061,'ics','i_uana@yahoo.com','','86.126.99.7','2008-04-23 17:56:47','2008-04-23 15:56:47','Gropare, satisfy my curiosity...fara nici o legatura cu ce ai scris tu aici, doar ca ascultam o melodie care, nu stiu cum se face, inevitabil mi-a amintit  de tine. Deci, ai intalnit vreodata o fata care \"langa ea cand ai ajuns/ [..] de nevoi a plans/ si ti-a spus cu voce tare/ \" te iubesc la disperare!\". e?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(22829,1044,'PuturOSU`','puturosu@mail2manhunter.com','http://www.wraith.ro','89.41.45.156','2008-04-23 18:09:08','2008-04-23 16:09:08','vezi tu..aici e o foarte mare problema... multi nu deosebesc virtualul de real...si ajung sa faca dragoste cu o fereastra de windows... si eu joc travian, si sunt un jucator foarte bun, dar nu ma trezesc noaptea sa dau comenzi... gen lavi... ma joc zilnic..majoritatea timpului ori cu dureri de tavan de la noaptea de dinainte ca a avut 40 de grade...ori cu gandu` la tavaleala de mai devreme cu tipa aia...en fin, nu conteaza, nu o cunoasteti. jocul are grafica banala, nu penala, dar nu e banal, e foarte bine definit si foarte complex, dar unu` care intra si vede decat ce specii sunt... normal ca i se pare \"penal\"...in fine, eu sustin jocul si`l recomand...dar numai celor care stiu sa faca diferenta intre RL si VL... ca altfel se vor transforma in neshte iermi cu radacini... bafta multa straine.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727)','',0,0),(34390,1160,'Turambar','mirel@ccsb.ro','http://turambarr.blogspot.com','62.217.213.177','2008-07-22 22:58:00','2008-07-22 20:58:00','Dragostea se face cu dragostea? Hait! Nu stiam. Eu tot traiam cu impresia ca dragostea se face cu altceva. \r\n\r\nCu totul altceva. Dar ma rog, s\'ar putea sa fi invatzat la alta gradinitza, cu alta programa shcolara.\r\n\r\n:blink:',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9) Gecko/2008052906 Firefox/3.0','',0,0),(30956,1138,'Uca','','','86.34.167.172','2008-06-23 10:47:40','2008-06-23 08:47:40','da sunt faine si experimentele astea',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1; .NET CLR 2.0.50727; .NET CLR 1.0.3705; .NET CLR 1.1.4322)','',0,0),(24865,1084,'Bobby Voicu','bobby_voicu@yahoo.com','http://www.bobbyvoicu.ro/','217.12.15.52','2008-05-08 23:28:32','2008-05-08 21:28:32','Poate... depinde cat de fin e...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(34394,1160,'Name','mail@mailinator.com','','86.107.83.222','2008-07-22 23:30:02','2008-07-22 21:30:02','Cum ma, sa nu-i intrebi de harem? Pe site au si <i>sugestii</i> [..} Sa le iei sa le asezi pe fro 3-4 linii, un 4-4-2.. <i>Grija mare la portar!</i>',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(32952,1153,'seliman','ionut.seliman@gmail.com','http://ionutu.wordpress.com','213.157.171.107','2008-07-08 09:34:09','2008-07-08 07:34:09','VÃ®nt din pupÄƒ Gropare! ;)',0,'1','Opera/9.27 (Windows NT 5.1; U; en)','',0,0),(26443,588,'','','','86.122.50.212','2008-05-24 02:07:41','2008-05-24 00:07:41','sibian :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(26451,316,'cheap kansas','cheap@hotmail.com','http://groups.google.us/group/ticketsss','85.91.82.38','2008-05-24 03:19:12','2008-05-24 01:19:12','gdsgdsf gdsfgdsfg sdgfgdsfg sdfgdsf g<a href=\"http://groups.google.us/group/ticketsss \" rel=\"nofollow\">belk theater tickets</a>',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(24873,1087,'julius constantinescu','julius@universitateacraiova.ro','http://www.7plus.ro/?arhiva=09/05/2008&#38;id=5472','84.232.169.63','2008-05-09 03:32:21','2008-05-09 01:32:21','Gropare, bordelul numai pentru mamelit mi se pare o idee foarte, foarte buna. Vrei placere, platesti! Pana cand sa ne suim in autobuz si sa mamelim gratis, ca nesimtitii?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(32931,1150,'mihai ursu','','http://mihaiursu.wordpress.com','86.163.7.46','2008-07-08 04:37:56','2008-07-08 02:37:56','normal, mah, ca nu avem ce cauta in ue. in csi, e voie sa fumezi unde vrea muschii tai, si in dispensarul gradinitei, iar votca e ca si pe degeaba. aici, unde sint io, adica londonistan, fumezi mai pohales, numai linga ghena de gunoi, iar alcoolul costa de mai bine iti faci un cocteil din aspirine si pasta de dinti, ca aia de la pirnaie...\r\nca sa nu mai zic ca in olanda olandejilor tai acum e voie sa fumezi iarba, dar nu mai ai voie sa aprinzi dracului tigare de tutun. \r\ncum o fi sa il vezi pe hans cristiansen van spiutzen ca il ia la impins vagoane pe fi-su al mic: \"nemernicule, ce tot te spurci cu iarba dracului, de ce nu poti fuma si tu niste cannabis, ca oamenii normali?\"\r\ndeci rusia, frate...',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1)','',0,0),(34458,1161,'ionutu','ionut.seliman@gmail.com','http://ionutu.wordpress.com','213.157.171.107','2008-07-23 07:35:08','2008-07-23 05:35:08','Cumnatul meu croat Ã®i fÄƒcuse soacrÄƒ-mii un cd cu Jovanotti cÄƒ el e cel mai mare fan din CroaÅ£ia a lu\' interpretu\' cu pricina. Åži ÅŸtiind el rumuneÅŸte la nivel de vorbire destul de bine s-a gÃ®ndit cÄƒ e timpul pentru next level: romÃ®neÅŸte scris. Åži vrÃ®nd sÄƒ scrie pe cd Opere/LucrÄƒri Complete, a scris cu font de 48: JOVANOTTI - LUCRURI COMPLETE. :D',0,'1','Opera/9.27 (Windows NT 5.1; U; en)','',0,0),(22849,1061,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','89.137.109.142','2008-04-24 04:59:56','2008-04-24 02:59:56','Mai multe or plans, da\' de fericire ca or scapat de mine.\r\n\r\nFinca le-am dus la disperare!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(24881,1087,'un om','paul_bv@yahoo.com','','82.79.251.239','2008-05-09 05:45:44','2008-05-09 03:45:44','la filiala aia cu adoptii sunt primu client (asta daca n-ai ceva prieteni de bagat inainte, caz in care stau linistit si astept)...\r\niar daca vrei sa te extinzi... pot sa te ajut cu o filiala la Brasov... enitaim!!! cred ca gasesc chiar si vreo duzina de clienti pe termen lung...\r\n\r\nAm putea face un contract cu un orfelinat... si ar fi reciproc benefic... ceva de genul o armata de parinti avang grija de o armata de copchii...\r\nprin rotatie...\r\n\r\nCa pe vremuri cand plecau parintii si ne lasau in grija vecinilor sau prietenilor de familie si cresteam alaturi o cireada de plozi...',0,'1','Opera/9.27 (Windows NT 5.1; U; en)','',0,0),(24888,1087,'ameÅ£itul','','http://ametzitul.wordpress.com','62.217.236.12','2008-05-09 07:38:26','2008-05-09 05:38:26','mÄƒ, io mÄƒ-ndoiesc cÄƒ ar fi prima :)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(22855,1061,'!?_Je_?!','florina_audochii@hotmail.com','','194.102.139.9','2008-04-24 07:38:42','2008-04-24 05:38:42','Daca nu stii sa fluieri, poate d\'aia au ajuns la disperare :P',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(24890,1087,'iulianuss','realvision@k.ro','','193.231.107.209','2008-05-09 08:32:46','2008-05-09 06:32:46','MÄƒi Gropare, dacÄƒ vine la mine cÃ¢nd se simte neconcubitÄƒ? O trimit la tine?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(22858,1061,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-04-24 08:23:28','2008-04-24 06:23:28','Fluier, da\' a paguba.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(24892,1087,'ionutu','ionut.seliman@gmail.com','http://ionutu.wordpress.com','213.157.171.107','2008-05-09 09:28:24','2008-05-09 07:28:24','ÃŽi bunÄƒ ÅŸi asta..dacÄƒ aÅŸ fi bancÄƒ, te-aÅŸ finanÅ£a!',0,'1','Opera/9.27 (Windows NT 5.1; U; en)','',0,0),(32957,1153,'hadean','contact@adihadean.com','http://www.adihadean.com','86.125.34.195','2008-07-08 10:16:00','2008-07-08 08:16:00','apoi fain program. ÅŸi cum meri tu \"tu ze airport\", aÅŸe a mere frÄƒtiucu meu peste o lunÄƒ sÄƒ mÄƒ ie pÄƒ mine ÅŸi sÄƒ mÄƒ batÄƒ nepotÄƒ-mio la \"no te enojas hermano\" (bag samÄƒ cÄƒ aÅŸa Ã®Ã® zÃ¢ce Ã®n spania lor unde s-o dus ii mai demult). ioi cÄƒ abie aÅŸtept sÄƒ stau cu puÅ£a-n mediterana cea lipede ca cristalu\', sÄƒ vÄƒd cum sÄƒ mirÄƒ meduzÄƒle de ie.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.15) Gecko/20080623 Firefox/2.0.0.15','',0,0),(22860,1078,'hadean','contact@adihadean.com','http://www.adihadean.com','194.102.126.6','2008-04-24 09:20:34','2008-04-24 07:20:34','este. da\' io cred cÄƒ-i ÅŸi o buzÄƒciune Ã®n acelaÅŸi timp.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12','',0,0),(22861,1078,'banalu','ra_macovei@yahoo.com','','86.124.52.36','2008-04-24 09:23:56','2008-04-24 07:23:56','Si personajul principal din romanul \"Din Buzoseni, cu dragoste\". Si femeia care a inventat bezeaua. Singura persoana care nu tzuca, ci Pupa. Angelina poate scrie \"teleenciclopedia\" cu buzele. Este singura persoana din lume care poate mima \"hedonism\" doar cu gura. Cand fuma, facea cele mai rotunde rotocoale. Tigarile isi doresc, de altfel, sa fie fumate de Angelina si nu invers. Si tot asa.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(22862,1078,'Andreea','puistrulet2003@yahoo.com','http://n/a','81.196.150.196','2008-04-24 09:25:45','2008-04-24 07:25:45','Ahem, adica  bunaciune nu?\r\n\r\n:)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(24894,1087,'CÄƒlÄƒ','acalarasu@gmail.com','http://adriancalarasu.wordpress.com','80.96.53.9','2008-05-09 10:01:21','2008-05-09 08:01:21','e buna, patenteaz-o si vinde-o la ghei',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(24895,1087,'Lars','lars@targetit.ro','http://www.nenealars.com/','82.76.131.48','2008-05-09 10:16:11','2008-05-09 08:16:11','Si eu care ma intrebam unde sa las copiii in week-end... :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(24896,1087,'parsiimpar','lummi31@gmail.com','http://www.luminita-dragomir.ro/blog','81.196.54.24','2008-05-09 10:21:52','2008-05-09 08:21:52','Finalul e ...apoteotic. :))))',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1)','',0,0),(22864,1078,'ameÅ£itul','','http://ametzitul.wordpress.com','62.217.236.12','2008-04-24 10:20:51','2008-04-24 08:20:51','eu cred cÄƒ el se gÃ¢ndea de fapt la alte buze ale susnumitei...',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(22865,1078,'invidioasa','totmea@yahoo.com','','89.123.106.135','2008-04-24 10:25:41','2008-04-24 08:25:41','no, si?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Zango 10.3.36.0)','',0,0),(32967,1153,'Nello','','','194.117.242.3','2008-07-08 11:56:25','2008-07-08 09:56:25','Unde e restaurantu, gropare ? Si sper ca nu faci o gluma si de fapt e tiganesc...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9) Gecko/2008052906 Firefox/3.0','',0,0),(22869,1076,'Hammer','hammer@alpinet.org','','81.196.168.118','2008-04-24 11:29:55','2008-04-24 09:29:55','Deci daca ati ajunge in Motis fara sa treceti prin Copsa poate asemanarea n-ar fi atat de mare :-D',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(31605,1146,'Roza','popescu.onita@yahoo.com','','79.117.158.64','2008-06-27 15:38:37','2008-06-27 13:38:37','Si eu as fi vrut sa castige rusoteii...\r\nsa fi vazut atuncea finala de finala...\r\nfuhrie vs  stalin...\r\nmacel de macel...\r\npoa\' se isca si vrun razbel!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(24906,1087,'vitalie','sprinceana@mail.md','http://www.spranceana.com/','89.28.16.74','2008-05-09 13:02:39','2008-05-09 11:02:39','eu pot ajuta la infiintarea unei branse la Chisinau, de ce sa n-o facem multinationala???',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(30998,1139,'mo','verde_poveste@yahoo.com','','194.126.220.240','2008-06-23 13:43:43','2008-06-23 11:43:43','Muahahahahahhaha! Muahahahahahahahha!!!!!! Tu-i falafelu\' lui de batranel acru! \r\nApropo, bancu meu preferat cu ovrei (sper sa nu-l stii):\r\nItic si Rasela isi cheama rudele la masa in familie de Craciun. Vin toate rubedeniile fericite sa manance moka si cand ajung, masa intinsa, tacamuri si doua cosuri mari cu paine. itic ii invita sa se aseze si ii indeamna sa manance paine. Iau astia cate o felie si molfaie fara chef la ea. La un moment dat se aude Rasela din bucatarie: \"Itic, au terminat oaspetii de mancat painea, sa pot aduce si eu gaina?\" Sarmanii invitati inteleg ca pana nu e gata toata painea din cosuri nu pupa gaina asa ca se chinuie sa o haleasca pe toata. Rasela striga iar: \"Au terminat oaspetii painea, sa aduc gaina?\" Itic spune ca da, lumea se insenineaza cu gandul la friptura si de dupa usa apare Rasela cu o gaina vie pe care o pune pe masa ca sa ciuguleasca firmiturile de paine. :D',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1)','',0,0),(31036,1139,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-06-23 15:36:04','2008-06-23 13:36:04','Da, deci eu eram, da\' nu eram cu gipu\', decat daca erea negru.\r\n\r\nErea negru?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(31022,1139,'hadean','contact@adihadean.com','http://www.adihadean.com','86.125.34.195','2008-06-23 14:52:14','2008-06-23 12:52:14','no cÄƒ ai descoprit gÃ¢za cu douÄƒ capuri, pfoia, racoviÅ£Äƒ Ã®ÅŸ suje nervii de ciudÄƒ amu! premiu nobel pÃ¢ntru zoolojie te paÅŸte.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(28514,1118,'nonick','agentuzerozeroopt@yahoo.com','','84.232.144.5','2008-06-08 14:52:06','2008-06-08 12:52:06','@Groparu: al Greavului sunt, si ma bucur ca saramura de la Ocna a functionat la tine.\r\nLa peste nu stiu daca-i buna (saramura locala), dar doctorii zic ca pt. cealalta chestie mirositoare functioneste.',0,'1','Opera/9.02 (Windows NT 5.1; U; en)','',0,0),(22880,1078,'james crissilv','jamescrissilv@weblog.roj','http://jamescrissilv.weblog.ro','82.76.149.33','2008-04-24 14:17:55','2008-04-24 12:17:55','nu asta a fost filmul care a lansat-o?\r\no zi minunata iti doresc',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(31044,1139,'raudemusca','raudemusca@gmail.com','','92.82.77.40','2008-06-23 18:27:24','2008-06-23 16:27:24','negru erea vere, si scria COMPASS pe curu lui, sa mor io ce coincidenta, sa circulam ambii amadoi pe aceiasi ruta la aceiasi ora',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14 ImageShackToolbar/4.4.3','',0,0),(24920,1087,'Greuceanu','','','89.46.104.35','2008-05-09 17:29:13','2008-05-09 15:29:13','da\' sh aia insuratzi se pot inscrie la ajentzie?! poate se schimba sotiile  o data la catziva ani, cel putin la o parte prin tragere la sortzi! sa nu bata la uochi ca aici \"nimeni nu are probleme si nimeni nu divortzeaza...\"',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(31043,1139,'pliscu','pliscu@gmail.com','http://pliscu.blogspot.com','89.137.100.118','2008-06-23 18:16:56','2008-06-23 16:16:56','Soseaua pana la Balea cum e? Borbandata? Sau poti merge si pe capota <a href=\"http://video.google.com/videoplay?docid=-6268082647615157600\" rel=\"nofollow\">daca esti hotarat</a>? :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9) Gecko/2008052906 Firefox/3.0','',0,0),(31049,1139,'PhenoBarbieDoll','oana.gavrila@mediafax.ro','','86.120.236.133','2008-06-23 20:20:39','2008-06-23 18:20:39','Oy with the poodles already!',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1)','',0,0),(33208,1152,'csoksi','csoksi@yahoo.com','','86.122.8.71','2008-07-11 15:09:11','2008-07-11 13:09:11','vai ce door o sa-mi fie!!! ai putea sa nu mai scrii deloc ca nu o sa ne lipsesti',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.15) Gecko/20080623 Firefox/2.0.0.15','',0,0),(31447,1145,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-06-26 15:17:18','2008-06-26 13:17:18','Da!\r\n\r\nSi vor deveni nazisti estia, cum le zice, magrebinii, ca nici ei nu or sa-i mai suporte pe albii astia porci si imputiti.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(24933,1088,'ics','i_uana@yahoo.com','','86.126.99.7','2008-05-09 21:16:20','2008-05-09 19:16:20','faina urare, da\' cu o mentiune : \" sa fii plina de SUCCESURI\" . eh, gaseste rima acum la asta :&gt;',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(26594,1094,'Cititor','','','89.36.52.72','2008-05-24 21:17:17','2008-05-24 19:17:17','Telefonia VoIP are dezavantajele ei. Dar pentru abonat primeaza pretul. Noi ca abonati la incheierea unui contract nu intrebam de calitate, intrebam de cost. Sa nu va mire ca in ani operatorii care nu investesc in echipamente devin o mare dezamagire pe banii nostrii dar ei isi asigura lovitura.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(31431,1145,'Nello','','','194.117.242.3','2008-06-26 13:55:20','2008-06-26 11:55:20','Si io vreau un  blog chiar si numai sa imi inchei asa articolul :\r\n\"- Ba Jorg, ba!\r\n- Da, ba Gropare!\r\n- Muie, ba.\"\r\n\r\nAs face si un clip cu aceasta secventa ! :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(33203,1152,'Cristian Ungur','cristian.ungur@utopium.ro','http://cristianungur.blogspot.com','85.186.103.54','2008-07-11 14:32:27','2008-07-11 12:32:27','Esti neserios. Ce, in concediu nu poti scrie? Ca eu am fost la Sibiu si am vazut ca era internet si acolo.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(31393,1145,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-06-26 08:38:46','2008-06-26 06:38:46','@ mo: ej tareeeeee!!! =))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(31385,1145,'Arhi','admin@arhiblog.com','http://www.arhiblog.com','79.117.93.251','2008-06-26 08:10:37','2008-06-26 06:10:37','noroc ca participa israelul, care se stie, e european de pe vremea  cand se taia iisus primprejurul preputului',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.9) Gecko/2008052906 Firefox/3.0','',0,0),(33176,1154,'hurri','hurri_canne@yahoo.com','http://hurrionline.net','89.137.58.105','2008-07-11 07:47:31','2008-07-11 05:47:31','mai tii minte gropare cand n-ai dat tipului de la colt 1 leu de prenandez? sau cand nu i-ai cedat locul babei din autobuz? trecutu` te urmareste maestre...pe tine si pe colegii tai. :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.9) Gecko/2008052906 Firefox/2.0.0.14;MEGAUPLOAD 1.0','',0,0),(31376,1139,'Hammer','pontos.alin@gmail.com','','81.196.168.118','2008-06-26 07:36:44','2008-06-26 05:36:44','ai mai betoana zona din Fagaras unde poate urca omu\' sa prajasca un mic.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(22941,1078,'hadean','contact@adihadean.com','http://www.adihadean.com','194.102.126.6','2008-04-25 08:48:14','2008-04-25 06:48:14','Gropare, PaÅŸte fericit.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12','',0,0),(22942,1061,'Turambar','mirel@ccsb.ro','http://turambarr.blogspot.com','79.114.190.23','2008-04-25 09:17:34','2008-04-25 07:17:34','Aha. Deci itz ei carnet. Aha. Deci tot in suburbia aia austro-ungara locuieshti. Aha. Deci az ma vad cu Ametzitu shi ne imbatat creshtineshte, in Vinerea Mare, de bucurie ca traim intr-un orash bucuros, carele ne desparte un lant muntos de natura orogenica shi nishte sute bune de kilometri de primejdie.\r\n\r\nVezi de ce e bine sa traieshti in Balcani? Pentru ca nu traieshti in Cluj shi nu te loveshte mashina condusa de de\'alde de\'ashtia care ish ia acuma carnetu carele sa ne loveasca pe noi care am trait shi facut copii shi muncim shi platim taxe la stat ca sa ne loveasca incepatorii ashtia pe trecerea de pietoni ca ma duc acuma sa\'mi las sacosha la coada la elicoptere ca asha ceva nu se mai poate shi nu mai suport shi de ce este viatza asha de grea shi de agera a zis cineva ager am o privire agera care uite nishte domni in paltoane albe cu plase de prins fluturi care imi face cu mana da eu am o privire ageRAAAAAA\r\n\r\nAAAAAARGHHHHH.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(22943,1061,'Greuceanu','','','89.46.104.35','2008-04-25 09:18:21','2008-04-25 07:18:21','ba-za,\r\n\r\ndaca nora le \"lipseshte o doaga, n-aopi sa jti ca doaga aia e la tine! dar numai aia o ai! restu\' iti lipsesc toate\"',0,'1','Opera/9.25 (Windows NT 5.1; U; en)','',0,0),(22944,1078,'Turambar','mirel@ccsb.ro','http://turambarr.blogspot.com','79.114.190.23','2008-04-25 09:21:05','2008-04-25 07:21:05','Mda. Dar pe langa asta, shi moreover, mai este shi o bucoshenie. Ba chiar shi o bucaciune. Pe langa faptul ca este o bunaciune shi o bunoshenie.\r\n\r\nDar cam slaba. Shi din plastic. Definitely din plastic. Pen\' ca doar femeile din plastic carele va sa zica ca noi nu avem acces never ever la ele. Therefore e din plastic.\r\n\r\nTherefore lament and wails. And gore and slaughter. And emptiness and sorrow.\r\n\r\nHai, miel fericit!\r\n\r\n:)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(33045,1149,'Sinzi','fata_cu_par_verde@yahoo.com','','86.123.76.106','2008-07-09 10:41:31','2008-07-09 08:41:31','oaaaiii...sa ma vedeti pe mine in frageda pruncie cum in tabara fiind pe la Busteni m-am dus sa-mi cumpar o paine :\r\n- buna ziua , vreau o paine!\r\n- o pita?\r\n- o paine!\r\n- o pita?!\r\n- NU , o PAINE\r\n( femeia intinde painea)\r\n- DA , o PITA',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.15) Gecko/20080623 Firefox/2.0.0.15','',0,0),(28643,1119,'Turistu','asds@zsdas.re','http://www.turism-forum.ro','213.157.188.71','2008-06-09 11:33:19','2008-06-09 09:33:19','gropare, asta ii numa inceputu. azi mane te vedem prin reviste porno. numa sa n-ajungi in alea pt poponari :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(24982,1087,'Unu','unu@mailinator.com','','86.107.83.222','2008-05-10 11:44:26','2008-05-10 09:44:26','Vizite trimestriale la socrii? Aia nu e casatorie de \"convenienta\". Ala e lagar de concentrare. Sa se introduca in codu muncii meseria de consoarta. Cand o fi asta bine platita si la mare cautare (eventual la munte), atunci sa-ti faci dumneata si agentie si companie si corporatie si ce vrei matale. Niste mici cu bere si Salam in fata scarii blocului n-ar merge? Zic si eu..',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8','',0,0),(28638,1119,'Catzaua','ana.man.fox@gmail.com','http://catzaua.wordpress.com','213.233.101.70','2008-06-09 11:15:39','2008-06-09 09:15:39','nashu\', .. felicitari mari, late si felicitatoare. ai mai trecut o steluta la blog. pe cand la TeVeu? :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(28639,1119,'Andreea','puistrulet2003@yahoo.com','http://n/a','81.196.150.196','2008-06-09 11:17:48','2008-06-09 09:17:48','Congratulationes.....:)))\r\n\r\nSper sa nu ti se urce la capsor..\r\n\r\nA.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(33050,1153,'eu','ripahoratiu@yahoo.com','','81.196.156.83','2008-07-09 12:06:18','2008-07-09 10:06:18','Aha, d-aia n-ai raspuns cand am vrut sa te chem sa bem o bere in gura.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.15) Gecko/20080623 Firefox/2.0.0.15','',0,0),(31103,1144,'ics','i_uana@yahoo.com','','86.126.99.7','2008-06-24 12:44:35','2008-06-24 10:44:35','carevasazica, si voo va plac chestiile lungi, tari si lipicioase ...s-a zis cu nimfa lacului',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(33781,51,'miru be','miruna_stefana@yahoo.com','','86.55.81.75','2008-07-17 22:09:44','2008-07-17 20:09:44','eu cred cÄƒ vÄƒ lipseÅŸte doar spiritul practic.ÅŸi o dozÄƒ de nesimÅ£ire tupeistÄƒ.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.16) Gecko/20080702 Firefox/2.0.0.16','',0,0),(33782,53,'miru be','miruna_stefana@yahoo.com','http://mirubesoddstuff.blogspot.com/2008/06/balchik.html','86.55.81.75','2008-07-17 22:17:25','2008-07-17 20:17:25','mdeah,bulgarii nu pot vorbi nicio limbÄƒ strÄƒinÄƒ,Ã®n schimb pot comenta Ã®n bÃ¢lbÃ¢iala lor despre \"rumÃ¢niÅŸii\" care,deÅŸi se pot exprima fluent ÅŸi pot Ã®nÅ£elege vreo douÄƒ-trei limbi strÄƒine,nu se pot lÄƒmuri de ce trebuie sÄƒ plÄƒteascÄƒ 8leva,cÃ¢nd au stat Ã®n parcare trei ore ÅŸi douÄƒ minute ÅŸi ora costa 2LB...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.16) Gecko/20080702 Firefox/2.0.0.16','',0,0),(24990,1088,'Laura','lauraciuci@yahoo.com','','89.41.218.173','2008-05-10 13:17:41','2008-05-10 11:17:41','mai, ics, esti plin de stresuri, huh? :) lasa omu\' \"impace\" cum scria cineva...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11','',0,0),(31104,1139,'Sweeper','ak70g2@gmail.com','','86.107.192.53','2008-06-24 13:57:38','2008-06-24 11:57:38','Deci nu te legi de Sambata de Sus, ca te aia mama dracu\' Gropare. Bunicii din partea lu\' tata erau de-acolo si unchiu\'meu de spitza a 16-a e staretz. Vrei sa fii afurisit?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; .NET CLR 2.0.50727)','',0,0),(28656,1119,'julius','julius@universitateacraiova.ro','http://www.7plus.ro/?arhiva=09/06/2008&#38;id=6711','84.232.160.62','2008-06-09 14:24:20','2008-06-09 12:24:20','@groparu: sper ca nu incerci sa-i vinzi castraveti gradinarului, da? io am descoperit site-urile de pornache inainte sa aflu ca s-a inventat internetul :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(22965,1079,'ramonici','mum_2_us@yahoo.com','http://www.ramonaa.deviantart.com/','79.119.149.154','2008-04-25 15:17:19','2008-04-25 13:17:19','stai in manastur? :)) ce rad, ca si eu stau =))',0,'1','Opera/9.26 (Windows NT 5.1; U; en)','',0,0),(22967,1079,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-04-25 15:44:38','2008-04-25 13:44:38','Najpa de ei!\r\n\r\nDe manajtureni, zic.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(22968,1078,'ionutu','ionut.seliman@gmail.com','http://ionutu.wordpress.com','82.78.189.109','2008-04-25 15:44:43','2008-04-25 13:44:43','Pun pariu ca cand erea ea mica avea de furca pe plan social la fel ca ratusca cea urata a lu\' Andersen. Acuma e\'o lebadoaie cu buza mare. Daca s-ar fi nascut in Romainiea s-ar fi numit BuzamÄƒt Angelina?',0,'1','Opera/9.27 (Windows NT 5.1; U; en)','',0,0),(33759,485,'pliscu','pliscu@gmail.com','http://pliscu.blogspot.com','89.137.100.118','2008-07-17 17:10:02','2008-07-17 15:10:02','Dac-ai fi vrut concedii lungi ÅŸi plictisitoare, de ce n-ai rÄƒmas tu profesor???\r\n\r\n(Ã®Å£i dai seama ce-mi mere mintea, de mÄƒ prind cu Ã®ntÃ¢rziere de un an ÅŸi ceva... :P )',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9) Gecko/2008052906 Firefox/3.0','',0,0),(33756,1157,'Uca','','','86.34.167.172','2008-07-17 17:00:28','2008-07-17 15:00:28','Cel putin te-a respectat suficient si nu ti-a dat tie zama cu pricina. Asta daca s-o fi gandit inainte.\r\nDaca se gandea si ti-o dadea tie, atunci trebuia sa-ti faci cu adevarat probleme.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1; .NET CLR 2.0.50727; .NET CLR 1.0.3705; .NET CLR 1.1.4322)','',0,0),(29861,1127,'catalin','catalin_heghes@yahoo.com','http://heghes.blogspot.com','84.232.142.163','2008-06-17 16:59:20','2008-06-17 14:59:20','ionescu asta si mie-mi scrie de cÃ¢teva sÄƒptÄƒmÃ¢ni bune cam tot o datÄƒ la 3-4 zile...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(32334,1149,'eve','sushica2005@yahoo.com','','86.120.69.132','2008-07-02 17:34:42','2008-07-02 15:34:42','aia cu fusei sunt olteni  :P',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(22970,1079,'ionutu','ionut.seliman@gmail.com','http://ionutu.wordpress.com','82.78.189.109','2008-04-25 15:50:34','2008-04-25 13:50:34','Apropo de enoriasi, biserici, popi, Doamne Doamne.\r\nCum poate fi El, Doamne Doamne, Atotputernic ÅŸi Preamilostiv...Ã®n acelaÅŸi timp?\r\nSÄƒrbÄƒtori fericite!',0,'1','Opera/9.27 (Windows NT 5.1; U; en)','',0,0),(22971,1079,'Lars','lars@targetit.ro','http://www.nenealars.com','82.76.131.48','2008-04-25 15:52:33','2008-04-25 13:52:33','Uite de-aia ne umplem de pacate, ca ele stau! :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(33136,1154,'.marius','marius@perijoc.com','http://marius.wirelessisfun.com','79.116.79.124','2008-07-10 17:49:41','2008-07-10 15:49:41','@groparu apai io cred ca tie ti ciudÄƒ mÄƒ cÄƒ nu are ÅŸi tu maÅŸinÄƒ ÅŸi de aia ai zgÃ¢riat maÅŸinile colegilor... puteai ÅŸi tu sÄƒ fii mai suptil si sa ridici un ÅŸtergÄƒtor sau sa dezumflii o roatÄƒ... \r\n\r\ntisk tisk tisk...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9) Gecko/2008052906 Firefox/3.0','',0,0),(22977,1079,'Usim','mihaimitan@gmail.com','','87.237.108.33','2008-04-25 16:33:13','2008-04-25 14:33:13','Sa Pasti fericit Gropare!\r\nCat despre pacate, din lista ta io zic ca numa\' tutunu-i pacat. Si nu pacat de la Dumnezeu ci pacat de sanatatea ta. Sanatate pe care eu ti-o doresc!\r\n\r\nSa stii ca esti asteptat in continuare in Bucuresti. Berea-i la rece.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648)','',0,0),(22979,1079,'Mazgalici','fcmazgalici@yahoo.com','http://mazgalici.ro','82.208.151.149','2008-04-25 16:53:09','2008-04-25 14:53:09','Cine sapa groapa altuia se cheama gropar',0,'1','Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.1.11) Gecko/20060601 Firefox/2.0.0.11 (Ubuntu-edgy)','',0,0),(22984,1079,'sophia','paula_sofia_d@yahoo.com','','86.122.37.172','2008-04-25 18:15:22','2008-04-25 16:15:22','Intzeleg ca te tragi din Sibiu? Sibiu - municipiu sau Sibiu - judet? Oricum, nu intzeleg : ce naiba ai cautat la popa sa te spovedesti ? Pai nu m-as duce.... never! ... sau ... ba da, daca ar fi Keanu Reeves popa si m-ar pune in genunchi... [....]... oh, mama, ce m-as mai spovedi... in fiecare zi!!!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(29895,1136,'Kissu @ julius','','http://www.pacurar.net','79.116.70.125','2008-06-17 19:57:01','2008-06-17 17:57:01','Lamurire: totul a pornit de la Firefox 3... programat cu surle si trambiite sa fie rilisuit azi la ora 17:00 UTC (Coordinated Universal Time)... Eu am suduit: \"Bag pu...shca, pana si astia de la MozÃ®la Ã®s utecishti!\" Restul e prezentat mai sus, in post. ;) Sau nu intelegi legatura dintre UTC  PSD?! ;)))))))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(22993,1079,'ramonici','mum_2_us@yahoo.com','http://www.ramonaa.deviantart.com/','79.119.149.154','2008-04-25 20:59:07','2008-04-25 18:59:07','chiar e nashpa de manastureni... sunt departe de civilizatie ;))',0,'1','Opera/9.26 (Windows NT 5.1; U; en)','',0,0),(28710,316,'map','map@hotmail.com','http://groups.google.us/group/linkmaps','61.86.36.2','2008-06-09 23:02:45','2008-06-09 21:02:45','great work great site thanks http://groups.google.us/group/linkmaps bye see you',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(31138,1144,'Ionut','iong002@yahoo.com','','89.34.225.25','2008-06-25 01:08:36','2008-06-24 23:08:36','RATUC fiind un RATB clujean, nu? :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(33764,1157,'Usim','mihaimitan@gmail.com','','87.237.108.33','2008-07-17 18:27:35','2008-07-17 16:27:35','Al\'data sa nu mai mananci cu ejipteni care nu stie de gluma, sa bei! Ca poate le vine simptul umorului. Numa ca aia nu prea beu (dacat pe ascuns sau cand nu-i vede Allah) ca e un fel de pocaitii lu\'Mahomed.\r\nNu ma duce mintea cum sa iesi din impasul aiesta.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648)','',0,0),(23011,1079,'Sibilla','sibilla_poesis@yahoo.com','http://sfinx667.wordpress.com','89.123.5.0','2008-04-26 03:38:16','2008-04-26 01:38:16','Sarbatori Pascale fericite si binecuvantate alaturi de toti cei dragi ! Lumina Sfanta sa te daruie cu sanatate si impliniri ! Pasti fericit !\r\nnoua, sa ne daruie Iepurasul un cosulet imens si nesecat de zambete din partea minunatului \" nascut din spermatozoizi campioni \" catre umilii care suntem...\r\nuitasi sa zici ceva si despre cei/cele care nu se pleaca, dar, le plac plecaciunile... \r\nrespecte si pretuire,\r\nSibilla',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(25144,1085,'Hammer','hammer@alpinet.org','','81.196.168.118','2008-05-12 10:16:52','2008-05-12 08:16:52','Berea ANTIRID',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(27035,1097,'Rin Tin Tin','zediable@yahoo.com','http://tsigaradedupa.wordpress.com','217.20.167.41','2008-05-27 10:17:57','2008-05-27 08:17:57','Pffft. Oricum restaurantele chinezesti sunt jegoase, altfel n-ar fi asa gustoase ( lol ). Dar cred ca exportul de victime ar costa prea mult, desi la ce molime banuiesc ca sunt pe-acolo, ar dori asa ceva, bietzii.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(28895,1121,'Turambar','mirel@ccsb.ro','http://turambarr.blogspot.com','79.114.190.107','2008-06-11 10:36:33','2008-06-11 08:36:33','waw :blink: \r\n\r\nThat\'s a mighty strong substance that you smoke, mate. Respira, vidro...\r\n\r\n:blink:\r\n\r\n@ Andreea: yup. _xulescu te-a trimis bine. Aia e... \r\n\r\nBatman! Batman!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(26867,1105,'sweeper','ak70g2@gmail.com','','89.122.203.71','2008-05-26 11:32:53','2008-05-26 09:32:53','Baga poze, detalii si film, Gropare! Sa vedem paranghelie Gropareasca! Tot va calc io la anu\'...',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1)','',0,0),(28773,1121,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-06-10 11:27:19','2008-06-10 09:27:19','Pai mo mo, pai daca io rezolv toate astea, despre ce mai scriu pe blog? Despre Orange, asa cum voi scrie maine?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(28777,1121,'Andreea','puistrulet2003@yahoo.com','http://n/a','81.196.150.196','2008-06-10 11:54:18','2008-06-10 09:54:18','Io cred ca rugaciunile cuiva au fost ascultate, tu ce zici Gropare? Ia fain frumos, iei o coala de hartie, un creionas si scrie tu din memoria ta fantastica cine crezi tu ca ti-ai dori :\"asa mult bine\" :)\r\nPoate poate....\r\n\r\nPS: nu noi am fost...:)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(23037,1079,'WhiteWolf','contact@white-wolf.ro','http://white-wolf.ro','79.115.97.4','2008-04-26 11:22:49','2008-04-26 09:22:49','Sa mÃ nci, sa beai si sa sheikÃ£nesthi mÃ£nurile shi chicioarele ca tare ti-o fi fo\' greu dupa post, Gropare.\r\nSi sa inchini un pahar si pentru mine (pentru noi) care\'tz dÃ£m sens blogului si poftei zilnice de aberat intru lÃ£tzirea zÃ mbetului iliescean (ala de se opreste fix in urechi), om bun. Nu de alta da\' io am sa o fac cu siguranta. Ca meriti\r\n<b>Sa-ti fie liniste si luminÃ£ !</b>\r\nA! - si sa nu uit; sÃ£ ai oo tari ! :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(28780,1121,'Turambar','mirel@ccsb.ro','http://turambarr.blogspot.com','92.80.54.150','2008-06-10 12:00:38','2008-06-10 10:00:38','Nasol. Io tz\'am spus sa te faci ateu. Tu nu shi nu. \"Batman! Batman!\". Acuma fereshte pterodactilii. Nasol. Life is a bitch and then we start lighting candles.\r\n\r\nRun, Gropare, run...\r\n\r\n:(',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(33130,1154,'add','addatwork@gmail.com','http://add-at-work.com/blog','82.76.38.219','2008-07-10 16:47:52','2008-07-10 14:47:52','Gropare, here\'s an idea: sa nu le mai parcheze pe trotuar nene :)\r\n\r\nAm si eu unu la Medicina care se smneaza pe capote, orizontal prima data cand o parchezi in gura intrarii la medicina si in zig-zag de la a doua incolo. \r\n\r\nDaca-l prind nu stiu daca sa-i strang mana ca din cauza lui am si eu pe unde trece sau sa-l dau in gat ca a facut pagube de vrun mertan mai mic asa pana acu\'.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.0; en-US; rv:1.9) Gecko/2008052906 Firefox/3.0','',0,0),(31197,1144,'Andreea MKT','supergirgir@yahoo.com','http://marlahermina.deviantart.com/gallery/','82.77.126.254','2008-06-25 13:26:03','2008-06-25 11:26:03','sa se tina barbatzii de barele luni si lipicioase, noi ne tinem de barbatzi.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; InfoPath.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(28793,1121,'Andreea','puistrulet2003@yahoo.com','http://n/a','81.196.150.196','2008-06-10 13:13:30','2008-06-10 11:13:30','@Turambar... frumos sfat....:)) (am ras bine); legat de expresia \"Batman! Batman\" ma lamuresti si pe moi, de unde vine? O prietena de-a mea o tot spunea dar nu intelegeam de ce... And iti is KILLING MEEE!\r\n\r\n\r\nMersi, \r\nA.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(28797,1121,'Andreea','puistrulet2003@yahoo.com','http://n/a','81.196.150.196','2008-06-10 13:40:01','2008-06-10 11:40:01','@ _xulescu: mersi mersi... :) ; in sfarsit...\r\n\r\nA.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(28788,1121,'Ucu','simeria@yahoo.com','','160.213.122.247','2008-06-10 12:51:54','2008-06-10 10:51:54','...de une si vorba ca Dumnezeu nu bate cu bota :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.0; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(28794,1121,'_xulescu','s_a_b_i_n@mymail.ro','','81.196.150.96','2008-06-10 13:28:18','2008-06-10 11:28:18','@Andreea: \r\nwatch this:\r\n\r\nhttp://youtube.com/watch?v=RdVizi4O5X8',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648; InfoPath.1; .NET CLR 3.5.21022)','',0,0),(29841,1135,'alexnicolae','alexnicolae@gmail.com','http://alexnicolaeblogspot.com','62.180.224.130','2008-06-17 15:29:52','2008-06-17 13:29:52','am schimbat un usb mai mic pe un usb mai mare la metro. easy. apoi o trebuit sa schimb o ghilotina mica pe una mare, si atata o comentat si o fatzait ca poate am stricat ghilotina.. da pana la urma le-am ecsplicat ca luam un produs de 2 ori mai scump si dam unu mai ieftin si ei castiga la faza asta ca le fac reclama.si ni l-o dat pe ala mai afumat din vitrina, ala pe care o pus toti oamenii destele sa vada daca taie ghilotina aia. asta noua e invatata si mere bine. ailalta nu. \r\nasta din seria ce am schimbat io si unde si pe ce.',0,'1','Mozilla/4.0 (compatible; MSIE 5.01; Windows NT 5.0; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(26900,1105,'hadean','contact@adihadean.com','http://www.adihadean.com','86.125.34.195','2008-05-26 16:23:07','2008-05-26 14:23:07','no, nu te nÄƒcÄƒjÃ¢, o sÄƒ vez cÄƒ de fapt Ã®i un pitic pe\' mic pÃ¢ntru un creier aÅŸe de mare ÅŸi pÃ¢nÄƒ la urmÄƒ sÄƒ dÄƒ Ã®nfrÃ¢nt.serus!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(33137,1154,'seliman','ionut.seliman@gmail.com','http://ionutu.wordpress.com','82.78.189.109','2008-07-10 17:59:20','2008-07-10 15:59:20','ÃŽnainte sÄƒ-i tÄƒbÄƒceascÄƒ bÄƒjeÅ£ii ceafa cu cÄƒlcÃ®ie, sÄƒ -l Ã®ntrebe ÅŸi de Å£oacla ta, mai ÅŸtii? Poate dai de ea.. :D',0,'1','Opera/9.50 (Windows NT 5.1; U; en)','',0,0),(33138,1154,'UnCopilutz','uncopilutz@yahoo.com','http://www.uncopilutz.haipa.ro','79.116.64.179','2008-07-10 18:18:24','2008-07-10 16:18:24','ÅžTIIIIU: MergeÅ£i la lucru cu bicicleta!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.15) Gecko/20080623 Firefox/2.0.0.15','',0,0),(25085,1088,'Emaginatoru','e_magistatyahoo.com','','79.116.81.126','2008-05-11 18:44:25','2008-05-11 16:44:25','Imi imaginez discutie in firma: ma Gro, vine zua lu shefa. Sa nu te pui al\' rau sa nu-i scrii o dedicatze cacum ai scris la noi tatz, ca ne tae la tatz oole. Si auzind Groparu una ca asta, se apuca de scris. Si scrise el ce scrise pana catrenul se lungi suficient de mult sa scape oole lu colegii lui si ale sale proprii sa fie menajate de menajeritza.\r\n\r\nDeci, Gropare fii atent la mnine! Keep up the good work, ca daca o sa incepi sa scrii mai subtirel o sa stim totzi ce ai patit.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(28832,1119,'deci,totodatÄƒ...','costelush70@yahoo.com','','92.80.236.35','2008-06-10 19:51:09','2008-06-10 17:51:09','ia cearca un drept la replica,asa la mijto! scapi prilej bun de a te face auzit(vazut) ,si daca nu primesti,fa-i de cacat,da-i in mortzii masii de luzeri ciufutzi!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(33143,1154,'Ionut','id_as2000@yahoo.com','','89.34.225.25','2008-07-10 20:31:13','2008-07-10 18:31:13','O camera mica ascunsa intr-un colt',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(23065,1079,'james crissilv','jamescrissilv@weblog.ro','http://jamescrissilv.weblog.ro','86.120.67.72','2008-04-26 19:41:52','2008-04-26 17:41:52','Paste Fericit\r\nun weekend minunat iti doresc',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; SLCC1; .NET CLR 2.0.50727; .NET CLR 3.0.04506; .NET CLR 1.1.4322)','',0,0),(33750,1157,'hadean','contact@adihadean.com','http://www.adihadean.com','86.125.34.195','2008-07-17 15:17:41','2008-07-17 13:17:41','no, daca musca nu era decedatÄƒ pÃ¢n spÃ¢nzurare cu un fir de pÄƒr nici scurt, nici lung, nici subÅ£ire nici lins da\' creÅ£ bine ci pÃ¢n Ã®nec Ã®n zamÄƒ curatÄƒ, nu-i de dat la ÅŸtiri. da nici de mÃ¢ncat acolo nu-i, cÄƒ de bunÄƒ samÄƒ nu s-o Ã®necat musca Ã®n blid de la bucÄƒtÄƒrie la masÄƒ, io cred cÄƒ o dat colÅ£u unieva deasupra la plita pÄƒ care stÄƒte oala cu zamÄƒ fÄƒrÄƒ figheu. ÅŸi mai cred cÄƒ ÅŸi friptanu egipÅ£ianului o fo dint-o bucatÄƒ de vacÄƒ nebunÄƒ, mai nebunÄƒ decÃ¢t vaca Ã®nsÄƒÅŸi.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.16) Gecko/20080702 Firefox/2.0.0.16','',0,0),(25099,1088,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','79.116.97.12','2008-05-11 21:38:45','2008-05-11 19:38:45','Deci mo, Mihaiela din poiezie nu mi-e sefa :) d-aia imi permit sa ii radic osanalÄƒ acilea. A, si si din cauza ca e o femeie de treaba!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(33748,1157,'pliscu','pliscu@gmail.com','http://pliscu.blogspot.com','89.137.100.118','2008-07-17 14:53:03','2008-07-17 12:53:03','@fotoghin: aia era vorba mea! VORBA MEA!!\r\n\r\nCare, de fapt, ii dintr-un banc, ca nu-s io ashe inteligent... :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9) Gecko/2008052906 Firefox/3.0','',0,0),(31297,1139,'Cu Ssangyong Kyron pe Transfagarasan | Blogul lui Bobby Voicu - alpha beta version','','http://www.bobbyvoicu.ro/cu-ssangyong-kyron-pe-transfagarasan.html','212.146.105.56','2008-06-25 23:48:44','2008-06-25 21:48:44','[...] (unde am facut si poze - poze cu masina aici). La Balea m-am vazut si cu Andrei Crivat si Groparu. Care erau cu jumatatile lor, sa nu credeti ca erau impreuna. Adica erau impreuna&#8230; eeeee, va [...]',0,'1','Incutio XML-RPC -- WordPress/2.5','pingback',0,0),(31406,1139,'Groparu','groparu_ro@yahoo.com','http://','82.77.126.254','2008-06-26 10:29:22','2008-06-26 08:29:22','Mo, deci pe partea asta despre Ardeal e - cum sa-ti zic, oglinda.\r\n\r\nIo am tot zis asta: pacat ca e-n Romania. Mare pacat.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,1),(25141,1085,'ucshiva','mail@ucshiva.net','http://ucshiva.net','89.46.44.249','2008-05-12 10:05:37','2008-05-12 08:05:37','Fara anti-celulita n-ai facut nimic. :-S',0,'1','Opera/9.25 (Windows NT 5.1; U; en)','',0,0),(25104,1088,'fuck politics - ma alatur &laquo; Gandurilemariei&#8217;s Weblog','','http://gandurilemariei.wordpress.com/2008/05/11/fuck-politics-ma-alatur/','72.233.94.33','2008-05-11 22:55:32','2008-05-11 20:55:32','[...] ca merita atentie si o dau si eu mai departe aici, aici, aici, aici, aici, aici, aici, [...]',0,'1','Incutio XML-RPC -- WordPress/MU','pingback',0,0),(29811,1135,'mo','verde_poveste@yahoo.com','','194.126.220.240','2008-06-17 12:52:24','2008-06-17 10:52:24','oki, oki, atunci ramane de educat apoticareasa ;)\r\natata numa ca in cazu\' asta o pocnitura cu o cutie de ceai nu cred sa functioneze... atlasu\' botanic in schimb e cu totul alta treaba.....',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1)','',0,0),(32298,1148,'cris','plattamon@yahoo.com','','89.136.54.77','2008-07-02 12:43:07','2008-07-02 10:43:07','deci...io m am dus sa imi platesc factura la net si era una care era toata izghita in spatele meu, pana m am intors la ea si i-am zis doamna, va rog sa va dati jos de pe mine. si ea o zis vai, dar v am facut ceva? da, ma izbeatzi cu janta peste chicioare si ma chisca fiinca is arsa de soare. si ea o zis , o vai.......si io m-am dus 2 cm mai incolo.....si o ramas conflictu in aer.ca la Cluj:))',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(32286,1148,'un om','paul_bv@yahoo.com','','82.79.251.239','2008-07-02 11:42:33','2008-07-02 09:42:33','da poate ierea de djej? care se stie ca ie un pol mai ceva ca cluju...',0,'1','Opera/9.50 (Windows NT 5.1; U; en)','',0,0),(33731,1156,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-07-17 11:44:16','2008-07-17 09:44:16','Dap! Un trib intreg de tzatze guale, da\' guale-guale!!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.16) Gecko/20080702 Firefox/2.0.0.16','',0,0),(29797,1135,'mo','verde_poveste@yahoo.com','','194.126.220.240','2008-06-17 11:43:36','2008-06-17 09:43:36','*plantele medicinale (dumbass me)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1)','',0,0),(33733,1156,'Turambar','mirel@ccsb.ro','http://turambarr.blogspot.com','84.232.187.214','2008-07-17 12:05:26','2008-07-17 10:05:26','Oamenii de stiinta, dupa indelungate analize si bugete de cercetare obtinute prin granturi guvernamentale, au ajuns la concluzia, studiind un esantion reprezentativ de barbatzi de sex masculin, ca exista o corelatie negativa semnificativa ( p ',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9) Gecko/2008052906 Firefox/3.0','',0,0),(33734,1156,'Turambar','mirel@ccsb.ro','http://turambarr.blogspot.com','84.232.187.214','2008-07-17 12:06:53','2008-07-17 10:06:53','Damn it. Semnele astea de punctuatzie care scurteaza viatza shi lungimea postului. \r\n\r\nAgain... :(\r\n\r\n=====\r\n\r\nOamenii de stiinta, dupa indelungate analize si bugete de cercetare obtinute prin granturi guvernamentale, au ajuns la concluzia, studiind un esantion reprezentativ de barbatzi de sex masculin, ca exista o corelatie negativa semnificativa ( p miai mic decat 0.01) intre normalitate, culoarea chilotzilor, volumul creierului in centrimetri cubi si lungimea instrumentului de placeri primitive, da\' bune. \r\n\r\nDe asemenea, un colectiv de oameni de stiinta polonezi, mai destepti, dar mai saraci decat omologii lor americani sau francezi, au descoperit explicatia de tip adaptativ a extremitatii calosferice a sus-numitului instrument de placeri conjugale si / sau vinovate. Insa aceasta este subiectul unei alte comunicari stiintifice, de natura jocular-populara, pe care presupun ca o stie tata lumea, ca d\'aia s-au inventat bancurile, sa fie spuse in weceu la liceu, in pauza, la tigara aia buna si cancerigena.\r\n\r\nThe rest is intercourse, of course.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9) Gecko/2008052906 Firefox/3.0','',0,0),(33738,1156,'WhiteWolf','laskmerge@gmail.com','http://white-wolf.ro','79.118.187.150','2008-07-17 12:39:47','2008-07-17 10:39:47','Daca nici nu stii... hai ca mi-am amintit si mai ca pot sa-ti dau un hint.\r\nO mai tii minte pe aia a lu\' Ioan Gyuri Pascu cu <b>Africa, Africa, ah ce vis fierbinte</b> ? :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.16) Gecko/20080702 Firefox/2.0.0.16','',0,0),(23089,1079,'Sibilla','sibilla_poesis@yahoo.com','http://sfinx667.wordpress.com','89.123.14.173','2008-04-27 02:13:18','2008-04-27 00:13:18','Hristos a Inviat !\r\nLumina Sfanta sa ne mangaie sufletele, tuturor !\r\nrespecte si pretuire,\r\nSibilla',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(29795,1135,'mo','verde_poveste@yahoo.com','','194.126.220.240','2008-06-17 11:42:09','2008-06-17 09:42:09','@ hadean:\r\nNeeee, n-ai tu timp de probat chestii cand tre sa faci scandal! ;)\r\nDeci se ia cutia de ceai de musetel si, in functie de disponibilitatea omului de a se deplasa, se pocneste in frunte ori una bucata gagica pana isi uita aminirile de kindergarten ori una bucata farmacista pana invata diferenta intre planetele medicinale.\r\n@ groparu:\r\nAve! :P',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1)','',0,0),(25120,1085,'josephine','','','202.120.39.241','2008-05-12 03:51:44','2008-05-12 01:51:44','Imi place cum scrii (romana ta mutilata) si iti citesc (prea des) blogul. Sper ca ideile tale de afaceri sa prinda contur si sa traim cu totii intr-o lume mai alba, mai curata si sa avem din belsug senzatia protectiei :) Ah, si sa scapam de matreata de la a 3-a utilizare.',0,'1','Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.1.12) Gecko/20080207 Ubuntu/7.10 (gutsy) Firefox/2.0.0.12','',0,0),(32266,1149,'seliman','ionut.seliman@gmail.com','http://ionutu.wordpress.com','213.157.171.107','2008-07-02 10:20:59','2008-07-02 08:20:59','@hadean &amp; Turambar\r\nvÄƒ mulÅ£umesc pentru traduceri, ÅŸi acum am certitudinea cÄƒ limba noastrÄƒ e o limbÄƒ greu de Ã®nvÄƒÅ£at, cÄƒci io cu 10 la romÃ®nÄƒ Ã®n tÄƒt liceul ÅŸi ÅŸcoala generalÄƒ, dacÄƒ m-aÅŸ rÄƒtÄƒci prin zonele gen Oradea, MaramureÅŸ, Baia Mare, mi-ar trebui traducÄƒtor. Clar. :)',0,'1','Opera/9.27 (Windows NT 5.1; U; en)','',0,0),(32267,1149,'Je','','','194.102.139.9','2008-07-02 10:25:18','2008-07-02 08:25:18','@ al: Nii la ei, ce probleme au ;)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(32268,1149,'Je','','','194.102.139.9','2008-07-02 10:25:44','2008-07-02 08:25:44','scuze @ all (mi\'i fomica mare)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(29771,1135,'anonim','princesshgabriela@yahoo.com','','80.97.216.138','2008-06-17 09:20:35','2008-06-17 07:20:35','Felicitari pentru cumparaturi!\r\nO lenjerie de pat veche este mult mai igienica decat o bara dintr-un autobuz sau metrou.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648)','',0,0),(33721,1156,'hadean','contact@adihadean.com','http://www.adihadean.com','86.125.34.195','2008-07-17 10:02:52','2008-07-17 08:02:52','te ÅŸi vÄƒd cu teaca de un meter Ã®nainte ÅŸi cu un os de ciocÃ¢rlie tras prin nas, conducÃ¢nd tribul cu p#l@ forte:-))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.16) Gecko/20080702 Firefox/2.0.0.16','',0,0),(32250,1149,'hadean','contact@adihadean.com','http://www.adihadean.com','86.125.34.195','2008-07-02 08:57:27','2008-07-02 06:57:27','ioi mÄƒ prunci! nanÄƒ Ã®i aÅŸe cum o zÃ¢s turumbar. iarÄƒ restu\' ar fi fain sÄƒ fie aÅŸe, da nu-s. fiÅ£ atenÅ£: straiÅ£ Ã®i pluralu de la straiÅ£Äƒ, care-i ca on fel de louis vuiton mai iefin cu trizÄƒcii de mnii de ieuro ÅŸi Ã®i din cÃ®rpÄƒ nu din ptiele de puÅ£Äƒ de papagal ca aia adevÄƒrtÄƒ ÅŸÃ¢ scumpÄƒ.\r\ncantalauÄƒ Ã®s  niÅŸte badoaje (no, amu f-am tras-o iarÄƒ). adicÄƒ niÅŸte vasÄƒ de tablÄƒ jmÄƒlÅ£uitÄƒ, cu figheu (capac mÄƒ) Ã®n care sÄƒ bagÄƒ laptile ÅŸi groÅŸtioru. care-i on fel de lapte stÃ¢cat. adicÄƒ iaurt numa\' bun, de la naturÄƒ nu ca Äƒla din lapte praf de la natura din inox, cum Ã®i Äƒla din reclamÄƒ. iarÄƒ dacÄƒ amestici groÅŸtioru cu fructile, te cufureÅŸti apoi ÅŸtii precis cÄƒ-i natural.no bine amu?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(29767,1135,'Andrei Crivat','andrei@andreicrivat.ro','http://www.andreicrivat.ro','89.137.83.141','2008-06-17 09:01:18','2008-06-17 07:01:18','nu s-o daramat acoperisu\'. doar o bucata de tavan fals, de vreo doua palme. nu-i bai, am supravietuit cu totii :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.9) Gecko/2008052906 Firefox/3.0','',0,0),(33719,1156,'Ancuta','delcisor_m@yahoo.com','','195.245.251.18','2008-07-17 09:25:58','2008-07-17 07:25:58','Asa \"ment\" cum oi fi tu! E clar ca nu te simti prea bine... :P',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(25135,1085,'hadean','contact@adihadean.com','http://www.adihadean.com','86.125.34.195','2008-05-12 08:54:30','2008-05-12 06:54:30','mai, buna idee, numa\' sa nu uiti si de varianta neagra.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(25136,1085,'hadean','contact@adihadean.com','http://www.adihadean.com','86.125.34.195','2008-05-12 08:54:58','2008-05-12 06:54:58','hmm.neagra antimatreata...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(33715,1156,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-07-17 08:50:18','2008-07-17 06:50:18','Nu-i adevarat ca-s dement! Io-z foarte ment. Asa sa stiti.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.16) Gecko/20080702 Firefox/2.0.0.16','',0,0),(33718,1156,'mea','totmea@yahoo.com','','89.123.121.110','2008-07-17 09:09:35','2008-07-17 07:09:35','breeee, mataringa creste de la durere. tata lumea stie. fuga in africa, sa prinzi batar un madat.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Zango 10.3.36.0)','',0,0),(31402,1139,'Turistu','asdasda@yahoo.com','http://www.turism-forum.ro','213.157.188.71','2008-06-26 10:00:43','2008-06-26 08:00:43','ma gropare, ii bun drumu... transfagarasanu? fara gropi si nebunii?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(25130,1085,'ameÅ£itul','','http://ametzitul.wordpress.com','62.217.236.12','2008-05-12 08:21:31','2008-05-12 06:21:31','vezi sÄƒ faci ÅŸi bere brunÄƒ, sÄƒ beau ÅŸi eu mai cu spor :)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)','',0,0),(31392,1145,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-06-26 08:37:51','2008-06-26 06:37:51','Poi steagul ala UE cu 12 stele nu e o referire clara la numarul de discipoli hristoÅŸi?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(25133,1085,'CÄƒlÄƒ','acalarasu@gmail.com','http://adriancalarasu.wordpress.com','80.96.53.9','2008-05-12 08:38:52','2008-05-12 06:38:52','crezi ca-i mai pasa cuiva de matreatza dupa zece beri? sau crezi ca se mai rade elegant cu mana la gura (hehe) dupa paispe, din cauza (sau datorita?)cariilor?\r\ndeci functioneaza, cu conditia sa fie suficienta bere. lipseste doar spotul publicitar, deci hai sa-l filmam, ada\' o cisterna cu bere, ca carii si matreatza, cacalau!',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(28897,1125,'catalin','solo@xsolo.biz','http://xsolo.biz','84.62.58.225','2008-06-11 11:03:37','2008-06-11 09:03:37','acuma cine a copiat pe cine: calusarii pe dansatorii tai sau viceversa? :-))\r\noricum danseaza fain.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(25147,1085,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-05-12 10:51:22','2008-05-12 08:51:22','Berea anti-burta!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(32239,1149,'mo','verde_poveste@yahoo.com','','194.126.220.240','2008-07-02 08:09:43','2008-07-02 06:09:43','Da\' cu olandejii ce-ai patit? Sa nu zici ca ai dat de un olandez zburator de apreciaza barbati care fac autostopu\' in cearcanele goale :D',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1)','',0,0),(32240,1149,'Turambar','mirel@ccsb.ro','http://turambarr.blogspot.com','79.114.190.111','2008-07-02 08:11:07','2008-07-02 06:11:07','nana = matusa. baba. hoascha. boshoroaga\r\nstrait = fusta. dantelareala. pliuri.\r\ncantalaua = ??? probabil cantar cu patalama. sau cantare italiana\r\ngrostior = ??? probabil un puiutz de grof, gros la talie, la portofel shi la shtremeleag.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9) Gecko/2008052906 Firefox/3.0','',0,0),(29757,1135,'mo','verde_poveste@yahoo.com','','194.126.220.240','2008-06-17 07:58:09','2008-06-17 05:58:09','Vad ca am probleme cu acordurile la ora asta..ma duc sa imi fac o perfuzie cu cafea.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1)','',0,0),(33713,1156,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-07-17 08:16:51','2008-07-17 06:16:51','Apai nij nush ce pula mea sa zic la faza asta!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.16) Gecko/20080702 Firefox/2.0.0.16','',0,0),(29838,1136,'Kissu','','http://www.pacurar.net','82.77.126.254','2008-06-17 15:22:11','2008-06-17 13:22:11','Si ca sa fie tacamul compleCt... ui\'ce fain era pe-atunci, in fiecare dimineata! ;))))\r\n\r\nhttp://www.youtube.com/watch?v=M9kxPxfOS20&amp;feature=related\r\n\r\nK',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; InfoPath.1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648)','',0,0),(33746,1157,'Turambar','mirel@ccsb.ro','http://turambarr.blogspot.com','84.232.187.214','2008-07-17 14:34:45','2008-07-17 12:34:45','Singura maniera in care ati fi putut fi siguri ca nu va aduce aceeashi zama de musca era sa pastratzi castronul cu victima verde shi inecata pe masa, proba numaru unu, si sa ceretzi alt castron de zama de ciorba cu adaus proteic insectifil. Cum ar veni, proba doi. Si cand aducea ciorba de rezerva, atunci si voi ca detectivii priceputzi ii dadeatz inapoi proba unu, aia cu musca verde si decedata. \r\n\r\nThe late fly in the soup. Asta imi aduce aminte de schetchul acela al lui Monty Python cu papagalul mort in colivie. The late parrot. Very deceased. Dead. Stiff. Gone.\r\n\r\n:)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9) Gecko/2008052906 Firefox/3.0','',0,0),(32313,1149,'hadean','contact@adihadean.com','http://www.adihadean.com','86.125.34.195','2008-07-02 14:17:30','2008-07-02 12:17:30','No well Sagi, you see amu, We speack like tÄƒt omu\'. Just with a delicious accent. All right darÄƒ?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.15) Gecko/20080623 Firefox/2.0.0.15','',0,0),(33745,1156,'de ce?','mail@deceblog.net','http://deceblog.net','79.114.56.10','2008-07-17 14:22:00','2008-07-17 12:22:00','vezi sa nu-ti tai si tu vreo ureche ca van goghu\' cand te intorci in africa :))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9) Gecko/2008052906 Firefox/3.0','',0,0),(32306,1149,'Sagi','mail@constantablog.net','http://www.2creative.ro','62.231.95.98','2008-07-02 13:19:24','2008-07-02 11:19:24','Da io-s curios cum vorbesc ardelenii in engleza si moldovenii la fel...si aia cu fusai la fel',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(32292,1149,'alexnicolae','alexnicolae@gmail.com','http://alexnicolaeblogspot.com','62.180.224.130','2008-07-02 12:11:35','2008-07-02 10:11:35','intelectuali...',0,'1','Mozilla/4.0 (compatible; MSIE 5.01; Windows NT 5.0; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(32280,1149,'dora','dora.bacanu@yahoo.com','','86.122.94.196','2008-07-02 11:11:47','2008-07-02 09:11:47','seliman, io zic sa-i iei pe moldovenste... sa-i bagi tu in ceata,mai!!! ;)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(32262,1149,'...','n0thing_iz_wr0ng@yahoo.com','','78.97.78.12','2008-07-02 10:11:21','2008-07-02 08:11:21','Sh pe urma ai trimes un mail dinala cu subj:Fwd in care iera scris ca daca nu trimete la inca 150 de tovarasi di pa tat mapamondu, inclusiv tie, o sa fie trajedie mare pe planieta sh o sa-i crape chilotii sh o sa-i creasca ratiele sh bube di tate ciele pan tate locurile...\r\nHopa...nii un aidii !!! \r\nZÃ® ca nu...zÃ® ca nu',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; SIMBAR={390E0102-C5C4-42ec-8D97-7009A97840A4}; .NET CLR 1.1.4322)','',0,0),(29779,1043,'Teo Fefe','teo_fefe@yahoo.com','','78.96.75.170','2008-06-17 10:10:32','2008-06-17 08:10:32','ce tareeee ;) !!!! nu am gasit niciodata o cale de a expune ceea ce simt... esti unul dintre cei norocosi ;)!!!! FELICITARI',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14 SPOENB/1.0','',0,0),(31371,1145,'Emi','emi.cristea@floaredecolt.org','http://emi.floaredecolt.org','79.114.196.90','2008-06-26 07:17:29','2008-06-26 05:17:29','Corect! :)',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.648; .NET CLR 3.5.21022; InfoPath.1)','',0,0),(33178,1154,'eu','ripahoratiu@yahoo.com','','81.196.156.83','2008-07-11 07:58:42','2008-07-11 05:58:42','No vez de ce-am plecat io de la firma aia!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.15) Gecko/20080623 Firefox/2.0.0.15','',0,0),(31382,1139,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-06-26 08:04:26','2008-06-26 06:04:26','...sau rade una mica.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(31390,1145,'mo','verde_poveste@yahoo.com','','194.126.220.240','2008-06-26 08:35:44','2008-06-26 06:35:44','@arhi: ataaaaaat! :D\r\n\r\n@ groparu: Eh, nu te poti supara pe nazist ca isi simte invadat lebensraumu\' de tot felul de creaturi josnice care n-au nevoie de factor de protectie cand stau la soare si indraznesc pe deasupra sa mai si respire aeru\' lui cu trompele lor non-ariene :P\r\nintrebari:\r\nDe ce apare in amandoua pozele de mai sus cu o fata crispata de parca ar avea vreo 3 jnitale in fund? Crezi ca si-a luat multe peste cap cu o editie de lux din \"mein kampf\" cand nu era cuminte acolo jos, in pivnita?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1)','',0,0),(28890,1125,'mo','verde_poveste@yahoo.com','','194.126.220.240','2008-06-11 09:26:55','2008-06-11 07:26:55','Am si io o nelamurire: de ce naiba vrei sa iti cumperi o fusta tiganeasca de la Sonata Lunii (sau cum ii zice) sh nu cizme, nadragi si chemese inflorate? Haoleo, da\' si cand scoate capu\' din adancuri Groparita din Gropar....',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1)','',0,0),(29756,1135,'mo','verde_poveste@yahoo.com','','194.126.220.240','2008-06-17 07:56:22','2008-06-17 05:56:22','Mnoah, buna dimineata. \r\nNesimtit rau minionu\' din Cora, da\' asa fac astia in general, de parca l-ar fi prins pe Dumnezo de-un picior ca a scapat de la raionu\' cu carne congelata (si implicit de izmenele de sub blugi) si amu\' e tamplar-sef 5 metri mai incolo.\r\nTate bune si frumoase la Kaufland, da\' daca ti-ai luat pkita si telemea cand dracu\' schimbi si tu odata asternutu\'? Vezi ca in cel mult 2 saptamani o sa inceapa sa maraie la tine cand vrei sa intri in pat. Partea buna e ca o sa il poti fluiera sa sara singur in masina de spalat...',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1)','',0,0),(33202,1152,'Roza','popescu.onita@yahoo.com','','79.117.161.38','2008-07-11 14:05:31','2008-07-11 12:05:31','Conced placut! :)\r\nDistractiune maxima! :)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(28900,1121,'mo','verde_poveste@yahoo.com','','194.126.220.240','2008-06-11 12:10:01','2008-06-11 10:10:01','whatever, nu vreau sa te dezamagesc dar fara casnicie nu se poate preacurvi... \r\ndin cate imi amintesc, a curvi inseamna aaaaa.....  a zbura din floare-n floare iar a preacurvi inseamna a f@@@e nevestele altora - cer scuze pentru limbajul buruienos, dar relevant.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1)','',0,0),(33195,1154,'Adi','adriana.argeseanu@gmail.com','http://aboutnothingsro.blogspot.com/','78.96.200.199','2008-07-11 13:31:16','2008-07-11 11:31:16','lasa ca asa va recunoasteti mai usor masinile prin oras, acum ca sunt toate cu model',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9) Gecko/2008052906 Firefox/3.0','',0,0),(32233,1149,'seliman','ionut.seliman@gmail.com','http://ionutu.wordpress.com','213.157.171.107','2008-07-02 07:28:30','2008-07-02 05:28:30','Gropare, ce Ã®nseamnÄƒ \"nane cu straiÅ£ cu cantalauÄƒ de groÅŸtior\" ? CÄƒ matale eÅŸti traductologu\'. Pe hÄƒdean nu-l Ã®ntreb cÄƒ mi-i cÄƒ rÄƒspunde tot Ã®n limbaj regional. :)',0,'1','Opera/9.27 (Windows NT 5.1; U; en)','',0,0),(28907,1121,'V_for_Whatever','stephanovendetta@yahoo.com','','89.136.50.177','2008-06-11 13:23:03','2008-06-11 11:23:03','era doar o idee...mai lunga ce-i drept + ca sa curvesti ii ok, ca nu scrie nici unde sa nu curvesti...prea-curvia ii alta momeala de peshte...',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; .NET CLR 2.0.50727; InfoPath.2; Seekmo 10.0.424.0)','',0,0),(28913,1121,'sammas','noname_noname_2111@yahoo.co.uk','http://sam.weblog.ro/','81.180.224.209','2008-06-11 14:37:36','2008-06-11 12:37:36','help, domne! vreau si eu sa zic ceva la teraba cu fustili tiganesti, da\' nush; ce are de nu ma lasa :( . e da\' la stapanire sa nu ma lase? sau sunt io chiar asa da proasta si nu stiu?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','',0,0),(31438,1145,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-06-26 14:41:55','2008-06-26 12:41:55','Se mananca, da\' numa bucutza de chelneritza (mi s-a spus, ca io n-am de unde sa stiu)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(32221,1149,'Turambar','mirel@ccsb.ro','http://turambarr.blogspot.com','79.114.190.111','2008-07-02 06:39:57','2008-07-02 04:39:57','Aha. Pentru tzarishoara ta. Aha. Shi noi vrei sa te credem. Aha. Cand tu, de fapt, erai cu ochishorii tai ca doi cercei doar intre sanii ei. Ai bunoacei, bunintzeles. \r\n\r\nMai patriot tzatzofil. Mai ipocritule de rit casanovic. Mai opsedat tricolor. Mai afemeiatule natzionale... \r\n\r\n:)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9) Gecko/2008052906 Firefox/3.0','',0,0),(28919,1126,'julius','julius@universitateacraiova.ro','http://www.7plus.ro/?arhiva=11/06/2008&#38;id=6786','84.232.162.174','2008-06-11 16:04:45','2008-06-11 14:04:45','Pentru asta cu \"fiul lui Mihai Constantinescu\" n-o sa te uit niciodata, Gropare! De ce joci, ma, murdar? De ce nu ma lasi sa ma fac de cacat singur? De ce eu pot fi un baiat extraordinar si nu spun nimanui ca esti fiul lui Ricky Dandel?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(31479,119,'catalin botezatu','catalinbotezatu30@yahoo.com','http://nuare','92.80.97.165','2008-06-26 19:02:08','2008-06-26 17:02:08','penibil',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(31506,1146,'','','','92.82.42.223','2008-06-26 23:20:04','2008-06-26 21:20:04','hehe am prins postarea live',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(31507,1146,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','79.116.96.110','2008-06-26 23:22:27','2008-06-26 21:22:27',':))\r\n\r\nNij tu nu ai ceva mai bun de facut? (io beau bere rrreeeeceee... si ma citesc!)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(31510,1146,'','','','92.82.42.223','2008-06-26 23:35:00','2008-06-26 21:35:00','apai se pare ca nu...daca esti un clasic in viata...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(28947,1122,'nebuloasa','nebuloasablonda@yahoo.com','http://nebuloasa.wordpress.com/','62.217.238.137','2008-06-11 23:29:44','2008-06-11 21:29:44','ca fost reprezentant al maretului Orange, pot sa-ti confirm: e plin de femei acolo, si io cred ca faza cu CEO care e barbat e asa numai de fatzada. drept urmare, n-ai vrea sa vezi comunicarile interne Orange (cum ar veni, alea de le citesc amploaiatii): menopauza+pauza totala+\"ti se pare ca sunt grasa?\"+istericale+\"draga, ma iubesti?\" etc',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(33663,1155,'felix','felix.felix@gmail.com','','82.76.4.55','2008-07-16 22:22:09','2008-07-16 20:22:09','gropare, fericirea nu se atinge decat dupa ce un plod de ala de il tii in brate iti trimite inter-ochi un jet luuuung de voma.\r\nvad ca te pregatesti serios pentru viitor...ai planuri?',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; InfoPath.1)','',0,0),(28951,1122,'Mayol','cosmin_vmv@yahoo.com','','79.117.119.194','2008-06-12 00:05:18','2008-06-11 22:05:18','Bai Gropare...ce sa zic?? Esti prea porno frate...ieri te-am descoperit intamplator..si imi dau lacrimile (de fericire) cand mai citesc cate un post de-al tau!! Numai bine si \'mmmmmm......uie\' la orange daca tot e femeie!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(27135,1007,'baghy','baghy83@lycos.it','http://www.baghy.info','78.12.20.87','2008-05-28 01:18:26','2008-05-27 23:18:26','nu e corect. toata lumea asteapta si tu pleci. Dar te iertam',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; it; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(31597,583,'bombonika tah nebunatikha','yonutza_blondutza_4you@yahoo.com','','89.123.183.76','2008-06-27 14:41:29','2008-06-27 12:41:29','dak vretzi id`ul meu intratzi aki yonutza_blondutza_4you dap tare in rest',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 2.0.50727)','',0,0),(31569,1146,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-06-27 10:51:06','2008-06-27 08:51:06','Nu se poate de amandoua, da\' mai multi?\r\n\r\nOK. Am inteles.\r\n\r\nDeci nu se poate.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(31552,1146,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-06-27 08:48:23','2008-06-27 06:48:23','...vezi ca nu mai dau bani imprumut la cititori:|',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(27174,1007,'hadean','contact@adihadean.com','http://www.adihadean.com','86.125.34.195','2008-05-28 08:17:05','2008-05-28 06:17:05','no ce truda sÄƒ petrece cu tÄƒtÄƒ lume? tu nu ai vreme, io nu am vreme, nime nu mai are vreme de nimnic. am ajuns sÄƒ-mi scriu textele la 11 noaptea ÅŸi ziua abia dacÄƒ mai apuc sÄƒ vizitez cÃ¢te unblog vecin ÅŸi pretin din cÃ¢nd Ã¢n cÃ¢nd. doarÄƒ nu sÄƒ gatÄƒ vremea?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(27179,1094,'alexnicolae','alexnicolae@gmail.com','http://alexnicolaeblogspot.com','62.180.224.130','2008-05-28 08:58:54','2008-05-28 06:58:54','http://www.rdsnet.ro/reteaua/mures.htm, incearca sa suni la ORICE numar de pe pagina asta. Asta ca sa iti faci o idee despre client service. Eu i-am prins asa :mers la client service p f. Aia o zis sa sun la tehnic ca la ei e ok, telefonul il gasesc pe site(ala de mai sus). Niet. am sunat la bucuresti, mi-au dat numarul de la brasov, am sunat la brasov si mi-au dat o line directa la mures. Am fost la ei le-am zis in poola mea sa zica la cine sa ma duc numa sa imi mearga netu. Au zis ca se gandesc si ca ma suna ei. M-au sunat si mi-au zis sa ma duc inapoi la clienti persoane fizice sa imi fac un nou contract, probabil s-au incurcat in stiinta si e mai usor sa o ia de la inceput.  Fibra optica mere fain, si pretul e ok, pacat ca is un pic depasiti de situatie o crescut mai mult deact pot sa suporte.',0,'1','Mozilla/4.0 (compatible; MSIE 5.01; Windows NT 5.0; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(31557,1146,'Turambar','mirel@ccsb.ro','http://turambarr.blogspot.com','79.114.190.111','2008-06-27 09:13:19','2008-06-27 07:13:19','Haide, bre, ca au jucat spaniolii un fotbal de numa numa. Sa curga cu atomica, noi nu le shtim frica, fugim in America, cu putza cat furnica ... :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9) Gecko/2008052906 Firefox/3.0','',0,0),(31558,1146,'Usim','mihaimitan@gmail.com','','87.237.108.33','2008-06-27 09:21:55','2008-06-27 07:21:55','Bre, Gropare, da\' daca nu te mai citesc imi dai bani?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648)','',0,0),(28990,2,'Bill818947487\',\'590467127billy@msn.com\',\'\',\'56.199.57.55\',\'2008-06-12 16:16:41\',\'2008-06-12 16:16:41\',\'\',\'0\',\'lynx\',\'comment\',\'0\',\'0\'),(\'0\', \'\', \'\', \'\', \'\', \'2008-06-13 16:16:41\', \'2008-06-13 16:16:41\', \'\', \'spam\', \'\', \'comment\', \'0\',\'0\' ) /*','','http://None','124.217.227.127','2008-06-12 09:24:21','2008-06-12 07:24:21','<strong>None...</strong>\n\nNone...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ru; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13','trackback',0,0),(28993,1122,'Ancuta','','','195.245.251.18','2008-06-12 09:41:16','2008-06-12 07:41:16','Adevarat! Eu cred ca ii face ceva mai rau..',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(29007,1132,'baghy','baghy83@lycos.it','http://www.baghy.info','78.12.22.182','2008-06-12 11:22:56','2008-06-12 09:22:56','foarte tare',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; it; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(31576,1139,'mo','verde_poveste@yahoo.com','','194.126.220.240','2008-06-27 11:35:01','2008-06-27 09:35:01','....mic flavored, too :P',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1)','',0,0),(29023,1132,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-06-12 13:58:37','2008-06-12 11:58:37','@ Turambarr: is scrise gresit intentionat, ca sa vedem daca te prinzi. Amu tre sa catam incercari mai grele pentru intelectul tau!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(29025,1132,'deci,','totmea@yahoo.com','','89.123.81.70','2008-06-12 14:05:29','2008-06-12 12:05:29','pe cind pantalonii?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; SIMBAR={3523AA32-EC48-4B99-902E-C5F036C0464E}; Zango 10.3.36.0)','',0,0),(33630,1155,'Elisa','elivasu@yahoo.com.au','http://elisagradinameadevis.blogspot.com/','92.81.57.106','2008-07-16 17:04:50','2008-07-16 15:04:50','Nox,numai copiii altora sunt asa cum zice Groparu,ai tai....ntz,ntz,ntz!!Asa ca sa nu zici.... niciodata......,ca pe copii ii face femeia si femeile cam fac ce vor ele,nu crezi??   :lol:\r\nGropare,deci la Orlat ai cam Urlat....  :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.16) Gecko/20080702 Firefox/2.0.0.16','',0,0),(27240,1007,'ics','i_uana@yahoo.com','','86.126.99.7','2008-05-28 18:01:53','2008-05-28 16:01:53','oai,  \" numai nu pleca\" :&gt; de cate ori ai ocazia sa auzi asa ceva?  Jack, come back...come back!!!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(32035,1148,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-07-01 15:33:29','2008-07-01 13:33:29','Si io am vast una, da\' mai demult: era vorba, binenteles, de sor-mea.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(31643,786,'fu','fff@uuu.com','','89.43.196.18','2008-06-27 22:27:29','2008-06-27 20:27:29','Jenantilor!Sunteti niste nulitati jenante',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9) Gecko/2008052906 Firefox/3.0','',0,0),(29064,1133,'KillerINC','webmaster@bcdentalab.ro','http://killerinc.voce.ro','79.113.166.84','2008-06-12 23:01:21','2008-06-12 21:01:21','n-are simtul umorului fata :) fa-o sa isi dea demisia ... nu merita sa fie printre voi :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(29065,1133,'Ovi','ovidiu@sirb.net','http://sirb.net','79.114.83.149','2008-06-12 23:01:32','2008-06-12 21:01:32','Si era?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9) Gecko/2008052906 Firefox/3.0','',0,0),(29066,1132,'ics','i_uana@yahoo.com','','86.126.99.7','2008-06-12 23:03:19','2008-06-12 21:03:19','vro\' 2-3 ecsemplare din modelu 4, marimea S la masa 15, va rog...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(29557,40,'alexnicolae','alexnicolae@gmail.com','http://alexnicolaeblogspot.com','62.180.224.130','2008-06-16 10:35:48','2008-06-16 08:35:48','am facut cercetari si am gasit pe cineva care o dat informatii despre frigideru! ala o fo stricat da numa indoit. ca de la 8 nu o putut sa il arunce ca nu o incaput pe geam. Frigiderul a mai folosit cu succes inca cel putin un an! Functiona numa daca 2 persoane il apucau usor si il clatinau. pe acest principiu, freonu se mesteca si mergea pana cand il scotea cineva din priza. Dupa aia se relua procedeul. Informatiile sunt prea delaliilate si prea asemanatoare ca sa nu fie vorba de acealasi frigider. pune poza sau trimite pe mail ca sa verificam.',0,'1','Mozilla/4.0 (compatible; MSIE 5.01; Windows NT 5.0; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(32004,1148,'kittynel','kittynel@gmail.com','','213.208.242.81','2008-07-01 13:16:21','2008-07-01 11:16:21','@Groparu \r\nnu te mai plange de bicicleta, in Amsterdam se fura toate bicicletele tot timpul. invariabil se permuteaza intre ele, fiindca urmatoarea bitza ti-o iei pe 10 para de la un junkie, care tocmai a furat-o de la altcineva, si tot asa, in catva timp, poti sa ajungi chiar sa ai bicicleta ta inapoi.. platind bani pe ea, of cors...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9) Gecko/2008052906 Firefox/3.0','',0,0),(31980,1148,'Roza','popescu.onita@yahoo.com','','79.117.158.194','2008-07-01 10:19:28','2008-07-01 08:19:28','Banuia lumea ca clujanu\' i politicos!\r\nNice! :)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)','',0,0),(31981,1147,'Uca','','','86.34.167.172','2008-07-01 10:22:40','2008-07-01 08:22:40','si totusi, parca ar merita o biÅ£Äƒ noo...',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1; .NET CLR 2.0.50727; .NET CLR 1.0.3705; .NET CLR 1.1.4322)','',0,0),(33370,1154,'Uca','','','89.38.26.43','2008-07-13 09:32:23','2008-07-13 07:32:23','hm.. deci se intampla si in Cluuuuj.....',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1)','',0,0),(31976,1148,'RMN','mikyi_ro@yahoo.co.uk','http://dragajurnal.wordpress.com/','15.219.153.75','2008-07-01 09:52:41','2008-07-01 07:52:41','Ui\' ba ca orce problema se poa\' sa se rezolve romaneste.',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.0.3705; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(29105,1133,'danezu','jupanarul@yahoo.com','','79.112.0.75','2008-06-13 07:24:31','2008-06-13 05:24:31','si asta se vrea a fi postare pe blog?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9) Gecko/2008052906 Firefox/3.0','',0,0),(29110,1133,'un om','paul_bv@yahoo.com','','82.79.251.239','2008-06-13 07:57:59','2008-06-13 05:57:59','ioi \r\nnici ca se putea mai gropareshte...\r\n\r\nadica ce-ati fi vrut o dezbatere pro si contra in ceea ce priveste apartenenta cu planeta Zorg? \r\n\r\niar daca femeia zicea: Da, un pic parca...\r\nchiar n-ar fi fost fani deloc.',0,'1','Opera/9.27 (Windows NT 5.1; U; en)','',0,0),(31975,1148,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-07-01 09:48:14','2008-07-01 07:48:14','Nu veni! \r\n\r\nSe fura biciclete.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(33611,1155,'Uca','','','86.34.167.172','2008-07-16 10:17:30','2008-07-16 08:17:30','Stai sa vezi cum e sa faci asta zilnic. Eu nu am zi sa scap fara sa ma joc cu fimiu\', care acum are 2 ani (pe langa hranit, spalat, schimbat, sculat noaptea, etc). Noroc ca exista si tati, bunici si frati asa ca tine.\r\nApoi sunt atat de draguti, ca nu te poti supara orice ar face.',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1; .NET CLR 2.0.50727; .NET CLR 1.0.3705; .NET CLR 1.1.4322)','',0,0),(33613,1155,'nonick','agentuzerozeroopt@yahoo.com','','82.77.201.94','2008-07-16 10:47:53','2008-07-16 08:47:53','No-apÄƒi de aia-i bine sa dezveÅ£i copiii de scutece cÃ¢t mai iute, nu sÄƒ aÅŸtepÅ£i pÃ¢nÄƒ la 3 ani cÃ¢nd deja au suficientÄƒ Ã®ndemÃ¢nare sÄƒ-l trimitÄƒ spre cÄƒpÄƒÅ£Ã¢na ta!',0,'1','Opera/9.25 (Windows NT 5.1; U; en)','',0,0),(29113,1127,'dush','tirbushon@gail.com','http://dushrece.blogspot.com','82.77.41.201','2008-06-13 09:07:16','2008-06-13 07:07:16','dom\'le..esti un delicat. io le spuneam direct ceva depre familie, serviciu, popa si purgatoriu. laolalta cu adresa de mail a avocatului, numa asa sa nu mai spammeze :D',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(29115,1127,'10MBC','alin.banc@gmail.com','','86.122.9.207','2008-06-13 09:13:44','2008-06-13 07:13:44','\"eye for an eye\"',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(29117,1127,'anonim','','','89.38.26.43','2008-06-13 09:52:39','2008-06-13 07:52:39','citesc de vreo doua zile blogul asta al tau si mi-am dat in sfarsit seama de ce imi place. Imi aduci aminte de Salinger. Doar ca, fireste, el \"vorbeste mai frumos\"',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1)','',0,0),(32019,1148,'seliman','ionut.seliman@gmail.com','http://ionutu.wordpress.com','213.157.171.107','2008-07-01 14:10:42','2008-07-01 12:10:42','scuze.. pe un montÄƒn baic cu oglinzi tunate ÅŸi aparat de mÄƒsurat bÄƒtÄƒile inimii+claxon cu 12 sonerii presetate ÅŸi Ã®n format mp3..\r\nManelistul casual: exact ca Äƒla de-l descrii tu mai sus da pe o biÅ£Äƒ din Americi de aia cu cadru gros ca un butuc ÅŸi cu aspect retro cu un pitt-bull dupe el care sÄƒ sparie toatÄƒ puÅ£imea din cartier cÃ®nd trece el, barosanu\'.. :D',0,'1','Opera/9.27 (Windows NT 5.1; U; en)','',0,0),(32018,1148,'seliman','ionut.seliman@gmail.com','http://ionutu.wordpress.com','213.157.171.107','2008-07-01 14:07:02','2008-07-01 12:07:02','Eu vreau sÄƒ vÄƒd maneliÅŸti pe biciclete. Deci, tablou: manelistul elegant - cÄƒmaÅŸÄƒ creponatÄƒ cu dragon cauciucat pe spate ÅŸi stofari (pantaloni de stofÄƒ) cu pantofi negri-lucioÅŸi stil Ali baba cu bot ascuÅ£it ÅŸi lung pe un',0,'1','Opera/9.27 (Windows NT 5.1; U; en)','',0,0),(29120,1127,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-06-13 10:11:16','2008-06-13 08:11:16','...plus ca el e ÅŸi MUUUULT mai catcher-in-the-rye-eÅŸte decat as vorbi io vrodata, asta deja stie toata blogosfera.\r\n\r\nPS: Da\' Salinger ni\' nu tinea blog updatat zilnic, trei joburi tat zilnice si si girlfriend concomitent, asa cum cu (in)succes face Groparele.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(29122,1126,'un om','paul_bv@yahoo.com','','82.79.251.239','2008-06-13 10:44:55','2008-06-13 08:44:55','@Andrei Crivat:\r\nasa mai suna plauzibil ca prea erau... incurcate',0,'1','Opera/9.27 (Windows NT 5.1; U; en)','',0,0),(29133,1127,'Andreea','puistrulet2003@yahoo.com','http://n/a','81.196.150.196','2008-06-13 13:02:00','2008-06-13 11:02:00','Io is curioasa daca iti raspunde :)))))\r\n\r\nAtunci sa vedem razbunarea lui Groparu\'\r\n\r\nA.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(29141,1127,'mo','verde_poveste@yahoo.com','','194.126.220.240','2008-06-13 13:42:51','2008-06-13 11:42:51','no bine.... me= chairman of the bored ;)',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1)','',0,0),(29142,1127,'seliman','ionut.seliman@gmail.com','http://ionutu.wordpress.com','213.157.171.107','2008-06-13 13:46:28','2008-06-13 11:46:28','Spammer-ii Äƒjtia sunt precum Äƒia de vindeau pensii private. Nu se Ã®nvaÅ£Äƒ minte niciodatÄƒ. :D',0,'1','Opera/9.27 (Windows NT 5.1; U; en)','',0,0),(29144,1127,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-06-13 14:06:38','2008-06-13 12:06:38','@ mo: nimic nu este mai proaspat ca aerul care iasÄƒ din mine, din simplul motiv ca cu 0.3 nanosecunde in urma se nastea el, aeru\', in mine, el.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(29145,1127,'mo','verde_poveste@yahoo.com','','194.126.220.240','2008-06-13 14:08:38','2008-06-13 12:08:38','desigur, compozitia nu se discuta :P',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1)','',0,0),(29146,1133,'whiteWolf','laskmerge@gmail.com','http://white-wolf.ro','79.118.187.174','2008-06-13 14:38:38','2008-06-13 12:38:38','<b>The verry best of the year !</b> =))',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(29147,1127,'whiteWolf','laskmerge@gmail.com','http://white-wolf.ro','79.118.187.174','2008-06-13 14:39:30','2008-06-13 12:39:30','Adica se face vorbirea despre compozitia spammerului ? - ca n\'am fost pe faza de la inceput :P',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(29148,1132,'brosky','brosky@gmail.com','http://blog.101net.ro','89.32.151.59','2008-06-13 14:40:58','2008-06-13 12:40:58','Subscriu si io gropare la un tricouas, sa-mi fac la amicul PMACluj.\r\n\r\nUn .cdr sau ce sursa o avut nenea, si promit ca pe acolo pe la urinare, bagam si un groparu.ro',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(29152,1127,'mo','verde_poveste@yahoo.com','','194.126.220.240','2008-06-13 15:02:48','2008-06-13 13:02:48','pai ce, numa\' zdob si zdub sa stea-n spital?!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1)','',0,0),(29153,1127,'nonick','agentuzerozeroopt@yahoo.com','','82.77.201.94','2008-06-13 15:02:57','2008-06-13 13:02:57','Mai da ce ce senzatie a creat printre bloggeri spamul asta:\r\n\r\nhttp://www.hangarhosting.info/2008/06/11/nici-spammerii-nu-mai-sunt-ce-erau-odata/\r\n\r\nP.S. Ce facea la 4 metri inaltime in pom? Culegea cirese?',0,'1','Opera/9.25 (Windows NT 5.1; U; en)','',0,0),(29154,1127,'mo','verde_poveste@yahoo.com','','194.126.220.240','2008-06-13 15:05:06','2008-06-13 13:05:06','Sau voia neaparat sa culeaga nuca de cocos buclucasa care l-a fentat si pe Keith Richards anu\' trecut... :D',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1)','',0,0),(29155,1127,'nonick','agentuzerozeroopt@yahoo.com','','82.77.201.94','2008-06-13 15:07:03','2008-06-13 13:07:03','P.P.S. Care te-ai enervat pe spammer si i-ai mÄƒtrÄƒÅŸit saitu\'? CÄƒ mie nu mi se Ã®ncarcÄƒ :))',0,'1','Opera/9.25 (Windows NT 5.1; U; en)','',0,0),(27374,1007,'jospehine','fake@yahoo.com','','222.67.159.183','2008-05-29 15:00:20','2008-05-29 13:00:20','Hai mai, intoarce-te! Povesteste-ne de tzigani... Gaseste 5 minute sa scrii,  inainte de dush!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(29158,1132,'Nea Nderthal','','','82.77.201.141','2008-06-13 15:20:15','2008-06-13 13:20:15','Da\' plua une\'i ?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.11','',0,0),(29159,1133,'Turambar','mirel@ccsb.ro','http://turambarr.blogspot.com','92.80.1.157','2008-06-13 15:23:55','2008-06-13 13:23:55','Damn! Io i\'ash fi zic altceva. Shi ash fi shi accentuat fraza cu anumita mishcare cu puternica incarcatura simbolica, ce implica extremitatzile superioare, pricepere shi rapiditate tactila, proximitate spatio-temporala corporala si oareshce contact cu materiale textile.\r\n\r\nChiar daca mi-ash fi luat o poshetutza in cap. In fond si la urma urmei, alt contact cu un material textil, nu?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(29160,1133,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-06-13 15:26:22','2008-06-13 13:26:22','Amu daca-i poseta din piele de crocodilÄƒ, si pielea e prevazuta cu dinti? Tu ÅŸtii cum poate muÅŸca o crocodilÄƒ???',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(33588,1155,'Nemtzasca','dintz_best@yahoo.com','','81.180.170.53','2008-07-15 22:49:32','2008-07-15 20:49:32','ba ,vezi ca esti dator cu aventurile Panterei din Orlat de la timbilding',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(33577,316,'Hduslaay','mbizklff@sedmdimk.com','http://sites.google.com/site/analcreampiemovies1','210.0.198.81','2008-07-15 20:39:37','2008-07-15 18:39:37','Good luck, <a href=\"http://sites.google.com/site/analcreampiemovies1/anatomy-of-anal-intercourse \" rel=\"nofollow\">anatomy of anal intercourse</a>,  xcuxvv,',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)','',0,0),(33576,1154,'innuenda','innuennda@yahoo.com','http://innuennda.blogspot.com','92.81.8.74','2008-07-15 19:47:12','2008-07-15 17:47:12','Asta e specia recunoscutÄƒ drept pitecantropus ubicuus. Pentru cÄƒ zgÃ¢rie simultan maÅŸini ÅŸi la Cluj ÅŸi la BucureÅŸti ÅŸi la GalaÅ£i ÅŸi cine-mai-ÅŸtie-pe-unde. \r\nNici nu conteazÄƒ motivul: poate nu a avut maÅŸinuÅ£e sÄƒ se joace cÃ¢nd era mic, deci, o copilÄƒrie nefericitÄƒ. Ori poate cÄƒ, urangutanul, vrea sÄƒ arate cine e masculuâ€™ dominant pe strada aia sau, cine ÅŸtie, poate cÄƒ e reÃ®ncarnarea unei sÃ¢rme ghimpate. \r\nOri una din astea ori, dacÄƒ nu, e pur ÅŸi simplu un frustrat, un gherÅ£oi, un retardatâ€¦cÄƒruia i-aÅŸ spune, fÄƒrÄƒ sÄƒ mÄƒ repet, cele mai groaznice Ã®njurÄƒturi, Ã®n timp ce i-aÅŸ da ÅŸuturi Ã®n cur pÃ¢nÄƒ m-ar durea piciorul.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.8.1.15) Gecko/20080623 Firefox/2.0.0.15','',0,0),(27418,1007,'Groparu','groparu_ro@yahoo.com','http://','79.116.97.9','2008-05-29 21:15:25','2008-05-29 19:15:25','Intre timp mi s-o bulit si saitu, si sysadminu meu e la chefuri si nu are vremuri de iel.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,1),(27423,1007,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','79.116.97.9','2008-05-29 21:30:56','2008-05-29 19:30:56','N-am ce faceeee :(( ca asta pana luni nu revina in civilizatie, ca e plecat aiurea...\r\n\r\nSi tocma ma rugase un prekin sa scriu despre festivalu\' motoristilor care va avea loc weekendu\' urmator... si nici el nu ma crede cand ii zic ca saitu\' mi-o foarte crepat...!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(31739,1139,'baghy','baghy83@lycos.it','http://www.baghy.info','78.12.17.141','2008-06-28 21:59:37','2008-06-28 19:59:37','Si Baghy luvz la Groparu para siempre',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; it; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(29192,1133,'Turambar','mirel@ccsb.ro','http://turambarr.blogspot.com','84.232.187.243','2008-06-14 00:53:28','2008-06-13 22:53:28','Daca pui mana repede, n\'apuca sa mushte. Atingi si fugi. Atingi si fugi. Atingi shi...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(29235,1133,'Andreea MKT','supergirgir@yahoo.com','','89.43.186.64','2008-06-14 09:26:21','2008-06-14 07:26:21','Nici io nu jtiam ce e aia planeta zorg, dar mi-am dat seama ca o fi ceva alienesc...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(27509,1007,'nerabdatoare','totmea@yahoo.com','','89.123.75.30','2008-05-30 12:05:17','2008-05-30 10:05:17','bravo greucene! vezi mah, cum stie oamenii cu esperienta..care este...care-a patit. pina luni, s-o-mpaci!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; SIMBAR={3523AA32-EC48-4B99-902E-C5F036C0464E}; Zango 10.3.36.0)','',0,0),(33469,665,'Ceasuri','poza_ta@yahoo.com','http://www.ecristal.ro','89.136.125.186','2008-07-14 13:42:26','2008-07-14 11:42:26','Eu am o firma al carei singur si unic angajat sunt deci se poate spune ca ocup concomitent toate pozitiile. Asta ma face omul multitasking? :))',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 2.0.50727)','',0,0),(32244,1148,'Greuceanu','','','89.46.104.35','2008-07-02 08:22:10','2008-07-02 06:22:10','\"vand branza de sibiu si jiop de cluj!\" - evident',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(33714,1156,'Ancuta','delcisor_m@yahoo.com','','195.245.251.18','2008-07-17 08:43:30','2008-07-17 06:43:30','ESTI DEMENT!!! :))))\r\n\r\nPS: E bine ca vezi partea pozitiva a lucrurilor! Tu spera in continuare...',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(33683,1155,'WhiteWolf','laskmerge@gmail.com','http://white-wolf.ro','79.118.187.179','2008-07-17 02:04:57','2008-07-17 00:04:57','Spune \"sanchiu\" ca-i ai si ca\'s ai tai doar un uichiend :)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.16) Gecko/20080702 Firefox/2.0.0.16','',0,0),(32483,1151,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','79.116.97.49','2008-07-04 01:56:52','2008-07-03 23:56:52','TURAMBARR!\r\n\r\nDECI daca nu revii, io te belezc. Finca voi sta in chirie gratisÄƒ la Usim, ÅŸi de acolo voi Ã®ntreprinde plundering raids la tine-n garsonerÄƒ, ÅŸi dacÄƒ trebe ÅŸi-n Viena aia unie tu te prezinÅ£i mai ÅŸtirb ca - cum sÄƒ-Å£i zic - ca matuÅŸe-mea. Oricare ar fi iea. Ca toate mÄƒtujile mele-s ca mine. AdicÄƒ najpa. Sau ÅŸtirbe. Sau amandoo.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.15) Gecko/20080623 Firefox/2.0.0.15','',0,0),(27994,1115,'!?_Je_?!','florina_audochii@hotmail.com','','194.102.139.9','2008-06-04 07:34:07','2008-06-04 05:34:07','@ Usim: Mai conteaza formularea???? Nope, tot ceea ce \'importa\' este mesajul!!! :D\r\nTiganiada, ceva detalii, orice, pentru noi, muritorii de rand, d-l Groparele?!',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; .NET CLR 1.1.4322; InfoPath.1)','',0,0),(28025,1117,'kittynel','kittynel@gmail.com','','213.208.242.81','2008-06-04 11:58:21','2008-06-04 09:58:21','?!?!?!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9) Gecko/2008051206 Firefox/3.0','',0,0),(28030,1117,'Andrei Crivat','andrei@andreicrivat.ro','http://www.andreicrivat.ro','89.137.83.141','2008-06-04 12:09:09','2008-06-04 10:09:09','e banc. e un banc cretin, stupid, care numa\' lui i s-o parut amuzant. deci n-a patit nada, am vb cu el acush.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.9) Gecko/2008051206 Firefox/3.0','',0,0),(28037,1117,'ics','i_uana@yahoo.com','','86.126.99.7','2008-06-04 12:46:46','2008-06-04 10:46:46','de dus te-ai dus tu cu elicopteru\', da\' de intors ?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(32546,1151,'IepurasulAtomic','praetorian21uk@yahoo.com','http://iepurasulatomic.weblog.ro','192.100.104.17','2008-07-04 13:22:23','2008-07-04 11:22:23','Acuma imi zici ca numa\' romancele pun botu\' la straini din alta tzara? M-am dus si eu tzantzos in discoteci prin canadaland, ca: \"Uite fa, is din rOMANIA, vrei sa ma iubesti?\". Da\' s-o ras toate de mine, o zis ca ele nu vorbesc cu ghiulangii si ca cica sa ma descurc singur. Asta cu descurcatu\' singur n-am priceput-o. Adica ce sa fac?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; InfoPath.1; MS-RTC LM 8; .NET CLR 3.0.04506.30)','',0,0),(32548,1151,'kittynel','kittynel@gmail.com','','213.208.242.81','2008-07-04 13:47:02','2008-07-04 11:47:02','apai asa-i olandejii, daca tu ai facut ceva pt ei, iti multumesc frumos, da\' ei nu inteleg ca tre sa faca acelasi lucru pentru tine... \r\n\r\nnaspa anyway, puteau sa iti dea macar adrese de hostel eftine...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9) Gecko/2008052906 Firefox/3.0','',0,0),(30311,1137,'adi','adi@ucluj.ro','http://blog.ucluj.ro','86.35.201.235','2008-06-19 13:36:27','2008-06-19 11:36:27','Da ce faceai in liga? Doar nu esti franar, Gropare! :-O',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.9) Gecko/2008052906 Firefox/3.0','',0,0),(28051,1117,'julius constantinescu','julius@universitateacraiova.ro','http://www.7plus.ro/?arhiva=04/06/2008&#38;id=6545','84.232.160.54','2008-06-04 13:47:27','2008-06-04 11:47:27','Gropare, mie mi se pare amuzant. Da\', daca vrei s-o faci pe mama-ta sa se distreze si mai tare, poti sa-i zici: \"No, vorbeste mai repede, ca acu\' arunca astia cu pamant deasupra si pierd semnalu\'\".',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(32555,1151,'eu','ripahoratiu@yahoo.com','','81.196.156.83','2008-07-04 14:28:20','2008-07-04 12:28:20','No de ce nu ma mir oare? Ca \"i-am rugat, daca pot, sa imi gaseasca o cazare eftina la ei in patrie, in Amsterdamuâ€™ lor. Si ei or zis ca le pare foarte am sorry, daâ€™ nu au cum sa ma ajute.\"\r\nAstia, olandejii, e mai scartanari ca toate neamurile pamantului, is atata de zgarciti ca nici nu indraznesc sa zica bancuri cu scotieni zgarciti sa nu-i trazneasca. Io am vazt ca-s foarte priceputi cand ii vorba sa-i omenesti tu\' nimeni nu stie sa primeasca si sa consume mai bine ca ei.\r\nDa\' daca e vorba sa te-ajute si ei cu ceva, parca-i pici cu ceara, parca-i lovesti cu usa de la tancheta, le citesti pe fata o panica de nedescris si isi aduc brusc aminte ca au parintii, fratii si pestii de acvariu pe moarte, tocma\' li s-a prabusit meteoritu\' pe casa, firma la care munceau a dat faliment si toata viata lor e ca de spermatozoid campion...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.15) Gecko/20080623 Firefox/2.0.0.15','',0,0),(28063,1117,'jospehine','fake@yahoo.com','','58.38.30.177','2008-06-04 14:48:00','2008-06-04 12:48:00','Bine asa! Nu putea sa fie altceva decat banc, altfel nu ai fi stat tu sa scrii pe blog in conditiile in care te-ar fi carat cu elicopteru\'... Plus, cine a mai vazut elicoptere SMURD in Romania care chiar sa transporte bolnavi de rand?',0,'1','Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(34166,1159,'hadean','contact@adihadean.com','http://www.adihadean.com','86.125.34.195','2008-07-21 08:14:19','2008-07-21 06:14:19','no, aÅŸe cum o zÃ¢ci tu, mai cÄƒ-Å£ vine sÄƒ muÅ£ fuÅŸte.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.16) Gecko/20080702 Firefox/2.0.0.16','',0,0),(28070,1117,'Turambar','mirel@ccsb.ro','http://turambarr.blogspot.com','79.114.190.107','2008-06-04 15:26:27','2008-06-04 13:26:27','SMURDu era tare ocupat si plin de schedule in intarziere, si pilotu se grabea, si atunci n-a mai aterizat, ci doar mi tzi l-o basculat prin rasturnare. De la 2000 de metri in jos shi la vale, direct in salonu cu cameshi cu maneci lungi.\r\n\r\nA mai avut timp sa vorbeasca la telefon fro 10 - 15 secunde. Mammaaaaa, nu mai sunt in elicop...\r\n\r\nBUF!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(30326,1138,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-06-19 16:27:06','2008-06-19 14:27:06','@ ics: Ba nu, ca mama mea de fapt e-o doamna, nu o batranica, si nu prea mere la biserica sa se roage, ca sa nu-i aminteasca lu\' Dumnezau de noi, ca te miri la ce incercari ne mai supune Demiurgul, in imensa Sa plictiseala!\r\n\r\n@ eu: M-am lovit la folbal la cap amu vreo 4 saptamani, de mi-am si amintit unde mi-am ascuns masinuta aia de fier cand eram in clasa a treia, de nu am mai gasit-o nici macar niciodata.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(30331,1138,'seliman','ionut.seliman@gmail.com','http://ionutu.wordpress.com','82.78.189.109','2008-06-19 17:32:37','2008-06-19 15:32:37',':D :D Groparele rulz!\r\nUite din cauza unor astfel de articole meriÅ£i tu sÄƒ fii citit zilnic..nu-i Ã®n van osteneala.. ;) Io te-aÅŸ bÄƒga ÅŸi-n manualele alternative de limba ÅŸi literatura romÃ®nÄƒ, la capitolul bildungsroman! ;)',0,'1','Opera/9.50 (Windows NT 5.1; U; en)','',0,0),(28118,1117,'radio fara filtru','tucashow2001@yahoo.com','http://www.radiofarafiltru.ro','193.186.33.9','2008-06-04 21:20:18','2008-06-04 19:20:18','salut \r\n\r\nimi place blogul tau este genial , daca vrei sa facem link exchange eu voi publica la mine pe sait http://www.radiofarafiltru.ro un link catre pagina ta iar tu daca vrei poti sa pui un player la care zbarnaie radio fara filtru . aici ai codul pentru player \r\n\r\n\r\n\r\n\r\nastept confirmarea pe email radiofarafiltru@yahoo.com',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; InfoPath.1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(30457,1138,'cure de slabire','luiza_valiza@yahoo.com','http://www.curedeslabire.org','92.81.134.208','2008-06-20 08:49:14','2008-06-20 06:49:14','foaarte tare frate :)) =)) \r\nbah esti genial! ar trebui sa tii cursuri la facultate :))\r\nyou rule dude!',0,'1','Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.1.6) Gecko/20071008 Ubuntu/7.10 (gutsy) Firefox/2.0.0.6','',0,0),(30476,1138,'Cris','crismocanu@gmail.com','http://mydaysmymind.blogspot.com','82.76.6.241','2008-06-20 11:08:14','2008-06-20 09:08:14','Iti spun eu bancul daca promiti ca nu stergi insemnarea',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1)','',0,0),(30477,1138,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-06-20 11:18:29','2008-06-20 09:18:29','Ala cu evreu si fi-su care se converteste la crestinism? :D\r\n\r\nZi bancu, ca sterg numa\' jumate atunci.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(28194,1117,'Hammer','hammer@alpinet.org','','81.196.168.118','2008-06-05 10:56:53','2008-06-05 08:56:53','Era mijto daca ai fi coroborat faza asta cu campania cu aia doi la suta:-))',0,'1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)','',0,0),(33481,1139,'cug','ionuion@yahoo.com','','82.77.126.3','2008-07-14 16:15:04','2008-07-14 14:15:04','Am ajuns aici foarte Ã®ntÃ¢mplÄƒtor ca sÄƒ aflu cÄƒ È™i eu sunt membru al acelei suprasecrete asociaÈ›ii de dreptaci. TotuÈ™i eu m-am tÄƒiat Ã®n direcÈ›ia cot-unghie. CÃ¢ndva pÃ¢nea nu a fost tocmai de post.\r\nCÃ¢te informaÈ›ie poate scoate coitul la suprafaÈ›Äƒ',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.9) Gecko/2008052906 Firefox/3.0','',0,0),(34316,1159,'cristi','alex_cristi20@yahoo.com','','195.178.103.230','2008-07-22 09:34:48','2008-07-22 07:34:48','Sunteti rai de musca ?',0,'1','Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)','',0,0),(34330,1160,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-07-22 11:14:10','2008-07-22 09:14:10','Dej io creca tre\' sa meri pe sait. Daca ti-i prea lene, afla ca sediul e pe strada Barbusse (daca meri cu taxiu\', ii zici la taximetrist ca mergi pe strada BARBUSE), si acolo poti sta la o mescioara si poci si pÄƒpa. Dar nu e inca de iesit seara, la o cina romantica cu desert de morcovi cu migdale si curry si iubitel prajit.',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.16) Gecko/20080702 Firefox/2.0.0.16','',0,0),(34336,1160,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-07-22 12:02:04','2008-07-22 10:02:04','Deci daca nu-s in Muntenegru (se aude, Carpenishene?), is sigur acasa:D \'aide, dara!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.16) Gecko/20080702 Firefox/2.0.0.16','',0,0),(34348,1160,'SkyRain','SkyRainSecrets@gmail.com','','79.113.240.251','2008-07-22 14:16:33','2008-07-22 12:16:33','Tot ce faci cu dragoste iese bine. ;)',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.16) Gecko/20080702 Firefox/2.0.0.16','',0,0),(34352,1160,'Groparu','groparu_ro@yahoo.com','http://www.groparu.ro','82.77.126.254','2008-07-22 14:51:05','2008-07-22 12:51:05','Mai ales dragostea!',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.16) Gecko/20080702 Firefox/2.0.0.16','',0,0),(34410,1161,'alhambra','mihdana@yahoo.com','http://www.zideziinromania.blogspot.com','89.120.204.80','2008-07-23 01:43:12','2008-07-22 23:43:12',':)))))))))))))))))))))))))))))\r\nsper ca herr popa e un nene de treaba si doara se bucura si el de infratirea-ntre popoare ! cat despre soptitul cu voce tare, been there, done that, I`m a woman si de-aia...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14','',0,0),(34437,1160,'Sorinelu\'','','','210.150.186.60','2008-07-23 04:37:19','2008-07-23 02:37:19','no pai daca este restaurant indienesc la cloj, apoi ma intorc acasa. mai ales ca ii si aproape de unde stau. si mai ales ca curry-ul ala nu te zgarie... ca asta de pe aici asa te zgarie dupaaaaa...',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.15) Gecko/20080623 Firefox/2.0.0.15','',0,0),(34482,1162,'Groparu','groparu_ro@yahoo.com','http://','79.116.79.42','2008-07-25 10:35:02','2008-07-25 08:35:02','wfvrefv',0,'1','Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.0.1) Gecko/2008070208 Firefox/3.0.1','',0,1);
/*!40000 ALTER TABLE `wp_comments` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `wp_links`
--

DROP TABLE IF EXISTS `wp_links`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `wp_links` (
  `link_id` bigint(20) NOT NULL AUTO_INCREMENT,
  `link_url` varchar(255) NOT NULL DEFAULT '',
  `link_name` varchar(255) NOT NULL DEFAULT '',
  `link_image` varchar(255) NOT NULL DEFAULT '',
  `link_target` varchar(25) NOT NULL DEFAULT '',
  `link_category` bigint(20) NOT NULL DEFAULT 0,
  `link_description` varchar(255) NOT NULL DEFAULT '',
  `link_visible` varchar(20) NOT NULL DEFAULT 'Y',
  `link_owner` int(11) NOT NULL DEFAULT 1,
  `link_rating` int(11) NOT NULL DEFAULT 0,
  `link_updated` datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  `link_rel` varchar(255) NOT NULL DEFAULT '',
  `link_notes` mediumtext NOT NULL,
  `link_rss` varchar(255) NOT NULL DEFAULT '',
  PRIMARY KEY (`link_id`),
  KEY `link_category` (`link_category`),
  KEY `link_visible` (`link_visible`)
) ENGINE=MyISAM AUTO_INCREMENT=59 DEFAULT CHARSET=latin1;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `wp_links`
--

LOCK TABLES `wp_links` WRITE;
/*!40000 ALTER TABLE `wp_links` DISABLE KEYS */;
INSERT INTO `wp_links` VALUES (19,'http://www.doingtheartwork.com/','Mihaitza, chiar iel!','','',0,'Dizainar, cantecaci, si nu numai','Y',2,0,'0000-00-00 00:00:00','','',''),(8,'http://www.beatmort.ro','BeatMort, da\' mort de beat!','','',0,'BeatMort, da\' mort de beat!','Y',1,0,'0000-00-00 00:00:00','','',''),(52,'http://sufleteinoglinda.blogspot.com/','Suflete in oglinda de deasupra patului','','',0,'Sper ca e bine prinsa oglinda de tavan, alfel pica','Y',1,0,'0000-00-00 00:00:00','','',''),(10,'http://mituriurbane.vira.ro/','Mituri urbane romanesti','','',0,'','Y',1,0,'0000-00-00 00:00:00','','',''),(14,'http://rottencabbage.haipa.ro/','Varza putreda','','',0,'Varza putreda, da\' \'ntelectoala','Y',1,0,'0000-00-00 00:00:00','','',''),(15,'http://oedip.blogspot.com/','Oedip, da\' nu ala cu ma-sa','','',0,'','Y',1,0,'0000-00-00 00:00:00','','',''),(20,'http://www.curatmurdar.ro/','Necurat, nemurdar','','',0,'Ma cutremurrrr!!!!','Y',2,0,'0000-00-00 00:00:00','','',''),(18,'http://idei-locale.blogspot.com/','Razvan fara Vidra','','',0,'Razvan cu nume de legionar','Y',1,0,'0000-00-00 00:00:00','','',''),(23,'http://www.milecarpenisan.ro','Mile Carpenisan, cine zice care e prenumele lui e meseriash!','','',0,'Prietenu\' nostru banateano-sarbo-croat-bosniac, da\' roman!','Y',1,0,'0000-00-00 00:00:00','','',''),(22,'http://rezistenta.blogspot.com','Rezistentza inca nearsa','','',0,'Rezistentza urbana, suburbana sau rurala? Exact!','Y',1,0,'0000-00-00 00:00:00','','',''),(24,'http://www.andreicrivat.ro','Bate Crivatz a racoare, eu ma uit, pasari dispare','','',0,'Daca e crivatz, bag sama ca e cool','Y',1,0,'0000-00-00 00:00:00','','',''),(25,'http://fluture.friendlyfrog.ro','Flutelelele','','',0,'- asa pronuntza pe vremuri un baietel: flutelelele','Y',1,0,'0000-00-00 00:00:00','','',''),(48,'http://www.mana.ciutacu.ro/','Femeia din spatele arogantului genial','','',0,'Viitoare imparateasa galactica','Y',1,0,'0000-00-00 00:00:00','','',''),(27,'http://moka.t2i.info/','Poze Moka!','','',0,'POZE MOKA!','Y',1,0,'0000-00-00 00:00:00','','',''),(29,'http://andreanum.org/','Acilea nu prea am ce comenta!','','',0,'Finca le zice de nu mai prea ai ce comenta!','Y',1,0,'0000-00-00 00:00:00','','',''),(31,'http://www.ciutacu.ro','Nashu\' Victor','','',0,'Omu\' asta ciutaceshte demential','Y',1,0,'0000-00-00 00:00:00','','',''),(32,'http://nenea.wordpress.com/','Cosmos, sau univers? aceste cuvinte ne doare','','',0,'Creca totusi e nenea, nu o tanti grasa','Y',1,0,'0000-00-00 00:00:00','','',''),(33,'http://www.mihaic.blogspot.com/','Blog foto cu munti','','',0,'Blog foto cu munti','Y',1,0,'0000-00-00 00:00:00','','',''),(34,'http://www.white-wolf.ro/','Lupulainu\' Balan','','',0,'Lupulainu\' Balan sh sibian!','Y',1,0,'0000-00-00 00:00:00','','',''),(36,'http://www.hobbitul.ro/','Cel mai poet contimporan!','','',0,'Emil Brumaru','Y',1,0,'0000-00-00 00:00:00','','',''),(39,'http://warsongu.wordpress.com/','War song, not swan song!','','',0,'Cantic ghi jele ghe mori de rÃ¢s','Y',1,0,'0000-00-00 00:00:00','','',''),(41,'http://adriancalarasu.wordpress.com/','Blogu lu CÄƒlÄƒ\'','','',0,'Cum zicea Nea Marin, CÄƒlÄƒraÅŸ cu schimbu\'!','Y',1,0,'0000-00-00 00:00:00','','',''),(42,'http://cronicaru.blogspot.com/','Cronicaru\' dupa Ureche','','',0,'Deci neculai milescu spataru cronicaru','Y',1,0,'0000-00-00 00:00:00','','',''),(56,'http://www.7plus.ro','Cauta rubrica lui Julius Constantinescu!!!','','',0,'Aici te kishi pe dvs de ras!','Y',2,0,'0000-00-00 00:00:00','','',''),(45,'http://gk.voce.ro/','Si asta scrie bine!','','',0,'Dap!','Y',1,0,'0000-00-00 00:00:00','','',''),(46,'http://peculiarme.wordpress.com/','O gajica care scrie mai ghini ca mine :D','','',0,'O gajica cu tecste.','Y',1,0,'0000-00-00 00:00:00','','',''),(47,'http://www.sergiubiris.ro/','Baiatul lui Veta Biris','','',0,'Omu\' asta e cam trilulilu!','Y',1,0,'0000-00-00 00:00:00','','',''),(49,'http://boomboombay.canalblog.com/','Blogu\' lu Emilie, frantuzoaica din India','','',0,'Daca nu v-ati prins pan-amu, e in alta limba!','Y',1,0,'0000-00-00 00:00:00','','','');
/*!40000 ALTER TABLE `wp_links` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `wp_options`
--

DROP TABLE IF EXISTS `wp_options`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `wp_options` (
  `option_id` bigint(20) NOT NULL AUTO_INCREMENT,
  `blog_id` int(11) NOT NULL DEFAULT 0,
  `option_name` varchar(64) NOT NULL DEFAULT '',
  `option_value` longtext NOT NULL,
  `autoload` varchar(20) NOT NULL DEFAULT 'yes',
  PRIMARY KEY (`option_id`,`blog_id`,`option_name`),
  KEY `option_name` (`option_name`),
  FULLTEXT KEY `option_value` (`option_value`),
  FULLTEXT KEY `option_value_2` (`option_value`)
) ENGINE=MyISAM AUTO_INCREMENT=209 DEFAULT CHARSET=latin1;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `wp_options`
--

LOCK TABLES `wp_options` WRITE;
/*!40000 ALTER TABLE `wp_options` DISABLE KEYS */;
INSERT INTO `wp_options` VALUES (1,0,'siteurl','http://groparu.mariusperijoc.ro','yes'),(2,0,'blogname','Nascut din spermatozoizi campioni','yes'),(3,0,'blogdescription','Sunt un om dintr-o bucata. Una de creier','yes'),(66,0,'wp_user_roles','a:5:{s:13:\"administrator\";a:2:{s:4:\"name\";s:13:\"Administrator\";s:12:\"capabilities\";a:51:{s:13:\"switch_themes\";b:1;s:11:\"edit_themes\";b:1;s:16:\"activate_plugins\";b:1;s:12:\"edit_plugins\";b:1;s:10:\"edit_users\";b:1;s:10:\"edit_files\";b:1;s:14:\"manage_options\";b:1;s:17:\"moderate_comments\";b:1;s:17:\"manage_categories\";b:1;s:12:\"manage_links\";b:1;s:12:\"upload_files\";b:1;s:6:\"import\";b:1;s:15:\"unfiltered_html\";b:1;s:10:\"edit_posts\";b:1;s:17:\"edit_others_posts\";b:1;s:20:\"edit_published_posts\";b:1;s:13:\"publish_posts\";b:1;s:10:\"edit_pages\";b:1;s:4:\"read\";b:1;s:8:\"level_10\";b:1;s:7:\"level_9\";b:1;s:7:\"level_8\";b:1;s:7:\"level_7\";b:1;s:7:\"level_6\";b:1;s:7:\"level_5\";b:1;s:7:\"level_4\";b:1;s:7:\"level_3\";b:1;s:7:\"level_2\";b:1;s:7:\"level_1\";b:1;s:7:\"level_0\";b:1;s:17:\"edit_others_pages\";b:1;s:20:\"edit_published_pages\";b:1;s:13:\"publish_pages\";b:1;s:12:\"delete_pages\";b:1;s:19:\"delete_others_pages\";b:1;s:22:\"delete_published_pages\";b:1;s:12:\"delete_posts\";b:1;s:19:\"delete_others_posts\";b:1;s:22:\"delete_published_posts\";b:1;s:20:\"delete_private_posts\";b:1;s:18:\"edit_private_posts\";b:1;s:18:\"read_private_posts\";b:1;s:20:\"delete_private_pages\";b:1;s:18:\"edit_private_pages\";b:1;s:18:\"read_private_pages\";b:1;s:12:\"delete_users\";b:1;s:12:\"create_users\";b:1;s:17:\"unfiltered_upload\";b:1;s:14:\"edit_dashboard\";b:1;s:14:\"update_plugins\";b:1;s:14:\"delete_plugins\";b:1;}}s:6:\"editor\";a:2:{s:4:\"name\";s:6:\"Editor\";s:12:\"capabilities\";a:34:{s:17:\"moderate_comments\";b:1;s:17:\"manage_categories\";b:1;s:12:\"manage_links\";b:1;s:12:\"upload_files\";b:1;s:15:\"unfiltered_html\";b:1;s:10:\"edit_posts\";b:1;s:17:\"edit_others_posts\";b:1;s:20:\"edit_published_posts\";b:1;s:13:\"publish_posts\";b:1;s:10:\"edit_pages\";b:1;s:4:\"read\";b:1;s:7:\"level_7\";b:1;s:7:\"level_6\";b:1;s:7:\"level_5\";b:1;s:7:\"level_4\";b:1;s:7:\"level_3\";b:1;s:7:\"level_2\";b:1;s:7:\"level_1\";b:1;s:7:\"level_0\";b:1;s:17:\"edit_others_pages\";b:1;s:20:\"edit_published_pages\";b:1;s:13:\"publish_pages\";b:1;s:12:\"delete_pages\";b:1;s:19:\"delete_others_pages\";b:1;s:22:\"delete_published_pages\";b:1;s:12:\"delete_posts\";b:1;s:19:\"delete_others_posts\";b:1;s:22:\"delete_published_posts\";b:1;s:20:\"delete_private_posts\";b:1;s:18:\"edit_private_posts\";b:1;s:18:\"read_private_posts\";b:1;s:20:\"delete_private_pages\";b:1;s:18:\"edit_private_pages\";b:1;s:18:\"read_private_pages\";b:1;}}s:6:\"author\";a:2:{s:4:\"name\";s:6:\"Author\";s:12:\"capabilities\";a:10:{s:12:\"upload_files\";b:1;s:10:\"edit_posts\";b:1;s:20:\"edit_published_posts\";b:1;s:13:\"publish_posts\";b:1;s:4:\"read\";b:1;s:7:\"level_2\";b:1;s:7:\"level_1\";b:1;s:7:\"level_0\";b:1;s:12:\"delete_posts\";b:1;s:22:\"delete_published_posts\";b:1;}}s:11:\"contributor\";a:2:{s:4:\"name\";s:11:\"Contributor\";s:12:\"capabilities\";a:5:{s:10:\"edit_posts\";b:1;s:4:\"read\";b:1;s:7:\"level_1\";b:1;s:7:\"level_0\";b:1;s:12:\"delete_posts\";b:1;}}s:10:\"subscriber\";a:2:{s:4:\"name\";s:10:\"Subscriber\";s:12:\"capabilities\";a:2:{s:4:\"read\";b:1;s:7:\"level_0\";b:1;}}}','yes'),(5,0,'users_can_register','','yes'),(6,0,'admin_email','groparu_ro@yahoo.com','yes'),(7,0,'start_of_week','1','yes'),(8,0,'use_balanceTags','','yes'),(9,0,'use_smilies','1','yes'),(10,0,'require_name_email','','yes'),(11,0,'comments_notify','1','yes'),(12,0,'posts_per_rss','8','yes'),(13,0,'rss_excerpt_length','50','yes'),(14,0,'rss_use_excerpt','1','yes'),(15,0,'mailserver_url','mail.example.com','yes'),(16,0,'mailserver_login','login@example.com','yes'),(17,0,'mailserver_pass','password','yes'),(18,0,'mailserver_port','110','yes'),(19,0,'default_category','7','yes'),(20,0,'default_comment_status','open','yes'),(21,0,'default_ping_status','open','yes'),(22,0,'default_pingback_flag','1','yes'),(23,0,'default_post_edit_rows','10','yes'),(24,0,'posts_per_page','8','yes'),(25,0,'what_to_show','posts','yes'),(26,0,'date_format','j,, F, Y','yes'),(27,0,'time_format','g:i a','yes'),(28,0,'links_updated_date_format','F j, Y g:i a','yes'),(29,0,'links_recently_updated_prepend','<em>','yes'),(30,0,'links_recently_updated_append','</em>','yes'),(31,0,'links_recently_updated_time','120','yes'),(32,0,'comment_moderation','','yes'),(33,0,'moderation_notify','1','yes'),(34,0,'permalink_structure','','yes'),(35,0,'gzipcompression','','yes'),(36,0,'hack_file','','yes'),(37,0,'blog_charset','UTF-8','yes'),(38,0,'moderation_keys','','no'),(39,0,'active_plugins','a:0:{}','yes'),(40,0,'home','http://groparu.mariusperijoc.ro','yes'),(41,0,'category_base','','yes'),(42,0,'ping_sites','http://rpc.pingomatic.com/','yes'),(43,0,'advanced_edit','0','yes'),(44,0,'comment_max_links','2','yes'),(45,0,'gmt_offset','2','yes'),(46,0,'default_email_category','1','yes'),(47,0,'recently_edited','a:5:{i:0;s:19:\"wp-content/plugins/\";i:1;s:35:\"wp-content/themes/default/style.css\";i:3;s:36:\"wp-content/themes/default/header.php\";i:4;s:52:\"wp-content/plugins/video-embedder/video-embedder.php\";i:5;s:52:\"wp-content/plugins/embedded-video/embedded-video.php\";}','no'),(48,0,'use_linksupdate','','yes'),(49,0,'template','default','yes'),(50,0,'stylesheet','default','yes'),(51,0,'comment_whitelist','','yes'),(53,0,'blacklist_keys','','no'),(54,0,'comment_registration','','yes'),(55,0,'rss_language','en','yes'),(56,0,'html_type','text/html','yes'),(57,0,'use_trackback','0','yes'),(58,0,'default_role','subscriber','yes'),(59,0,'db_version','8201','yes'),(60,0,'uploads_use_yearmonth_folders','1','yes'),(61,0,'upload_path','wp-content/uploads','yes'),(62,0,'secret','VjVbt)8@ObgXAWA#LySYrComG#2$SVbcv2HueQIGOiEHwdUv5NA#^GjQ*qf(CoKB','yes'),(63,0,'blog_public','1','yes'),(64,0,'default_link_category','7','yes'),(65,0,'show_on_front','','yes'),(68,0,'rss_867bd5c64f85878d03a060509cd2f92c','O:9:\"MagpieRSS\":19:{s:6:\"parser\";i:0;s:12:\"current_item\";a:0:{}s:5:\"items\";a:50:{i:0;a:7:{s:5:\"title\";s:24:\"Matt: Visiting Techstars\";s:4:\"guid\";s:20:\"http://ma.tt/?p=6735\";s:4:\"link\";s:40:\"http://ma.tt/2008/07/visiting-techstars/\";s:11:\"description\";s:9976:\"<p>Visiting the Techstars in Boulder, Colorado.</p>\n<p><span id=\"more-6735\"></span></p>\n\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4767/\" title=\"mcm_4767\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4767-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4768/\" title=\"mcm_4768\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4768-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4772/\" title=\"mcm_4772\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4772-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4773/\" title=\"mcm_4773\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4773-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4774/\" title=\"mcm_4774\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4774-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4775/\" title=\"mcm_4775\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4775-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4783/\" title=\"mcm_4783\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4783-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4784/\" title=\"mcm_4784\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4784-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4785/\" title=\"mcm_4785\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4785-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4789/\" title=\"mcm_4789\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4789-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4790/\" title=\"mcm_4790\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4790-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4791/\" title=\"mcm_4791\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4791-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4794/\" title=\"mcm_4794\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4794-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4799/\" title=\"mcm_4799\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4799-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4801/\" title=\"mcm_4801\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4801-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4805/\" title=\"mcm_4805\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4805-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4806/\" title=\"mcm_4806\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4806-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4808/\" title=\"mcm_4808\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4808-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4809/\" title=\"mcm_4809\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4809-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4812/\" title=\"mcm_4812\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4812-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4813/\" title=\"mcm_4813\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4813-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4815/\" title=\"mcm_4815\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4815-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4816/\" title=\"mcm_4816\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4816-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4820/\" title=\"mcm_4820\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4820-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4822/\" title=\"mcm_4822\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4822-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4826/\" title=\"mcm_4826\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4826-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4827/\" title=\"mcm_4827\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4827-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4833/\" title=\"mcm_4833\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4833-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4835/\" title=\"mcm_4835\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4835-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4836/\" title=\"mcm_4836\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4836-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4839/\" title=\"mcm_4839\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4839-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4841/\" title=\"mcm_4841\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4841-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4843/\" title=\"mcm_4843\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4843-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4845/\" title=\"mcm_4845\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4845-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4848/\" title=\"mcm_4848\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4848-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4849/\" title=\"mcm_4849\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4849-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4857/\" title=\"mcm_4857\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4857-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4862/\" title=\"mcm_4862\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4862-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4868/\" title=\"mcm_4868\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4868-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4874/\" title=\"mcm_4874\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4874-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4877/\" title=\"mcm_4877\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4877-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4880/\" title=\"mcm_4880\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4880-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4882/\" title=\"mcm_4882\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4882-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4887/\" title=\"mcm_4887\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4887-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4889/\" title=\"mcm_4889\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4889-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4890/\" title=\"mcm_4890\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4890-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4892/\" title=\"mcm_4892\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4892-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4896/\" title=\"mcm_4896\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4896-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\";s:7:\"pubdate\";s:31:\"Fri, 25 Jul 2008 07:00:15 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Matt\";}s:7:\"summary\";s:9976:\"<p>Visiting the Techstars in Boulder, Colorado.</p>\n<p><span id=\"more-6735\"></span></p>\n\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4767/\" title=\"mcm_4767\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4767-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4768/\" title=\"mcm_4768\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4768-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4772/\" title=\"mcm_4772\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4772-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4773/\" title=\"mcm_4773\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4773-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4774/\" title=\"mcm_4774\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4774-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4775/\" title=\"mcm_4775\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4775-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4783/\" title=\"mcm_4783\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4783-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4784/\" title=\"mcm_4784\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4784-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4785/\" title=\"mcm_4785\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4785-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4789/\" title=\"mcm_4789\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4789-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4790/\" title=\"mcm_4790\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4790-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4791/\" title=\"mcm_4791\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4791-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4794/\" title=\"mcm_4794\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4794-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4799/\" title=\"mcm_4799\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4799-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4801/\" title=\"mcm_4801\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4801-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4805/\" title=\"mcm_4805\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4805-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4806/\" title=\"mcm_4806\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4806-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4808/\" title=\"mcm_4808\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4808-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4809/\" title=\"mcm_4809\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4809-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4812/\" title=\"mcm_4812\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4812-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4813/\" title=\"mcm_4813\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4813-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4815/\" title=\"mcm_4815\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4815-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4816/\" title=\"mcm_4816\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4816-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4820/\" title=\"mcm_4820\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4820-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4822/\" title=\"mcm_4822\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4822-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4826/\" title=\"mcm_4826\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4826-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4827/\" title=\"mcm_4827\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4827-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4833/\" title=\"mcm_4833\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4833-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4835/\" title=\"mcm_4835\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4835-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4836/\" title=\"mcm_4836\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4836-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4839/\" title=\"mcm_4839\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4839-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4841/\" title=\"mcm_4841\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4841-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4843/\" title=\"mcm_4843\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4843-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4845/\" title=\"mcm_4845\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4845-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4848/\" title=\"mcm_4848\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4848-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4849/\" title=\"mcm_4849\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4849-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4857/\" title=\"mcm_4857\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4857-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4862/\" title=\"mcm_4862\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4862-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4868/\" title=\"mcm_4868\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4868-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4874/\" title=\"mcm_4874\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4874-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4877/\" title=\"mcm_4877\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4877-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4880/\" title=\"mcm_4880\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4880-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4882/\" title=\"mcm_4882\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4882-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4887/\" title=\"mcm_4887\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4887-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4889/\" title=\"mcm_4889\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4889-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4890/\" title=\"mcm_4890\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4890-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4892/\" title=\"mcm_4892\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4892-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/visiting-techstars/mcm_4896/\" title=\"mcm_4896\"><img src=\"http://s.ma.tt/files/2008/07/mcm_4896-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\";}i:1;a:7:{s:5:\"title\";s:24:\"Matt: 2.6 by the numbers\";s:4:\"guid\";s:20:\"http://ma.tt/?p=6733\";s:4:\"link\";s:39:\"http://ma.tt/2008/07/26-by-the-numbers/\";s:11:\"description\";s:1432:\"<p>Now that we&#8217;re now 10 days into the release of <a href=\"http://wordpress.org/development/2008/07/wordpress-26-tyner/\">version 2.6 of WordPress</a>, it&#8217;d be interesting to look at a few of the numbers around it.</p>\n<ul>\n<li>There have been around 23 thousand downloads per day. (Of just the English version.)</li>\n<li>According to the update system there are 201 thousand blogs using 2.6 already.</li>\n<li>That&#8217;s about 9% of all known WordPress.org blogs in 10 days.</li>\n<li>The video in the announcement post has been viewed 665,080 times.</li>\n<li>There have been over 300 themes submitted to the new <a href=\"http://wordpress.org/extend/themes/\">Theme directory</a>, which <a href=\"http://wordpress.org/development/2008/07/theme-directory/\">launched</a> just 6 days ago.</li>\n<li>In the same period (10 days) there were 579,871 downloads of 2,527 plugins.</li>\n</ul>\n<p>I imagine 2.6 adoption will pick up after the 2.6.1 release &#8212; a lot of people wait for the .1 before upgrading.</p>\n<p>How are we celebrating? <strong>By working on 2.7!</strong></p>\n<p>It should be a fun release both for the features we have planned and also because it might incorporate some of the aspects of Crazyhorse, our experimental bizarro world <a href=\"http://svn.automattic.com/wordpress/branches/crazyhorse/\">dev branch</a> which we&#8217;re laser-eye-testing in NYC next week. (700 blogs are running 2.7 already.)</p>\";s:7:\"pubdate\";s:31:\"Fri, 25 Jul 2008 05:34:17 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Matt\";}s:7:\"summary\";s:1432:\"<p>Now that we&#8217;re now 10 days into the release of <a href=\"http://wordpress.org/development/2008/07/wordpress-26-tyner/\">version 2.6 of WordPress</a>, it&#8217;d be interesting to look at a few of the numbers around it.</p>\n<ul>\n<li>There have been around 23 thousand downloads per day. (Of just the English version.)</li>\n<li>According to the update system there are 201 thousand blogs using 2.6 already.</li>\n<li>That&#8217;s about 9% of all known WordPress.org blogs in 10 days.</li>\n<li>The video in the announcement post has been viewed 665,080 times.</li>\n<li>There have been over 300 themes submitted to the new <a href=\"http://wordpress.org/extend/themes/\">Theme directory</a>, which <a href=\"http://wordpress.org/development/2008/07/theme-directory/\">launched</a> just 6 days ago.</li>\n<li>In the same period (10 days) there were 579,871 downloads of 2,527 plugins.</li>\n</ul>\n<p>I imagine 2.6 adoption will pick up after the 2.6.1 release &#8212; a lot of people wait for the .1 before upgrading.</p>\n<p>How are we celebrating? <strong>By working on 2.7!</strong></p>\n<p>It should be a fun release both for the features we have planned and also because it might incorporate some of the aspects of Crazyhorse, our experimental bizarro world <a href=\"http://svn.automattic.com/wordpress/branches/crazyhorse/\">dev branch</a> which we&#8217;re laser-eye-testing in NYC next week. (700 blogs are running 2.7 already.)</p>\";}i:2;a:7:{s:5:\"title\";s:57:\"Weblog Tools Collection: Slickdeals.net Blog on WordPress\";s:4:\"guid\";s:40:\"http://weblogtoolscollection.com/?p=3775\";s:4:\"link\";s:85:\"http://weblogtoolscollection.com/archives/2008/07/24/slickdealsnet-blog-on-wordpress/\";s:11:\"description\";s:462:\"<p><a href=\"http://blog.slickdeals.net/\">Slickdeals.net Blog</a>: Slickdeals recently started a new &#8220;Slickblog&#8221; with WordPress. They seem to have put together a pretty seamless integeration between WordPress and their highly complex vBulletin installation and the comments on their blog are redirected to the main forums. I really like their sidebar items, including their hot topics by ratings and up and coming topics by the number of comments.</p>\";s:7:\"pubdate\";s:31:\"Fri, 25 Jul 2008 01:21:42 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:10:\"Mark Ghosh\";}s:7:\"summary\";s:462:\"<p><a href=\"http://blog.slickdeals.net/\">Slickdeals.net Blog</a>: Slickdeals recently started a new &#8220;Slickblog&#8221; with WordPress. They seem to have put together a pretty seamless integeration between WordPress and their highly complex vBulletin installation and the comments on their blog are redirected to the main forums. I really like their sidebar items, including their hot topics by ratings and up and coming topics by the number of comments.</p>\";}i:3;a:7:{s:5:\"title\";s:30:\"Matt: Caloric Restriction Pill\";s:4:\"guid\";s:46:\"http://ma.tt/2008/07/caloric-restriction-pill/\";s:4:\"link\";s:46:\"http://ma.tt/2008/07/caloric-restriction-pill/\";s:11:\"description\";s:121:\"<p><a href=\"http://blog.wired.com/wiredscience/2008/07/caloric-restric.html\">Caloric Restriction Comes in a Pill</a>.</p>\";s:7:\"pubdate\";s:31:\"Thu, 24 Jul 2008 21:24:59 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Matt\";}s:7:\"summary\";s:121:\"<p><a href=\"http://blog.wired.com/wiredscience/2008/07/caloric-restric.html\">Caloric Restriction Comes in a Pill</a>.</p>\";}i:4;a:7:{s:5:\"title\";s:56:\"Weblog Tools Collection: WordPress Plugin Releases 07/24\";s:4:\"guid\";s:40:\"http://weblogtoolscollection.com/?p=3774\";s:4:\"link\";s:84:\"http://weblogtoolscollection.com/archives/2008/07/24/wordpress-plugin-releases-0724/\";s:11:\"description\";s:3767:\"<p><a href=\"http://beyn.org/sidecat/\"><strong>Category Selector Back to the Sidebar</strong></a></p>\n<p>A simple plugin which moves the category selector back to the sidebar of the Post New page. In return, it removes the Related section (just because that I&#8217;m new in PHP and this is my first plugin), except the Press This bookmarklet.</p>\n<p><a href=\"http://scribu.net/projects/deviant-thumbs.html\"><strong>Deviant Thumbs</strong></a><strong> </strong></p>\n<p>This plugin displays thumbs from deviantART in a configurable carousel. It has widget support and is licensed under the GPL.</p>\n<p><a href=\"http://www.themoviequotes.com/tools/wordpress\"><strong>Movie Quotes</strong></a></p>\n<p>The Movie Quotes widget will fetch the latest, random or top rated quotes from themoviequotes.com website, and display them on your blog.</p>\n<p><a href=\"http://www.prelovac.com/vladimir/wordpress-plugins/snazzy-archives\"><strong>Snazzy Archives</strong></a></p>\n<p>A visualization plugin for your WordPress site featuring an unique way to display all your posts. Your archive page will never be boring again!</p>\n<p><a href=\"http://www.prelovac.com/vladimir/wordpress-plugins/show-me-options\"><strong>Show Me Options</strong></a></p>\n<p>How many times have you activated a plugin and the searched hopelessly for it’s options page? When you activate a new plugin, Show Me Options will show you a link to the options page you can use immediately.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/zdmultilang/\"><strong>ZdMultilang</strong></a></p>\n<p>A Multilingual plugin for WordPress allowing you to blog in more than one language. You can define multiple languages and translate posts/tags/categories using the interface that will be added to your blog’s administration panel.</p>\n<p><a href=\"http://www.zen-dreams.com/en/zdstats/\"><strong>ZdStats</strong></a></p>\n<p>A WordPress plugin allowing you to trace your visitors. This is not a simple statistics plugin, it’s very flexible and dynamic. This means you can update your filters by yourself and therefore by as realistic as possible.</p>\n<p><a href=\"http://techblissonline.com/broken-links-remover-wordpress-plugin/\"><strong>Broken Links Remover</strong></a></p>\n<p>It helps you fix bad/broken links, both text links(anchor tags) and image links (img tags). It blocks the display of such links on your WordPress post/page, until you fix them. These are not made visible to search engine robots as well, until you correct them.</p>\n<p><a href=\"http://www.dkcell.com.br/design/2008/dk-obama-plugin/\"><strong>Dk Obama</strong></a></p>\n<p>Imitates the gallery as on Barack Obama&#8217;s site.</p>\n<p><a href=\"http://www.webmaster-source.com/wp125-ad-plugin-wordpress/\"><strong>WP125</strong></a></p>\n<p>The WP125 plugin can help you manage your ads more efficiently, leaving you with more time to write new posts. Ads are automatically taken down when their time is up, and optional click counting is available.</p>\n<p><a href=\"http://nwfloridarepublican.com/?page_id=77\"><strong>McCain Widget</strong></a></p>\n<p>Place a Blogs for McCain widget in your side bar.</p>\n<p><a href=\"http://calendarscripts.info/overweight-calculator-wordpress-plugin.html\"><strong>Overweight Calculator</strong></a></p>\n<p>This bmi calculator is intended to blogs who write about health, wellness, fitness, food and recipes and sport. The plugin helps your visitors calculate their body mass index and if they are overweight, to understand what is the weight range they should aim for.</p>\n<p><a href=\"http://sharkinvestor.com/investment-calculator-wordpress-plugin/\"><strong>Investment Calculator</strong></a></p>\n<p>This plugin will be most useful for personal finance, credit, loans, investment related or trading blogs.</p>\";s:7:\"pubdate\";s:31:\"Thu, 24 Jul 2008 18:52:30 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Ajay\";}s:7:\"summary\";s:3767:\"<p><a href=\"http://beyn.org/sidecat/\"><strong>Category Selector Back to the Sidebar</strong></a></p>\n<p>A simple plugin which moves the category selector back to the sidebar of the Post New page. In return, it removes the Related section (just because that I&#8217;m new in PHP and this is my first plugin), except the Press This bookmarklet.</p>\n<p><a href=\"http://scribu.net/projects/deviant-thumbs.html\"><strong>Deviant Thumbs</strong></a><strong> </strong></p>\n<p>This plugin displays thumbs from deviantART in a configurable carousel. It has widget support and is licensed under the GPL.</p>\n<p><a href=\"http://www.themoviequotes.com/tools/wordpress\"><strong>Movie Quotes</strong></a></p>\n<p>The Movie Quotes widget will fetch the latest, random or top rated quotes from themoviequotes.com website, and display them on your blog.</p>\n<p><a href=\"http://www.prelovac.com/vladimir/wordpress-plugins/snazzy-archives\"><strong>Snazzy Archives</strong></a></p>\n<p>A visualization plugin for your WordPress site featuring an unique way to display all your posts. Your archive page will never be boring again!</p>\n<p><a href=\"http://www.prelovac.com/vladimir/wordpress-plugins/show-me-options\"><strong>Show Me Options</strong></a></p>\n<p>How many times have you activated a plugin and the searched hopelessly for it’s options page? When you activate a new plugin, Show Me Options will show you a link to the options page you can use immediately.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/zdmultilang/\"><strong>ZdMultilang</strong></a></p>\n<p>A Multilingual plugin for WordPress allowing you to blog in more than one language. You can define multiple languages and translate posts/tags/categories using the interface that will be added to your blog’s administration panel.</p>\n<p><a href=\"http://www.zen-dreams.com/en/zdstats/\"><strong>ZdStats</strong></a></p>\n<p>A WordPress plugin allowing you to trace your visitors. This is not a simple statistics plugin, it’s very flexible and dynamic. This means you can update your filters by yourself and therefore by as realistic as possible.</p>\n<p><a href=\"http://techblissonline.com/broken-links-remover-wordpress-plugin/\"><strong>Broken Links Remover</strong></a></p>\n<p>It helps you fix bad/broken links, both text links(anchor tags) and image links (img tags). It blocks the display of such links on your WordPress post/page, until you fix them. These are not made visible to search engine robots as well, until you correct them.</p>\n<p><a href=\"http://www.dkcell.com.br/design/2008/dk-obama-plugin/\"><strong>Dk Obama</strong></a></p>\n<p>Imitates the gallery as on Barack Obama&#8217;s site.</p>\n<p><a href=\"http://www.webmaster-source.com/wp125-ad-plugin-wordpress/\"><strong>WP125</strong></a></p>\n<p>The WP125 plugin can help you manage your ads more efficiently, leaving you with more time to write new posts. Ads are automatically taken down when their time is up, and optional click counting is available.</p>\n<p><a href=\"http://nwfloridarepublican.com/?page_id=77\"><strong>McCain Widget</strong></a></p>\n<p>Place a Blogs for McCain widget in your side bar.</p>\n<p><a href=\"http://calendarscripts.info/overweight-calculator-wordpress-plugin.html\"><strong>Overweight Calculator</strong></a></p>\n<p>This bmi calculator is intended to blogs who write about health, wellness, fitness, food and recipes and sport. The plugin helps your visitors calculate their body mass index and if they are overweight, to understand what is the weight range they should aim for.</p>\n<p><a href=\"http://sharkinvestor.com/investment-calculator-wordpress-plugin/\"><strong>Investment Calculator</strong></a></p>\n<p>This plugin will be most useful for personal finance, credit, loans, investment related or trading blogs.</p>\";}i:5;a:7:{s:5:\"title\";s:62:\"Mark Jaquith: How to write a solid and stable WordPress plugin\";s:4:\"guid\";s:39:\"http://markjaquith.wordpress.com/?p=155\";s:4:\"link\";s:93:\"http://markjaquith.wordpress.com/2008/07/23/how-to-write-a-solid-and-stable-wordpress-plugin/\";s:11:\"description\";s:4469:\"<div class=\"snap_preview\"><br /><p>The <a href=\"http://b5media.com/\">b5media</a> tech team was having a discussion today about what criteria we use when reviewing a WordPress plugin for possible inclusion on one of our sites or across our network.  It makes for a good list of what not to do (or not do) when writing a WordPress plugin, something that might be generally useful to plugin authors.  These things won&#8217;t make your plugin <em>good</em> &#8212; they&#8217;ll just help make it secure and stable.</p>\n<h3>Don&#8217;t ignore security</h3>\n<p>WordPress plugins have unlimited power, which is a blessing (it makes WordPress very flexible), but it can be a curse if your plugin is not code with security in mind.  If things like <a href=\"http://markjaquith.wordpress.com/2006/06/02/wordpress-203-nonces/\">CSRF</a>, <a href=\"http://apeatling.wordpress.com/2008/06/25/prepare-dont-escape/\">the prepare() method</a> (SQL injection protection), XSS are not intimately known to you, it&#8217;s time for you to do some research.  When someone installs their plugin, they are potentially putting their site&#8217;s security in your hands.  Rise to the occasion.</p>\n<h3>Make proper use of the role/capability system</h3>\n<p>WordPress controls admin access using a roles/capabilities system.  Make sure your plugin is checking against an appropriate capability.  If it is the sort of thing that only &#8220;admins&#8221; should use, you should be checking against the <code>manage_options</code> capability.  If this is something that an author should be able to do, you might use the <code>publish_post</code> capability.  Do not check against roles.  Roles are only containers for capabilities, and you can&#8217;t assume that an &#8220;author&#8221; on one blog means the same thing on all of them.</p>\n<h3>Use current API functions</h3>\n<p>WordPress has a lot of legacy code and deprecated functions.  We try not to break stuff without good reason, so often times we&#8217;ll leave in compatibility for old API functions.  If your plugin is using these functions, it tells me that you&#8217;re not up on current WordPress development.  This means that your plugin might be more likely to break with a WordPress upgrade, and it suggests sloppiness that can lead to security issues.</p>\n<h3>Mind your performance</h3>\n<p>The number of queries that your plugin makes can affect its performance.  We don&#8217;t care how cool your plugin is &#8212; if it uses 10 MySQL queries on every page, it&#8217;s not going in.  You should work to minimize these queries as much as possible.  Other performance issues like the efficiency of your PHP code should be taken into consideration as well.</p>\n<h3>Use existing WordPress data structures whenever possible</h3>\n<p>Don&#8217;t create your own tables unless you&#8217;re absolutely certain there is no way to accomplish your functionality within the WordPress data system.</p>\n<p>I&#8217;m going to go into more detail on these topics at a later date.  Maybe even with screencasts, which seem to be a great way of demonstrating these sorts of things.</p>\n<img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/categories/markjaquith.wordpress.com/155/\" /> <img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/tags/markjaquith.wordpress.com/155/\" /> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/gocomments/markjaquith.wordpress.com/155/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/comments/markjaquith.wordpress.com/155/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/godelicious/markjaquith.wordpress.com/155/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/delicious/markjaquith.wordpress.com/155/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/gostumble/markjaquith.wordpress.com/155/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/stumble/markjaquith.wordpress.com/155/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/godigg/markjaquith.wordpress.com/155/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/digg/markjaquith.wordpress.com/155/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/goreddit/markjaquith.wordpress.com/155/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/reddit/markjaquith.wordpress.com/155/\" /></a> <img alt=\"\" border=\"0\" src=\"http://stats.wordpress.com/b.gif?host=markjaquith.wordpress.com&blog=316&post=155&subd=markjaquith&ref=&feed=1\" /></div>\";s:7:\"pubdate\";s:31:\"Thu, 24 Jul 2008 04:00:44 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:12:\"Mark Jaquith\";}s:7:\"summary\";s:4469:\"<div class=\"snap_preview\"><br /><p>The <a href=\"http://b5media.com/\">b5media</a> tech team was having a discussion today about what criteria we use when reviewing a WordPress plugin for possible inclusion on one of our sites or across our network.  It makes for a good list of what not to do (or not do) when writing a WordPress plugin, something that might be generally useful to plugin authors.  These things won&#8217;t make your plugin <em>good</em> &#8212; they&#8217;ll just help make it secure and stable.</p>\n<h3>Don&#8217;t ignore security</h3>\n<p>WordPress plugins have unlimited power, which is a blessing (it makes WordPress very flexible), but it can be a curse if your plugin is not code with security in mind.  If things like <a href=\"http://markjaquith.wordpress.com/2006/06/02/wordpress-203-nonces/\">CSRF</a>, <a href=\"http://apeatling.wordpress.com/2008/06/25/prepare-dont-escape/\">the prepare() method</a> (SQL injection protection), XSS are not intimately known to you, it&#8217;s time for you to do some research.  When someone installs their plugin, they are potentially putting their site&#8217;s security in your hands.  Rise to the occasion.</p>\n<h3>Make proper use of the role/capability system</h3>\n<p>WordPress controls admin access using a roles/capabilities system.  Make sure your plugin is checking against an appropriate capability.  If it is the sort of thing that only &#8220;admins&#8221; should use, you should be checking against the <code>manage_options</code> capability.  If this is something that an author should be able to do, you might use the <code>publish_post</code> capability.  Do not check against roles.  Roles are only containers for capabilities, and you can&#8217;t assume that an &#8220;author&#8221; on one blog means the same thing on all of them.</p>\n<h3>Use current API functions</h3>\n<p>WordPress has a lot of legacy code and deprecated functions.  We try not to break stuff without good reason, so often times we&#8217;ll leave in compatibility for old API functions.  If your plugin is using these functions, it tells me that you&#8217;re not up on current WordPress development.  This means that your plugin might be more likely to break with a WordPress upgrade, and it suggests sloppiness that can lead to security issues.</p>\n<h3>Mind your performance</h3>\n<p>The number of queries that your plugin makes can affect its performance.  We don&#8217;t care how cool your plugin is &#8212; if it uses 10 MySQL queries on every page, it&#8217;s not going in.  You should work to minimize these queries as much as possible.  Other performance issues like the efficiency of your PHP code should be taken into consideration as well.</p>\n<h3>Use existing WordPress data structures whenever possible</h3>\n<p>Don&#8217;t create your own tables unless you&#8217;re absolutely certain there is no way to accomplish your functionality within the WordPress data system.</p>\n<p>I&#8217;m going to go into more detail on these topics at a later date.  Maybe even with screencasts, which seem to be a great way of demonstrating these sorts of things.</p>\n<img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/categories/markjaquith.wordpress.com/155/\" /> <img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/tags/markjaquith.wordpress.com/155/\" /> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/gocomments/markjaquith.wordpress.com/155/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/comments/markjaquith.wordpress.com/155/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/godelicious/markjaquith.wordpress.com/155/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/delicious/markjaquith.wordpress.com/155/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/gostumble/markjaquith.wordpress.com/155/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/stumble/markjaquith.wordpress.com/155/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/godigg/markjaquith.wordpress.com/155/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/digg/markjaquith.wordpress.com/155/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/goreddit/markjaquith.wordpress.com/155/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/reddit/markjaquith.wordpress.com/155/\" /></a> <img alt=\"\" border=\"0\" src=\"http://stats.wordpress.com/b.gif?host=markjaquith.wordpress.com&blog=316&post=155&subd=markjaquith&ref=&feed=1\" /></div>\";}i:6;a:7:{s:5:\"title\";s:55:\"Weblog Tools Collection: WordPress Theme Releases 07/23\";s:4:\"guid\";s:40:\"http://weblogtoolscollection.com/?p=3773\";s:4:\"link\";s:83:\"http://weblogtoolscollection.com/archives/2008/07/23/wordpress-theme-releases-0723/\";s:11:\"description\";s:2761:\"<p><a href=\"http://www.rodrigoghedin.com.br/squared/\"><strong>Squared</strong></a></p>\n<p><img alt=\"squared-10\" src=\"http://weblogtoolscollection.com/b2-img/2008/07/squared-10.gif\" height=\"125\" width=\"155\" /></p>\n<p>Squared is a very simple theme, two columns, widget ready, and valid XHTML 1.0</p>\n<p><a href=\"http://www.mubinahmed.com/wordpress-theme-directory-now-open/\"><strong>Simple</strong></a></p>\n<p><img alt=\"Simple\" src=\"http://weblogtoolscollection.com/b2-img/2008/07/simple.png\" height=\"125\" width=\"167\" /></p>\n<p>A two column colorful theme</p>\n<p><a href=\"http://www.slimmity.com/ragteka-v1/\"><strong>Rateka</strong></a></p>\n<p><a href=\"http://demo.slimmity.com/index.php?wptheme=Ragteka+Premium\"><img alt=\"rateka\" src=\"http://weblogtoolscollection.com/b2-img/2008/07/rateka.gif\" height=\"119\" width=\"200\" /></a></p>\n<p>Two column theme comes widget ready. Custom sidebar ad widgets. Also has 3 color schemes incorporated. Allows you to add subscription by email from admin panel. Easy to manage ads from php file.</p>\n<p><a href=\"http://fresh01.co.za/preview/index.php?wptheme=Scruffy\"><strong>Scruffy</strong></a></p>\n<p><a href=\"http://fresh01.co.za/preview/index.php?wptheme=Scruffy\"><img alt=\"Scruffy\" src=\"http://weblogtoolscollection.com/b2-img/2008/07/scruffy.jpg\" height=\"118\" width=\"200\" /></a></p>\n<p>Scruffy is a WordPress theme with a standard two column layout and all the basic WP features. What makes this theme special is it&#8217;s unique &#8220;grunge&#8221; design.</p>\n<p><a href=\"http://www.teckitech.com/07/wordpress-theme-web-20-blue/\"><strong>Web 2.0 Blue</strong></a></p>\n<p><a href=\"http://ourfather.co.cc/index.php?wptheme=Web+2.0+Blue\"><img alt=\"web2-0blue\" src=\"http://weblogtoolscollection.com/b2-img/2008/07/web2-0blue.jpg\" height=\"125\" width=\"175\" /></a></p>\n<p>Great web 2.0 looking, Great use of colors, Simple, Plain, Minimalist theme, Hemingway Style, Can be customized easily through detailed CSS. Support all plugins that Hemingway supports, Huge space for Widget lovers as it is 3 Column theme, Can customize images for blockquotes and so on&#8230;</p>\n<p><a href=\"http://www.fikirbozan.net/if-wordpress-theme/\"><strong>iF</strong></a></p>\n<p><img alt=\"iF\" src=\"http://weblogtoolscollection.com/b2-img/2008/07/if.png\" height=\"116\" width=\"200\" /></p>\n<p>iF is a clean, simple theme with a left sidebar.</p>\n<p><a href=\"http://www.wpthemedesigner.com/2008/07/13/funky-zine-theme/\"><strong>FunkyZine</strong></a></p>\n<p><a href=\"http://ythv.info/funkyzine/\"><img alt=\"FunkyZine\" src=\"http://weblogtoolscollection.com/b2-img/2008/07/funkyzine.jpg\" height=\"114\" width=\"200\" /></a></p>\n<p>2 Columns, Wood Design, Rounded Corners, Dark, Banner Ad Ready, Tested on WordPress 2.5, Fixed Width, PSD logo Attached.</p>\";s:7:\"pubdate\";s:31:\"Wed, 23 Jul 2008 20:45:07 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Ajay\";}s:7:\"summary\";s:2761:\"<p><a href=\"http://www.rodrigoghedin.com.br/squared/\"><strong>Squared</strong></a></p>\n<p><img alt=\"squared-10\" src=\"http://weblogtoolscollection.com/b2-img/2008/07/squared-10.gif\" height=\"125\" width=\"155\" /></p>\n<p>Squared is a very simple theme, two columns, widget ready, and valid XHTML 1.0</p>\n<p><a href=\"http://www.mubinahmed.com/wordpress-theme-directory-now-open/\"><strong>Simple</strong></a></p>\n<p><img alt=\"Simple\" src=\"http://weblogtoolscollection.com/b2-img/2008/07/simple.png\" height=\"125\" width=\"167\" /></p>\n<p>A two column colorful theme</p>\n<p><a href=\"http://www.slimmity.com/ragteka-v1/\"><strong>Rateka</strong></a></p>\n<p><a href=\"http://demo.slimmity.com/index.php?wptheme=Ragteka+Premium\"><img alt=\"rateka\" src=\"http://weblogtoolscollection.com/b2-img/2008/07/rateka.gif\" height=\"119\" width=\"200\" /></a></p>\n<p>Two column theme comes widget ready. Custom sidebar ad widgets. Also has 3 color schemes incorporated. Allows you to add subscription by email from admin panel. Easy to manage ads from php file.</p>\n<p><a href=\"http://fresh01.co.za/preview/index.php?wptheme=Scruffy\"><strong>Scruffy</strong></a></p>\n<p><a href=\"http://fresh01.co.za/preview/index.php?wptheme=Scruffy\"><img alt=\"Scruffy\" src=\"http://weblogtoolscollection.com/b2-img/2008/07/scruffy.jpg\" height=\"118\" width=\"200\" /></a></p>\n<p>Scruffy is a WordPress theme with a standard two column layout and all the basic WP features. What makes this theme special is it&#8217;s unique &#8220;grunge&#8221; design.</p>\n<p><a href=\"http://www.teckitech.com/07/wordpress-theme-web-20-blue/\"><strong>Web 2.0 Blue</strong></a></p>\n<p><a href=\"http://ourfather.co.cc/index.php?wptheme=Web+2.0+Blue\"><img alt=\"web2-0blue\" src=\"http://weblogtoolscollection.com/b2-img/2008/07/web2-0blue.jpg\" height=\"125\" width=\"175\" /></a></p>\n<p>Great web 2.0 looking, Great use of colors, Simple, Plain, Minimalist theme, Hemingway Style, Can be customized easily through detailed CSS. Support all plugins that Hemingway supports, Huge space for Widget lovers as it is 3 Column theme, Can customize images for blockquotes and so on&#8230;</p>\n<p><a href=\"http://www.fikirbozan.net/if-wordpress-theme/\"><strong>iF</strong></a></p>\n<p><img alt=\"iF\" src=\"http://weblogtoolscollection.com/b2-img/2008/07/if.png\" height=\"116\" width=\"200\" /></p>\n<p>iF is a clean, simple theme with a left sidebar.</p>\n<p><a href=\"http://www.wpthemedesigner.com/2008/07/13/funky-zine-theme/\"><strong>FunkyZine</strong></a></p>\n<p><a href=\"http://ythv.info/funkyzine/\"><img alt=\"FunkyZine\" src=\"http://weblogtoolscollection.com/b2-img/2008/07/funkyzine.jpg\" height=\"114\" width=\"200\" /></a></p>\n<p>2 Columns, Wood Design, Rounded Corners, Dark, Banner Ad Ready, Tested on WordPress 2.5, Fixed Width, PSD logo Attached.</p>\";}i:7;a:7:{s:5:\"title\";s:27:\"Matt: WordPress for iPhone!\";s:4:\"guid\";s:42:\"http://ma.tt/2008/07/wordpress-for-iphone/\";s:4:\"link\";s:42:\"http://ma.tt/2008/07/wordpress-for-iphone/\";s:11:\"description\";s:308:\"<p><a href=\"http://iphone.wordpress.org/2008/07/22/wordpress-for-iphone-available-now/\">WordPress for iPhone Available Now</a>. :)! Reviews coming in: <a href=\"http://news.cnet.com/8301-17939_109-9996382-2.html?part=rss&#038;tag=feed&#038;subj=Webware\">WordPress app hits the iPhone fashionably late</a>.</p>\";s:7:\"pubdate\";s:31:\"Tue, 22 Jul 2008 19:30:34 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Matt\";}s:7:\"summary\";s:308:\"<p><a href=\"http://iphone.wordpress.org/2008/07/22/wordpress-for-iphone-available-now/\">WordPress for iPhone Available Now</a>. :)! Reviews coming in: <a href=\"http://news.cnet.com/8301-17939_109-9996382-2.html?part=rss&#038;tag=feed&#038;subj=Webware\">WordPress app hits the iPhone fashionably late</a>.</p>\";}i:8;a:7:{s:5:\"title\";s:66:\"Weblog Tools Collection: How to get featured in our Daily Releases\";s:4:\"guid\";s:40:\"http://weblogtoolscollection.com/?p=3763\";s:4:\"link\";s:95:\"http://weblogtoolscollection.com/archives/2008/07/22/how-to-get-featured-in-our-daily-releases/\";s:11:\"description\";s:4464:\"<p>Our aim here at Weblog Tools Collection is to provide a platform for authors of themes and plugins and at the same time provide WordPress users a single place to keep up-to-date with the WordPress world.</p>\n<p>We try to keep abreast with both plugin and theme releases. The first place that we look for releases is the <a href=\"http://weblogtoolscollection.com/news/\">WLTC News Forum</a> and in this post I&#8217;ll try to cover some of the points that you should keep in mind to facilitate your listing.</p>\n<h4>1. Post in the appropriate category</h4>\n<p>The forum has been divided into several categories for different content. The two primary categories that you should be looking at are the <a href=\"http://weblogtoolscollection.com/news/forum/new-wordpress-plugins\">New Wordpress Plugins</a> category and the <a href=\"http://weblogtoolscollection.com/news/forum/new-wordpress-themes\">New Wordpress Themes</a> category for plugins and themes respectively. We also have a <a href=\"http://weblogtoolscollection.com/news/forum/premium-wordpress-themes\">Premium WordPress Themes</a> category for those themes which require payment to use.</p>\n<h4>2. Writing your post</h4>\n<p>This is the most important part of the process. Remember that the key to attracting a user to visit your plugin or theme page is a good detailed description. I, for one, would like to gather as much information about the plugin or theme from the post. Browsing to your site and then making a search for the right post / page is a big big no no!</p>\n<p>Plugin Authors should ensure the following is present in the post.</p>\n<ol>\n<li><strong>Plugin Name</strong>: short forms are OK, however the full form of the name is ideal</li>\n<li><strong>Plugin URL</strong>: This should be the direct url to the plugin page and not your site. Ideally keep a separate page for each plugin. It provides for a single interface to interact with users, as well helps in SEO.</li>\n<li><strong>Description</strong>: Let me iterate; provide a detailed description. Mention what exactly your plugin does. Elaborate on some of the features that the plugin has. Ask for suggestions. State what plans you have for the future of the plugin. Optionally, add information on installing and using the plugin. This information should also be present on the plugin page on your site.</li>\n<li><strong>License</strong></li>\n</ol>\n<p>Theme Authors should ensure the following is present in the post.</p>\n<ol>\n<li><strong>Theme Name</strong>: same rule to follow as that of plugin authors above</li>\n<li><strong>Theme URL</strong>: Once again, link to the url of the theme page. Putting several themes on a single page only serves as a distraction to a person looking for that specific theme.</li>\n<li><strong>Description</strong>: A detailed description for the theme should come here. Mention if your theme is widget ready, or if supports gravatars. Does it have an options page? Is it a one, two or three column theme? What colors is it available in? Is the header customizable?</li>\n<li><strong>Demo URL</strong>: Every theme should have a demo for a user to see what their site will look like. It is a pain to download and install a theme to check if it looks good, only to find that this is not the case.</li>\n<li><strong>Screenshot</strong>: This is optional but again highly recommended. A screenshot is the first view that a potential user sees.</li>\n<li><strong>License</strong></li>\n</ol>\n<p>The points I have made above are not just pertaining to our News forum. In fact this should something that you should follow strictly whenever you are looking to get listed at any site announcing releases.</p>\n<h4>3. Other methods to inform us about your release</h4>\n<p>The News forum is the preferred method to bring your creation to our attention. Not only does it bring your theme / plugin to our attention but it also ensures that you reach out to our regular readers even before our daily release posts.</p>\n<p>You could also use the <a href=\"http://weblogtoolscollection.com/contact-me/\">contact form</a> to inform us about the release. However, this is a much slower method to get listed. Remember to provide as many details as you would if you were to make a post in the News forum. Also, change the Subject line to <em>Plugin Release: your theme/plugin name</em>.</p>\n<p>Happy posting <img src=\"http://weblogtoolscollection.com/wp-includes/images/smilies/icon_smile.gif\" alt=\":)\" class=\"wp-smiley\" /></p>\";s:7:\"pubdate\";s:31:\"Tue, 22 Jul 2008 18:42:48 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Ajay\";}s:7:\"summary\";s:4464:\"<p>Our aim here at Weblog Tools Collection is to provide a platform for authors of themes and plugins and at the same time provide WordPress users a single place to keep up-to-date with the WordPress world.</p>\n<p>We try to keep abreast with both plugin and theme releases. The first place that we look for releases is the <a href=\"http://weblogtoolscollection.com/news/\">WLTC News Forum</a> and in this post I&#8217;ll try to cover some of the points that you should keep in mind to facilitate your listing.</p>\n<h4>1. Post in the appropriate category</h4>\n<p>The forum has been divided into several categories for different content. The two primary categories that you should be looking at are the <a href=\"http://weblogtoolscollection.com/news/forum/new-wordpress-plugins\">New Wordpress Plugins</a> category and the <a href=\"http://weblogtoolscollection.com/news/forum/new-wordpress-themes\">New Wordpress Themes</a> category for plugins and themes respectively. We also have a <a href=\"http://weblogtoolscollection.com/news/forum/premium-wordpress-themes\">Premium WordPress Themes</a> category for those themes which require payment to use.</p>\n<h4>2. Writing your post</h4>\n<p>This is the most important part of the process. Remember that the key to attracting a user to visit your plugin or theme page is a good detailed description. I, for one, would like to gather as much information about the plugin or theme from the post. Browsing to your site and then making a search for the right post / page is a big big no no!</p>\n<p>Plugin Authors should ensure the following is present in the post.</p>\n<ol>\n<li><strong>Plugin Name</strong>: short forms are OK, however the full form of the name is ideal</li>\n<li><strong>Plugin URL</strong>: This should be the direct url to the plugin page and not your site. Ideally keep a separate page for each plugin. It provides for a single interface to interact with users, as well helps in SEO.</li>\n<li><strong>Description</strong>: Let me iterate; provide a detailed description. Mention what exactly your plugin does. Elaborate on some of the features that the plugin has. Ask for suggestions. State what plans you have for the future of the plugin. Optionally, add information on installing and using the plugin. This information should also be present on the plugin page on your site.</li>\n<li><strong>License</strong></li>\n</ol>\n<p>Theme Authors should ensure the following is present in the post.</p>\n<ol>\n<li><strong>Theme Name</strong>: same rule to follow as that of plugin authors above</li>\n<li><strong>Theme URL</strong>: Once again, link to the url of the theme page. Putting several themes on a single page only serves as a distraction to a person looking for that specific theme.</li>\n<li><strong>Description</strong>: A detailed description for the theme should come here. Mention if your theme is widget ready, or if supports gravatars. Does it have an options page? Is it a one, two or three column theme? What colors is it available in? Is the header customizable?</li>\n<li><strong>Demo URL</strong>: Every theme should have a demo for a user to see what their site will look like. It is a pain to download and install a theme to check if it looks good, only to find that this is not the case.</li>\n<li><strong>Screenshot</strong>: This is optional but again highly recommended. A screenshot is the first view that a potential user sees.</li>\n<li><strong>License</strong></li>\n</ol>\n<p>The points I have made above are not just pertaining to our News forum. In fact this should something that you should follow strictly whenever you are looking to get listed at any site announcing releases.</p>\n<h4>3. Other methods to inform us about your release</h4>\n<p>The News forum is the preferred method to bring your creation to our attention. Not only does it bring your theme / plugin to our attention but it also ensures that you reach out to our regular readers even before our daily release posts.</p>\n<p>You could also use the <a href=\"http://weblogtoolscollection.com/contact-me/\">contact form</a> to inform us about the release. However, this is a much slower method to get listed. Remember to provide as many details as you would if you were to make a post in the News forum. Also, change the Subject line to <em>Plugin Release: your theme/plugin name</em>.</p>\n<p>Happy posting <img src=\"http://weblogtoolscollection.com/wp-includes/images/smilies/icon_smile.gif\" alt=\":)\" class=\"wp-smiley\" /></p>\";}i:9;a:7:{s:5:\"title\";s:59:\"Weblog Tools Collection: WordPress iPhone App Now Available\";s:4:\"guid\";s:40:\"http://weblogtoolscollection.com/?p=3761\";s:4:\"link\";s:88:\"http://weblogtoolscollection.com/archives/2008/07/22/wordpress-iphone-app-now-available/\";s:11:\"description\";s:1678:\"<p><a title=\"Opens Itunes And Takes You To The WordPress App\" href=\"http://ax.phobos.apple.com.edgesuite.net/WebObjects/MZStore.woa/wa/browserRedirect?url=itms%253A%252F%252Fax.phobos.apple.com.edgesuite.net%252FWebObjects%252FMZStore.woa%252Fwa%252FviewSoftware%253Fid%253D285073074%2526mt%253D8\" target=\"_blank\">It&#8217;s official</a>, the WordPress application for the iPhone has officially been released. Now you&#8217;ll be able to publish to WordPress powered blogs right from your Jesus phone. Here is what you can expect from this free app:</p>\n<ul>\n<li>Support for WP.com blogs and self-installed blogs version 2.5.1 and higher</li>\n<li>Embedded Safari for true previews of posts</li>\n<li>Full tag and category support</li>\n<li>Photo support for both camera pictures as well as library photos</li>\n<li>Support for multiple blogs</li>\n<li>Ability to password protect a post, save as a draft, or mark the post for later review</li>\n<li>Auto-recovery. This will recover posts which have been interrupted by phone calls</li>\n</ul>\n<p>The app is at version 1.0, is a tiny 0.3MB download, and is compatible with the iPhone as well as the iPod touch. However, this application requires the iPhone 2.0 software update.</p>\n<p><center><a href=\"http://weblogtoolscollection.com/b2-img/2008/07/wordpressapp.png\"><img src=\"http://weblogtoolscollection.com/b2-img/2008/07/wordpressapp-300x241.png\" alt=\"The WordPress iPhone Application\" title=\"The WordPress iPhone Application\" class=\"alignnone size-medium wp-image-3762\" height=\"241\" width=\"300\" /></a></center></p>\n<p>Be sure to let us know what your experience is like, browsing and publishing to WordPress from your iPhone.</p>\";s:7:\"pubdate\";s:31:\"Tue, 22 Jul 2008 05:24:43 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:13:\"Jeff Chandler\";}s:7:\"summary\";s:1678:\"<p><a title=\"Opens Itunes And Takes You To The WordPress App\" href=\"http://ax.phobos.apple.com.edgesuite.net/WebObjects/MZStore.woa/wa/browserRedirect?url=itms%253A%252F%252Fax.phobos.apple.com.edgesuite.net%252FWebObjects%252FMZStore.woa%252Fwa%252FviewSoftware%253Fid%253D285073074%2526mt%253D8\" target=\"_blank\">It&#8217;s official</a>, the WordPress application for the iPhone has officially been released. Now you&#8217;ll be able to publish to WordPress powered blogs right from your Jesus phone. Here is what you can expect from this free app:</p>\n<ul>\n<li>Support for WP.com blogs and self-installed blogs version 2.5.1 and higher</li>\n<li>Embedded Safari for true previews of posts</li>\n<li>Full tag and category support</li>\n<li>Photo support for both camera pictures as well as library photos</li>\n<li>Support for multiple blogs</li>\n<li>Ability to password protect a post, save as a draft, or mark the post for later review</li>\n<li>Auto-recovery. This will recover posts which have been interrupted by phone calls</li>\n</ul>\n<p>The app is at version 1.0, is a tiny 0.3MB download, and is compatible with the iPhone as well as the iPod touch. However, this application requires the iPhone 2.0 software update.</p>\n<p><center><a href=\"http://weblogtoolscollection.com/b2-img/2008/07/wordpressapp.png\"><img src=\"http://weblogtoolscollection.com/b2-img/2008/07/wordpressapp-300x241.png\" alt=\"The WordPress iPhone Application\" title=\"The WordPress iPhone Application\" class=\"alignnone size-medium wp-image-3762\" height=\"241\" width=\"300\" /></a></center></p>\n<p>Be sure to let us know what your experience is like, browsing and publishing to WordPress from your iPhone.</p>\";}i:10;a:7:{s:5:\"title\";s:32:\"Ryan Boren: WordPress for iPhone\";s:4:\"guid\";s:57:\"http://boren.nu/archives/2008/07/21/wordpress-for-iphone/\";s:4:\"link\";s:57:\"http://boren.nu/archives/2008/07/21/wordpress-for-iphone/\";s:11:\"description\";s:329:\"<p>I&#8217;m writing this on the WordPress app for the iPhone, which is <a href=\"http://iphone.wordpress.net/2008/07/22/wordpress-for-iphone-available now\">now available</a>.  Now if only the iPhone had cut-and-paste.  <img src=\"http://boren.nu/weblog/wp-includes/images/smilies/icon_smile.gif\" alt=\":-)\" class=\"wp-smiley\" /></p>\";s:7:\"pubdate\";s:31:\"Tue, 22 Jul 2008 05:08:15 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Ryan\";}s:7:\"summary\";s:329:\"<p>I&#8217;m writing this on the WordPress app for the iPhone, which is <a href=\"http://iphone.wordpress.net/2008/07/22/wordpress-for-iphone-available now\">now available</a>.  Now if only the iPhone had cut-and-paste.  <img src=\"http://boren.nu/weblog/wp-includes/images/smilies/icon_smile.gif\" alt=\":-)\" class=\"wp-smiley\" /></p>\";}i:11;a:7:{s:5:\"title\";s:60:\"Weblog Tools Collection: WordPress Plugin Releases for 07/21\";s:4:\"guid\";s:40:\"http://weblogtoolscollection.com/?p=3760\";s:4:\"link\";s:88:\"http://weblogtoolscollection.com/archives/2008/07/21/wordpress-plugin-releases-for-0721/\";s:11:\"description\";s:2279:\"<p><a href=\"http://davidebenini.it/wordpress-plugins/events-manager/\"><strong>Events Manager</strong></a></p>\n<p>A plugin to manage events such as music gigs, art expositions, or job meetings. Events Manager inserts an Events page in the Manage menu of WordPress Administration, to let you insert, modify and delete events. You can describe events specifying their date and location, and also add a few notes. You can then add events list, calendars and description to your blog using a sidebar widget; if you’re web designer you can simply employ the template tags provided by Events Manager.</p>\n<p><a href=\"http://www.neotrinity.at/projects/#wordpress_generalstats\"><strong>General Stats</strong></a></p>\n<p>Counts the number of users, categories, posts, comments, pages, links, tags, link-categories, words in posts, words in comments and words in pages.</p>\n<p><a href=\"http://www.neotrinity.at/projects/#wordpress_timezonecalculator\"><strong>TimeZoneCalculator</strong></a></p>\n<p>Calculates different times and dates in timezones with respect to daylight saving on basis of utc.</p>\n<p><a href=\"http://broken-watch.info/?p=42\"><strong>Inline Google Docs</strong></a></p>\n<p>Many people maintain dynamic content on Google Documents or hold volatile data on Google Spreadsheets. These change when collaborators save an update or users submit a form. Occasionally, one may wish to embed the contents of one&#8217;s Google Documents or Spreadsheets in a post/page to reflect the latest updates on one&#8217;s blog. This plugin seeks to provide this functionality without using an iframe.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/cross-references-plugin/\"><strong>Cross References Plugin</strong></a></p>\n<p>With this plugin you can easily set a reference to another post or page in posts und pages and you get all back references automatically listed for every post and page.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/el-aleph/\"><strong>Aleph</strong></a></p>\n<p>Aleph implements profiles, paginated and customizable user lists, and some characteristics of social networks, like friends and sets. It supports localization and pretty permalinks. Suggestions, bug reports and fixes (specially security &amp; bug fixes) are welcomed. PHP 5 is required.</p>\";s:7:\"pubdate\";s:31:\"Mon, 21 Jul 2008 19:29:04 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Ajay\";}s:7:\"summary\";s:2279:\"<p><a href=\"http://davidebenini.it/wordpress-plugins/events-manager/\"><strong>Events Manager</strong></a></p>\n<p>A plugin to manage events such as music gigs, art expositions, or job meetings. Events Manager inserts an Events page in the Manage menu of WordPress Administration, to let you insert, modify and delete events. You can describe events specifying their date and location, and also add a few notes. You can then add events list, calendars and description to your blog using a sidebar widget; if you’re web designer you can simply employ the template tags provided by Events Manager.</p>\n<p><a href=\"http://www.neotrinity.at/projects/#wordpress_generalstats\"><strong>General Stats</strong></a></p>\n<p>Counts the number of users, categories, posts, comments, pages, links, tags, link-categories, words in posts, words in comments and words in pages.</p>\n<p><a href=\"http://www.neotrinity.at/projects/#wordpress_timezonecalculator\"><strong>TimeZoneCalculator</strong></a></p>\n<p>Calculates different times and dates in timezones with respect to daylight saving on basis of utc.</p>\n<p><a href=\"http://broken-watch.info/?p=42\"><strong>Inline Google Docs</strong></a></p>\n<p>Many people maintain dynamic content on Google Documents or hold volatile data on Google Spreadsheets. These change when collaborators save an update or users submit a form. Occasionally, one may wish to embed the contents of one&#8217;s Google Documents or Spreadsheets in a post/page to reflect the latest updates on one&#8217;s blog. This plugin seeks to provide this functionality without using an iframe.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/cross-references-plugin/\"><strong>Cross References Plugin</strong></a></p>\n<p>With this plugin you can easily set a reference to another post or page in posts und pages and you get all back references automatically listed for every post and page.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/el-aleph/\"><strong>Aleph</strong></a></p>\n<p>Aleph implements profiles, paginated and customizable user lists, and some characteristics of social networks, like friends and sets. It supports localization and pretty permalinks. Suggestions, bug reports and fixes (specially security &amp; bug fixes) are welcomed. PHP 5 is required.</p>\";}i:12;a:7:{s:5:\"title\";s:73:\"Weblog Tools Collection: WPMU.org - WordPress MU plugins, themes and news\";s:4:\"guid\";s:40:\"http://weblogtoolscollection.com/?p=3759\";s:4:\"link\";s:98:\"http://weblogtoolscollection.com/archives/2008/07/21/wpmuorg-wordpress-mu-plugins-themes-and-news/\";s:11:\"description\";s:698:\"<p><a href=\"http://wpmu.org/\">WPMU.org</a> has changed hands and the blog is now written by James and Andrew from <a href=\"http://incsub.com\">Incsub</a>. WPMU.org is intended to be a WeblogToolsCollection for WordPress MU with the latest and greatest news, MU plugins, themes, SEO tips, ‘How to’ guides etc. If you are a WordPress MU user, <a href=\"http://feeds.feedburner.com/Wpmu-Wordpress-Mu-PluginsThemesAndNews\">add their feed</a> to your feed reader and if you have something to share with their readers, take a gander at their <a href=\"http://wpmu.org/contribute/\">contribute page</a>. Incsub has been an ardent supporter and reader of WeblogToolsCollection and they are good people.</p>\";s:7:\"pubdate\";s:31:\"Mon, 21 Jul 2008 14:33:03 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:10:\"Mark Ghosh\";}s:7:\"summary\";s:698:\"<p><a href=\"http://wpmu.org/\">WPMU.org</a> has changed hands and the blog is now written by James and Andrew from <a href=\"http://incsub.com\">Incsub</a>. WPMU.org is intended to be a WeblogToolsCollection for WordPress MU with the latest and greatest news, MU plugins, themes, SEO tips, ‘How to’ guides etc. If you are a WordPress MU user, <a href=\"http://feeds.feedburner.com/Wpmu-Wordpress-Mu-PluginsThemesAndNews\">add their feed</a> to your feed reader and if you have something to share with their readers, take a gander at their <a href=\"http://wpmu.org/contribute/\">contribute page</a>. Incsub has been an ardent supporter and reader of WeblogToolsCollection and they are good people.</p>\";}i:13;a:7:{s:5:\"title\";s:65:\"Weblog Tools Collection: Plugin Competition Update and Prize List\";s:4:\"guid\";s:40:\"http://weblogtoolscollection.com/?p=3758\";s:4:\"link\";s:94:\"http://weblogtoolscollection.com/archives/2008/07/20/plugin-competition-update-and-prize-list/\";s:11:\"description\";s:1504:\"<p><strong>There were a total of 51 entries into the Plugin Competition this year</strong>. A list of all the entries with their respective voting and download pages will soon be published. The entries are being sent to the judges as we speak. In the meantime, here is the list of prizes for the participants and the winners of the plugin competition.<br />\n<strong></strong><strong>Thank you prizes:</strong></p>\n<ul>\n<li>$10 to <em>every participant</em> as a thank you for their hard work and dedication</li>\n</ul>\n<p><strong>$250 prize:</strong></p>\n<ul>\n<li>For the best WPMU compatible plugin from Incsub</li>\n</ul>\n<p><strong>Consolation Prize:</strong></p>\n<ul>\n<li>12 month blogclub subscription from Blogalized</li>\n<li>Copy of OIOPublisher Advertising Plugin</li>\n</ul>\n<p><strong>Third Prize:</strong></p>\n<ul>\n<li>$200</li>\n<li>Country codes of the world poster</li>\n<li>Copy of OIOPublisher Advertising Plugin</li>\n</ul>\n<p><strong>Second Prize:</strong></p>\n<ul>\n<li>$700</li>\n<li>Tom Clancy’s Rainbow Six Vegas for the PC and Enemy Territory: Quake Wars</li>\n<li>Copy of OIOPublisher Advertising Plugin</li>\n</ul>\n<h2><strong>Grand Prize:</strong></h2>\n<ul>\n<li><strong>$2000</strong></li>\n<li>Production of a professionally recorded song for the winner.</li>\n<li>Dedicated server for one year from iWeb (Intel Core 2 Duo, HD 160GB Sata2, 1GB of RAM and 1500GB of bandwidth per month)</li>\n<li>Copy of OIOPublisher Advertising Plugin</li>\n</ul>\n<p>Good luck to all the participants!</p>\";s:7:\"pubdate\";s:31:\"Sun, 20 Jul 2008 21:22:22 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:10:\"Mark Ghosh\";}s:7:\"summary\";s:1504:\"<p><strong>There were a total of 51 entries into the Plugin Competition this year</strong>. A list of all the entries with their respective voting and download pages will soon be published. The entries are being sent to the judges as we speak. In the meantime, here is the list of prizes for the participants and the winners of the plugin competition.<br />\n<strong></strong><strong>Thank you prizes:</strong></p>\n<ul>\n<li>$10 to <em>every participant</em> as a thank you for their hard work and dedication</li>\n</ul>\n<p><strong>$250 prize:</strong></p>\n<ul>\n<li>For the best WPMU compatible plugin from Incsub</li>\n</ul>\n<p><strong>Consolation Prize:</strong></p>\n<ul>\n<li>12 month blogclub subscription from Blogalized</li>\n<li>Copy of OIOPublisher Advertising Plugin</li>\n</ul>\n<p><strong>Third Prize:</strong></p>\n<ul>\n<li>$200</li>\n<li>Country codes of the world poster</li>\n<li>Copy of OIOPublisher Advertising Plugin</li>\n</ul>\n<p><strong>Second Prize:</strong></p>\n<ul>\n<li>$700</li>\n<li>Tom Clancy’s Rainbow Six Vegas for the PC and Enemy Territory: Quake Wars</li>\n<li>Copy of OIOPublisher Advertising Plugin</li>\n</ul>\n<h2><strong>Grand Prize:</strong></h2>\n<ul>\n<li><strong>$2000</strong></li>\n<li>Production of a professionally recorded song for the winner.</li>\n<li>Dedicated server for one year from iWeb (Intel Core 2 Duo, HD 160GB Sata2, 1GB of RAM and 1500GB of bandwidth per month)</li>\n<li>Copy of OIOPublisher Advertising Plugin</li>\n</ul>\n<p>Good luck to all the participants!</p>\";}i:14;a:7:{s:5:\"title\";s:60:\"Weblog Tools Collection: WordPress Plugin Releases for 07/19\";s:4:\"guid\";s:40:\"http://weblogtoolscollection.com/?p=3757\";s:4:\"link\";s:88:\"http://weblogtoolscollection.com/archives/2008/07/19/wordpress-plugin-releases-for-0719/\";s:11:\"description\";s:2012:\"<p><a href=\"http://johnmiedema.ca/openbook-wordpress-plugin/\"><strong>Open Book Book Data</strong></a></p>\n<p>Insert OpenBook tags and a book&#8217;s ISBN into a post, and OpenBook will replace it with a book cover, title, author and publisher. It links to more book details at its data source, Open Library (<a href=\"http://openlibrary.org\">http://openlibrary.org</a>).</p>\n<p><a href=\"http://deanjrobinson.com/projects/fluency-admin/\"><strong>Fluency Admin</strong></a></p>\n<p>A plugin that beautifies and enhances the default WordPress Admin interface.</p>\n<p><a href=\"http://www.geldmacher.net/superlinks/\"><strong>SuperLinks</strong></a></p>\n<p>SuperLinks is a WordPress 2.5+ plugin that replaces the standard Links sidebar widget. SuperLinks gives the site owner greater control over how links in the sidebar are displayed. For example, one can choose to display all links categories or only a single links category. Additionally, a site owner may have any number of SuperLinks widgets in the sidebar.</p>\n<p><a href=\"http://striderweb.com/nerdaphernalia/features/wp-javascript-pull-quotes/\"><strong>JavaScript Pull Quotes</strong></a></p>\n<p>The JavaScript Pull-Quotes plugin is an add-on for WordPress that allows you to easily insert pull-quotes into your posts and pages.</p>\n<p><a href=\"http://www.zirona.com/software/wordpress-msm/\"><strong>MultiSiteManager</strong></a></p>\n<p>MultiSiteManager (MSM) is a WordPress plugin which will perform two of the most important tasks of an administrator: backups and upgrades. MSM can manage any number of WordPress installations from one &#8220;master&#8221; WP installation. (To manage a WordPress website with MSM, you need FTP access to the site.)</p>\n<p><a href=\"http://seoroi.com/specialty-services/new-seo-plugin-for-wordpress-internal-link-building/\"><strong>Internal Link Building</strong></a></p>\n<p>Allows people to define a keyword as always linking to a given URL. This allows you to link within your site like Wikipedia, and rank accordingly.</p>\";s:7:\"pubdate\";s:31:\"Sat, 19 Jul 2008 18:38:18 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Ajay\";}s:7:\"summary\";s:2012:\"<p><a href=\"http://johnmiedema.ca/openbook-wordpress-plugin/\"><strong>Open Book Book Data</strong></a></p>\n<p>Insert OpenBook tags and a book&#8217;s ISBN into a post, and OpenBook will replace it with a book cover, title, author and publisher. It links to more book details at its data source, Open Library (<a href=\"http://openlibrary.org\">http://openlibrary.org</a>).</p>\n<p><a href=\"http://deanjrobinson.com/projects/fluency-admin/\"><strong>Fluency Admin</strong></a></p>\n<p>A plugin that beautifies and enhances the default WordPress Admin interface.</p>\n<p><a href=\"http://www.geldmacher.net/superlinks/\"><strong>SuperLinks</strong></a></p>\n<p>SuperLinks is a WordPress 2.5+ plugin that replaces the standard Links sidebar widget. SuperLinks gives the site owner greater control over how links in the sidebar are displayed. For example, one can choose to display all links categories or only a single links category. Additionally, a site owner may have any number of SuperLinks widgets in the sidebar.</p>\n<p><a href=\"http://striderweb.com/nerdaphernalia/features/wp-javascript-pull-quotes/\"><strong>JavaScript Pull Quotes</strong></a></p>\n<p>The JavaScript Pull-Quotes plugin is an add-on for WordPress that allows you to easily insert pull-quotes into your posts and pages.</p>\n<p><a href=\"http://www.zirona.com/software/wordpress-msm/\"><strong>MultiSiteManager</strong></a></p>\n<p>MultiSiteManager (MSM) is a WordPress plugin which will perform two of the most important tasks of an administrator: backups and upgrades. MSM can manage any number of WordPress installations from one &#8220;master&#8221; WP installation. (To manage a WordPress website with MSM, you need FTP access to the site.)</p>\n<p><a href=\"http://seoroi.com/specialty-services/new-seo-plugin-for-wordpress-internal-link-building/\"><strong>Internal Link Building</strong></a></p>\n<p>Allows people to define a keyword as always linking to a given URL. This allows you to link within your site like Wikipedia, and rank accordingly.</p>\";}i:15;a:7:{s:5:\"title\";s:45:\"Donncha: Sitewide tags pages for WordPress MU\";s:4:\"guid\";s:29:\"http://ocaoimh.ie/?p=89493808\";s:4:\"link\";s:66:\"http://ocaoimh.ie/2008/07/19/sitewide-tags-pages-for-wordpress-mu/\";s:11:\"description\";s:2075:\"<p>For WordPress MU only. My latest plugin is the <a href=\"http://ocaoimh.ie/wordpress-mu-sitewide-tags/\">sitewide tags pages plugin</a>.</p>\n<p>This is the initial release of a plugin that creates a set of pages like the <a href=\"http://wordpress.com/tags/\">WordPress.com Hot Topics</a> pages. It&#8217;s a lot more simplistic, but by feeding posts into one blog it also creates a sitewide feed of all posts plus feeds of any tags and categories too.</p>\n<div align=\"center\"><img src=\"http://ocaoimh.ie/wp-content/uploads/2008/07/global-tags.png\" alt=\"\" title=\"global-tags\" width=\"500\" height=\"233\" class=\"alignnone size-full wp-image-89493810\" /><br />\nSitewide Tags Options</div>\n<p><a href=\"http://mu.wordpress.org/\">WordPress MU</a> is a multi blog version of WordPress that runs on <a href=\"http://wordpress.com/\">WordPress.com</a>. If you use the regular version of WordPress this plugin is not for you and you can ignore this post.</p>\n<p>PS. In other MU news. <a href=\"http://raanan.com/\">Raanan</a> has a <a href=\"http://publisherblog.automattic.com/2008/07/17/nationen-blog-selects-wordpress-mu/\">new post</a> on the Publisher Blog about <a href=\"http://nationenblog.dk/\">Nationen! blog</a>, a new Danish blog site based on WordPress MU that looks rather nice!<br />\nThe site was developed by <a href=\"http://incsub.com/\">Incsub</a> who are also the guys behind <a href=\"http://wpmu.org/\">wpmu.org</a> where you&#8217;ll probably find all sorts of useful nuggets of MU goodness on a regular basis!</p>\n<p><img src=\"http://ocaoimh.ie/?voyeur=1\" /></p><p><strong>Related Posts</strong><ul><li><a href=\"http://ocaoimh.ie/wordpress-mu-sitewide-tags/\" rel=\"bookmark\" title=\"Permanent Link: WordPress MU Sitewide Tags\">WordPress MU Sitewide Tags</a></li><li><a href=\"http://ocaoimh.ie/2006/03/26/more-wordpress-feeds/\" rel=\"bookmark\" title=\"Permanent Link: More Wordpress Feeds\">More Wordpress Feeds</a></li><li><a href=\"http://ocaoimh.ie/2008/04/19/wordpress-mu-15-rc1/\" rel=\"bookmark\" title=\"Permanent Link: WordPress MU 1.5 RC1\">WordPress MU 1.5 RC1</a></li></ul></p>\";s:7:\"pubdate\";s:31:\"Sat, 19 Jul 2008 11:00:57 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:7:\"Donncha\";}s:7:\"summary\";s:2075:\"<p>For WordPress MU only. My latest plugin is the <a href=\"http://ocaoimh.ie/wordpress-mu-sitewide-tags/\">sitewide tags pages plugin</a>.</p>\n<p>This is the initial release of a plugin that creates a set of pages like the <a href=\"http://wordpress.com/tags/\">WordPress.com Hot Topics</a> pages. It&#8217;s a lot more simplistic, but by feeding posts into one blog it also creates a sitewide feed of all posts plus feeds of any tags and categories too.</p>\n<div align=\"center\"><img src=\"http://ocaoimh.ie/wp-content/uploads/2008/07/global-tags.png\" alt=\"\" title=\"global-tags\" width=\"500\" height=\"233\" class=\"alignnone size-full wp-image-89493810\" /><br />\nSitewide Tags Options</div>\n<p><a href=\"http://mu.wordpress.org/\">WordPress MU</a> is a multi blog version of WordPress that runs on <a href=\"http://wordpress.com/\">WordPress.com</a>. If you use the regular version of WordPress this plugin is not for you and you can ignore this post.</p>\n<p>PS. In other MU news. <a href=\"http://raanan.com/\">Raanan</a> has a <a href=\"http://publisherblog.automattic.com/2008/07/17/nationen-blog-selects-wordpress-mu/\">new post</a> on the Publisher Blog about <a href=\"http://nationenblog.dk/\">Nationen! blog</a>, a new Danish blog site based on WordPress MU that looks rather nice!<br />\nThe site was developed by <a href=\"http://incsub.com/\">Incsub</a> who are also the guys behind <a href=\"http://wpmu.org/\">wpmu.org</a> where you&#8217;ll probably find all sorts of useful nuggets of MU goodness on a regular basis!</p>\n<p><img src=\"http://ocaoimh.ie/?voyeur=1\" /></p><p><strong>Related Posts</strong><ul><li><a href=\"http://ocaoimh.ie/wordpress-mu-sitewide-tags/\" rel=\"bookmark\" title=\"Permanent Link: WordPress MU Sitewide Tags\">WordPress MU Sitewide Tags</a></li><li><a href=\"http://ocaoimh.ie/2006/03/26/more-wordpress-feeds/\" rel=\"bookmark\" title=\"Permanent Link: More Wordpress Feeds\">More Wordpress Feeds</a></li><li><a href=\"http://ocaoimh.ie/2008/04/19/wordpress-mu-15-rc1/\" rel=\"bookmark\" title=\"Permanent Link: WordPress MU 1.5 RC1\">WordPress MU 1.5 RC1</a></li></ul></p>\";}i:16;a:7:{s:5:\"title\";s:30:\"Matt: Favorite Women Bloggers?\";s:4:\"guid\";s:45:\"http://ma.tt/2008/07/favorite-women-bloggers/\";s:4:\"link\";s:45:\"http://ma.tt/2008/07/favorite-women-bloggers/\";s:11:\"description\";s:129:\"<p><a href=\"http://www.readwriteweb.com/archives/blogher_who_are_your_favorite.php\">Who Are Your Favorite Women Bloggers</a>?</p>\";s:7:\"pubdate\";s:31:\"Sat, 19 Jul 2008 05:13:00 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Matt\";}s:7:\"summary\";s:129:\"<p><a href=\"http://www.readwriteweb.com/archives/blogher_who_are_your_favorite.php\">Who Are Your Favorite Women Bloggers</a>?</p>\";}i:17;a:7:{s:5:\"title\";s:59:\"Weblog Tools Collection: WordPress Theme Releases for 07/18\";s:4:\"guid\";s:40:\"http://weblogtoolscollection.com/?p=3756\";s:4:\"link\";s:87:\"http://weblogtoolscollection.com/archives/2008/07/18/wordpress-theme-releases-for-0718/\";s:11:\"description\";s:1198:\"<p>Only two themes on the platter today.</p>\n<p><a href=\"http://www.abcflirt.com/a-new-wordpress-dating-theme-template/\"><strong>WordPress Dating Theme</strong></a></p>\n<p><img alt=\"abc-dating-template\" src=\"http://weblogtoolscollection.com/b2-img/2008/07/abc-dating-template.gif\" width=\"172\" height=\"125\" /></p>\n<p>Simple, two column, widget ready theme for dating sites</p>\n<p><a href=\"http://themetation.com/superfresh/\"><strong>SuperFresh</strong></a></p>\n<p><a href=\"http://themetation.com/demo/superfresh/\"><img alt=\"SuperFresh\" src=\"http://weblogtoolscollection.com/b2-img/2008/07/superfresh.jpg\" width=\"200\" height=\"125\" /></a></p>\n<p>SuperFresh is a 3 Column fresh theme base with natural green. It contain 2 widget-ready sidebar, custom templates, with a featured post section in the main page. It’s compatible with up to WordPress 2.6 and has been tested with in Firefox, Internet Explorer 6 &amp; 7, Opera, and Safari.</p>\n<p>Would you like to have your theme featured on WLTC? Then, head over to the <a href=\"http://weblogtoolscollection.com/news/\">News Forum</a> and post a link to your theme. Remember to add a good description and preferably a link to the a demo of the theme.</p>\";s:7:\"pubdate\";s:31:\"Fri, 18 Jul 2008 19:02:38 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Ajay\";}s:7:\"summary\";s:1198:\"<p>Only two themes on the platter today.</p>\n<p><a href=\"http://www.abcflirt.com/a-new-wordpress-dating-theme-template/\"><strong>WordPress Dating Theme</strong></a></p>\n<p><img alt=\"abc-dating-template\" src=\"http://weblogtoolscollection.com/b2-img/2008/07/abc-dating-template.gif\" width=\"172\" height=\"125\" /></p>\n<p>Simple, two column, widget ready theme for dating sites</p>\n<p><a href=\"http://themetation.com/superfresh/\"><strong>SuperFresh</strong></a></p>\n<p><a href=\"http://themetation.com/demo/superfresh/\"><img alt=\"SuperFresh\" src=\"http://weblogtoolscollection.com/b2-img/2008/07/superfresh.jpg\" width=\"200\" height=\"125\" /></a></p>\n<p>SuperFresh is a 3 Column fresh theme base with natural green. It contain 2 widget-ready sidebar, custom templates, with a featured post section in the main page. It’s compatible with up to WordPress 2.6 and has been tested with in Firefox, Internet Explorer 6 &amp; 7, Opera, and Safari.</p>\n<p>Would you like to have your theme featured on WLTC? Then, head over to the <a href=\"http://weblogtoolscollection.com/news/\">News Forum</a> and post a link to your theme. Remember to add a good description and preferably a link to the a demo of the theme.</p>\";}i:18;a:7:{s:5:\"title\";s:40:\"Mike Little: Almost ready for WordCampUK\";s:4:\"guid\";s:35:\"http://zed1.com/journalized/?p=1234\";s:4:\"link\";s:76:\"http://zed1.com/journalized/archives/2008/07/18/almost-ready-for-wordcampuk/\";s:11:\"description\";s:750:\"<p>I&#8217;m almost ready for my trip to <a href=\"http://uk.wordcamp.org/\">WordCamp UK</a>. I&#8217;m going first thing tomorrow morning by train. &#8220;It&#8217;s easier by train&#8221;, and as it happens, the car is broken and in the menders!</p>\n<p>I forgot to mention that I am also on the <a href=\"http://wiki.wordcampuk.tonyscott.org.uk/Content_ideas#Code_Surgery_Session\">Code Surgery</a> panel on Sunday too. If you have any coding problems there is still time to <a href=\"http://www.simonwheatley.co.uk/code-surgery-questions/\">submit your questions to the surgeons</a>.</p>\n<p>There are still a couple more hours to <a href=\"http://wordcampuk2008.eventbrite.com/\">buy tickets</a>. Please come along, I look forward to seeing you there.</p>\";s:7:\"pubdate\";s:31:\"Fri, 18 Jul 2008 17:02:18 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"mike\";}s:7:\"summary\";s:750:\"<p>I&#8217;m almost ready for my trip to <a href=\"http://uk.wordcamp.org/\">WordCamp UK</a>. I&#8217;m going first thing tomorrow morning by train. &#8220;It&#8217;s easier by train&#8221;, and as it happens, the car is broken and in the menders!</p>\n<p>I forgot to mention that I am also on the <a href=\"http://wiki.wordcampuk.tonyscott.org.uk/Content_ideas#Code_Surgery_Session\">Code Surgery</a> panel on Sunday too. If you have any coding problems there is still time to <a href=\"http://www.simonwheatley.co.uk/code-surgery-questions/\">submit your questions to the surgeons</a>.</p>\n<p>There are still a couple more hours to <a href=\"http://wordcampuk2008.eventbrite.com/\">buy tickets</a>. Please come along, I look forward to seeing you there.</p>\";}i:19;a:7:{s:5:\"title\";s:54:\"Weblog Tools Collection: NEW WordPress Theme Directory\";s:4:\"guid\";s:40:\"http://weblogtoolscollection.com/?p=3753\";s:4:\"link\";s:83:\"http://weblogtoolscollection.com/archives/2008/07/18/new-wordpress-theme-directory/\";s:11:\"description\";s:1525:\"<p>This is pretty exciting news and I am very enthusiastic about it. The new <a href=\"http://wordpress.org/development/2008/07/theme-directory/\">WordPress Theme Directory</a> has just been announced. It is available through <a href=\"http://wordpress.org/extend/themes/\">http://wordpress.org/extend/themes</a> just like the plugin directory and has all the features and infrastructure support of the WordPress Extend umbrella. The look of the plugin area has also been maintained to provide a familiar feel.</p>\n<p>That being said, there are only a few themes on the new directory. You can upload your themes by just logging into the Theme Directory using your WordPress.org username and password and following the instructions and meeting the <a href=\"http://wordpress.org/extend/themes/about/#requirements\">requirements</a> on the <a href=\"http://wordpress.org/extend/themes/upload/\">upload page</a>. The theme upload process is mostly automated except for a manual review. When you upload your theme, you should expect to receive an email (soon after uploading your theme, email reception times may vary) saying that your theme is waiting to be reviewed. If you do not receive this email, your upload did not work.</p>\n<p>A lot of usable and popularly expected features have been added to the system including some that I believe the theme authors will love and will really help highlight them and their designs. Thanks to <a href=\"http://joseph.randomnetworks.com/\">Joseph</a> for his hard work on the Theme Directory.</p>\";s:7:\"pubdate\";s:31:\"Fri, 18 Jul 2008 12:23:04 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:10:\"Mark Ghosh\";}s:7:\"summary\";s:1525:\"<p>This is pretty exciting news and I am very enthusiastic about it. The new <a href=\"http://wordpress.org/development/2008/07/theme-directory/\">WordPress Theme Directory</a> has just been announced. It is available through <a href=\"http://wordpress.org/extend/themes/\">http://wordpress.org/extend/themes</a> just like the plugin directory and has all the features and infrastructure support of the WordPress Extend umbrella. The look of the plugin area has also been maintained to provide a familiar feel.</p>\n<p>That being said, there are only a few themes on the new directory. You can upload your themes by just logging into the Theme Directory using your WordPress.org username and password and following the instructions and meeting the <a href=\"http://wordpress.org/extend/themes/about/#requirements\">requirements</a> on the <a href=\"http://wordpress.org/extend/themes/upload/\">upload page</a>. The theme upload process is mostly automated except for a manual review. When you upload your theme, you should expect to receive an email (soon after uploading your theme, email reception times may vary) saying that your theme is waiting to be reviewed. If you do not receive this email, your upload did not work.</p>\n<p>A lot of usable and popularly expected features have been added to the system including some that I believe the theme authors will love and will really help highlight them and their designs. Thanks to <a href=\"http://joseph.randomnetworks.com/\">Joseph</a> for his hard work on the Theme Directory.</p>\";}i:20;a:7:{s:5:\"title\";s:25:\"Dev Blog: Theme Directory\";s:4:\"guid\";s:39:\"http://wordpress.org/development/?p=266\";s:4:\"link\";s:57:\"http://wordpress.org/development/2008/07/theme-directory/\";s:11:\"description\";s:2452:\"<p>It&#8217;s been a long time since <a href=\"http://themes.wordpress.net/blog/4426/upcoming-changes/\">themes.wordpress.net</a> stopped accepting new themes.  Since then most theme authors have been distributing their themes from their own sites, without a good centralized place for people to browse, search, comment on, and rate themes.  With the success of the <a href=\"http://wordpress.org/extend/plugins/\">plugins directory</a>, we&#8217;ve wanted to have those same benefits in a theme directory.  Today is the day we start making that happen, with the introduction of <a href=\"http://wordpress.org/extend/themes/\">wordpress.org/extend/themes/</a>.</p>\n<p>Bringing the new theme directory under the WordPress &#8220;<a href=\"http://wordpress.org/extend/\">extend</a>&#8221; umbrella allowed us to take advantage of all the infrastructure that has already been built up to support WordPress.org.  If you&#8217;ve browsed through the plugin directory, you&#8217;ll feel right at home in the new theme directory.</p>\n<p>We&#8217;ve gone through great lengths to make this as painless as possible for theme authors.  You don&#8217;t need to know anything about Subversion (our back end magic takes care of all that for you), just login with your WordPress.org username and password and go to the <a href=\"http://wordpress.org/extend/themes/upload/\">upload page</a>.  From there you upload your regular theme zip file and we take care of the rest.</p>\n<p>Once you upload your new theme we do a few automated checks for some of the <a href=\"http://wordpress.org/extend/themes/about/#requirements\">requirements</a> for each theme.  If we find one that you missed we&#8217;ll provide you an error and description of what needs to be fixed.  When a theme upload has been accepted we&#8217;ll send you an email and put it in the queue to be reviewed, to make sure we didn&#8217;t miss anything.  After the theme has been approved you&#8217;ll get another email letting you know that the theme is now live.</p>\n<p>That catches you up to where we&#8217;re at today.  When you finish that theme you&#8217;ve been slaving over, upload it to the new directory and let us know what you think. Since so much has changed since the old theme directory we&#8217;re starting fresh from zero. If you&#8217;ve got specific questions or suggestions <a href=\"http://wordpress.org/extend/themes/contact/\">contact us</a> and we&#8217;ll do our best to get them answered.</p>\";s:7:\"pubdate\";s:31:\"Fri, 18 Jul 2008 06:11:13 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:6:\"joseph\";}s:7:\"summary\";s:2452:\"<p>It&#8217;s been a long time since <a href=\"http://themes.wordpress.net/blog/4426/upcoming-changes/\">themes.wordpress.net</a> stopped accepting new themes.  Since then most theme authors have been distributing their themes from their own sites, without a good centralized place for people to browse, search, comment on, and rate themes.  With the success of the <a href=\"http://wordpress.org/extend/plugins/\">plugins directory</a>, we&#8217;ve wanted to have those same benefits in a theme directory.  Today is the day we start making that happen, with the introduction of <a href=\"http://wordpress.org/extend/themes/\">wordpress.org/extend/themes/</a>.</p>\n<p>Bringing the new theme directory under the WordPress &#8220;<a href=\"http://wordpress.org/extend/\">extend</a>&#8221; umbrella allowed us to take advantage of all the infrastructure that has already been built up to support WordPress.org.  If you&#8217;ve browsed through the plugin directory, you&#8217;ll feel right at home in the new theme directory.</p>\n<p>We&#8217;ve gone through great lengths to make this as painless as possible for theme authors.  You don&#8217;t need to know anything about Subversion (our back end magic takes care of all that for you), just login with your WordPress.org username and password and go to the <a href=\"http://wordpress.org/extend/themes/upload/\">upload page</a>.  From there you upload your regular theme zip file and we take care of the rest.</p>\n<p>Once you upload your new theme we do a few automated checks for some of the <a href=\"http://wordpress.org/extend/themes/about/#requirements\">requirements</a> for each theme.  If we find one that you missed we&#8217;ll provide you an error and description of what needs to be fixed.  When a theme upload has been accepted we&#8217;ll send you an email and put it in the queue to be reviewed, to make sure we didn&#8217;t miss anything.  After the theme has been approved you&#8217;ll get another email letting you know that the theme is now live.</p>\n<p>That catches you up to where we&#8217;re at today.  When you finish that theme you&#8217;ve been slaving over, upload it to the new directory and let us know what you think. Since so much has changed since the old theme directory we&#8217;re starting fresh from zero. If you&#8217;ve got specific questions or suggestions <a href=\"http://wordpress.org/extend/themes/contact/\">contact us</a> and we&#8217;ll do our best to get them answered.</p>\";}i:21;a:7:{s:5:\"title\";s:21:\"Matt: In SF Chronicle\";s:4:\"guid\";s:37:\"http://ma.tt/2008/07/in-sf-chronicle/\";s:4:\"link\";s:37:\"http://ma.tt/2008/07/in-sf-chronicle/\";s:11:\"description\";s:415:\"<p><a href=\"http://www.sfgate.com/cgi-bin/article.cgi?f=/c/a/2008/07/17/BU5P11MA4R.DTL\">There&#8217;s an article about me in the San Francisco Chronicle</a>, written by Chris Cadelago. It&#8217;s a good mainstream summary of what&#8217;s been going on the past few years. Chris talked to almost everyone I know, including getting Toni&#8217;s opinion of my car. You can, of course, get a paper copy in SF today.</p>\";s:7:\"pubdate\";s:31:\"Thu, 17 Jul 2008 15:57:37 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Matt\";}s:7:\"summary\";s:415:\"<p><a href=\"http://www.sfgate.com/cgi-bin/article.cgi?f=/c/a/2008/07/17/BU5P11MA4R.DTL\">There&#8217;s an article about me in the San Francisco Chronicle</a>, written by Chris Cadelago. It&#8217;s a good mainstream summary of what&#8217;s been going on the past few years. Chris talked to almost everyone I know, including getting Toni&#8217;s opinion of my car. You can, of course, get a paper copy in SF today.</p>\";}i:22;a:7:{s:5:\"title\";s:60:\"Weblog Tools Collection: WordPress Plugin Releases for 07/16\";s:4:\"guid\";s:40:\"http://weblogtoolscollection.com/?p=3751\";s:4:\"link\";s:88:\"http://weblogtoolscollection.com/archives/2008/07/16/wordpress-plugin-releases-for-0716/\";s:11:\"description\";s:2408:\"<p><a href=\"http://techie-buzz.com/wordpress-plugins/wordpress-automatic-upgrade-12-release.html\"><strong>WordPress Automatic Upgrade</strong></a></p>\n<p>This is the latest version of the popular plugin that helps ease the upgrade of your WordPress blog.</p>\n<p><a href=\"http://epicalex.com/epic-theme-viewer/\"><strong>Epic Theme Viewer</strong></a></p>\n<p>This plugin uses that native theme viewer in WordPress 2.6 to display a front end display of all the themes available on your blog.</p>\n<p><a href=\"http://www.eruditor.com/spec/wordpress-recommendedbooks.html.en\"><strong>Recommended Books</strong></a></p>\n<p>This is higly configurable widget to WordPress sidebar. It displays up to 10 books with liks to Eruditor.com bookshop and optionaly with jacket images, prices in dollars or pounds and/or discounts.</p>\n<p><a href=\"http://beejay.perthmatrix.com/servage-referral-widget/\"><strong>Servage Referral Widget</strong></a></p>\n<p>This widget allows customers of Servage to display a link containing their coupon code to Servage, customers that use this code get 25GB of extra web space and 2 months free hosting when a new customer that uses the code joins up, in return the new customer automatically receives 25GB of extra quota.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/paginated-comments/\"><strong>Paginated Comments</strong></a></p>\n<p>Paginated Comments is a WordPress Plugin that gives you the ability to break your comments into a number of search engine optimized pages.</p>\n<p><a href=\"http://andrerenaut.ovh.org/wp/?page_id=70\"><strong>MailPress</strong></a></p>\n<p>This plugin allows you to send beautiful and styled html and plain text mails based on dedicated themes and templates. If you are already comfortable with Worpress organisation and how it works, you will not be lost with MailPress. The MailPress theme and templates organisation is very similar to WordPress.</p>\n<p><a href=\"http://likemind.co.uk/wordpress-side-content-plugin/\"><strong>Side Content</strong></a></p>\n<p>This plugin allows you to create widgets that have different content on different pages.</p>\n<p><a href=\"http://www.halmatferello.com/lab/wp-js/\"><strong>WP JS</strong></a></p>\n<p>This plugin will GZIP and JSMIN your JavaScript files as well as allowing the ability to put JavaScript files into a single file at the client&#8217;s end. Cache expiry time can also be set in the admin page.</p>\";s:7:\"pubdate\";s:31:\"Wed, 16 Jul 2008 18:58:16 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Ajay\";}s:7:\"summary\";s:2408:\"<p><a href=\"http://techie-buzz.com/wordpress-plugins/wordpress-automatic-upgrade-12-release.html\"><strong>WordPress Automatic Upgrade</strong></a></p>\n<p>This is the latest version of the popular plugin that helps ease the upgrade of your WordPress blog.</p>\n<p><a href=\"http://epicalex.com/epic-theme-viewer/\"><strong>Epic Theme Viewer</strong></a></p>\n<p>This plugin uses that native theme viewer in WordPress 2.6 to display a front end display of all the themes available on your blog.</p>\n<p><a href=\"http://www.eruditor.com/spec/wordpress-recommendedbooks.html.en\"><strong>Recommended Books</strong></a></p>\n<p>This is higly configurable widget to WordPress sidebar. It displays up to 10 books with liks to Eruditor.com bookshop and optionaly with jacket images, prices in dollars or pounds and/or discounts.</p>\n<p><a href=\"http://beejay.perthmatrix.com/servage-referral-widget/\"><strong>Servage Referral Widget</strong></a></p>\n<p>This widget allows customers of Servage to display a link containing their coupon code to Servage, customers that use this code get 25GB of extra web space and 2 months free hosting when a new customer that uses the code joins up, in return the new customer automatically receives 25GB of extra quota.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/paginated-comments/\"><strong>Paginated Comments</strong></a></p>\n<p>Paginated Comments is a WordPress Plugin that gives you the ability to break your comments into a number of search engine optimized pages.</p>\n<p><a href=\"http://andrerenaut.ovh.org/wp/?page_id=70\"><strong>MailPress</strong></a></p>\n<p>This plugin allows you to send beautiful and styled html and plain text mails based on dedicated themes and templates. If you are already comfortable with Worpress organisation and how it works, you will not be lost with MailPress. The MailPress theme and templates organisation is very similar to WordPress.</p>\n<p><a href=\"http://likemind.co.uk/wordpress-side-content-plugin/\"><strong>Side Content</strong></a></p>\n<p>This plugin allows you to create widgets that have different content on different pages.</p>\n<p><a href=\"http://www.halmatferello.com/lab/wp-js/\"><strong>WP JS</strong></a></p>\n<p>This plugin will GZIP and JSMIN your JavaScript files as well as allowing the ability to put JavaScript files into a single file at the client&#8217;s end. Cache expiry time can also be set in the admin page.</p>\";}i:23;a:7:{s:5:\"title\";s:31:\"bbPress: bbPress at WordCamp UK\";s:4:\"guid\";s:24:\"http://bbpress.org/?p=86\";s:4:\"link\";s:55:\"http://bbpress.org/blog/2008/07/bbpress-at-wordcamp-uk/\";s:11:\"description\";s:533:\"<p>I (Sam Bauers) will be speaking about bbPress at WordCamp UK in Birmingham this weekend.</p>\n<p>I&#8217;ll be going through how to integrate bbPress (0.9.0.2) with WordPress (2.5.1) as well as talking a little about where bbPress is heading at the moment.</p>\n<p>There is lots of other great stuff going on, full details are available via <a href=\"http://wordcampuk.wp-cms.com/\">their blog</a>.</p>\n<p>Or just <a href=\"http://wordcampuk2008.eventbrite.com/\">buy tickets here</a>.</p>\n<p>I hope to see some bbPress users there!</p>\";s:7:\"pubdate\";s:31:\"Wed, 16 Jul 2008 16:53:51 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:10:\"Sam Bauers\";}s:7:\"summary\";s:533:\"<p>I (Sam Bauers) will be speaking about bbPress at WordCamp UK in Birmingham this weekend.</p>\n<p>I&#8217;ll be going through how to integrate bbPress (0.9.0.2) with WordPress (2.5.1) as well as talking a little about where bbPress is heading at the moment.</p>\n<p>There is lots of other great stuff going on, full details are available via <a href=\"http://wordcampuk.wp-cms.com/\">their blog</a>.</p>\n<p>Or just <a href=\"http://wordcampuk2008.eventbrite.com/\">buy tickets here</a>.</p>\n<p>I hope to see some bbPress users there!</p>\";}i:24;a:7:{s:5:\"title\";s:18:\"Matt: Dr. Horrible\";s:4:\"guid\";s:33:\"http://ma.tt/2008/07/dr-horrible/\";s:4:\"link\";s:33:\"http://ma.tt/2008/07/dr-horrible/\";s:11:\"description\";s:137:\"<p><a href=\"http://www.drhorrible.com/\">Dr. Horrible&#8217;s Sing-Along Blog</a>, a project from Joss Whedon and Neil Patrick Harris.</p>\";s:7:\"pubdate\";s:31:\"Tue, 15 Jul 2008 20:45:03 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Matt\";}s:7:\"summary\";s:137:\"<p><a href=\"http://www.drhorrible.com/\">Dr. Horrible&#8217;s Sing-Along Blog</a>, a project from Joss Whedon and Neil Patrick Harris.</p>\";}i:25;a:7:{s:5:\"title\";s:59:\"Weblog Tools Collection: WordPress Theme Releases for 07/15\";s:4:\"guid\";s:40:\"http://weblogtoolscollection.com/?p=3750\";s:4:\"link\";s:87:\"http://weblogtoolscollection.com/archives/2008/07/15/wordpress-theme-releases-for-0715/\";s:11:\"description\";s:1142:\"<p><a href=\"http://www.positivenoize.com/\"><strong>PositiveNoize</strong></a></p>\n<p><a href=\"http://wordpress.positivenoize.com/\"><img alt=\"PositiveNoize\" src=\"http://weblogtoolscollection.com/b2-img/2008/07/positivenoize.gif\" height=\"125\" width=\"167\" /></a></p>\n<p>A simple, light-weight, fast-loading, widget-ready two column WordPress 2.5+ theme</p>\n<p><a href=\"http://fresh01.co.za/2008/07/14/base\"><strong>Base</strong></a></p>\n<p><a href=\"http://fresh01.co.za/preview/?wptheme=BASE\"><img alt=\"Base\" src=\"http://weblogtoolscollection.com/b2-img/2008/07/base.gif\" height=\"121\" width=\"200\" /></a></p>\n<p>BASE is a very solid two column WordPress theme, covering all the basic features a standard WordPress theme should have…plus one or two extras.</p>\n<p><a href=\"http://www.subcess.de/themes-wordpress-download/\"><strong>simple.business</strong></a></p>\n<p><a href=\"http://www.subcess.de/themes-wordpress-download/\"><img alt=\"simple.business\" src=\"http://weblogtoolscollection.com/b2-img/2008/07/simplebusiness.jpg\" height=\"125\" width=\"139\" /></a></p>\n<p>simple.business is a simple two column WordPress theme with a tabbed sidebar</p>\";s:7:\"pubdate\";s:31:\"Tue, 15 Jul 2008 19:30:14 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Ajay\";}s:7:\"summary\";s:1142:\"<p><a href=\"http://www.positivenoize.com/\"><strong>PositiveNoize</strong></a></p>\n<p><a href=\"http://wordpress.positivenoize.com/\"><img alt=\"PositiveNoize\" src=\"http://weblogtoolscollection.com/b2-img/2008/07/positivenoize.gif\" height=\"125\" width=\"167\" /></a></p>\n<p>A simple, light-weight, fast-loading, widget-ready two column WordPress 2.5+ theme</p>\n<p><a href=\"http://fresh01.co.za/2008/07/14/base\"><strong>Base</strong></a></p>\n<p><a href=\"http://fresh01.co.za/preview/?wptheme=BASE\"><img alt=\"Base\" src=\"http://weblogtoolscollection.com/b2-img/2008/07/base.gif\" height=\"121\" width=\"200\" /></a></p>\n<p>BASE is a very solid two column WordPress theme, covering all the basic features a standard WordPress theme should have…plus one or two extras.</p>\n<p><a href=\"http://www.subcess.de/themes-wordpress-download/\"><strong>simple.business</strong></a></p>\n<p><a href=\"http://www.subcess.de/themes-wordpress-download/\"><img alt=\"simple.business\" src=\"http://weblogtoolscollection.com/b2-img/2008/07/simplebusiness.jpg\" height=\"125\" width=\"139\" /></a></p>\n<p>simple.business is a simple two column WordPress theme with a tabbed sidebar</p>\";}i:26;a:7:{s:5:\"title\";s:39:\"Dougal Campbell: WordPress 2.6 Released\";s:4:\"guid\";s:33:\"http://dougal.gunters.org/?p=1007\";s:4:\"link\";s:63:\"http://dougal.gunters.org/blog/2008/07/15/wordpress-26-released\";s:11:\"description\";s:1550:\"<p>The release of <a href=\"http://wordpress.org/development/2008/07/wordpress-26-tyner/\">WordPress 2.6</a> is now official. In addition to the features I <a href=\"http://dougal.gunters.org/blog/2008/06/24/wordpress-26-beta-1\">highlighted previously</a>, Ryan has details on his blog about the <a href=\"http://boren.nu/archives/2008/07/14/ssl-and-cookies-in-wordpress-26/\">improved support for SSL</a>, and some new helper functions which will be useful for plugin and theme authors. And the official dev blog post has details on other new features. One of the more interesting things that I didn&#8217;t yet know about was that the Press This bookmarklet has some nifty autodetection which will make it easy to automatically embed content from sites like <a href=\"http://youtube.com/\">YouTube</a> and <a href=\"http://flickr.com/\">Flickr</a>.</p>\n<p>In addition to the new features, I&#8217;d also like to point out that there has been a recent effort to improve the inline source documentation (using <a href=\"http://www.phpdoc.org/\">PHPdoc</a>). I, for one, certainly appreciate the work that is going into documenting the parameters, return values, and purpose of each function. It make things much easier when you have to trace back through the call stack to figure out where certain things happen.</p>\n<p><a href=\"http://sharethis.com/item?&wp=2.6.1-alpha&amp;publisher=06a70a77-1fc0-46a9-81d1-6a696e6ed23f&amp;title=WordPress+2.6+Released&amp;url=http%3A%2F%2Fdougal.gunters.org%2Fblog%2F2008%2F07%2F15%2Fwordpress-26-released\">ShareThis</a></p>\";s:7:\"pubdate\";s:31:\"Tue, 15 Jul 2008 12:31:00 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:6:\"Dougal\";}s:7:\"summary\";s:1550:\"<p>The release of <a href=\"http://wordpress.org/development/2008/07/wordpress-26-tyner/\">WordPress 2.6</a> is now official. In addition to the features I <a href=\"http://dougal.gunters.org/blog/2008/06/24/wordpress-26-beta-1\">highlighted previously</a>, Ryan has details on his blog about the <a href=\"http://boren.nu/archives/2008/07/14/ssl-and-cookies-in-wordpress-26/\">improved support for SSL</a>, and some new helper functions which will be useful for plugin and theme authors. And the official dev blog post has details on other new features. One of the more interesting things that I didn&#8217;t yet know about was that the Press This bookmarklet has some nifty autodetection which will make it easy to automatically embed content from sites like <a href=\"http://youtube.com/\">YouTube</a> and <a href=\"http://flickr.com/\">Flickr</a>.</p>\n<p>In addition to the new features, I&#8217;d also like to point out that there has been a recent effort to improve the inline source documentation (using <a href=\"http://www.phpdoc.org/\">PHPdoc</a>). I, for one, certainly appreciate the work that is going into documenting the parameters, return values, and purpose of each function. It make things much easier when you have to trace back through the call stack to figure out where certain things happen.</p>\n<p><a href=\"http://sharethis.com/item?&wp=2.6.1-alpha&amp;publisher=06a70a77-1fc0-46a9-81d1-6a696e6ed23f&amp;title=WordPress+2.6+Released&amp;url=http%3A%2F%2Fdougal.gunters.org%2Fblog%2F2008%2F07%2F15%2Fwordpress-26-released\">ShareThis</a></p>\";}i:27;a:7:{s:5:\"title\";s:52:\"Mark Jaquith: Congratulations to Andrew Ozz (azaozz)\";s:4:\"guid\";s:39:\"http://markjaquith.wordpress.com/?p=154\";s:4:\"link\";s:81:\"http://markjaquith.wordpress.com/2008/07/15/congratulations-to-andrew-ozz-azaozz/\";s:11:\"description\";s:2205:\"<div class=\"snap_preview\"><br /><p>Not only does <a href=\"http://www.laptoptips.ca/\">Andrew Ozz</a> have one of the coolest names ever (His name starts with A and ends with Z, for heaven&#8217;s sake!), he also just gained commit access to the WordPress project!  Congratulations, and well-deserved.  The vote was unanimous. <img src=\"http://s.wordpress.com/wp-includes/images/smilies/icon_smile.gif\" alt=\":-)\" class=\"wp-smiley\" /> </p>\n<p>Andrew&#8217;s specialty is the Visual Editor (a.k.a. &#8220;Rich Text Editor&#8221;).  At first, I hated the Visual Editor.  Now I frequently use it.  Andrew gets a lot of the credit for that.  Welcome to the team!</p>\n<p>Psst: <a title=\"Read about WordPress 2.6\" href=\"http://wordpress.org/development/2008/07/wordpress-26-tyner/\">WordPress 2.6 is now available</a> for your blogging pleasure.</p>\n<img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/categories/markjaquith.wordpress.com/154/\" /> <img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/tags/markjaquith.wordpress.com/154/\" /> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/gocomments/markjaquith.wordpress.com/154/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/comments/markjaquith.wordpress.com/154/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/godelicious/markjaquith.wordpress.com/154/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/delicious/markjaquith.wordpress.com/154/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/gostumble/markjaquith.wordpress.com/154/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/stumble/markjaquith.wordpress.com/154/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/godigg/markjaquith.wordpress.com/154/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/digg/markjaquith.wordpress.com/154/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/goreddit/markjaquith.wordpress.com/154/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/reddit/markjaquith.wordpress.com/154/\" /></a> <img alt=\"\" border=\"0\" src=\"http://stats.wordpress.com/b.gif?host=markjaquith.wordpress.com&blog=316&post=154&subd=markjaquith&ref=&feed=1\" /></div>\";s:7:\"pubdate\";s:31:\"Tue, 15 Jul 2008 06:14:37 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:12:\"Mark Jaquith\";}s:7:\"summary\";s:2205:\"<div class=\"snap_preview\"><br /><p>Not only does <a href=\"http://www.laptoptips.ca/\">Andrew Ozz</a> have one of the coolest names ever (His name starts with A and ends with Z, for heaven&#8217;s sake!), he also just gained commit access to the WordPress project!  Congratulations, and well-deserved.  The vote was unanimous. <img src=\"http://s.wordpress.com/wp-includes/images/smilies/icon_smile.gif\" alt=\":-)\" class=\"wp-smiley\" /> </p>\n<p>Andrew&#8217;s specialty is the Visual Editor (a.k.a. &#8220;Rich Text Editor&#8221;).  At first, I hated the Visual Editor.  Now I frequently use it.  Andrew gets a lot of the credit for that.  Welcome to the team!</p>\n<p>Psst: <a title=\"Read about WordPress 2.6\" href=\"http://wordpress.org/development/2008/07/wordpress-26-tyner/\">WordPress 2.6 is now available</a> for your blogging pleasure.</p>\n<img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/categories/markjaquith.wordpress.com/154/\" /> <img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/tags/markjaquith.wordpress.com/154/\" /> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/gocomments/markjaquith.wordpress.com/154/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/comments/markjaquith.wordpress.com/154/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/godelicious/markjaquith.wordpress.com/154/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/delicious/markjaquith.wordpress.com/154/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/gostumble/markjaquith.wordpress.com/154/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/stumble/markjaquith.wordpress.com/154/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/godigg/markjaquith.wordpress.com/154/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/digg/markjaquith.wordpress.com/154/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/goreddit/markjaquith.wordpress.com/154/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/reddit/markjaquith.wordpress.com/154/\" /></a> <img alt=\"\" border=\"0\" src=\"http://stats.wordpress.com/b.gif?host=markjaquith.wordpress.com&blog=316&post=154&subd=markjaquith&ref=&feed=1\" /></div>\";}i:28;a:7:{s:5:\"title\";s:58:\"Weblog Tools Collection: WordPress 2.6 Released Officially\";s:4:\"guid\";s:40:\"http://weblogtoolscollection.com/?p=3746\";s:4:\"link\";s:86:\"http://weblogtoolscollection.com/archives/2008/07/15/wordpress-26-released-officially/\";s:11:\"description\";s:612:\"<p>WordPress 2.6 has been <a href=\"http://wordpress.org/development/2008/07/wordpress-26-tyner/\">officially released today</a>. Matt surprised many of us by releasing WordPress 2.6 almost a month ahead of schedule.</p>\n<p>There are several new features in WordPress 2.6, few of <a href=\"http://weblogtoolscollection.com/archives/2008/06/30/what-you-need-to-know-about-wordpress-26/\">which we had covered earlier</a>. The WordPress team have also created a video that demonstrates the new features bundled with WordPress 2.6.</p>\n<p></p>\n<p><a href=\"http://wordpress.org/latest.zip\">Download WordPress 2.6</a></p>\";s:7:\"pubdate\";s:31:\"Tue, 15 Jul 2008 04:12:40 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:12:\"Keith Dsouza\";}s:7:\"summary\";s:612:\"<p>WordPress 2.6 has been <a href=\"http://wordpress.org/development/2008/07/wordpress-26-tyner/\">officially released today</a>. Matt surprised many of us by releasing WordPress 2.6 almost a month ahead of schedule.</p>\n<p>There are several new features in WordPress 2.6, few of <a href=\"http://weblogtoolscollection.com/archives/2008/06/30/what-you-need-to-know-about-wordpress-26/\">which we had covered earlier</a>. The WordPress team have also created a video that demonstrates the new features bundled with WordPress 2.6.</p>\n<p></p>\n<p><a href=\"http://wordpress.org/latest.zip\">Download WordPress 2.6</a></p>\";}i:29;a:7:{s:5:\"title\";s:21:\"Matt: 2.6 and Cookies\";s:4:\"guid\";s:20:\"http://ma.tt/?p=6715\";s:4:\"link\";s:36:\"http://ma.tt/2008/07/26-and-cookies/\";s:11:\"description\";s:562:\"<p><a href=\"http://wordpress.org/development/2008/07/wordpress-26-tyner/\">WordPress 2.6 is out</a> and it&#8217;s a really solid release, so check it out. Ryan has a good post on <a href=\"http://boren.nu/archives/2008/07/14/ssl-and-cookies-in-wordpress-26/\">SSL and Cookies in WP 2.6</a>. My congrats go out to the whole team for putting together the release, ahead of schedule! <strong>Update:</strong> <a href=\"http://joseph.randomnetworks.com/archives/2008/07/14/wordpress-26-xml-rpc-atompub-changes/\">Joseph has some info on XML-RPC and Atom changes</a>.</p>\";s:7:\"pubdate\";s:31:\"Tue, 15 Jul 2008 04:08:38 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Matt\";}s:7:\"summary\";s:562:\"<p><a href=\"http://wordpress.org/development/2008/07/wordpress-26-tyner/\">WordPress 2.6 is out</a> and it&#8217;s a really solid release, so check it out. Ryan has a good post on <a href=\"http://boren.nu/archives/2008/07/14/ssl-and-cookies-in-wordpress-26/\">SSL and Cookies in WP 2.6</a>. My congrats go out to the whole team for putting together the release, ahead of schedule! <strong>Update:</strong> <a href=\"http://joseph.randomnetworks.com/archives/2008/07/14/wordpress-26-xml-rpc-atompub-changes/\">Joseph has some info on XML-RPC and Atom changes</a>.</p>\";}i:30;a:7:{s:5:\"title\";s:23:\"Dev Blog: WordPress 2.6\";s:4:\"guid\";s:39:\"http://wordpress.org/development/?p=246\";s:4:\"link\";s:60:\"http://wordpress.org/development/2008/07/wordpress-26-tyner/\";s:11:\"description\";s:9657:\"<p> I&#8217;m happy to announce that version 2.6 of WordPress.org <a href=\"http://wordpress.org/download/\">is now available</a>, almost a month ahead schedule. Version 2.6 &#8220;Tyner,&#8221; named for jazz pianist <a href=\"http://en.wikipedia.org/wiki/McCoy_Tyner\">McCoy Tyner</a>, contains a number of new features that make WordPress a more powerful CMS: you can now track changes to every post and page and easily post from wherever you are on the web, plus there are dozens of incremental improvements to the features introduced in <a href=\"http://wordpress.org/development/2008/03/wordpress-25-brecker/\">version 2.5</a>.</p>\n<p>We&#8217;ve prepared a brief video tour of 2.6, if you have 3 minutes and 29 seconds to spare, it&#8217;s worth a watch:</p>\n<p> </p>\n<p>If you&#8217;d like to embed the tour video in your blog, copy and paste this code for the high quality version:</p>\n<pre name=\"code\" class=\"html\">\n&lt;embed src=\"http://v.wordpress.com/mARhRBcT/fmt_dvd\" type=\"application/x-shockwave-flash\" width=\"640\" height=\"385\" flashvars=\"blog_domain=http://wordpress.org/development/2008/07/wordpress-26/&amp;width=640&amp;height=385\"&gt; &lt;/embed&gt;\n</pre>\n<p>And here&#8217;s a smaller version, 400 pixels wide:</p>\n<pre name=\"code\" class=\"html\">\n&lt;embed src=\"http://v.wordpress.com/mARhRBcT/fmt_std\" type=\"application/x-shockwave-flash\" width=\"400\" height=\"250\" flashvars=\"blog_domain=http://wordpress.org/development/2008/07/wordpress-26/&amp;width=400&amp;height=250\"&gt; &lt;/embed&gt;\n</pre>\n<p>Here&#8217;s a more textual overview of what&#8217;s hawt in 2.6:</p>\n<h3>Post Revisions: Wiki-like tracking of edits</h3>\n<p>With the power of modern computers, it&#8217;s silly that we still use save and editing metaphors from the time when the most common method of storage was floppy disks. WordPress has always respected the importance of your writing with auto-save, and now we&#8217;re taking that to another level by allowing you to view who made what changes when to any post or page through a super-easy interface, much like <a href=\"http://en.wikipedia.org/w/index.php?title=Wikipedia&#038;action=history\">Wikipedia</a> or a <a href=\"http://codex.wordpress.org/Using_Subversion\">version control system</a>.</p>\n<p><img src=\"http://wpdotorg.wordpress.com/files/2008/07/diff.gif\" alt=\"Differences between two versions of posts.\" class=\"alignnone size-full wp-image-3\" /></p>\n<p>This is handy on any blog in case you make a mistake and want to go back to an older version of a post, and it&#8217;s super handy for multi-author blogs where you can see every change tracked by person.</p>\n<h3>Press This!: Post from wherever you are on the web</h3>\n<p>A few months ago on my blog we <a href=\"http://ma.tt/2008/05/favorite-posting-bookmarklet/\">started a conversation about the posting bookmarklet</a> in WordPress and which systems we should look to for inspiration, like Flock, FriendFeed, Facebook, Tumblr, and Delicious. From these suggestions and the Quick Post plugin by Josh Kenzer, we developed a Press This bookmark you can add to your toolbar that provides a fast and smart popup to do posts to your WordPress blog:</p>\n<p><img src=\"http://wpdotorg.wordpress.com/files/2008/07/press-this.gif\" alt=\"Screenshot of Press This interface.\" title=\"press-this\" class=\"alignnone size-full wp-image-4\" /></p>\n<p>For example, if you click &#8220;Press This&#8221; from a <a href=\"http://youtube.com/\">Youtube</a> page it&#8217;ll magically extract the video embed code, and if you do it from a <a href=\"http://flickr.com/\">Flickr</a> page it&#8217;ll make it easy for you to put the image in your post. On my blog I&#8217;ve been experimenting with using different categories and the <code>in_category()</code> function &#8212; such as video, quote, aside, et cetera &#8212; to create a more tumblelog-like format.</p>\n<h3>Shift Gears: Turbo-speed your blogging</h3>\n<p><a href=\"http://gears.google.com/\">Gears</a> is an open source browser extension project started by Google that developers like us can use to give you features we wouldn&#8217;t normally be able to. There are a lot of things we can do with Gears in the future, but in this release we&#8217;ve stuck to using what&#8217;s called a &#8220;Local Server&#8221; to cache or keep a copy of commonly-used Javascript and CSS files on your computer, which can speed up the loading of some pages by several seconds (they just pop right up!). You can install Gears for Firefox or Internet Explorer, with support for Safari and Opera pending. WordPress works just fine without it, you just get a little extra juice when you have it installed.</p>\n<h3>Theme Previews: See it before your audience does</h3>\n<p>Now when you select a theme it pops up a window that shows the theme live with all your content, instead of immediately making it active on your site. This is great for just test driving themes before making a switch over publicly, and it is also helpful when you are developing a theme and need to test it but don&#8217;t want everybody to see your ongoing <del datetime=\"2008-07-14T21:23:41+00:00\">mistakes</del> development.</p>\n<p>Here are some of the smaller features and improvements in 2.6:</p>\n<ul>\n<li><strong>Word count!</strong> Never guess how many words are in your post anymore.</li>\n<li><strong>Image captions</strong>, so you can add sweet captions <a href=\"http://politicalticker.blogs.cnn.com/\">like Political Ticker does</a> under your images.</li>\n<li><strong>Bulk management</strong> of plugins.</li>\n<li>A completely <strong>revamped image control</strong> to allow for easier inserting, floating, and resizing. It&#8217;s now fully integrated with the WYSIWYG.</li>\n<li>Drag-and-drop <strong>reordering of Galleries</strong>.</li>\n<li><strong>Plugin update</strong> notification bubble.</li>\n<li>Customizable default avatars.</li>\n<li>You can now upload media when in full-screen mode.</li>\n<li>Remote publishing via XML-RPC and APP is now secure (off) by default, but you can turn it on easily through the options screen.</li>\n<li>Full <a href=\"http://en.wikipedia.org/wiki/Secure_Sockets_Layer\">SSL support</a> in the core, and the ability to <strong>force SSL</strong> for security.</li>\n<li>You can now have many thousands of pages or categories with no interface issues.</li>\n<li>Ability to move your <code>wp-config</code> file and <code>wp-content</code> directories to a custom location, for &#8220;clean&#8221; SVN checkouts.</li>\n<li>Select a range of checkboxes with &#8220;shift-click.&#8221;</li>\n<li>You can toggle between the Flash uploader and the classic one.</li>\n<li>A number of proactive security enhancements, including cookies and database interactions.</li>\n<li>Stronger better faster versions of TinyMCE, jQuery, and jQuery UI.</li>\n<li>Version 2.6 <a href=\"http://trac.wordpress.org/query?status=closed&#038;milestone=2.6\">fixes approximately 194 bugs</a>.</li>\n</ul>\n<h3>Developer Notes</h3>\n<p>WordPress.org had over 75 people contributing code to WordPress 2.6. In addition to the <a href=\"http://wordpress.org/about/\">core commit team</a> we had contributions from <a href=\"http://dd32.id.au/\">Dion Hulse</a>, <a href=\"http://www.ilfilosofo.com/\">Austin Matzko</a>, <a href=\"http://ottodestruct.com/blog/\">Otto42</a>, <a href=\"http://extralogical.net/\">Benedict Eastaugh</a>, and <a href=\"http://www.freecharity.org.uk/\">pishmishy</a>. <a href=\"http://xavisys.com/\">AaronCampbell</a> and <a href=\"http://www.marcozehe.de/\">Marco Zehe</a> provided more than a few patches. Back among the top code contributors is <a href=\"http://www.santosj.name/\">Jacob Santos</a>. <a href=\"http://www.buayacorp.com/\">Alex Concha</a> continues to have WordPress&#8217; back. Joining bug reporting and gardening elite are <a href=\"http://codex.wordpress.org/User:Hakre\">hakre</a>, <a href=\"http://www.simonwheatley.co.uk/\">Simon Wheatley</a>, mtekk, and <a href=\"http://www.prescriber.org.uk/\">Matty Rob</a>. Finally, congratulations to our <a href=\"http://westi.wordpress.com/\">Peter Westwood</a> on your recent wedding! I&#8217;m also proud to announce we&#8217;re adding a new core committer to the team: Andrew Ozz (azaozz) has been a huge help to the core team this year, particularly around TinyMCE and making the WYSIWYG something that works for you, not against you.</p>\n<p>Because of the new capabilities to make WordPress a clean SVN checkout, plugin and theme authors should do their best to handle forms and posts through WP rather than trying to post to their files directly, here&#8217;s a quick Codex article about <a href=\"http://codex.wordpress.org/Handling_POST_and_AJAX_Requests\">how to do it using our forward-compatible APIs</a>.</p>\n<h3>Upgrading</h3>\n<p>2.6 is pretty much identical to 2.5 from a plugin and theme compatibility point of view, so upgrades from 2.5 should be pretty painless. The 2.5 branch will no longer be maintain so everyone is encouraged to upgrade. <a href=\"http://codex.wordpress.org/Upgrading_WordPress\">Our standard 3-step upgrade instructions apply to this release</a>. There were at least 1,984,047 downloads of the 2.5 series, the fastest growing release we&#8217;ve ever had, and I think all of those people will find 2.6 adds a level of polish that really makes WP a pleasure to use every day. (At least I do. :))</p>\n<h3>Easter Egg</h3>\n<p>There have been rumors and allegations that there was a so-called &#8220;easter egg&#8221; added to 2.6 early in its development. These rumors and allegations are completely false!</p>\n<p>P.S. If you&#8217;re a fan of WordPress, <a href=\"http://www.facebook.com/pages/WordPress/6427302910\">consider joining our fan page on Facebook</a>.</p>\";s:7:\"pubdate\";s:31:\"Tue, 15 Jul 2008 03:38:42 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Matt\";}s:7:\"summary\";s:9657:\"<p> I&#8217;m happy to announce that version 2.6 of WordPress.org <a href=\"http://wordpress.org/download/\">is now available</a>, almost a month ahead schedule. Version 2.6 &#8220;Tyner,&#8221; named for jazz pianist <a href=\"http://en.wikipedia.org/wiki/McCoy_Tyner\">McCoy Tyner</a>, contains a number of new features that make WordPress a more powerful CMS: you can now track changes to every post and page and easily post from wherever you are on the web, plus there are dozens of incremental improvements to the features introduced in <a href=\"http://wordpress.org/development/2008/03/wordpress-25-brecker/\">version 2.5</a>.</p>\n<p>We&#8217;ve prepared a brief video tour of 2.6, if you have 3 minutes and 29 seconds to spare, it&#8217;s worth a watch:</p>\n<p> </p>\n<p>If you&#8217;d like to embed the tour video in your blog, copy and paste this code for the high quality version:</p>\n<pre name=\"code\" class=\"html\">\n&lt;embed src=\"http://v.wordpress.com/mARhRBcT/fmt_dvd\" type=\"application/x-shockwave-flash\" width=\"640\" height=\"385\" flashvars=\"blog_domain=http://wordpress.org/development/2008/07/wordpress-26/&amp;width=640&amp;height=385\"&gt; &lt;/embed&gt;\n</pre>\n<p>And here&#8217;s a smaller version, 400 pixels wide:</p>\n<pre name=\"code\" class=\"html\">\n&lt;embed src=\"http://v.wordpress.com/mARhRBcT/fmt_std\" type=\"application/x-shockwave-flash\" width=\"400\" height=\"250\" flashvars=\"blog_domain=http://wordpress.org/development/2008/07/wordpress-26/&amp;width=400&amp;height=250\"&gt; &lt;/embed&gt;\n</pre>\n<p>Here&#8217;s a more textual overview of what&#8217;s hawt in 2.6:</p>\n<h3>Post Revisions: Wiki-like tracking of edits</h3>\n<p>With the power of modern computers, it&#8217;s silly that we still use save and editing metaphors from the time when the most common method of storage was floppy disks. WordPress has always respected the importance of your writing with auto-save, and now we&#8217;re taking that to another level by allowing you to view who made what changes when to any post or page through a super-easy interface, much like <a href=\"http://en.wikipedia.org/w/index.php?title=Wikipedia&#038;action=history\">Wikipedia</a> or a <a href=\"http://codex.wordpress.org/Using_Subversion\">version control system</a>.</p>\n<p><img src=\"http://wpdotorg.wordpress.com/files/2008/07/diff.gif\" alt=\"Differences between two versions of posts.\" class=\"alignnone size-full wp-image-3\" /></p>\n<p>This is handy on any blog in case you make a mistake and want to go back to an older version of a post, and it&#8217;s super handy for multi-author blogs where you can see every change tracked by person.</p>\n<h3>Press This!: Post from wherever you are on the web</h3>\n<p>A few months ago on my blog we <a href=\"http://ma.tt/2008/05/favorite-posting-bookmarklet/\">started a conversation about the posting bookmarklet</a> in WordPress and which systems we should look to for inspiration, like Flock, FriendFeed, Facebook, Tumblr, and Delicious. From these suggestions and the Quick Post plugin by Josh Kenzer, we developed a Press This bookmark you can add to your toolbar that provides a fast and smart popup to do posts to your WordPress blog:</p>\n<p><img src=\"http://wpdotorg.wordpress.com/files/2008/07/press-this.gif\" alt=\"Screenshot of Press This interface.\" title=\"press-this\" class=\"alignnone size-full wp-image-4\" /></p>\n<p>For example, if you click &#8220;Press This&#8221; from a <a href=\"http://youtube.com/\">Youtube</a> page it&#8217;ll magically extract the video embed code, and if you do it from a <a href=\"http://flickr.com/\">Flickr</a> page it&#8217;ll make it easy for you to put the image in your post. On my blog I&#8217;ve been experimenting with using different categories and the <code>in_category()</code> function &#8212; such as video, quote, aside, et cetera &#8212; to create a more tumblelog-like format.</p>\n<h3>Shift Gears: Turbo-speed your blogging</h3>\n<p><a href=\"http://gears.google.com/\">Gears</a> is an open source browser extension project started by Google that developers like us can use to give you features we wouldn&#8217;t normally be able to. There are a lot of things we can do with Gears in the future, but in this release we&#8217;ve stuck to using what&#8217;s called a &#8220;Local Server&#8221; to cache or keep a copy of commonly-used Javascript and CSS files on your computer, which can speed up the loading of some pages by several seconds (they just pop right up!). You can install Gears for Firefox or Internet Explorer, with support for Safari and Opera pending. WordPress works just fine without it, you just get a little extra juice when you have it installed.</p>\n<h3>Theme Previews: See it before your audience does</h3>\n<p>Now when you select a theme it pops up a window that shows the theme live with all your content, instead of immediately making it active on your site. This is great for just test driving themes before making a switch over publicly, and it is also helpful when you are developing a theme and need to test it but don&#8217;t want everybody to see your ongoing <del datetime=\"2008-07-14T21:23:41+00:00\">mistakes</del> development.</p>\n<p>Here are some of the smaller features and improvements in 2.6:</p>\n<ul>\n<li><strong>Word count!</strong> Never guess how many words are in your post anymore.</li>\n<li><strong>Image captions</strong>, so you can add sweet captions <a href=\"http://politicalticker.blogs.cnn.com/\">like Political Ticker does</a> under your images.</li>\n<li><strong>Bulk management</strong> of plugins.</li>\n<li>A completely <strong>revamped image control</strong> to allow for easier inserting, floating, and resizing. It&#8217;s now fully integrated with the WYSIWYG.</li>\n<li>Drag-and-drop <strong>reordering of Galleries</strong>.</li>\n<li><strong>Plugin update</strong> notification bubble.</li>\n<li>Customizable default avatars.</li>\n<li>You can now upload media when in full-screen mode.</li>\n<li>Remote publishing via XML-RPC and APP is now secure (off) by default, but you can turn it on easily through the options screen.</li>\n<li>Full <a href=\"http://en.wikipedia.org/wiki/Secure_Sockets_Layer\">SSL support</a> in the core, and the ability to <strong>force SSL</strong> for security.</li>\n<li>You can now have many thousands of pages or categories with no interface issues.</li>\n<li>Ability to move your <code>wp-config</code> file and <code>wp-content</code> directories to a custom location, for &#8220;clean&#8221; SVN checkouts.</li>\n<li>Select a range of checkboxes with &#8220;shift-click.&#8221;</li>\n<li>You can toggle between the Flash uploader and the classic one.</li>\n<li>A number of proactive security enhancements, including cookies and database interactions.</li>\n<li>Stronger better faster versions of TinyMCE, jQuery, and jQuery UI.</li>\n<li>Version 2.6 <a href=\"http://trac.wordpress.org/query?status=closed&#038;milestone=2.6\">fixes approximately 194 bugs</a>.</li>\n</ul>\n<h3>Developer Notes</h3>\n<p>WordPress.org had over 75 people contributing code to WordPress 2.6. In addition to the <a href=\"http://wordpress.org/about/\">core commit team</a> we had contributions from <a href=\"http://dd32.id.au/\">Dion Hulse</a>, <a href=\"http://www.ilfilosofo.com/\">Austin Matzko</a>, <a href=\"http://ottodestruct.com/blog/\">Otto42</a>, <a href=\"http://extralogical.net/\">Benedict Eastaugh</a>, and <a href=\"http://www.freecharity.org.uk/\">pishmishy</a>. <a href=\"http://xavisys.com/\">AaronCampbell</a> and <a href=\"http://www.marcozehe.de/\">Marco Zehe</a> provided more than a few patches. Back among the top code contributors is <a href=\"http://www.santosj.name/\">Jacob Santos</a>. <a href=\"http://www.buayacorp.com/\">Alex Concha</a> continues to have WordPress&#8217; back. Joining bug reporting and gardening elite are <a href=\"http://codex.wordpress.org/User:Hakre\">hakre</a>, <a href=\"http://www.simonwheatley.co.uk/\">Simon Wheatley</a>, mtekk, and <a href=\"http://www.prescriber.org.uk/\">Matty Rob</a>. Finally, congratulations to our <a href=\"http://westi.wordpress.com/\">Peter Westwood</a> on your recent wedding! I&#8217;m also proud to announce we&#8217;re adding a new core committer to the team: Andrew Ozz (azaozz) has been a huge help to the core team this year, particularly around TinyMCE and making the WYSIWYG something that works for you, not against you.</p>\n<p>Because of the new capabilities to make WordPress a clean SVN checkout, plugin and theme authors should do their best to handle forms and posts through WP rather than trying to post to their files directly, here&#8217;s a quick Codex article about <a href=\"http://codex.wordpress.org/Handling_POST_and_AJAX_Requests\">how to do it using our forward-compatible APIs</a>.</p>\n<h3>Upgrading</h3>\n<p>2.6 is pretty much identical to 2.5 from a plugin and theme compatibility point of view, so upgrades from 2.5 should be pretty painless. The 2.5 branch will no longer be maintain so everyone is encouraged to upgrade. <a href=\"http://codex.wordpress.org/Upgrading_WordPress\">Our standard 3-step upgrade instructions apply to this release</a>. There were at least 1,984,047 downloads of the 2.5 series, the fastest growing release we&#8217;ve ever had, and I think all of those people will find 2.6 adds a level of polish that really makes WP a pleasure to use every day. (At least I do. :))</p>\n<h3>Easter Egg</h3>\n<p>There have been rumors and allegations that there was a so-called &#8220;easter egg&#8221; added to 2.6 early in its development. These rumors and allegations are completely false!</p>\n<p>P.S. If you&#8217;re a fan of WordPress, <a href=\"http://www.facebook.com/pages/WordPress/6427302910\">consider joining our fan page on Facebook</a>.</p>\";}i:31;a:7:{s:5:\"title\";s:44:\"Ryan Boren: SSL and Cookies in WordPress 2.6\";s:4:\"guid\";s:23:\"http://boren.nu/?p=1579\";s:4:\"link\";s:68:\"http://boren.nu/archives/2008/07/14/ssl-and-cookies-in-wordpress-26/\";s:11:\"description\";s:5958:\"<p><a href=\"http://wordpress.org/\">WordPress</a> 2.6 includes better support for visiting the admin over <a href=\"http://en.wikipedia.org/wiki/Secure_Sockets_Layer\">SSL</a>. Part of this support involves making sure authorization cookies are delivered only over SSL-encrypted <a href=\"http://en.wikipedia.org/wiki/Https\">HTTPS</a> sessions.  To accommodate this while still allowing the option of visiting the admin over plain http, 2.6 moves from a single cookie setup to a three cookie setup.</p>\n<p>In previous releases, WP set one cookie.  This cookie was delivered to all parts of your blog over both secure SSL connections and regular, unsecured connections.  It was delivered to the front page of the blog and to the admin pages.  Delivering a cookie to the front page allows WP to display inline editing and logout links for the currently logged in user.  To properly support SSL, WP needs to be able to restrict delivery of the auth cookie to only secure SSL sessions.  If WP stuck with a single cookie and delivered it only over secure sessions, that cookie would not be delivered to the front page since most people don&#8217;t visit the front page of their blogs over SSL.  Thus, WP would be unable to display info related to the current user on the front page.</p>\n<p>To remedy this, WordPress 2.6 sets separate &#8220;logged in&#8221; and &#8220;auth&#8221; cookies.  The logged in cookie is delivered for all pages of your blog over both SSL and non-SSL sessions.  The logged in cookie cannot be used to access the admin.  It merely indicates that a particular user is currently logged in. The logged in cookie cannot be used to make changes to the blog.</p>\n<p>The auth cookie, on the other hand, is delivered only for the admin area and can be used to make changes to the blog.  If you login via https, your auth cookie will be delivered only for SSL sessions.  If you login over https and later visit your admin via regular http, you will have to log in again to get a non-SSL auth cookie. By default, you have the option of visiting your admin either via http or https.  If you want to force all admin sessions to be over https, add the following to your wp-config.php:</p>\n<blockquote><p>define(&#8217;FORCE_SSL_ADMIN&#8217;, true);</p></blockquote>\n<p>This will prevent non-SSL logins to your blog. This means you will never have an auth cookie delivered in the clear.  If you want to force logins to be over SSL to prevent usernames and passwords from being sent in the clear while letting your users have the choice of using http or https when visiting the admin, add this to your wp-config.php:</p>\n<blockquote><p>define(&#8217;FORCE_SSL_LOGIN&#8217;, true);</p></blockquote>\n<p>This does not force all cookies to be delivered over SSL.  The user has a choice between the greater security of an https session and the greater speed of an http session.  If you want to remove this choice and force secure https sessions, FORCE_SSL_ADMIN is for you.</p>\n<p>With these new cookies comes new secret keys for signing them.  Recall that WordPress 2.5 <a href=\"http://boren.nu/archives/2008/04/24/cookie-security-in-wordpress-25/\">introduced SECRET_KEY</a> as a means of adding a little extra security to cookie signing.  If you intend to use the SSL support in 2.6, you will probably want to define the secret key for the secure cookie.  If you don&#8217;t intend to use SSL, you can stick with your existing SECRET_KEY.  Here&#8217;s an example of what the new secret key definitions look like:</p>\n<blockquote><p>define(&#8217;AUTH_KEY&#8217;, &#8216;put your unique phrase here&#8217;);<br />\ndefine(&#8217;SECURE_AUTH_KEY&#8217;, &#8216;put your unique phrase here&#8217;);<br />\ndefine(&#8217;LOGGED_IN_KEY&#8217;, &#8216;put your unique phrase here&#8217;);</p></blockquote>\n<p>You should change those sample phrases to unique, preferably random phrases.  Each key should have a different phrase.  Visit <a href=\"http://api.wordpress.org/secret-key/1.1/\">http://api.wordpress.org/secret-key/1.1/</a> to get a set of random keys that you can cut-and-paste into your wp-config.php.  Once again, if you don&#8217;t intend to use SSL, you can stick with the SECRET_KEY you already have.</p>\n<p>This should be mostly transparent to plugins and themes. I say mostly because there are some themes that send POST and AJAX requests to files within the themes directory.  The auth cookies are delivered only to the wp-admin and wp-content/plugins directories, so files directly loaded from wp-content/themes will not see the cookies.  Themes should send their POST and AJAX requests to the admin-post.php or admin-ajax.php files.  I&#8217;ve added a short article to the codex on <a href=\"http://codex.wordpress.org/Handling_POST_and_AJAX_Requests\">how themes and plugins should handle their POST and AJAX requests</a>.</p>\n<p>Plugins might also create links that are not properly prefixed with &#8216;https&#8217;.  Any content loaded into a secure page must come via an https link to avoid warnings from the browser about the content being only partially encrypted.  WordPress 2.6 introduces five new functions that take care of using the proper protocol when loading CSS, JS, and other files into an SSL-encrypted admin page.  They are site_url(), admin_url(), includes_ur(), plugins_url(), and content_url().  Each accepts an optional path relative to the site, admin, include, plugins, and content urls, respectively.  For example, to link to wp-content/plugins/foo/foo.php use plugins_url(&#8217;foo/foo.php&#8217;).  Plugins that load CSS and JS via relative links do not need to use these functions.  Relative links will automatically use the proper protocol.</p>\n<p>If your host supports SSL, WordPress 2.6 enables you to make use of that support in a secure manner.  Enjoy, and help us make SSL support better by <a href=\"http://codex.wordpress.org/Reporting_Bugs\">reporting any bugs you find</a>.</p>\";s:7:\"pubdate\";s:31:\"Tue, 15 Jul 2008 00:25:10 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Ryan\";}s:7:\"summary\";s:5958:\"<p><a href=\"http://wordpress.org/\">WordPress</a> 2.6 includes better support for visiting the admin over <a href=\"http://en.wikipedia.org/wiki/Secure_Sockets_Layer\">SSL</a>. Part of this support involves making sure authorization cookies are delivered only over SSL-encrypted <a href=\"http://en.wikipedia.org/wiki/Https\">HTTPS</a> sessions.  To accommodate this while still allowing the option of visiting the admin over plain http, 2.6 moves from a single cookie setup to a three cookie setup.</p>\n<p>In previous releases, WP set one cookie.  This cookie was delivered to all parts of your blog over both secure SSL connections and regular, unsecured connections.  It was delivered to the front page of the blog and to the admin pages.  Delivering a cookie to the front page allows WP to display inline editing and logout links for the currently logged in user.  To properly support SSL, WP needs to be able to restrict delivery of the auth cookie to only secure SSL sessions.  If WP stuck with a single cookie and delivered it only over secure sessions, that cookie would not be delivered to the front page since most people don&#8217;t visit the front page of their blogs over SSL.  Thus, WP would be unable to display info related to the current user on the front page.</p>\n<p>To remedy this, WordPress 2.6 sets separate &#8220;logged in&#8221; and &#8220;auth&#8221; cookies.  The logged in cookie is delivered for all pages of your blog over both SSL and non-SSL sessions.  The logged in cookie cannot be used to access the admin.  It merely indicates that a particular user is currently logged in. The logged in cookie cannot be used to make changes to the blog.</p>\n<p>The auth cookie, on the other hand, is delivered only for the admin area and can be used to make changes to the blog.  If you login via https, your auth cookie will be delivered only for SSL sessions.  If you login over https and later visit your admin via regular http, you will have to log in again to get a non-SSL auth cookie. By default, you have the option of visiting your admin either via http or https.  If you want to force all admin sessions to be over https, add the following to your wp-config.php:</p>\n<blockquote><p>define(&#8217;FORCE_SSL_ADMIN&#8217;, true);</p></blockquote>\n<p>This will prevent non-SSL logins to your blog. This means you will never have an auth cookie delivered in the clear.  If you want to force logins to be over SSL to prevent usernames and passwords from being sent in the clear while letting your users have the choice of using http or https when visiting the admin, add this to your wp-config.php:</p>\n<blockquote><p>define(&#8217;FORCE_SSL_LOGIN&#8217;, true);</p></blockquote>\n<p>This does not force all cookies to be delivered over SSL.  The user has a choice between the greater security of an https session and the greater speed of an http session.  If you want to remove this choice and force secure https sessions, FORCE_SSL_ADMIN is for you.</p>\n<p>With these new cookies comes new secret keys for signing them.  Recall that WordPress 2.5 <a href=\"http://boren.nu/archives/2008/04/24/cookie-security-in-wordpress-25/\">introduced SECRET_KEY</a> as a means of adding a little extra security to cookie signing.  If you intend to use the SSL support in 2.6, you will probably want to define the secret key for the secure cookie.  If you don&#8217;t intend to use SSL, you can stick with your existing SECRET_KEY.  Here&#8217;s an example of what the new secret key definitions look like:</p>\n<blockquote><p>define(&#8217;AUTH_KEY&#8217;, &#8216;put your unique phrase here&#8217;);<br />\ndefine(&#8217;SECURE_AUTH_KEY&#8217;, &#8216;put your unique phrase here&#8217;);<br />\ndefine(&#8217;LOGGED_IN_KEY&#8217;, &#8216;put your unique phrase here&#8217;);</p></blockquote>\n<p>You should change those sample phrases to unique, preferably random phrases.  Each key should have a different phrase.  Visit <a href=\"http://api.wordpress.org/secret-key/1.1/\">http://api.wordpress.org/secret-key/1.1/</a> to get a set of random keys that you can cut-and-paste into your wp-config.php.  Once again, if you don&#8217;t intend to use SSL, you can stick with the SECRET_KEY you already have.</p>\n<p>This should be mostly transparent to plugins and themes. I say mostly because there are some themes that send POST and AJAX requests to files within the themes directory.  The auth cookies are delivered only to the wp-admin and wp-content/plugins directories, so files directly loaded from wp-content/themes will not see the cookies.  Themes should send their POST and AJAX requests to the admin-post.php or admin-ajax.php files.  I&#8217;ve added a short article to the codex on <a href=\"http://codex.wordpress.org/Handling_POST_and_AJAX_Requests\">how themes and plugins should handle their POST and AJAX requests</a>.</p>\n<p>Plugins might also create links that are not properly prefixed with &#8216;https&#8217;.  Any content loaded into a secure page must come via an https link to avoid warnings from the browser about the content being only partially encrypted.  WordPress 2.6 introduces five new functions that take care of using the proper protocol when loading CSS, JS, and other files into an SSL-encrypted admin page.  They are site_url(), admin_url(), includes_ur(), plugins_url(), and content_url().  Each accepts an optional path relative to the site, admin, include, plugins, and content urls, respectively.  For example, to link to wp-content/plugins/foo/foo.php use plugins_url(&#8217;foo/foo.php&#8217;).  Plugins that load CSS and JS via relative links do not need to use these functions.  Relative links will automatically use the proper protocol.</p>\n<p>If your host supports SSL, WordPress 2.6 enables you to make use of that support in a secure manner.  Enjoy, and help us make SSL support better by <a href=\"http://codex.wordpress.org/Reporting_Bugs\">reporting any bugs you find</a>.</p>\";}i:32;a:7:{s:5:\"title\";s:60:\"Weblog Tools Collection: WordPress Plugin Releases for 07/14\";s:4:\"guid\";s:40:\"http://weblogtoolscollection.com/?p=3745\";s:4:\"link\";s:88:\"http://weblogtoolscollection.com/archives/2008/07/14/wordpress-plugin-releases-for-0714/\";s:11:\"description\";s:2943:\"<p><a href=\"http://blog.cagdaspolat.com/index.php/proje/version-creator/\"><strong>Version Creator</strong></a></p>\n<p>This plugin have made to put your site&#8217;s version on it. You can give your version number, version name, version note whatever you want and the release date organize automatically.</p>\n<p><a href=\"http://www.sattes-faction.de/picasaview/\"><strong>PicasaView</strong></a></p>\n<p>With picasaView you can easily view your picasaweb-albums in your WordPress blog.</p>\n<p><a href=\"http://neverblog.net/tagline-rotator-plugin-for-wordpress/\"><strong>Tagline Rotator</strong></a></p>\n<p>The Tagline Rotator plugin does pretty much what it sounds like it would do: it randomly selects a tagline (that’s the description of your blog beneath the title) from a list of user-compiled taglines, then displays it within your blog.</p>\n<p><a href=\"http://www.artonesia.org/post/wordpress-tabs-and-slides-accordion.html/\"><strong>WordPress Tabs and Slides</strong></a></p>\n<p>WP-TabsAndSlides (in post items) Plugin gives you the ability to easily add content tabs and/or content slides. The tabs emulate a multi-page structure, while the slides emulate an accordion-like structure, inside a single page.</p>\n<p><a href=\"http://www.artonesia.org/2008/07/13/rsscake-insert-rss-feeds-your-posts-pages/\"><strong>RSSCake</strong></a></p>\n<p>RSSCake is evolution from QuickRSS, a plugin to show RSS into your post and page. You can insert one or more feed into your post, RSSCake is still use SimplePie as feed parser.</p>\n<p><a href=\"http://mhough.com/wordpress/2008/header-image-rotator-plugin/\"><strong>Header Image Rotator</strong></a></p>\n<p>Displays a new header image in your blog based on different time variables. Simply create a folder called wp-contents/header-images/ and add as many pictures as your heart desires. Supported time intervals are per minute, half hour, hourly, daily, and weekly.</p>\n<p><a href=\"http://www.geekyramblings.org/plugins/ad-wrap/\"><strong>Context Ad Wrapper</strong></a></p>\n<p>This plugin will mark the key parts of a blog post so that context based ad services can identify the post content and comments for the best ad matching (thus avoiding the static content that is irrelevant for context ad matching).</p>\n<p><a href=\"http://www.clker.com/blog/category/plugins-extensions/wordpress-plugins-extensions/\"><strong>Ciker.com Clipart</strong></a></p>\n<p>Through a user friendly interface, search clker.com clip art library, select and add any image to your posts. No upload required. The plugin is very easy to use.</p>\n<p><a href=\"http://www.geldmacher.net/index.php/superlinks/\"><strong>SuperLinks</strong></a></p>\n<p>SuperLinks replaces the standard WordPress 2.5 Links widget with a more customizable one. With SuperLinks you can add as many Links widgets as you want, and set the display options for each widget. For instance, you can set which Links category is displayed on each block.</p>\";s:7:\"pubdate\";s:31:\"Mon, 14 Jul 2008 19:20:31 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Ajay\";}s:7:\"summary\";s:2943:\"<p><a href=\"http://blog.cagdaspolat.com/index.php/proje/version-creator/\"><strong>Version Creator</strong></a></p>\n<p>This plugin have made to put your site&#8217;s version on it. You can give your version number, version name, version note whatever you want and the release date organize automatically.</p>\n<p><a href=\"http://www.sattes-faction.de/picasaview/\"><strong>PicasaView</strong></a></p>\n<p>With picasaView you can easily view your picasaweb-albums in your WordPress blog.</p>\n<p><a href=\"http://neverblog.net/tagline-rotator-plugin-for-wordpress/\"><strong>Tagline Rotator</strong></a></p>\n<p>The Tagline Rotator plugin does pretty much what it sounds like it would do: it randomly selects a tagline (that’s the description of your blog beneath the title) from a list of user-compiled taglines, then displays it within your blog.</p>\n<p><a href=\"http://www.artonesia.org/post/wordpress-tabs-and-slides-accordion.html/\"><strong>WordPress Tabs and Slides</strong></a></p>\n<p>WP-TabsAndSlides (in post items) Plugin gives you the ability to easily add content tabs and/or content slides. The tabs emulate a multi-page structure, while the slides emulate an accordion-like structure, inside a single page.</p>\n<p><a href=\"http://www.artonesia.org/2008/07/13/rsscake-insert-rss-feeds-your-posts-pages/\"><strong>RSSCake</strong></a></p>\n<p>RSSCake is evolution from QuickRSS, a plugin to show RSS into your post and page. You can insert one or more feed into your post, RSSCake is still use SimplePie as feed parser.</p>\n<p><a href=\"http://mhough.com/wordpress/2008/header-image-rotator-plugin/\"><strong>Header Image Rotator</strong></a></p>\n<p>Displays a new header image in your blog based on different time variables. Simply create a folder called wp-contents/header-images/ and add as many pictures as your heart desires. Supported time intervals are per minute, half hour, hourly, daily, and weekly.</p>\n<p><a href=\"http://www.geekyramblings.org/plugins/ad-wrap/\"><strong>Context Ad Wrapper</strong></a></p>\n<p>This plugin will mark the key parts of a blog post so that context based ad services can identify the post content and comments for the best ad matching (thus avoiding the static content that is irrelevant for context ad matching).</p>\n<p><a href=\"http://www.clker.com/blog/category/plugins-extensions/wordpress-plugins-extensions/\"><strong>Ciker.com Clipart</strong></a></p>\n<p>Through a user friendly interface, search clker.com clip art library, select and add any image to your posts. No upload required. The plugin is very easy to use.</p>\n<p><a href=\"http://www.geldmacher.net/index.php/superlinks/\"><strong>SuperLinks</strong></a></p>\n<p>SuperLinks replaces the standard WordPress 2.5 Links widget with a more customizable one. With SuperLinks you can add as many Links widgets as you want, and set the display options for each widget. For instance, you can set which Links category is displayed on each block.</p>\";}i:33;a:7:{s:5:\"title\";s:76:\"Weblog Tools Collection: Evolution of WordPress: B2/Cafelog to WordPress 1.0\";s:4:\"guid\";s:40:\"http://weblogtoolscollection.com/?p=3721\";s:4:\"link\";s:102:\"http://weblogtoolscollection.com/archives/2008/07/14/evolution-of-wordpress-b2cafelog-to-wordpress-10/\";s:11:\"description\";s:4621:\"<p>A few days ago we had told you <a href=\"http://weblogtoolscollection.com/archives/2008/06/30/what-you-need-to-know-about-wordpress-26/\" target=\"_blank\">what you should know about WordPress 2.6</a>. The post described new features that will be introduced shortly in WordPress 2.6. Though there are several new features that you may like in this new version, there might be many that have gone unnoticed that were introduced in the earlier versions of WordPress. To quell the anticipation that users might have for the latest version, we wanted to write a series of posts that will cover WordPress from its infancy to WordPress 2.5 (the latest major version) that many of you use.</p>\n<p>The WordPress team has been naming their major releases after popular Jazz legends and we will take a look at code names for the past releases.</p>\n<h3>B2 / Cafelog</h3>\n<p>WordPress is the official successor of <a href=\"http://cafelog.com/\" target=\"_blank\">B2/Cafelog</a> which is a blogging platform created in early 2001 by <a href=\"http://intraordinary.com/\" target=\"_blank\">Michel Valdrighi</a> using PHP and MySQL. <a href=\"http://ma.tt/\" target=\"_blank\">Matt Mullenweg</a> and <a href=\"http://zed1.com/journalized/\" target=\"_blank\">Mike Little</a> took over the development to come up with (fork?) the WordPress platform as we officially know it now in early 2003, giving birth to one of the best blogging platforms ever developed.</p>\n<h3>WordPress 0.7 – 0.71</h3>\n<p>The first version to come out under the new name was WordPress 0.7 which was released in May 2003, marking several changes over the B2/Cafelog software. <a href=\"http://wordpress.org/development/2003/05/wordpress-now-available/\" target=\"_blank\">WordPress 0.7</a> introduced several new features such as allowing users to add links to their blogrolls,  new administration interfaces, manual excerpts, default templates and more.</p>\n<p><a href=\"http://wordpress.org/development/2003/06/wordpress-071-now-available/\" target=\"_blank\">WordPress 0.71</a> was just a minor revision but it brought incorporated many changes that form an integral part of WordPress as we know it today. WordPress 0.71 &#8220;Gold” introduced cool new features such as post status where users could mark the post state as draft, publish or private. A blog owner would also have greater flexibility over the comments by disabling them on a per-post basis. 0.71 also combined trackbacks, pingbacks and user written comments into a single category. There were several other changes including better administration, security fixes and more.</p>\n<p><a href=\"http://wordpress.org/development/2003/10/072-final-version-available/\">WordPress 0.72</a> added password protected posts, new xmlrpc APIs, a Blogger import and many other improvements. This version also included a new theme from Dave Shea.</p>\n<h3>WordPress 1.0</h3>\n<p>There were several minor versions in between WordPress 0.71 and WordPress 1.2 beside WordPress 1.0, which included <a href=\"http://wordpress.org/development/2004/01/101-miles-release-available/\" target=\"_blank\">WordPress 1.0.1</a> code named “Miles”. This was followed by <a href=\"http://codex.wordpress.org/Changelog/1.0.2\" target=\"_blank\">WordPress 1.0.2</a> code named “Blakey” which was a smaller release based on bug fixes.</p>\n<p>The much anticipated <a href=\"http://wordpress.org/development/2004/01/wordpress-10/\" target=\"_blank\">WordPress 1.0</a> was finally released on January 3rd, 2004. This version included several new exciting features (as usual). The most noticeable feature was the introduction of better search engine friendly permalinks which allowed users to structure their URLs to get better search engine visibility using mod_rewrite. The version also lifted the limitation of allowing only one category per post. This meant that users could assign several categories to a single post.</p>\n<p>For all those who were worried about comment spam, this version included comment moderation where blog authors could moderate comments, before they would be viewable on the blog. Users could also edit pages or comments with the newly provided links. WordPress 1.0 also included support for ATOM based feeds. 1.0 was a very popular release.</p>\n<p>There were several other new releases which we will take a look in other parts of this series. In the mean time, we would love to hear from users who had used these versions. How did the earlier versions of WordPress change your outlook towards blogging? Did those earlier versions make you a fan?</p>\n<p>[EDIT] Fixed minor error in versions and added 0.72. Thanks Carson and Geof</p>\";s:7:\"pubdate\";s:31:\"Mon, 14 Jul 2008 12:00:04 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:12:\"Keith Dsouza\";}s:7:\"summary\";s:4621:\"<p>A few days ago we had told you <a href=\"http://weblogtoolscollection.com/archives/2008/06/30/what-you-need-to-know-about-wordpress-26/\" target=\"_blank\">what you should know about WordPress 2.6</a>. The post described new features that will be introduced shortly in WordPress 2.6. Though there are several new features that you may like in this new version, there might be many that have gone unnoticed that were introduced in the earlier versions of WordPress. To quell the anticipation that users might have for the latest version, we wanted to write a series of posts that will cover WordPress from its infancy to WordPress 2.5 (the latest major version) that many of you use.</p>\n<p>The WordPress team has been naming their major releases after popular Jazz legends and we will take a look at code names for the past releases.</p>\n<h3>B2 / Cafelog</h3>\n<p>WordPress is the official successor of <a href=\"http://cafelog.com/\" target=\"_blank\">B2/Cafelog</a> which is a blogging platform created in early 2001 by <a href=\"http://intraordinary.com/\" target=\"_blank\">Michel Valdrighi</a> using PHP and MySQL. <a href=\"http://ma.tt/\" target=\"_blank\">Matt Mullenweg</a> and <a href=\"http://zed1.com/journalized/\" target=\"_blank\">Mike Little</a> took over the development to come up with (fork?) the WordPress platform as we officially know it now in early 2003, giving birth to one of the best blogging platforms ever developed.</p>\n<h3>WordPress 0.7 – 0.71</h3>\n<p>The first version to come out under the new name was WordPress 0.7 which was released in May 2003, marking several changes over the B2/Cafelog software. <a href=\"http://wordpress.org/development/2003/05/wordpress-now-available/\" target=\"_blank\">WordPress 0.7</a> introduced several new features such as allowing users to add links to their blogrolls,  new administration interfaces, manual excerpts, default templates and more.</p>\n<p><a href=\"http://wordpress.org/development/2003/06/wordpress-071-now-available/\" target=\"_blank\">WordPress 0.71</a> was just a minor revision but it brought incorporated many changes that form an integral part of WordPress as we know it today. WordPress 0.71 &#8220;Gold” introduced cool new features such as post status where users could mark the post state as draft, publish or private. A blog owner would also have greater flexibility over the comments by disabling them on a per-post basis. 0.71 also combined trackbacks, pingbacks and user written comments into a single category. There were several other changes including better administration, security fixes and more.</p>\n<p><a href=\"http://wordpress.org/development/2003/10/072-final-version-available/\">WordPress 0.72</a> added password protected posts, new xmlrpc APIs, a Blogger import and many other improvements. This version also included a new theme from Dave Shea.</p>\n<h3>WordPress 1.0</h3>\n<p>There were several minor versions in between WordPress 0.71 and WordPress 1.2 beside WordPress 1.0, which included <a href=\"http://wordpress.org/development/2004/01/101-miles-release-available/\" target=\"_blank\">WordPress 1.0.1</a> code named “Miles”. This was followed by <a href=\"http://codex.wordpress.org/Changelog/1.0.2\" target=\"_blank\">WordPress 1.0.2</a> code named “Blakey” which was a smaller release based on bug fixes.</p>\n<p>The much anticipated <a href=\"http://wordpress.org/development/2004/01/wordpress-10/\" target=\"_blank\">WordPress 1.0</a> was finally released on January 3rd, 2004. This version included several new exciting features (as usual). The most noticeable feature was the introduction of better search engine friendly permalinks which allowed users to structure their URLs to get better search engine visibility using mod_rewrite. The version also lifted the limitation of allowing only one category per post. This meant that users could assign several categories to a single post.</p>\n<p>For all those who were worried about comment spam, this version included comment moderation where blog authors could moderate comments, before they would be viewable on the blog. Users could also edit pages or comments with the newly provided links. WordPress 1.0 also included support for ATOM based feeds. 1.0 was a very popular release.</p>\n<p>There were several other new releases which we will take a look in other parts of this series. In the mean time, we would love to hear from users who had used these versions. How did the earlier versions of WordPress change your outlook towards blogging? Did those earlier versions make you a fan?</p>\n<p>[EDIT] Fixed minor error in versions and added 0.72. Thanks Carson and Geof</p>\";}i:34;a:7:{s:5:\"title\";s:49:\"Weblog Tools Collection: WordCast Mugshot Contest\";s:4:\"guid\";s:40:\"http://weblogtoolscollection.com/?p=3744\";s:4:\"link\";s:78:\"http://weblogtoolscollection.com/archives/2008/07/13/wordcast-mugshot-contest/\";s:11:\"description\";s:1907:\"<p>The guys and gal over at the WordCast Podcast is currently holding a <a href=\"http://bitwire.tv/contests/\" target=\"_blank\">Mugshot contest</a>. The contest is all about taking a photo of your favorite mug.</p>\n<p>Check out this awesome line up prizes:</p>\n<p><strong>4th Place:</strong> WordPress mug and WordPress T-shirt</p>\n<p><strong>3rd Place:</strong> WordPress mug, WordPress T-shirt and <a href=\"http://www.lijit.com/\">Lijit</a> T-Shirt</p>\n<p><strong>2nd Place:</strong> WordPress mug, WordPress T-shirt, <a href=\"http://www.lijit.com/\">Lijit</a> T-Shirt, signed copy of <a href=\"http://lorelle.wordpress.com/2007/05/18/announcement-blogging-tips-book-by-lorelle-vanfossen/\"><em>Blogging Tips: What bloggers won’t tell you about blogging</em></a>, and one single-user <a href=\"http://www.revolutiontheme.com/\">Revolution theme</a> license of the winners’ choice</p>\n<p><strong>1st Place:</strong> WordPress mug, WordPress T-shirt, <a href=\"http://www.lijit.com/\">Lijit</a> T-Shirt, signed copy of <a href=\"http://lorelle.wordpress.com/2007/05/18/announcement-blogging-tips-book-by-lorelle-vanfossen/\"><em>Blogging Tips: What bloggers won’t tell you about blogging</em></a>, one <a title=\"http://www.wpelements.com/demos/tvelements/\" href=\"http://www.wpelements.com/demos/tvelements/\" target=\"_blank\">TV.Elements</a> theme license, one single-user <a href=\"http://www.revolutiontheme.com/\">Revolution theme</a> license of the winners’ choice, a free copy of <a href=\"http://successful-blog.com/\">The Secret to Writing a Successful and Outstanding Blog</a>, and an (optional) free 30 minute consultation with Liz Strauss.</p>\n<p>The contest is still going on with no clear indication as to when the final images will be accepted. Please check out <a href=\"http://bitwire.tv/contests/\" target=\"_blank\">their contest page</a> to discover the rules of the contest as well as how to enter.</p>\";s:7:\"pubdate\";s:31:\"Mon, 14 Jul 2008 00:13:24 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:13:\"Jeff Chandler\";}s:7:\"summary\";s:1907:\"<p>The guys and gal over at the WordCast Podcast is currently holding a <a href=\"http://bitwire.tv/contests/\" target=\"_blank\">Mugshot contest</a>. The contest is all about taking a photo of your favorite mug.</p>\n<p>Check out this awesome line up prizes:</p>\n<p><strong>4th Place:</strong> WordPress mug and WordPress T-shirt</p>\n<p><strong>3rd Place:</strong> WordPress mug, WordPress T-shirt and <a href=\"http://www.lijit.com/\">Lijit</a> T-Shirt</p>\n<p><strong>2nd Place:</strong> WordPress mug, WordPress T-shirt, <a href=\"http://www.lijit.com/\">Lijit</a> T-Shirt, signed copy of <a href=\"http://lorelle.wordpress.com/2007/05/18/announcement-blogging-tips-book-by-lorelle-vanfossen/\"><em>Blogging Tips: What bloggers won’t tell you about blogging</em></a>, and one single-user <a href=\"http://www.revolutiontheme.com/\">Revolution theme</a> license of the winners’ choice</p>\n<p><strong>1st Place:</strong> WordPress mug, WordPress T-shirt, <a href=\"http://www.lijit.com/\">Lijit</a> T-Shirt, signed copy of <a href=\"http://lorelle.wordpress.com/2007/05/18/announcement-blogging-tips-book-by-lorelle-vanfossen/\"><em>Blogging Tips: What bloggers won’t tell you about blogging</em></a>, one <a title=\"http://www.wpelements.com/demos/tvelements/\" href=\"http://www.wpelements.com/demos/tvelements/\" target=\"_blank\">TV.Elements</a> theme license, one single-user <a href=\"http://www.revolutiontheme.com/\">Revolution theme</a> license of the winners’ choice, a free copy of <a href=\"http://successful-blog.com/\">The Secret to Writing a Successful and Outstanding Blog</a>, and an (optional) free 30 minute consultation with Liz Strauss.</p>\n<p>The contest is still going on with no clear indication as to when the final images will be accepted. Please check out <a href=\"http://bitwire.tv/contests/\" target=\"_blank\">their contest page</a> to discover the rules of the contest as well as how to enter.</p>\";}i:35;a:7:{s:5:\"title\";s:28:\"Matt: Transition to Electric\";s:4:\"guid\";s:44:\"http://ma.tt/2008/07/transition-to-electric/\";s:4:\"link\";s:44:\"http://ma.tt/2008/07/transition-to-electric/\";s:11:\"description\";s:162:\"<p><a href=\"http://www.american.com/archive/2008/july-august-magazine-contents/our-electric-future\">Our Electric Future</a>?, by Andy Grove formerly of Intel.</p>\";s:7:\"pubdate\";s:31:\"Sun, 13 Jul 2008 15:46:08 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Matt\";}s:7:\"summary\";s:162:\"<p><a href=\"http://www.american.com/archive/2008/july-august-magazine-contents/our-electric-future\">Our Electric Future</a>?, by Andy Grove formerly of Intel.</p>\";}i:36;a:7:{s:5:\"title\";s:45:\"Ryan Boren: WordPress 2.6 Release Candidate 1\";s:4:\"guid\";s:23:\"http://boren.nu/?p=1573\";s:4:\"link\";s:69:\"http://boren.nu/archives/2008/07/12/wordpress-26-release-candidate-1/\";s:11:\"description\";s:722:\"<p>WordPress <a href=\"http://wordpress.org/wordpress-2.6-RC1.zip\">2.6 Release Candidate 1</a> is now available. We think this is ready for release on Monday.  Try out RC1 and tell us if you agree.  New since Beta 3:</p>\n<ul>\n<li>Media uploader and gallery improvements</li>\n<li>Image caption and image editing fixes</li>\n<li>Press This fixes</li>\n<li>Ability to toggle between the flash uploader and a regular browser uploader</li>\n<li>Notification bubble on the Plugins menu when plugin updates are available</li>\n</ul>\n<p>See the <a href=\"http://trac.wordpress.org/log/trunk?rev=8324&amp;stop_rev=8299\">full list of changes since Beta 3</a>.</p>\n<p><a href=\"http://wordpress.org/wordpress-2.6-RC1.zip\">Get RC1</a>.</p>\";s:7:\"pubdate\";s:31:\"Sun, 13 Jul 2008 06:00:09 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Ryan\";}s:7:\"summary\";s:722:\"<p>WordPress <a href=\"http://wordpress.org/wordpress-2.6-RC1.zip\">2.6 Release Candidate 1</a> is now available. We think this is ready for release on Monday.  Try out RC1 and tell us if you agree.  New since Beta 3:</p>\n<ul>\n<li>Media uploader and gallery improvements</li>\n<li>Image caption and image editing fixes</li>\n<li>Press This fixes</li>\n<li>Ability to toggle between the flash uploader and a regular browser uploader</li>\n<li>Notification bubble on the Plugins menu when plugin updates are available</li>\n</ul>\n<p>See the <a href=\"http://trac.wordpress.org/log/trunk?rev=8324&amp;stop_rev=8299\">full list of changes since Beta 3</a>.</p>\n<p><a href=\"http://wordpress.org/wordpress-2.6-RC1.zip\">Get RC1</a>.</p>\";}i:37;a:7:{s:5:\"title\";s:59:\"Weblog Tools Collection: WordPress Theme Releases for 07/12\";s:4:\"guid\";s:40:\"http://weblogtoolscollection.com/?p=3743\";s:4:\"link\";s:87:\"http://weblogtoolscollection.com/archives/2008/07/12/wordpress-theme-releases-for-0712/\";s:11:\"description\";s:4679:\"<p><a href=\"http://easternwest.com/helloblogger-wordpress-theme/\"><strong>HelloBlogger</strong></a></p>\n<p><a href=\"http://easternwest.com/helloblogger-wordpress-theme/\"><img alt=\"Hello Blogger\" src=\"http://weblogtoolscollection.com/b2-img/2008/07/hellobloggerpreview.gif\" height=\"150\" width=\"200\" /></a></p>\n<p>A simple two column blue and white WordPress theme</p>\n<p><a href=\"http://3oneseven.com/12/typography-wordpress-theme-2/\"><strong>Typography</strong></a></p>\n<p><a href=\"http://wp.3oneseven.com/index.php?wptheme=typo\"><img alt=\"typography\" src=\"http://weblogtoolscollection.com/b2-img/2008/07/typography.jpg\" height=\"125\" width=\"200\" /></a></p>\n<p>A fixed two column outfit and some modern typographic styles. The front page shows the latest post in excerpts with an article image pulled via the custom fields, while the sidebar features a custom built news slider.</p>\n<p><a href=\"http://3oneseven.com/12/bullit-wordpress-theme/\"><strong>Bullit</strong></a></p>\n<p><a href=\"http://wp.3oneseven.com/index.php?wptheme=bullit\"><img alt=\"bullit\" src=\"http://weblogtoolscollection.com/b2-img/2008/07/bullit.jpg\" height=\"126\" width=\"200\" /></a></p>\n<p>Bullit WordPress theme with a fixed two column outfit and some stylish black layout. The front page shows the latest post in excerpts with an article image pulled via the custom fields, while the sidebar features a special news slider.</p>\n<p><a href=\"http://www.ifgogo.com/116/the-tes-wordpress-theme/\"><strong>The Enhancing Spring</strong></a></p>\n<p><a href=\"http://www.ifgogo.com/116/the-tes-wordpress-theme/\"><img alt=\"The Enhancing Spring\" src=\"http://weblogtoolscollection.com/b2-img/2008/07/enhancingspring.png\" height=\"139\" width=\"200\" /></a></p>\n<p>The Enhancing Spring (TES) is a 2-column theme in green style. It&#8217;s autofit to your screen width and looks very clean, which makes your posts easy to read. The XHTML and CSS are well separated so it&#8217;s very easy to customize for your own needs.</p>\n<p><a href=\"http://dinolatoga.com/2008/07/04/una-wordpress-theme/\"><strong>Una</strong></a></p>\n<p><a href=\"http://dinolatoga.com/2008/07/04/una-wordpress-theme/\"><img alt=\"Una\" src=\"http://weblogtoolscollection.com/b2-img/2008/07/una.jpg\" height=\"125\" width=\"200\" /></a></p>\n<p>Una is a clean, minimalistic, steady and excellent theme. It has 2 columns divided with the guide of the divine proportion. The front page shows the latest post with it’s accompanying large graphic image which helps attract readers more than the usual large text titles. Below the latest post is a list of the 3 other recent posts with each post accompanied by a nice thumbnail image. Each section title is supported by a nice subtitle. The comments and trackbacks are organized to produce a clean and organized look.</p>\n<p><a href=\"http://www.junglejar.com/templates-in-a-jar/\"><strong>Introspection</strong></a></p>\n<p><a href=\"http://www.junglejar.com/templates-in-a-jar/\"><img alt=\"Introspection\" src=\"http://weblogtoolscollection.com/b2-img/2008/07/introspection.jpg\" height=\"125\" width=\"193\" /></a></p>\n<p>Introspection is a two column, widget ready ad-system ready</p>\n<p><a href=\"http://www.thematology.com/free-wordpress-theme-apollo/\"><strong>Apollo</strong></a></p>\n<p><a href=\"http://apollo.thematology.com/\"><img alt=\"Apollo\" src=\"http://weblogtoolscollection.com/b2-img/2008/07/apollo.jpg\" height=\"125\" width=\"191\" /></a></p>\n<p>Apollo is a free WordPress theme with a few added user options. You can customize most of the display: 1 or 2 sidebars, left or right layout, fonts, rss feeds, gravatars, show pingbacks etc. The design - fairly bland and shouldn&#8217;t distract from the content of your blog.</p>\n<p><a href=\"http://www.jauhari.net/themes/hamasaki\"><strong>Hamasaki</strong></a></p>\n<p><a href=\"http://demo.jauhari.net/?wptheme=Hamasaki\"><img alt=\"Hamasaki\" src=\"http://weblogtoolscollection.com/b2-img/2008/07/hamasaki.jpg\" height=\"125\" width=\"184\" /></a></p>\n<p>Hamasaki is a two column, fixed width, widget and Gravatar ready WordPress theme.</p>\n<p><a href=\"http://redstar.jayhafling.com/\"><strong>Red Star</strong></a></p>\n<p><a href=\"http://redstar.jayhafling.com/\"><img alt=\"RedStar\" src=\"http://weblogtoolscollection.com/b2-img/2008/07/redstar.jpg\" height=\"124\" width=\"200\" /></a></p>\n<p>Red Star is a simple, two column WordPress theme with a big header.</p>\n<p><a href=\"http://greenblood.jayhafling.com/\"><strong>Green Blood</strong></a></p>\n<p><a href=\"http://greenblood.jayhafling.com/\"><img alt=\"GreenBlood\" src=\"http://weblogtoolscollection.com/b2-img/2008/07/greenblood.jpg\" height=\"125\" width=\"196\" /></a></p>\n<p>Green Blood is a grey and green two column WordPress theme.</p>\";s:7:\"pubdate\";s:31:\"Sat, 12 Jul 2008 19:49:25 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Ajay\";}s:7:\"summary\";s:4679:\"<p><a href=\"http://easternwest.com/helloblogger-wordpress-theme/\"><strong>HelloBlogger</strong></a></p>\n<p><a href=\"http://easternwest.com/helloblogger-wordpress-theme/\"><img alt=\"Hello Blogger\" src=\"http://weblogtoolscollection.com/b2-img/2008/07/hellobloggerpreview.gif\" height=\"150\" width=\"200\" /></a></p>\n<p>A simple two column blue and white WordPress theme</p>\n<p><a href=\"http://3oneseven.com/12/typography-wordpress-theme-2/\"><strong>Typography</strong></a></p>\n<p><a href=\"http://wp.3oneseven.com/index.php?wptheme=typo\"><img alt=\"typography\" src=\"http://weblogtoolscollection.com/b2-img/2008/07/typography.jpg\" height=\"125\" width=\"200\" /></a></p>\n<p>A fixed two column outfit and some modern typographic styles. The front page shows the latest post in excerpts with an article image pulled via the custom fields, while the sidebar features a custom built news slider.</p>\n<p><a href=\"http://3oneseven.com/12/bullit-wordpress-theme/\"><strong>Bullit</strong></a></p>\n<p><a href=\"http://wp.3oneseven.com/index.php?wptheme=bullit\"><img alt=\"bullit\" src=\"http://weblogtoolscollection.com/b2-img/2008/07/bullit.jpg\" height=\"126\" width=\"200\" /></a></p>\n<p>Bullit WordPress theme with a fixed two column outfit and some stylish black layout. The front page shows the latest post in excerpts with an article image pulled via the custom fields, while the sidebar features a special news slider.</p>\n<p><a href=\"http://www.ifgogo.com/116/the-tes-wordpress-theme/\"><strong>The Enhancing Spring</strong></a></p>\n<p><a href=\"http://www.ifgogo.com/116/the-tes-wordpress-theme/\"><img alt=\"The Enhancing Spring\" src=\"http://weblogtoolscollection.com/b2-img/2008/07/enhancingspring.png\" height=\"139\" width=\"200\" /></a></p>\n<p>The Enhancing Spring (TES) is a 2-column theme in green style. It&#8217;s autofit to your screen width and looks very clean, which makes your posts easy to read. The XHTML and CSS are well separated so it&#8217;s very easy to customize for your own needs.</p>\n<p><a href=\"http://dinolatoga.com/2008/07/04/una-wordpress-theme/\"><strong>Una</strong></a></p>\n<p><a href=\"http://dinolatoga.com/2008/07/04/una-wordpress-theme/\"><img alt=\"Una\" src=\"http://weblogtoolscollection.com/b2-img/2008/07/una.jpg\" height=\"125\" width=\"200\" /></a></p>\n<p>Una is a clean, minimalistic, steady and excellent theme. It has 2 columns divided with the guide of the divine proportion. The front page shows the latest post with it’s accompanying large graphic image which helps attract readers more than the usual large text titles. Below the latest post is a list of the 3 other recent posts with each post accompanied by a nice thumbnail image. Each section title is supported by a nice subtitle. The comments and trackbacks are organized to produce a clean and organized look.</p>\n<p><a href=\"http://www.junglejar.com/templates-in-a-jar/\"><strong>Introspection</strong></a></p>\n<p><a href=\"http://www.junglejar.com/templates-in-a-jar/\"><img alt=\"Introspection\" src=\"http://weblogtoolscollection.com/b2-img/2008/07/introspection.jpg\" height=\"125\" width=\"193\" /></a></p>\n<p>Introspection is a two column, widget ready ad-system ready</p>\n<p><a href=\"http://www.thematology.com/free-wordpress-theme-apollo/\"><strong>Apollo</strong></a></p>\n<p><a href=\"http://apollo.thematology.com/\"><img alt=\"Apollo\" src=\"http://weblogtoolscollection.com/b2-img/2008/07/apollo.jpg\" height=\"125\" width=\"191\" /></a></p>\n<p>Apollo is a free WordPress theme with a few added user options. You can customize most of the display: 1 or 2 sidebars, left or right layout, fonts, rss feeds, gravatars, show pingbacks etc. The design - fairly bland and shouldn&#8217;t distract from the content of your blog.</p>\n<p><a href=\"http://www.jauhari.net/themes/hamasaki\"><strong>Hamasaki</strong></a></p>\n<p><a href=\"http://demo.jauhari.net/?wptheme=Hamasaki\"><img alt=\"Hamasaki\" src=\"http://weblogtoolscollection.com/b2-img/2008/07/hamasaki.jpg\" height=\"125\" width=\"184\" /></a></p>\n<p>Hamasaki is a two column, fixed width, widget and Gravatar ready WordPress theme.</p>\n<p><a href=\"http://redstar.jayhafling.com/\"><strong>Red Star</strong></a></p>\n<p><a href=\"http://redstar.jayhafling.com/\"><img alt=\"RedStar\" src=\"http://weblogtoolscollection.com/b2-img/2008/07/redstar.jpg\" height=\"124\" width=\"200\" /></a></p>\n<p>Red Star is a simple, two column WordPress theme with a big header.</p>\n<p><a href=\"http://greenblood.jayhafling.com/\"><strong>Green Blood</strong></a></p>\n<p><a href=\"http://greenblood.jayhafling.com/\"><img alt=\"GreenBlood\" src=\"http://weblogtoolscollection.com/b2-img/2008/07/greenblood.jpg\" height=\"125\" width=\"196\" /></a></p>\n<p>Green Blood is a grey and green two column WordPress theme.</p>\";}i:38;a:7:{s:5:\"title\";s:55:\"Weblog Tools Collection: How many Queries are too many?\";s:4:\"guid\";s:40:\"http://weblogtoolscollection.com/?p=3731\";s:4:\"link\";s:83:\"http://weblogtoolscollection.com/archives/2008/07/12/how-many-queries-are-too-many/\";s:11:\"description\";s:2268:\"<p>I have been asked this question quite a few times and I never have a perfect answer. It is obviously an important question to ask but it can be answered in many different ways based on preferences, need for plugins, optimization techniques used and a variety of other factors.</p>\n<p>Weblog Tools Collection uses a lot of plugins and is very query heavy but the in spite of that, the front page uses 59 queries to generate itself. I think the default (on a vanilla WordPress install on the default theme) is 27 or something of that nature. The larger the number of queries, the slower the page is going to load and the more load you are going to put on your MySql server. All of the above is true if you do <em>not</em> use inline or regenerative caching mechanisms. The caveat on this blog is that its plugins and its MySql server are highly optimized (via inline caching mechanisms) to reduce load.</p>\n<p>Larger number of queries on a WordPress blog are probably caused by plugins that have been installed. Plugin authors can have non-optimized and useless queries that either take a long time to execute or need a large(r) number of queries to acheive a simple(r) result. I suspect that one could follow the 80-20 rule with 80% of the queries on your blog being generated by 20% of the plugins. If you can identify the top hitters and either optimize or replace them, you will have a happier blog and a happier MySql server.</p>\n<p>It is also important to remember that the number of queries might not be the <em>only</em> straw that is breaking the camel&#8217;s back. SQL queries can be poorly constructed and can put a tremendous drain on resources. I remember a certain recent comments plugin that made queries which scanned entire tables before producing a result. If you are concerned about the speed of you blog or the number of queries, start disabling plugins. You might be pleasantly surprised to find that a few plugins might be causing most of your headaches. Once you identify the suspect plugins, you can then either find replacements that are more oprtimized or find other ways of obtaining the same result.</p>\n<p>How many queries does your font page generate? If you find efficiencies by disabling plugins, please tell us about the results.</p>\";s:7:\"pubdate\";s:31:\"Sat, 12 Jul 2008 14:05:56 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:10:\"Mark Ghosh\";}s:7:\"summary\";s:2268:\"<p>I have been asked this question quite a few times and I never have a perfect answer. It is obviously an important question to ask but it can be answered in many different ways based on preferences, need for plugins, optimization techniques used and a variety of other factors.</p>\n<p>Weblog Tools Collection uses a lot of plugins and is very query heavy but the in spite of that, the front page uses 59 queries to generate itself. I think the default (on a vanilla WordPress install on the default theme) is 27 or something of that nature. The larger the number of queries, the slower the page is going to load and the more load you are going to put on your MySql server. All of the above is true if you do <em>not</em> use inline or regenerative caching mechanisms. The caveat on this blog is that its plugins and its MySql server are highly optimized (via inline caching mechanisms) to reduce load.</p>\n<p>Larger number of queries on a WordPress blog are probably caused by plugins that have been installed. Plugin authors can have non-optimized and useless queries that either take a long time to execute or need a large(r) number of queries to acheive a simple(r) result. I suspect that one could follow the 80-20 rule with 80% of the queries on your blog being generated by 20% of the plugins. If you can identify the top hitters and either optimize or replace them, you will have a happier blog and a happier MySql server.</p>\n<p>It is also important to remember that the number of queries might not be the <em>only</em> straw that is breaking the camel&#8217;s back. SQL queries can be poorly constructed and can put a tremendous drain on resources. I remember a certain recent comments plugin that made queries which scanned entire tables before producing a result. If you are concerned about the speed of you blog or the number of queries, start disabling plugins. You might be pleasantly surprised to find that a few plugins might be causing most of your headaches. Once you identify the suspect plugins, you can then either find replacements that are more oprtimized or find other ways of obtaining the same result.</p>\n<p>How many queries does your font page generate? If you find efficiencies by disabling plugins, please tell us about the results.</p>\";}i:39;a:7:{s:5:\"title\";s:60:\"Weblog Tools Collection: WordPress Plugin Releases for 07/11\";s:4:\"guid\";s:40:\"http://weblogtoolscollection.com/?p=3732\";s:4:\"link\";s:88:\"http://weblogtoolscollection.com/archives/2008/07/11/wordpress-plugin-releases-for-0711/\";s:11:\"description\";s:1076:\"<p><a href=\"http://blog.avirtualhome.com/wordpress-plugins/avh-extended-categories/\"><strong>AVH Extended Categories</strong></a></p>\n<p>A replacement of the category widget to allow for greater customization of the category widget.</p>\n<p><a href=\"http://blog.avirtualhome.com/wordpress-plugins/avh-amazon/\"><strong>AVH Amazon</strong></a></p>\n<p>The avh-amazon plugin gives you the ability to add a widget which will display a random item from your Amazon wish list, baby registry and/or wedding registry.</p>\n<p><a href=\"http://perassi.org/p/dilw/\"><strong>dilw</strong></a></p>\n<p>It lets you see displayed the Daily Dilbert. It uses the DilbertDailyStrip RSS feed.</p>\n<p><a href=\"http://www.vincentprat.info/dev/wordpress-plugins/enhanced-recent-posts/\"><strong>Enhanced Recent Posts</strong></a></p>\n<p>Enhanced Recent Posts is a widget that comes as a replacement to the built-in widget. As the first enhancement, you can choose if you want to show posts from all categories, from some categories in particular or from all categories but some (exclude categories).</p>\";s:7:\"pubdate\";s:31:\"Fri, 11 Jul 2008 20:11:02 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Ajay\";}s:7:\"summary\";s:1076:\"<p><a href=\"http://blog.avirtualhome.com/wordpress-plugins/avh-extended-categories/\"><strong>AVH Extended Categories</strong></a></p>\n<p>A replacement of the category widget to allow for greater customization of the category widget.</p>\n<p><a href=\"http://blog.avirtualhome.com/wordpress-plugins/avh-amazon/\"><strong>AVH Amazon</strong></a></p>\n<p>The avh-amazon plugin gives you the ability to add a widget which will display a random item from your Amazon wish list, baby registry and/or wedding registry.</p>\n<p><a href=\"http://perassi.org/p/dilw/\"><strong>dilw</strong></a></p>\n<p>It lets you see displayed the Daily Dilbert. It uses the DilbertDailyStrip RSS feed.</p>\n<p><a href=\"http://www.vincentprat.info/dev/wordpress-plugins/enhanced-recent-posts/\"><strong>Enhanced Recent Posts</strong></a></p>\n<p>Enhanced Recent Posts is a widget that comes as a replacement to the built-in widget. As the first enhancement, you can choose if you want to show posts from all categories, from some categories in particular or from all categories but some (exclude categories).</p>\";}i:40;a:7:{s:5:\"title\";s:21:\"Matt: Pimping Firefox\";s:4:\"guid\";s:37:\"http://ma.tt/2008/07/pimping-firefox/\";s:4:\"link\";s:37:\"http://ma.tt/2008/07/pimping-firefox/\";s:11:\"description\";s:257:\"<p>Tim Ferriss writes <a href=\"http://www.fourhourworkweek.com/blog/2008/07/10/pimping-firefox-the-basics-matt-mullenweg-garrett-camp-and-more/\">Pimping Firefox: The Basics (Matt Mullenweg, Garrett Camp, and More)</a>. Includes my 5 favorite extensions.</p>\";s:7:\"pubdate\";s:31:\"Fri, 11 Jul 2008 15:19:12 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Matt\";}s:7:\"summary\";s:257:\"<p>Tim Ferriss writes <a href=\"http://www.fourhourworkweek.com/blog/2008/07/10/pimping-firefox-the-basics-matt-mullenweg-garrett-camp-and-more/\">Pimping Firefox: The Basics (Matt Mullenweg, Garrett Camp, and More)</a>. Includes my 5 favorite extensions.</p>\";}i:41;a:7:{s:5:\"title\";s:49:\"Weblog Tools Collection: WordPress for iPhone App\";s:4:\"guid\";s:40:\"http://weblogtoolscollection.com/?p=3730\";s:4:\"link\";s:78:\"http://weblogtoolscollection.com/archives/2008/07/11/wordpress-for-iphone-app/\";s:11:\"description\";s:1046:\"<p><a href=\"http://iphone.wordpress.net/\">WordPress for iPhone</a>: Big news from the Automattic team yesterday. They released a first look at their iPhone App that works on both WordPress.com and WordPress.org blogs. The application is Open Source, available from the iPhone App store and will be available for free. The screen real estate problem with the large on screen keyboard looks to be largely solved with this app and it adds the ability to modify previous posts and view your blog on the web. The official iPhone app for WordPress blog is linked above. The application received rave reviews from a variety of sources such as <a href=\"http://www.techcrunch.com/2008/07/10/wordpress-and-typepad-spawn-mobile-blogging/\">TechCrunch</a> and <a href=\"http://news.cnet.com/8301-17939_109-9988501-2.html?hhTest=1&amp;part=rss&amp;subj=Webware\">Webware</a> and <a href=\"http://ma.tt/2008/07/iphone-native-wordpress-client/\">ma.tt talked about it yesterday</a>. Check out the screencast when you get a chance. It definitely has a wow factor.</p>\";s:7:\"pubdate\";s:31:\"Fri, 11 Jul 2008 12:32:06 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:10:\"Mark Ghosh\";}s:7:\"summary\";s:1046:\"<p><a href=\"http://iphone.wordpress.net/\">WordPress for iPhone</a>: Big news from the Automattic team yesterday. They released a first look at their iPhone App that works on both WordPress.com and WordPress.org blogs. The application is Open Source, available from the iPhone App store and will be available for free. The screen real estate problem with the large on screen keyboard looks to be largely solved with this app and it adds the ability to modify previous posts and view your blog on the web. The official iPhone app for WordPress blog is linked above. The application received rave reviews from a variety of sources such as <a href=\"http://www.techcrunch.com/2008/07/10/wordpress-and-typepad-spawn-mobile-blogging/\">TechCrunch</a> and <a href=\"http://news.cnet.com/8301-17939_109-9988501-2.html?hhTest=1&amp;part=rss&amp;subj=Webware\">Webware</a> and <a href=\"http://ma.tt/2008/07/iphone-native-wordpress-client/\">ma.tt talked about it yesterday</a>. Check out the screencast when you get a chance. It definitely has a wow factor.</p>\";}i:42;a:7:{s:5:\"title\";s:36:\"Matt: iPhone-native WordPress Client\";s:4:\"guid\";s:52:\"http://ma.tt/2008/07/iphone-native-wordpress-client/\";s:4:\"link\";s:52:\"http://ma.tt/2008/07/iphone-native-wordpress-client/\";s:11:\"description\";s:529:\"<p>We&#8217;re doing an iPhone-native WordPress client, <a href=\"http://iphone.wordpress.net/2008/07/10/wordpress-for-iphone/\">check out the screencast here</a>. It will work for both .com and .org, be available FREE from the App Store, and best of all it&#8217;s going to be completely Open Source, which<br />\nas far as I know no current apps in the store are. <ins datetime=\"2008-07-11T15:19:18+00:00\"><strong>Update:</strong> Good news, sounds like there will be at least a few OS apps in the store on opening days.</ins></p>\";s:7:\"pubdate\";s:31:\"Fri, 11 Jul 2008 00:21:45 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Matt\";}s:7:\"summary\";s:529:\"<p>We&#8217;re doing an iPhone-native WordPress client, <a href=\"http://iphone.wordpress.net/2008/07/10/wordpress-for-iphone/\">check out the screencast here</a>. It will work for both .com and .org, be available FREE from the App Store, and best of all it&#8217;s going to be completely Open Source, which<br />\nas far as I know no current apps in the store are. <ins datetime=\"2008-07-11T15:19:18+00:00\"><strong>Update:</strong> Good news, sounds like there will be at least a few OS apps in the store on opening days.</ins></p>\";}i:43;a:7:{s:5:\"title\";s:46:\"Mike Little: I’ll Be Speaking At WordCamp UK\";s:4:\"guid\";s:35:\"http://zed1.com/journalized/?p=1230\";s:4:\"link\";s:79:\"http://zed1.com/journalized/archives/2008/07/10/ill-be-speaking-at-wordcamp-uk/\";s:11:\"description\";s:645:\"<p>Ooh! I&#8217;ve been invited to sit on the panel for a question and answer session on Saturday at<a href=\"http://uk.wordcamp.org/\"> WordCamp UK</a>. I&#8217;m sort of looking forward to it.</p>\n<p>The <a href=\"http://wiki.wordcampuk.tonyscott.org.uk/Running_order\">current running order</a> has the panel on just before lunch, but I don&#8217;t think that&#8217;s finalised yet.</p>\n<p><a href=\"http://wordcampuk2008.eventbrite.com/\">Tickets are still on sale</a> and it&#8217;s a <strong>ticket only event</strong>. No ticket, no getting in.</p>\n<p>Check out the all new <a href=\"http://wordcampuk.wp-cms.com/\">WordCamp UK 2008 blog</a>.</p>\";s:7:\"pubdate\";s:31:\"Thu, 10 Jul 2008 22:59:14 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"mike\";}s:7:\"summary\";s:645:\"<p>Ooh! I&#8217;ve been invited to sit on the panel for a question and answer session on Saturday at<a href=\"http://uk.wordcamp.org/\"> WordCamp UK</a>. I&#8217;m sort of looking forward to it.</p>\n<p>The <a href=\"http://wiki.wordcampuk.tonyscott.org.uk/Running_order\">current running order</a> has the panel on just before lunch, but I don&#8217;t think that&#8217;s finalised yet.</p>\n<p><a href=\"http://wordcampuk2008.eventbrite.com/\">Tickets are still on sale</a> and it&#8217;s a <strong>ticket only event</strong>. No ticket, no getting in.</p>\n<p>Check out the all new <a href=\"http://wordcampuk.wp-cms.com/\">WordCamp UK 2008 blog</a>.</p>\";}i:44;a:7:{s:5:\"title\";s:47:\"Donncha: Anti spam-blog plugin for WordPress MU\";s:4:\"guid\";s:29:\"http://ocaoimh.ie/?p=89493798\";s:4:\"link\";s:68:\"http://ocaoimh.ie/2008/07/10/anti-spam-blog-plugin-for-wordpress-mu/\";s:11:\"description\";s:1935:\"<p>The very popular <a href=\"http://wordpress-plugins.feifei.us/hashcash/\">WP Hashcash plugin</a> for WordPress has been modified to work on the WordPress MU signup page.</p>\n<p>WP Hashcash is an anti spam plugin that protects blogs from comment spam. It does this with Javascript and is quite successful. I worked on it over the last few days and the plugin now offers the same protection on the WordPress MU signup form!</p>\n<p>This is the first release of the code so handle with care. Grab the latest version (version 4.2 as of this moment) from the <a href=\"http://wordpress.org/extend/plugins/wp-hashcash/\">download page</a>. Unzip it and copy wp-hashcash.php into wp-content/mu-plugins/ and visit &#8220;Site Admin&#8221; -> &#8220;WordPress Hashcash&#8221; to confirm it&#8217;s working.</p>\n<p>Now logout and create a new blog, just to make sure everything is working ok. Occasionally some users will have problems registering, and those that have Javascript turned off won&#8217;t be able to create a new blog at all. That&#8217;s the downside of using this plugin unfortunately.</p>\n<p>Keep an eye on the stats counter on the admin page. I want to hear how well this works on your site!</p>\n<p><img src=\"http://ocaoimh.ie/?voyeur=1\" /></p><p><strong>Related Posts</strong><ul><li><a href=\"http://ocaoimh.ie/2004/11/15/yet-another-anti-spam-measure/\" rel=\"bookmark\" title=\"Permanent Link: Yet another anti-spam measure\">Yet another anti-spam measure</a></li><li><a href=\"http://ocaoimh.ie/2004/11/01/wordpress-discussion-options-limiting-spam-annoyances-and-problems/\" rel=\"bookmark\" title=\"Permanent Link: WordPress Discussion Options - limiting spam annoyances and problems\">WordPress Discussion Options - limiting spam annoyances and problems</a></li><li><a href=\"http://ocaoimh.ie/2004/11/02/kittens-spaminator/\" rel=\"bookmark\" title=\"Permanent Link: Kitten&#8217;s Spaminator\">Kitten&#8217;s Spaminator</a></li></ul></p>\";s:7:\"pubdate\";s:31:\"Thu, 10 Jul 2008 20:26:20 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:7:\"Donncha\";}s:7:\"summary\";s:1935:\"<p>The very popular <a href=\"http://wordpress-plugins.feifei.us/hashcash/\">WP Hashcash plugin</a> for WordPress has been modified to work on the WordPress MU signup page.</p>\n<p>WP Hashcash is an anti spam plugin that protects blogs from comment spam. It does this with Javascript and is quite successful. I worked on it over the last few days and the plugin now offers the same protection on the WordPress MU signup form!</p>\n<p>This is the first release of the code so handle with care. Grab the latest version (version 4.2 as of this moment) from the <a href=\"http://wordpress.org/extend/plugins/wp-hashcash/\">download page</a>. Unzip it and copy wp-hashcash.php into wp-content/mu-plugins/ and visit &#8220;Site Admin&#8221; -> &#8220;WordPress Hashcash&#8221; to confirm it&#8217;s working.</p>\n<p>Now logout and create a new blog, just to make sure everything is working ok. Occasionally some users will have problems registering, and those that have Javascript turned off won&#8217;t be able to create a new blog at all. That&#8217;s the downside of using this plugin unfortunately.</p>\n<p>Keep an eye on the stats counter on the admin page. I want to hear how well this works on your site!</p>\n<p><img src=\"http://ocaoimh.ie/?voyeur=1\" /></p><p><strong>Related Posts</strong><ul><li><a href=\"http://ocaoimh.ie/2004/11/15/yet-another-anti-spam-measure/\" rel=\"bookmark\" title=\"Permanent Link: Yet another anti-spam measure\">Yet another anti-spam measure</a></li><li><a href=\"http://ocaoimh.ie/2004/11/01/wordpress-discussion-options-limiting-spam-annoyances-and-problems/\" rel=\"bookmark\" title=\"Permanent Link: WordPress Discussion Options - limiting spam annoyances and problems\">WordPress Discussion Options - limiting spam annoyances and problems</a></li><li><a href=\"http://ocaoimh.ie/2004/11/02/kittens-spaminator/\" rel=\"bookmark\" title=\"Permanent Link: Kitten&#8217;s Spaminator\">Kitten&#8217;s Spaminator</a></li></ul></p>\";}i:45;a:7:{s:5:\"title\";s:46:\"Peter Westwood: WordCamp UK 2008, 9 days to go\";s:4:\"guid\";s:32:\"http://westi.wordpress.com/?p=50\";s:4:\"link\";s:68:\"http://westi.wordpress.com/2008/07/10/wordcamp-uk-2008-9-days-to-go/\";s:11:\"description\";s:1720:\"<div class=\"snap_preview\"><br /><p><a href=\"http://uk.wordcamp.org\">WordCamp UK 2008</a> is fast approaching in fact there are only 9 days to go! I&#8217;ve got my <a href=\"http://wordcampuk2008.eventbrite.com/\">ticket</a> - have you got yours yet?  The organisers have arranged a packed 2 day program which is very good value for money.  I will be doing a talk on the sunday all about getting involved in WordPress development. See you there.</p>\n<img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/categories/westi.wordpress.com/50/\" /> <img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/tags/westi.wordpress.com/50/\" /> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/gocomments/westi.wordpress.com/50/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/comments/westi.wordpress.com/50/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/godelicious/westi.wordpress.com/50/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/delicious/westi.wordpress.com/50/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/gostumble/westi.wordpress.com/50/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/stumble/westi.wordpress.com/50/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/godigg/westi.wordpress.com/50/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/digg/westi.wordpress.com/50/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/goreddit/westi.wordpress.com/50/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/reddit/westi.wordpress.com/50/\" /></a> <img alt=\"\" border=\"0\" src=\"http://stats.wordpress.com/b.gif?host=westi.wordpress.com&blog=15396&post=50&subd=westi&ref=&feed=1\" /></div>\";s:7:\"pubdate\";s:31:\"Thu, 10 Jul 2008 19:01:16 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:14:\"Peter Westwood\";}s:7:\"summary\";s:1720:\"<div class=\"snap_preview\"><br /><p><a href=\"http://uk.wordcamp.org\">WordCamp UK 2008</a> is fast approaching in fact there are only 9 days to go! I&#8217;ve got my <a href=\"http://wordcampuk2008.eventbrite.com/\">ticket</a> - have you got yours yet?  The organisers have arranged a packed 2 day program which is very good value for money.  I will be doing a talk on the sunday all about getting involved in WordPress development. See you there.</p>\n<img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/categories/westi.wordpress.com/50/\" /> <img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/tags/westi.wordpress.com/50/\" /> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/gocomments/westi.wordpress.com/50/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/comments/westi.wordpress.com/50/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/godelicious/westi.wordpress.com/50/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/delicious/westi.wordpress.com/50/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/gostumble/westi.wordpress.com/50/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/stumble/westi.wordpress.com/50/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/godigg/westi.wordpress.com/50/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/digg/westi.wordpress.com/50/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/goreddit/westi.wordpress.com/50/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/reddit/westi.wordpress.com/50/\" /></a> <img alt=\"\" border=\"0\" src=\"http://stats.wordpress.com/b.gif?host=westi.wordpress.com&blog=15396&post=50&subd=westi&ref=&feed=1\" /></div>\";}i:46;a:7:{s:5:\"title\";s:56:\"Weblog Tools Collection: Last Day for Plugin Competition\";s:4:\"guid\";s:40:\"http://weblogtoolscollection.com/?p=3729\";s:4:\"link\";s:85:\"http://weblogtoolscollection.com/archives/2008/07/10/last-day-for-plugin-competition/\";s:11:\"description\";s:2375:\"<p>Today is the last day to submit entries to the WordPress Plugin Competition.</p>\n<ul>\n<li><strong>We will accept entries till 11:59 PM EST tonight.</strong> <strong>A little leeway will be allowed</strong> because of time differences across the world. However we will not accept any entries that come in tomorrow.</li>\n<li>Please make sure that all entrants are registered on the <a href=\"http://weblogtoolscollection.com/pluginblog/\">Plugin Competition Blog</a> and have written at least one post about their plugin entry</li>\n<li>If you find a bug, please resend your entry. A plugin that crashes and burns in a fatal error on install is quite a downer to your chances at winning the competition.</li>\n<li>Please send in your entries before the deadline to <strong>wpplugincomp [at] wltc [dot] net</strong> with the subject line as “<strong>WP Plugin Competition:</strong> <em>Plugin Name</em>“</li>\n<li>There are over <a href=\"http://weblogtoolscollection.com/plugin-competition-prizes/\">$3800 in prizes</a> to be won in this competition</li>\n<li>Over 40 plugins have been announced so far. We have received a lesser number of submissions. <strong>Remember that you need to submit your plugin code to us via the email provided above in order to be considered as an entry into the competition. </strong></li>\n<li>Once all the entries are in and tabulated, we will provide a list of all entries and their respective rating pages so users can weigh in with their choices. <strong>Users&#8217; rating of the plugin will have a heavy weight in the final results.</strong></li>\n<li>The judges will have two weeks to finish the judging. So the tentative date for the results to be declared is the first week of August</li>\n<li>If you have promised a monetary prize for the competition, please Paypal the money to mark at wltc dot net at your convenience. (<em>We would appreciate a little extra to cover the overhead, especially for larger dollar amounts, but that is up to you</em>.)</li>\n</ul>\n<p>A heartfelt <a href=\"http://weblogtoolscollection.com/plugin-competition-prizes/\">thank you to all the donors</a> who have made the competition a reality, to all the users who have spent their time and effort in testing and encouraging the developers and to the plugin developers who are working hard to get their work ready in time for the plugin competition deadline.</p>\";s:7:\"pubdate\";s:31:\"Thu, 10 Jul 2008 14:11:50 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:10:\"Mark Ghosh\";}s:7:\"summary\";s:2375:\"<p>Today is the last day to submit entries to the WordPress Plugin Competition.</p>\n<ul>\n<li><strong>We will accept entries till 11:59 PM EST tonight.</strong> <strong>A little leeway will be allowed</strong> because of time differences across the world. However we will not accept any entries that come in tomorrow.</li>\n<li>Please make sure that all entrants are registered on the <a href=\"http://weblogtoolscollection.com/pluginblog/\">Plugin Competition Blog</a> and have written at least one post about their plugin entry</li>\n<li>If you find a bug, please resend your entry. A plugin that crashes and burns in a fatal error on install is quite a downer to your chances at winning the competition.</li>\n<li>Please send in your entries before the deadline to <strong>wpplugincomp [at] wltc [dot] net</strong> with the subject line as “<strong>WP Plugin Competition:</strong> <em>Plugin Name</em>“</li>\n<li>There are over <a href=\"http://weblogtoolscollection.com/plugin-competition-prizes/\">$3800 in prizes</a> to be won in this competition</li>\n<li>Over 40 plugins have been announced so far. We have received a lesser number of submissions. <strong>Remember that you need to submit your plugin code to us via the email provided above in order to be considered as an entry into the competition. </strong></li>\n<li>Once all the entries are in and tabulated, we will provide a list of all entries and their respective rating pages so users can weigh in with their choices. <strong>Users&#8217; rating of the plugin will have a heavy weight in the final results.</strong></li>\n<li>The judges will have two weeks to finish the judging. So the tentative date for the results to be declared is the first week of August</li>\n<li>If you have promised a monetary prize for the competition, please Paypal the money to mark at wltc dot net at your convenience. (<em>We would appreciate a little extra to cover the overhead, especially for larger dollar amounts, but that is up to you</em>.)</li>\n</ul>\n<p>A heartfelt <a href=\"http://weblogtoolscollection.com/plugin-competition-prizes/\">thank you to all the donors</a> who have made the competition a reality, to all the users who have spent their time and effort in testing and encouraging the developers and to the plugin developers who are working hard to get their work ready in time for the plugin competition deadline.</p>\";}i:47;a:7:{s:5:\"title\";s:59:\"Weblog Tools Collection: WordPress Theme Releases for 07/09\";s:4:\"guid\";s:40:\"http://weblogtoolscollection.com/?p=3722\";s:4:\"link\";s:87:\"http://weblogtoolscollection.com/archives/2008/07/09/wordpress-theme-releases-for-0709/\";s:11:\"description\";s:2886:\"<h3>One Column Themes</h3>\n<p><a href=\"http://ulyssesonline.com/2008/07/03/black-green-theme/\"><strong>Black Green</strong></a></p>\n<p><a href=\"http://ulyssesonline.com/themes/index.php?wptheme=Black-Green\"><img src=\"http://weblogtoolscollection.com/b2-img/2008/07/black-green-150x150.png\" alt=\"Black Green\" title=\"Black Green\" class=\"alignnone size-thumbnail wp-image-3726\" width=\"150\" height=\"150\" /></a></p>\n<p>It’s simple, elegant and ultra-minimal. The theme uses an Ajax Accordion script to toggle display of posts and the archives/sidebar page.</p>\n<h3>Two Column Themes</h3>\n<p><a href=\"http://easternwest.com/wordpress-themes/\"><strong>Simplifi</strong></a></p>\n<p><a href=\"http://www.easternwest.com/\"><img src=\"http://weblogtoolscollection.com/b2-img/2008/07/simplifi-150x150.gif\" alt=\"simplifi\" title=\"simplifi\" class=\"alignnone size-thumbnail wp-image-3724\" width=\"150\" height=\"150\" /></a></p>\n<p>Simplifi is a very simple theme, for people who publish a lot of content and don’t want a heavy design to waste space.</p>\n<p><a href=\"http://www.wpthemedesigner.com/2008/07/07/basicblue-theme/\"><strong>BasicBlue</strong></a></p>\n<p><a href=\"http://ythv.info/basicblue/\"><img src=\"http://weblogtoolscollection.com/b2-img/2008/07/basicblue-150x150.gif\" alt=\"BasicBlue Theme\" title=\"BasicBlue Theme\" class=\"alignnone size-thumbnail wp-image-3725\" width=\"150\" height=\"150\" /></a></p>\n<p>Quick Loading Theme, Widget ready, Minimalist Design, 2 Columns, Banner Ads Ready.</p>\n<p><a href=\"http://www.themelab.com/2008/06/10/rs10-free-wordpress-theme/\"><strong>RS10</strong></a></p>\n<p><a href=\"http://demo.themelab.com/index.php?wptheme=RS10\"><img src=\"http://weblogtoolscollection.com/b2-img/2008/07/rs10-150x150.jpg\" alt=\"RS10\" title=\"RS10\" class=\"alignnone size-thumbnail wp-image-3728\" width=\"150\" height=\"150\" /></a></p>\n<p>This free WordPress theme has a homepage template, posts of which can be configured through a config file. Widget-ready sidebar and Gravatar support.</p>\n<h3>Three Column Themes</h3>\n<p><a href=\"http://www.wpthemedesigner.com/2008/06/17/personal-mag-theme/\"><strong>Personal Mag</strong></a></p>\n<p><a href=\"http://ythv.info/personalmag/\"><img src=\"http://weblogtoolscollection.com/b2-img/2008/07/personalmg-150x150.gif\" alt=\"Personal Mag\" title=\"Personal Mag\" class=\"alignnone size-thumbnail wp-image-3727\" width=\"150\" height=\"150\" /></a></p>\n<p>3 Columns. Widget Ready. Minimalist Design. Awesome Menu Hover!</p>\n<p><a href=\"http://www.ofimdavarzea.com/up-front-free-wordpress-theme/\"><strong>Up Front</strong></a></p>\n<p><a href=\"http://themes.ofimdavarzea.com/\"><img src=\"http://weblogtoolscollection.com/b2-img/2008/07/upfront-150x150.jpg\" alt=\"Up Front\" title=\"Up Front\" class=\"alignnone size-thumbnail wp-image-3723\" width=\"150\" height=\"150\" /></a></p>\n<p>Up Front is a two/three column widget, Gravatar and Adsense ready WordPress theme.</p>\";s:7:\"pubdate\";s:31:\"Wed, 09 Jul 2008 13:16:51 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Ajay\";}s:7:\"summary\";s:2886:\"<h3>One Column Themes</h3>\n<p><a href=\"http://ulyssesonline.com/2008/07/03/black-green-theme/\"><strong>Black Green</strong></a></p>\n<p><a href=\"http://ulyssesonline.com/themes/index.php?wptheme=Black-Green\"><img src=\"http://weblogtoolscollection.com/b2-img/2008/07/black-green-150x150.png\" alt=\"Black Green\" title=\"Black Green\" class=\"alignnone size-thumbnail wp-image-3726\" width=\"150\" height=\"150\" /></a></p>\n<p>It’s simple, elegant and ultra-minimal. The theme uses an Ajax Accordion script to toggle display of posts and the archives/sidebar page.</p>\n<h3>Two Column Themes</h3>\n<p><a href=\"http://easternwest.com/wordpress-themes/\"><strong>Simplifi</strong></a></p>\n<p><a href=\"http://www.easternwest.com/\"><img src=\"http://weblogtoolscollection.com/b2-img/2008/07/simplifi-150x150.gif\" alt=\"simplifi\" title=\"simplifi\" class=\"alignnone size-thumbnail wp-image-3724\" width=\"150\" height=\"150\" /></a></p>\n<p>Simplifi is a very simple theme, for people who publish a lot of content and don’t want a heavy design to waste space.</p>\n<p><a href=\"http://www.wpthemedesigner.com/2008/07/07/basicblue-theme/\"><strong>BasicBlue</strong></a></p>\n<p><a href=\"http://ythv.info/basicblue/\"><img src=\"http://weblogtoolscollection.com/b2-img/2008/07/basicblue-150x150.gif\" alt=\"BasicBlue Theme\" title=\"BasicBlue Theme\" class=\"alignnone size-thumbnail wp-image-3725\" width=\"150\" height=\"150\" /></a></p>\n<p>Quick Loading Theme, Widget ready, Minimalist Design, 2 Columns, Banner Ads Ready.</p>\n<p><a href=\"http://www.themelab.com/2008/06/10/rs10-free-wordpress-theme/\"><strong>RS10</strong></a></p>\n<p><a href=\"http://demo.themelab.com/index.php?wptheme=RS10\"><img src=\"http://weblogtoolscollection.com/b2-img/2008/07/rs10-150x150.jpg\" alt=\"RS10\" title=\"RS10\" class=\"alignnone size-thumbnail wp-image-3728\" width=\"150\" height=\"150\" /></a></p>\n<p>This free WordPress theme has a homepage template, posts of which can be configured through a config file. Widget-ready sidebar and Gravatar support.</p>\n<h3>Three Column Themes</h3>\n<p><a href=\"http://www.wpthemedesigner.com/2008/06/17/personal-mag-theme/\"><strong>Personal Mag</strong></a></p>\n<p><a href=\"http://ythv.info/personalmag/\"><img src=\"http://weblogtoolscollection.com/b2-img/2008/07/personalmg-150x150.gif\" alt=\"Personal Mag\" title=\"Personal Mag\" class=\"alignnone size-thumbnail wp-image-3727\" width=\"150\" height=\"150\" /></a></p>\n<p>3 Columns. Widget Ready. Minimalist Design. Awesome Menu Hover!</p>\n<p><a href=\"http://www.ofimdavarzea.com/up-front-free-wordpress-theme/\"><strong>Up Front</strong></a></p>\n<p><a href=\"http://themes.ofimdavarzea.com/\"><img src=\"http://weblogtoolscollection.com/b2-img/2008/07/upfront-150x150.jpg\" alt=\"Up Front\" title=\"Up Front\" class=\"alignnone size-thumbnail wp-image-3723\" width=\"150\" height=\"150\" /></a></p>\n<p>Up Front is a two/three column widget, Gravatar and Adsense ready WordPress theme.</p>\";}i:48;a:7:{s:5:\"title\";s:32:\"Donncha: WordPress MU 2.6 beta 1\";s:4:\"guid\";s:29:\"http://ocaoimh.ie/?p=89493797\";s:4:\"link\";s:52:\"http://ocaoimh.ie/2008/07/09/wordpress-mu-26-beta-1/\";s:11:\"description\";s:2348:\"<p><strong>Edit:</strong> The release candidate is now online. Here&#8217;s the <a href=\"http://mu.wordpress.org/forums/topic.php?id=8885\">forum thread</a> on it. Grab the <a href=\"http://mu.wordpress.org/wordpress-mu-2.6-rc1.zip\">zip file</a> to test!</p>\n<p>WordPress MU 2.6 beta 1 is now available. WordPress 2.6 is due for release shortly and it&#8217;s already on it&#8217;s third beta so it&#8217;s times for WordPress MU to be updated.</p>\n<p>This release has many new features as well as a few security fixes. In his <a href=\"http://boren.nu/archives/2008/06/23/wordpress-26-beta-1/\">beta 1</a>, <a href=\"http://boren.nu/archives/2008/07/01/wordpress-26-beta-2/\">beta 2</a> and <a href=\"http://boren.nu/archives/2008/07/08/wordpress-26-beta-3/\">beta 3</a> posts Ryan listed some of the main features, including post revisioning, gears support for faster loading, theme previews, better SSL support and much much more.</p>\n<p>WordPress MU specific changes include:\n<ul>\n<li> The version number is being bumped to 2.6 rather than 1.6 because of version confusion. Minor MU versions will probably append a letter to the version.</li>\n<li> Signup page now has a nonce to help defeat spammers.</li>\n<li> Plugins in wp-content/plugins/ are version checked like in WordPress. mu-plugins isn&#8217;t covered just yet.</li>\n<li> Major object cache changes.</li>\n<li> And many more bug fixes. Check the <a href=\"http://trac.mu.wordpress.org/timeline\">timeline</a> for a list of changes.</li>\n</ul>\n<p>Download <a href=\"http://mu.wordpress.org/wordpress-mu-2.6-beta1.zip\" class=\"broken_link\">wordpress-mu-2.6-beta1.zip</a></p>\n<p><img src=\"http://ocaoimh.ie/?voyeur=1\" /></p><p><strong>Related Posts</strong><ul><li><a href=\"http://ocaoimh.ie/2003/02/13/woo-the-latest-beta/\" rel=\"bookmark\" title=\"Permanent Link: Woo! The latest beta of Safari &#8230;\">Woo! The latest beta of Safari &#8230;</a></li><li><a href=\"http://ocaoimh.ie/2004/12/08/s-c-i-z-z-o-g-i-m-p-o-r-g-lots-of-gimp-stuff/\" rel=\"bookmark\" title=\"Permanent Link: s c i z z o . g i m p . o r g - lots of GIMP stuff!\">s c i z z o . g i m p . o r g - lots of GIMP stuff!</a></li><li><a href=\"http://ocaoimh.ie/2007/08/27/bloglines-new-interface-is-beta/\" rel=\"bookmark\" title=\"Permanent Link: Blogline&#8217;s new interface is beta\">Blogline&#8217;s new interface is beta</a></li></ul></p>\";s:7:\"pubdate\";s:31:\"Wed, 09 Jul 2008 10:50:40 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:7:\"Donncha\";}s:7:\"summary\";s:2348:\"<p><strong>Edit:</strong> The release candidate is now online. Here&#8217;s the <a href=\"http://mu.wordpress.org/forums/topic.php?id=8885\">forum thread</a> on it. Grab the <a href=\"http://mu.wordpress.org/wordpress-mu-2.6-rc1.zip\">zip file</a> to test!</p>\n<p>WordPress MU 2.6 beta 1 is now available. WordPress 2.6 is due for release shortly and it&#8217;s already on it&#8217;s third beta so it&#8217;s times for WordPress MU to be updated.</p>\n<p>This release has many new features as well as a few security fixes. In his <a href=\"http://boren.nu/archives/2008/06/23/wordpress-26-beta-1/\">beta 1</a>, <a href=\"http://boren.nu/archives/2008/07/01/wordpress-26-beta-2/\">beta 2</a> and <a href=\"http://boren.nu/archives/2008/07/08/wordpress-26-beta-3/\">beta 3</a> posts Ryan listed some of the main features, including post revisioning, gears support for faster loading, theme previews, better SSL support and much much more.</p>\n<p>WordPress MU specific changes include:\n<ul>\n<li> The version number is being bumped to 2.6 rather than 1.6 because of version confusion. Minor MU versions will probably append a letter to the version.</li>\n<li> Signup page now has a nonce to help defeat spammers.</li>\n<li> Plugins in wp-content/plugins/ are version checked like in WordPress. mu-plugins isn&#8217;t covered just yet.</li>\n<li> Major object cache changes.</li>\n<li> And many more bug fixes. Check the <a href=\"http://trac.mu.wordpress.org/timeline\">timeline</a> for a list of changes.</li>\n</ul>\n<p>Download <a href=\"http://mu.wordpress.org/wordpress-mu-2.6-beta1.zip\" class=\"broken_link\">wordpress-mu-2.6-beta1.zip</a></p>\n<p><img src=\"http://ocaoimh.ie/?voyeur=1\" /></p><p><strong>Related Posts</strong><ul><li><a href=\"http://ocaoimh.ie/2003/02/13/woo-the-latest-beta/\" rel=\"bookmark\" title=\"Permanent Link: Woo! The latest beta of Safari &#8230;\">Woo! The latest beta of Safari &#8230;</a></li><li><a href=\"http://ocaoimh.ie/2004/12/08/s-c-i-z-z-o-g-i-m-p-o-r-g-lots-of-gimp-stuff/\" rel=\"bookmark\" title=\"Permanent Link: s c i z z o . g i m p . o r g - lots of GIMP stuff!\">s c i z z o . g i m p . o r g - lots of GIMP stuff!</a></li><li><a href=\"http://ocaoimh.ie/2007/08/27/bloglines-new-interface-is-beta/\" rel=\"bookmark\" title=\"Permanent Link: Blogline&#8217;s new interface is beta\">Blogline&#8217;s new interface is beta</a></li></ul></p>\";}i:49;a:7:{s:5:\"title\";s:23:\"Matt: Sphere Wrap Party\";s:4:\"guid\";s:20:\"http://ma.tt/?p=6639\";s:4:\"link\";s:39:\"http://ma.tt/2008/07/sphere-wrap-party/\";s:11:\"description\";s:13826:\"<p>Sphere celebration party at Phil&#8217;s house.</p>\n<p><span id=\"more-6639\"></span></p>\n\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2187/\" title=\"mcm_2187\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2187-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2193/\" title=\"mcm_2193\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2193-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2194/\" title=\"mcm_2194\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2194-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2197/\" title=\"mcm_2197\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2197-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2199/\" title=\"mcm_2199\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2199-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2203/\" title=\"mcm_2203\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2203-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2205/\" title=\"mcm_2205\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2205-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2208/\" title=\"mcm_2208\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2208-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2210/\" title=\"mcm_2210\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2210-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2212/\" title=\"mcm_2212\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2212-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2215/\" title=\"mcm_2215\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2215-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2216/\" title=\"mcm_2216\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2216-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2220/\" title=\"mcm_2220\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2220-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2226/\" title=\"mcm_2226\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2226-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2229/\" title=\"mcm_2229\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2229-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2230/\" title=\"mcm_2230\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2230-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2234/\" title=\"mcm_2234\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2234-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2238/\" title=\"mcm_2238\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2238-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2239/\" title=\"mcm_2239\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2239-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2246/\" title=\"mcm_2246\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2246-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2247/\" title=\"mcm_2247\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2247-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2248/\" title=\"mcm_2248\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2248-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2254/\" title=\"mcm_2254\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2254-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2255/\" title=\"mcm_2255\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2255-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2258/\" title=\"mcm_2258\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2258-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2262/\" title=\"mcm_2262\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2262-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2267/\" title=\"mcm_2267\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2267-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2270/\" title=\"mcm_2270\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2270-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2277/\" title=\"mcm_2277\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2277-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2278/\" title=\"mcm_2278\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2278-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2282/\" title=\"mcm_2282\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2282-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2291/\" title=\"mcm_2291\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2291-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2293/\" title=\"mcm_2293\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2293-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2297/\" title=\"mcm_2297\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2297-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2299/\" title=\"mcm_2299\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2299-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2313/\" title=\"mcm_2313\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2313-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2316/\" title=\"mcm_2316\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2316-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2320/\" title=\"mcm_2320\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2320-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2323/\" title=\"mcm_2323\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2323-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2326/\" title=\"mcm_2326\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2326-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2329/\" title=\"mcm_2329\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2329-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2334/\" title=\"mcm_2334\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2334-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2340/\" title=\"mcm_2340\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2340-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2342/\" title=\"mcm_2342\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2342-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2344/\" title=\"mcm_2344\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2344-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2349/\" title=\"mcm_2349\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2349-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2351/\" title=\"mcm_2351\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2351-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2354/\" title=\"mcm_2354\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2354-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2363/\" title=\"mcm_2363\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2363-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2366/\" title=\"mcm_2366\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2366-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2370/\" title=\"mcm_2370\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2370-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2376/\" title=\"mcm_2376\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2376-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2381/\" title=\"mcm_2381\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2381-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2384/\" title=\"mcm_2384\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2384-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2385/\" title=\"mcm_2385\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2385-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2397/\" title=\"mcm_2397\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2397-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2401/\" title=\"mcm_2401\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2401-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2405/\" title=\"mcm_2405\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2405-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2412/\" title=\"mcm_2412\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2412-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2422/\" title=\"mcm_2422\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2422-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2434/\" title=\"mcm_2434\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2434-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2438/\" title=\"mcm_2438\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2438-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2446/\" title=\"mcm_2446\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2446-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2450/\" title=\"mcm_2450\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2450-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2461/\" title=\"mcm_2461\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2461-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2468/\" title=\"mcm_2468\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2468-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2472/\" title=\"mcm_2472\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2472-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\";s:7:\"pubdate\";s:31:\"Wed, 09 Jul 2008 08:00:01 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Matt\";}s:7:\"summary\";s:13826:\"<p>Sphere celebration party at Phil&#8217;s house.</p>\n<p><span id=\"more-6639\"></span></p>\n\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2187/\" title=\"mcm_2187\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2187-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2193/\" title=\"mcm_2193\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2193-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2194/\" title=\"mcm_2194\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2194-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2197/\" title=\"mcm_2197\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2197-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2199/\" title=\"mcm_2199\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2199-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2203/\" title=\"mcm_2203\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2203-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2205/\" title=\"mcm_2205\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2205-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2208/\" title=\"mcm_2208\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2208-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2210/\" title=\"mcm_2210\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2210-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2212/\" title=\"mcm_2212\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2212-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2215/\" title=\"mcm_2215\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2215-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2216/\" title=\"mcm_2216\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2216-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2220/\" title=\"mcm_2220\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2220-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2226/\" title=\"mcm_2226\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2226-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2229/\" title=\"mcm_2229\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2229-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2230/\" title=\"mcm_2230\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2230-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2234/\" title=\"mcm_2234\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2234-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2238/\" title=\"mcm_2238\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2238-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2239/\" title=\"mcm_2239\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2239-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2246/\" title=\"mcm_2246\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2246-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2247/\" title=\"mcm_2247\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2247-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2248/\" title=\"mcm_2248\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2248-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2254/\" title=\"mcm_2254\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2254-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2255/\" title=\"mcm_2255\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2255-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2258/\" title=\"mcm_2258\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2258-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2262/\" title=\"mcm_2262\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2262-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2267/\" title=\"mcm_2267\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2267-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2270/\" title=\"mcm_2270\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2270-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2277/\" title=\"mcm_2277\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2277-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2278/\" title=\"mcm_2278\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2278-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2282/\" title=\"mcm_2282\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2282-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2291/\" title=\"mcm_2291\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2291-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2293/\" title=\"mcm_2293\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2293-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2297/\" title=\"mcm_2297\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2297-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2299/\" title=\"mcm_2299\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2299-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2313/\" title=\"mcm_2313\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2313-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2316/\" title=\"mcm_2316\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2316-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2320/\" title=\"mcm_2320\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2320-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2323/\" title=\"mcm_2323\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2323-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2326/\" title=\"mcm_2326\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2326-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2329/\" title=\"mcm_2329\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2329-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2334/\" title=\"mcm_2334\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2334-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2340/\" title=\"mcm_2340\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2340-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2342/\" title=\"mcm_2342\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2342-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2344/\" title=\"mcm_2344\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2344-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2349/\" title=\"mcm_2349\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2349-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2351/\" title=\"mcm_2351\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2351-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2354/\" title=\"mcm_2354\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2354-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2363/\" title=\"mcm_2363\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2363-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2366/\" title=\"mcm_2366\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2366-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2370/\" title=\"mcm_2370\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2370-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2376/\" title=\"mcm_2376\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2376-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2381/\" title=\"mcm_2381\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2381-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2384/\" title=\"mcm_2384\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2384-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2385/\" title=\"mcm_2385\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2385-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2397/\" title=\"mcm_2397\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2397-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2401/\" title=\"mcm_2401\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2401-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2405/\" title=\"mcm_2405\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2405-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2412/\" title=\"mcm_2412\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2412-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2422/\" title=\"mcm_2422\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2422-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2434/\" title=\"mcm_2434\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2434-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2438/\" title=\"mcm_2438\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2438-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2446/\" title=\"mcm_2446\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2446-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2450/\" title=\"mcm_2450\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2450-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2461/\" title=\"mcm_2461\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2461-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2468/\" title=\"mcm_2468\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2468-139x210.jpg\" width=\"139\" height=\"210\" class=\"attachment-thumbnail\" alt=\"\" /></a>\n<a href=\"http://ma.tt/2008/07/sphere-wrap-party/mcm_2472/\" title=\"mcm_2472\"><img src=\"http://s.ma.tt/files/2008/07/mcm_2472-195x129.jpg\" width=\"195\" height=\"129\" class=\"attachment-thumbnail\" alt=\"\" /></a>\";}}s:7:\"channel\";a:5:{s:5:\"title\";s:16:\"WordPress Planet\";s:4:\"link\";s:28:\"http://planet.wordpress.org/\";s:8:\"language\";s:2:\"en\";s:11:\"description\";s:47:\"WordPress Planet - http://planet.wordpress.org/\";s:7:\"tagline\";s:47:\"WordPress Planet - http://planet.wordpress.org/\";}s:9:\"textinput\";a:0:{}s:5:\"image\";a:0:{}s:9:\"feed_type\";s:3:\"RSS\";s:12:\"feed_version\";s:3:\"2.0\";s:5:\"stack\";a:0:{}s:9:\"inchannel\";b:0;s:6:\"initem\";b:0;s:9:\"incontent\";b:0;s:11:\"intextinput\";b:0;s:7:\"inimage\";b:0;s:13:\"current_field\";s:0:\"\";s:17:\"current_namespace\";b:0;s:19:\"_CONTENT_CONSTRUCTS\";a:6:{i:0;s:7:\"content\";i:1;s:7:\"summary\";i:2;s:4:\"info\";i:3;s:5:\"title\";i:4;s:7:\"tagline\";i:5;s:9:\"copyright\";}s:4:\"etag\";s:25:\"\"27150-48898f19-468597\"\r\n\";s:13:\"last_modified\";s:31:\"Fri, 25 Jul 2008 08:30:17 GMT\r\n\";}','no'),(208,0,'category_children','a:0:{}','yes'),(69,0,'rss_867bd5c64f85878d03a060509cd2f92c_ts','1216974858','no'),(70,0,'rss_e0606a1ed20504810e7f40fde29a91dd','O:9:\"MagpieRSS\":17:{s:6:\"parser\";i:0;s:12:\"current_item\";a:0:{}s:5:\"items\";a:20:{i:0;a:9:{s:5:\"title\";s:17:\"Daca e luni, eâ€¦\";s:4:\"link\";s:42:\"http://xsolo.biz/2008/07/21/daca-e-luni-e/\";s:8:\"comments\";s:87:\"http://technorati.com/search/http%3A%2F%2Fxsolo.biz%2F2008%2F07%2F21%2Fdaca-e-luni-e%2F\";s:4:\"guid\";s:42:\"http://xsolo.biz/2008/07/21/daca-e-luni-e/\";s:7:\"pubdate\";s:31:\"Mon, 21 Jul 2008 15:06:11 +0000\";s:11:\"description\";s:49:\" Blogroll  groparu kobeâ€™s climbing blog ruxx   \";s:6:\"source\";s:17:\"xsolo travel blog\";s:4:\"tapi\";a:6:{s:6:\"rssurl\";s:22:\"http://xsolo.biz/feed/\";s:7:\"atomurl\";s:27:\"http://xsolo.biz/feed/atom/\";s:12:\"inboundblogs\";s:1:\"6\";s:12:\"inboundlinks\";s:1:\"7\";s:11:\"linkcreated\";s:31:\"Mon, 21 Jul 2008 08:06:11 -0700\";s:7:\"linkurl\";s:22:\"http://www.groparu.ro/\";}s:7:\"summary\";s:49:\" Blogroll  groparu kobeâ€™s climbing blog ruxx   \";}i:1;a:9:{s:5:\"title\";s:20:\"Lecturi din blogroll\";s:4:\"link\";s:59:\"http://www.mana.ciutacu.ro/2008/07/21/lecturi-din-blogroll/\";s:8:\"comments\";s:104:\"http://technorati.com/search/http%3A%2F%2Fwww.mana.ciutacu.ro%2F2008%2F07%2F21%2Flecturi-din-blogroll%2F\";s:4:\"guid\";s:59:\"http://www.mana.ciutacu.ro/2008/07/21/lecturi-din-blogroll/\";s:7:\"pubdate\";s:31:\"Mon, 21 Jul 2008 14:09:44 +0000\";s:11:\"description\";s:377:\"voi, cÄƒ eu am fÄƒcut deschiderea! Poate completaÈ›i cu povestirea lui Aristofan din Banchetul lui Platon, cea cunoscutÄƒ sub numele Mitul androginului. Cum, n-o È™tiÈ›i? Cea cu jumÄƒtÄƒÈ›ile de sferÄƒâ€¦ È˜i sÄƒ nu vÄƒ lÄƒsaÈ›i induÈ™i Ã®n eroare de Groparu, el doar aparent abordeazÄƒ acelaÈ™i subiectâ€¦ Sauâ€¦ mai È™tii? Ä‚la o fi animÄƒluÈ›ul? Ä‚la o fi sufletul-pereche? \";s:6:\"source\";s:15:\"Mariana Ciutacu\";s:4:\"tapi\";a:5:{s:6:\"rssurl\";s:32:\"http://www.mana.ciutacu.ro/feed/\";s:12:\"inboundblogs\";s:2:\"38\";s:12:\"inboundlinks\";s:3:\"124\";s:11:\"linkcreated\";s:31:\"Mon, 21 Jul 2008 07:09:44 -0700\";s:7:\"linkurl\";s:29:\"http://www.groparu.ro/?p=1159\";}s:7:\"summary\";s:377:\"voi, cÄƒ eu am fÄƒcut deschiderea! Poate completaÈ›i cu povestirea lui Aristofan din Banchetul lui Platon, cea cunoscutÄƒ sub numele Mitul androginului. Cum, n-o È™tiÈ›i? Cea cu jumÄƒtÄƒÈ›ile de sferÄƒâ€¦ È˜i sÄƒ nu vÄƒ lÄƒsaÈ›i induÈ™i Ã®n eroare de Groparu, el doar aparent abordeazÄƒ acelaÈ™i subiectâ€¦ Sauâ€¦ mai È™tii? Ä‚la o fi animÄƒluÈ›ul? Ä‚la o fi sufletul-pereche? \";}i:2;a:9:{s:5:\"title\";s:29:\"Victor Ciutacu - Vorbe Grele \";s:4:\"link\";s:21:\"http://www.ciutacu.ro\";s:8:\"comments\";s:21:\"/blogs/www.ciutacu.ro\";s:4:\"guid\";s:21:\"/blogs/www.ciutacu.ro\";s:7:\"pubdate\";s:31:\"Sun, 20 Jul 2008 08:42:05 +0000\";s:11:\"description\";s:429:\" adrian.filozofie.ro adrianpopa.ro ancaalexandrescu.ro/blog/ andreicrivat.ro antena2.tv ardeimedia.ro chinezu.eu danandronic.blogspot.com dianatusa.blogspot.com dragos.ro globe-trotter.ro/ziaruldela5 groparu.ro ilariont.blogspot.com ioniliescu.wordpress.com istoriacomunismului.blogspot.com jeg.ro jurnalul.ro mana.ciutacu.ro mesterulmanole.wordpress.com moshemordachai.wordpress.com nastase.wordpress.com oana-dobre.blogspot.com\";s:6:\"source\";s:29:\"Victor Ciutacu - Vorbe Grele \";s:4:\"tapi\";a:5:{s:7:\"atomurl\";s:27:\"http://www.ciutacu.ro/feed/\";s:12:\"inboundblogs\";s:3:\"325\";s:12:\"inboundlinks\";s:3:\"726\";s:11:\"linkcreated\";s:31:\"Sun, 20 Jul 2008 01:42:05 -0700\";s:7:\"linkurl\";s:17:\"http://groparu.ro\";}s:7:\"summary\";s:429:\" adrian.filozofie.ro adrianpopa.ro ancaalexandrescu.ro/blog/ andreicrivat.ro antena2.tv ardeimedia.ro chinezu.eu danandronic.blogspot.com dianatusa.blogspot.com dragos.ro globe-trotter.ro/ziaruldela5 groparu.ro ilariont.blogspot.com ioniliescu.wordpress.com istoriacomunismului.blogspot.com jeg.ro jurnalul.ro mana.ciutacu.ro mesterulmanole.wordpress.com moshemordachai.wordpress.com nastase.wordpress.com oana-dobre.blogspot.com\";}i:3;a:9:{s:5:\"title\";s:24:\"Deci Clujul ruleazÄƒ fin\";s:4:\"link\";s:59:\"http://www.arhiblog.ro/2008/07/deci-clujul-ruleaza-fin.html\";s:8:\"comments\";s:100:\"http://technorati.com/search/http%3A%2F%2Fwww.arhiblog.ro%2F2008%2F07%2Fdeci-clujul-ruleaza-fin.html\";s:4:\"guid\";s:59:\"http://www.arhiblog.ro/2008/07/deci-clujul-ruleaza-fin.html\";s:7:\"pubdate\";s:31:\"Fri, 18 Jul 2008 19:57:32 +0000\";s:11:\"description\";s:501:\"eu, care mÄƒnÃ¢nc mult mai intens. Nu mai zic de beuturÄƒ. Am bÄƒut cu CrivÄƒÅ£ Ã®n astea douÄƒ zile de ne-a ieÅŸit pe urechi. Are omul o palincÄƒ de ZalÄƒu de innebuneÅŸti.   De fapt, palinca a fost motivul de bazÄƒ pentru care l-am sunat pe Groparu, sÄƒ Ã®i spunem cÄƒ Ã®l iubim ÅŸi cÄƒ e idolul nostru Ã®n viaÅ£Äƒ. Nu cÄƒ nu ar fi aÅŸa, dar fÄƒrÄƒ palincÄƒ nu aveam tupeu.  AÅŸa cÄƒ, dacÄƒ sunteÅ£i cu afaceri Ã®n Cluj ÅŸi vreÅ£i sÄƒ staÅ£i Ã®ntr-o locaÅ£ie elegantÄƒ, ÅŸtiÅ£i unde sÄƒ vÄƒ duceÅ£i.\";s:6:\"source\";s:4:\"ARHI\";s:4:\"tapi\";a:5:{s:6:\"rssurl\";s:27:\"http://www.arhiblog.ro/feed\";s:12:\"inboundblogs\";s:2:\"56\";s:12:\"inboundlinks\";s:2:\"88\";s:11:\"linkcreated\";s:31:\"Fri, 18 Jul 2008 12:57:32 -0700\";s:7:\"linkurl\";s:17:\"http://groparu.ro\";}s:7:\"summary\";s:501:\"eu, care mÄƒnÃ¢nc mult mai intens. Nu mai zic de beuturÄƒ. Am bÄƒut cu CrivÄƒÅ£ Ã®n astea douÄƒ zile de ne-a ieÅŸit pe urechi. Are omul o palincÄƒ de ZalÄƒu de innebuneÅŸti.   De fapt, palinca a fost motivul de bazÄƒ pentru care l-am sunat pe Groparu, sÄƒ Ã®i spunem cÄƒ Ã®l iubim ÅŸi cÄƒ e idolul nostru Ã®n viaÅ£Äƒ. Nu cÄƒ nu ar fi aÅŸa, dar fÄƒrÄƒ palincÄƒ nu aveam tupeu.  AÅŸa cÄƒ, dacÄƒ sunteÅ£i cu afaceri Ã®n Cluj ÅŸi vreÅ£i sÄƒ staÅ£i Ã®ntr-o locaÅ£ie elegantÄƒ, ÅŸtiÅ£i unde sÄƒ vÄƒ duceÅ£i.\";}i:4;a:9:{s:5:\"title\";s:17:\"Alo, iRealitatea?\";s:4:\"link\";s:44:\"http://xsolo.biz/2008/07/17/alo-irealitatea/\";s:8:\"comments\";s:89:\"http://technorati.com/search/http%3A%2F%2Fxsolo.biz%2F2008%2F07%2F17%2Falo-irealitatea%2F\";s:4:\"guid\";s:44:\"http://xsolo.biz/2008/07/17/alo-irealitatea/\";s:7:\"pubdate\";s:31:\"Thu, 17 Jul 2008 07:35:59 +0000\";s:11:\"description\";s:49:\" Blogroll  groparu kobeâ€™s climbing blog ruxx   \";s:6:\"source\";s:17:\"xsolo travel blog\";s:4:\"tapi\";a:6:{s:6:\"rssurl\";s:22:\"http://xsolo.biz/feed/\";s:7:\"atomurl\";s:27:\"http://xsolo.biz/feed/atom/\";s:12:\"inboundblogs\";s:1:\"6\";s:12:\"inboundlinks\";s:1:\"7\";s:11:\"linkcreated\";s:31:\"Thu, 17 Jul 2008 00:35:59 -0700\";s:7:\"linkurl\";s:22:\"http://www.groparu.ro/\";}s:7:\"summary\";s:49:\" Blogroll  groparu kobeâ€™s climbing blog ruxx   \";}i:5;a:9:{s:5:\"title\";s:13:\"Cum sa how to\";s:4:\"link\";s:42:\"http://xsolo.biz/2008/07/16/cum-sa-how-to/\";s:8:\"comments\";s:87:\"http://technorati.com/search/http%3A%2F%2Fxsolo.biz%2F2008%2F07%2F16%2Fcum-sa-how-to%2F\";s:4:\"guid\";s:42:\"http://xsolo.biz/2008/07/16/cum-sa-how-to/\";s:7:\"pubdate\";s:31:\"Wed, 16 Jul 2008 09:42:11 +0000\";s:11:\"description\";s:49:\" Blogroll  groparu kobeâ€™s climbing blog ruxx   \";s:6:\"source\";s:17:\"xsolo travel blog\";s:4:\"tapi\";a:6:{s:6:\"rssurl\";s:22:\"http://xsolo.biz/feed/\";s:7:\"atomurl\";s:27:\"http://xsolo.biz/feed/atom/\";s:12:\"inboundblogs\";s:1:\"6\";s:12:\"inboundlinks\";s:1:\"7\";s:11:\"linkcreated\";s:31:\"Wed, 16 Jul 2008 02:42:11 -0700\";s:7:\"linkurl\";s:22:\"http://www.groparu.ro/\";}s:7:\"summary\";s:49:\" Blogroll  groparu kobeâ€™s climbing blog ruxx   \";}i:6;a:9:{s:5:\"title\";s:6:\"Unegro\";s:4:\"link\";s:35:\"http://xsolo.biz/2008/07/15/unegro/\";s:8:\"comments\";s:80:\"http://technorati.com/search/http%3A%2F%2Fxsolo.biz%2F2008%2F07%2F15%2Funegro%2F\";s:4:\"guid\";s:35:\"http://xsolo.biz/2008/07/15/unegro/\";s:7:\"pubdate\";s:31:\"Tue, 15 Jul 2008 17:19:30 +0000\";s:11:\"description\";s:49:\" Blogroll  groparu kobeâ€™s climbing blog ruxx   \";s:6:\"source\";s:17:\"xsolo travel blog\";s:4:\"tapi\";a:6:{s:6:\"rssurl\";s:22:\"http://xsolo.biz/feed/\";s:7:\"atomurl\";s:27:\"http://xsolo.biz/feed/atom/\";s:12:\"inboundblogs\";s:1:\"6\";s:12:\"inboundlinks\";s:1:\"7\";s:11:\"linkcreated\";s:31:\"Tue, 15 Jul 2008 10:19:30 -0700\";s:7:\"linkurl\";s:22:\"http://www.groparu.ro/\";}s:7:\"summary\";s:49:\" Blogroll  groparu kobeâ€™s climbing blog ruxx   \";}i:7;a:9:{s:5:\"title\";s:10:\"Riverworld\";s:4:\"link\";s:39:\"http://xsolo.biz/2008/07/14/riverworld/\";s:8:\"comments\";s:84:\"http://technorati.com/search/http%3A%2F%2Fxsolo.biz%2F2008%2F07%2F14%2Friverworld%2F\";s:4:\"guid\";s:39:\"http://xsolo.biz/2008/07/14/riverworld/\";s:7:\"pubdate\";s:31:\"Mon, 14 Jul 2008 08:30:17 +0000\";s:11:\"description\";s:49:\" Blogroll  groparu kobeâ€™s climbing blog ruxx   \";s:6:\"source\";s:17:\"xsolo travel blog\";s:4:\"tapi\";a:6:{s:6:\"rssurl\";s:22:\"http://xsolo.biz/feed/\";s:7:\"atomurl\";s:27:\"http://xsolo.biz/feed/atom/\";s:12:\"inboundblogs\";s:1:\"6\";s:12:\"inboundlinks\";s:1:\"7\";s:11:\"linkcreated\";s:31:\"Mon, 14 Jul 2008 01:30:17 -0700\";s:7:\"linkurl\";s:22:\"http://www.groparu.ro/\";}s:7:\"summary\";s:49:\" Blogroll  groparu kobeâ€™s climbing blog ruxx   \";}i:8;a:9:{s:5:\"title\";s:7:\"Iceberg\";s:4:\"link\";s:36:\"http://xsolo.biz/2008/07/13/iceberg/\";s:8:\"comments\";s:81:\"http://technorati.com/search/http%3A%2F%2Fxsolo.biz%2F2008%2F07%2F13%2Ficeberg%2F\";s:4:\"guid\";s:36:\"http://xsolo.biz/2008/07/13/iceberg/\";s:7:\"pubdate\";s:31:\"Sun, 13 Jul 2008 11:14:28 +0000\";s:11:\"description\";s:49:\" Blogroll  groparu kobeâ€™s climbing blog ruxx   \";s:6:\"source\";s:17:\"xsolo travel blog\";s:4:\"tapi\";a:6:{s:6:\"rssurl\";s:22:\"http://xsolo.biz/feed/\";s:7:\"atomurl\";s:27:\"http://xsolo.biz/feed/atom/\";s:12:\"inboundblogs\";s:1:\"6\";s:12:\"inboundlinks\";s:1:\"7\";s:11:\"linkcreated\";s:31:\"Sun, 13 Jul 2008 04:14:28 -0700\";s:7:\"linkurl\";s:22:\"http://www.groparu.ro/\";}s:7:\"summary\";s:49:\" Blogroll  groparu kobeâ€™s climbing blog ruxx   \";}i:9;a:9:{s:5:\"title\";s:19:\"Tehnica frigaruilor\";s:4:\"link\";s:48:\"http://xsolo.biz/2008/07/12/tehnica-frigaruilor/\";s:8:\"comments\";s:93:\"http://technorati.com/search/http%3A%2F%2Fxsolo.biz%2F2008%2F07%2F12%2Ftehnica-frigaruilor%2F\";s:4:\"guid\";s:48:\"http://xsolo.biz/2008/07/12/tehnica-frigaruilor/\";s:7:\"pubdate\";s:31:\"Sat, 12 Jul 2008 21:23:45 +0000\";s:11:\"description\";s:49:\" Blogroll  groparu kobeâ€™s climbing blog ruxx   \";s:6:\"source\";s:17:\"xsolo travel blog\";s:4:\"tapi\";a:6:{s:6:\"rssurl\";s:22:\"http://xsolo.biz/feed/\";s:7:\"atomurl\";s:27:\"http://xsolo.biz/feed/atom/\";s:12:\"inboundblogs\";s:1:\"6\";s:12:\"inboundlinks\";s:1:\"7\";s:11:\"linkcreated\";s:31:\"Sat, 12 Jul 2008 14:23:45 -0700\";s:7:\"linkurl\";s:22:\"http://www.groparu.ro/\";}s:7:\"summary\";s:49:\" Blogroll  groparu kobeâ€™s climbing blog ruxx   \";}i:10;a:9:{s:5:\"title\";s:19:\"Si dupa cum spuneam\";s:4:\"link\";s:48:\"http://xsolo.biz/2008/07/11/si-dupa-cum-spuneam/\";s:8:\"comments\";s:93:\"http://technorati.com/search/http%3A%2F%2Fxsolo.biz%2F2008%2F07%2F11%2Fsi-dupa-cum-spuneam%2F\";s:4:\"guid\";s:48:\"http://xsolo.biz/2008/07/11/si-dupa-cum-spuneam/\";s:7:\"pubdate\";s:31:\"Fri, 11 Jul 2008 22:05:43 +0000\";s:11:\"description\";s:49:\" Blogroll  groparu kobeâ€™s climbing blog ruxx   \";s:6:\"source\";s:17:\"xsolo travel blog\";s:4:\"tapi\";a:6:{s:6:\"rssurl\";s:22:\"http://xsolo.biz/feed/\";s:7:\"atomurl\";s:27:\"http://xsolo.biz/feed/atom/\";s:12:\"inboundblogs\";s:1:\"6\";s:12:\"inboundlinks\";s:1:\"7\";s:11:\"linkcreated\";s:31:\"Fri, 11 Jul 2008 15:05:43 -0700\";s:7:\"linkurl\";s:22:\"http://www.groparu.ro/\";}s:7:\"summary\";s:49:\" Blogroll  groparu kobeâ€™s climbing blog ruxx   \";}i:11;a:9:{s:5:\"title\";s:6:\"sammas\";s:4:\"link\";s:20:\"http://sam.weblog.ro\";s:8:\"comments\";s:20:\"/blogs/sam.weblog.ro\";s:4:\"guid\";s:20:\"/blogs/sam.weblog.ro\";s:7:\"pubdate\";s:31:\"Thu, 10 Jul 2008 08:26:32 +0000\";s:11:\"description\";s:151:\" Lista Favorite adrian calarasu  BC  magdici  groparu  domnu\' inginer  dorianboy  Cristina  rusoaica  Dulce Mahala  zully mustafa  v  domnu\' doctor    \";s:6:\"source\";s:6:\"sammas\";s:4:\"tapi\";a:6:{s:6:\"rssurl\";s:25:\"http://sam.weblog.ro/feed\";s:7:\"atomurl\";s:30:\"http://sam.weblog.ro/feed/atom\";s:12:\"inboundblogs\";s:1:\"2\";s:12:\"inboundlinks\";s:1:\"2\";s:11:\"linkcreated\";s:31:\"Thu, 10 Jul 2008 01:26:32 -0700\";s:7:\"linkurl\";s:22:\"http://www.groparu.ro/\";}s:7:\"summary\";s:151:\" Lista Favorite adrian calarasu  BC  magdici  groparu  domnu\' inginer  dorianboy  Cristina  rusoaica  Dulce Mahala  zully mustafa  v  domnu\' doctor    \";}i:12;a:9:{s:5:\"title\";s:13:\"ce nu spun ;)\";s:4:\"link\";s:25:\"http://andera4u.weblog.ro\";s:8:\"comments\";s:25:\"/blogs/andera4u.weblog.ro\";s:4:\"guid\";s:25:\"/blogs/andera4u.weblog.ro\";s:7:\"pubdate\";s:31:\"Thu, 10 Jul 2008 08:22:32 +0000\";s:11:\"description\";s:148:\" Lista Favorite Retoric  Groparu\' Clujeanu\'  Pitzi  Ligia - via Morar  Cabral  Jeg  Blonde  Chirila - Vama  Morar  tirowka  Jurnalul unei amante    \";s:6:\"source\";s:13:\"ce nu spun ;)\";s:4:\"tapi\";a:6:{s:6:\"rssurl\";s:30:\"http://andera4u.weblog.ro/feed\";s:7:\"atomurl\";s:35:\"http://andera4u.weblog.ro/feed/atom\";s:12:\"inboundblogs\";s:1:\"0\";s:12:\"inboundlinks\";s:1:\"0\";s:11:\"linkcreated\";s:31:\"Thu, 10 Jul 2008 01:22:32 -0700\";s:7:\"linkurl\";s:21:\"http://www.groparu.ro\";}s:7:\"summary\";s:148:\" Lista Favorite Retoric  Groparu\' Clujeanu\'  Pitzi  Ligia - via Morar  Cabral  Jeg  Blonde  Chirila - Vama  Morar  tirowka  Jurnalul unei amante    \";}i:13;a:9:{s:5:\"title\";s:17:\"Le Tour de France\";s:4:\"link\";s:46:\"http://xsolo.biz/2008/07/10/le-tour-de-france/\";s:8:\"comments\";s:91:\"http://technorati.com/search/http%3A%2F%2Fxsolo.biz%2F2008%2F07%2F10%2Fle-tour-de-france%2F\";s:4:\"guid\";s:46:\"http://xsolo.biz/2008/07/10/le-tour-de-france/\";s:7:\"pubdate\";s:31:\"Thu, 10 Jul 2008 03:19:04 +0000\";s:11:\"description\";s:49:\" Blogroll  groparu kobeâ€™s climbing blog ruxx   \";s:6:\"source\";s:17:\"xsolo travel blog\";s:4:\"tapi\";a:6:{s:6:\"rssurl\";s:22:\"http://xsolo.biz/feed/\";s:7:\"atomurl\";s:27:\"http://xsolo.biz/feed/atom/\";s:12:\"inboundblogs\";s:1:\"6\";s:12:\"inboundlinks\";s:1:\"7\";s:11:\"linkcreated\";s:31:\"Wed, 09 Jul 2008 20:19:04 -0700\";s:7:\"linkurl\";s:22:\"http://www.groparu.ro/\";}s:7:\"summary\";s:49:\" Blogroll  groparu kobeâ€™s climbing blog ruxx   \";}i:14;a:9:{s:5:\"title\";s:21:\"Me, Jamaica & P.Diana\";s:4:\"link\";s:46:\"http://xsolo.biz/2008/07/08/me-jamaica-pdiana/\";s:8:\"comments\";s:91:\"http://technorati.com/search/http%3A%2F%2Fxsolo.biz%2F2008%2F07%2F08%2Fme-jamaica-pdiana%2F\";s:4:\"guid\";s:46:\"http://xsolo.biz/2008/07/08/me-jamaica-pdiana/\";s:7:\"pubdate\";s:31:\"Tue, 08 Jul 2008 13:13:41 +0000\";s:11:\"description\";s:49:\" Blogroll  groparu kobeâ€™s climbing blog ruxx   \";s:6:\"source\";s:17:\"xsolo travel blog\";s:4:\"tapi\";a:6:{s:6:\"rssurl\";s:22:\"http://xsolo.biz/feed/\";s:7:\"atomurl\";s:27:\"http://xsolo.biz/feed/atom/\";s:12:\"inboundblogs\";s:1:\"6\";s:12:\"inboundlinks\";s:1:\"7\";s:11:\"linkcreated\";s:31:\"Tue, 08 Jul 2008 06:13:41 -0700\";s:7:\"linkurl\";s:22:\"http://www.groparu.ro/\";}s:7:\"summary\";s:49:\" Blogroll  groparu kobeâ€™s climbing blog ruxx   \";}i:15;a:9:{s:5:\"title\";s:10:\"Cafeina.ro\";s:4:\"link\";s:17:\"http://cafeina.ro\";s:8:\"comments\";s:17:\"/blogs/cafeina.ro\";s:4:\"guid\";s:17:\"/blogs/cafeina.ro\";s:7:\"pubdate\";s:31:\"Tue, 08 Jul 2008 09:05:04 +0000\";s:11:\"description\";s:155:\" Pe cine citesc  Adrian Boioglu Adrian Ciubotaru Cabral ContraSENS Cristian Sutu Fluture Groparuâ€™ No excuses Povestea vorbei Silviu Brizu Subiectiv.ro   \";s:6:\"source\";s:10:\"Cafeina.ro\";s:4:\"tapi\";a:5:{s:6:\"rssurl\";s:23:\"http://cafeina.ro/feed/\";s:12:\"inboundblogs\";s:2:\"19\";s:12:\"inboundlinks\";s:2:\"46\";s:11:\"linkcreated\";s:31:\"Tue, 08 Jul 2008 02:05:04 -0700\";s:7:\"linkurl\";s:22:\"http://www.groparu.ro/\";}s:7:\"summary\";s:155:\" Pe cine citesc  Adrian Boioglu Adrian Ciubotaru Cabral ContraSENS Cristian Sutu Fluture Groparuâ€™ No excuses Povestea vorbei Silviu Brizu Subiectiv.ro   \";}i:16;a:9:{s:5:\"title\";s:12:\"Pousada Cuba\";s:4:\"link\";s:41:\"http://xsolo.biz/2008/07/07/pousada-cuba/\";s:8:\"comments\";s:86:\"http://technorati.com/search/http%3A%2F%2Fxsolo.biz%2F2008%2F07%2F07%2Fpousada-cuba%2F\";s:4:\"guid\";s:41:\"http://xsolo.biz/2008/07/07/pousada-cuba/\";s:7:\"pubdate\";s:31:\"Mon, 07 Jul 2008 10:25:28 +0000\";s:11:\"description\";s:49:\" Blogroll  groparu kobeâ€™s climbing blog ruxx   \";s:6:\"source\";s:17:\"xsolo travel blog\";s:4:\"tapi\";a:6:{s:6:\"rssurl\";s:22:\"http://xsolo.biz/feed/\";s:7:\"atomurl\";s:27:\"http://xsolo.biz/feed/atom/\";s:12:\"inboundblogs\";s:1:\"6\";s:12:\"inboundlinks\";s:1:\"7\";s:11:\"linkcreated\";s:31:\"Mon, 07 Jul 2008 03:25:28 -0700\";s:7:\"linkurl\";s:22:\"http://www.groparu.ro/\";}s:7:\"summary\";s:49:\" Blogroll  groparu kobeâ€™s climbing blog ruxx   \";}i:17;a:9:{s:5:\"title\";s:4:\"ARHI\";s:4:\"link\";s:22:\"http://www.arhiblog.ro\";s:8:\"comments\";s:22:\"/blogs/www.arhiblog.ro\";s:4:\"guid\";s:22:\"/blogs/www.arhiblog.ro\";s:7:\"pubdate\";s:31:\"Sun, 06 Jul 2008 22:09:04 +0000\";s:11:\"description\";s:287:\"Desspina, Laura Driha, Rottenkizii, Femeia simpla, Gramo`s World, Opinii fara diacritice, Kapra`s Blog, Robintel, Cipoc, Lumea Nwradu, Badjoke, limpede, pisicainbocanci, Bloggerita, swamp, CrivÄƒÅ£, Cabral, Groparu, Cazare Eforie Sud Statistici   GTop.ro - tu unde te pozitionezi ?      \";s:6:\"source\";s:4:\"ARHI\";s:4:\"tapi\";a:5:{s:6:\"rssurl\";s:27:\"http://www.arhiblog.ro/feed\";s:12:\"inboundblogs\";s:2:\"56\";s:12:\"inboundlinks\";s:2:\"88\";s:11:\"linkcreated\";s:31:\"Sun, 06 Jul 2008 15:09:04 -0700\";s:7:\"linkurl\";s:18:\"http://groparu.ro/\";}s:7:\"summary\";s:287:\"Desspina, Laura Driha, Rottenkizii, Femeia simpla, Gramo`s World, Opinii fara diacritice, Kapra`s Blog, Robintel, Cipoc, Lumea Nwradu, Badjoke, limpede, pisicainbocanci, Bloggerita, swamp, CrivÄƒÅ£, Cabral, Groparu, Cazare Eforie Sud Statistici   GTop.ro - tu unde te pozitionezi ?      \";}i:18;a:9:{s:5:\"title\";s:13:\"Soul Medicine\";s:4:\"link\";s:42:\"http://xsolo.biz/2008/07/06/soul-medicine/\";s:8:\"comments\";s:87:\"http://technorati.com/search/http%3A%2F%2Fxsolo.biz%2F2008%2F07%2F06%2Fsoul-medicine%2F\";s:4:\"guid\";s:42:\"http://xsolo.biz/2008/07/06/soul-medicine/\";s:7:\"pubdate\";s:31:\"Sun, 06 Jul 2008 03:43:45 +0000\";s:11:\"description\";s:49:\" Blogroll  groparu kobeâ€™s climbing blog ruxx   \";s:6:\"source\";s:17:\"xsolo travel blog\";s:4:\"tapi\";a:6:{s:6:\"rssurl\";s:22:\"http://xsolo.biz/feed/\";s:7:\"atomurl\";s:27:\"http://xsolo.biz/feed/atom/\";s:12:\"inboundblogs\";s:1:\"6\";s:12:\"inboundlinks\";s:1:\"7\";s:11:\"linkcreated\";s:31:\"Sat, 05 Jul 2008 20:43:45 -0700\";s:7:\"linkurl\";s:22:\"http://www.groparu.ro/\";}s:7:\"summary\";s:49:\" Blogroll  groparu kobeâ€™s climbing blog ruxx   \";}i:19;a:9:{s:5:\"title\";s:60:\"â€žDe CrÄƒciun, sÄƒ omorÃ¢Å£i porcul cu responsabilitate!â€œ\";s:4:\"link\";s:95:\"http://xsolo.biz/2008/07/05/%e2%80%9ede-craciun-sa-omorati-porcul-cu-responsabilitate%e2%80%9c/\";s:8:\"comments\";s:152:\"http://technorati.com/search/http%3A%2F%2Fxsolo.biz%2F2008%2F07%2F05%2F%25e2%2580%259ede-craciun-sa-omorati-porcul-cu-responsabilitate%25e2%2580%259c%2F\";s:4:\"guid\";s:95:\"http://xsolo.biz/2008/07/05/%e2%80%9ede-craciun-sa-omorati-porcul-cu-responsabilitate%e2%80%9c/\";s:7:\"pubdate\";s:31:\"Sat, 05 Jul 2008 09:26:16 +0000\";s:11:\"description\";s:49:\" Blogroll  groparu kobeâ€™s climbing blog ruxx   \";s:6:\"source\";s:17:\"xsolo travel blog\";s:4:\"tapi\";a:6:{s:6:\"rssurl\";s:22:\"http://xsolo.biz/feed/\";s:7:\"atomurl\";s:27:\"http://xsolo.biz/feed/atom/\";s:12:\"inboundblogs\";s:1:\"6\";s:12:\"inboundlinks\";s:1:\"7\";s:11:\"linkcreated\";s:31:\"Sat, 05 Jul 2008 02:26:16 -0700\";s:7:\"linkurl\";s:22:\"http://www.groparu.ro/\";}s:7:\"summary\";s:49:\" Blogroll  groparu kobeâ€™s climbing blog ruxx   \";}}s:7:\"channel\";a:11:{s:5:\"title\";s:40:\"Blog reactions to http://www.groparu.ro/\";s:4:\"link\";s:59:\"http://technorati.com/search/http%3A%2F%2Fwww.groparu.ro%2F\";s:11:\"description\";s:59:\"Blog posts linking to http://www.groparu.ro/ on Technorati.\";s:7:\"pubdate\";s:31:\"Fri, 25 Jul 2008 00:23:16 -0700\";s:9:\"generator\";s:15:\"Technorati v1.0\";s:9:\"webmaster\";s:43:\"support@technorati.com (Technorati Support)\";s:4:\"docs\";s:37:\"http://blogs.law.harvard.edu/tech/rss\";s:3:\"ttl\";s:2:\"60\";s:4:\"tapi\";a:3:{s:6:\"result\";s:5:\"\n    \";s:10:\"result_url\";s:22:\"http://www.groparu.ro/\";s:19:\"result_inboundlinks\";s:3:\"593\";}s:6:\"result\";s:10:\"\n    \n    \";s:7:\"tagline\";s:59:\"Blog posts linking to http://www.groparu.ro/ on Technorati.\";}s:9:\"textinput\";a:0:{}s:5:\"image\";a:3:{s:3:\"url\";s:50:\"http://static.technorati.com/pix/logos/logo_sm.gif\";s:5:\"title\";s:15:\"Technorati logo\";s:4:\"link\";s:59:\"http://technorati.com/search/http%3A%2F%2Fwww.groparu.ro%2F\";}s:9:\"feed_type\";s:3:\"RSS\";s:12:\"feed_version\";s:3:\"2.0\";s:5:\"stack\";a:0:{}s:9:\"inchannel\";b:0;s:6:\"initem\";b:0;s:9:\"incontent\";b:0;s:11:\"intextinput\";b:0;s:7:\"inimage\";b:0;s:13:\"current_field\";s:0:\"\";s:17:\"current_namespace\";b:0;s:19:\"_CONTENT_CONSTRUCTS\";a:6:{i:0;s:7:\"content\";i:1;s:7:\"summary\";i:2;s:4:\"info\";i:3;s:5:\"title\";i:4;s:7:\"tagline\";i:5;s:9:\"copyright\";}}','no'),(71,0,'rss_e0606a1ed20504810e7f40fde29a91dd_ts','1216970449','no'),(72,0,'rss_0ff4b43bd116a9d8720d689c80e7dfd4','O:9:\"MagpieRSS\":19:{s:6:\"parser\";i:0;s:12:\"current_item\";a:0:{}s:5:\"items\";a:10:{i:0;a:12:{s:5:\"title\";s:15:\"Theme Directory\";s:4:\"link\";s:57:\"http://wordpress.org/development/2008/07/theme-directory/\";s:8:\"comments\";s:66:\"http://wordpress.org/development/2008/07/theme-directory/#comments\";s:7:\"pubdate\";s:31:\"Fri, 18 Jul 2008 06:11:13 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:12:\"Joseph Scott\";}s:8:\"category\";s:10:\"Metathemes\";s:4:\"guid\";s:39:\"http://wordpress.org/development/?p=266\";s:11:\"description\";s:353:\"It&#8217;s been a long time since themes.wordpress.net stopped accepting new themes.  Since then most theme authors have been distributing their themes from their own sites, without a good centralized place for people to browse, search, comment on, and rate themes.  With the success of the plugins directory, we&#8217;ve wanted to have those same [...]\";s:7:\"content\";a:1:{s:7:\"encoded\";s:2453:\"<p>It&#8217;s been a long time since <a href=\"http://themes.wordpress.net/blog/4426/upcoming-changes/\">themes.wordpress.net</a> stopped accepting new themes.  Since then most theme authors have been distributing their themes from their own sites, without a good centralized place for people to browse, search, comment on, and rate themes.  With the success of the <a href=\"http://wordpress.org/extend/plugins/\">plugins directory</a>, we&#8217;ve wanted to have those same benefits in a theme directory.  Today is the day we start making that happen, with the introduction of <a href=\"http://wordpress.org/extend/themes/\">wordpress.org/extend/themes/</a>.</p>\n<p>Bringing the new theme directory under the WordPress &#8220;<a href=\"http://wordpress.org/extend/\">extend</a>&#8221; umbrella allowed us to take advantage of all the infrastructure that has already been built up to support WordPress.org.  If you&#8217;ve browsed through the plugin directory, you&#8217;ll feel right at home in the new theme directory.</p>\n<p>We&#8217;ve gone through great lengths to make this as painless as possible for theme authors.  You don&#8217;t need to know anything about Subversion (our back end magic takes care of all that for you), just login with your WordPress.org username and password and go to the <a href=\"http://wordpress.org/extend/themes/upload/\">upload page</a>.  From there you upload your regular theme zip file and we take care of the rest.</p>\n<p>Once you upload your new theme we do a few automated checks for some of the <a href=\"http://wordpress.org/extend/themes/about/#requirements\">requirements</a> for each theme.  If we find one that you missed we&#8217;ll provide you an error and description of what needs to be fixed.  When a theme upload has been accepted we&#8217;ll send you an email and put it in the queue to be reviewed, to make sure we didn&#8217;t miss anything.  After the theme has been approved you&#8217;ll get another email letting you know that the theme is now live.</p>\n<p>That catches you up to where we&#8217;re at today.  When you finish that theme you&#8217;ve been slaving over, upload it to the new directory and let us know what you think. Since so much has changed since the old theme directory we&#8217;re starting fresh from zero. If you&#8217;ve got specific questions or suggestions <a href=\"http://wordpress.org/extend/themes/contact/\">contact us</a> and we&#8217;ll do our best to get them answered.</p>\n\";}s:3:\"wfw\";a:1:{s:10:\"commentrss\";s:62:\"http://wordpress.org/development/2008/07/theme-directory/feed/\";}s:7:\"summary\";s:353:\"It&#8217;s been a long time since themes.wordpress.net stopped accepting new themes.  Since then most theme authors have been distributing their themes from their own sites, without a good centralized place for people to browse, search, comment on, and rate themes.  With the success of the plugins directory, we&#8217;ve wanted to have those same [...]\";s:12:\"atom_content\";s:2453:\"<p>It&#8217;s been a long time since <a href=\"http://themes.wordpress.net/blog/4426/upcoming-changes/\">themes.wordpress.net</a> stopped accepting new themes.  Since then most theme authors have been distributing their themes from their own sites, without a good centralized place for people to browse, search, comment on, and rate themes.  With the success of the <a href=\"http://wordpress.org/extend/plugins/\">plugins directory</a>, we&#8217;ve wanted to have those same benefits in a theme directory.  Today is the day we start making that happen, with the introduction of <a href=\"http://wordpress.org/extend/themes/\">wordpress.org/extend/themes/</a>.</p>\n<p>Bringing the new theme directory under the WordPress &#8220;<a href=\"http://wordpress.org/extend/\">extend</a>&#8221; umbrella allowed us to take advantage of all the infrastructure that has already been built up to support WordPress.org.  If you&#8217;ve browsed through the plugin directory, you&#8217;ll feel right at home in the new theme directory.</p>\n<p>We&#8217;ve gone through great lengths to make this as painless as possible for theme authors.  You don&#8217;t need to know anything about Subversion (our back end magic takes care of all that for you), just login with your WordPress.org username and password and go to the <a href=\"http://wordpress.org/extend/themes/upload/\">upload page</a>.  From there you upload your regular theme zip file and we take care of the rest.</p>\n<p>Once you upload your new theme we do a few automated checks for some of the <a href=\"http://wordpress.org/extend/themes/about/#requirements\">requirements</a> for each theme.  If we find one that you missed we&#8217;ll provide you an error and description of what needs to be fixed.  When a theme upload has been accepted we&#8217;ll send you an email and put it in the queue to be reviewed, to make sure we didn&#8217;t miss anything.  After the theme has been approved you&#8217;ll get another email letting you know that the theme is now live.</p>\n<p>That catches you up to where we&#8217;re at today.  When you finish that theme you&#8217;ve been slaving over, upload it to the new directory and let us know what you think. Since so much has changed since the old theme directory we&#8217;re starting fresh from zero. If you&#8217;ve got specific questions or suggestions <a href=\"http://wordpress.org/extend/themes/contact/\">contact us</a> and we&#8217;ll do our best to get them answered.</p>\n\";}i:1;a:12:{s:5:\"title\";s:13:\"WordPress 2.6\";s:4:\"link\";s:60:\"http://wordpress.org/development/2008/07/wordpress-26-tyner/\";s:8:\"comments\";s:69:\"http://wordpress.org/development/2008/07/wordpress-26-tyner/#comments\";s:7:\"pubdate\";s:31:\"Tue, 15 Jul 2008 03:38:42 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Matt\";}s:8:\"category\";s:8:\"Releases\";s:4:\"guid\";s:39:\"http://wordpress.org/development/?p=246\";s:11:\"description\";s:340:\" I&#8217;m happy to announce that version 2.6 of WordPress.org is now available, almost a month ahead schedule. Version 2.6 &#8220;Tyner,&#8221; named for jazz pianist McCoy Tyner, contains a number of new features that make WordPress a more powerful CMS: you can now track changes to every post and page and easily post from wherever [...]\";s:7:\"content\";a:1:{s:7:\"encoded\";s:10270:\"<p><iframe src=\'http://digg.com/api/diggthis.php?u=http%3A%2F%2Fdigg.com%2Fsoftware%2FWordPress_2_6_Tyner_Released\' height=\'82\' width=\'55\' frameborder=\'0\' scrolling=\'no\' style=\'float: right; margin-left: 10px; margin-bottom: 5px; padding: 4px 0 2px 4px; background: #fff;\'></iframe> I&#8217;m happy to announce that version 2.6 of WordPress.org <a href=\"http://wordpress.org/download/\">is now available</a>, almost a month ahead schedule. Version 2.6 &#8220;Tyner,&#8221; named for jazz pianist <a href=\"http://en.wikipedia.org/wiki/McCoy_Tyner\">McCoy Tyner</a>, contains a number of new features that make WordPress a more powerful CMS: you can now track changes to every post and page and easily post from wherever you are on the web, plus there are dozens of incremental improvements to the features introduced in <a href=\"http://wordpress.org/development/2008/03/wordpress-25-brecker/\">version 2.5</a>.</p>\n<p>We&#8217;ve prepared a brief video tour of 2.6, if you have 3 minutes and 29 seconds to spare, it&#8217;s worth a watch:</p>\n<p><embed src=\"http://v.wordpress.com/mARhRBcT/fmt_dvd\" type=\"application/x-shockwave-flash\" width=\"640\" height=\"385\" flashvars=\"blog_domain=http://wordpress.org/development/2008/07/wordpress-26/&#038;width=640&#038;height=385\"> </embed></p>\n<p>If you&#8217;d like to embed the tour video in your blog, copy and paste this code for the high quality version:</p>\n<pre name=\"code\" class=\"html\">\n&lt;embed src=&quot;http://v.wordpress.com/mARhRBcT/fmt_dvd&quot; type=&quot;application/x-shockwave-flash&quot; width=&quot;640&quot; height=&quot;385&quot; flashvars=&quot;blog_domain=http://wordpress.org/development/2008/07/wordpress-26/&amp;width=640&amp;height=385&quot;&gt; &lt;/embed&gt;\n</pre>\n<p>And here&#8217;s a smaller version, 400 pixels wide:</p>\n<pre name=\"code\" class=\"html\">\n&lt;embed src=&quot;http://v.wordpress.com/mARhRBcT/fmt_std&quot; type=&quot;application/x-shockwave-flash&quot; width=&quot;400&quot; height=&quot;250&quot; flashvars=&quot;blog_domain=http://wordpress.org/development/2008/07/wordpress-26/&amp;width=400&amp;height=250&quot;&gt; &lt;/embed&gt;\n</pre>\n<p>Here&#8217;s a more textual overview of what&#8217;s hawt in 2.6:</p>\n<h3>Post Revisions: Wiki-like tracking of edits</h3>\n<p>With the power of modern computers, it&#8217;s silly that we still use save and editing metaphors from the time when the most common method of storage was floppy disks. WordPress has always respected the importance of your writing with auto-save, and now we&#8217;re taking that to another level by allowing you to view who made what changes when to any post or page through a super-easy interface, much like <a href=\"http://en.wikipedia.org/w/index.php?title=Wikipedia&#038;action=history\">Wikipedia</a> or a <a href=\"http://codex.wordpress.org/Using_Subversion\">version control system</a>.</p>\n<p><img src=\"http://wpdotorg.wordpress.com/files/2008/07/diff.gif\" alt=\"Differences between two versions of posts.\" class=\"alignnone size-full wp-image-3\" /></p>\n<p>This is handy on any blog in case you make a mistake and want to go back to an older version of a post, and it&#8217;s super handy for multi-author blogs where you can see every change tracked by person.</p>\n<h3>Press This!: Post from wherever you are on the web</h3>\n<p>A few months ago on my blog we <a href=\"http://ma.tt/2008/05/favorite-posting-bookmarklet/\">started a conversation about the posting bookmarklet</a> in WordPress and which systems we should look to for inspiration, like Flock, FriendFeed, Facebook, Tumblr, and Delicious. From these suggestions and the Quick Post plugin by Josh Kenzer, we developed a Press This bookmark you can add to your toolbar that provides a fast and smart popup to do posts to your WordPress blog:</p>\n<p><img src=\"http://wpdotorg.wordpress.com/files/2008/07/press-this.gif\" alt=\"Screenshot of Press This interface.\" title=\"press-this\" class=\"alignnone size-full wp-image-4\" /></p>\n<p>For example, if you click &#8220;Press This&#8221; from a <a href=\"http://youtube.com/\">Youtube</a> page it&#8217;ll magically extract the video embed code, and if you do it from a <a href=\"http://flickr.com/\">Flickr</a> page it&#8217;ll make it easy for you to put the image in your post. On my blog I&#8217;ve been experimenting with using different categories and the <code>in_category()</code> function &#8212; such as video, quote, aside, et cetera &#8212; to create a more tumblelog-like format.</p>\n<h3>Shift Gears: Turbo-speed your blogging</h3>\n<p><a href=\"http://gears.google.com/\">Gears</a> is an open source browser extension project started by Google that developers like us can use to give you features we wouldn&#8217;t normally be able to. There are a lot of things we can do with Gears in the future, but in this release we&#8217;ve stuck to using what&#8217;s called a &#8220;Local Server&#8221; to cache or keep a copy of commonly-used Javascript and CSS files on your computer, which can speed up the loading of some pages by several seconds (they just pop right up!). You can install Gears for Firefox or Internet Explorer, with support for Safari and Opera pending. WordPress works just fine without it, you just get a little extra juice when you have it installed.</p>\n<h3>Theme Previews: See it before your audience does</h3>\n<p>Now when you select a theme it pops up a window that shows the theme live with all your content, instead of immediately making it active on your site. This is great for just test driving themes before making a switch over publicly, and it is also helpful when you are developing a theme and need to test it but don&#8217;t want everybody to see your ongoing <del datetime=\"2008-07-14T21:23:41+00:00\">mistakes</del> development.</p>\n<p>Here are some of the smaller features and improvements in 2.6:</p>\n<ul>\n<li><strong>Word count!</strong> Never guess how many words are in your post anymore.</li>\n<li><strong>Image captions</strong>, so you can add sweet captions <a href=\"http://politicalticker.blogs.cnn.com/\">like Political Ticker does</a> under your images.</li>\n<li><strong>Bulk management</strong> of plugins.</li>\n<li>A completely <strong>revamped image control</strong> to allow for easier inserting, floating, and resizing. It&#8217;s now fully integrated with the WYSIWYG.</li>\n<li>Drag-and-drop <strong>reordering of Galleries</strong>.</li>\n<li><strong>Plugin update</strong> notification bubble.</li>\n<li>Customizable default avatars.</li>\n<li>You can now upload media when in full-screen mode.</li>\n<li>Remote publishing via XML-RPC and APP is now secure (off) by default, but you can turn it on easily through the options screen.</li>\n<li>Full <a href=\"http://en.wikipedia.org/wiki/Secure_Sockets_Layer\">SSL support</a> in the core, and the ability to <strong>force SSL</strong> for security.</li>\n<li>You can now have many thousands of pages or categories with no interface issues.</li>\n<li>Ability to move your <code>wp-config</code> file and <code>wp-content</code> directories to a custom location, for &#8220;clean&#8221; SVN checkouts.</li>\n<li>Select a range of checkboxes with &#8220;shift-click.&#8221;</li>\n<li>You can toggle between the Flash uploader and the classic one.</li>\n<li>A number of proactive security enhancements, including cookies and database interactions.</li>\n<li>Stronger better faster versions of TinyMCE, jQuery, and jQuery UI.</li>\n<li>Version 2.6 <a href=\"http://trac.wordpress.org/query?status=closed&#038;milestone=2.6\">fixes approximately 194 bugs</a>.</li>\n</ul>\n<h3>Developer Notes</h3>\n<p>WordPress.org had over 75 people contributing code to WordPress 2.6. In addition to the <a href=\"http://wordpress.org/about/\">core commit team</a> we had contributions from <a href=\"http://dd32.id.au/\">Dion Hulse</a>, <a href=\"http://www.ilfilosofo.com/\">Austin Matzko</a>, <a href=\"http://ottodestruct.com/blog/\">Otto42</a>, <a href=\"http://extralogical.net/\">Benedict Eastaugh</a>, and <a href=\"http://www.freecharity.org.uk/\">pishmishy</a>. <a href=\"http://xavisys.com/\">AaronCampbell</a> and <a href=\"http://www.marcozehe.de/\">Marco Zehe</a> provided more than a few patches. Back among the top code contributors is <a href=\"http://www.santosj.name/\">Jacob Santos</a>. <a href=\"http://www.buayacorp.com/\">Alex Concha</a> continues to have WordPress&#8217; back. Joining bug reporting and gardening elite are <a href=\"http://codex.wordpress.org/User:Hakre\">hakre</a>, <a href=\"http://www.simonwheatley.co.uk/\">Simon Wheatley</a>, mtekk, and <a href=\"http://www.prescriber.org.uk/\">Matty Rob</a>. Finally, congratulations to our <a href=\"http://westi.wordpress.com/\">Peter Westwood</a> on your recent wedding! I&#8217;m also proud to announce we&#8217;re adding a new core committer to the team: Andrew Ozz (azaozz) has been a huge help to the core team this year, particularly around TinyMCE and making the WYSIWYG something that works for you, not against you.</p>\n<p>Because of the new capabilities to make WordPress a clean SVN checkout, plugin and theme authors should do their best to handle forms and posts through WP rather than trying to post to their files directly, here&#8217;s a quick Codex article about <a href=\"http://codex.wordpress.org/Handling_POST_and_AJAX_Requests\">how to do it using our forward-compatible APIs</a>.</p>\n<h3>Upgrading</h3>\n<p>2.6 is pretty much identical to 2.5 from a plugin and theme compatibility point of view, so upgrades from 2.5 should be pretty painless. The 2.5 branch will no longer be maintain so everyone is encouraged to upgrade. <a href=\"http://codex.wordpress.org/Upgrading_WordPress\">Our standard 3-step upgrade instructions apply to this release</a>. There were at least 1,984,047 downloads of the 2.5 series, the fastest growing release we&#8217;ve ever had, and I think all of those people will find 2.6 adds a level of polish that really makes WP a pleasure to use every day. (At least I do. :))</p>\n<h3>Easter Egg</h3>\n<p>There have been rumors and allegations that there was a so-called &#8220;easter egg&#8221; added to 2.6 early in its development. These rumors and allegations are completely false!</p>\n<p>P.S. If you&#8217;re a fan of WordPress, <a href=\"http://www.facebook.com/pages/WordPress/6427302910\">consider joining our fan page on Facebook</a>.</p>\n\";}s:3:\"wfw\";a:1:{s:10:\"commentrss\";s:65:\"http://wordpress.org/development/2008/07/wordpress-26-tyner/feed/\";}s:7:\"summary\";s:340:\" I&#8217;m happy to announce that version 2.6 of WordPress.org is now available, almost a month ahead schedule. Version 2.6 &#8220;Tyner,&#8221; named for jazz pianist McCoy Tyner, contains a number of new features that make WordPress a more powerful CMS: you can now track changes to every post and page and easily post from wherever [...]\";s:12:\"atom_content\";s:10270:\"<p><iframe src=\'http://digg.com/api/diggthis.php?u=http%3A%2F%2Fdigg.com%2Fsoftware%2FWordPress_2_6_Tyner_Released\' height=\'82\' width=\'55\' frameborder=\'0\' scrolling=\'no\' style=\'float: right; margin-left: 10px; margin-bottom: 5px; padding: 4px 0 2px 4px; background: #fff;\'></iframe> I&#8217;m happy to announce that version 2.6 of WordPress.org <a href=\"http://wordpress.org/download/\">is now available</a>, almost a month ahead schedule. Version 2.6 &#8220;Tyner,&#8221; named for jazz pianist <a href=\"http://en.wikipedia.org/wiki/McCoy_Tyner\">McCoy Tyner</a>, contains a number of new features that make WordPress a more powerful CMS: you can now track changes to every post and page and easily post from wherever you are on the web, plus there are dozens of incremental improvements to the features introduced in <a href=\"http://wordpress.org/development/2008/03/wordpress-25-brecker/\">version 2.5</a>.</p>\n<p>We&#8217;ve prepared a brief video tour of 2.6, if you have 3 minutes and 29 seconds to spare, it&#8217;s worth a watch:</p>\n<p><embed src=\"http://v.wordpress.com/mARhRBcT/fmt_dvd\" type=\"application/x-shockwave-flash\" width=\"640\" height=\"385\" flashvars=\"blog_domain=http://wordpress.org/development/2008/07/wordpress-26/&#038;width=640&#038;height=385\"> </embed></p>\n<p>If you&#8217;d like to embed the tour video in your blog, copy and paste this code for the high quality version:</p>\n<pre name=\"code\" class=\"html\">\n&lt;embed src=&quot;http://v.wordpress.com/mARhRBcT/fmt_dvd&quot; type=&quot;application/x-shockwave-flash&quot; width=&quot;640&quot; height=&quot;385&quot; flashvars=&quot;blog_domain=http://wordpress.org/development/2008/07/wordpress-26/&amp;width=640&amp;height=385&quot;&gt; &lt;/embed&gt;\n</pre>\n<p>And here&#8217;s a smaller version, 400 pixels wide:</p>\n<pre name=\"code\" class=\"html\">\n&lt;embed src=&quot;http://v.wordpress.com/mARhRBcT/fmt_std&quot; type=&quot;application/x-shockwave-flash&quot; width=&quot;400&quot; height=&quot;250&quot; flashvars=&quot;blog_domain=http://wordpress.org/development/2008/07/wordpress-26/&amp;width=400&amp;height=250&quot;&gt; &lt;/embed&gt;\n</pre>\n<p>Here&#8217;s a more textual overview of what&#8217;s hawt in 2.6:</p>\n<h3>Post Revisions: Wiki-like tracking of edits</h3>\n<p>With the power of modern computers, it&#8217;s silly that we still use save and editing metaphors from the time when the most common method of storage was floppy disks. WordPress has always respected the importance of your writing with auto-save, and now we&#8217;re taking that to another level by allowing you to view who made what changes when to any post or page through a super-easy interface, much like <a href=\"http://en.wikipedia.org/w/index.php?title=Wikipedia&#038;action=history\">Wikipedia</a> or a <a href=\"http://codex.wordpress.org/Using_Subversion\">version control system</a>.</p>\n<p><img src=\"http://wpdotorg.wordpress.com/files/2008/07/diff.gif\" alt=\"Differences between two versions of posts.\" class=\"alignnone size-full wp-image-3\" /></p>\n<p>This is handy on any blog in case you make a mistake and want to go back to an older version of a post, and it&#8217;s super handy for multi-author blogs where you can see every change tracked by person.</p>\n<h3>Press This!: Post from wherever you are on the web</h3>\n<p>A few months ago on my blog we <a href=\"http://ma.tt/2008/05/favorite-posting-bookmarklet/\">started a conversation about the posting bookmarklet</a> in WordPress and which systems we should look to for inspiration, like Flock, FriendFeed, Facebook, Tumblr, and Delicious. From these suggestions and the Quick Post plugin by Josh Kenzer, we developed a Press This bookmark you can add to your toolbar that provides a fast and smart popup to do posts to your WordPress blog:</p>\n<p><img src=\"http://wpdotorg.wordpress.com/files/2008/07/press-this.gif\" alt=\"Screenshot of Press This interface.\" title=\"press-this\" class=\"alignnone size-full wp-image-4\" /></p>\n<p>For example, if you click &#8220;Press This&#8221; from a <a href=\"http://youtube.com/\">Youtube</a> page it&#8217;ll magically extract the video embed code, and if you do it from a <a href=\"http://flickr.com/\">Flickr</a> page it&#8217;ll make it easy for you to put the image in your post. On my blog I&#8217;ve been experimenting with using different categories and the <code>in_category()</code> function &#8212; such as video, quote, aside, et cetera &#8212; to create a more tumblelog-like format.</p>\n<h3>Shift Gears: Turbo-speed your blogging</h3>\n<p><a href=\"http://gears.google.com/\">Gears</a> is an open source browser extension project started by Google that developers like us can use to give you features we wouldn&#8217;t normally be able to. There are a lot of things we can do with Gears in the future, but in this release we&#8217;ve stuck to using what&#8217;s called a &#8220;Local Server&#8221; to cache or keep a copy of commonly-used Javascript and CSS files on your computer, which can speed up the loading of some pages by several seconds (they just pop right up!). You can install Gears for Firefox or Internet Explorer, with support for Safari and Opera pending. WordPress works just fine without it, you just get a little extra juice when you have it installed.</p>\n<h3>Theme Previews: See it before your audience does</h3>\n<p>Now when you select a theme it pops up a window that shows the theme live with all your content, instead of immediately making it active on your site. This is great for just test driving themes before making a switch over publicly, and it is also helpful when you are developing a theme and need to test it but don&#8217;t want everybody to see your ongoing <del datetime=\"2008-07-14T21:23:41+00:00\">mistakes</del> development.</p>\n<p>Here are some of the smaller features and improvements in 2.6:</p>\n<ul>\n<li><strong>Word count!</strong> Never guess how many words are in your post anymore.</li>\n<li><strong>Image captions</strong>, so you can add sweet captions <a href=\"http://politicalticker.blogs.cnn.com/\">like Political Ticker does</a> under your images.</li>\n<li><strong>Bulk management</strong> of plugins.</li>\n<li>A completely <strong>revamped image control</strong> to allow for easier inserting, floating, and resizing. It&#8217;s now fully integrated with the WYSIWYG.</li>\n<li>Drag-and-drop <strong>reordering of Galleries</strong>.</li>\n<li><strong>Plugin update</strong> notification bubble.</li>\n<li>Customizable default avatars.</li>\n<li>You can now upload media when in full-screen mode.</li>\n<li>Remote publishing via XML-RPC and APP is now secure (off) by default, but you can turn it on easily through the options screen.</li>\n<li>Full <a href=\"http://en.wikipedia.org/wiki/Secure_Sockets_Layer\">SSL support</a> in the core, and the ability to <strong>force SSL</strong> for security.</li>\n<li>You can now have many thousands of pages or categories with no interface issues.</li>\n<li>Ability to move your <code>wp-config</code> file and <code>wp-content</code> directories to a custom location, for &#8220;clean&#8221; SVN checkouts.</li>\n<li>Select a range of checkboxes with &#8220;shift-click.&#8221;</li>\n<li>You can toggle between the Flash uploader and the classic one.</li>\n<li>A number of proactive security enhancements, including cookies and database interactions.</li>\n<li>Stronger better faster versions of TinyMCE, jQuery, and jQuery UI.</li>\n<li>Version 2.6 <a href=\"http://trac.wordpress.org/query?status=closed&#038;milestone=2.6\">fixes approximately 194 bugs</a>.</li>\n</ul>\n<h3>Developer Notes</h3>\n<p>WordPress.org had over 75 people contributing code to WordPress 2.6. In addition to the <a href=\"http://wordpress.org/about/\">core commit team</a> we had contributions from <a href=\"http://dd32.id.au/\">Dion Hulse</a>, <a href=\"http://www.ilfilosofo.com/\">Austin Matzko</a>, <a href=\"http://ottodestruct.com/blog/\">Otto42</a>, <a href=\"http://extralogical.net/\">Benedict Eastaugh</a>, and <a href=\"http://www.freecharity.org.uk/\">pishmishy</a>. <a href=\"http://xavisys.com/\">AaronCampbell</a> and <a href=\"http://www.marcozehe.de/\">Marco Zehe</a> provided more than a few patches. Back among the top code contributors is <a href=\"http://www.santosj.name/\">Jacob Santos</a>. <a href=\"http://www.buayacorp.com/\">Alex Concha</a> continues to have WordPress&#8217; back. Joining bug reporting and gardening elite are <a href=\"http://codex.wordpress.org/User:Hakre\">hakre</a>, <a href=\"http://www.simonwheatley.co.uk/\">Simon Wheatley</a>, mtekk, and <a href=\"http://www.prescriber.org.uk/\">Matty Rob</a>. Finally, congratulations to our <a href=\"http://westi.wordpress.com/\">Peter Westwood</a> on your recent wedding! I&#8217;m also proud to announce we&#8217;re adding a new core committer to the team: Andrew Ozz (azaozz) has been a huge help to the core team this year, particularly around TinyMCE and making the WYSIWYG something that works for you, not against you.</p>\n<p>Because of the new capabilities to make WordPress a clean SVN checkout, plugin and theme authors should do their best to handle forms and posts through WP rather than trying to post to their files directly, here&#8217;s a quick Codex article about <a href=\"http://codex.wordpress.org/Handling_POST_and_AJAX_Requests\">how to do it using our forward-compatible APIs</a>.</p>\n<h3>Upgrading</h3>\n<p>2.6 is pretty much identical to 2.5 from a plugin and theme compatibility point of view, so upgrades from 2.5 should be pretty painless. The 2.5 branch will no longer be maintain so everyone is encouraged to upgrade. <a href=\"http://codex.wordpress.org/Upgrading_WordPress\">Our standard 3-step upgrade instructions apply to this release</a>. There were at least 1,984,047 downloads of the 2.5 series, the fastest growing release we&#8217;ve ever had, and I think all of those people will find 2.6 adds a level of polish that really makes WP a pleasure to use every day. (At least I do. :))</p>\n<h3>Easter Egg</h3>\n<p>There have been rumors and allegations that there was a so-called &#8220;easter egg&#8221; added to 2.6 early in its development. These rumors and allegations are completely false!</p>\n<p>P.S. If you&#8217;re a fan of WordPress, <a href=\"http://www.facebook.com/pages/WordPress/6427302910\">consider joining our fan page on Facebook</a>.</p>\n\";}i:2;a:12:{s:5:\"title\";s:24:\"WordPress Birthday Party\";s:4:\"link\";s:56:\"http://wordpress.org/development/2008/05/birthday-party/\";s:8:\"comments\";s:65:\"http://wordpress.org/development/2008/05/birthday-party/#comments\";s:7:\"pubdate\";s:31:\"Sun, 25 May 2008 05:51:03 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Matt\";}s:8:\"category\";s:6:\"Events\";s:4:\"guid\";s:39:\"http://wordpress.org/development/?p=243\";s:11:\"description\";s:321:\"On Tuesday, May 27th, WordPress will turn 5 years old. We&#8217;ve come a long way from that original 0.7 release.\nTo celebrate we&#8217;re throwing a party in San Francisco at 111 Minna, starting at 9PM. You can get the full details and RSVP on Upcoming.org or on Facebook.\nI hope you see some of you there, should [...]\";s:7:\"content\";a:1:{s:7:\"encoded\";s:874:\"<p>On Tuesday, May 27th, WordPress will turn 5 years old. We&#8217;ve come a long way from <a href=\"http://wordpress.org/development/2003/05/wordpress-now-available/\">that original 0.7 release</a>.</p>\n<p>To celebrate we&#8217;re throwing a party in San Francisco at 111 Minna, starting at 9PM. You can get the full details and RSVP <a href=\"http://upcoming.yahoo.com/event/714298\">on Upcoming.org</a> or <a href=\"http://www.facebook.com/event.php?eid=44552835108\">on Facebook</a>.</p>\n<p>I hope you see some of you there, should be a fun time.</p>\n<p>If you host a party in your area for WordPress&#8217; 5th, let us know and we&#8217;ll post it here.</p>\n<p><strong>Update:</strong> Party in Sydney! <a href=\"http://bethesignal.org/blog/2008/05/25/wordpress-party-sydney-style/\">Blog post</a>, <a href=\"http://www.facebook.com/event.php?eid=13815594694\">Facebook</a>.</p>\n\";}s:3:\"wfw\";a:1:{s:10:\"commentrss\";s:61:\"http://wordpress.org/development/2008/05/birthday-party/feed/\";}s:7:\"summary\";s:321:\"On Tuesday, May 27th, WordPress will turn 5 years old. We&#8217;ve come a long way from that original 0.7 release.\nTo celebrate we&#8217;re throwing a party in San Francisco at 111 Minna, starting at 9PM. You can get the full details and RSVP on Upcoming.org or on Facebook.\nI hope you see some of you there, should [...]\";s:12:\"atom_content\";s:874:\"<p>On Tuesday, May 27th, WordPress will turn 5 years old. We&#8217;ve come a long way from <a href=\"http://wordpress.org/development/2003/05/wordpress-now-available/\">that original 0.7 release</a>.</p>\n<p>To celebrate we&#8217;re throwing a party in San Francisco at 111 Minna, starting at 9PM. You can get the full details and RSVP <a href=\"http://upcoming.yahoo.com/event/714298\">on Upcoming.org</a> or <a href=\"http://www.facebook.com/event.php?eid=44552835108\">on Facebook</a>.</p>\n<p>I hope you see some of you there, should be a fun time.</p>\n<p>If you host a party in your area for WordPress&#8217; 5th, let us know and we&#8217;ll post it here.</p>\n<p><strong>Update:</strong> Party in Sydney! <a href=\"http://bethesignal.org/blog/2008/05/25/wordpress-party-sydney-style/\">Blog post</a>, <a href=\"http://www.facebook.com/event.php?eid=13815594694\">Facebook</a>.</p>\n\";}i:3;a:12:{s:5:\"title\";s:29:\"Usability Testing in New York\";s:4:\"link\";s:71:\"http://wordpress.org/development/2008/05/usability-testing-in-new-york/\";s:8:\"comments\";s:80:\"http://wordpress.org/development/2008/05/usability-testing-in-new-york/#comments\";s:7:\"pubdate\";s:31:\"Tue, 20 May 2008 22:13:49 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Ryan\";}s:8:\"category\";s:11:\"Development\";s:4:\"guid\";s:39:\"http://wordpress.org/development/?p=241\";s:11:\"description\";s:98:\"We&#8217;re doing some usability testing in New York City.  Join in if you&#8217;re in the area.\n\";s:7:\"content\";a:1:{s:7:\"encoded\";s:187:\"<p><a href=\"http://en.blog.wordpress.com/2008/05/20/new-york-usability-testing/\">We&#8217;re doing some usability testing in New York City</a>.  Join in if you&#8217;re in the area.</p>\n\";}s:3:\"wfw\";a:1:{s:10:\"commentrss\";s:76:\"http://wordpress.org/development/2008/05/usability-testing-in-new-york/feed/\";}s:7:\"summary\";s:98:\"We&#8217;re doing some usability testing in New York City.  Join in if you&#8217;re in the area.\n\";s:12:\"atom_content\";s:187:\"<p><a href=\"http://en.blog.wordpress.com/2008/05/20/new-york-usability-testing/\">We&#8217;re doing some usability testing in New York City</a>.  Join in if you&#8217;re in the area.</p>\n\";}i:4;a:12:{s:5:\"title\";s:18:\"Upcoming WordCamps\";s:4:\"link\";s:60:\"http://wordpress.org/development/2008/04/upcoming-wordcamps/\";s:8:\"comments\";s:69:\"http://wordpress.org/development/2008/04/upcoming-wordcamps/#comments\";s:7:\"pubdate\";s:31:\"Wed, 30 Apr 2008 09:54:48 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Matt\";}s:8:\"category\";s:6:\"Events\";s:4:\"guid\";s:39:\"http://wordpress.org/development/?p=240\";s:11:\"description\";s:343:\"WordCamps are my favorite events to go to because there&#8217;s something about the core WordPress community that attracts smart folks with good philosophies that are fun to hang out with. In this post I&#8217;ve collated the upcoming WordCamps we know about, including the one in San Francisco. Hopefully there will be one nearby so you [...]\";s:7:\"content\";a:1:{s:7:\"encoded\";s:1446:\"<p>WordCamps are my favorite events to go to because there&#8217;s something about the core WordPress community that attracts smart folks with good philosophies that are fun to hang out with. In this post I&#8217;ve collated the upcoming WordCamps we know about, including the one in San Francisco. Hopefully there will be one nearby so you can meet other WordPressers in your area.</p>\n<p><strong>WordCamp San Francisco</strong> will be August 16 at the Mission Bay Conference Center.</p>\n<p><a href=\"http://barcamp.org/WordCampParis\">WordCamp Paris will be on May 3rd</a>. <a href=\"http://wordcamp.fr/\">Here&#8217;s their official site</a>.</p>\n<p><a href=\"http://iwordpresscamp.wordpress.com/2008/02/20/european-wordcamp-beta/\">WordCamp Italy in Milan will be May 10th</a>. (And I believe I&#8217;ll be there.)</p>\n<p><a href=\"http://wiki.wordcampuk.tonyscott.org.uk/Main_Page\">WordCamp Birmingham UK</a> will be July 19-20.</p>\n<p><a href=\"http://wordcamptoronto.eventbrite.com/\">WordCamp Toronto will be October 4th</a>.</p>\n<p>There are people in the planning stages in <a href=\"http://australia.wordcamp.org/\">Australia</a>, Philippines, Beijing, Utah, Hawaii, UK, NYC, and possibly others, so if you live in one of those areas and would like to help set up a WordCamp in your area Google around or connect with bloggers in your area.</p>\n<p>You can always find out more at <a href=\"http://central.wordcamp.org/\">WordCamp Central</a>.</p>\n\";}s:3:\"wfw\";a:1:{s:10:\"commentrss\";s:65:\"http://wordpress.org/development/2008/04/upcoming-wordcamps/feed/\";}s:7:\"summary\";s:343:\"WordCamps are my favorite events to go to because there&#8217;s something about the core WordPress community that attracts smart folks with good philosophies that are fun to hang out with. In this post I&#8217;ve collated the upcoming WordCamps we know about, including the one in San Francisco. Hopefully there will be one nearby so you [...]\";s:12:\"atom_content\";s:1446:\"<p>WordCamps are my favorite events to go to because there&#8217;s something about the core WordPress community that attracts smart folks with good philosophies that are fun to hang out with. In this post I&#8217;ve collated the upcoming WordCamps we know about, including the one in San Francisco. Hopefully there will be one nearby so you can meet other WordPressers in your area.</p>\n<p><strong>WordCamp San Francisco</strong> will be August 16 at the Mission Bay Conference Center.</p>\n<p><a href=\"http://barcamp.org/WordCampParis\">WordCamp Paris will be on May 3rd</a>. <a href=\"http://wordcamp.fr/\">Here&#8217;s their official site</a>.</p>\n<p><a href=\"http://iwordpresscamp.wordpress.com/2008/02/20/european-wordcamp-beta/\">WordCamp Italy in Milan will be May 10th</a>. (And I believe I&#8217;ll be there.)</p>\n<p><a href=\"http://wiki.wordcampuk.tonyscott.org.uk/Main_Page\">WordCamp Birmingham UK</a> will be July 19-20.</p>\n<p><a href=\"http://wordcamptoronto.eventbrite.com/\">WordCamp Toronto will be October 4th</a>.</p>\n<p>There are people in the planning stages in <a href=\"http://australia.wordcamp.org/\">Australia</a>, Philippines, Beijing, Utah, Hawaii, UK, NYC, and possibly others, so if you live in one of those areas and would like to help set up a WordCamp in your area Google around or connect with bloggers in your area.</p>\n<p>You can always find out more at <a href=\"http://central.wordcamp.org/\">WordCamp Central</a>.</p>\n\";}i:5;a:12:{s:5:\"title\";s:15:\"WordPress 2.5.1\";s:4:\"link\";s:55:\"http://wordpress.org/development/2008/04/wordpress-251/\";s:8:\"comments\";s:64:\"http://wordpress.org/development/2008/04/wordpress-251/#comments\";s:7:\"pubdate\";s:31:\"Fri, 25 Apr 2008 15:54:19 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Ryan\";}s:8:\"category\";s:8:\"Releases\";s:4:\"guid\";s:39:\"http://wordpress.org/development/?p=231\";s:11:\"description\";s:360:\"Version 2.5.1 of WordPress is now available. It includes a number of bug fixes, performance enhancements, and one very important security fix. We recommend everyone update immediately, particularly if your blog has open registration. The vulnerability is not public but it will be shortly.\nIn addition to the security fix, 2.5.1 contains many bug fixes.  [...]\";s:7:\"content\";a:1:{s:7:\"encoded\";s:2251:\"<p>Version 2.5.1 of WordPress is now available. It includes a number of bug fixes, performance enhancements, and one very important security fix. We recommend everyone update immediately, particularly if your blog has open registration. The vulnerability is not public but it will be shortly.</p>\n<p>In addition to the security fix, 2.5.1 contains many bug fixes.  If you are interested only in the security fixes, you can download these corrected copies of <a href=\"http://trac.wordpress.org/browser/tags/2.5.1/wp-includes/pluggable.php?format=raw\">wp-includes/pluggable.php</a>, <a href=\"http://trac.wordpress.org/browser/tags/2.5.1/wp-admin/includes/media.php?format=raw\">wp-admin/includes/media.php</a>, and <a href=\"http://trac.wordpress.org/browser/tags/2.5.1/wp-admin/media.php?format=raw\">wp-admin/media.php</a>.  Replace your existing copies of these files with these new copies.</p>\n<p>If you download the entire 2.5.1 release, you will be getting <a href=\"http://trac.wordpress.org/query?status=closed&amp;milestone=2.5.1&amp;resolution=fixed&amp;order=priority\">over 70 other fixes</a>.  2.5.1 focuses on fixing the most annoying bugs and improving performance.  Here are some highlights:</p>\n<ul>\n<li>Performance improvements for the Dashboard, Write Post, and Edit Comments pages.</li>\n<li>Better performance for those who have many categories</li>\n<li>Media Uploader fixes</li>\n<li>An upgrade to TinyMCE 3.0.7</li>\n<li>Widget Administration fixes</li>\n<li>Various usability improvements</li>\n<li>Layout fixes for IE</li>\n</ul>\n<h3>Secret lives of blogs</h3>\n<p>Since 2.5 your <code>wp-config.php</code> file allows a new constant called <code>SECRET_KEY</code> which basically is meant to introduce a little permanent randomness into the cryptographic functions used for cookies in WordPress. You can <a href=\"http://api.wordpress.org/secret-key/1.0/\">visit this link we set up to get a unique secret key</a> for your config file. (It&#8217;s unique and random on every page load.) Having this line in your config file helps secure your blog.</p>\n<p>Many thanks to <a href=\"http://www.cl.cam.ac.uk/~sjm217/\">Steven Murdoch</a> for responsibly reporting the security issue (CVE-2008-1930) and Alex Concha for reporting an XSS issue.</p>\n\";}s:3:\"wfw\";a:1:{s:10:\"commentrss\";s:60:\"http://wordpress.org/development/2008/04/wordpress-251/feed/\";}s:7:\"summary\";s:360:\"Version 2.5.1 of WordPress is now available. It includes a number of bug fixes, performance enhancements, and one very important security fix. We recommend everyone update immediately, particularly if your blog has open registration. The vulnerability is not public but it will be shortly.\nIn addition to the security fix, 2.5.1 contains many bug fixes.  [...]\";s:12:\"atom_content\";s:2251:\"<p>Version 2.5.1 of WordPress is now available. It includes a number of bug fixes, performance enhancements, and one very important security fix. We recommend everyone update immediately, particularly if your blog has open registration. The vulnerability is not public but it will be shortly.</p>\n<p>In addition to the security fix, 2.5.1 contains many bug fixes.  If you are interested only in the security fixes, you can download these corrected copies of <a href=\"http://trac.wordpress.org/browser/tags/2.5.1/wp-includes/pluggable.php?format=raw\">wp-includes/pluggable.php</a>, <a href=\"http://trac.wordpress.org/browser/tags/2.5.1/wp-admin/includes/media.php?format=raw\">wp-admin/includes/media.php</a>, and <a href=\"http://trac.wordpress.org/browser/tags/2.5.1/wp-admin/media.php?format=raw\">wp-admin/media.php</a>.  Replace your existing copies of these files with these new copies.</p>\n<p>If you download the entire 2.5.1 release, you will be getting <a href=\"http://trac.wordpress.org/query?status=closed&amp;milestone=2.5.1&amp;resolution=fixed&amp;order=priority\">over 70 other fixes</a>.  2.5.1 focuses on fixing the most annoying bugs and improving performance.  Here are some highlights:</p>\n<ul>\n<li>Performance improvements for the Dashboard, Write Post, and Edit Comments pages.</li>\n<li>Better performance for those who have many categories</li>\n<li>Media Uploader fixes</li>\n<li>An upgrade to TinyMCE 3.0.7</li>\n<li>Widget Administration fixes</li>\n<li>Various usability improvements</li>\n<li>Layout fixes for IE</li>\n</ul>\n<h3>Secret lives of blogs</h3>\n<p>Since 2.5 your <code>wp-config.php</code> file allows a new constant called <code>SECRET_KEY</code> which basically is meant to introduce a little permanent randomness into the cryptographic functions used for cookies in WordPress. You can <a href=\"http://api.wordpress.org/secret-key/1.0/\">visit this link we set up to get a unique secret key</a> for your config file. (It&#8217;s unique and random on every page load.) Having this line in your config file helps secure your blog.</p>\n<p>Many thanks to <a href=\"http://www.cl.cam.ac.uk/~sjm217/\">Steven Murdoch</a> for responsibly reporting the security issue (CVE-2008-1930) and Alex Concha for reporting an XSS issue.</p>\n\";}i:6;a:12:{s:5:\"title\";s:23:\"An Event Apart Discount\";s:4:\"link\";s:65:\"http://wordpress.org/development/2008/04/an-event-apart-discount/\";s:8:\"comments\";s:74:\"http://wordpress.org/development/2008/04/an-event-apart-discount/#comments\";s:7:\"pubdate\";s:31:\"Tue, 22 Apr 2008 22:33:19 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Matt\";}s:8:\"category\";s:36:\"Eventsan event aparthappy cogzeldman\";s:4:\"guid\";s:65:\"http://wordpress.org/development/2008/04/an-event-apart-discount/\";s:11:\"description\";s:321:\"An Event Apart is a web design and development conference which features some of the same fine folks who helped out with WordPress 2.5. (And many others.) I attended the one in Chicago a while back and was engaged the whole day in interesting talks on design, writing copy as interface, advanced CSS, and creativity [...]\";s:7:\"content\";a:1:{s:7:\"encoded\";s:1194:\"<p><a href=\"http://aneventapart.com/\">An Event Apart</a> is a web design and development conference which features some of the same fine folks who helped out with WordPress 2.5. (And many others.) I attended the one in Chicago a while back and was engaged the whole day in interesting talks on design, writing copy as interface, advanced CSS, and creativity &#8212; each topic presented by the leading folks in the field.</p>\n<p>The conference normally costs just under a thousand dollars to attend, which is well worth it, but because of our association with the folks they&#8217;ve set up a discount for WordPress users.</p>\n<p>If you enter AEAWP on checkout the price drops to $795, or $200 below the regular registration fee. The coupon is unlimited, and can be used for one ticket or five. They have events coming up in New Orleans, Boston, San Francisco, and Chicago. <a href=\"http://aneventapart.com/\">You can learn more and register on their site at aneventapart.com</a>.</p>\n<p>We&#8217;ll also have some final dates for WordCamp San Francisco coming up, I&#8217;ll be posting those soonish so people can start making vacation and travel plans. (Nothing like a blogging vacation.)</p>\n\";}s:3:\"wfw\";a:1:{s:10:\"commentrss\";s:70:\"http://wordpress.org/development/2008/04/an-event-apart-discount/feed/\";}s:7:\"summary\";s:321:\"An Event Apart is a web design and development conference which features some of the same fine folks who helped out with WordPress 2.5. (And many others.) I attended the one in Chicago a while back and was engaged the whole day in interesting talks on design, writing copy as interface, advanced CSS, and creativity [...]\";s:12:\"atom_content\";s:1194:\"<p><a href=\"http://aneventapart.com/\">An Event Apart</a> is a web design and development conference which features some of the same fine folks who helped out with WordPress 2.5. (And many others.) I attended the one in Chicago a while back and was engaged the whole day in interesting talks on design, writing copy as interface, advanced CSS, and creativity &#8212; each topic presented by the leading folks in the field.</p>\n<p>The conference normally costs just under a thousand dollars to attend, which is well worth it, but because of our association with the folks they&#8217;ve set up a discount for WordPress users.</p>\n<p>If you enter AEAWP on checkout the price drops to $795, or $200 below the regular registration fee. The coupon is unlimited, and can be used for one ticket or five. They have events coming up in New Orleans, Boston, San Francisco, and Chicago. <a href=\"http://aneventapart.com/\">You can learn more and register on their site at aneventapart.com</a>.</p>\n<p>We&#8217;ll also have some final dates for WordCamp San Francisco coming up, I&#8217;ll be posting those soonish so people can start making vacation and travel plans. (Nothing like a blogging vacation.)</p>\n\";}i:7;a:12:{s:5:\"title\";s:13:\"WordPress 2.5\";s:4:\"link\";s:62:\"http://wordpress.org/development/2008/03/wordpress-25-brecker/\";s:8:\"comments\";s:71:\"http://wordpress.org/development/2008/03/wordpress-25-brecker/#comments\";s:7:\"pubdate\";s:31:\"Sat, 29 Mar 2008 16:49:45 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Matt\";}s:8:\"category\";s:8:\"Releases\";s:4:\"guid\";s:39:\"http://wordpress.org/development/?p=228\";s:11:\"description\";s:391:\"WordPress 2.5, the culmination of six months of work by the WordPress community, people just like you. The improvements in 2.5 are numerous, and almost entirely a result of your feedback: multi-file uploading, one-click plugin upgrades, built-in galleries, customizable dashboard, salted passwords and cookie encryption, media library, a WYSIWYG that doesn&#8217;t mess with your code, [...]\";s:7:\"content\";a:1:{s:7:\"encoded\";s:15112:\"<p>WordPress 2.5, the culmination of six months of work by the WordPress community, people just like you. The improvements in 2.5 are numerous, and almost entirely a result of your feedback: multi-file uploading, one-click plugin upgrades, built-in galleries, customizable dashboard, salted passwords and cookie encryption, media library, a WYSIWYG that doesn&#8217;t mess with your code, concurrent post editing protection, full-screen writing, and search that covers posts <em>and</em> pages.</p>\n<p>For a short overview of the features with screenshots, it&#8217;d be best to <a href=\"http://wordpress.org/development/2008/03/25-sneak-peek/\">visit our sneak peek announcement for RC1</a>. Or check out <a href=\"http://wordpress.org/development/2008/03/wordpress-25-rc2/\">a 4-minute screencast of the new interface in action</a>. If you just want to jump straight to the good stuff <a href=\"http://wordpress.org/download/\">here&#8217;s where you can find 2.5 upgrade and download information</a>.</p>\n<p>If you want to see everything I would grab a cup of coffee or a mojito, because this post is epic.</p>\n<h3>User Features</h3>\n<p><strong>Cleaner, faster, less cluttered dashboard</strong> &#8212; we&#8217;ve worked hard to take your feedback about what&#8217;s most important in the dashboard and organize things to allow you to focus on what&#8217;s important &#8212; your blog &#8212; and get out of your way. In collaboration with <a href=\"http://happycog.com/\">Happy Cog</a> and the community  we&#8217;ve taken the first major step forward in the WordPress interface since version 1.5.</p>\n<p><strong>Dashboard Widgets</strong> &#8212; the dashboard home page is now a series of widgets, including ones to show you fun stats about your posting, latest comments, people linking to you, new and popular plugins, and of course WordPress news. You can customize any of the dashboard widgets to show, for example, news from your local paper instead of WP news. Plugins can also hook in, for example the <a href=\"http://wordpress.org/extend/plugins/stats/\">WordPress.com stats widget</a> adds a handy double-wide stats box.</p>\n<p><img src=\"http://s.wordpress.org/screenshots/2.5/stats-widget.png\" alt=\"\" width=\"690\" /></p>\n<p><strong>Multi-file upload with progress bar</strong> &#8212; before when you would upload a large file you&#8217;d wait forever, never knowing how far along it was. And uploading more than one photo was an exercise in patience, as you could only do one at a time. Now you can select a whole of folder images or music or videos at once and it&#8217;ll show you the progress of each upload.</p>\n<p><strong>Bonus: EXIF extraction</strong> &#8212; if you upload JPEG files with EXIF metadata like camera make and model, aperture, shutter speed, ISO, et al. WordPress will extract all the data into custom fields you can use in your template. If you use the EXIF title fields or similar those will be put into their equivalent fields in WP. Most modern digital cameras generate EXIF data.</p>\n<p><strong>Search posts and pages</strong> &#8212; search used to cover just posts, now it includes pages too, a great boon for those using WordPress as a CMS. New themes can style or sort pages differently in results.</p>\n<p><strong>Tag management</strong> &#8212; you can now add, rename, delete, and do whatever else you like to tags from inside WordPress, no plugins needed.</p>\n<p><strong>Password strength meter</strong> &#8212; when you change your password on your profile it&#8217;ll tell you how strong your password is to help you pick a good one.</p>\n<p><strong>Concurrent editing protection</strong> &#8212; for those of you on multi-author blogs, have you ever opened a post while someone was already editing it, and your auto-saves kept overwriting each other, irrecoverably losing hours of work? I bet that added a few words to your vocabulary. Now if you open a post that someone else is editing, WordPress magically locks it and prevents you from saving until the other person is done. You&#8217;ll see a message like below.</p>\n<p><img src=\"http://s.wordpress.org/screenshots/2.5/write-currently-editing.png\" alt=\"\" /></p>\n<p><strong>Few-click plugin upgrades</strong> &#8212; if the plugins you use are part of the plugin directory since 2.3 we&#8217;ve told you when they have an update available. Now we take that to the next logical step &#8212; downloading and installing the upgrade for you. This is dependent a little bit on your host setup, and it may ask you for your FTP password much like OS X or Windows will ask you for a password, but it works well on majority of hosts we were able to test, your mileage may very, plugins in mirror may be larger than they appear.</p>\n<p><strong>Friendlier visual post editor</strong> &#8212; I&#8217;m not sure how to articulate this improvement except to say &#8220;it doesn&#8217;t mess with your code anymore.&#8221; We&#8217;re now using version 3.0 of TinyMCE, which means better compatibility with Safari, and we&#8217;ve paid particular attention this release to its integration and interaction with complex HTML. It also now has a &#8220;no-distractions&#8221; mode which is like Writeroom for your browser.</p>\n<p><strong>Built-in galleries</strong> &#8212; when you take advantage of multi-file upload to upload a bunch of photos, we have a new shortcode that lets you to easily embed galleries by just putting [ gallery] (without the space) in your post. It&#8217;ll display all your thumbnails and captions and each will link each to a page where people can comment on the individual photos. I&#8217;ve been using this feature on my blog and have already uploaded over <a href=\"http://ma.tt/category/gallery/\">1,200 pictures into 23 galleries</a>. The shortcode has some hidden options too, <a href=\"http://codex.wordpress.org/Using_the_gallery_shortcode\">check out this documentation</a>.</p>\n<h3>Developer Features</h3>\n<p>Now for the geeky stuff. While we&#8217;re excited about the above features, each one represents a new opportunity or API for other developers to take to another level. (The best of which we&#8217;ll someday integrate back into WP.)</p>\n<p><strong>Salted passwords</strong> &#8212; we now use the <a href=\"http://www.openwall.com/phpass/\">phpass</a> library to stretch and salt all passwords stored in the database, which makes brute-forcing them impractical. If you use something like <a href=\"http://modauthmysql.sourceforge.net/\">mod_auth_mysql</a> we&#8217;ve <a href=\"http://wordpress.org/extend/plugins/md5-password-hashes/\">created a plugin that will allow you to use legacy MD5 hashing</a>. (The hashing is completely pluggable.) Users will automatically switch to the more secure passwords next time they log in.</p>\n<p><strong>Secure cookies</strong> &#8212; cookies are now encrypted based on the protocol described <a href=\"http://www.cse.msu.edu/~alexliu/publications/Cookie/cookie.pdf\">in this PDF paper</a>. which is something like <code>user name|expiration time|HMAC( user name|expiration time, k)</code> where <code>k = HMAC(user name|expiration time, sk)</code> and where <code>sk</code> is a secret key, which you can define in your config.</p>\n<p><strong>Easy taxonomy and URL creation</strong> &#8212; probably best illustrated with an example: I can call <code>register_taxonomy()</code> with <a href=\"http://trac.wordpress.org/attachment/ticket/6357/taxes.php\">a few arguments</a> to register a &#8220;people&#8221; taxonomy and whenever I edit an image I&#8217;ll see a UI like tags has for identifying the people in a photo, and these will be URL addressable with <code>/person/firstname-lastname/</code>. All with a single function call.</p>\n<p><strong>Inline documentation</strong> &#8212; the vast majority of the new code going into WordPress include inline documentation that explains the functions and documents their arguments.</p>\n<p><strong>Database optimization</strong> &#8212; we haven&#8217;t changed the table layout in this release, which is one of the reasons so many plugins work fine with 2.5. We have added a few new indicies and made a few default fields more flexible based on some bottlenecks we found on WordPress.com, which now hosts 2.7 million WordPress blogs. It should be invisible to the application, just a bit faster on the database side.</p>\n<p><strong>$wpdb->prepare()</strong> &#8212; now almost all of the SQL in WordPress is prepared first, and the same functions are available to your plugins. This should prevent elementary SQL escaping issues.</p>\n<p><strong>Media buttons</strong> &#8212; the add media buttons above the post are both expandable, so you could have an &#8220;Add Google Map&#8221; button if you like, They can be overridden, so if you think you can do the video or audio tab better than we have you can replace the default.</p>\n<p><strong>Shortcode API</strong> &#8212; the new gallery functionality is powered by the new shortcode API. Shortcodes are little bracket-delineated strings that can be magically expanded at runtime to something more interesting. They give users a short, easy to type and copy/paste string they can move around their post without worrying about messing up complex HTML or embed codes. <a href=\"http://codex.wordpress.org/Shortcode_API\">The Shortcode API is fully documented</a>.</p>\n<p>Now you see why 2.5 took a little extra time. <img src=\'http://wordpress.org/development/wp-includes/images/smilies/icon_smile.gif\' alt=\':)\' class=\'wp-smiley\' /> </p>\n<h3>Upgrade Notes</h3>\n<p>2.5 does include security fixes so it is recommended for all users, the 2.3 branch will no longer be updated. <a href=\"http://codex.wordpress.org/Upgrading_WordPress\">The upgrade instructions for this version are pretty much the same as any other version</a>. The most important thing to check is your plugins, so if for example everything works except the new uploader, a legacy plugin might be causing a javascript error on the page and breaking it. If something goes wrong, the safest thing to do is turn your plugins off (we have a button to do them all at once, now) and turn them back on one-by-one, testing the problem along the way. This has solved almost everybody&#8217;s problems in testing, and it also lets you know which plugin author to show some love to so they&#8217;ll update their plugin, and which plugin authors already have so you can shower them with praises on your blog.</p>\n<p>One brief note about some of the new upload and plugin upgrade features, there are some edge-case hosting platforms, like versions of Lighttpd before 1.5 or over-agressive mod_security rules, which can break. If something isn&#8217;t working like it was looked in the screenshot, ask your host if there&#8217;s something on the server side which may be interfering. Hosts, feel free to join and post to <a href=\"http://lists.automattic.com/mailman/listinfo/wp-testers\">our wp-testers mailing list</a> if you have an environment that requires some extra code to work around. We&#8217;d be happy to include it in the next update.</p>\n<p><em>Quick tip:</em> in 2.5 you click the name of things to edit them, like your username to edit your profile or the title of a post to edit it.</p>\n<h3>The Community is Growing</h3>\n<p>More than growing, it&#8217;s on fire. We always talk about things like downloads, and the 2.3 branch has already had <strong>1.92 million downloads</strong> as I write this post, but this time we have some far more interesting information I&#8217;d like to share.</p>\n<p>There were over 1,200 commits to our repository since 2.3.0 and <strong>over 90 people were credited</strong> in them. This means in our core code, not plugins, there were at least 90 individual folks that contributed something high-quality enough that it made the cut to be part of the download you guys get today. I had no idea this group of people was so large.</p>\n<p>Outside of the <a href=\"http://wordpress.org/about/\">core commit team</a>, there was particular help from these people, in rough order of number of credits and tickets: <a href=\"http://blogwaffe.com/\">mdawaffe (Michael Adams)</a>, <a href=\"http://www.laptoptips.ca/\">azaozz (Andrew Ozz)</a>, <a href=\"http://nb.niichavo.org/\">nbachiyski (Nikolay Bachiyski)</a>, <a href=\"http://skeltoac.com/\">andy (Andy Skelton)</a>, <a href=\"http://iammattthomas.com/\">iammattthomas (Matt Thomas)</a>, <a href=\"http://thresholdstate.com/\">tellyworth (Alex Shiels)</a>, <a href=\"http://joseph.randomnetworks.com/\">josephscott (Joseph Scott)</a>, <a href=\"http://foolswisdom.com/\">lloydbudd (Lloyd Budd)</a>, <a href=\"http://dd32.id.au/\">DD32 (Dion)</a>, <a href=\"http://www.ilfilosofo.com/\">filosofo (Austin Matzko)</a>, <a href=\"http://engel.uk.to/\">hansengel (Hans Engel)</a>, <a href=\"http://www.freecharity.org.uk/\">pishmishy</a>, ffemtcj, <a href=\"http://www.viper007bond.com/\">Viper007Bond</a>, <a href=\"http://extralogical.net/\">ionfish (Benedict Eastaugh)</a>, <a href=\"http://www.poplarware.com/\">jhodgdon (Jennifer Hodgdon)</a>, <a href=\"http://ottodestruct.com/blog/\">Otto42</a>, <a href=\"http://www.cefm.ca/\">thee17 (Charles E. Free-Melvin)</a>, and <a href=\"http://www.buayacorp.com/\">xknown</a>. Also want to thank MichaelH and Lorelle on the documentation side, and moshu, Kafkaesqui, whooami, MichaelH, Otto42, and jeremyclark13 for helping with support.</p>\n<p>The 2.5 branch is nicknamed &#8220;Brecker&#8221; in honor of <a href=\"http://en.wikipedia.org/wiki/Michael_Brecker\">Michael Brecker</a>, an exceptionally talented saxophonist who could cross styles effortlessly and never stopped experimenting and pushing himself until he passed away last year.</p>\n<h3>New WordPress.org</h3>\n<p>All of this wasn&#8217;t enough, so in our copious spare time we decided to redesign WordPress.org to better match the aesthetics of the new dashboard and also to spruce up a few areas that needed lovin&#8217;. Some parts of the site, like the Codex, might show the old style for a day or two. We know, just give us a bit of time. Thanks to <a href=\"http://iammattthomas.com/\">Matt Thomas</a> for his epic effort in designing and coding the new site.</p>\n<h3>What&#8217;s Next</h3>\n<p>As always with WordPress, we don&#8217;t claim any of these features to be perfect, or to be better than everyone else in the world, but they are done by and for the people and the one thing we do promise is that with every release we listen and do our best to improve. </p>\n<p>2.5 is a major milestone for WordPress not because it added dozens of user-requested features, but because it reaffirms that we&#8217;re as passionate about blogging as the day we started. Our community is too fierce to rest on its laurels &#8212; contrary to what pundits claim, blogging is far from &#8220;finished&#8221; and every improvement just whets our appetite for more. And more is coming.</p>\n<p>It&#8217;s a good thing WordPress doesn&#8217;t limit the length of posts, because this one would have hit it. If you made it this far, thanks for sharing a bit of your day with us. I sincerely hope this new version of WordPress helps you do what you love to do.</p>\n\";}s:3:\"wfw\";a:1:{s:10:\"commentrss\";s:67:\"http://wordpress.org/development/2008/03/wordpress-25-brecker/feed/\";}s:7:\"summary\";s:391:\"WordPress 2.5, the culmination of six months of work by the WordPress community, people just like you. The improvements in 2.5 are numerous, and almost entirely a result of your feedback: multi-file uploading, one-click plugin upgrades, built-in galleries, customizable dashboard, salted passwords and cookie encryption, media library, a WYSIWYG that doesn&#8217;t mess with your code, [...]\";s:12:\"atom_content\";s:15112:\"<p>WordPress 2.5, the culmination of six months of work by the WordPress community, people just like you. The improvements in 2.5 are numerous, and almost entirely a result of your feedback: multi-file uploading, one-click plugin upgrades, built-in galleries, customizable dashboard, salted passwords and cookie encryption, media library, a WYSIWYG that doesn&#8217;t mess with your code, concurrent post editing protection, full-screen writing, and search that covers posts <em>and</em> pages.</p>\n<p>For a short overview of the features with screenshots, it&#8217;d be best to <a href=\"http://wordpress.org/development/2008/03/25-sneak-peek/\">visit our sneak peek announcement for RC1</a>. Or check out <a href=\"http://wordpress.org/development/2008/03/wordpress-25-rc2/\">a 4-minute screencast of the new interface in action</a>. If you just want to jump straight to the good stuff <a href=\"http://wordpress.org/download/\">here&#8217;s where you can find 2.5 upgrade and download information</a>.</p>\n<p>If you want to see everything I would grab a cup of coffee or a mojito, because this post is epic.</p>\n<h3>User Features</h3>\n<p><strong>Cleaner, faster, less cluttered dashboard</strong> &#8212; we&#8217;ve worked hard to take your feedback about what&#8217;s most important in the dashboard and organize things to allow you to focus on what&#8217;s important &#8212; your blog &#8212; and get out of your way. In collaboration with <a href=\"http://happycog.com/\">Happy Cog</a> and the community  we&#8217;ve taken the first major step forward in the WordPress interface since version 1.5.</p>\n<p><strong>Dashboard Widgets</strong> &#8212; the dashboard home page is now a series of widgets, including ones to show you fun stats about your posting, latest comments, people linking to you, new and popular plugins, and of course WordPress news. You can customize any of the dashboard widgets to show, for example, news from your local paper instead of WP news. Plugins can also hook in, for example the <a href=\"http://wordpress.org/extend/plugins/stats/\">WordPress.com stats widget</a> adds a handy double-wide stats box.</p>\n<p><img src=\"http://s.wordpress.org/screenshots/2.5/stats-widget.png\" alt=\"\" width=\"690\" /></p>\n<p><strong>Multi-file upload with progress bar</strong> &#8212; before when you would upload a large file you&#8217;d wait forever, never knowing how far along it was. And uploading more than one photo was an exercise in patience, as you could only do one at a time. Now you can select a whole of folder images or music or videos at once and it&#8217;ll show you the progress of each upload.</p>\n<p><strong>Bonus: EXIF extraction</strong> &#8212; if you upload JPEG files with EXIF metadata like camera make and model, aperture, shutter speed, ISO, et al. WordPress will extract all the data into custom fields you can use in your template. If you use the EXIF title fields or similar those will be put into their equivalent fields in WP. Most modern digital cameras generate EXIF data.</p>\n<p><strong>Search posts and pages</strong> &#8212; search used to cover just posts, now it includes pages too, a great boon for those using WordPress as a CMS. New themes can style or sort pages differently in results.</p>\n<p><strong>Tag management</strong> &#8212; you can now add, rename, delete, and do whatever else you like to tags from inside WordPress, no plugins needed.</p>\n<p><strong>Password strength meter</strong> &#8212; when you change your password on your profile it&#8217;ll tell you how strong your password is to help you pick a good one.</p>\n<p><strong>Concurrent editing protection</strong> &#8212; for those of you on multi-author blogs, have you ever opened a post while someone was already editing it, and your auto-saves kept overwriting each other, irrecoverably losing hours of work? I bet that added a few words to your vocabulary. Now if you open a post that someone else is editing, WordPress magically locks it and prevents you from saving until the other person is done. You&#8217;ll see a message like below.</p>\n<p><img src=\"http://s.wordpress.org/screenshots/2.5/write-currently-editing.png\" alt=\"\" /></p>\n<p><strong>Few-click plugin upgrades</strong> &#8212; if the plugins you use are part of the plugin directory since 2.3 we&#8217;ve told you when they have an update available. Now we take that to the next logical step &#8212; downloading and installing the upgrade for you. This is dependent a little bit on your host setup, and it may ask you for your FTP password much like OS X or Windows will ask you for a password, but it works well on majority of hosts we were able to test, your mileage may very, plugins in mirror may be larger than they appear.</p>\n<p><strong>Friendlier visual post editor</strong> &#8212; I&#8217;m not sure how to articulate this improvement except to say &#8220;it doesn&#8217;t mess with your code anymore.&#8221; We&#8217;re now using version 3.0 of TinyMCE, which means better compatibility with Safari, and we&#8217;ve paid particular attention this release to its integration and interaction with complex HTML. It also now has a &#8220;no-distractions&#8221; mode which is like Writeroom for your browser.</p>\n<p><strong>Built-in galleries</strong> &#8212; when you take advantage of multi-file upload to upload a bunch of photos, we have a new shortcode that lets you to easily embed galleries by just putting [ gallery] (without the space) in your post. It&#8217;ll display all your thumbnails and captions and each will link each to a page where people can comment on the individual photos. I&#8217;ve been using this feature on my blog and have already uploaded over <a href=\"http://ma.tt/category/gallery/\">1,200 pictures into 23 galleries</a>. The shortcode has some hidden options too, <a href=\"http://codex.wordpress.org/Using_the_gallery_shortcode\">check out this documentation</a>.</p>\n<h3>Developer Features</h3>\n<p>Now for the geeky stuff. While we&#8217;re excited about the above features, each one represents a new opportunity or API for other developers to take to another level. (The best of which we&#8217;ll someday integrate back into WP.)</p>\n<p><strong>Salted passwords</strong> &#8212; we now use the <a href=\"http://www.openwall.com/phpass/\">phpass</a> library to stretch and salt all passwords stored in the database, which makes brute-forcing them impractical. If you use something like <a href=\"http://modauthmysql.sourceforge.net/\">mod_auth_mysql</a> we&#8217;ve <a href=\"http://wordpress.org/extend/plugins/md5-password-hashes/\">created a plugin that will allow you to use legacy MD5 hashing</a>. (The hashing is completely pluggable.) Users will automatically switch to the more secure passwords next time they log in.</p>\n<p><strong>Secure cookies</strong> &#8212; cookies are now encrypted based on the protocol described <a href=\"http://www.cse.msu.edu/~alexliu/publications/Cookie/cookie.pdf\">in this PDF paper</a>. which is something like <code>user name|expiration time|HMAC( user name|expiration time, k)</code> where <code>k = HMAC(user name|expiration time, sk)</code> and where <code>sk</code> is a secret key, which you can define in your config.</p>\n<p><strong>Easy taxonomy and URL creation</strong> &#8212; probably best illustrated with an example: I can call <code>register_taxonomy()</code> with <a href=\"http://trac.wordpress.org/attachment/ticket/6357/taxes.php\">a few arguments</a> to register a &#8220;people&#8221; taxonomy and whenever I edit an image I&#8217;ll see a UI like tags has for identifying the people in a photo, and these will be URL addressable with <code>/person/firstname-lastname/</code>. All with a single function call.</p>\n<p><strong>Inline documentation</strong> &#8212; the vast majority of the new code going into WordPress include inline documentation that explains the functions and documents their arguments.</p>\n<p><strong>Database optimization</strong> &#8212; we haven&#8217;t changed the table layout in this release, which is one of the reasons so many plugins work fine with 2.5. We have added a few new indicies and made a few default fields more flexible based on some bottlenecks we found on WordPress.com, which now hosts 2.7 million WordPress blogs. It should be invisible to the application, just a bit faster on the database side.</p>\n<p><strong>$wpdb->prepare()</strong> &#8212; now almost all of the SQL in WordPress is prepared first, and the same functions are available to your plugins. This should prevent elementary SQL escaping issues.</p>\n<p><strong>Media buttons</strong> &#8212; the add media buttons above the post are both expandable, so you could have an &#8220;Add Google Map&#8221; button if you like, They can be overridden, so if you think you can do the video or audio tab better than we have you can replace the default.</p>\n<p><strong>Shortcode API</strong> &#8212; the new gallery functionality is powered by the new shortcode API. Shortcodes are little bracket-delineated strings that can be magically expanded at runtime to something more interesting. They give users a short, easy to type and copy/paste string they can move around their post without worrying about messing up complex HTML or embed codes. <a href=\"http://codex.wordpress.org/Shortcode_API\">The Shortcode API is fully documented</a>.</p>\n<p>Now you see why 2.5 took a little extra time. <img src=\'http://wordpress.org/development/wp-includes/images/smilies/icon_smile.gif\' alt=\':)\' class=\'wp-smiley\' /> </p>\n<h3>Upgrade Notes</h3>\n<p>2.5 does include security fixes so it is recommended for all users, the 2.3 branch will no longer be updated. <a href=\"http://codex.wordpress.org/Upgrading_WordPress\">The upgrade instructions for this version are pretty much the same as any other version</a>. The most important thing to check is your plugins, so if for example everything works except the new uploader, a legacy plugin might be causing a javascript error on the page and breaking it. If something goes wrong, the safest thing to do is turn your plugins off (we have a button to do them all at once, now) and turn them back on one-by-one, testing the problem along the way. This has solved almost everybody&#8217;s problems in testing, and it also lets you know which plugin author to show some love to so they&#8217;ll update their plugin, and which plugin authors already have so you can shower them with praises on your blog.</p>\n<p>One brief note about some of the new upload and plugin upgrade features, there are some edge-case hosting platforms, like versions of Lighttpd before 1.5 or over-agressive mod_security rules, which can break. If something isn&#8217;t working like it was looked in the screenshot, ask your host if there&#8217;s something on the server side which may be interfering. Hosts, feel free to join and post to <a href=\"http://lists.automattic.com/mailman/listinfo/wp-testers\">our wp-testers mailing list</a> if you have an environment that requires some extra code to work around. We&#8217;d be happy to include it in the next update.</p>\n<p><em>Quick tip:</em> in 2.5 you click the name of things to edit them, like your username to edit your profile or the title of a post to edit it.</p>\n<h3>The Community is Growing</h3>\n<p>More than growing, it&#8217;s on fire. We always talk about things like downloads, and the 2.3 branch has already had <strong>1.92 million downloads</strong> as I write this post, but this time we have some far more interesting information I&#8217;d like to share.</p>\n<p>There were over 1,200 commits to our repository since 2.3.0 and <strong>over 90 people were credited</strong> in them. This means in our core code, not plugins, there were at least 90 individual folks that contributed something high-quality enough that it made the cut to be part of the download you guys get today. I had no idea this group of people was so large.</p>\n<p>Outside of the <a href=\"http://wordpress.org/about/\">core commit team</a>, there was particular help from these people, in rough order of number of credits and tickets: <a href=\"http://blogwaffe.com/\">mdawaffe (Michael Adams)</a>, <a href=\"http://www.laptoptips.ca/\">azaozz (Andrew Ozz)</a>, <a href=\"http://nb.niichavo.org/\">nbachiyski (Nikolay Bachiyski)</a>, <a href=\"http://skeltoac.com/\">andy (Andy Skelton)</a>, <a href=\"http://iammattthomas.com/\">iammattthomas (Matt Thomas)</a>, <a href=\"http://thresholdstate.com/\">tellyworth (Alex Shiels)</a>, <a href=\"http://joseph.randomnetworks.com/\">josephscott (Joseph Scott)</a>, <a href=\"http://foolswisdom.com/\">lloydbudd (Lloyd Budd)</a>, <a href=\"http://dd32.id.au/\">DD32 (Dion)</a>, <a href=\"http://www.ilfilosofo.com/\">filosofo (Austin Matzko)</a>, <a href=\"http://engel.uk.to/\">hansengel (Hans Engel)</a>, <a href=\"http://www.freecharity.org.uk/\">pishmishy</a>, ffemtcj, <a href=\"http://www.viper007bond.com/\">Viper007Bond</a>, <a href=\"http://extralogical.net/\">ionfish (Benedict Eastaugh)</a>, <a href=\"http://www.poplarware.com/\">jhodgdon (Jennifer Hodgdon)</a>, <a href=\"http://ottodestruct.com/blog/\">Otto42</a>, <a href=\"http://www.cefm.ca/\">thee17 (Charles E. Free-Melvin)</a>, and <a href=\"http://www.buayacorp.com/\">xknown</a>. Also want to thank MichaelH and Lorelle on the documentation side, and moshu, Kafkaesqui, whooami, MichaelH, Otto42, and jeremyclark13 for helping with support.</p>\n<p>The 2.5 branch is nicknamed &#8220;Brecker&#8221; in honor of <a href=\"http://en.wikipedia.org/wiki/Michael_Brecker\">Michael Brecker</a>, an exceptionally talented saxophonist who could cross styles effortlessly and never stopped experimenting and pushing himself until he passed away last year.</p>\n<h3>New WordPress.org</h3>\n<p>All of this wasn&#8217;t enough, so in our copious spare time we decided to redesign WordPress.org to better match the aesthetics of the new dashboard and also to spruce up a few areas that needed lovin&#8217;. Some parts of the site, like the Codex, might show the old style for a day or two. We know, just give us a bit of time. Thanks to <a href=\"http://iammattthomas.com/\">Matt Thomas</a> for his epic effort in designing and coding the new site.</p>\n<h3>What&#8217;s Next</h3>\n<p>As always with WordPress, we don&#8217;t claim any of these features to be perfect, or to be better than everyone else in the world, but they are done by and for the people and the one thing we do promise is that with every release we listen and do our best to improve. </p>\n<p>2.5 is a major milestone for WordPress not because it added dozens of user-requested features, but because it reaffirms that we&#8217;re as passionate about blogging as the day we started. Our community is too fierce to rest on its laurels &#8212; contrary to what pundits claim, blogging is far from &#8220;finished&#8221; and every improvement just whets our appetite for more. And more is coming.</p>\n<p>It&#8217;s a good thing WordPress doesn&#8217;t limit the length of posts, because this one would have hit it. If you made it this far, thanks for sharing a bit of your day with us. I sincerely hope this new version of WordPress helps you do what you love to do.</p>\n\";}i:8;a:12:{s:5:\"title\";s:32:\"Screencast and WordPress 2.5 RC2\";s:4:\"link\";s:58:\"http://wordpress.org/development/2008/03/wordpress-25-rc2/\";s:8:\"comments\";s:67:\"http://wordpress.org/development/2008/03/wordpress-25-rc2/#comments\";s:7:\"pubdate\";s:31:\"Wed, 26 Mar 2008 11:36:25 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Matt\";}s:8:\"category\";s:11:\"Development\";s:4:\"guid\";s:39:\"http://wordpress.org/development/?p=227\";s:11:\"description\";s:334:\"2.5 is coming along thanks to the fantastic feedback you guys provided on RC1 (over 580 pingbacks and counting), and we&#8217;re now ready to show you a bit more of a peek with a short screencast covering the new dashboard and uploader and Release Candidate 2. First here&#8217;s the screencast, which is also available embedded [...]\";s:7:\"content\";a:1:{s:7:\"encoded\";s:2991:\"<p>2.5 is coming along thanks to the <a href=\"http://wordpress.org/development/2008/03/25-sneak-peek/\">fantastic feedback you guys provided on RC1</a> (over 580 pingbacks and counting), and we&#8217;re now ready to show you a bit more of a peek with a short screencast covering the new dashboard and uploader and Release Candidate 2. First here&#8217;s the screencast, which is also available embedded below, <a href=\"http://s.wordpress.org/resources/2.5/dashboard-and-images.swf\">as a Flash movie</a>, or as a <a href=\"http://s.wordpress.org/resources/2.5/dashboard-and-images.avi\">17mb AVI download</a>:</p>\n<p>            <object id=\"csSWF\" classid=\"clsid:d27cdb6e-ae6d-11cf-96b8-444553540000\" width=\"640\" height=\"355\" codebase=\"http://active.macromedia.com/flash7/cabs/ swflash.cab#version=9,0,28,0\"><param name=\"src\" value=\"\"/><param name=\"bgcolor\" value=\"#1a1a1a\"/><param name=\"quality\" value=\"best\"/><param name=\"allowScriptAccess\" value=\"always\"/><param name=\"allowFullScreen\" value=\"true\"/><param name=\"scale\" value=\"showall\"/><param name=\"flashVars\" value=\"autostart=false\"/><embed name=\"csSWF\" src=\"http://s.wordpress.org/resources/2.5/dashboard-and-images.swf\" width=\"549\" height=\"304\" bgcolor=\"#1a1a1a\" quality=\"best\" allowScriptAccess=\"always\" allowFullScreen=\"true\" scale=\"showall\" flashVars=\"autostart=false\" pluginspage=\"http://www.macromedia.com/shockwave/download/index.cgi?P1_Prod_Version=ShockwaveFlash\"></embed></object></p>\n<p>I&#8217;ve <a href=\"http://ma.tt/category/gallery/\">uploaded more than a thousand photos already</a> into the new gallery system &#8212; it works.</p>\n<p>(This was my first screencast, but I hope we can have more on WordPress.org and our documentation in the future.)</p>\n<p>If you make frequent backups and you’re interested in helping us out with development by testing the very latest, <a href=\"http://wordpress.org/wordpress-2.5-RC2.zip\">download</a> and install <a href=\"http://wordpress.org/wordpress-2.5-RC2.zip\">Release Candidate 2</a> of WordPress 2.5, and <a href=\"http://lists.automattic.com/mailman/listinfo/wp-testers\">join our testers mailing list</a> to report any bugs you find in the code.</p>\n<p>Finally with regards to theme and plugin compatibility, we&#8217;ve had no reports of any broken themes in this upgrade, which makes sense because we didn&#8217;t really change anything core about themes, just added new optional capabilities like Gravatars. Plugins that work with the admin may require updating to take advantage of the new, cleaner UI in WordPress 2.5.</p>\n<p>The community has started to <a href=\"http://codex.wordpress.org/Plugins/Plugin_Compatibility/2.5\">keep a list here of which plugins work great and which don&#8217;t</a>. It&#8217;s worth looking at, or even better just deactivate your plugins before upgrading for 2.5 and let the built-in updater notify and give you one-click upgrades to plugins you have installed, assuming the developer is cool and has updated their code for 2.5 already.</p>\n\";}s:3:\"wfw\";a:1:{s:10:\"commentrss\";s:63:\"http://wordpress.org/development/2008/03/wordpress-25-rc2/feed/\";}s:7:\"summary\";s:334:\"2.5 is coming along thanks to the fantastic feedback you guys provided on RC1 (over 580 pingbacks and counting), and we&#8217;re now ready to show you a bit more of a peek with a short screencast covering the new dashboard and uploader and Release Candidate 2. First here&#8217;s the screencast, which is also available embedded [...]\";s:12:\"atom_content\";s:2991:\"<p>2.5 is coming along thanks to the <a href=\"http://wordpress.org/development/2008/03/25-sneak-peek/\">fantastic feedback you guys provided on RC1</a> (over 580 pingbacks and counting), and we&#8217;re now ready to show you a bit more of a peek with a short screencast covering the new dashboard and uploader and Release Candidate 2. First here&#8217;s the screencast, which is also available embedded below, <a href=\"http://s.wordpress.org/resources/2.5/dashboard-and-images.swf\">as a Flash movie</a>, or as a <a href=\"http://s.wordpress.org/resources/2.5/dashboard-and-images.avi\">17mb AVI download</a>:</p>\n<p>            <object id=\"csSWF\" classid=\"clsid:d27cdb6e-ae6d-11cf-96b8-444553540000\" width=\"640\" height=\"355\" codebase=\"http://active.macromedia.com/flash7/cabs/ swflash.cab#version=9,0,28,0\"><param name=\"src\" value=\"\"/><param name=\"bgcolor\" value=\"#1a1a1a\"/><param name=\"quality\" value=\"best\"/><param name=\"allowScriptAccess\" value=\"always\"/><param name=\"allowFullScreen\" value=\"true\"/><param name=\"scale\" value=\"showall\"/><param name=\"flashVars\" value=\"autostart=false\"/><embed name=\"csSWF\" src=\"http://s.wordpress.org/resources/2.5/dashboard-and-images.swf\" width=\"549\" height=\"304\" bgcolor=\"#1a1a1a\" quality=\"best\" allowScriptAccess=\"always\" allowFullScreen=\"true\" scale=\"showall\" flashVars=\"autostart=false\" pluginspage=\"http://www.macromedia.com/shockwave/download/index.cgi?P1_Prod_Version=ShockwaveFlash\"></embed></object></p>\n<p>I&#8217;ve <a href=\"http://ma.tt/category/gallery/\">uploaded more than a thousand photos already</a> into the new gallery system &#8212; it works.</p>\n<p>(This was my first screencast, but I hope we can have more on WordPress.org and our documentation in the future.)</p>\n<p>If you make frequent backups and you’re interested in helping us out with development by testing the very latest, <a href=\"http://wordpress.org/wordpress-2.5-RC2.zip\">download</a> and install <a href=\"http://wordpress.org/wordpress-2.5-RC2.zip\">Release Candidate 2</a> of WordPress 2.5, and <a href=\"http://lists.automattic.com/mailman/listinfo/wp-testers\">join our testers mailing list</a> to report any bugs you find in the code.</p>\n<p>Finally with regards to theme and plugin compatibility, we&#8217;ve had no reports of any broken themes in this upgrade, which makes sense because we didn&#8217;t really change anything core about themes, just added new optional capabilities like Gravatars. Plugins that work with the admin may require updating to take advantage of the new, cleaner UI in WordPress 2.5.</p>\n<p>The community has started to <a href=\"http://codex.wordpress.org/Plugins/Plugin_Compatibility/2.5\">keep a list here of which plugins work great and which don&#8217;t</a>. It&#8217;s worth looking at, or even better just deactivate your plugins before upgrading for 2.5 and let the built-in updater notify and give you one-click upgrades to plugins you have installed, assuming the developer is cool and has updated their code for 2.5 already.</p>\n\";}i:9;a:12:{s:5:\"title\";s:14:\"2.5 Sneak Peek\";s:4:\"link\";s:55:\"http://wordpress.org/development/2008/03/25-sneak-peek/\";s:8:\"comments\";s:64:\"http://wordpress.org/development/2008/03/25-sneak-peek/#comments\";s:7:\"pubdate\";s:31:\"Tue, 18 Mar 2008 07:08:57 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Matt\";}s:8:\"category\";s:11:\"Development\";s:4:\"guid\";s:39:\"http://wordpress.org/development/?p=226\";s:11:\"description\";s:360:\"A customizable dashboard, multi-file upload, built-in galleries, one-click plugin upgrades, tag management, built-in Gravatars, full text feeds, and faster load times sound interesting? Then WordPress 2.5 might be the release for you. It&#8217;s been in the oven for a while, and we&#8217;re finally ready to open the doors a bit to give you a taste.\nFor [...]\";s:7:\"content\";a:1:{s:7:\"encoded\";s:5448:\"<p>A customizable dashboard, multi-file upload, built-in galleries, one-click plugin upgrades, tag management, built-in Gravatars, full text feeds, and faster load times sound interesting? Then WordPress 2.5 might be the release for you. It&#8217;s been in the oven for a while, and we&#8217;re finally ready to open the doors a bit to give you a taste.</p>\n<p>For the past few months, we’ve been working with our friends at Happy Cog &#8212; <a href=\"http://zeldman.com/\">Jeffrey Zeldman</a>, <a href=\"http://jasonsantamaria.com/\">Jason Santa Maria</a>, and <a href=\"http://bobulate.com/\">Liz Danzico</a> &#8212; to redesign WordPress from the ground-up. The result is a new way of interacting with WordPress that will remain familiar to seasoned users while improving the experience for everyone. This isn’t just a fresh coat of paint &#8212; we’ve re-thought the look of WordPress, as well as how it’s organized so that you can forget about the software and focus on your own creative pursuits.</p>\n<p>Here are a few vignettes of what&#8217;s in store.</p>\n<h3>The Dashboard</h3>\n<p class=\"tutscreen\"><img src=\"http://wpcom.wordpress.com/files/2008/03/dashboard-wide.png\" alt=\"dashboard-wide.png\" /></p>\n<p>The Dashboard’s most important role is to inform quickly and get you to where you’re headed in the admin. In interviewing users, we found that most of you ignore the Dashboard entirely &#8212; its useful information being mostly hidden in an overly complex design. The new Dashboard is focused on the most relevant tasks at hand: a quick summary of what’s published and scheduled for publication, the latest comments and incoming links, blog stats, and WordPress updates and news. You can add your own RSS feeds and edit the way information is presented so that the new Dashboard conforms to the way you use WordPress.</p>\n<h3>Navigation</h3>\n<p class=\"tutscreen\"><img src=\"http://wpcom.wordpress.com/files/2008/03/nav-wide.png\" alt=\"nav-wide.png\" /></p>\n<p>The WordPress navigation has confounded even sophisticated users. With the new design, we’ve cut the number of navigation options in half, separating the primary functions (writing, managing posts and pages, editing the blog’s design, and managing comments) from secondary functions. This presents information at a more comfortable pace, revealing only the information that’s necessary. Everything you need is still there &#8212; just better organized. (Especially for people new to WP.)</p>\n<h3>Write</h3>\n<p class=\"tutscreen\"><img src=\"http://wpcom.wordpress.com/files/2008/03/write-wide.png\" alt=\"write-wide.png\" /></p>\n<p><img class=\"right\" src=\"http://wpcom.wordpress.com/files/2008/03/write3.png\" alt=\"write2.png\" /></p>\n<p>By far, the most frequently accessed part of WordPress is the Write screen. It gets the job done, but its myriad options can be overwhelming. The new write screen only displays the information that you’ll use most often. It displays the most common fields in a way that makes posting incredibly easy. Additional options are hidden away until you need them. The new Write screen anticipates the natural flow of the way you write, and is smart enough to remember the way you left it so that your preferred writing environment is always quickly available. The new visual editor even has a handy full-screen mode to help block out distractions while composing your newest post. (My personal favorite new feature.)</p>\n<h3>Manage</h3>\n<p class=\"tutscreen\"><img src=\"http://wpcom.wordpress.com/files/2008/03/manage-wide.png\" alt=\"\" /></p>\n<p><img class=\"right\" src=\"http://wpcom.wordpress.com/files/2008/03/manage.png\" alt=\"\" /></p>\n<p>The Manage screens have been redesigned and unified so that now, managing your pages, posts, media, and comments all use similar, consistent interfaces. We’ve omitted superfluous information and made what’s important faster to find. We believe these changes will make you a faster, more proficient blogger.</p>\n<p>You might also notice there are some new colors, the dashboard feels much fresher and lighter. If you&#8217;re jonesing for the old look under your user options you can now select the &#8220;classic&#8221; colors and get those old blues back. (It&#8217;s also pluggable so people can easily add or share their own color schemes.)</p>\n<p>If you make frequent backups and you&#8217;re interested in helping us out with development by testing the new code, <a href=\"http://wordpress.org/wordpress-2.5-RC1.zip\">download</a> and install <a href=\"http://wordpress.org/wordpress-2.5-RC1.zip\">Release Candidate 1</a> of WordPress 2.5, and <a href=\"http://lists.automattic.com/mailman/listinfo/wp-testers\">join our testers mailing list</a> to report any bugs you find in the code.</p>\n<p>We&#8217;re also interested in feedback on the new interface and would love to hear your opinions, thoughts, rants, raves, and anything in between. We created a special email address just for the occasion: <a href=\"mailto:2.5-feedback@wordpress.org\">2.5-feedback@wordpress.org</a>.</p>\n<p>The software is basically done and stable, and could be released today, but we&#8217;d like to incorporate feedback from a wider audience before making it available to the general public. After a few days of your feedback we&#8217;ll set a final release date. Personally, I can&#8217;t wait. <img src=\'http://wordpress.org/development/wp-includes/images/smilies/icon_smile.gif\' alt=\':)\' class=\'wp-smiley\' /></p>\n\";}s:3:\"wfw\";a:1:{s:10:\"commentrss\";s:60:\"http://wordpress.org/development/2008/03/25-sneak-peek/feed/\";}s:7:\"summary\";s:360:\"A customizable dashboard, multi-file upload, built-in galleries, one-click plugin upgrades, tag management, built-in Gravatars, full text feeds, and faster load times sound interesting? Then WordPress 2.5 might be the release for you. It&#8217;s been in the oven for a while, and we&#8217;re finally ready to open the doors a bit to give you a taste.\nFor [...]\";s:12:\"atom_content\";s:5448:\"<p>A customizable dashboard, multi-file upload, built-in galleries, one-click plugin upgrades, tag management, built-in Gravatars, full text feeds, and faster load times sound interesting? Then WordPress 2.5 might be the release for you. It&#8217;s been in the oven for a while, and we&#8217;re finally ready to open the doors a bit to give you a taste.</p>\n<p>For the past few months, we’ve been working with our friends at Happy Cog &#8212; <a href=\"http://zeldman.com/\">Jeffrey Zeldman</a>, <a href=\"http://jasonsantamaria.com/\">Jason Santa Maria</a>, and <a href=\"http://bobulate.com/\">Liz Danzico</a> &#8212; to redesign WordPress from the ground-up. The result is a new way of interacting with WordPress that will remain familiar to seasoned users while improving the experience for everyone. This isn’t just a fresh coat of paint &#8212; we’ve re-thought the look of WordPress, as well as how it’s organized so that you can forget about the software and focus on your own creative pursuits.</p>\n<p>Here are a few vignettes of what&#8217;s in store.</p>\n<h3>The Dashboard</h3>\n<p class=\"tutscreen\"><img src=\"http://wpcom.wordpress.com/files/2008/03/dashboard-wide.png\" alt=\"dashboard-wide.png\" /></p>\n<p>The Dashboard’s most important role is to inform quickly and get you to where you’re headed in the admin. In interviewing users, we found that most of you ignore the Dashboard entirely &#8212; its useful information being mostly hidden in an overly complex design. The new Dashboard is focused on the most relevant tasks at hand: a quick summary of what’s published and scheduled for publication, the latest comments and incoming links, blog stats, and WordPress updates and news. You can add your own RSS feeds and edit the way information is presented so that the new Dashboard conforms to the way you use WordPress.</p>\n<h3>Navigation</h3>\n<p class=\"tutscreen\"><img src=\"http://wpcom.wordpress.com/files/2008/03/nav-wide.png\" alt=\"nav-wide.png\" /></p>\n<p>The WordPress navigation has confounded even sophisticated users. With the new design, we’ve cut the number of navigation options in half, separating the primary functions (writing, managing posts and pages, editing the blog’s design, and managing comments) from secondary functions. This presents information at a more comfortable pace, revealing only the information that’s necessary. Everything you need is still there &#8212; just better organized. (Especially for people new to WP.)</p>\n<h3>Write</h3>\n<p class=\"tutscreen\"><img src=\"http://wpcom.wordpress.com/files/2008/03/write-wide.png\" alt=\"write-wide.png\" /></p>\n<p><img class=\"right\" src=\"http://wpcom.wordpress.com/files/2008/03/write3.png\" alt=\"write2.png\" /></p>\n<p>By far, the most frequently accessed part of WordPress is the Write screen. It gets the job done, but its myriad options can be overwhelming. The new write screen only displays the information that you’ll use most often. It displays the most common fields in a way that makes posting incredibly easy. Additional options are hidden away until you need them. The new Write screen anticipates the natural flow of the way you write, and is smart enough to remember the way you left it so that your preferred writing environment is always quickly available. The new visual editor even has a handy full-screen mode to help block out distractions while composing your newest post. (My personal favorite new feature.)</p>\n<h3>Manage</h3>\n<p class=\"tutscreen\"><img src=\"http://wpcom.wordpress.com/files/2008/03/manage-wide.png\" alt=\"\" /></p>\n<p><img class=\"right\" src=\"http://wpcom.wordpress.com/files/2008/03/manage.png\" alt=\"\" /></p>\n<p>The Manage screens have been redesigned and unified so that now, managing your pages, posts, media, and comments all use similar, consistent interfaces. We’ve omitted superfluous information and made what’s important faster to find. We believe these changes will make you a faster, more proficient blogger.</p>\n<p>You might also notice there are some new colors, the dashboard feels much fresher and lighter. If you&#8217;re jonesing for the old look under your user options you can now select the &#8220;classic&#8221; colors and get those old blues back. (It&#8217;s also pluggable so people can easily add or share their own color schemes.)</p>\n<p>If you make frequent backups and you&#8217;re interested in helping us out with development by testing the new code, <a href=\"http://wordpress.org/wordpress-2.5-RC1.zip\">download</a> and install <a href=\"http://wordpress.org/wordpress-2.5-RC1.zip\">Release Candidate 1</a> of WordPress 2.5, and <a href=\"http://lists.automattic.com/mailman/listinfo/wp-testers\">join our testers mailing list</a> to report any bugs you find in the code.</p>\n<p>We&#8217;re also interested in feedback on the new interface and would love to hear your opinions, thoughts, rants, raves, and anything in between. We created a special email address just for the occasion: <a href=\"mailto:2.5-feedback@wordpress.org\">2.5-feedback@wordpress.org</a>.</p>\n<p>The software is basically done and stable, and could be released today, but we&#8217;d like to incorporate feedback from a wider audience before making it available to the general public. After a few days of your feedback we&#8217;ll set a final release date. Personally, I can&#8217;t wait. <img src=\'http://wordpress.org/development/wp-includes/images/smilies/icon_smile.gif\' alt=\':)\' class=\'wp-smiley\' /></p>\n\";}}s:7:\"channel\";a:7:{s:5:\"title\";s:26:\"WordPress Development Blog\";s:4:\"link\";s:32:\"http://wordpress.org/development\";s:11:\"description\";s:33:\"WordPress development and updates\";s:7:\"pubdate\";s:31:\"Fri, 18 Jul 2008 06:11:13 +0000\";s:9:\"generator\";s:36:\"http://wordpress.org/?v=2.7-bleeding\";s:8:\"language\";s:2:\"en\";s:7:\"tagline\";s:33:\"WordPress development and updates\";}s:9:\"textinput\";a:0:{}s:5:\"image\";a:0:{}s:9:\"feed_type\";s:3:\"RSS\";s:12:\"feed_version\";s:3:\"2.0\";s:5:\"stack\";a:0:{}s:9:\"inchannel\";b:0;s:6:\"initem\";b:0;s:9:\"incontent\";b:0;s:11:\"intextinput\";b:0;s:7:\"inimage\";b:0;s:13:\"current_field\";s:0:\"\";s:17:\"current_namespace\";b:0;s:19:\"_CONTENT_CONSTRUCTS\";a:6:{i:0;s:7:\"content\";i:1;s:7:\"summary\";i:2;s:4:\"info\";i:3;s:5:\"title\";i:4;s:7:\"tagline\";i:5;s:9:\"copyright\";}s:13:\"last_modified\";s:31:\"Fri, 18 Jul 2008 06:11:13 GMT\r\n\";s:4:\"etag\";s:36:\"\"5edf58286558257950589540fe318e24\"\r\n\";}','no'),(206,0,'rss_1a5f760f2e2b48827d4974a60857e7c2','O:9:\"MagpieRSS\":19:{s:6:\"parser\";i:0;s:12:\"current_item\";a:0:{}s:5:\"items\";a:15:{i:0;a:7:{s:5:\"title\";s:39:\"pfefferle on \"SixGroups Live Community\"\";s:4:\"link\";s:70:\"http://wordpress.org/extend/plugins/sixgroups-livecommunity/#post-6210\";s:7:\"pubdate\";s:31:\"Mon, 07 Jul 2008 19:46:40 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:9:\"pfefferle\";}s:4:\"guid\";s:41:\"6210@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:48:\"to pimp your blog with a sixgroups livecommunity\";s:7:\"summary\";s:48:\"to pimp your blog with a sixgroups livecommunity\";}i:1;a:7:{s:5:\"title\";s:20:\"eelay on \"Listen To\"\";s:4:\"link\";s:56:\"http://wordpress.org/extend/plugins/listen-to/#post-4826\";s:7:\"pubdate\";s:31:\"Thu, 13 Mar 2008 01:32:44 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:5:\"eelay\";}s:4:\"guid\";s:41:\"4826@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:91:\"This plugin will display the latest song you scrobbled trough Last.fm while writing a post.\";s:7:\"summary\";s:91:\"This plugin will display the latest song you scrobbled trough Last.fm while writing a post.\";}i:2;a:7:{s:5:\"title\";s:45:\"maxblogpress on \"MaxBlogPress Ping Optimizer\"\";s:4:\"link\";s:74:\"http://wordpress.org/extend/plugins/maxblogpress-ping-optimizer/#post-2661\";s:7:\"pubdate\";s:31:\"Sun, 16 Dec 2007 07:20:03 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:12:\"maxblogpress\";}s:4:\"guid\";s:41:\"2661@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:87:\"Save your wordpress blog from getting tagged as ping spammer by installing this plugin.\";s:7:\"summary\";s:87:\"Save your wordpress blog from getting tagged as ping spammer by installing this plugin.\";}i:3;a:7:{s:5:\"title\";s:22:\"rungta on \"LinkedList\"\";s:4:\"link\";s:57:\"http://wordpress.org/extend/plugins/linkedlist/#post-5061\";s:7:\"pubdate\";s:31:\"Wed, 02 Apr 2008 08:10:43 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:6:\"rungta\";}s:4:\"guid\";s:41:\"5061@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:87:\"LinkedList sorts your blogroll in the order by which the sites on it were last updated.\";s:7:\"summary\";s:87:\"LinkedList sorts your blogroll in the order by which the sites on it were last updated.\";}i:4;a:7:{s:5:\"title\";s:29:\"hervada on \"Cross-references\"\";s:4:\"link\";s:70:\"http://wordpress.org/extend/plugins/cross-references-plugin/#post-2318\";s:7:\"pubdate\";s:31:\"Sun, 16 Sep 2007 06:45:05 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:7:\"hervada\";}s:4:\"guid\";s:41:\"2318@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:129:\"Insert cross-references between posts and pages easily and get a list of backward references on each post and page automatically.\";s:7:\"summary\";s:129:\"Insert cross-references between posts and pages easily and get a list of backward references on each post and page automatically.\";}i:5;a:7:{s:5:\"title\";s:23:\"photozero on \"Get_OPML\"\";s:4:\"link\";s:55:\"http://wordpress.org/extend/plugins/get-opml/#post-6150\";s:7:\"pubdate\";s:31:\"Tue, 01 Jul 2008 02:40:46 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:9:\"photozero\";}s:4:\"guid\";s:41:\"6150@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:150:\"The plugin can search for the RSS address from your blog Links(Blogroll) automatically,and create a OPML menu.You can insert it into the Reader that s\";s:7:\"summary\";s:150:\"The plugin can search for the RSS address from your blog Links(Blogroll) automatically,and create a OPML menu.You can insert it into the Reader that s\";}i:6;a:7:{s:5:\"title\";s:22:\"boo-box on \"boo-boxfy\"\";s:4:\"link\";s:56:\"http://wordpress.org/extend/plugins/boo-boxfy/#post-5653\";s:7:\"pubdate\";s:31:\"Fri, 16 May 2008 17:26:15 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:7:\"boo-box\";}s:4:\"guid\";s:41:\"5653@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:148:\"Identifies images and videos and creates and insertion interface for boo-box links in those images and videos of the post editing page of WordPress.\";s:7:\"summary\";s:148:\"Identifies images and videos and creates and insertion interface for boo-box links in those images and videos of the post editing page of WordPress.\";}i:7;a:7:{s:5:\"title\";s:36:\"rinogo on \"Featurific For Wordpress\"\";s:4:\"link\";s:71:\"http://wordpress.org/extend/plugins/featurific-for-wordpress/#post-5767\";s:7:\"pubdate\";s:31:\"Wed, 28 May 2008 18:27:08 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:6:\"rinogo\";}s:4:\"guid\";s:41:\"5767@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:150:\"An effortless but powerful interface to Featurific Free, the featured story slideshow.  (Similar to the \'featured\'\nwidget on time.com, msn.com, walmar\";s:7:\"summary\";s:150:\"An effortless but powerful interface to Featurific Free, the featured story slideshow.  (Similar to the \'featured\'\nwidget on time.com, msn.com, walmar\";}i:8;a:7:{s:5:\"title\";s:39:\"Alphawolf on \"Admin Management Xtended\"\";s:4:\"link\";s:71:\"http://wordpress.org/extend/plugins/admin-management-xtended/#post-5415\";s:7:\"pubdate\";s:31:\"Mon, 28 Apr 2008 17:26:30 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:9:\"Alphawolf\";}s:4:\"guid\";s:41:\"5415@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:150:\"Adds AJAX-driven options to some admin management pages with CMS-known functions like toggling post/page visibility without having to open the edit sc\";s:7:\"summary\";s:150:\"Adds AJAX-driven options to some admin management pages with CMS-known functions like toggling post/page visibility without having to open the edit sc\";}i:9;a:7:{s:5:\"title\";s:28:\"aaron_guitar on \"Manageable\"\";s:4:\"link\";s:57:\"http://wordpress.org/extend/plugins/manageable/#post-6071\";s:7:\"pubdate\";s:31:\"Mon, 23 Jun 2008 08:01:03 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:12:\"aaron_guitar\";}s:4:\"guid\";s:41:\"6071@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:150:\"Inline editing of the date, title, author, categories, tags, status and more on both posts and pages without leaving the \"Manage\" admin sections. No n\";s:7:\"summary\";s:150:\"Inline editing of the date, title, author, categories, tags, status and more on both posts and pages without leaving the \"Manage\" admin sections. No n\";}i:10;a:7:{s:5:\"title\";s:20:\"rmm5t on \"WP-Syntax\"\";s:4:\"link\";s:55:\"http://wordpress.org/extend/plugins/wp-syntax/#post-383\";s:7:\"pubdate\";s:31:\"Fri, 09 Mar 2007 23:19:46 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:5:\"rmm5t\";}s:4:\"guid\";s:40:\"383@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:93:\"WP-Syntax provides clean syntax highlighting for embedding source code within pages or posts.\";s:7:\"summary\";s:93:\"WP-Syntax provides clean syntax highlighting for embedding source code within pages or posts.\";}i:11;a:7:{s:5:\"title\";s:22:\"LeonBo on \"com_resize\"\";s:4:\"link\";s:57:\"http://wordpress.org/extend/plugins/com-resize/#post-5407\";s:7:\"pubdate\";s:31:\"Sun, 27 Apr 2008 22:22:46 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:6:\"LeonBo\";}s:4:\"guid\";s:41:\"5407@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:64:\"A nice simple plugin for resizing your images. No configuration!\";s:7:\"summary\";s:64:\"A nice simple plugin for resizing your images. No configuration!\";}i:12;a:7:{s:5:\"title\";s:39:\"oncletom on \"Amazon Widgets Shortcodes\"\";s:4:\"link\";s:72:\"http://wordpress.org/extend/plugins/amazon-widgets-shortcodes/#post-5909\";s:7:\"pubdate\";s:31:\"Tue, 10 Jun 2008 06:59:09 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:8:\"oncletom\";}s:4:\"guid\";s:41:\"5909@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:117:\"Keep your time and save your money with these Amazon widgets shortcodes. Standard compliants, easy to use and so on !\";s:7:\"summary\";s:117:\"Keep your time and save your money with these Amazon widgets shortcodes. Standard compliants, easy to use and so on !\";}i:13;a:7:{s:5:\"title\";s:31:\"GDragoN on \"GD Pages Navigator\"\";s:4:\"link\";s:65:\"http://wordpress.org/extend/plugins/gd-pages-navigator/#post-4510\";s:7:\"pubdate\";s:31:\"Mon, 18 Feb 2008 21:01:36 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:7:\"GDragoN\";}s:4:\"guid\";s:41:\"4510@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:80:\"This widget can be used to change the way of navigating through your blog pages.\";s:7:\"summary\";s:80:\"This widget can be used to change the way of navigating through your blog pages.\";}i:14;a:7:{s:5:\"title\";s:23:\"aercolino on \"WP Chili\"\";s:4:\"link\";s:55:\"http://wordpress.org/extend/plugins/wp-chili/#post-4803\";s:7:\"pubdate\";s:31:\"Sun, 09 Mar 2008 18:00:06 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:9:\"aercolino\";}s:4:\"guid\";s:41:\"4803@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:47:\"Easy code highlighting for Wordpress with Chili\";s:7:\"summary\";s:47:\"Easy code highlighting for Wordpress with Chili\";}}s:7:\"channel\";a:6:{s:5:\"title\";s:16:\"Recently Updated\";s:4:\"link\";s:36:\"http://wordpress.org/extend/plugins/\";s:11:\"description\";s:16:\"Recently Updated\";s:8:\"language\";s:2:\"en\";s:7:\"pubdate\";s:31:\"Fri, 25 Jul 2008 08:34:13 +0000\";s:7:\"tagline\";s:16:\"Recently Updated\";}s:9:\"textinput\";a:0:{}s:5:\"image\";a:0:{}s:9:\"feed_type\";s:3:\"RSS\";s:12:\"feed_version\";s:3:\"2.0\";s:5:\"stack\";a:0:{}s:9:\"inchannel\";b:0;s:6:\"initem\";b:0;s:9:\"incontent\";b:0;s:11:\"intextinput\";b:0;s:7:\"inimage\";b:0;s:13:\"current_field\";s:0:\"\";s:17:\"current_namespace\";b:0;s:19:\"_CONTENT_CONSTRUCTS\";a:6:{i:0;s:7:\"content\";i:1;s:7:\"summary\";i:2;s:4:\"info\";i:3;s:5:\"title\";i:4;s:7:\"tagline\";i:5;s:9:\"copyright\";}s:13:\"last_modified\";s:21:\"2008-07-07 19:46:40\r\n\";s:4:\"etag\";s:36:\"\"a8cc173e307438673214bab863752a13\"\r\n\";}','no'),(73,0,'rss_0ff4b43bd116a9d8720d689c80e7dfd4_ts','1216974853','no'),(74,0,'cron','a:1:{s:7:\"version\";i:2;}','yes'),(75,0,'doing_cron','0','yes'),(78,0,'page_on_front','','yes'),(80,0,'kubrick_header_image','header-img.php?upper=434343&lower=4180b6','yes'),(81,0,'kubrick_header_color','white','yes'),(90,0,'page_attachment_uris','a:1:{s:31:\"tiganiada-2005-2/tiganiada-2005\";s:2:\"25\";}','yes'),(103,0,'wordpress_api_key','825a99ad2f13','yes'),(104,0,'akismet_discard_month','false','yes'),(105,0,'akismet_spam_count','30829','yes'),(114,0,'embeddedvideo_prefix','Direkt','yes'),(115,0,'embeddedvideo_space','false','yes'),(116,0,'embeddedvideo_width','425','yes'),(117,0,'embeddedvideo_show_quicktag','1','yes'),(118,0,'embeddedvideo_small','false','yes'),(119,0,'embeddedvideo_pluginlink','false','yes'),(120,0,'embeddedvideo_version','EV_VERSION','yes'),(121,0,'embeddedvideo_updnotific','','yes'),(122,0,'embeddedvideo_shownolink','false','yes'),(171,0,'page_uris','a:20:{s:26:\"ganduri-de-aproape-weekend\";i:887;s:64:\"groparu-a-facut-accident-de-bicicleta-soferul-a-scapat-nevatamat\";i:886;s:55:\"cateva-consideratiuni-asupra-istoriei-neamului-romanesc\";i:885;s:32:\"idee-de-cum-sa-te-simti-mai-bine\";i:884;s:31:\"cea-mai-mare-companie-americana\";i:883;s:31:\"despre-decebal-traian-remes-dtr\";i:882;s:22:\"era-odata-ca-niciodata\";i:881;s:39:\"despe-privirea-lui-basescu-a-true-story\";i:880;s:30:\"deci-despre-italiani-si-romani\";i:879;s:17:\"la-pizzeria-gente\";i:878;s:32:\"despre-ion-iliescu-si-blogul-sau\";i:877;s:18:\"deci-despre-tigani\";i:876;s:58:\"deci-10-experientze-najpa-ce-le-poti-patiii-la-buda-firmei\";i:875;s:66:\"deci-top-10-chestii-care-nu-se-spune-la-scoala-de-soferi-partea-ii\";i:874;s:65:\"deci-top-10-chestii-care-nu-se-spune-la-scoala-cu-soferi-partea-i\";i:873;s:21:\"deci-scoala-de-soferi\";i:872;s:49:\"top-10-chestii-care-nu-se-spun-miresei-la-o-nunta\";i:871;s:57:\"deci-de-ce-nu-s-o-bucurat-cumnatu-meu-de-craciunul-trecut\";i:870;s:37:\"cateva-replici-penibile-cand-faci-sex\";i:862;s:5:\"about\";i:2;}','yes'),(180,0,'videoembedder_options','a:26:{s:7:\"version\";s:3:\"1.6\";s:11:\"video_width\";s:3:\"425\";s:12:\"video_height\";s:3:\"355\";s:11:\"youtube_tag\";s:7:\"youtube\";s:10:\"google_tag\";s:6:\"google\";s:12:\"metacafe_tag\";s:8:\"metacafe\";s:12:\"liveleak_tag\";s:8:\"liveleak\";s:10:\"revver_tag\";s:6:\"revver\";s:9:\"ifilm_tag\";s:5:\"ifilm\";s:11:\"myspace_tag\";s:7:\"myspace\";s:10:\"bliptv_tag\";s:6:\"bliptv\";s:11:\"college_tag\";s:7:\"college\";s:12:\"videojug_tag\";s:8:\"videojug\";s:11:\"godtube_tag\";s:7:\"godtube\";s:8:\"veoh_tag\";s:4:\"veoh\";s:9:\"break_tag\";s:5:\"break\";s:15:\"dailymotion_tag\";s:5:\"daily\";s:12:\"movieweb_tag\";s:8:\"movieweb\";s:10:\"jaycut_tag\";s:6:\"jaycut\";s:11:\"myvideo_tag\";s:7:\"myvideo\";s:9:\"vimeo_tag\";s:5:\"vimeo\";s:13:\"gtrailers_tag\";s:8:\"gtrailer\";s:11:\"viddler_tag\";s:7:\"viddler\";s:9:\"snotr_tag\";s:5:\"snotr\";s:13:\"quicktime_tag\";s:9:\"quicktime\";s:16:\"windowsmedia_tag\";s:12:\"windowsmedia\";}','yes'),(181,0,'update_core','O:8:\"stdClass\":5:{s:12:\"last_checked\";i:1242065511;s:15:\"version_checked\";s:3:\"2.6\";s:8:\"response\";s:7:\"upgrade\";s:3:\"url\";s:30:\"http://wordpress.org/download/\";s:7:\"current\";s:5:\"2.7.1\";}','yes'),(182,0,'update_plugins','O:8:\"stdClass\":3:{s:12:\"last_checked\";i:1242065511;s:7:\"checked\";a:2:{s:19:\"akismet/akismet.php\";s:5:\"2.1.6\";s:9:\"hello.php\";s:3:\"1.5\";}s:8:\"response\";a:1:{s:19:\"akismet/akismet.php\";O:8:\"stdClass\":5:{s:2:\"id\";s:2:\"15\";s:4:\"slug\";s:7:\"akismet\";s:11:\"new_version\";s:5:\"2.2.3\";s:3:\"url\";s:44:\"http://wordpress.org/extend/plugins/akismet/\";s:7:\"package\";s:49:\"http://downloads.wordpress.org/plugin/akismet.zip\";}}}','yes'),(183,0,'tag_base','','yes'),(184,0,'show_avatars','1','yes'),(185,0,'avatar_rating','G','yes'),(186,0,'upload_url_path','','yes'),(187,0,'thumbnail_size_w','150','yes'),(188,0,'thumbnail_size_h','150','yes'),(189,0,'thumbnail_crop','1','yes'),(190,0,'medium_size_w','300','yes'),(191,0,'medium_size_h','300','yes'),(192,0,'avatar_default','mystery','yes'),(193,0,'enable_app','1','yes'),(194,0,'enable_xmlrpc','1','yes'),(195,0,'auth_salt','j195!wq%c@*)','yes'),(196,0,'logged_in_salt','fa8lX4V2KabH','yes'),(197,0,'dashboard_widget_options','a:3:{s:24:\"dashboard_incoming_links\";a:5:{s:4:\"home\";s:21:\"http://www.groparu.ro\";s:4:\"link\";s:103:\"http://blogsearch.google.com/blogsearch?hl=en&scoring=d&partner=wordpress&q=link:http://www.groparu.ro/\";s:3:\"url\";s:136:\"http://blogsearch.google.com/blogsearch_feeds?hl=en&scoring=d&ie=utf-8&num=10&output=rss&partner=wordpress&q=link:http://www.groparu.ro/\";s:5:\"items\";i:5;s:9:\"show_date\";i:0;}s:17:\"dashboard_primary\";a:7:{s:4:\"link\";s:33:\"http://wordpress.org/development/\";s:3:\"url\";s:38:\"http://wordpress.org/development/feed/\";s:5:\"title\";s:26:\"WordPress Development Blog\";s:5:\"items\";i:2;s:12:\"show_summary\";i:1;s:11:\"show_author\";i:0;s:9:\"show_date\";i:1;}s:19:\"dashboard_secondary\";a:4:{s:4:\"link\";s:28:\"http://planet.wordpress.org/\";s:3:\"url\";s:33:\"http://planet.wordpress.org/feed/\";s:5:\"title\";s:20:\"Other WordPress News\";s:5:\"items\";i:15;}}','yes'),(198,0,'current_theme','WordPress Default','yes'),(199,0,'sidebars_widgets','a:1:{s:13:\"array_version\";i:3;}','yes'),(200,0,'rss_c7068a69ea9ae08dc3d6435f1568114c','O:9:\"MagpieRSS\":17:{s:6:\"parser\";i:0;s:12:\"current_item\";a:0:{}s:5:\"items\";a:3:{i:0;a:5:{s:5:\"title\";s:20:\"Lecturi din blogroll\";s:4:\"link\";s:59:\"http://www.mana.ciutacu.ro/2008/07/21/lecturi-din-blogroll/\";s:11:\"description\";s:244:\"Azi n-am nici timp, nici chef s? scriu. ?i nici vreo idee de Doamne-ajut?! Nu v? spun decât c? anul ?sta n-am ajuns la Cris Garden s? cump?r flori de plantat în ghivece. Jardinierele  mele sunt goale. Adic? nu chiar goale, <b>...</b>\";s:2:\"dc\";a:3:{s:9:\"publisher\";s:15:\"Mariana Ciutacu\";s:7:\"creator\";s:4:\"Mana\";s:4:\"date\";s:20:\"2008-07-21T14:09:44Z\";}s:7:\"summary\";s:244:\"Azi n-am nici timp, nici chef s? scriu. ?i nici vreo idee de Doamne-ajut?! Nu v? spun decât c? anul ?sta n-am ajuns la Cris Garden s? cump?r flori de plantat în ghivece. Jardinierele  mele sunt goale. Adic? nu chiar goale, <b>...</b>\";}i:1;a:5:{s:5:\"title\";s:22:\"Ami, remplis mon verre\";s:4:\"link\";s:64:\"http://turambarr.blogspot.com/2008/07/ami-remplis-mon-verre.html\";s:11:\"description\";s:242:\"In sanatatea lu Groparu, pentru ca ne iubeshte femeile shi e moarte dupe noi. Lasa, frate! Uite aici cum se sublimeaza durerea si cum se stoarce arta din suferintza. Sa cante muzica! Sa curga votca! Inca una shi ma duc... L\'ivrogne <b>...</b>\";s:2:\"dc\";a:3:{s:9:\"publisher\";s:8:\"Turambar\";s:7:\"creator\";s:30:\"noreply@blogger.com (Turambar)\";s:4:\"date\";s:20:\"2008-07-03T22:01:00Z\";}s:7:\"summary\";s:242:\"In sanatatea lu Groparu, pentru ca ne iubeshte femeile shi e moarte dupe noi. Lasa, frate! Uite aici cum se sublimeaza durerea si cum se stoarce arta din suferintza. Sa cante muzica! Sa curga votca! Inca una shi ma duc... L\'ivrogne <b>...</b>\";}i:2;a:5:{s:5:\"title\";s:36:\"Cu Ssangyong Kyron pe Transfagarasan\";s:4:\"link\";s:66:\"http://www.bobbyvoicu.ro/cu-ssangyong-kyron-pe-transfagarasan.html\";s:11:\"description\";s:245:\"I-am “pacalit” iar pe cei de la Ssangyong si mi-au dat si un Kyron la teste (si urmeaza si Actyon-ul). Si am fost pe Transfagarasan (unde am facut si poze - poze cu masina aici). La Balea m-am vazut si cu Andrei Crivat si Groparu. <b>...</b>\";s:2:\"dc\";a:3:{s:9:\"publisher\";s:43:\"Blogul lui Bobby Voicu - alpha beta version\";s:7:\"creator\";s:11:\"Bobby Voicu\";s:4:\"date\";s:20:\"2008-06-25T21:48:50Z\";}s:7:\"summary\";s:245:\"I-am “pacalit” iar pe cei de la Ssangyong si mi-au dat si un Kyron la teste (si urmeaza si Actyon-ul). Si am fost pe Transfagarasan (unde am facut si poze - poze cu masina aici). La Balea m-am vazut si cu Andrei Crivat si Groparu. <b>...</b>\";}}s:7:\"channel\";a:4:{s:5:\"title\";s:48:\"link:http://www.groparu.ro/ - Google Blog Search\";s:4:\"link\";s:106:\"http://blogsearch.google.com/blogsearch?hl=en&scoring=d&ie=ISO-8859-1&num=10&q=link:http://www.groparu.ro/\";s:11:\"description\";s:114:\"Google Blog Search Results: <b>3</b> results for <b>http://www.groparu.ro/</b> - showing <b>1</b> through <b>3</b>\";s:7:\"tagline\";s:114:\"Google Blog Search Results: <b>3</b> results for <b>http://www.groparu.ro/</b> - showing <b>1</b> through <b>3</b>\";}s:9:\"textinput\";a:0:{}s:5:\"image\";a:0:{}s:9:\"feed_type\";s:3:\"RSS\";s:12:\"feed_version\";s:3:\"2.0\";s:5:\"stack\";a:0:{}s:9:\"inchannel\";b:0;s:6:\"initem\";b:0;s:9:\"incontent\";b:0;s:11:\"intextinput\";b:0;s:7:\"inimage\";b:0;s:13:\"current_field\";s:0:\"\";s:17:\"current_namespace\";b:0;s:19:\"_CONTENT_CONSTRUCTS\";a:6:{i:0;s:7:\"content\";i:1;s:7:\"summary\";i:2;s:4:\"info\";i:3;s:5:\"title\";i:4;s:7:\"tagline\";i:5;s:9:\"copyright\";}}','no'),(201,0,'rss_c7068a69ea9ae08dc3d6435f1568114c_ts','1216974852','no'),(202,0,'rss_a5420c83891a9c88ad2a4f04584a5efc','O:9:\"MagpieRSS\":19:{s:6:\"parser\";i:0;s:12:\"current_item\";a:0:{}s:5:\"items\";a:15:{i:0;a:7:{s:5:\"title\";s:33:\"uberdose on \"All in One SEO Pack\"\";s:4:\"link\";s:65:\"http://wordpress.org/extend/plugins/all-in-one-seo-pack/#post-753\";s:7:\"pubdate\";s:31:\"Fri, 30 Mar 2007 20:08:18 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:8:\"uberdose\";}s:4:\"guid\";s:40:\"753@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:92:\"Automatically optimizes your Wordpress blog for Search Engines (Search Engine Optimization).\";s:7:\"summary\";s:92:\"Automatically optimizes your Wordpress blog for Search Engines (Search Engine Optimization).\";}i:1;a:7:{s:5:\"title\";s:44:\"keithdsouza on \"Wordpress Automatic upgrade\"\";s:4:\"link\";s:74:\"http://wordpress.org/extend/plugins/wordpress-automatic-upgrade/#post-2560\";s:7:\"pubdate\";s:31:\"Sat, 27 Oct 2007 20:55:05 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:11:\"keithdsouza\";}s:4:\"guid\";s:41:\"2560@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:112:\"Wordpress automatic upgrade allows a user to automatically upgrade the wordpress installation to the latest one.\";s:7:\"summary\";s:112:\"Wordpress automatic upgrade allows a user to automatically upgrade the wordpress installation to the latest one.\";}i:2;a:7:{s:5:\"title\";s:17:\"matt on \"Akismet\"\";s:4:\"link\";s:52:\"http://wordpress.org/extend/plugins/akismet/#post-15\";s:7:\"pubdate\";s:31:\"Fri, 09 Mar 2007 22:11:30 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"matt\";}s:4:\"guid\";s:39:\"15@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:98:\"Akismet checks your comments against the Akismet web service to see if they look like spam or not.\";s:7:\"summary\";s:98:\"Akismet checks your comments against the Akismet web service to see if they look like spam or not.\";}i:3;a:7:{s:5:\"title\";s:30:\"arnee on \"Google XML Sitemaps\"\";s:4:\"link\";s:70:\"http://wordpress.org/extend/plugins/google-sitemap-generator/#post-132\";s:7:\"pubdate\";s:31:\"Fri, 09 Mar 2007 22:31:32 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:5:\"arnee\";}s:4:\"guid\";s:40:\"132@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:87:\"This plugin will create a Google sitemaps compliant XML-Sitemap of your WordPress blog.\";s:7:\"summary\";s:87:\"This plugin will create a Google sitemaps compliant XML-Sitemap of your WordPress blog.\";}i:4;a:7:{s:5:\"title\";s:29:\"alexrabe on \"NextGEN Gallery\"\";s:4:\"link\";s:62:\"http://wordpress.org/extend/plugins/nextgen-gallery/#post-1169\";s:7:\"pubdate\";s:31:\"Mon, 23 Apr 2007 20:08:06 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:8:\"alexrabe\";}s:4:\"guid\";s:41:\"1169@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:102:\"NextGEN Gallery is a full integrated Image Gallery plugin for WordPress with a Flash slideshow option.\";s:7:\"summary\";s:102:\"NextGEN Gallery is a full integrated Image Gallery plugin for WordPress with a Flash slideshow option.\";}i:5;a:7:{s:5:\"title\";s:25:\"joostdevalk on \"Sociable\"\";s:4:\"link\";s:55:\"http://wordpress.org/extend/plugins/sociable/#post-2865\";s:7:\"pubdate\";s:31:\"Thu, 31 Jan 2008 11:36:17 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:11:\"joostdevalk\";}s:4:\"guid\";s:41:\"2865@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:74:\"Automatically add links on your posts to popular social bookmarking sites.\";s:7:\"summary\";s:74:\"Automatically add links on your posts to popular social bookmarking sites.\";}i:6;a:7:{s:5:\"title\";s:36:\"olivers on \"cformsII - contact form\"\";s:4:\"link\";s:52:\"http://wordpress.org/extend/plugins/cforms/#post-925\";s:7:\"pubdate\";s:31:\"Mon, 09 Apr 2007 22:12:26 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:7:\"olivers\";}s:4:\"guid\";s:40:\"925@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:119:\"cforms II is the most customizable, flexible &#038; powerful ajax supporting contact form plugin (&#038; comment form)!\";s:7:\"summary\";s:119:\"cforms II is the most customizable, flexible &#038; powerful ajax supporting contact form plugin (&#038; comment form)!\";}i:7;a:7:{s:5:\"title\";s:29:\"andy on \"WordPress.com Stats\"\";s:4:\"link\";s:52:\"http://wordpress.org/extend/plugins/stats/#post-1355\";s:7:\"pubdate\";s:31:\"Sun, 06 May 2007 02:15:03 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"andy\";}s:4:\"guid\";s:41:\"1355@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:119:\"You can have simple, concise stats with no additional load on your server by plugging into WordPress.com\'s stat system.\";s:7:\"summary\";s:119:\"You can have simple, concise stats with no additional load on your server by plugging into WordPress.com\'s stat system.\";}i:8;a:7:{s:5:\"title\";s:23:\"GamerZ on \"WP-PageNavi\"\";s:4:\"link\";s:57:\"http://wordpress.org/extend/plugins/wp-pagenavi/#post-363\";s:7:\"pubdate\";s:31:\"Fri, 09 Mar 2007 23:17:57 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:6:\"GamerZ\";}s:4:\"guid\";s:40:\"363@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:59:\"Adds a more advanced paging navigation your WordPress blog.\";s:7:\"summary\";s:59:\"Adds a more advanced paging navigation your WordPress blog.\";}i:9;a:7:{s:5:\"title\";s:20:\"GamerZ on \"WP-Polls\"\";s:4:\"link\";s:54:\"http://wordpress.org/extend/plugins/wp-polls/#post-368\";s:7:\"pubdate\";s:31:\"Fri, 09 Mar 2007 23:18:28 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:6:\"GamerZ\";}s:4:\"guid\";s:40:\"368@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:117:\"Adds an AJAX poll system to your WordPress blog. You can also easily add a poll into your WordPress\'s blog post/page.\";s:7:\"summary\";s:117:\"Adds an AJAX poll system to your WordPress blog. You can also easily add a poll into your WordPress\'s blog post/page.\";}i:10;a:7:{s:5:\"title\";s:27:\"donncha on \"WP Super Cache\"\";s:4:\"link\";s:61:\"http://wordpress.org/extend/plugins/wp-super-cache/#post-2572\";s:7:\"pubdate\";s:31:\"Mon, 05 Nov 2007 11:40:04 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:7:\"donncha\";}s:4:\"guid\";s:41:\"2572@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:73:\"A very fast caching engine for WordPress that produces static html files.\";s:7:\"summary\";s:73:\"A very fast caching engine for WordPress that produces static html files.\";}i:11;a:7:{s:5:\"title\";s:47:\"joostdevalk on \"Google Analytics for WordPress\"\";s:4:\"link\";s:77:\"http://wordpress.org/extend/plugins/google-analytics-for-wordpress/#post-2316\";s:7:\"pubdate\";s:31:\"Fri, 14 Sep 2007 12:15:27 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:11:\"joostdevalk\";}s:4:\"guid\";s:41:\"2316@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:150:\"The Google Analytics for WordPress plugin automatically tracks and segments all outbound links from within posts, comment author links, links within c\";s:7:\"summary\";s:150:\"The Google Analytics for WordPress plugin automatically tracks and segments all outbound links from within posts, comment author links, links within c\";}i:12;a:7:{s:5:\"title\";s:34:\"ronalfy on \"WP Ajax Edit Comments\"\";s:4:\"link\";s:68:\"http://wordpress.org/extend/plugins/wp-ajax-edit-comments/#post-1706\";s:7:\"pubdate\";s:31:\"Sun, 20 May 2007 06:15:08 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:7:\"ronalfy\";}s:4:\"guid\";s:41:\"1706@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:141:\"Allows users and admins to edit comments on a post. Users can edit their own comments for a limited time, while admins can edit all comments.\";s:7:\"summary\";s:141:\"Allows users and admins to edit comments on a post. Users can edit their own comments for a limited time, while admins can edit all comments.\";}i:13;a:7:{s:5:\"title\";s:26:\"GamerZ on \"WP-PostRatings\"\";s:4:\"link\";s:60:\"http://wordpress.org/extend/plugins/wp-postratings/#post-369\";s:7:\"pubdate\";s:31:\"Fri, 09 Mar 2007 23:18:33 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:6:\"GamerZ\";}s:4:\"guid\";s:40:\"369@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:63:\"Adds an AJAX rating system for your WordPress blog\'s post/page.\";s:7:\"summary\";s:63:\"Adds an AJAX rating system for your WordPress blog\'s post/page.\";}i:14;a:7:{s:5:\"title\";s:28:\"azaozz on \"TinyMCE Advanced\"\";s:4:\"link\";s:63:\"http://wordpress.org/extend/plugins/tinymce-advanced/#post-2082\";s:7:\"pubdate\";s:31:\"Wed, 27 Jun 2007 15:00:26 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:6:\"azaozz\";}s:4:\"guid\";s:41:\"2082@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:79:\"Enables most of the advanced features of TinyMCE, the WordPress WYSIWYG editor.\";s:7:\"summary\";s:79:\"Enables most of the advanced features of TinyMCE, the WordPress WYSIWYG editor.\";}}s:7:\"channel\";a:6:{s:5:\"title\";s:12:\"Most Popular\";s:4:\"link\";s:36:\"http://wordpress.org/extend/plugins/\";s:11:\"description\";s:12:\"Most Popular\";s:8:\"language\";s:2:\"en\";s:7:\"pubdate\";s:31:\"Fri, 25 Jul 2008 08:34:12 +0000\";s:7:\"tagline\";s:12:\"Most Popular\";}s:9:\"textinput\";a:0:{}s:5:\"image\";a:0:{}s:9:\"feed_type\";s:3:\"RSS\";s:12:\"feed_version\";s:3:\"2.0\";s:5:\"stack\";a:0:{}s:9:\"inchannel\";b:0;s:6:\"initem\";b:0;s:9:\"incontent\";b:0;s:11:\"intextinput\";b:0;s:7:\"inimage\";b:0;s:13:\"current_field\";s:0:\"\";s:17:\"current_namespace\";b:0;s:19:\"_CONTENT_CONSTRUCTS\";a:6:{i:0;s:7:\"content\";i:1;s:7:\"summary\";i:2;s:4:\"info\";i:3;s:5:\"title\";i:4;s:7:\"tagline\";i:5;s:9:\"copyright\";}s:13:\"last_modified\";s:21:\"2007-03-30 20:08:18\r\n\";s:4:\"etag\";s:36:\"\"a8894f3af502f182fd4e92b6405bade8\"\r\n\";}','no'),(203,0,'rss_a5420c83891a9c88ad2a4f04584a5efc_ts','1216974852','no'),(204,0,'rss_57bc725ad6568758915363af670fd8bc','O:9:\"MagpieRSS\":19:{s:6:\"parser\";i:0;s:12:\"current_item\";a:0:{}s:5:\"items\";a:15:{i:0;a:7:{s:5:\"title\";s:45:\"donncha on \"WordPress MU Sitewide Tags Pages\"\";s:4:\"link\";s:73:\"http://wordpress.org/extend/plugins/wordpress-mu-sitewide-tags/#post-6301\";s:7:\"pubdate\";s:31:\"Wed, 16 Jul 2008 17:06:26 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:7:\"donncha\";}s:4:\"guid\";s:41:\"6301@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:75:\"A central area where all the posts on a WordPress MU site can be collected.\";s:7:\"summary\";s:75:\"A central area where all the posts on a WordPress MU site can be collected.\";}i:1;a:7:{s:5:\"title\";s:39:\"pfefferle on \"SixGroups Live Community\"\";s:4:\"link\";s:70:\"http://wordpress.org/extend/plugins/sixgroups-livecommunity/#post-6210\";s:7:\"pubdate\";s:31:\"Mon, 07 Jul 2008 19:46:40 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:9:\"pfefferle\";}s:4:\"guid\";s:41:\"6210@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:48:\"to pimp your blog with a sixgroups livecommunity\";s:7:\"summary\";s:48:\"to pimp your blog with a sixgroups livecommunity\";}i:2;a:7:{s:5:\"title\";s:25:\"muzedon on \"Hictu Widget\"\";s:4:\"link\";s:83:\"http://wordpress.org/extend/plugins/hictu-plugin-textaudiovideo-comments/#post-6208\";s:7:\"pubdate\";s:31:\"Mon, 07 Jul 2008 13:43:22 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:7:\"muzedon\";}s:4:\"guid\";s:41:\"6208@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:51:\"Easily include the Hictu Widget in WordPress posts.\";s:7:\"summary\";s:51:\"Easily include the Hictu Widget in WordPress posts.\";}i:3;a:7:{s:5:\"title\";s:29:\"djzone on \"Media in response\"\";s:4:\"link\";s:64:\"http://wordpress.org/extend/plugins/media-in-response/#post-6206\";s:7:\"pubdate\";s:31:\"Mon, 07 Jul 2008 06:44:10 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:6:\"djzone\";}s:4:\"guid\";s:41:\"6206@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:17:\"Media in response\";s:7:\"summary\";s:17:\"Media in response\";}i:4;a:7:{s:5:\"title\";s:27:\"ev3rywh3re on \"Yank Widget\"\";s:4:\"link\";s:58:\"http://wordpress.org/extend/plugins/yank-widget/#post-6204\";s:7:\"pubdate\";s:31:\"Sun, 06 Jul 2008 23:19:43 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:10:\"ev3rywh3re\";}s:4:\"guid\";s:41:\"6204@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:97:\"Yank Widget allows the placement of page content in sidebar widgets for different pages or posts.\";s:7:\"summary\";s:97:\"Yank Widget allows the placement of page content in sidebar widgets for different pages or posts.\";}i:5;a:7:{s:5:\"title\";s:18:\"renlok on \"RateIt\"\";s:4:\"link\";s:53:\"http://wordpress.org/extend/plugins/rateit/#post-6203\";s:7:\"pubdate\";s:31:\"Sun, 06 Jul 2008 21:47:25 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:6:\"renlok\";}s:4:\"guid\";s:41:\"6203@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:30:\"Let your users rate your blog.\";s:7:\"summary\";s:30:\"Let your users rate your blog.\";}i:6;a:7:{s:5:\"title\";s:33:\"joostdevalk on \"Email Commenters\"\";s:4:\"link\";s:63:\"http://wordpress.org/extend/plugins/email-commenters/#post-6200\";s:7:\"pubdate\";s:31:\"Sun, 06 Jul 2008 19:34:55 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:11:\"joostdevalk\";}s:4:\"guid\";s:41:\"6200@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:97:\"Gives a simple mailto: link below a post for logged in admins, to email all commenters on a post.\";s:7:\"summary\";s:97:\"Gives a simple mailto: link below a post for logged in admins, to email all commenters on a post.\";}i:7;a:7:{s:5:\"title\";s:36:\"jacobsantos on \"Performance Testing\"\";s:4:\"link\";s:66:\"http://wordpress.org/extend/plugins/performance-testing/#post-6195\";s:7:\"pubdate\";s:31:\"Sun, 06 Jul 2008 13:18:36 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:11:\"jacobsantos\";}s:4:\"guid\";s:41:\"6195@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:59:\"Processes Xdebug cachegrind files for viewing in WordPress.\";s:7:\"summary\";s:59:\"Processes Xdebug cachegrind files for viewing in WordPress.\";}i:8;a:7:{s:5:\"title\";s:38:\"stringfold on \"TinyMCE Entities Patch\"\";s:4:\"link\";s:69:\"http://wordpress.org/extend/plugins/tinymce-entities-patch/#post-6194\";s:7:\"pubdate\";s:31:\"Sun, 06 Jul 2008 07:07:06 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:10:\"stringfold\";}s:4:\"guid\";s:41:\"6194@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:112:\"Prevent spaces and HTML entities (e.g. &amp;gt; or &amp;#39;) from disappearing when editing posts with TinyMCE.\";s:7:\"summary\";s:112:\"Prevent spaces and HTML entities (e.g. &amp;gt; or &amp;#39;) from disappearing when editing posts with TinyMCE.\";}i:9;a:7:{s:5:\"title\";s:35:\"midrangeman on \"Context Ad Wrapper\"\";s:4:\"link\";s:54:\"http://wordpress.org/extend/plugins/ad-wrap/#post-6190\";s:7:\"pubdate\";s:31:\"Sat, 05 Jul 2008 15:35:11 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:11:\"midrangeman\";}s:4:\"guid\";s:41:\"6190@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:150:\"This plugin will mark the key parts of a blog post so that context\nbased ad services can identify the post content and comments for\nthe best ad matchi\";s:7:\"summary\";s:150:\"This plugin will mark the key parts of a blog post so that context\nbased ad services can identify the post content and comments for\nthe best ad matchi\";}i:10;a:7:{s:5:\"title\";s:23:\"xenlab on \"Flare Smith\"\";s:4:\"link\";s:56:\"http://wordpress.org/extend/plugins/feedflare/#post-6188\";s:7:\"pubdate\";s:31:\"Fri, 04 Jul 2008 21:26:21 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:6:\"xenlab\";}s:4:\"guid\";s:41:\"6188@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:134:\"FlareSmith is a plugin to integrate the FeedBurner Stats and FeedFlare services into your WordPress site - without editing your theme!\";s:7:\"summary\";s:134:\"FlareSmith is a plugin to integrate the FeedBurner Stats and FeedFlare services into your WordPress site - without editing your theme!\";}i:11;a:7:{s:5:\"title\";s:24:\"HVBX on \"WP-LinkChanger\"\";s:4:\"link\";s:61:\"http://wordpress.org/extend/plugins/wp-linkchanger/#post-6187\";s:7:\"pubdate\";s:31:\"Fri, 04 Jul 2008 21:15:37 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"HVBX\";}s:4:\"guid\";s:41:\"6187@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:142:\"A small script for affiliate link masking. That means all of your affiliate links in a post will automatically be changed to an internal file.\";s:7:\"summary\";s:142:\"A small script for affiliate link masking. That means all of your affiliate links in a post will automatically be changed to an internal file.\";}i:12;a:7:{s:5:\"title\";s:26:\"alfaguru on \"Side Content\"\";s:4:\"link\";s:59:\"http://wordpress.org/extend/plugins/side-content/#post-6186\";s:7:\"pubdate\";s:31:\"Fri, 04 Jul 2008 19:04:02 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:8:\"alfaguru\";}s:4:\"guid\";s:41:\"6186@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:91:\"Side Content enables you to create widgets which have different content on different pages.\";s:7:\"summary\";s:91:\"Side Content enables you to create widgets which have different content on different pages.\";}i:13;a:7:{s:5:\"title\";s:27:\"mg12 on \"WP-RecentComments\"\";s:4:\"link\";s:64:\"http://wordpress.org/extend/plugins/wp-recentcomments/#post-6185\";s:7:\"pubdate\";s:31:\"Fri, 04 Jul 2008 18:19:04 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"mg12\";}s:4:\"guid\";s:41:\"6185@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:45:\"Display recent comments in your blog sidebar.\";s:7:\"summary\";s:45:\"Display recent comments in your blog sidebar.\";}i:14;a:7:{s:5:\"title\";s:20:\"kofic on \"Adsurfari\"\";s:4:\"link\";s:56:\"http://wordpress.org/extend/plugins/adsurfari/#post-6184\";s:7:\"pubdate\";s:31:\"Fri, 04 Jul 2008 18:07:23 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:5:\"kofic\";}s:4:\"guid\";s:41:\"6184@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:112:\"Post ads on various sites using credits or dollars and make your visitors happy by sharing ad revenue with them.\";s:7:\"summary\";s:112:\"Post ads on various sites using credits or dollars and make your visitors happy by sharing ad revenue with them.\";}}s:7:\"channel\";a:6:{s:5:\"title\";s:6:\"Newest\";s:4:\"link\";s:36:\"http://wordpress.org/extend/plugins/\";s:11:\"description\";s:6:\"Newest\";s:8:\"language\";s:2:\"en\";s:7:\"pubdate\";s:31:\"Fri, 25 Jul 2008 08:34:12 +0000\";s:7:\"tagline\";s:6:\"Newest\";}s:9:\"textinput\";a:0:{}s:5:\"image\";a:0:{}s:9:\"feed_type\";s:3:\"RSS\";s:12:\"feed_version\";s:3:\"2.0\";s:5:\"stack\";a:0:{}s:9:\"inchannel\";b:0;s:6:\"initem\";b:0;s:9:\"incontent\";b:0;s:11:\"intextinput\";b:0;s:7:\"inimage\";b:0;s:13:\"current_field\";s:0:\"\";s:17:\"current_namespace\";b:0;s:19:\"_CONTENT_CONSTRUCTS\";a:6:{i:0;s:7:\"content\";i:1;s:7:\"summary\";i:2;s:4:\"info\";i:3;s:5:\"title\";i:4;s:7:\"tagline\";i:5;s:9:\"copyright\";}s:13:\"last_modified\";s:21:\"2008-07-16 17:06:26\r\n\";s:4:\"etag\";s:36:\"\"b6d05f5026694b7dd3ac32293d40205c\"\r\n\";}','no'),(205,0,'rss_57bc725ad6568758915363af670fd8bc_ts','1216974853','no'),(207,0,'rss_1a5f760f2e2b48827d4974a60857e7c2_ts','1216974853','no');
/*!40000 ALTER TABLE `wp_options` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `wp_postmeta`
--

DROP TABLE IF EXISTS `wp_postmeta`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `wp_postmeta` (
  `meta_id` bigint(20) NOT NULL AUTO_INCREMENT,
  `post_id` bigint(20) NOT NULL DEFAULT 0,
  `meta_key` varchar(255) DEFAULT NULL,
  `meta_value` longtext DEFAULT NULL,
  PRIMARY KEY (`meta_id`),
  KEY `post_id` (`post_id`),
  KEY `meta_key` (`meta_key`)
) ENGINE=MyISAM AUTO_INCREMENT=3479 DEFAULT CHARSET=latin1;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `wp_postmeta`
--

LOCK TABLES `wp_postmeta` WRITE;
/*!40000 ALTER TABLE `wp_postmeta` DISABLE KEYS */;
INSERT INTO `wp_postmeta` VALUES (11,4,'_encloseme','1'),(7,2,'_wp_page_template','default'),(10,4,'_pingme','1'),(16,7,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/catorman.jpg'),(17,7,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:339;s:6:\"height\";i:440;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'73\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2007/03/catorman.jpg\";s:5:\"thumb\";s:22:\"catorman.thumbnail.jpg\";}'),(18,8,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/party-skype.png'),(19,8,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:96;s:6:\"height\";i:96;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'96\'\";s:4:\"file\";s:68:\"/home/groparu/public_html/wp-content/uploads/2007/03/party-skype.png\";s:5:\"thumb\";s:25:\"party-skype.thumbnail.png\";}'),(20,9,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/6477.jpg'),(21,9,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:1280;s:6:\"height\";i:960;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:61:\"/home/groparu/public_html/wp-content/uploads/2007/03/6477.jpg\";s:5:\"thumb\";s:18:\"6477.thumbnail.jpg\";}'),(24,10,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/64771.jpg'),(25,10,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:1280;s:6:\"height\";i:960;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:62:\"/home/groparu/public_html/wp-content/uploads/2007/03/64771.jpg\";s:5:\"thumb\";s:19:\"64771.thumbnail.jpg\";}'),(30,13,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/64772.jpg'),(31,13,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:1280;s:6:\"height\";i:960;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:62:\"/home/groparu/public_html/wp-content/uploads/2007/03/64772.jpg\";s:5:\"thumb\";s:19:\"64772.thumbnail.jpg\";}'),(34,14,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/64773.jpg'),(35,14,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:1280;s:6:\"height\";i:960;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:62:\"/home/groparu/public_html/wp-content/uploads/2007/03/64773.jpg\";s:5:\"thumb\";s:19:\"64773.thumbnail.jpg\";}'),(40,18,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/copsa-mica.jpg'),(41,18,'_wp_attachment_metadata','a:4:{s:5:\"width\";i:2304;s:6:\"height\";i:1536;s:14:\"hwstring_small\";s:23:\"height=\'85\' width=\'128\'\";s:4:\"file\";s:67:\"/home/groparu/public_html/wp-content/uploads/2007/03/copsa-mica.jpg\";}'),(44,19,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/64774.jpg'),(45,19,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:1280;s:6:\"height\";i:960;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:62:\"/home/groparu/public_html/wp-content/uploads/2007/03/64774.jpg\";s:5:\"thumb\";s:19:\"64774.thumbnail.jpg\";}'),(50,20,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/copsa-mica.jpg'),(51,20,'_wp_attachment_metadata','a:4:{s:5:\"width\";i:2304;s:6:\"height\";i:1536;s:14:\"hwstring_small\";s:23:\"height=\'85\' width=\'128\'\";s:4:\"file\";s:67:\"/home/groparu/public_html/wp-content/uploads/2007/03/copsa-mica.jpg\";}'),(52,21,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/copsa-mica_.jpg'),(53,21,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:1152;s:6:\"height\";i:768;s:14:\"hwstring_small\";s:23:\"height=\'85\' width=\'128\'\";s:4:\"file\";s:68:\"/home/groparu/public_html/wp-content/uploads/2007/03/copsa-mica_.jpg\";s:5:\"thumb\";s:25:\"copsa-mica_.thumbnail.jpg\";}'),(58,23,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/tiganiada_11.jpg'),(59,23,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:500;s:6:\"height\";i:375;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:69:\"/home/groparu/public_html/wp-content/uploads/2007/03/tiganiada_11.jpg\";s:5:\"thumb\";s:26:\"tiganiada_11.thumbnail.jpg\";}'),(62,25,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/tiganiada_11.jpg'),(63,25,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:500;s:6:\"height\";i:375;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:69:\"/home/groparu/public_html/wp-content/uploads/2007/03/tiganiada_11.jpg\";s:5:\"thumb\";s:26:\"tiganiada_11.thumbnail.jpg\";}'),(65,27,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/tiganiada_11.jpg'),(66,27,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:500;s:6:\"height\";i:375;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:69:\"/home/groparu/public_html/wp-content/uploads/2007/03/tiganiada_11.jpg\";s:5:\"thumb\";s:26:\"tiganiada_11.thumbnail.jpg\";}'),(69,30,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/politia.jpg'),(70,30,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:1280;s:6:\"height\";i:960;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:64:\"/home/groparu/public_html/wp-content/uploads/2007/03/politia.jpg\";s:5:\"thumb\";s:21:\"politia.thumbnail.jpg\";}'),(73,31,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/manfred.jpg'),(74,31,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:475;s:6:\"height\";i:600;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'76\'\";s:4:\"file\";s:64:\"/home/groparu/public_html/wp-content/uploads/2007/03/manfred.jpg\";s:5:\"thumb\";s:21:\"manfred.thumbnail.jpg\";}'),(83,36,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/leucemie.jpg'),(84,36,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:768;s:6:\"height\";i:1024;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'72\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2007/03/leucemie.jpg\";s:5:\"thumb\";s:22:\"leucemie.thumbnail.jpg\";}'),(89,37,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/ou.jpg'),(90,37,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:135;s:6:\"height\";i:128;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'101\'\";s:4:\"file\";s:59:\"/home/groparu/public_html/wp-content/uploads/2007/03/ou.jpg\";s:5:\"thumb\";s:16:\"ou.thumbnail.jpg\";}'),(93,39,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/camin-16.jpg'),(94,39,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:1024;s:6:\"height\";i:683;s:14:\"hwstring_small\";s:23:\"height=\'85\' width=\'128\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2007/03/camin-16.jpg\";s:5:\"thumb\";s:22:\"camin-16.thumbnail.jpg\";}'),(106,44,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:598;s:6:\"height\";i:503;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'114\'\";s:4:\"file\";s:61:\"/home/groparu/public_html/wp-content/uploads/2007/03/f373.jpg\";s:5:\"thumb\";s:18:\"f373.thumbnail.jpg\";}'),(105,44,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/f373.jpg'),(111,45,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/micutzu.jpg'),(112,45,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:448;s:6:\"height\";i:329;s:14:\"hwstring_small\";s:23:\"height=\'94\' width=\'128\'\";s:4:\"file\";s:64:\"/home/groparu/public_html/wp-content/uploads/2007/03/micutzu.jpg\";s:5:\"thumb\";s:21:\"micutzu.thumbnail.jpg\";}'),(115,46,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/tiganu.jpg'),(116,46,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:480;s:6:\"height\";i:360;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:63:\"/home/groparu/public_html/wp-content/uploads/2007/03/tiganu.jpg\";s:5:\"thumb\";s:20:\"tiganu.thumbnail.jpg\";}'),(119,49,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/maini-si-palinca.jpg'),(120,49,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:1024;s:6:\"height\";i:768;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:73:\"/home/groparu/public_html/wp-content/uploads/2007/03/maini-si-palinca.jpg\";s:5:\"thumb\";s:30:\"maini-si-palinca.thumbnail.jpg\";}'),(123,50,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/coada.jpg'),(124,50,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:475;s:6:\"height\";i:321;s:14:\"hwstring_small\";s:23:\"height=\'86\' width=\'128\'\";s:4:\"file\";s:62:\"/home/groparu/public_html/wp-content/uploads/2007/03/coada.jpg\";s:5:\"thumb\";s:19:\"coada.thumbnail.jpg\";}'),(129,54,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/stilian.jpg'),(130,54,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:1024;s:6:\"height\";i:768;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:64:\"/home/groparu/public_html/wp-content/uploads/2007/03/stilian.jpg\";s:5:\"thumb\";s:21:\"stilian.thumbnail.jpg\";}'),(133,55,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/coprea.jpg'),(134,55,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:768;s:6:\"height\";i:576;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:63:\"/home/groparu/public_html/wp-content/uploads/2007/03/coprea.jpg\";s:5:\"thumb\";s:20:\"coprea.thumbnail.jpg\";}'),(141,59,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/eye-of-god.jpg'),(142,59,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:410;s:6:\"height\";i:410;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'96\'\";s:4:\"file\";s:67:\"/home/groparu/public_html/wp-content/uploads/2007/03/eye-of-god.jpg\";s:5:\"thumb\";s:24:\"eye-of-god.thumbnail.jpg\";}'),(147,62,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/soimii.jpg'),(148,62,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:800;s:6:\"height\";i:533;s:14:\"hwstring_small\";s:23:\"height=\'85\' width=\'128\'\";s:4:\"file\";s:63:\"/home/groparu/public_html/wp-content/uploads/2007/03/soimii.jpg\";s:5:\"thumb\";s:20:\"soimii.thumbnail.jpg\";}'),(151,64,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/hack.jpg'),(152,64,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:1024;s:6:\"height\";i:768;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:61:\"/home/groparu/public_html/wp-content/uploads/2007/03/hack.jpg\";s:5:\"thumb\";s:18:\"hack.thumbnail.jpg\";}'),(155,66,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/peste.jpg'),(156,66,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:1024;s:6:\"height\";i:768;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:62:\"/home/groparu/public_html/wp-content/uploads/2007/03/peste.jpg\";s:5:\"thumb\";s:19:\"peste.thumbnail.jpg\";}'),(157,68,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/peste.jpg'),(158,68,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:700;s:6:\"height\";i:525;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:62:\"/home/groparu/public_html/wp-content/uploads/2007/03/peste.jpg\";s:5:\"thumb\";s:19:\"peste.thumbnail.jpg\";}'),(161,69,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/la-radu.jpg'),(162,69,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:1024;s:6:\"height\";i:768;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:64:\"/home/groparu/public_html/wp-content/uploads/2007/03/la-radu.jpg\";s:5:\"thumb\";s:21:\"la-radu.thumbnail.jpg\";}'),(165,72,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/venus.jpg'),(166,72,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:235;s:6:\"height\";i:598;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'37\'\";s:4:\"file\";s:62:\"/home/groparu/public_html/wp-content/uploads/2007/03/venus.jpg\";s:5:\"thumb\";s:19:\"venus.thumbnail.jpg\";}'),(179,73,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/venus.jpg'),(180,73,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:235;s:6:\"height\";i:598;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'37\'\";s:4:\"file\";s:62:\"/home/groparu/public_html/wp-content/uploads/2007/03/venus.jpg\";s:5:\"thumb\";s:19:\"venus.thumbnail.jpg\";}'),(187,75,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/filtru.jpg'),(188,75,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:248;s:6:\"height\";i:301;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'79\'\";s:4:\"file\";s:63:\"/home/groparu/public_html/wp-content/uploads/2007/03/filtru.jpg\";s:5:\"thumb\";s:20:\"filtru.thumbnail.jpg\";}'),(197,78,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/kitty.jpg'),(198,78,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:702;s:6:\"height\";i:457;s:14:\"hwstring_small\";s:23:\"height=\'83\' width=\'128\'\";s:4:\"file\";s:62:\"/home/groparu/public_html/wp-content/uploads/2007/03/kitty.jpg\";s:5:\"thumb\";s:19:\"kitty.thumbnail.jpg\";}'),(201,80,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/ciai.jpg'),(202,80,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:150;s:6:\"height\";i:203;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'70\'\";s:4:\"file\";s:61:\"/home/groparu/public_html/wp-content/uploads/2007/03/ciai.jpg\";s:5:\"thumb\";s:18:\"ciai.thumbnail.jpg\";}'),(209,83,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/13e0.jpg'),(210,83,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:223;s:6:\"height\";i:223;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'96\'\";s:4:\"file\";s:61:\"/home/groparu/public_html/wp-content/uploads/2007/03/13e0.jpg\";s:5:\"thumb\";s:18:\"13e0.thumbnail.jpg\";}'),(219,88,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/kika.jpg'),(220,88,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:240;s:6:\"height\";i:180;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:61:\"/home/groparu/public_html/wp-content/uploads/2007/03/kika.jpg\";s:5:\"thumb\";s:18:\"kika.thumbnail.jpg\";}'),(225,91,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/fute.jpg'),(226,91,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:960;s:6:\"height\";i:1280;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'72\'\";s:4:\"file\";s:61:\"/home/groparu/public_html/wp-content/uploads/2007/03/fute.jpg\";s:5:\"thumb\";s:18:\"fute.thumbnail.jpg\";}'),(227,92,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/fute.jpg'),(228,92,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:600;s:6:\"height\";i:800;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'72\'\";s:4:\"file\";s:61:\"/home/groparu/public_html/wp-content/uploads/2007/03/fute.jpg\";s:5:\"thumb\";s:18:\"fute.thumbnail.jpg\";}'),(235,95,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/papa.jpg'),(236,95,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:1280;s:6:\"height\";i:960;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:61:\"/home/groparu/public_html/wp-content/uploads/2007/03/papa.jpg\";s:5:\"thumb\";s:18:\"papa.thumbnail.jpg\";}'),(239,96,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/god.jpg'),(240,96,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:780;s:6:\"height\";i:574;s:14:\"hwstring_small\";s:23:\"height=\'94\' width=\'128\'\";s:4:\"file\";s:60:\"/home/groparu/public_html/wp-content/uploads/2007/03/god.jpg\";s:5:\"thumb\";s:17:\"god.thumbnail.jpg\";}'),(243,99,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/matza.jpg'),(244,99,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:800;s:6:\"height\";i:600;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:62:\"/home/groparu/public_html/wp-content/uploads/2007/03/matza.jpg\";s:5:\"thumb\";s:19:\"matza.thumbnail.jpg\";}'),(251,102,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/fire.jpg'),(252,102,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:300;s:6:\"height\";i:198;s:14:\"hwstring_small\";s:23:\"height=\'84\' width=\'128\'\";s:4:\"file\";s:61:\"/home/groparu/public_html/wp-content/uploads/2007/03/fire.jpg\";s:5:\"thumb\";s:18:\"fire.thumbnail.jpg\";}'),(255,104,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/b220.jpg'),(256,104,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:450;s:6:\"height\";i:329;s:14:\"hwstring_small\";s:23:\"height=\'93\' width=\'128\'\";s:4:\"file\";s:61:\"/home/groparu/public_html/wp-content/uploads/2007/03/b220.jpg\";s:5:\"thumb\";s:18:\"b220.thumbnail.jpg\";}'),(261,107,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/robinson-of-a-bitch.jpg'),(262,107,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:332;s:6:\"height\";i:515;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'61\'\";s:4:\"file\";s:76:\"/home/groparu/public_html/wp-content/uploads/2007/03/robinson-of-a-bitch.jpg\";s:5:\"thumb\";s:33:\"robinson-of-a-bitch.thumbnail.jpg\";}'),(345,140,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/porc.jpg'),(346,140,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:470;s:6:\"height\";i:335;s:14:\"hwstring_small\";s:23:\"height=\'91\' width=\'128\'\";s:4:\"file\";s:61:\"/home/groparu/public_html/wp-content/uploads/2007/03/porc.jpg\";s:5:\"thumb\";s:18:\"porc.thumbnail.jpg\";}'),(269,111,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/kitty-bebe.jpg'),(270,111,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:506;s:6:\"height\";i:165;s:14:\"hwstring_small\";s:23:\"height=\'41\' width=\'128\'\";s:4:\"file\";s:67:\"/home/groparu/public_html/wp-content/uploads/2007/03/kitty-bebe.jpg\";s:5:\"thumb\";s:24:\"kitty-bebe.thumbnail.jpg\";}'),(275,112,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/commission.jpg'),(276,112,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:250;s:6:\"height\";i:117;s:14:\"hwstring_small\";s:23:\"height=\'59\' width=\'128\'\";s:4:\"file\";s:67:\"/home/groparu/public_html/wp-content/uploads/2007/03/commission.jpg\";s:5:\"thumb\";s:24:\"commission.thumbnail.jpg\";}'),(281,116,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/companie.jpg'),(282,116,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:504;s:6:\"height\";i:304;s:14:\"hwstring_small\";s:23:\"height=\'77\' width=\'128\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2007/03/companie.jpg\";s:5:\"thumb\";s:22:\"companie.thumbnail.jpg\";}'),(297,123,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/porumb.jpg'),(298,123,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:162;s:6:\"height\";i:145;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'107\'\";s:4:\"file\";s:63:\"/home/groparu/public_html/wp-content/uploads/2007/03/porumb.jpg\";s:5:\"thumb\";s:20:\"porumb.thumbnail.jpg\";}'),(349,141,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/putin.jpg'),(350,141,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:250;s:6:\"height\";i:225;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'106\'\";s:4:\"file\";s:62:\"/home/groparu/public_html/wp-content/uploads/2007/03/putin.jpg\";s:5:\"thumb\";s:19:\"putin.thumbnail.jpg\";}'),(309,129,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/putin.jpg'),(310,129,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:250;s:6:\"height\";i:225;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'106\'\";s:4:\"file\";s:62:\"/home/groparu/public_html/wp-content/uploads/2007/03/putin.jpg\";s:5:\"thumb\";s:19:\"putin.thumbnail.jpg\";}'),(358,143,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:319;s:6:\"height\";i:400;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'76\'\";s:4:\"file\";s:63:\"/home/groparu/public_html/wp-content/uploads/2007/03/eskimo.JPG\";s:5:\"thumb\";s:20:\"eskimo.thumbnail.JPG\";}'),(353,142,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/uncle-sam.jpg'),(354,142,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:479;s:6:\"height\";i:599;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'76\'\";s:4:\"file\";s:66:\"/home/groparu/public_html/wp-content/uploads/2007/03/uncle-sam.jpg\";s:5:\"thumb\";s:23:\"uncle-sam.thumbnail.jpg\";}'),(357,143,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/eskimo.JPG'),(319,135,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/ele.jpg'),(320,135,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:468;s:6:\"height\";i:303;s:14:\"hwstring_small\";s:23:\"height=\'82\' width=\'128\'\";s:4:\"file\";s:60:\"/home/groparu/public_html/wp-content/uploads/2007/03/ele.jpg\";s:5:\"thumb\";s:17:\"ele.thumbnail.jpg\";}'),(341,138,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/bedroommainfloor.JPG'),(342,138,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:313;s:6:\"height\";i:234;s:14:\"hwstring_small\";s:23:\"height=\'95\' width=\'128\'\";s:4:\"file\";s:73:\"/home/groparu/public_html/wp-content/uploads/2007/03/bedroommainfloor.JPG\";s:5:\"thumb\";s:30:\"bedroommainfloor.thumbnail.JPG\";}'),(361,144,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/kitty-bebe.jpg'),(362,144,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:506;s:6:\"height\";i:165;s:14:\"hwstring_small\";s:23:\"height=\'41\' width=\'128\'\";s:4:\"file\";s:67:\"/home/groparu/public_html/wp-content/uploads/2007/03/kitty-bebe.jpg\";s:5:\"thumb\";s:24:\"kitty-bebe.thumbnail.jpg\";}'),(395,146,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/800px-rumunia_5806_resize.jpg'),(396,146,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:474;s:6:\"height\";i:340;s:14:\"hwstring_small\";s:23:\"height=\'91\' width=\'128\'\";s:4:\"file\";s:82:\"/home/groparu/public_html/wp-content/uploads/2007/03/800px-rumunia_5806_resize.jpg\";s:5:\"thumb\";s:39:\"800px-rumunia_5806_resize.thumbnail.jpg\";}'),(407,148,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/9177.jpg'),(408,148,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:244;s:6:\"height\";i:200;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'117\'\";s:4:\"file\";s:61:\"/home/groparu/public_html/wp-content/uploads/2007/03/9177.jpg\";s:5:\"thumb\";s:18:\"9177.thumbnail.jpg\";}'),(411,150,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/tanti-de-pe-tir.jpg'),(412,150,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:467;s:6:\"height\";i:334;s:14:\"hwstring_small\";s:23:\"height=\'91\' width=\'128\'\";s:4:\"file\";s:72:\"/home/groparu/public_html/wp-content/uploads/2007/03/tanti-de-pe-tir.jpg\";s:5:\"thumb\";s:29:\"tanti-de-pe-tir.thumbnail.jpg\";}'),(415,152,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/princeharry.jpg'),(416,152,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:152;s:6:\"height\";i:101;s:14:\"hwstring_small\";s:23:\"height=\'85\' width=\'128\'\";s:4:\"file\";s:68:\"/home/groparu/public_html/wp-content/uploads/2007/03/princeharry.jpg\";s:5:\"thumb\";s:25:\"princeharry.thumbnail.jpg\";}'),(433,156,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/cutezatorii_1970_02_05_electronica.jpg'),(434,156,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:449;s:6:\"height\";i:480;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'89\'\";s:4:\"file\";s:91:\"/home/groparu/public_html/wp-content/uploads/2007/03/cutezatorii_1970_02_05_electronica.jpg\";s:5:\"thumb\";s:48:\"cutezatorii_1970_02_05_electronica.thumbnail.jpg\";}'),(439,157,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/dsc02294.JPG'),(440,157,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:1024;s:6:\"height\";i:768;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2007/03/dsc02294.JPG\";s:5:\"thumb\";s:22:\"dsc02294.thumbnail.JPG\";}'),(441,158,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/kfc-albena_1.jpg'),(442,158,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:700;s:6:\"height\";i:525;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:69:\"/home/groparu/public_html/wp-content/uploads/2007/03/kfc-albena_1.jpg\";s:5:\"thumb\";s:26:\"kfc-albena_1.thumbnail.jpg\";}'),(443,159,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/kfc-albena_11.jpg'),(444,159,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:280;s:6:\"height\";i:210;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:70:\"/home/groparu/public_html/wp-content/uploads/2007/03/kfc-albena_11.jpg\";s:5:\"thumb\";s:27:\"kfc-albena_11.thumbnail.jpg\";}'),(445,161,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/kfc-varna_1.jpg'),(446,161,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:280;s:6:\"height\";i:210;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:68:\"/home/groparu/public_html/wp-content/uploads/2007/03/kfc-varna_1.jpg\";s:5:\"thumb\";s:25:\"kfc-varna_1.thumbnail.jpg\";}'),(447,162,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/kfc-varna_2.jpg'),(448,162,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:280;s:6:\"height\";i:210;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:68:\"/home/groparu/public_html/wp-content/uploads/2007/03/kfc-varna_2.jpg\";s:5:\"thumb\";s:25:\"kfc-varna_2.thumbnail.jpg\";}'),(451,163,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/calinpopescutariceanu.jpg'),(452,163,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:275;s:6:\"height\";i:372;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'70\'\";s:4:\"file\";s:78:\"/home/groparu/public_html/wp-content/uploads/2007/03/calinpopescutariceanu.jpg\";s:5:\"thumb\";s:35:\"calinpopescutariceanu.thumbnail.jpg\";}'),(457,165,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/01-tigani-in-parcare.jpg'),(458,165,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:327;s:6:\"height\";i:245;s:14:\"hwstring_small\";s:23:\"height=\'95\' width=\'128\'\";s:4:\"file\";s:77:\"/home/groparu/public_html/wp-content/uploads/2007/03/01-tigani-in-parcare.jpg\";s:5:\"thumb\";s:34:\"01-tigani-in-parcare.thumbnail.jpg\";}'),(461,166,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/02-tigani-in-parcare-ii.jpg'),(462,166,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:80:\"/home/groparu/public_html/wp-content/uploads/2007/03/02-tigani-in-parcare-ii.jpg\";s:5:\"thumb\";s:37:\"02-tigani-in-parcare-ii.thumbnail.jpg\";}'),(463,167,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/01-tigani-in-parcare.jpg'),(464,167,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:327;s:6:\"height\";i:245;s:14:\"hwstring_small\";s:23:\"height=\'95\' width=\'128\'\";s:4:\"file\";s:77:\"/home/groparu/public_html/wp-content/uploads/2007/03/01-tigani-in-parcare.jpg\";s:5:\"thumb\";s:34:\"01-tigani-in-parcare.thumbnail.jpg\";}'),(465,168,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/02-tigani-in-parcare-ii.jpg'),(466,168,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:80:\"/home/groparu/public_html/wp-content/uploads/2007/03/02-tigani-in-parcare-ii.jpg\";s:5:\"thumb\";s:37:\"02-tigani-in-parcare-ii.thumbnail.jpg\";}'),(467,169,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/03-tiganii-si-porcul.jpg'),(468,169,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:77:\"/home/groparu/public_html/wp-content/uploads/2007/03/03-tiganii-si-porcul.jpg\";s:5:\"thumb\";s:34:\"03-tiganii-si-porcul.thumbnail.jpg\";}'),(471,170,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/04-tiganii-si-porcul-ii.jpg'),(472,170,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:80:\"/home/groparu/public_html/wp-content/uploads/2007/03/04-tiganii-si-porcul-ii.jpg\";s:5:\"thumb\";s:37:\"04-tiganii-si-porcul-ii.thumbnail.jpg\";}'),(475,171,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/06-porcul-tiganilor-se-invatza-cu-lemnu.jpg'),(476,171,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:96:\"/home/groparu/public_html/wp-content/uploads/2007/03/06-porcul-tiganilor-se-invatza-cu-lemnu.jpg\";s:5:\"thumb\";s:53:\"06-porcul-tiganilor-se-invatza-cu-lemnu.thumbnail.jpg\";}'),(477,172,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/07-na-du-te-sa-te-tzuce-porcu-tigane.jpg'),(478,172,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:93:\"/home/groparu/public_html/wp-content/uploads/2007/03/07-na-du-te-sa-te-tzuce-porcu-tigane.jpg\";s:5:\"thumb\";s:50:\"07-na-du-te-sa-te-tzuce-porcu-tigane.thumbnail.jpg\";}'),(481,173,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/08-sa-nu-inerveze-careva-pe-tiganu-de-mandea.jpg'),(482,173,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:101:\"/home/groparu/public_html/wp-content/uploads/2007/03/08-sa-nu-inerveze-careva-pe-tiganu-de-mandea.jpg\";s:5:\"thumb\";s:58:\"08-sa-nu-inerveze-careva-pe-tiganu-de-mandea.thumbnail.jpg\";}'),(483,174,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/09-tiganu-si-matizu.jpg'),(484,174,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:76:\"/home/groparu/public_html/wp-content/uploads/2007/03/09-tiganu-si-matizu.jpg\";s:5:\"thumb\";s:33:\"09-tiganu-si-matizu.thumbnail.jpg\";}'),(485,175,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/10-tiganu-ca-leguma.jpg'),(486,175,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:76:\"/home/groparu/public_html/wp-content/uploads/2007/03/10-tiganu-ca-leguma.jpg\";s:5:\"thumb\";s:33:\"10-tiganu-ca-leguma.thumbnail.jpg\";}'),(487,176,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/11-tiganii-ca-legumele.jpg'),(488,176,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:79:\"/home/groparu/public_html/wp-content/uploads/2007/03/11-tiganii-ca-legumele.jpg\";s:5:\"thumb\";s:36:\"11-tiganii-ca-legumele.thumbnail.jpg\";}'),(489,177,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/12-crajma-vizavi-de-cimitir-unde-bea-tigani-ca-noi.jpg'),(490,177,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:107:\"/home/groparu/public_html/wp-content/uploads/2007/03/12-crajma-vizavi-de-cimitir-unde-bea-tigani-ca-noi.jpg\";s:5:\"thumb\";s:64:\"12-crajma-vizavi-de-cimitir-unde-bea-tigani-ca-noi.thumbnail.jpg\";}'),(491,178,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/13-hai-sa-ti-vindem-un-cal-tiganesc-fara-cip.jpg'),(492,178,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:101:\"/home/groparu/public_html/wp-content/uploads/2007/03/13-hai-sa-ti-vindem-un-cal-tiganesc-fara-cip.jpg\";s:5:\"thumb\";s:58:\"13-hai-sa-ti-vindem-un-cal-tiganesc-fara-cip.thumbnail.jpg\";}'),(495,179,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/14-tigan-calare.jpg'),(496,179,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:72:\"/home/groparu/public_html/wp-content/uploads/2007/03/14-tigan-calare.jpg\";s:5:\"thumb\";s:29:\"14-tigan-calare.thumbnail.jpg\";}'),(497,180,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/15-bulibasa-calare.jpg'),(498,180,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:75:\"/home/groparu/public_html/wp-content/uploads/2007/03/15-bulibasa-calare.jpg\";s:5:\"thumb\";s:32:\"15-bulibasa-calare.thumbnail.jpg\";}'),(499,181,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/16-tiganii-bea-lapte-numa-daca-vacile-bea-coniac.jpg'),(500,181,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:105:\"/home/groparu/public_html/wp-content/uploads/2007/03/16-tiganii-bea-lapte-numa-daca-vacile-bea-coniac.jpg\";s:5:\"thumb\";s:62:\"16-tiganii-bea-lapte-numa-daca-vacile-bea-coniac.thumbnail.jpg\";}'),(501,182,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/17-noul-nostru-prekin-mai-tigan-ca-noi.jpg'),(502,182,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:95:\"/home/groparu/public_html/wp-content/uploads/2007/03/17-noul-nostru-prekin-mai-tigan-ca-noi.jpg\";s:5:\"thumb\";s:52:\"17-noul-nostru-prekin-mai-tigan-ca-noi.thumbnail.jpg\";}'),(503,183,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/18-ce-pisha-tiganii-aia-de-beau-coniac.jpg'),(504,183,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:95:\"/home/groparu/public_html/wp-content/uploads/2007/03/18-ce-pisha-tiganii-aia-de-beau-coniac.jpg\";s:5:\"thumb\";s:52:\"18-ce-pisha-tiganii-aia-de-beau-coniac.thumbnail.jpg\";}'),(505,184,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/19-let-the-hostilities-begin-pe-muzica-tiganeasca.jpg'),(506,184,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:106:\"/home/groparu/public_html/wp-content/uploads/2007/03/19-let-the-hostilities-begin-pe-muzica-tiganeasca.jpg\";s:5:\"thumb\";s:63:\"19-let-the-hostilities-begin-pe-muzica-tiganeasca.thumbnail.jpg\";}'),(507,185,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/20-tigan-de-vierme-de-matase.jpg'),(508,185,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:85:\"/home/groparu/public_html/wp-content/uploads/2007/03/20-tigan-de-vierme-de-matase.jpg\";s:5:\"thumb\";s:42:\"20-tigan-de-vierme-de-matase.thumbnail.jpg\";}'),(511,186,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/01-tigani-in-parcare.jpg'),(512,186,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:327;s:6:\"height\";i:245;s:14:\"hwstring_small\";s:23:\"height=\'95\' width=\'128\'\";s:4:\"file\";s:77:\"/home/groparu/public_html/wp-content/uploads/2007/03/01-tigani-in-parcare.jpg\";s:5:\"thumb\";s:34:\"01-tigani-in-parcare.thumbnail.jpg\";}'),(513,187,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/02-tigani-in-parcare-ii.jpg'),(514,187,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:80:\"/home/groparu/public_html/wp-content/uploads/2007/03/02-tigani-in-parcare-ii.jpg\";s:5:\"thumb\";s:37:\"02-tigani-in-parcare-ii.thumbnail.jpg\";}'),(515,188,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/03-tiganii-si-porcul.jpg'),(516,188,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:77:\"/home/groparu/public_html/wp-content/uploads/2007/03/03-tiganii-si-porcul.jpg\";s:5:\"thumb\";s:34:\"03-tiganii-si-porcul.thumbnail.jpg\";}'),(519,189,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/04-tiganii-si-porcul-ii.jpg'),(520,189,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:80:\"/home/groparu/public_html/wp-content/uploads/2007/03/04-tiganii-si-porcul-ii.jpg\";s:5:\"thumb\";s:37:\"04-tiganii-si-porcul-ii.thumbnail.jpg\";}'),(521,190,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/06-porcul-tiganilor-se-invatza-cu-lemnu.jpg'),(522,190,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:96:\"/home/groparu/public_html/wp-content/uploads/2007/03/06-porcul-tiganilor-se-invatza-cu-lemnu.jpg\";s:5:\"thumb\";s:53:\"06-porcul-tiganilor-se-invatza-cu-lemnu.thumbnail.jpg\";}'),(523,191,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/07-na-du-te-sa-te-tzuce-porcu-tigane.jpg'),(524,191,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:93:\"/home/groparu/public_html/wp-content/uploads/2007/03/07-na-du-te-sa-te-tzuce-porcu-tigane.jpg\";s:5:\"thumb\";s:50:\"07-na-du-te-sa-te-tzuce-porcu-tigane.thumbnail.jpg\";}'),(525,192,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/08-sa-nu-inerveze-careva-pe-tiganu-de-mandea.jpg'),(526,192,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:101:\"/home/groparu/public_html/wp-content/uploads/2007/03/08-sa-nu-inerveze-careva-pe-tiganu-de-mandea.jpg\";s:5:\"thumb\";s:58:\"08-sa-nu-inerveze-careva-pe-tiganu-de-mandea.thumbnail.jpg\";}'),(527,193,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/09-tiganu-si-matizu.jpg'),(528,193,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:76:\"/home/groparu/public_html/wp-content/uploads/2007/03/09-tiganu-si-matizu.jpg\";s:5:\"thumb\";s:33:\"09-tiganu-si-matizu.thumbnail.jpg\";}'),(529,194,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/10-tiganu-ca-leguma.jpg'),(530,194,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:76:\"/home/groparu/public_html/wp-content/uploads/2007/03/10-tiganu-ca-leguma.jpg\";s:5:\"thumb\";s:33:\"10-tiganu-ca-leguma.thumbnail.jpg\";}'),(531,195,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/11-tiganii-ca-legumele.jpg'),(532,195,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:79:\"/home/groparu/public_html/wp-content/uploads/2007/03/11-tiganii-ca-legumele.jpg\";s:5:\"thumb\";s:36:\"11-tiganii-ca-legumele.thumbnail.jpg\";}'),(533,196,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/12-crajma-vizavi-de-cimitir-unde-bea-tigani-ca-noi.jpg'),(534,196,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:107:\"/home/groparu/public_html/wp-content/uploads/2007/03/12-crajma-vizavi-de-cimitir-unde-bea-tigani-ca-noi.jpg\";s:5:\"thumb\";s:64:\"12-crajma-vizavi-de-cimitir-unde-bea-tigani-ca-noi.thumbnail.jpg\";}'),(535,197,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/13-hai-sa-ti-vindem-un-cal-tiganesc-fara-cip.jpg'),(536,197,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:101:\"/home/groparu/public_html/wp-content/uploads/2007/03/13-hai-sa-ti-vindem-un-cal-tiganesc-fara-cip.jpg\";s:5:\"thumb\";s:58:\"13-hai-sa-ti-vindem-un-cal-tiganesc-fara-cip.thumbnail.jpg\";}'),(537,198,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/14-tigan-calare.jpg'),(538,198,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:72:\"/home/groparu/public_html/wp-content/uploads/2007/03/14-tigan-calare.jpg\";s:5:\"thumb\";s:29:\"14-tigan-calare.thumbnail.jpg\";}'),(539,199,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/15-bulibasa-calare.jpg'),(540,199,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:75:\"/home/groparu/public_html/wp-content/uploads/2007/03/15-bulibasa-calare.jpg\";s:5:\"thumb\";s:32:\"15-bulibasa-calare.thumbnail.jpg\";}'),(543,200,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/16-tiganii-bea-lapte-numa-daca-vacile-bea-coniac.jpg'),(544,200,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:105:\"/home/groparu/public_html/wp-content/uploads/2007/03/16-tiganii-bea-lapte-numa-daca-vacile-bea-coniac.jpg\";s:5:\"thumb\";s:62:\"16-tiganii-bea-lapte-numa-daca-vacile-bea-coniac.thumbnail.jpg\";}'),(545,201,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/17-noul-nostru-prekin-mai-tigan-ca-noi.jpg'),(546,201,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:95:\"/home/groparu/public_html/wp-content/uploads/2007/03/17-noul-nostru-prekin-mai-tigan-ca-noi.jpg\";s:5:\"thumb\";s:52:\"17-noul-nostru-prekin-mai-tigan-ca-noi.thumbnail.jpg\";}'),(547,202,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/18-ce-pisha-tiganii-aia-de-beau-coniac.jpg'),(548,202,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:95:\"/home/groparu/public_html/wp-content/uploads/2007/03/18-ce-pisha-tiganii-aia-de-beau-coniac.jpg\";s:5:\"thumb\";s:52:\"18-ce-pisha-tiganii-aia-de-beau-coniac.thumbnail.jpg\";}'),(549,203,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/19-let-the-hostilities-begin-pe-muzica-tiganeasca.jpg'),(550,203,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:106:\"/home/groparu/public_html/wp-content/uploads/2007/03/19-let-the-hostilities-begin-pe-muzica-tiganeasca.jpg\";s:5:\"thumb\";s:63:\"19-let-the-hostilities-begin-pe-muzica-tiganeasca.thumbnail.jpg\";}'),(551,204,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/20-tigan-de-vierme-de-matase.jpg'),(552,204,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:85:\"/home/groparu/public_html/wp-content/uploads/2007/03/20-tigan-de-vierme-de-matase.jpg\";s:5:\"thumb\";s:42:\"20-tigan-de-vierme-de-matase.thumbnail.jpg\";}'),(553,205,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/21-valea-noastra-plina-de-muzica-tiganeasca.jpg'),(554,205,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:100:\"/home/groparu/public_html/wp-content/uploads/2007/03/21-valea-noastra-plina-de-muzica-tiganeasca.jpg\";s:5:\"thumb\";s:57:\"21-valea-noastra-plina-de-muzica-tiganeasca.thumbnail.jpg\";}'),(555,206,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/22-porcu-tiganesc-incepe-indeplinirea-misiunii.jpg'),(556,206,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:103:\"/home/groparu/public_html/wp-content/uploads/2007/03/22-porcu-tiganesc-incepe-indeplinirea-misiunii.jpg\";s:5:\"thumb\";s:60:\"22-porcu-tiganesc-incepe-indeplinirea-misiunii.thumbnail.jpg\";}'),(557,207,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/23-porc-pe-umar-de-tigan.jpg'),(558,207,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:81:\"/home/groparu/public_html/wp-content/uploads/2007/03/23-porc-pe-umar-de-tigan.jpg\";s:5:\"thumb\";s:38:\"23-porc-pe-umar-de-tigan.thumbnail.jpg\";}'),(559,208,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/23-porc-pe-umar-de-tigan.jpg'),(560,208,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:81:\"/home/groparu/public_html/wp-content/uploads/2007/03/23-porc-pe-umar-de-tigan.jpg\";s:5:\"thumb\";s:38:\"23-porc-pe-umar-de-tigan.thumbnail.jpg\";}'),(563,209,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/24-imaginile-si-zambetul-zice-totul.jpg'),(564,209,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:92:\"/home/groparu/public_html/wp-content/uploads/2007/03/24-imaginile-si-zambetul-zice-totul.jpg\";s:5:\"thumb\";s:49:\"24-imaginile-si-zambetul-zice-totul.thumbnail.jpg\";}'),(565,210,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/25-porc-tiganesc.jpg'),(566,210,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:73:\"/home/groparu/public_html/wp-content/uploads/2007/03/25-porc-tiganesc.jpg\";s:5:\"thumb\";s:30:\"25-porc-tiganesc.thumbnail.jpg\";}'),(567,211,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/26-nu-il-mai-prajim.jpg'),(568,211,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:76:\"/home/groparu/public_html/wp-content/uploads/2007/03/26-nu-il-mai-prajim.jpg\";s:5:\"thumb\";s:33:\"26-nu-il-mai-prajim.thumbnail.jpg\";}'),(569,212,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/27-valsul-tiganesc.jpg'),(570,212,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:75:\"/home/groparu/public_html/wp-content/uploads/2007/03/27-valsul-tiganesc.jpg\";s:5:\"thumb\";s:32:\"27-valsul-tiganesc.thumbnail.jpg\";}'),(571,213,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/28-orgie-in-stil-rrom-anesc.jpg'),(572,213,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:84:\"/home/groparu/public_html/wp-content/uploads/2007/03/28-orgie-in-stil-rrom-anesc.jpg\";s:5:\"thumb\";s:41:\"28-orgie-in-stil-rrom-anesc.thumbnail.jpg\";}'),(573,214,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/29-orgie-in-stil-rrom-anesc-ii.jpg'),(574,214,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:87:\"/home/groparu/public_html/wp-content/uploads/2007/03/29-orgie-in-stil-rrom-anesc-ii.jpg\";s:5:\"thumb\";s:44:\"29-orgie-in-stil-rrom-anesc-ii.thumbnail.jpg\";}'),(575,215,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/31-porc-tiganesc-crestat-pt-usturoi.jpg'),(576,215,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:92:\"/home/groparu/public_html/wp-content/uploads/2007/03/31-porc-tiganesc-crestat-pt-usturoi.jpg\";s:5:\"thumb\";s:49:\"31-porc-tiganesc-crestat-pt-usturoi.thumbnail.jpg\";}'),(577,216,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/32-incepe-marea-sfaraiala.jpg'),(578,216,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:82:\"/home/groparu/public_html/wp-content/uploads/2007/03/32-incepe-marea-sfaraiala.jpg\";s:5:\"thumb\";s:39:\"32-incepe-marea-sfaraiala.thumbnail.jpg\";}'),(579,217,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/33-pic-pic-stalactita-de-slanina.jpg'),(580,217,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:89:\"/home/groparu/public_html/wp-content/uploads/2007/03/33-pic-pic-stalactita-de-slanina.jpg\";s:5:\"thumb\";s:46:\"33-pic-pic-stalactita-de-slanina.thumbnail.jpg\";}'),(581,218,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/34-imagine-explicita.jpg'),(582,218,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:77:\"/home/groparu/public_html/wp-content/uploads/2007/03/34-imagine-explicita.jpg\";s:5:\"thumb\";s:34:\"34-imagine-explicita.thumbnail.jpg\";}'),(583,219,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/35-ranjet-imposibil-de-reprodus.jpg'),(584,219,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:88:\"/home/groparu/public_html/wp-content/uploads/2007/03/35-ranjet-imposibil-de-reprodus.jpg\";s:5:\"thumb\";s:45:\"35-ranjet-imposibil-de-reprodus.thumbnail.jpg\";}'),(587,220,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/36-trei-doamne-si-toti-trei-insetati.jpg'),(588,220,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:93:\"/home/groparu/public_html/wp-content/uploads/2007/03/36-trei-doamne-si-toti-trei-insetati.jpg\";s:5:\"thumb\";s:50:\"36-trei-doamne-si-toti-trei-insetati.thumbnail.jpg\";}'),(589,221,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/37-nu-suntem-vegetarieni-nici-nu-vom-fi.jpg'),(590,221,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:96:\"/home/groparu/public_html/wp-content/uploads/2007/03/37-nu-suntem-vegetarieni-nici-nu-vom-fi.jpg\";s:5:\"thumb\";s:53:\"37-nu-suntem-vegetarieni-nici-nu-vom-fi.thumbnail.jpg\";}'),(591,222,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/38-manca-i-ai-coada-nelule.jpg'),(592,222,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:83:\"/home/groparu/public_html/wp-content/uploads/2007/03/38-manca-i-ai-coada-nelule.jpg\";s:5:\"thumb\";s:40:\"38-manca-i-ai-coada-nelule.thumbnail.jpg\";}'),(593,223,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/39-cocoshat-de-atata-munca.jpg'),(594,223,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:83:\"/home/groparu/public_html/wp-content/uploads/2007/03/39-cocoshat-de-atata-munca.jpg\";s:5:\"thumb\";s:40:\"39-cocoshat-de-atata-munca.thumbnail.jpg\";}'),(595,224,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/40-nelu-suciu-tigani-porc-love.jpg'),(596,224,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:87:\"/home/groparu/public_html/wp-content/uploads/2007/03/40-nelu-suciu-tigani-porc-love.jpg\";s:5:\"thumb\";s:44:\"40-nelu-suciu-tigani-porc-love.thumbnail.jpg\";}'),(599,225,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/41-parca-tai-din-saddam-asa-mi-place.jpg'),(600,225,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:93:\"/home/groparu/public_html/wp-content/uploads/2007/03/41-parca-tai-din-saddam-asa-mi-place.jpg\";s:5:\"thumb\";s:50:\"41-parca-tai-din-saddam-asa-mi-place.thumbnail.jpg\";}'),(601,226,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/42-imagine-exxxplicita.jpg'),(602,226,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:79:\"/home/groparu/public_html/wp-content/uploads/2007/03/42-imagine-exxxplicita.jpg\";s:5:\"thumb\";s:36:\"42-imagine-exxxplicita.thumbnail.jpg\";}'),(603,227,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/43-ce-daca-arde-si-stomacu-meu-tiganesc-arde.jpg'),(604,227,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:101:\"/home/groparu/public_html/wp-content/uploads/2007/03/43-ce-daca-arde-si-stomacu-meu-tiganesc-arde.jpg\";s:5:\"thumb\";s:58:\"43-ce-daca-arde-si-stomacu-meu-tiganesc-arde.thumbnail.jpg\";}'),(605,228,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/44-tiganii-mananca-cu-ochii-gura-nasul-urechile.jpg'),(606,228,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:104:\"/home/groparu/public_html/wp-content/uploads/2007/03/44-tiganii-mananca-cu-ochii-gura-nasul-urechile.jpg\";s:5:\"thumb\";s:61:\"44-tiganii-mananca-cu-ochii-gura-nasul-urechile.thumbnail.jpg\";}'),(607,229,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/45-pe-nailon-sa-nu-ne-murdarim-cu-iarba.jpg'),(608,229,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:96:\"/home/groparu/public_html/wp-content/uploads/2007/03/45-pe-nailon-sa-nu-ne-murdarim-cu-iarba.jpg\";s:5:\"thumb\";s:53:\"45-pe-nailon-sa-nu-ne-murdarim-cu-iarba.thumbnail.jpg\";}'),(609,230,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/46-oare-tiganu-asta-se-gandeste-la-ceva-sau-oare-numa-sta.jpg'),(610,230,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:114:\"/home/groparu/public_html/wp-content/uploads/2007/03/46-oare-tiganu-asta-se-gandeste-la-ceva-sau-oare-numa-sta.jpg\";s:5:\"thumb\";s:71:\"46-oare-tiganu-asta-se-gandeste-la-ceva-sau-oare-numa-sta.thumbnail.jpg\";}'),(611,231,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/47-bulibasa.jpg'),(612,231,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:68:\"/home/groparu/public_html/wp-content/uploads/2007/03/47-bulibasa.jpg\";s:5:\"thumb\";s:25:\"47-bulibasa.thumbnail.jpg\";}'),(613,232,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/48-tigan-mort-de-beutura.jpg'),(614,232,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:81:\"/home/groparu/public_html/wp-content/uploads/2007/03/48-tigan-mort-de-beutura.jpg\";s:5:\"thumb\";s:38:\"48-tigan-mort-de-beutura.thumbnail.jpg\";}'),(617,233,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/49-stau-tigani-la-foc-focu-i-la-mijloc-huby-cu-ghioc.jpg'),(618,233,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:109:\"/home/groparu/public_html/wp-content/uploads/2007/03/49-stau-tigani-la-foc-focu-i-la-mijloc-huby-cu-ghioc.jpg\";s:5:\"thumb\";s:66:\"49-stau-tigani-la-foc-focu-i-la-mijloc-huby-cu-ghioc.thumbnail.jpg\";}'),(619,234,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/50-natura-moarta-de-beata.jpg'),(620,234,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:82:\"/home/groparu/public_html/wp-content/uploads/2007/03/50-natura-moarta-de-beata.jpg\";s:5:\"thumb\";s:39:\"50-natura-moarta-de-beata.thumbnail.jpg\";}'),(621,235,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/51-tiganii-mananca-carne-cruda-post-transare.jpg'),(622,235,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:101:\"/home/groparu/public_html/wp-content/uploads/2007/03/51-tiganii-mananca-carne-cruda-post-transare.jpg\";s:5:\"thumb\";s:58:\"51-tiganii-mananca-carne-cruda-post-transare.thumbnail.jpg\";}'),(623,236,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/52-tigan-cu-carne-cruda-in-gura.jpg'),(624,236,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:88:\"/home/groparu/public_html/wp-content/uploads/2007/03/52-tigan-cu-carne-cruda-in-gura.jpg\";s:5:\"thumb\";s:45:\"52-tigan-cu-carne-cruda-in-gura.thumbnail.jpg\";}'),(625,237,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/53-maini-tiganesti-flamande-burti-tiganesti-insetate.jpg'),(626,237,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:109:\"/home/groparu/public_html/wp-content/uploads/2007/03/53-maini-tiganesti-flamande-burti-tiganesti-insetate.jpg\";s:5:\"thumb\";s:66:\"53-maini-tiganesti-flamande-burti-tiganesti-insetate.thumbnail.jpg\";}'),(627,238,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/54-natura-moarta-tiganeasca-cu-paine-alba-si-balega-vie.jpg'),(628,238,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:112:\"/home/groparu/public_html/wp-content/uploads/2007/03/54-natura-moarta-tiganeasca-cu-paine-alba-si-balega-vie.jpg\";s:5:\"thumb\";s:69:\"54-natura-moarta-tiganeasca-cu-paine-alba-si-balega-vie.thumbnail.jpg\";}'),(629,239,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/55-tigan-cazut-la-datorie.jpg'),(630,239,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:82:\"/home/groparu/public_html/wp-content/uploads/2007/03/55-tigan-cazut-la-datorie.jpg\";s:5:\"thumb\";s:39:\"55-tigan-cazut-la-datorie.thumbnail.jpg\";}'),(631,240,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/55-tigan-cazut-la-datorie.jpg'),(632,240,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:409;s:6:\"height\";i:545;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'72\'\";s:4:\"file\";s:82:\"/home/groparu/public_html/wp-content/uploads/2007/03/55-tigan-cazut-la-datorie.jpg\";s:5:\"thumb\";s:39:\"55-tigan-cazut-la-datorie.thumbnail.jpg\";}'),(635,241,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/55-tigan-cazut-la-datorie.jpg'),(636,241,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:409;s:6:\"height\";i:545;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'72\'\";s:4:\"file\";s:82:\"/home/groparu/public_html/wp-content/uploads/2007/03/55-tigan-cazut-la-datorie.jpg\";s:5:\"thumb\";s:39:\"55-tigan-cazut-la-datorie.thumbnail.jpg\";}'),(639,242,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/56-la-umbra-de-cruce-deasa.jpg'),(640,242,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:409;s:6:\"height\";i:545;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'72\'\";s:4:\"file\";s:83:\"/home/groparu/public_html/wp-content/uploads/2007/03/56-la-umbra-de-cruce-deasa.jpg\";s:5:\"thumb\";s:40:\"56-la-umbra-de-cruce-deasa.thumbnail.jpg\";}'),(641,243,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/57-daca-berea-sta-vertical-e-suficient.jpg'),(642,243,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:95:\"/home/groparu/public_html/wp-content/uploads/2007/03/57-daca-berea-sta-vertical-e-suficient.jpg\";s:5:\"thumb\";s:52:\"57-daca-berea-sta-vertical-e-suficient.thumbnail.jpg\";}'),(643,244,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/58-doamne-nu-l-omori-acum-pe-robul-tau-tigan-ca-si-mor.jpg'),(644,244,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:409;s:6:\"height\";i:545;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'72\'\";s:4:\"file\";s:111:\"/home/groparu/public_html/wp-content/uploads/2007/03/58-doamne-nu-l-omori-acum-pe-robul-tau-tigan-ca-si-mor.jpg\";s:5:\"thumb\";s:68:\"58-doamne-nu-l-omori-acum-pe-robul-tau-tigan-ca-si-mor.thumbnail.jpg\";}'),(645,245,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/59-trec-tigani-prin-colb.jpg'),(646,245,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:81:\"/home/groparu/public_html/wp-content/uploads/2007/03/59-trec-tigani-prin-colb.jpg\";s:5:\"thumb\";s:38:\"59-trec-tigani-prin-colb.thumbnail.jpg\";}'),(647,246,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/60-gratar-cu-porc-de-tigan.jpg'),(648,246,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:83:\"/home/groparu/public_html/wp-content/uploads/2007/03/60-gratar-cu-porc-de-tigan.jpg\";s:5:\"thumb\";s:40:\"60-gratar-cu-porc-de-tigan.thumbnail.jpg\";}'),(649,247,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/61-juganind-tiganul.jpg'),(650,247,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:76:\"/home/groparu/public_html/wp-content/uploads/2007/03/61-juganind-tiganul.jpg\";s:5:\"thumb\";s:33:\"61-juganind-tiganul.thumbnail.jpg\";}'),(651,248,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/62-tigan-rapus-de-beutura.jpg'),(652,248,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:82:\"/home/groparu/public_html/wp-content/uploads/2007/03/62-tigan-rapus-de-beutura.jpg\";s:5:\"thumb\";s:39:\"62-tigan-rapus-de-beutura.thumbnail.jpg\";}'),(653,249,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/63-tiganoi-pe-dacioi.jpg'),(654,249,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:77:\"/home/groparu/public_html/wp-content/uploads/2007/03/63-tiganoi-pe-dacioi.jpg\";s:5:\"thumb\";s:34:\"63-tiganoi-pe-dacioi.thumbnail.jpg\";}'),(655,250,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/64-tiganoi-in-cieloi.jpg'),(656,250,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:77:\"/home/groparu/public_html/wp-content/uploads/2007/03/64-tiganoi-in-cieloi.jpg\";s:5:\"thumb\";s:34:\"64-tiganoi-in-cieloi.thumbnail.jpg\";}'),(657,251,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/65-tigani-betivi.jpg'),(658,251,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:73:\"/home/groparu/public_html/wp-content/uploads/2007/03/65-tigani-betivi.jpg\";s:5:\"thumb\";s:30:\"65-tigani-betivi.thumbnail.jpg\";}'),(659,252,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/66-tigan-beutor-nu-borasc-niciodata-rog-seriozitate.jpg'),(660,252,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:108:\"/home/groparu/public_html/wp-content/uploads/2007/03/66-tigan-beutor-nu-borasc-niciodata-rog-seriozitate.jpg\";s:5:\"thumb\";s:65:\"66-tigan-beutor-nu-borasc-niciodata-rog-seriozitate.thumbnail.jpg\";}'),(661,253,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/67-m-a-facut-muica-tigan-oltean-betzivan.jpg'),(662,253,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:97:\"/home/groparu/public_html/wp-content/uploads/2007/03/67-m-a-facut-muica-tigan-oltean-betzivan.jpg\";s:5:\"thumb\";s:54:\"67-m-a-facut-muica-tigan-oltean-betzivan.thumbnail.jpg\";}'),(665,254,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/68-atata-jar-aveam-si-n-burta-a-doua-zi.jpg'),(666,254,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:96:\"/home/groparu/public_html/wp-content/uploads/2007/03/68-atata-jar-aveam-si-n-burta-a-doua-zi.jpg\";s:5:\"thumb\";s:53:\"68-atata-jar-aveam-si-n-burta-a-doua-zi.thumbnail.jpg\";}'),(667,255,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/69-cine-si-cand-a-facut-poza-asta-nu-mai-tine-minte-nime.jpg'),(668,255,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:113:\"/home/groparu/public_html/wp-content/uploads/2007/03/69-cine-si-cand-a-facut-poza-asta-nu-mai-tine-minte-nime.jpg\";s:5:\"thumb\";s:70:\"69-cine-si-cand-a-facut-poza-asta-nu-mai-tine-minte-nime.thumbnail.jpg\";}'),(669,256,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/70-tigan-adormit-in-plin-proces-de-imbracare-super-tare.jpg'),(670,256,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:112:\"/home/groparu/public_html/wp-content/uploads/2007/03/70-tigan-adormit-in-plin-proces-de-imbracare-super-tare.jpg\";s:5:\"thumb\";s:69:\"70-tigan-adormit-in-plin-proces-de-imbracare-super-tare.thumbnail.jpg\";}'),(671,257,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/71-a-doua-zi-tiganii-se-feresc-de-soare-ca-vampirii.jpg'),(672,257,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:108:\"/home/groparu/public_html/wp-content/uploads/2007/03/71-a-doua-zi-tiganii-se-feresc-de-soare-ca-vampirii.jpg\";s:5:\"thumb\";s:65:\"71-a-doua-zi-tiganii-se-feresc-de-soare-ca-vampirii.thumbnail.jpg\";}'),(673,258,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/72-tigan-urat-tigan-urat-tigan-urat-tigan-urat-tigan-urat-tigan-urat-tigan-urat-tigan-urat.jpg'),(674,258,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:147:\"/home/groparu/public_html/wp-content/uploads/2007/03/72-tigan-urat-tigan-urat-tigan-urat-tigan-urat-tigan-urat-tigan-urat-tigan-urat-tigan-urat.jpg\";s:5:\"thumb\";s:104:\"72-tigan-urat-tigan-urat-tigan-urat-tigan-urat-tigan-urat-tigan-urat-tigan-urat-tigan-urat.thumbnail.jpg\";}'),(675,259,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/73-tigani-fermentand-departe-de-soare.jpg'),(676,259,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:94:\"/home/groparu/public_html/wp-content/uploads/2007/03/73-tigani-fermentand-departe-de-soare.jpg\";s:5:\"thumb\";s:51:\"73-tigani-fermentand-departe-de-soare.thumbnail.jpg\";}'),(677,260,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/74-tigan-clocind-coniac.jpg'),(678,260,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:80:\"/home/groparu/public_html/wp-content/uploads/2007/03/74-tigan-clocind-coniac.jpg\";s:5:\"thumb\";s:37:\"74-tigan-clocind-coniac.thumbnail.jpg\";}'),(679,261,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/75-epilog-deshtiu-mi-era-ca-pruna.jpg'),(680,261,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:90:\"/home/groparu/public_html/wp-content/uploads/2007/03/75-epilog-deshtiu-mi-era-ca-pruna.jpg\";s:5:\"thumb\";s:47:\"75-epilog-deshtiu-mi-era-ca-pruna.thumbnail.jpg\";}'),(681,262,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/76-mamaliga-tiganeasca-de-final.jpg'),(682,262,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:88:\"/home/groparu/public_html/wp-content/uploads/2007/03/76-mamaliga-tiganeasca-de-final.jpg\";s:5:\"thumb\";s:45:\"76-mamaliga-tiganeasca-de-final.thumbnail.jpg\";}'),(683,263,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/24-imaginile-si-zambetul-zice-totul.jpg'),(684,263,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:545;s:6:\"height\";i:409;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:92:\"/home/groparu/public_html/wp-content/uploads/2007/03/24-imaginile-si-zambetul-zice-totul.jpg\";s:5:\"thumb\";s:49:\"24-imaginile-si-zambetul-zice-totul.thumbnail.jpg\";}'),(711,268,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/normal_curse-cu-oi.jpg'),(712,268,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:511;s:6:\"height\";i:333;s:14:\"hwstring_small\";s:23:\"height=\'83\' width=\'128\'\";s:4:\"file\";s:75:\"/home/groparu/public_html/wp-content/uploads/2007/03/normal_curse-cu-oi.jpg\";s:5:\"thumb\";s:32:\"normal_curse-cu-oi.thumbnail.jpg\";}'),(719,269,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/44-2007-03-22_025238.jpg'),(720,269,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:720;s:6:\"height\";i:576;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'120\'\";s:4:\"file\";s:77:\"/home/groparu/public_html/wp-content/uploads/2007/03/44-2007-03-22_025238.jpg\";s:5:\"thumb\";s:34:\"44-2007-03-22_025238.thumbnail.jpg\";}'),(725,272,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/bad-day.jpg'),(726,272,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:468;s:6:\"height\";i:351;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:64:\"/home/groparu/public_html/wp-content/uploads/2007/03/bad-day.jpg\";s:5:\"thumb\";s:21:\"bad-day.thumbnail.jpg\";}'),(733,273,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/hotnews-26032007.JPG'),(734,273,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:1024;s:6:\"height\";i:768;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:73:\"/home/groparu/public_html/wp-content/uploads/2007/03/hotnews-26032007.JPG\";s:5:\"thumb\";s:30:\"hotnews-26032007.thumbnail.JPG\";}'),(737,275,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/hotnews-26032007.JPG'),(738,275,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:627;s:6:\"height\";i:542;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'111\'\";s:4:\"file\";s:73:\"/home/groparu/public_html/wp-content/uploads/2007/03/hotnews-26032007.JPG\";s:5:\"thumb\";s:30:\"hotnews-26032007.thumbnail.JPG\";}'),(741,276,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/hotnews-26032007.JPG'),(742,276,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:526;s:6:\"height\";i:544;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'92\'\";s:4:\"file\";s:73:\"/home/groparu/public_html/wp-content/uploads/2007/03/hotnews-26032007.JPG\";s:5:\"thumb\";s:30:\"hotnews-26032007.thumbnail.JPG\";}'),(745,277,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/hotnews-26032007.JPG'),(746,277,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:476;s:6:\"height\";i:481;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'95\'\";s:4:\"file\";s:73:\"/home/groparu/public_html/wp-content/uploads/2007/03/hotnews-26032007.JPG\";s:5:\"thumb\";s:30:\"hotnews-26032007.thumbnail.JPG\";}'),(749,278,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/hotnews-26032007.JPG'),(750,278,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:368;s:6:\"height\";i:451;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'78\'\";s:4:\"file\";s:73:\"/home/groparu/public_html/wp-content/uploads/2007/03/hotnews-26032007.JPG\";s:5:\"thumb\";s:30:\"hotnews-26032007.thumbnail.JPG\";}'),(753,279,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/hotnews-26032007-large.JPG'),(754,279,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:1024;s:6:\"height\";i:768;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:79:\"/home/groparu/public_html/wp-content/uploads/2007/03/hotnews-26032007-large.JPG\";s:5:\"thumb\";s:36:\"hotnews-26032007-large.thumbnail.JPG\";}'),(757,281,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/prosop-pe-calorifer.JPG'),(758,281,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:640;s:6:\"height\";i:480;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:76:\"/home/groparu/public_html/wp-content/uploads/2007/03/prosop-pe-calorifer.JPG\";s:5:\"thumb\";s:33:\"prosop-pe-calorifer.thumbnail.JPG\";}'),(767,282,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/27_03_07_1726.jpg'),(768,282,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:640;s:6:\"height\";i:512;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'120\'\";s:4:\"file\";s:70:\"/home/groparu/public_html/wp-content/uploads/2007/03/27_03_07_1726.jpg\";s:5:\"thumb\";s:27:\"27_03_07_1726.thumbnail.jpg\";}'),(769,283,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/27_03_07_1727.jpg'),(770,283,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:640;s:6:\"height\";i:512;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'120\'\";s:4:\"file\";s:70:\"/home/groparu/public_html/wp-content/uploads/2007/03/27_03_07_1727.jpg\";s:5:\"thumb\";s:27:\"27_03_07_1727.thumbnail.jpg\";}'),(779,286,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/antrax.jpg'),(780,286,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:614;s:6:\"height\";i:461;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:63:\"/home/groparu/public_html/wp-content/uploads/2007/03/antrax.jpg\";s:5:\"thumb\";s:20:\"antrax.thumbnail.jpg\";}'),(781,287,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/antrax.jpg'),(782,287,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:614;s:6:\"height\";i:461;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:63:\"/home/groparu/public_html/wp-content/uploads/2007/03/antrax.jpg\";s:5:\"thumb\";s:20:\"antrax.thumbnail.jpg\";}'),(791,289,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/stalagmita-din-tavan.jpg'),(792,289,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:305;s:6:\"height\";i:500;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'58\'\";s:4:\"file\";s:77:\"/home/groparu/public_html/wp-content/uploads/2007/03/stalagmita-din-tavan.jpg\";s:5:\"thumb\";s:34:\"stalagmita-din-tavan.thumbnail.jpg\";}'),(799,292,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/untitled.JPG'),(800,292,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:409;s:6:\"height\";i:372;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'105\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2007/03/untitled.JPG\";s:5:\"thumb\";s:22:\"untitled.thumbnail.JPG\";}'),(805,294,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/bere.JPG'),(806,294,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:165;s:6:\"height\";i:234;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'67\'\";s:4:\"file\";s:61:\"/home/groparu/public_html/wp-content/uploads/2007/03/bere.JPG\";s:5:\"thumb\";s:18:\"bere.thumbnail.JPG\";}'),(807,295,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/03/bere.JPG'),(808,295,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:165;s:6:\"height\";i:234;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'67\'\";s:4:\"file\";s:61:\"/home/groparu/public_html/wp-content/uploads/2007/03/bere.JPG\";s:5:\"thumb\";s:18:\"bere.thumbnail.JPG\";}'),(811,297,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/04/1-aprilie.JPG'),(812,297,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:473;s:6:\"height\";i:234;s:14:\"hwstring_small\";s:23:\"height=\'63\' width=\'128\'\";s:4:\"file\";s:66:\"/home/groparu/public_html/wp-content/uploads/2007/04/1-aprilie.JPG\";s:5:\"thumb\";s:23:\"1-aprilie.thumbnail.JPG\";}'),(813,298,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/04/groparu-farsa-1-aprilie.jpg'),(814,298,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:598;s:6:\"height\";i:503;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'114\'\";s:4:\"file\";s:80:\"/home/groparu/public_html/wp-content/uploads/2007/04/groparu-farsa-1-aprilie.jpg\";s:5:\"thumb\";s:37:\"groparu-farsa-1-aprilie.thumbnail.jpg\";}'),(815,299,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/04/groparu-farsa-1-aprilie.jpg'),(816,299,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:398;s:6:\"height\";i:336;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'113\'\";s:4:\"file\";s:80:\"/home/groparu/public_html/wp-content/uploads/2007/04/groparu-farsa-1-aprilie.jpg\";s:5:\"thumb\";s:37:\"groparu-farsa-1-aprilie.thumbnail.jpg\";}'),(819,300,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/04/futaye.JPG'),(820,300,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:492;s:6:\"height\";i:468;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'100\'\";s:4:\"file\";s:63:\"/home/groparu/public_html/wp-content/uploads/2007/04/futaye.JPG\";s:5:\"thumb\";s:20:\"futaye.thumbnail.JPG\";}'),(821,302,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/04/futaye.JPG'),(822,302,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:492;s:6:\"height\";i:468;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'100\'\";s:4:\"file\";s:63:\"/home/groparu/public_html/wp-content/uploads/2007/04/futaye.JPG\";s:5:\"thumb\";s:20:\"futaye.thumbnail.JPG\";}'),(831,303,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/04/futaye.JPG'),(832,303,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:492;s:6:\"height\";i:468;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'100\'\";s:4:\"file\";s:63:\"/home/groparu/public_html/wp-content/uploads/2007/04/futaye.JPG\";s:5:\"thumb\";s:20:\"futaye.thumbnail.JPG\";}'),(837,305,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/04/coltzar.JPG'),(838,305,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:409;s:6:\"height\";i:138;s:14:\"hwstring_small\";s:23:\"height=\'43\' width=\'128\'\";s:4:\"file\";s:64:\"/home/groparu/public_html/wp-content/uploads/2007/04/coltzar.JPG\";s:5:\"thumb\";s:21:\"coltzar.thumbnail.JPG\";}'),(841,307,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/04/ratuc.JPG'),(842,307,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:296;s:6:\"height\";i:198;s:14:\"hwstring_small\";s:23:\"height=\'85\' width=\'128\'\";s:4:\"file\";s:62:\"/home/groparu/public_html/wp-content/uploads/2007/04/ratuc.JPG\";s:5:\"thumb\";s:19:\"ratuc.thumbnail.JPG\";}'),(843,308,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/04/ratuc.JPG'),(844,308,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:296;s:6:\"height\";i:198;s:14:\"hwstring_small\";s:23:\"height=\'85\' width=\'128\'\";s:4:\"file\";s:62:\"/home/groparu/public_html/wp-content/uploads/2007/04/ratuc.JPG\";s:5:\"thumb\";s:19:\"ratuc.thumbnail.JPG\";}'),(847,310,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/04/nobila-casa.JPG'),(848,310,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:526;s:6:\"height\";i:88;s:14:\"hwstring_small\";s:23:\"height=\'21\' width=\'128\'\";s:4:\"file\";s:68:\"/home/groparu/public_html/wp-content/uploads/2007/04/nobila-casa.JPG\";s:5:\"thumb\";s:25:\"nobila-casa.thumbnail.JPG\";}'),(852,312,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/04/victima.JPG'),(853,312,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:286;s:6:\"height\";i:181;s:14:\"hwstring_small\";s:23:\"height=\'81\' width=\'128\'\";s:4:\"file\";s:64:\"/home/groparu/public_html/wp-content/uploads/2007/04/victima.JPG\";s:5:\"thumb\";s:21:\"victima.thumbnail.JPG\";}'),(874,323,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/04/everything.jpg'),(875,323,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:375;s:6:\"height\";i:251;s:14:\"hwstring_small\";s:23:\"height=\'85\' width=\'128\'\";s:4:\"file\";s:67:\"/home/groparu/public_html/wp-content/uploads/2007/04/everything.jpg\";s:5:\"thumb\";s:24:\"everything.thumbnail.jpg\";}'),(878,325,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/04/pregnant-man.jpg'),(879,325,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:200;s:6:\"height\";i:150;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:69:\"/home/groparu/public_html/wp-content/uploads/2007/04/pregnant-man.jpg\";s:5:\"thumb\";s:26:\"pregnant-man.thumbnail.jpg\";}'),(884,327,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/04/250px-romanian_orthodox_monk.jpg'),(885,327,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:250;s:6:\"height\";i:250;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'96\'\";s:4:\"file\";s:85:\"/home/groparu/public_html/wp-content/uploads/2007/04/250px-romanian_orthodox_monk.jpg\";s:5:\"thumb\";s:42:\"250px-romanian_orthodox_monk.thumbnail.jpg\";}'),(900,334,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/04/gratar.JPG'),(901,334,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:614;s:6:\"height\";i:461;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:63:\"/home/groparu/public_html/wp-content/uploads/2007/04/gratar.JPG\";s:5:\"thumb\";s:20:\"gratar.thumbnail.JPG\";}'),(908,339,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/04/gold-fish.jpg'),(909,339,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:400;s:6:\"height\";i:320;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'120\'\";s:4:\"file\";s:66:\"/home/groparu/public_html/wp-content/uploads/2007/04/gold-fish.jpg\";s:5:\"thumb\";s:23:\"gold-fish.thumbnail.jpg\";}'),(916,340,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/04/p4221307.jpg'),(917,340,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:506;s:6:\"height\";i:380;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2007/04/p4221307.jpg\";s:5:\"thumb\";s:22:\"p4221307.thumbnail.jpg\";}'),(922,342,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/04/buda_0.jpg'),(923,342,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:270;s:6:\"height\";i:202;s:14:\"hwstring_small\";s:23:\"height=\'95\' width=\'128\'\";s:4:\"file\";s:63:\"/home/groparu/public_html/wp-content/uploads/2007/04/buda_0.jpg\";s:5:\"thumb\";s:20:\"buda_0.thumbnail.jpg\";}'),(930,344,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/04/bocitoare.jpg'),(931,344,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:200;s:6:\"height\";i:150;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:66:\"/home/groparu/public_html/wp-content/uploads/2007/04/bocitoare.jpg\";s:5:\"thumb\";s:23:\"bocitoare.thumbnail.jpg\";}'),(936,347,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/04/nepotu.JPG'),(937,347,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:414;s:6:\"height\";i:655;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'60\'\";s:4:\"file\";s:63:\"/home/groparu/public_html/wp-content/uploads/2007/04/nepotu.JPG\";s:5:\"thumb\";s:20:\"nepotu.thumbnail.JPG\";}'),(938,348,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/04/groparu.JPG'),(939,348,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:357;s:6:\"height\";i:715;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'47\'\";s:4:\"file\";s:64:\"/home/groparu/public_html/wp-content/uploads/2007/04/groparu.JPG\";s:5:\"thumb\";s:21:\"groparu.thumbnail.JPG\";}'),(950,350,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/04/spammer.JPG'),(951,350,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:315;s:6:\"height\";i:299;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'101\'\";s:4:\"file\";s:64:\"/home/groparu/public_html/wp-content/uploads/2007/04/spammer.JPG\";s:5:\"thumb\";s:21:\"spammer.thumbnail.JPG\";}'),(986,361,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/05/mail-basescu.JPG'),(987,361,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:632;s:6:\"height\";i:455;s:14:\"hwstring_small\";s:23:\"height=\'92\' width=\'128\'\";s:4:\"file\";s:69:\"/home/groparu/public_html/wp-content/uploads/2007/05/mail-basescu.JPG\";s:5:\"thumb\";s:26:\"mail-basescu.thumbnail.JPG\";}'),(988,362,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/05/mail-basescu.JPG'),(989,362,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:632;s:6:\"height\";i:455;s:14:\"hwstring_small\";s:23:\"height=\'92\' width=\'128\'\";s:4:\"file\";s:69:\"/home/groparu/public_html/wp-content/uploads/2007/05/mail-basescu.JPG\";s:5:\"thumb\";s:26:\"mail-basescu.thumbnail.JPG\";}'),(990,363,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/05/mail-basescu.JPG'),(991,363,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:632;s:6:\"height\";i:455;s:14:\"hwstring_small\";s:23:\"height=\'92\' width=\'128\'\";s:4:\"file\";s:69:\"/home/groparu/public_html/wp-content/uploads/2007/05/mail-basescu.JPG\";s:5:\"thumb\";s:26:\"mail-basescu.thumbnail.JPG\";}'),(992,364,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/05/mail-base.JPG'),(993,364,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:632;s:6:\"height\";i:455;s:14:\"hwstring_small\";s:23:\"height=\'92\' width=\'128\'\";s:4:\"file\";s:66:\"/home/groparu/public_html/wp-content/uploads/2007/05/mail-base.JPG\";s:5:\"thumb\";s:23:\"mail-base.thumbnail.JPG\";}'),(996,366,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/05/arta-pula.jpg'),(997,366,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:360;s:6:\"height\";i:240;s:14:\"hwstring_small\";s:23:\"height=\'85\' width=\'128\'\";s:4:\"file\";s:66:\"/home/groparu/public_html/wp-content/uploads/2007/05/arta-pula.jpg\";s:5:\"thumb\";s:23:\"arta-pula.thumbnail.jpg\";}'),(1002,367,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/05/wwwgroparuro-traian-basescu-brb.jpg'),(1003,367,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:460;s:6:\"height\";i:454;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'97\'\";s:4:\"file\";s:88:\"/home/groparu/public_html/wp-content/uploads/2007/05/wwwgroparuro-traian-basescu-brb.jpg\";s:5:\"thumb\";s:45:\"wwwgroparuro-traian-basescu-brb.thumbnail.jpg\";}'),(1014,372,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/05/troleu.jpg'),(1015,372,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:640;s:6:\"height\";i:480;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:63:\"/home/groparu/public_html/wp-content/uploads/2007/05/troleu.jpg\";s:5:\"thumb\";s:20:\"troleu.thumbnail.jpg\";}'),(1024,375,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/05/ceausescu-si-comunismul.jpg'),(1025,375,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:261;s:6:\"height\";i:400;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'62\'\";s:4:\"file\";s:80:\"/home/groparu/public_html/wp-content/uploads/2007/05/ceausescu-si-comunismul.jpg\";s:5:\"thumb\";s:37:\"ceausescu-si-comunismul.thumbnail.jpg\";}'),(1046,380,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/05/kartofelki.jpg'),(1047,380,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:637;s:6:\"height\";i:478;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:67:\"/home/groparu/public_html/wp-content/uploads/2007/05/kartofelki.jpg\";s:5:\"thumb\";s:24:\"kartofelki.thumbnail.jpg\";}'),(1050,382,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/05/octavian_paler.jpg'),(1051,382,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:113;s:6:\"height\";i:146;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'74\'\";s:4:\"file\";s:71:\"/home/groparu/public_html/wp-content/uploads/2007/05/octavian_paler.jpg\";s:5:\"thumb\";s:28:\"octavian_paler.thumbnail.jpg\";}'),(1056,384,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/05/referendum-2007-c-groparu-wwgroparuro-i.jpg'),(1057,384,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:317;s:6:\"height\";i:683;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'44\'\";s:4:\"file\";s:96:\"/home/groparu/public_html/wp-content/uploads/2007/05/referendum-2007-c-groparu-wwgroparuro-i.jpg\";s:5:\"thumb\";s:53:\"referendum-2007-c-groparu-wwgroparuro-i.thumbnail.jpg\";}'),(1058,385,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/05/referendum-2007-c-groparu-wwgroparuro-ii.jpg'),(1059,385,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:296;s:6:\"height\";i:296;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'96\'\";s:4:\"file\";s:97:\"/home/groparu/public_html/wp-content/uploads/2007/05/referendum-2007-c-groparu-wwgroparuro-ii.jpg\";s:5:\"thumb\";s:54:\"referendum-2007-c-groparu-wwgroparuro-ii.thumbnail.jpg\";}'),(1074,391,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/05/groparu-wwwgroparuro-blog-romanesc-romanian-blog-diarie.JPG'),(1075,391,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:640;s:6:\"height\";i:480;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:112:\"/home/groparu/public_html/wp-content/uploads/2007/05/groparu-wwwgroparuro-blog-romanesc-romanian-blog-diarie.JPG\";s:5:\"thumb\";s:69:\"groparu-wwwgroparuro-blog-romanesc-romanian-blog-diarie.thumbnail.JPG\";}'),(1088,394,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/05/wwwdoingtheartworkcom-wwwgroparuro-blog-romanesc-romanian-blog-referendum-2007-basescu.JPG'),(1089,394,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:317;s:6:\"height\";i:420;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'72\'\";s:4:\"file\";s:143:\"/home/groparu/public_html/wp-content/uploads/2007/05/wwwdoingtheartworkcom-wwwgroparuro-blog-romanesc-romanian-blog-referendum-2007-basescu.JPG\";s:5:\"thumb\";s:100:\"wwwdoingtheartworkcom-wwwgroparuro-blog-romanesc-romanian-blog-referendum-2007-basescu.thumbnail.JPG\";}'),(1090,395,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/05/wwwdoingtheartworkcom-wwwgroparuro-blog-romanesc-romanian-blog-referendum-2007-basescu.jpg'),(1091,395,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:582;s:6:\"height\";i:377;s:14:\"hwstring_small\";s:23:\"height=\'82\' width=\'128\'\";s:4:\"file\";s:143:\"/home/groparu/public_html/wp-content/uploads/2007/05/wwwdoingtheartworkcom-wwwgroparuro-blog-romanesc-romanian-blog-referendum-2007-basescu.jpg\";s:5:\"thumb\";s:100:\"wwwdoingtheartworkcom-wwwgroparuro-blog-romanesc-romanian-blog-referendum-2007-basescu.thumbnail.jpg\";}'),(1100,397,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/05/vacaroiu-votca-final.jpg'),(1101,397,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:446;s:6:\"height\";i:1080;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'39\'\";s:4:\"file\";s:77:\"/home/groparu/public_html/wp-content/uploads/2007/05/vacaroiu-votca-final.jpg\";s:5:\"thumb\";s:34:\"vacaroiu-votca-final.thumbnail.jpg\";}'),(1104,399,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/05/vacaroiu-votca-final1.jpg'),(1105,399,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:446;s:6:\"height\";i:1080;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'39\'\";s:4:\"file\";s:78:\"/home/groparu/public_html/wp-content/uploads/2007/05/vacaroiu-votca-final1.jpg\";s:5:\"thumb\";s:35:\"vacaroiu-votca-final1.thumbnail.jpg\";}'),(1112,401,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/05/coprea-chiloti.JPG'),(1113,401,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:459;s:6:\"height\";i:469;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'93\'\";s:4:\"file\";s:71:\"/home/groparu/public_html/wp-content/uploads/2007/05/coprea-chiloti.JPG\";s:5:\"thumb\";s:28:\"coprea-chiloti.thumbnail.JPG\";}'),(1147,407,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/05/basescu.JPG'),(1148,407,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:444;s:6:\"height\";i:454;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'93\'\";s:4:\"file\";s:64:\"/home/groparu/public_html/wp-content/uploads/2007/05/basescu.JPG\";s:5:\"thumb\";s:21:\"basescu.thumbnail.JPG\";}'),(1151,409,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/05/poza-minunata.jpg'),(1152,409,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:1024;s:6:\"height\";i:768;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:70:\"/home/groparu/public_html/wp-content/uploads/2007/05/poza-minunata.jpg\";s:5:\"thumb\";s:27:\"poza-minunata.thumbnail.jpg\";}'),(1159,416,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/05/basescu1.JPG'),(1160,416,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:455;s:6:\"height\";i:454;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'96\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2007/05/basescu1.JPG\";s:5:\"thumb\";s:22:\"basescu1.thumbnail.JPG\";}'),(1173,420,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/05/bones_logo.jpg'),(1174,420,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:346;s:6:\"height\";i:328;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'101\'\";s:4:\"file\";s:67:\"/home/groparu/public_html/wp-content/uploads/2007/05/bones_logo.jpg\";s:5:\"thumb\";s:24:\"bones_logo.thumbnail.jpg\";}'),(1181,424,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/05/basescu-telefon.JPG'),(1182,424,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:525;s:6:\"height\";i:357;s:14:\"hwstring_small\";s:23:\"height=\'87\' width=\'128\'\";s:4:\"file\";s:72:\"/home/groparu/public_html/wp-content/uploads/2007/05/basescu-telefon.JPG\";s:5:\"thumb\";s:29:\"basescu-telefon.thumbnail.JPG\";}'),(1189,425,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/05/anunt-basescu.jpg'),(1190,425,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:364;s:6:\"height\";i:360;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'97\'\";s:4:\"file\";s:70:\"/home/groparu/public_html/wp-content/uploads/2007/05/anunt-basescu.jpg\";s:5:\"thumb\";s:27:\"anunt-basescu.thumbnail.jpg\";}'),(1191,426,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/05/anunt-basescu.jpg'),(1192,426,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:364;s:6:\"height\";i:360;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'97\'\";s:4:\"file\";s:70:\"/home/groparu/public_html/wp-content/uploads/2007/05/anunt-basescu.jpg\";s:5:\"thumb\";s:27:\"anunt-basescu.thumbnail.jpg\";}'),(1193,427,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/05/gi12_domnilor_hoti_1.jpg'),(1194,427,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:400;s:6:\"height\";i:326;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'117\'\";s:4:\"file\";s:77:\"/home/groparu/public_html/wp-content/uploads/2007/05/gi12_domnilor_hoti_1.jpg\";s:5:\"thumb\";s:34:\"gi12_domnilor_hoti_1.thumbnail.jpg\";}'),(1209,429,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/05/dsc01254.JPG'),(1210,429,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:1024;s:6:\"height\";i:768;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2007/05/dsc01254.JPG\";s:5:\"thumb\";s:22:\"dsc01254.thumbnail.JPG\";}'),(1211,430,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/05/dsc01154.JPG'),(1212,430,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:1024;s:6:\"height\";i:768;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2007/05/dsc01154.JPG\";s:5:\"thumb\";s:22:\"dsc01154.thumbnail.JPG\";}'),(1213,431,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/05/dsc01236.JPG'),(1214,431,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:768;s:6:\"height\";i:1024;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'72\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2007/05/dsc01236.JPG\";s:5:\"thumb\";s:22:\"dsc01236.thumbnail.JPG\";}'),(1215,432,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/05/dsc01237.JPG'),(1216,432,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:1024;s:6:\"height\";i:768;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2007/05/dsc01237.JPG\";s:5:\"thumb\";s:22:\"dsc01237.thumbnail.JPG\";}'),(1217,433,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/05/dsc01220.JPG'),(1218,433,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:1024;s:6:\"height\";i:768;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2007/05/dsc01220.JPG\";s:5:\"thumb\";s:22:\"dsc01220.thumbnail.JPG\";}'),(1219,434,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/05/dsc01264.JPG'),(1220,434,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:1024;s:6:\"height\";i:768;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2007/05/dsc01264.JPG\";s:5:\"thumb\";s:22:\"dsc01264.thumbnail.JPG\";}'),(1221,435,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/05/dsc01144.JPG'),(1222,435,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:1024;s:6:\"height\";i:768;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2007/05/dsc01144.JPG\";s:5:\"thumb\";s:22:\"dsc01144.thumbnail.JPG\";}'),(1223,436,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/05/dsc01158.JPG'),(1224,436,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:768;s:6:\"height\";i:1024;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'72\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2007/05/dsc01158.JPG\";s:5:\"thumb\";s:22:\"dsc01158.thumbnail.JPG\";}'),(1243,440,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/05/dsc02095.JPG'),(1244,440,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:1280;s:6:\"height\";i:960;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2007/05/dsc02095.JPG\";s:5:\"thumb\";s:22:\"dsc02095.thumbnail.JPG\";}'),(1249,443,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/05/dsc02140.JPG'),(1250,443,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:1024;s:6:\"height\";i:768;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2007/05/dsc02140.JPG\";s:5:\"thumb\";s:22:\"dsc02140.thumbnail.JPG\";}'),(1255,444,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/05/dsc02148.JPG'),(1256,444,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:1024;s:6:\"height\";i:768;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2007/05/dsc02148.JPG\";s:5:\"thumb\";s:22:\"dsc02148.thumbnail.JPG\";}'),(1267,446,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/05/achim-petru.JPG'),(1268,446,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:448;s:6:\"height\";i:336;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:68:\"/home/groparu/public_html/wp-content/uploads/2007/05/achim-petru.JPG\";s:5:\"thumb\";s:25:\"achim-petru.thumbnail.JPG\";}'),(1277,447,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/05/wwwgroparuro-in-piscina.JPG'),(1278,447,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:1280;s:6:\"height\";i:960;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:80:\"/home/groparu/public_html/wp-content/uploads/2007/05/wwwgroparuro-in-piscina.JPG\";s:5:\"thumb\";s:37:\"wwwgroparuro-in-piscina.thumbnail.JPG\";}'),(1279,448,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/05/carlanu.JPG'),(1280,448,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:1280;s:6:\"height\";i:960;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:64:\"/home/groparu/public_html/wp-content/uploads/2007/05/carlanu.JPG\";s:5:\"thumb\";s:21:\"carlanu.thumbnail.JPG\";}'),(1283,449,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/05/crang.JPG'),(1284,449,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:1280;s:6:\"height\";i:960;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:62:\"/home/groparu/public_html/wp-content/uploads/2007/05/crang.JPG\";s:5:\"thumb\";s:19:\"crang.thumbnail.JPG\";}'),(1285,450,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/05/degeaba.JPG'),(1286,450,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:1280;s:6:\"height\";i:960;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:64:\"/home/groparu/public_html/wp-content/uploads/2007/05/degeaba.JPG\";s:5:\"thumb\";s:21:\"degeaba.thumbnail.JPG\";}'),(1287,451,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/05/duda.JPG'),(1288,451,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:1280;s:6:\"height\";i:960;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:61:\"/home/groparu/public_html/wp-content/uploads/2007/05/duda.JPG\";s:5:\"thumb\";s:18:\"duda.thumbnail.JPG\";}'),(1289,452,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/05/ganistra.JPG'),(1290,452,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:1280;s:6:\"height\";i:960;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2007/05/ganistra.JPG\";s:5:\"thumb\";s:22:\"ganistra.thumbnail.JPG\";}'),(1291,453,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/05/glezna.JPG'),(1292,453,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:1280;s:6:\"height\";i:960;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:63:\"/home/groparu/public_html/wp-content/uploads/2007/05/glezna.JPG\";s:5:\"thumb\";s:20:\"glezna.thumbnail.JPG\";}'),(1293,454,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/05/ielvis.JPG'),(1294,454,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:1280;s:6:\"height\";i:960;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:63:\"/home/groparu/public_html/wp-content/uploads/2007/05/ielvis.JPG\";s:5:\"thumb\";s:20:\"ielvis.thumbnail.JPG\";}'),(1295,455,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/05/nartzoaga.JPG'),(1296,455,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:1280;s:6:\"height\";i:960;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:66:\"/home/groparu/public_html/wp-content/uploads/2007/05/nartzoaga.JPG\";s:5:\"thumb\";s:23:\"nartzoaga.thumbnail.JPG\";}'),(1297,456,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/05/rramon.JPG'),(1298,456,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:1280;s:6:\"height\";i:960;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:63:\"/home/groparu/public_html/wp-content/uploads/2007/05/rramon.JPG\";s:5:\"thumb\";s:20:\"rramon.thumbnail.JPG\";}'),(1299,457,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/05/dsc02176.JPG'),(1300,457,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:1280;s:6:\"height\";i:960;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2007/05/dsc02176.JPG\";s:5:\"thumb\";s:22:\"dsc02176.thumbnail.JPG\";}'),(1301,458,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/05/dsc02181.JPG'),(1302,458,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:1280;s:6:\"height\";i:960;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2007/05/dsc02181.JPG\";s:5:\"thumb\";s:22:\"dsc02181.thumbnail.JPG\";}'),(1303,459,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/05/dsc02185.JPG'),(1304,459,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:1280;s:6:\"height\";i:960;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2007/05/dsc02185.JPG\";s:5:\"thumb\";s:22:\"dsc02185.thumbnail.JPG\";}'),(1371,479,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/06/komodo10.jpg'),(1372,479,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:390;s:6:\"height\";i:210;s:14:\"hwstring_small\";s:23:\"height=\'68\' width=\'128\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2007/06/komodo10.jpg\";s:5:\"thumb\";s:22:\"komodo10.thumbnail.jpg\";}'),(1405,489,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/06/wwwgroparuro-blog-romanesc-romanian-blog-tiganiada-greuceanu-tigani-rrom.jpg'),(1406,489,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:682;s:6:\"height\";i:1024;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'63\'\";s:4:\"file\";s:129:\"/home/groparu/public_html/wp-content/uploads/2007/06/wwwgroparuro-blog-romanesc-romanian-blog-tiganiada-greuceanu-tigani-rrom.jpg\";s:5:\"thumb\";s:86:\"wwwgroparuro-blog-romanesc-romanian-blog-tiganiada-greuceanu-tigani-rrom.thumbnail.jpg\";}'),(1407,490,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/06/micutza-lu-flaviu-cu-tiganca.JPG'),(1408,490,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:533;s:6:\"height\";i:400;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:85:\"/home/groparu/public_html/wp-content/uploads/2007/06/micutza-lu-flaviu-cu-tiganca.JPG\";s:5:\"thumb\";s:42:\"micutza-lu-flaviu-cu-tiganca.thumbnail.JPG\";}'),(1411,491,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/06/wwwgroparuro-blog-romanesc-romanian-blog-tiganiada-greuceanu-tigani-rrom.jpg'),(1412,491,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:555;s:6:\"height\";i:713;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'74\'\";s:4:\"file\";s:129:\"/home/groparu/public_html/wp-content/uploads/2007/06/wwwgroparuro-blog-romanesc-romanian-blog-tiganiada-greuceanu-tigani-rrom.jpg\";s:5:\"thumb\";s:86:\"wwwgroparuro-blog-romanesc-romanian-blog-tiganiada-greuceanu-tigani-rrom.thumbnail.jpg\";}'),(1413,492,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/06/wwwgroparuro-blog-romanesc-romanian-blog-tiganiada-greuceanu-tigani-rrom.jpg'),(1414,492,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:555;s:6:\"height\";i:713;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'74\'\";s:4:\"file\";s:129:\"/home/groparu/public_html/wp-content/uploads/2007/06/wwwgroparuro-blog-romanesc-romanian-blog-tiganiada-greuceanu-tigani-rrom.jpg\";s:5:\"thumb\";s:86:\"wwwgroparuro-blog-romanesc-romanian-blog-tiganiada-greuceanu-tigani-rrom.thumbnail.jpg\";}'),(1415,493,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/06/wwwgroparuro-blog-romanesc-romanian-blog-tiganiada-greuceanu-tigani-rrom.jpg'),(1416,493,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:492;s:6:\"height\";i:555;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'85\'\";s:4:\"file\";s:129:\"/home/groparu/public_html/wp-content/uploads/2007/06/wwwgroparuro-blog-romanesc-romanian-blog-tiganiada-greuceanu-tigani-rrom.jpg\";s:5:\"thumb\";s:86:\"wwwgroparuro-blog-romanesc-romanian-blog-tiganiada-greuceanu-tigani-rrom.thumbnail.jpg\";}'),(1431,499,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/06/orange.GIF'),(1432,499,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:738;s:6:\"height\";i:555;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:63:\"/home/groparu/public_html/wp-content/uploads/2007/06/orange.GIF\";s:5:\"thumb\";s:20:\"orange.thumbnail.GIF\";}'),(1457,508,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/07/1.JPG'),(1458,508,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:441;s:6:\"height\";i:693;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'61\'\";s:4:\"file\";s:58:\"/home/groparu/public_html/wp-content/uploads/2007/07/1.JPG\";s:5:\"thumb\";s:15:\"1.thumbnail.JPG\";}'),(1459,509,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/07/2.JPG'),(1460,509,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:320;s:6:\"height\";i:355;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'86\'\";s:4:\"file\";s:58:\"/home/groparu/public_html/wp-content/uploads/2007/07/2.JPG\";s:5:\"thumb\";s:15:\"2.thumbnail.JPG\";}'),(1461,510,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/07/3.JPG'),(1462,510,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:272;s:6:\"height\";i:475;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'54\'\";s:4:\"file\";s:58:\"/home/groparu/public_html/wp-content/uploads/2007/07/3.JPG\";s:5:\"thumb\";s:15:\"3.thumbnail.JPG\";}'),(1463,511,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/07/4.JPG'),(1464,511,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:254;s:6:\"height\";i:533;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'45\'\";s:4:\"file\";s:58:\"/home/groparu/public_html/wp-content/uploads/2007/07/4.JPG\";s:5:\"thumb\";s:15:\"4.thumbnail.JPG\";}'),(1465,512,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/07/5.JPG'),(1466,512,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:344;s:6:\"height\";i:690;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'47\'\";s:4:\"file\";s:58:\"/home/groparu/public_html/wp-content/uploads/2007/07/5.JPG\";s:5:\"thumb\";s:15:\"5.thumbnail.JPG\";}'),(1467,513,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/07/dsc00361.JPG'),(1468,513,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:533;s:6:\"height\";i:400;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2007/07/dsc00361.JPG\";s:5:\"thumb\";s:22:\"dsc00361.thumbnail.JPG\";}'),(1469,514,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/07/7.JPG'),(1470,514,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:711;s:6:\"height\";i:540;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'126\'\";s:4:\"file\";s:58:\"/home/groparu/public_html/wp-content/uploads/2007/07/7.JPG\";s:5:\"thumb\";s:15:\"7.thumbnail.JPG\";}'),(1471,515,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/07/dsc00276.JPG'),(1472,515,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:533;s:6:\"height\";i:400;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2007/07/dsc00276.JPG\";s:5:\"thumb\";s:22:\"dsc00276.thumbnail.JPG\";}'),(1473,516,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/07/dsc00423.JPG'),(1474,516,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:533;s:6:\"height\";i:400;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2007/07/dsc00423.JPG\";s:5:\"thumb\";s:22:\"dsc00423.thumbnail.JPG\";}'),(1477,518,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/07/dsc00212.JPG'),(1478,518,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:533;s:6:\"height\";i:400;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2007/07/dsc00212.JPG\";s:5:\"thumb\";s:22:\"dsc00212.thumbnail.JPG\";}'),(1508,529,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:600;s:6:\"height\";i:248;s:14:\"hwstring_small\";s:23:\"height=\'52\' width=\'128\'\";s:4:\"file\";s:59:\"/home/groparu/public_html/wp-content/uploads/2007/07/12.JPG\";s:5:\"thumb\";s:16:\"12.thumbnail.JPG\";}'),(1507,529,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/07/12.JPG'),(1498,527,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:480;s:6:\"height\";i:640;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'72\'\";s:4:\"file\";s:68:\"/home/groparu/public_html/wp-content/uploads/2007/07/avramiancu1.jpg\";s:5:\"thumb\";s:25:\"avramiancu1.thumbnail.jpg\";}'),(1497,527,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/07/avramiancu1.jpg'),(1489,524,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/07/11.JPG'),(1490,524,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:517;s:6:\"height\";i:390;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:59:\"/home/groparu/public_html/wp-content/uploads/2007/07/11.JPG\";s:5:\"thumb\";s:16:\"11.thumbnail.JPG\";}'),(1511,531,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/07/dsc00243.JPG'),(1512,531,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:533;s:6:\"height\";i:400;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2007/07/dsc00243.JPG\";s:5:\"thumb\";s:22:\"dsc00243.thumbnail.JPG\";}'),(1513,532,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/07/21.JPG'),(1514,532,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:416;s:6:\"height\";i:397;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'100\'\";s:4:\"file\";s:59:\"/home/groparu/public_html/wp-content/uploads/2007/07/21.JPG\";s:5:\"thumb\";s:16:\"21.thumbnail.JPG\";}'),(1515,533,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/07/dsc00668.JPG'),(1516,533,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:533;s:6:\"height\";i:400;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2007/07/dsc00668.JPG\";s:5:\"thumb\";s:22:\"dsc00668.thumbnail.JPG\";}'),(1529,538,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/07/dsc00141.JPG'),(1530,538,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:533;s:6:\"height\";i:400;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2007/07/dsc00141.JPG\";s:5:\"thumb\";s:22:\"dsc00141.thumbnail.JPG\";}'),(1531,539,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/07/dsc00004.JPG'),(1532,539,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:533;s:6:\"height\";i:400;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2007/07/dsc00004.JPG\";s:5:\"thumb\";s:22:\"dsc00004.thumbnail.JPG\";}'),(1541,541,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/07/dsc00077-1.JPG'),(1542,541,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:1632;s:6:\"height\";i:1224;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:67:\"/home/groparu/public_html/wp-content/uploads/2007/07/dsc00077-1.JPG\";s:5:\"thumb\";s:24:\"dsc00077-1.thumbnail.JPG\";}'),(1547,543,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/07/dsc07286.JPG'),(1548,543,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:400;s:6:\"height\";i:300;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2007/07/dsc07286.JPG\";s:5:\"thumb\";s:22:\"dsc07286.thumbnail.JPG\";}'),(1551,545,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/07/rotation-of-dsc00448.JPG'),(1552,545,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:400;s:6:\"height\";i:533;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'72\'\";s:4:\"file\";s:77:\"/home/groparu/public_html/wp-content/uploads/2007/07/rotation-of-dsc00448.JPG\";s:5:\"thumb\";s:34:\"rotation-of-dsc00448.thumbnail.JPG\";}'),(1563,549,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/07/dsc00330.JPG'),(1564,549,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:400;s:6:\"height\";i:300;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2007/07/dsc00330.JPG\";s:5:\"thumb\";s:22:\"dsc00330.thumbnail.JPG\";}'),(1587,561,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/08/chelie.jpg'),(1588,561,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:400;s:6:\"height\";i:298;s:14:\"hwstring_small\";s:23:\"height=\'95\' width=\'128\'\";s:4:\"file\";s:63:\"/home/groparu/public_html/wp-content/uploads/2007/08/chelie.jpg\";s:5:\"thumb\";s:20:\"chelie.thumbnail.jpg\";}'),(1589,562,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/08/goran-alin-patru-cinci.jpg'),(1590,562,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:400;s:6:\"height\";i:372;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'103\'\";s:4:\"file\";s:79:\"/home/groparu/public_html/wp-content/uploads/2007/08/goran-alin-patru-cinci.jpg\";s:5:\"thumb\";s:36:\"goran-alin-patru-cinci.thumbnail.jpg\";}'),(1593,563,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/08/goran-aeroport.jpg'),(1594,563,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:400;s:6:\"height\";i:473;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'81\'\";s:4:\"file\";s:71:\"/home/groparu/public_html/wp-content/uploads/2007/08/goran-aeroport.jpg\";s:5:\"thumb\";s:28:\"goran-aeroport.thumbnail.jpg\";}'),(1599,564,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/08/mesaj.jpg'),(1600,564,'_wp_attachment_metadata','a:4:{s:5:\"width\";i:2304;s:6:\"height\";i:1728;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:62:\"/home/groparu/public_html/wp-content/uploads/2007/08/mesaj.jpg\";}'),(1601,566,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/08/mesagiu.jpg'),(1602,566,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:768;s:6:\"height\";i:576;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:64:\"/home/groparu/public_html/wp-content/uploads/2007/08/mesagiu.jpg\";s:5:\"thumb\";s:21:\"mesagiu.thumbnail.jpg\";}'),(1613,570,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/08/dsc00482.JPG'),(1614,570,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:400;s:6:\"height\";i:300;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2007/08/dsc00482.JPG\";s:5:\"thumb\";s:22:\"dsc00482.thumbnail.JPG\";}'),(1615,571,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/08/dsc00500.JPG'),(1616,571,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:400;s:6:\"height\";i:300;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2007/08/dsc00500.JPG\";s:5:\"thumb\";s:22:\"dsc00500.thumbnail.JPG\";}'),(1619,572,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/08/fwd-cv.htm'),(1620,572,'_wp_attachment_metadata','a:0:{}'),(1621,573,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/08/fwd_cv-1.jpg'),(1622,573,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:1155;s:6:\"height\";i:1679;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'66\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2007/08/fwd_cv-1.jpg\";s:5:\"thumb\";s:22:\"fwd_cv-1.thumbnail.jpg\";}'),(1623,574,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/08/fwd_cv-2.jpg'),(1624,574,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:1155;s:6:\"height\";i:1681;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'65\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2007/08/fwd_cv-2.jpg\";s:5:\"thumb\";s:22:\"fwd_cv-2.thumbnail.jpg\";}'),(1625,575,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/08/fwd_cv-3.jpg'),(1626,575,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:1155;s:6:\"height\";i:1681;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'65\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2007/08/fwd_cv-3.jpg\";s:5:\"thumb\";s:22:\"fwd_cv-3.thumbnail.jpg\";}'),(1627,576,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/08/fwd_cv-4.jpg'),(1628,576,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:1155;s:6:\"height\";i:1681;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'65\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2007/08/fwd_cv-4.jpg\";s:5:\"thumb\";s:22:\"fwd_cv-4.thumbnail.jpg\";}'),(1629,577,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/08/fwd_cv-5.jpg'),(1630,577,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:1155;s:6:\"height\";i:1681;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'65\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2007/08/fwd_cv-5.jpg\";s:5:\"thumb\";s:22:\"fwd_cv-5.thumbnail.jpg\";}'),(1635,580,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/08/62355poza_interior.jpg'),(1636,580,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:250;s:6:\"height\";i:270;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'88\'\";s:4:\"file\";s:75:\"/home/groparu/public_html/wp-content/uploads/2007/08/62355poza_interior.jpg\";s:5:\"thumb\";s:32:\"62355poza_interior.thumbnail.jpg\";}'),(1651,584,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/08/dsc00146-3.JPG'),(1652,584,'_wp_attachment_metadata','a:4:{s:5:\"width\";i:2048;s:6:\"height\";i:1536;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:67:\"/home/groparu/public_html/wp-content/uploads/2007/08/dsc00146-3.JPG\";}'),(1653,586,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/08/groparii.jpg'),(1654,586,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:1024;s:6:\"height\";i:768;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2007/08/groparii.jpg\";s:5:\"thumb\";s:22:\"groparii.thumbnail.jpg\";}'),(1661,590,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/08/dsc00654.JPG'),(1662,590,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:1024;s:6:\"height\";i:768;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2007/08/dsc00654.JPG\";s:5:\"thumb\";s:22:\"dsc00654.thumbnail.JPG\";}'),(1663,591,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/08/dsc00722.JPG'),(1664,591,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:1024;s:6:\"height\";i:768;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2007/08/dsc00722.JPG\";s:5:\"thumb\";s:22:\"dsc00722.thumbnail.JPG\";}'),(1669,592,'enclosure','http://www.doingtheartwork.com/wp-content/uploads/2007/05/Mishu_-_Scrum.mp3\r\n5028049\r\naudio/mpeg'),(1686,600,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/08/untitled.JPG'),(1687,600,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:383;s:6:\"height\";i:323;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'113\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2007/08/untitled.JPG\";s:5:\"thumb\";s:22:\"untitled.thumbnail.JPG\";}'),(1700,605,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/08/vladimir.jpg'),(1701,605,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:266;s:6:\"height\";i:333;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'76\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2007/08/vladimir.jpg\";s:5:\"thumb\";s:22:\"vladimir.thumbnail.jpg\";}'),(1720,611,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/08/gropy_chair.jpg'),(1721,611,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:540;s:6:\"height\";i:412;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'125\'\";s:4:\"file\";s:68:\"/home/groparu/public_html/wp-content/uploads/2007/08/gropy_chair.jpg\";s:5:\"thumb\";s:25:\"gropy_chair.thumbnail.jpg\";}'),(1728,614,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/08/dsc00046.JPG'),(1729,614,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:400;s:6:\"height\";i:533;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'72\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2007/08/dsc00046.JPG\";s:5:\"thumb\";s:22:\"dsc00046.thumbnail.JPG\";}'),(1738,617,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/08/p4221300.JPG'),(1739,617,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:1024;s:6:\"height\";i:768;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2007/08/p4221300.JPG\";s:5:\"thumb\";s:22:\"p4221300.thumbnail.JPG\";}'),(1822,642,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/09/picture-007.jpg'),(1823,642,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:450;s:6:\"height\";i:600;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'72\'\";s:4:\"file\";s:68:\"/home/groparu/public_html/wp-content/uploads/2007/09/picture-007.jpg\";s:5:\"thumb\";s:25:\"picture-007.thumbnail.jpg\";}'),(1850,651,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/09/dsc00805.JPG'),(1851,651,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:768;s:6:\"height\";i:1024;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'72\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2007/09/dsc00805.JPG\";s:5:\"thumb\";s:22:\"dsc00805.thumbnail.JPG\";}'),(1852,652,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/09/dsc00101.JPG'),(1853,652,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:1280;s:6:\"height\";i:960;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2007/09/dsc00101.JPG\";s:5:\"thumb\";s:22:\"dsc00101.thumbnail.JPG\";}'),(1854,653,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/09/dsc00099.JPG'),(1855,653,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:1280;s:6:\"height\";i:960;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2007/09/dsc00099.JPG\";s:5:\"thumb\";s:22:\"dsc00099.thumbnail.JPG\";}'),(1862,654,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/09/buboi.JPG'),(1863,654,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:132;s:6:\"height\";i:299;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'42\'\";s:4:\"file\";s:62:\"/home/groparu/public_html/wp-content/uploads/2007/09/buboi.JPG\";s:5:\"thumb\";s:19:\"buboi.thumbnail.JPG\";}'),(1874,660,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/09/blazon_v1_final.jpg'),(1875,660,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:1024;s:6:\"height\";i:1591;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'61\'\";s:4:\"file\";s:72:\"/home/groparu/public_html/wp-content/uploads/2007/09/blazon_v1_final.jpg\";s:5:\"thumb\";s:29:\"blazon_v1_final.thumbnail.jpg\";}'),(1920,673,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/10/dsc00129.JPG'),(1921,673,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:1280;s:6:\"height\";i:960;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2007/10/dsc00129.JPG\";s:5:\"thumb\";s:22:\"dsc00129.thumbnail.JPG\";}'),(1924,674,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/10/dsc00129.JPG'),(1925,674,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:1280;s:6:\"height\";i:960;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2007/10/dsc00129.JPG\";s:5:\"thumb\";s:22:\"dsc00129.thumbnail.JPG\";}'),(1942,678,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/10/dsc00146.JPG'),(1943,678,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:1280;s:6:\"height\";i:960;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2007/10/dsc00146.JPG\";s:5:\"thumb\";s:22:\"dsc00146.thumbnail.JPG\";}'),(1944,679,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/10/dsc00147.JPG'),(1945,679,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:1280;s:6:\"height\";i:960;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2007/10/dsc00147.JPG\";s:5:\"thumb\";s:22:\"dsc00147.thumbnail.JPG\";}'),(1948,680,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/10/dsc00150.JPG'),(1949,680,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:1280;s:6:\"height\";i:960;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2007/10/dsc00150.JPG\";s:5:\"thumb\";s:22:\"dsc00150.thumbnail.JPG\";}'),(1954,681,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/10/dsc01025.JPG'),(1955,681,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:768;s:6:\"height\";i:576;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2007/10/dsc01025.JPG\";s:5:\"thumb\";s:22:\"dsc01025.thumbnail.JPG\";}'),(1956,682,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/10/aviva.JPG'),(1957,682,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:600;s:6:\"height\";i:800;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'72\'\";s:4:\"file\";s:62:\"/home/groparu/public_html/wp-content/uploads/2007/10/aviva.JPG\";s:5:\"thumb\";s:19:\"aviva.thumbnail.JPG\";}'),(1966,684,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/10/dsc00153.JPG'),(1967,684,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:1280;s:6:\"height\";i:960;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2007/10/dsc00153.JPG\";s:5:\"thumb\";s:22:\"dsc00153.thumbnail.JPG\";}'),(1968,686,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/10/dsc00153.JPG'),(1969,686,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:896;s:6:\"height\";i:672;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2007/10/dsc00153.JPG\";s:5:\"thumb\";s:22:\"dsc00153.thumbnail.JPG\";}'),(1970,687,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/10/dsc00152.JPG'),(1971,687,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:672;s:6:\"height\";i:896;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'72\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2007/10/dsc00152.JPG\";s:5:\"thumb\";s:22:\"dsc00152.thumbnail.JPG\";}'),(1990,694,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/10/dsc00158.JPG'),(1991,694,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:768;s:6:\"height\";i:576;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2007/10/dsc00158.JPG\";s:5:\"thumb\";s:22:\"dsc00158.thumbnail.JPG\";}'),(1992,695,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/10/dsc00160.JPG'),(1993,695,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:768;s:6:\"height\";i:576;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2007/10/dsc00160.JPG\";s:5:\"thumb\";s:22:\"dsc00160.thumbnail.JPG\";}'),(1994,696,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/10/dsc00161.JPG'),(1995,696,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:576;s:6:\"height\";i:768;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'72\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2007/10/dsc00161.JPG\";s:5:\"thumb\";s:22:\"dsc00161.thumbnail.JPG\";}'),(2034,705,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/10/groparu.JPG'),(2035,705,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:1024;s:6:\"height\";i:768;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:64:\"/home/groparu/public_html/wp-content/uploads/2007/10/groparu.JPG\";s:5:\"thumb\";s:21:\"groparu.thumbnail.JPG\";}'),(2048,710,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/10/groparu1.JPG'),(2049,710,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:937;s:6:\"height\";i:458;s:14:\"hwstring_small\";s:23:\"height=\'62\' width=\'128\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2007/10/groparu1.JPG\";s:5:\"thumb\";s:22:\"groparu1.thumbnail.JPG\";}'),(2060,714,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/10/basescu.JPG'),(2061,714,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:256;s:6:\"height\";i:201;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'122\'\";s:4:\"file\";s:64:\"/home/groparu/public_html/wp-content/uploads/2007/10/basescu.JPG\";s:5:\"thumb\";s:21:\"basescu.thumbnail.JPG\";}'),(2066,716,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/10/sperm-egg.jpg'),(2067,716,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:400;s:6:\"height\";i:274;s:14:\"hwstring_small\";s:23:\"height=\'87\' width=\'128\'\";s:4:\"file\";s:66:\"/home/groparu/public_html/wp-content/uploads/2007/10/sperm-egg.jpg\";s:5:\"thumb\";s:23:\"sperm-egg.thumbnail.jpg\";}'),(2078,719,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/10/20070831013740flpaofidenrphq2xhxyf5k450.jpg'),(2079,719,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:465;s:6:\"height\";i:155;s:14:\"hwstring_small\";s:23:\"height=\'42\' width=\'128\'\";s:4:\"file\";s:96:\"/home/groparu/public_html/wp-content/uploads/2007/10/20070831013740flpaofidenrphq2xhxyf5k450.jpg\";s:5:\"thumb\";s:53:\"20070831013740flpaofidenrphq2xhxyf5k450.thumbnail.jpg\";}'),(2084,721,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/10/turda-salina.JPG'),(2085,721,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:325;s:6:\"height\";i:383;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'81\'\";s:4:\"file\";s:69:\"/home/groparu/public_html/wp-content/uploads/2007/10/turda-salina.JPG\";s:5:\"thumb\";s:26:\"turda-salina.thumbnail.JPG\";}'),(2086,722,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/10/bloc-gheatya-1.JPG'),(2087,722,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:384;s:6:\"height\";i:512;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'72\'\";s:4:\"file\";s:71:\"/home/groparu/public_html/wp-content/uploads/2007/10/bloc-gheatya-1.JPG\";s:5:\"thumb\";s:28:\"bloc-gheatya-1.thumbnail.JPG\";}'),(2088,723,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/10/bloc-gheatya-2.JPG'),(2089,723,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:384;s:6:\"height\";i:512;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'72\'\";s:4:\"file\";s:71:\"/home/groparu/public_html/wp-content/uploads/2007/10/bloc-gheatya-2.JPG\";s:5:\"thumb\";s:28:\"bloc-gheatya-2.thumbnail.JPG\";}'),(2090,724,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/10/bloc-gheatya-2.JPG'),(2091,724,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:384;s:6:\"height\";i:512;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'72\'\";s:4:\"file\";s:71:\"/home/groparu/public_html/wp-content/uploads/2007/10/bloc-gheatya-2.JPG\";s:5:\"thumb\";s:28:\"bloc-gheatya-2.thumbnail.JPG\";}'),(2092,725,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/10/altar.JPG'),(2093,725,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:384;s:6:\"height\";i:512;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'72\'\";s:4:\"file\";s:62:\"/home/groparu/public_html/wp-content/uploads/2007/10/altar.JPG\";s:5:\"thumb\";s:19:\"altar.thumbnail.JPG\";}'),(2094,726,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/10/altar2.JPG'),(2095,726,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:512;s:6:\"height\";i:384;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:63:\"/home/groparu/public_html/wp-content/uploads/2007/10/altar2.JPG\";s:5:\"thumb\";s:20:\"altar2.thumbnail.JPG\";}'),(2096,727,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/10/intrare-salina.JPG'),(2097,727,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:384;s:6:\"height\";i:512;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'72\'\";s:4:\"file\";s:71:\"/home/groparu/public_html/wp-content/uploads/2007/10/intrare-salina.JPG\";s:5:\"thumb\";s:28:\"intrare-salina.thumbnail.JPG\";}'),(2098,728,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/10/perete-salina.JPG'),(2099,728,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:512;s:6:\"height\";i:384;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:70:\"/home/groparu/public_html/wp-content/uploads/2007/10/perete-salina.JPG\";s:5:\"thumb\";s:27:\"perete-salina.thumbnail.JPG\";}'),(2100,729,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/10/perete-salina-2.JPG'),(2101,729,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:384;s:6:\"height\";i:512;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'72\'\";s:4:\"file\";s:72:\"/home/groparu/public_html/wp-content/uploads/2007/10/perete-salina-2.JPG\";s:5:\"thumb\";s:29:\"perete-salina-2.thumbnail.JPG\";}'),(2102,730,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/10/perete-salina-3.JPG'),(2103,730,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:512;s:6:\"height\";i:384;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:72:\"/home/groparu/public_html/wp-content/uploads/2007/10/perete-salina-3.JPG\";s:5:\"thumb\";s:29:\"perete-salina-3.thumbnail.JPG\";}'),(2104,731,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/10/sala-mare.JPG'),(2105,731,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:512;s:6:\"height\";i:384;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:66:\"/home/groparu/public_html/wp-content/uploads/2007/10/sala-mare.JPG\";s:5:\"thumb\";s:23:\"sala-mare.thumbnail.JPG\";}'),(2106,732,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/10/trepte.JPG'),(2107,732,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:512;s:6:\"height\";i:384;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:63:\"/home/groparu/public_html/wp-content/uploads/2007/10/trepte.JPG\";s:5:\"thumb\";s:20:\"trepte.thumbnail.JPG\";}'),(2108,733,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/10/turturi.JPG'),(2109,733,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:512;s:6:\"height\";i:384;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:64:\"/home/groparu/public_html/wp-content/uploads/2007/10/turturi.JPG\";s:5:\"thumb\";s:21:\"turturi.thumbnail.JPG\";}'),(2110,734,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/10/la-taty-ni-greu.JPG'),(2111,734,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:512;s:6:\"height\";i:384;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:72:\"/home/groparu/public_html/wp-content/uploads/2007/10/la-taty-ni-greu.JPG\";s:5:\"thumb\";s:29:\"la-taty-ni-greu.thumbnail.JPG\";}'),(2114,736,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/10/pishu.JPG'),(2115,736,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:512;s:6:\"height\";i:384;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:62:\"/home/groparu/public_html/wp-content/uploads/2007/10/pishu.JPG\";s:5:\"thumb\";s:19:\"pishu.thumbnail.JPG\";}'),(2120,739,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/10/dsc00187.JPG'),(2121,739,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:1024;s:6:\"height\";i:768;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2007/10/dsc00187.JPG\";s:5:\"thumb\";s:22:\"dsc00187.thumbnail.JPG\";}'),(2126,741,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/10/dsc00176.JPG'),(2127,741,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:1280;s:6:\"height\";i:960;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2007/10/dsc00176.JPG\";s:5:\"thumb\";s:22:\"dsc00176.thumbnail.JPG\";}'),(2128,743,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/10/dsc00176.JPG'),(2129,743,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:768;s:6:\"height\";i:576;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2007/10/dsc00176.JPG\";s:5:\"thumb\";s:22:\"dsc00176.thumbnail.JPG\";}'),(2132,744,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/10/dsc00186.JPG'),(2133,744,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:960;s:6:\"height\";i:1280;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'72\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2007/10/dsc00186.JPG\";s:5:\"thumb\";s:22:\"dsc00186.thumbnail.JPG\";}'),(2178,762,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/11/dsc01128.JPG'),(2179,762,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:829;s:6:\"height\";i:622;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2007/11/dsc01128.JPG\";s:5:\"thumb\";s:22:\"dsc01128.thumbnail.JPG\";}'),(2180,764,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/11/dsc01119.JPG'),(2181,764,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:691;s:6:\"height\";i:922;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'71\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2007/11/dsc01119.JPG\";s:5:\"thumb\";s:22:\"dsc01119.thumbnail.JPG\";}'),(2182,765,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/11/dsc01121.JPG'),(2183,765,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:276;s:6:\"height\";i:369;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'71\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2007/11/dsc01121.JPG\";s:5:\"thumb\";s:22:\"dsc01121.thumbnail.JPG\";}'),(2184,766,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/11/dsc01119.JPG'),(2185,766,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:276;s:6:\"height\";i:369;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'71\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2007/11/dsc01119.JPG\";s:5:\"thumb\";s:22:\"dsc01119.thumbnail.JPG\";}'),(2186,767,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/11/dsc01120.JPG'),(2187,767,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:369;s:6:\"height\";i:276;s:14:\"hwstring_small\";s:23:\"height=\'95\' width=\'128\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2007/11/dsc01120.JPG\";s:5:\"thumb\";s:22:\"dsc01120.thumbnail.JPG\";}'),(2188,768,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/11/dsc01123.JPG'),(2189,768,'_wp_attachment_metadata','a:4:{s:5:\"width\";i:1728;s:6:\"height\";i:2304;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'72\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2007/11/dsc01123.JPG\";}'),(2208,773,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/11/iulius-mall.jpg'),(2209,773,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:960;s:6:\"height\";i:1280;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'72\'\";s:4:\"file\";s:68:\"/home/groparu/public_html/wp-content/uploads/2007/11/iulius-mall.jpg\";s:5:\"thumb\";s:25:\"iulius-mall.thumbnail.jpg\";}'),(2212,774,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/11/dsc00200.JPG'),(2213,774,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:470;s:6:\"height\";i:627;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'71\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2007/11/dsc00200.JPG\";s:5:\"thumb\";s:22:\"dsc00200.thumbnail.JPG\";}'),(2214,775,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/11/dsc00201.JPG'),(2215,775,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:470;s:6:\"height\";i:627;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'71\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2007/11/dsc00201.JPG\";s:5:\"thumb\";s:22:\"dsc00201.thumbnail.JPG\";}'),(2216,776,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/11/dsc00202.JPG'),(2217,776,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:470;s:6:\"height\";i:627;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'71\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2007/11/dsc00202.JPG\";s:5:\"thumb\";s:22:\"dsc00202.thumbnail.JPG\";}'),(2220,780,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/11/scorpions.JPG'),(2221,780,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:346;s:6:\"height\";i:461;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'72\'\";s:4:\"file\";s:66:\"/home/groparu/public_html/wp-content/uploads/2007/11/scorpions.JPG\";s:5:\"thumb\";s:23:\"scorpions.thumbnail.JPG\";}'),(2228,783,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/11/fiero-di-essere-romeno.jpg'),(2229,783,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:500;s:6:\"height\";i:281;s:14:\"hwstring_small\";s:23:\"height=\'71\' width=\'128\'\";s:4:\"file\";s:79:\"/home/groparu/public_html/wp-content/uploads/2007/11/fiero-di-essere-romeno.jpg\";s:5:\"thumb\";s:36:\"fiero-di-essere-romeno.thumbnail.jpg\";}'),(2238,787,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/11/dsc00108.JPG'),(2239,787,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:384;s:6:\"height\";i:288;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2007/11/dsc00108.JPG\";s:5:\"thumb\";s:22:\"dsc00108.thumbnail.JPG\";}'),(2252,791,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/11/08_1.jpg'),(2253,791,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:326;s:6:\"height\";i:479;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'65\'\";s:4:\"file\";s:61:\"/home/groparu/public_html/wp-content/uploads/2007/11/08_1.jpg\";s:5:\"thumb\";s:18:\"08_1.thumbnail.jpg\";}'),(2264,795,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/11/dsc00032.JPG'),(2265,795,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:512;s:6:\"height\";i:384;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2007/11/dsc00032.JPG\";s:5:\"thumb\";s:22:\"dsc00032.thumbnail.JPG\";}'),(2266,796,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/11/tricou.JPG'),(2267,796,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:477;s:6:\"height\";i:470;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'97\'\";s:4:\"file\";s:63:\"/home/groparu/public_html/wp-content/uploads/2007/11/tricou.JPG\";s:5:\"thumb\";s:20:\"tricou.thumbnail.JPG\";}'),(2282,802,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/11/protestrally-iamamuslim.jpg'),(2283,802,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:571;s:6:\"height\";i:596;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'91\'\";s:4:\"file\";s:80:\"/home/groparu/public_html/wp-content/uploads/2007/11/protestrally-iamamuslim.jpg\";s:5:\"thumb\";s:37:\"protestrally-iamamuslim.thumbnail.jpg\";}'),(2296,804,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/11/rotation-of-dsc00211.JPG'),(2297,804,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:576;s:6:\"height\";i:768;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'72\'\";s:4:\"file\";s:77:\"/home/groparu/public_html/wp-content/uploads/2007/11/rotation-of-dsc00211.JPG\";s:5:\"thumb\";s:34:\"rotation-of-dsc00211.thumbnail.JPG\";}'),(2300,806,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/11/101413-apple-orchard-2-0.jpg'),(2301,806,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:600;s:6:\"height\";i:450;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:81:\"/home/groparu/public_html/wp-content/uploads/2007/11/101413-apple-orchard-2-0.jpg\";s:5:\"thumb\";s:38:\"101413-apple-orchard-2-0.thumbnail.jpg\";}'),(2307,810,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:565;s:6:\"height\";i:503;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'107\'\";s:4:\"file\";s:81:\"/home/groparu/public_html/wp-content/uploads/2007/11/101413-apple-orchard-2-0.jpg\";s:5:\"thumb\";s:38:\"101413-apple-orchard-2-0.thumbnail.jpg\";}'),(2306,810,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/11/101413-apple-orchard-2-0.jpg'),(2334,821,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/11/buda.JPG'),(2335,821,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:384;s:6:\"height\";i:288;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:61:\"/home/groparu/public_html/wp-content/uploads/2007/11/buda.JPG\";s:5:\"thumb\";s:18:\"buda.thumbnail.JPG\";}'),(2342,823,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/11/groparu-picture-1.JPG'),(2343,823,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:400;s:6:\"height\";i:413;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'92\'\";s:4:\"file\";s:74:\"/home/groparu/public_html/wp-content/uploads/2007/11/groparu-picture-1.JPG\";s:5:\"thumb\";s:31:\"groparu-picture-1.thumbnail.JPG\";}'),(2344,824,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/11/groparu-picture-2.JPG'),(2345,824,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:390;s:6:\"height\";i:419;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'89\'\";s:4:\"file\";s:74:\"/home/groparu/public_html/wp-content/uploads/2007/11/groparu-picture-2.JPG\";s:5:\"thumb\";s:31:\"groparu-picture-2.thumbnail.JPG\";}'),(2346,825,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/11/groparu-picture-3.JPG'),(2347,825,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:434;s:6:\"height\";i:424;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'98\'\";s:4:\"file\";s:74:\"/home/groparu/public_html/wp-content/uploads/2007/11/groparu-picture-3.JPG\";s:5:\"thumb\";s:31:\"groparu-picture-3.thumbnail.JPG\";}'),(2348,826,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/11/groparu-picture-4.JPG'),(2349,826,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:400;s:6:\"height\";i:287;s:14:\"hwstring_small\";s:23:\"height=\'91\' width=\'128\'\";s:4:\"file\";s:74:\"/home/groparu/public_html/wp-content/uploads/2007/11/groparu-picture-4.JPG\";s:5:\"thumb\";s:31:\"groparu-picture-4.thumbnail.JPG\";}'),(2350,827,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/11/groparu-picture-5.JPG'),(2351,827,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:204;s:6:\"height\";i:355;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'55\'\";s:4:\"file\";s:74:\"/home/groparu/public_html/wp-content/uploads/2007/11/groparu-picture-5.JPG\";s:5:\"thumb\";s:31:\"groparu-picture-5.thumbnail.JPG\";}'),(2352,828,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/11/groparu-picture-6.JPG'),(2353,828,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:292;s:6:\"height\";i:363;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'77\'\";s:4:\"file\";s:74:\"/home/groparu/public_html/wp-content/uploads/2007/11/groparu-picture-6.JPG\";s:5:\"thumb\";s:31:\"groparu-picture-6.thumbnail.JPG\";}'),(2354,829,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/11/groparu-picture-che.JPG'),(2355,829,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:391;s:6:\"height\";i:530;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'70\'\";s:4:\"file\";s:76:\"/home/groparu/public_html/wp-content/uploads/2007/11/groparu-picture-che.JPG\";s:5:\"thumb\";s:33:\"groparu-picture-che.thumbnail.JPG\";}'),(2370,833,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/11/dsc08741.jpg'),(2371,833,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:1024;s:6:\"height\";i:682;s:14:\"hwstring_small\";s:23:\"height=\'85\' width=\'128\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2007/11/dsc08741.jpg\";s:5:\"thumb\";s:22:\"dsc08741.thumbnail.jpg\";}'),(2372,834,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/11/dsc08785.jpg'),(2373,834,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:682;s:6:\"height\";i:1024;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'63\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2007/11/dsc08785.jpg\";s:5:\"thumb\";s:22:\"dsc08785.thumbnail.jpg\";}'),(2374,835,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/11/dsc01761.JPG'),(2375,835,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:614;s:6:\"height\";i:461;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2007/11/dsc01761.JPG\";s:5:\"thumb\";s:22:\"dsc01761.thumbnail.JPG\";}'),(2420,848,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/12/dsc00221.jpg'),(2421,848,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:768;s:6:\"height\";i:576;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2007/12/dsc00221.jpg\";s:5:\"thumb\";s:22:\"dsc00221.thumbnail.jpg\";}'),(2422,849,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/12/it-specialists-crazy-wild-party.jpg'),(2423,849,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:640;s:6:\"height\";i:479;s:14:\"hwstring_small\";s:23:\"height=\'95\' width=\'128\'\";s:4:\"file\";s:88:\"/home/groparu/public_html/wp-content/uploads/2007/12/it-specialists-crazy-wild-party.jpg\";s:5:\"thumb\";s:45:\"it-specialists-crazy-wild-party.thumbnail.jpg\";}'),(2438,854,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/12/vand-porci.JPG'),(2439,854,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:640;s:6:\"height\";i:480;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:67:\"/home/groparu/public_html/wp-content/uploads/2007/12/vand-porci.JPG\";s:5:\"thumb\";s:24:\"vand-porci.thumbnail.JPG\";}'),(2446,857,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/12/avast.JPG'),(2447,857,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:377;s:6:\"height\";i:188;s:14:\"hwstring_small\";s:23:\"height=\'63\' width=\'128\'\";s:4:\"file\";s:62:\"/home/groparu/public_html/wp-content/uploads/2007/12/avast.JPG\";s:5:\"thumb\";s:19:\"avast.thumbnail.JPG\";}'),(2460,862,'_wp_page_template','default'),(2463,865,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/12/felix.JPG'),(2464,865,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:263;s:6:\"height\";i:547;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'46\'\";s:4:\"file\";s:62:\"/home/groparu/public_html/wp-content/uploads/2007/12/felix.JPG\";s:5:\"thumb\";s:19:\"felix.thumbnail.JPG\";}'),(2465,866,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/12/voiculescurectificracit.jpg'),(2466,866,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:550;s:6:\"height\";i:509;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'103\'\";s:4:\"file\";s:80:\"/home/groparu/public_html/wp-content/uploads/2007/12/voiculescurectificracit.jpg\";s:5:\"thumb\";s:37:\"voiculescurectificracit.thumbnail.jpg\";}'),(2469,869,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/12/triolegs80ua.jpg'),(2470,869,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:298;s:6:\"height\";i:446;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'64\'\";s:4:\"file\";s:69:\"/home/groparu/public_html/wp-content/uploads/2007/12/triolegs80ua.jpg\";s:5:\"thumb\";s:26:\"triolegs80ua.thumbnail.jpg\";}'),(2475,870,'_wp_page_template','default'),(2476,871,'_wp_page_template','default'),(2477,872,'_wp_page_template','default'),(2478,873,'_wp_page_template','default'),(2479,874,'_wp_page_template','default'),(2480,875,'_wp_page_template','default'),(2481,876,'_wp_page_template','default'),(2482,877,'_wp_page_template','default'),(2483,878,'_wp_page_template','default'),(2484,879,'_wp_page_template','default'),(2485,880,'_wp_page_template','default'),(2486,881,'_wp_page_template','default'),(2487,882,'_wp_page_template','default'),(2488,883,'_wp_page_template','default'),(2489,884,'_wp_page_template','default'),(2490,885,'_wp_page_template','default'),(2491,886,'_wp_page_template','default'),(2492,887,'_wp_page_template','default'),(2535,896,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/12/cj_7059.swf'),(2536,896,'_wp_attachment_metadata','a:0:{}'),(2539,899,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/12/aici.swf'),(2540,899,'_wp_attachment_metadata','a:0:{}'),(2545,901,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/12/dsc00231.jpg'),(2546,901,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:960;s:6:\"height\";i:1280;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'72\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2007/12/dsc00231.jpg\";s:5:\"thumb\";s:22:\"dsc00231.thumbnail.jpg\";}'),(2547,902,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/12/dsc00033.JPG'),(2548,902,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:1600;s:6:\"height\";i:1200;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2007/12/dsc00033.JPG\";s:5:\"thumb\";s:22:\"dsc00033.thumbnail.JPG\";}'),(2557,904,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/12/mare1041.jpg'),(2558,904,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:496;s:6:\"height\";i:775;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'61\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2007/12/mare1041.jpg\";s:5:\"thumb\";s:22:\"mare1041.thumbnail.jpg\";}'),(2561,905,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2007/12/mare10411.jpg'),(2562,905,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:298;s:6:\"height\";i:465;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'61\'\";s:4:\"file\";s:66:\"/home/groparu/public_html/wp-content/uploads/2007/12/mare10411.jpg\";s:5:\"thumb\";s:23:\"mare10411.thumbnail.jpg\";}'),(2613,919,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2008/01/no-manele.JPG'),(2614,919,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:401;s:6:\"height\";i:477;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'80\'\";s:4:\"file\";s:66:\"/home/groparu/public_html/wp-content/uploads/2008/01/no-manele.JPG\";s:5:\"thumb\";s:23:\"no-manele.thumbnail.JPG\";}'),(2615,920,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2008/01/dsc00550.JPG'),(2616,920,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:640;s:6:\"height\";i:480;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2008/01/dsc00550.JPG\";s:5:\"thumb\";s:22:\"dsc00550.thumbnail.JPG\";}'),(2617,921,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2008/01/dsc00554.JPG'),(2618,921,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:640;s:6:\"height\";i:480;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2008/01/dsc00554.JPG\";s:5:\"thumb\";s:22:\"dsc00554.thumbnail.JPG\";}'),(2619,922,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2008/01/dsc00557.JPG'),(2620,922,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:640;s:6:\"height\";i:480;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2008/01/dsc00557.JPG\";s:5:\"thumb\";s:22:\"dsc00557.thumbnail.JPG\";}'),(2621,923,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2008/01/dsc00195.jpg'),(2622,923,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:816;s:6:\"height\";i:612;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2008/01/dsc00195.jpg\";s:5:\"thumb\";s:22:\"dsc00195.thumbnail.jpg\";}'),(2623,924,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2008/01/dsc00475.JPG'),(2624,924,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:320;s:6:\"height\";i:240;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2008/01/dsc00475.JPG\";s:5:\"thumb\";s:22:\"dsc00475.thumbnail.JPG\";}'),(2627,926,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2008/01/dsc00716.JPG'),(2628,926,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:640;s:6:\"height\";i:480;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2008/01/dsc00716.JPG\";s:5:\"thumb\";s:22:\"dsc00716.thumbnail.JPG\";}'),(2643,928,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2008/01/dsc00251.JPG'),(2644,928,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:573;s:6:\"height\";i:430;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2008/01/dsc00251.JPG\";s:5:\"thumb\";s:22:\"dsc00251.thumbnail.JPG\";}'),(2645,929,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2008/01/dsc00252.JPG'),(2646,929,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:717;s:6:\"height\";i:538;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2008/01/dsc00252.JPG\";s:5:\"thumb\";s:22:\"dsc00252.thumbnail.JPG\";}'),(2647,930,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2008/01/dsc00253.JPG'),(2648,930,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:717;s:6:\"height\";i:538;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2008/01/dsc00253.JPG\";s:5:\"thumb\";s:22:\"dsc00253.thumbnail.JPG\";}'),(2649,931,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2008/01/dsc00257.JPG'),(2650,931,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:538;s:6:\"height\";i:717;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'72\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2008/01/dsc00257.JPG\";s:5:\"thumb\";s:22:\"dsc00257.thumbnail.JPG\";}'),(2651,932,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2008/01/dsc00265.JPG'),(2652,932,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:672;s:6:\"height\";i:896;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'72\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2008/01/dsc00265.JPG\";s:5:\"thumb\";s:22:\"dsc00265.thumbnail.JPG\";}'),(2653,933,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2008/01/dsc00255.JPG'),(2654,933,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:717;s:6:\"height\";i:538;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'127\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2008/01/dsc00255.JPG\";s:5:\"thumb\";s:22:\"dsc00255.thumbnail.JPG\";}'),(2655,934,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2008/01/dsc00264.JPG'),(2656,934,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:896;s:6:\"height\";i:672;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2008/01/dsc00264.JPG\";s:5:\"thumb\";s:22:\"dsc00264.thumbnail.JPG\";}'),(2657,935,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2008/01/dsc00290.JPG'),(2658,935,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:896;s:6:\"height\";i:672;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2008/01/dsc00290.JPG\";s:5:\"thumb\";s:22:\"dsc00290.thumbnail.JPG\";}'),(2659,936,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2008/01/dsc00286.JPG'),(2660,936,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:672;s:6:\"height\";i:896;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'72\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2008/01/dsc00286.JPG\";s:5:\"thumb\";s:22:\"dsc00286.thumbnail.JPG\";}'),(2661,937,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2008/01/dsc00287.JPG'),(2662,937,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:672;s:6:\"height\";i:896;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'72\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2008/01/dsc00287.JPG\";s:5:\"thumb\";s:22:\"dsc00287.thumbnail.JPG\";}'),(2663,938,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2008/01/dsc00288.JPG'),(2664,938,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:672;s:6:\"height\";i:896;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'72\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2008/01/dsc00288.JPG\";s:5:\"thumb\";s:22:\"dsc00288.thumbnail.JPG\";}'),(2665,939,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2008/01/dsc00291.JPG'),(2666,939,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:896;s:6:\"height\";i:672;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2008/01/dsc00291.JPG\";s:5:\"thumb\";s:22:\"dsc00291.thumbnail.JPG\";}'),(2667,940,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2008/01/untitled.JPG'),(2668,940,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:385;s:6:\"height\";i:424;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'87\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2008/01/untitled.JPG\";s:5:\"thumb\";s:22:\"untitled.thumbnail.JPG\";}'),(2669,941,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2008/01/funar.JPG'),(2670,941,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:390;s:6:\"height\";i:309;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'121\'\";s:4:\"file\";s:62:\"/home/groparu/public_html/wp-content/uploads/2008/01/funar.JPG\";s:5:\"thumb\";s:19:\"funar.thumbnail.JPG\";}'),(2673,942,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2008/01/dsc00271.JPG'),(2674,942,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:896;s:6:\"height\";i:672;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2008/01/dsc00271.JPG\";s:5:\"thumb\";s:22:\"dsc00271.thumbnail.JPG\";}'),(2675,943,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2008/01/friptura.JPG'),(2676,943,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:772;s:6:\"height\";i:548;s:14:\"hwstring_small\";s:23:\"height=\'90\' width=\'128\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2008/01/friptura.JPG\";s:5:\"thumb\";s:22:\"friptura.thumbnail.JPG\";}'),(2679,944,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2008/01/dsc00256.JPG'),(2680,944,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:538;s:6:\"height\";i:717;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'72\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2008/01/dsc00256.JPG\";s:5:\"thumb\";s:22:\"dsc00256.thumbnail.JPG\";}'),(2751,962,'_wp_attached_file','/home/groparu/public_html//../../../../../../../../../../../../../../../../../tmp/ro8kfbsmag.txt'),(2752,962,'_wp_attachment_metadata','a:0:{}'),(2903,997,'_wp_attached_file','/home/groparu/public_html//../../../../../../../../../../../../../../../../../tmp/yes.jpg'),(2904,997,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:583;s:6:\"height\";i:560;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'99\'\";s:4:\"file\";s:89:\"/home/groparu/public_html//../../../../../../../../../../../../../../../../../tmp/yes.jpg\";s:5:\"thumb\";s:17:\"yes.thumbnail.jpg\";}'),(2905,998,'_wp_attached_file','/home/groparu/public_html//../../../../../../../../../../../../../../../../../tmp/yes1.jpg'),(2906,998,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:583;s:6:\"height\";i:560;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'99\'\";s:4:\"file\";s:90:\"/home/groparu/public_html//../../../../../../../../../../../../../../../../../tmp/yes1.jpg\";s:5:\"thumb\";s:18:\"yes1.thumbnail.jpg\";}'),(2907,999,'_wp_attached_file','/home/groparu/public_html//../../../../../../../../../../../../../../../../../tmp/dsc00045.jpg'),(2908,999,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:536;s:6:\"height\";i:800;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'64\'\";s:4:\"file\";s:94:\"/home/groparu/public_html//../../../../../../../../../../../../../../../../../tmp/dsc00045.jpg\";s:5:\"thumb\";s:22:\"dsc00045.thumbnail.jpg\";}'),(2913,1003,'_wp_attached_file','/home/groparu/public_html//../../../../../../../../../../../../../../../../../tmp/sarada.jpg'),(2914,1003,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:583;s:6:\"height\";i:560;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'99\'\";s:4:\"file\";s:92:\"/home/groparu/public_html//../../../../../../../../../../../../../../../../../tmp/sarada.jpg\";s:5:\"thumb\";s:20:\"sarada.thumbnail.jpg\";}'),(2915,1004,'_wp_attached_file','/home/groparu/public_html//../../../../../../../../../../../../../../../../../tmp/sarada.jpg'),(2916,1004,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:583;s:6:\"height\";i:560;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'99\'\";s:4:\"file\";s:92:\"/home/groparu/public_html//../../../../../../../../../../../../../../../../../tmp/sarada.jpg\";s:5:\"thumb\";s:20:\"sarada.thumbnail.jpg\";}'),(2917,1005,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/sarada.jpg'),(2918,1005,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:583;s:6:\"height\";i:560;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'99\'\";s:4:\"file\";s:55:\"/home/groparu/public_html/wp-content/uploads/sarada.jpg\";s:5:\"thumb\";s:20:\"sarada.thumbnail.jpg\";}'),(2919,1006,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/_dsc8054.jpg'),(2920,1006,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:470;s:6:\"height\";i:700;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'64\'\";s:4:\"file\";s:57:\"/home/groparu/public_html/wp-content/uploads/_dsc8054.jpg\";s:5:\"thumb\";s:22:\"_dsc8054.thumbnail.jpg\";}'),(3141,1063,'_wp_attached_file','/home/groparu/public_html//../../../../../../../../../../../../../../../../../tmp/ro8kfbsmag.txt'),(3142,1063,'_wp_attachment_metadata','a:0:{}'),(3143,1068,'_wp_attached_file','/home/groparu/public_html//../../../../../../../../../../../../../../../../../tmp/1001.jpg'),(3144,1068,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:800;s:6:\"height\";i:600;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'128\'\";s:4:\"file\";s:90:\"/home/groparu/public_html//../../../../../../../../../../../../../../../../../tmp/1001.jpg\";s:5:\"thumb\";s:18:\"1001.thumbnail.jpg\";}'),(3245,1098,'_wp_attached_file','/home/groparu/public_html//../../../../../../../../../../../../../../../../../tmp/rotation-of-dsc00419.JPG'),(3246,1098,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:960;s:6:\"height\";i:1280;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'72\'\";s:4:\"file\";s:106:\"/home/groparu/public_html//../../../../../../../../../../../../../../../../../tmp/rotation-of-dsc00419.JPG\";s:5:\"thumb\";s:34:\"rotation-of-dsc00419.thumbnail.JPG\";}'),(3247,1099,'_wp_attached_file','/home/groparu/public_html//../../../../../../../../../../../../../../../../../tmp/05-10-07_1707.jpg'),(3248,1099,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:1280;s:6:\"height\";i:1024;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'120\'\";s:4:\"file\";s:99:\"/home/groparu/public_html//../../../../../../../../../../../../../../../../../tmp/05-10-07_1707.jpg\";s:5:\"thumb\";s:27:\"05-10-07_1707.thumbnail.jpg\";}'),(3249,1100,'_wp_attached_file','/home/groparu/public_html//../../../../../../../../../../../../../../../../../tmp/niiharta.jpg'),(3250,1100,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:1150;s:6:\"height\";i:782;s:14:\"hwstring_small\";s:23:\"height=\'87\' width=\'128\'\";s:4:\"file\";s:94:\"/home/groparu/public_html//../../../../../../../../../../../../../../../../../tmp/niiharta.jpg\";s:5:\"thumb\";s:22:\"niiharta.thumbnail.jpg\";}'),(3251,1101,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2008/05/niiharta.jpg'),(3252,1101,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:1150;s:6:\"height\";i:782;s:14:\"hwstring_small\";s:23:\"height=\'87\' width=\'128\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2008/05/niiharta.jpg\";s:5:\"thumb\";s:22:\"niiharta.thumbnail.jpg\";}'),(3253,1102,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2008/05/baza.jpg'),(3254,1102,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:1008;s:6:\"height\";i:432;s:14:\"hwstring_small\";s:23:\"height=\'54\' width=\'128\'\";s:4:\"file\";s:61:\"/home/groparu/public_html/wp-content/uploads/2008/05/baza.jpg\";s:5:\"thumb\";s:18:\"baza.thumbnail.jpg\";}'),(3255,1103,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2008/05/rotation-of-dsc00419.JPG'),(3256,1103,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:960;s:6:\"height\";i:1280;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'72\'\";s:4:\"file\";s:77:\"/home/groparu/public_html/wp-content/uploads/2008/05/rotation-of-dsc00419.JPG\";s:5:\"thumb\";s:34:\"rotation-of-dsc00419.thumbnail.JPG\";}'),(3267,1108,'_wp_attached_file','/home/groparu/public_html//../../../../../../../../../../../../../../../../../tmp/ro8kfbsmag.txt'),(3268,1108,'_wp_attachment_metadata','a:0:{}'),(3301,1123,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2008/06/gropar.JPG'),(3275,1114,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2008/06/afis-seth-on-fire-2008-a5-curbat-sponsori.jpg'),(3276,1114,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:1732;s:6:\"height\";i:1244;s:14:\"hwstring_small\";s:23:\"height=\'91\' width=\'128\'\";s:4:\"file\";s:98:\"/home/groparu/public_html/wp-content/uploads/2008/06/afis-seth-on-fire-2008-a5-curbat-sponsori.jpg\";s:5:\"thumb\";s:55:\"afis-seth-on-fire-2008-a5-curbat-sponsori.thumbnail.jpg\";}'),(3296,1120,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:1020;s:6:\"height\";i:1403;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'69\'\";s:4:\"file\";s:74:\"/home/groparu/public_html/wp-content/uploads/2008/06/resize-of-groparu.jpg\";s:5:\"thumb\";s:31:\"resize-of-groparu.thumbnail.jpg\";}'),(3295,1120,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2008/06/resize-of-groparu.jpg'),(3302,1123,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:576;s:6:\"height\";i:768;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'72\'\";s:4:\"file\";s:63:\"/home/groparu/public_html/wp-content/uploads/2008/06/gropar.JPG\";s:5:\"thumb\";s:20:\"gropar.thumbnail.JPG\";}'),(3303,1124,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2008/06/resize-of-gropar.JPG'),(3304,1124,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:461;s:6:\"height\";i:614;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'72\'\";s:4:\"file\";s:73:\"/home/groparu/public_html/wp-content/uploads/2008/06/resize-of-gropar.JPG\";s:5:\"thumb\";s:30:\"resize-of-gropar.thumbnail.JPG\";}'),(3315,1128,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2008/06/tricou-01.jpg'),(3316,1128,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:970;s:6:\"height\";i:972;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'95\'\";s:4:\"file\";s:66:\"/home/groparu/public_html/wp-content/uploads/2008/06/tricou-01.jpg\";s:5:\"thumb\";s:23:\"tricou-01.thumbnail.jpg\";}'),(3317,1129,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2008/06/tricou-02.jpg'),(3318,1129,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:926;s:6:\"height\";i:934;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'95\'\";s:4:\"file\";s:66:\"/home/groparu/public_html/wp-content/uploads/2008/06/tricou-02.jpg\";s:5:\"thumb\";s:23:\"tricou-02.thumbnail.jpg\";}'),(3319,1130,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2008/06/tricou-03.jpg'),(3320,1130,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:995;s:6:\"height\";i:990;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'96\'\";s:4:\"file\";s:66:\"/home/groparu/public_html/wp-content/uploads/2008/06/tricou-03.jpg\";s:5:\"thumb\";s:23:\"tricou-03.thumbnail.jpg\";}'),(3321,1131,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2008/06/tricou-04.jpg'),(3322,1131,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:926;s:6:\"height\";i:936;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'94\'\";s:4:\"file\";s:66:\"/home/groparu/public_html/wp-content/uploads/2008/06/tricou-04.jpg\";s:5:\"thumb\";s:23:\"tricou-04.thumbnail.jpg\";}'),(3347,1140,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2008/06/dsc00474.JPG'),(3348,1140,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:960;s:6:\"height\";i:1280;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'72\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2008/06/dsc00474.JPG\";s:5:\"thumb\";s:22:\"dsc00474.thumbnail.JPG\";}'),(3349,1141,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2008/06/resize-of-img_6914.JPG'),(3350,1141,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:795;s:6:\"height\";i:596;s:14:\"hwstring_small\";s:23:\"height=\'95\' width=\'128\'\";s:4:\"file\";s:75:\"/home/groparu/public_html/wp-content/uploads/2008/06/resize-of-img_6914.JPG\";s:5:\"thumb\";s:32:\"resize-of-img_6914.thumbnail.JPG\";}'),(3351,1142,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2008/06/dsc00471.JPG'),(3352,1142,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:960;s:6:\"height\";i:1280;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'72\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2008/06/dsc00471.JPG\";s:5:\"thumb\";s:22:\"dsc00471.thumbnail.JPG\";}'),(3353,1143,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2008/06/img_6913.JPG'),(3354,1143,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:852;s:6:\"height\";i:1136;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'72\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2008/06/img_6913.JPG\";s:5:\"thumb\";s:22:\"img_6913.thumbnail.JPG\";}'),(3475,1163,'_wp_attached_file','/home/groparu/public_html/wp-content/uploads/2008/07/img_6752.JPG'),(3476,1163,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:852;s:6:\"height\";i:1136;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'72\'\";s:4:\"file\";s:65:\"/home/groparu/public_html/wp-content/uploads/2008/07/img_6752.JPG\";s:5:\"thumb\";s:22:\"img_6752.thumbnail.JPG\";}');
/*!40000 ALTER TABLE `wp_postmeta` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `wp_posts`
--

DROP TABLE IF EXISTS `wp_posts`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `wp_posts` (
  `ID` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `post_author` bigint(20) NOT NULL DEFAULT 0,
  `post_date` datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  `post_date_gmt` datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  `post_content` longtext NOT NULL,
  `post_title` text NOT NULL,
  `post_category` int(4) NOT NULL DEFAULT 0,
  `post_excerpt` text NOT NULL,
  `post_status` varchar(20) NOT NULL DEFAULT 'publish',
  `comment_status` varchar(20) NOT NULL DEFAULT 'open',
  `ping_status` varchar(20) NOT NULL DEFAULT 'open',
  `post_password` varchar(20) NOT NULL DEFAULT '',
  `post_name` varchar(200) NOT NULL DEFAULT '',
  `to_ping` text NOT NULL,
  `pinged` text NOT NULL,
  `post_modified` datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  `post_modified_gmt` datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  `post_content_filtered` text NOT NULL,
  `post_parent` bigint(20) NOT NULL DEFAULT 0,
  `guid` varchar(255) NOT NULL DEFAULT '',
  `menu_order` int(11) NOT NULL DEFAULT 0,
  `post_type` varchar(20) NOT NULL DEFAULT 'post',
  `post_mime_type` varchar(100) NOT NULL DEFAULT '',
  `comment_count` bigint(20) NOT NULL DEFAULT 0,
  PRIMARY KEY (`ID`),
  KEY `type_status_date` (`post_type`,`post_status`(1),`post_date`,`ID`),
  KEY `post_name` (`post_name`),
  KEY `post_status` (`post_status`(1))
) ENGINE=MyISAM AUTO_INCREMENT=1165 DEFAULT CHARSET=latin1;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `wp_posts`
--

LOCK TABLES `wp_posts` WRITE;
/*!40000 ALTER TABLE `wp_posts` DISABLE KEYS */;
INSERT INTO `wp_posts` VALUES (2,2,'2007-03-12 12:15:18','2007-03-12 10:15:18','Veti invata despre mine din cartile de istorie. Sau filosofie. Sau literatura. Sau din cartile de joc cu femei goale.\r\n\r\nIar prietenilor mei le-am zis: \"...iar cand moartea ma va lua cu ea, voi in borhot sa ma puneti, si palinca sa ma faceti. Si cu mare veselie sa ma beti, si mare sarbatoare sa faceti!\"\r\n\r\nSi, ca ultimele cuvinte, imi veti spune:\r\n\r\nNU TE VOM VOMITA NICIODATA!','Despre mine',0,'','publish','open','open','','about','','','2007-10-25 18:26:56','2007-10-25 16:26:56','',0,'http://www.groparu.ro/?page_id=2',0,'post','',2),(7,1,'2007-03-12 20:05:41','2007-03-12 18:05:41','Cat or man','Cat or man',0,'','inherit','open','open','','cat-or-man','','','2007-03-12 20:05:41','2007-03-12 18:05:41','',0,'http://www.groparu.ro/wp-content/uploads/2007/03/catorman.jpg',0,'post','image/jpeg',0),(8,1,'2007-03-12 20:09:42','2007-03-12 18:09:42','dsfsf','etr',0,'','inherit','open','open','','etr','','','2007-03-12 20:09:42','2007-03-12 18:09:42','',-1173722068,'http://www.groparu.ro/wp-content/uploads/2007/03/party-skype.png',0,'post','image/png',0),(16,1,'2007-03-12 20:30:58','2007-03-12 18:30:58','<span style=\"font-size: 9pt; font-family: Georgia\">Eram tineri, eram frumosi ca niste boboci de anul I.\r\nCateva cuvinte, mai intai, despre caminul 16.\r\nCaminul 16 este camin de baieti si se afla in partea de vest a Hajdeului. Aici vei intalni mai multe femei decat in orice camin de fete. Mai ales la dushuri. O femeie in caminul 16 arata incredibil de atragatoare.\r\nCaminul a fost construit anume cu 10 etaje pentru ca Ceausescu s-a rastit la bocancii celor care facusera Hajdeul ca \"De ce irosesc ei terenul agricol al patriei lui Bazavan construind camine cu numai 4 etaje?\" \"Sire,\" i s-a raspuns, \"solul este... care e cuvantul acela, romanesc... HIGHLY UNSTABLE! Riscam sa patim ce vor pati americanii in 9/11\" \"DA?\" S-a sumetit carmaciul.  \"Atunci vom demonstra Occidentului decadent ca noi putem inalta bloace de 10 etaje si acolo unde nu se poate!\" Rezultatul este vizibil pana in zilele noatre: o stanca cenusie cu interfatza cenusiu-murdara din care se scurg zilnic catre locurile cu bere cca 1100 de studenti, animale, femei. O intreaga gradina zoologica. Intre care m-am numarat si eu, cu glorie, in cei mai frumosi ani ai vietii acesteia bicisnice pe care o iubesc: anul 1 si anul 4.\r\nDeci... Anul I, emotii, deschidere festiva pe care nu am prins-o in nici un an de faculta (din informatiile mele, anul se deskidea in Music Pub), urmeaza o sesiune, urmeaza una-alta... si - in cele din urma - prindem si razia. Ce este razia?\r\nEi bine, razia, in universul limitat de bere-camin-bere al studentului clujean, semnifica inceputul unei lungi serii de ciubuce duse la administratoare ca sa te anunte cand vine baietii cu chipiuri ca sa verifice flotorul, sau flotantul, sau care pizda ma-sii e alalalt, nu ala care sta in vasul de la WC. In fine, toti sobolanii (me included) fara flotor, recte studentii cazati ilegal, recte cei care isi cunparasera locurile, deveneau pamantii cand ii intrebai definitia unui cuvant din 5 litere care incepe cu r. O razie inseama nopti dormite cu carote cat ridichile negre infipte brutal supt shira spinarii. Inseamna emotii cand pleci in Pub dimineatza. Emotii cand vii seara flancat de doi prieteni mai vajnici care te taraie sus 5 etaje, in cel mai bun caz (ce e aia lift?). Emotii cand mergi la WC in puterea noptii, si te lupti cu pipi sa mai stea otzara pana e liniste pe coridor.\r\nIntr-o buna seara aflam din sursele noastre sigure ca dimineatza urmatoare este DIMINEATZA. Situatia se prezenta in felul urmator: Johnny dormea cu Carmen - cazata ilegal. Restul de 4 eram OK. Cat se poate de legai. Dar cine nu are Flavius, sa-si cumpere! Nu s-a dezmintit nici de data asta. Always surprinsing-ul ne-a scos la bere cu maaaari eforturi si acolo s-a imprietenit cu inca trei. Doi baieti si o gajica. Pe care, in imensa lui marinimie, i-a adus in camera cand a auzit ca nu au unde dormi. Eu plecasem de la berule mai devreme, pe la vreo 2, si cand sa deschid dulapul sa imi las chilotii am dat de Carmen, care se ascunsese acolo la primul zgomot. De frica raziei.\r\nIn fine, dimineatza am avut placerea de a-i vedea pe ceilalti trei la ora 7, cand am auzit ca neinfricatii oameni ai legii busheau deja cu pulanele din dotare usile palierului pentru a-i trezi pe meseriashi sa prezinte buletinele cu flotant. Cred ca in 3,2 secunde ne-am trezit cu totii. De-a binelea. Eram 8 intr-o camera cu 4 cazati legal. Ce sa faci?\r\nSi atunci geniul creator al romanului s-a manifestat plenar. Carmen a fugit inapoi in dulapul cu chilotii. Unul dintre venetici a fost inghesuit, cu fortza, sub un pat, si baricadat cu toti bocancii nostri sa nu se vada. Ca un lunetist intr-o gramada de balega de porc.\r\nMai ramaneau doi. Cuplul crapulos. Aiaiai! P-astia unde-i mai bagi? Si atunci am mototolit plapuma de pe un pat, si am strecurat domnisorica - care era cam cat o vrabiutza - supt. Probabil ca ii placea sa stea <em><span style=\"font-family: Georgia\">dedesubt</span></em>, pt ca nu a scos nici un cipcirip@yahoo.com. Mai ramanea zdrahonul. Pe care, ca in Matrix, l-am inghesuit, intr-o milisecunda, dincolo de usa unui dulap deskis. Ati ghicit, cel cu maieurile, aflat langa cel cu chilotii. Am dat drumul la apa sa nu se mai auda ca se partzaia ingrozitor de emotie. Si, cu fatza cacanie, am deskis agentului care s-a straduit sa para fioros. Pana cand l-a vazut pe Ivan.\r\nAcum, merita sa fac o paranteza despre Ivan. Ivan are inaltimea mea. 185 cm. Barbat bine, ati spune, cei care ma cunoasteti! Asa e. Orice mascul cu inaltimea mea si pe deasupra si de un chintal greutate este cel putin impunator. Si daca mai e si moroshan, si dintr-un sat de ucraineni in acelasi timp, va dati seama ca era numai bun de pus in filmele cu Van Damme, in rolul de baiat-rau-care-vrea-sa-distruga-lumea-si-care-e-ucis-la-final. Uitai sa va spun ca niciodata nu am incuiat usa la camera cat am stat cu el. Niciodata. Nimeni nu risca. Vanzatorii ambulanti de casete audio din camin il salutau cu \"sarumana\". Basarabenii se laudau ca <em><strong><span style=\"font-family: Georgia\">ii</span></strong></em><em><span style=\"font-family: Georgia\"> sunt pieteni. Nu ca el le este lor, ci ca ei </span></em><strong><em><span style=\"font-family: Georgia\">ii</span></em></strong><em><span style=\"font-family: Georgia\"> </span></em><em><span style=\"font-style: normal; font-family: Georgia\">sunt lui. Niciodata nu ducea lipsa de tigari, sau de maini intinse cu brichete aprinse cand isi lua una. Era omul cel mai cinstit cu bere din cati am cunoscut. Cel care era salutat mereu primul. Cei care il vedeau erau atata de fascinati de privirea lui de \"ce-vrei-de-la-mine-blestematule\" ca uitau sa mai dea noroc si cu noi. Era OK. Ii iertam. </span></em><em>  </em><em><span style=\"font-style: normal; font-family: Georgia\">Ei bine, deci o jumatate de politai ne cerea cu toti dintii, dupa ce batuse ca un inger al mortii in usha noastra cat o scandurica, flotantele. Pana cand s-a intunecat in camera: Ivan se ridicase din pat. Noi eram obisnuiti, mitridatizati, imuni. Politaiul nu. Si cred ca nici nu prea vroia sa se obisnuiasca cu peisajul. </span></em><em>  </em><em><span style=\"font-style: normal; font-family: Georgia\">Carmen incremenise in dulapul cu chilotii. Partzurile incetasera. Ala de langa bocanci nu mai icnea ca nu are aer. Vrabiutza de sub plapuma tacea ca o stanca de sare. Nu se mai auzeau decat doua priviri care rascoleau camera ca laserele, de la un capat la altul. In capatul uneia dintre ele se afla un agent care tocmai isi terminase autoritatea. In capatul celeilalte, Ivan al nost\' (uitai sa va zic, si noi </span></em><strong><em><span style=\"font-family: Georgia\">ii</span></em></strong><em><span style=\"font-style: normal; font-family: Georgia\"> eram prieteni). Cand privirile s-au incrucisat, jur ca am auzit scantei. Dupa care una din priviri s-a blegit. A coborat, rusinata, catre buletinele de identitate cu paginutze stampilate neclar. Buletinul lui Flaviu avea autograf de la Nicu Covaci (Phoenix) pe ultima pagina. Al meu fusese patat cu galbenush. Era super OK. </span></em><em>  </em><em><span style=\"font-style: normal; font-family: Georgia\">Ne-a inmanat inapoi, in viteza, buletinele. Flaviu zice ca l-a auzit pocnind din calcaie in semn de salut cand a plecat, dar eu cred ca avea picioarele prea muiate. </span></em><em>\r\n</em><em><span style=\"font-style: normal; font-family: Georgia\">Am plecat la baie sa facem dushul de rigoare. Si, la dush, am descoperit aproape 30 de oameni in prosoape de culoarea caminului care asteptau sa plece politia. Ei nu aveau Ivani in camera. </span></em></span>\r\n\r\n<em><span style=\"font-style: normal; font-family: Georgia\">PS: Dupa cutremurul din 1977, caminul s-a inclinat usurel in fatza, ca turnul din pizza.</span></em><em>\r\n</em>','Cum am scapat de razie',0,'','publish','open','open','','cum-am-scapat-de-razie','','','2007-03-12 20:37:53','2007-03-12 18:37:53','',0,'http://www.groparu.ro/?p=16',0,'post','',5),(13,1,'2007-03-12 20:25:26','2007-03-12 18:25:26','','Ye, mah',0,'','inherit','open','open','','ye-mah','','','2007-03-12 20:25:26','2007-03-12 18:25:26','',0,'http://www.groparu.ro/wp-content/uploads/2007/03/64772.jpg',0,'post','image/jpeg',0),(14,1,'2007-03-12 20:28:12','2007-03-12 18:28:12','','Ye, mah!',0,'','inherit','open','open','','ye-mah-2','','','2007-03-12 20:28:12','2007-03-12 18:28:12','',15,'http://www.groparu.ro/wp-content/uploads/2007/03/64773.jpg',0,'post','image/jpeg',0),(15,1,'2007-03-12 20:28:52','2007-03-12 18:28:52','\r\n<p class=\"content-wrapper\"><a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/64774.jpg\" title=\"Cheile Turzii\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/64774.thumbnail.jpg\" alt=\"Cheile Turzii\" /></a></p>\r\n<p class=\"content-wrapper\">Noa, asta ar trebui cetita in gand asa cum se o spune Flaviu, alias Mitroa, alias Greuceanu. Cand o spune, o icneste, usor, din fundul gatului. Imi aduce aminte de nush ce film, family comedy din asta  americana (sa fi fost kiar Married with Childrenz?) in care nush care personaj spune aluilalt nush-care-personaj, bineinteles, cu paoza de rigoare ca sa lase publicul platit (nu platitor) sa behaie regulamentar de ras: \"Da, ma, alalalt macar nu geme cand se ridica de pe scaun!\"</p>\r\nV-ati dat seama vreodata cata lume icneste cand se ridica de pe scaun? Tineri sau batrani, femei (mmm... femei icnind!) sau barbati, shafi sau amploaiati cu juma\' de norma, pentru toti a devenit o moda sa icneasca atunci cand se ridica de pe scaun, fie el ergonomic sau de bucatarie, in troleibuzele astea ruginite de Cluj sau de pe banca mai ieri tricolora, azi alba, punctata de gainatz de cioara adevarata si ucraineana din Parcul Mare. Hai, mah copii! D-apai cat efort poate consuma ridicatul in doua picioare? Cand eram mic nu icneam cand saream din banca pentru a fugi intr-un suflet sa ne jucam <em>calaritea</em> in curtea scolii (eu eram calul lui Titus Popescu, ca aveam de atunci picioare bune, atunci ca si acum, si el era usurel de purtat in skinare!), de mama nu mai razbea sa se minune cate resurse de inverzire a pantalonilor de la uniforma scolareasca mai gaseam (da, am prins si eu acele momente binecuvintate! Doamne, sexy mai erau colegele noastre de-a 7-a in uniforma...)\r\n\r\nIcneala... scoala generala... mai, sa fie, ce urechi negre mai avea dirigu nostru cand o murit! Fii iertat, Paganele! Cred ca dirigu\' si-a dat obstescul sfarsit tot cu un icnit.\r\n\r\nDa: deci titlul deci trebuie deci cetit asa, expirand aerul, spunand un \"ye mah\" cu juma de gura, pentru ca fundul gatului este deja inundat de masa de aer pulmonar care se revarsa afara intr-un oftat sfasietor. Omuletul (lueta) se plimba si el un pic voios prin Katrina de aer care mai miroase a fum de tigare de la ultima betie din Jay\'s, de aseara (ye, mah, aseara inca bagam la greu, la ora asta, sugeam beri si pufaiam si eu tabac la greu, in rand cu ailalti catindati la impovarat bugetul asigurarilor de sanatate mai incolo, care vor ajunge asa ca vecinii lor, in stadiul in care ei, fiind copii cu doi de i, nu isi explicau cum de vecinii lor tusesc paralel cu ecoul acela de scara de bloc cand urcau pana la etajul 4, dupa care horcaiau cu pasiune, agatzau cu radacina limbii cheagul de flegma galbuie din locul unde se face laringita si, prelingand-o bine scaldata in saliva, ca sa mai taie din greatza, de-a lungul muschiului dotat cu papile gustative, o nasteau in lumina chioara de la bec tocma\' in scara de bloc, unde urcau copiii aia mici cu trei de i in 4 labe atunci cand faceau concurs seara ca \"cine e ultimu acasa ma-sa-i proasta!\"). Icnesti. Masa asta de aer suiera usor printre papile, de-a lungul limbii suspect de albe, cu vinisoare vinetii dizgratioase, le increteste oleaca, duce cu ea ceva aburi de prin interiorul obrajilor, si afara iese exact sub forma icnealii aceleia, atunci cand, adus din spate, incerci sa te ridici sa stai in pozitie de drepti ca sa iti saluti cunoscutul sau sa mergi frumos la pishu.\r\n\r\nIcniti, dragii mei. Este sunetul nostru gutural, sunetul omului care renunta o secunda la modernitate ca sa exprime nepervertit, franc si sincer cu secunda aceea unica in care se ridica de pe scaun, oboseala, sictirul enorm, lehamitea si <em>j\'en ai eu assez</em>-ul. Cum ziceau poetii nostru nemuritori pe care ii kiama Ombladon? \"Incearca sa nu uiti cand erai copil ce ti-ai promis!\"\r\n\r\nAcuma ar fi trebuit sa fiu un hibrid intre Rambo si Rocky.','Ye, mah!',0,'','publish','open','open','','ye-mah','','','2007-03-12 20:37:37','2007-03-12 18:37:37','',0,'http://www.groparu.ro/?p=15',0,'post','',0),(9,1,'2007-03-12 20:17:37','2007-03-12 18:17:37','','Cheile Turzii',0,'','inherit','open','open','','cheile-turzii','','','2007-03-12 20:17:37','2007-03-12 18:17:37','',-1173722068,'http://www.groparu.ro/wp-content/uploads/2007/03/6477.jpg',0,'post','image/jpeg',0),(10,1,'2007-03-12 20:20:26','2007-03-12 18:20:26','','64771.jpg',0,'','inherit','open','open','','64771jpg','','','2007-03-12 20:20:26','2007-03-12 18:20:26','',0,'http://www.groparu.ro/wp-content/uploads/2007/03/64771.jpg',0,'post','image/jpeg',0),(17,1,'2007-03-12 20:35:03','2007-03-12 18:35:03','<a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/copsa-mica_.jpg\" title=\"Copsa Mica\">\r\n</a>\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/copsa-mica_.jpg\" title=\"Copsa Mica\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/copsa-mica_.jpg\" alt=\"Copsa Mica\" height=\"285\" width=\"420\" /></a>\r\n\r\nDe regula, ca fost vajnic angajat al fabricii de caramida din Sibiu, am o nostalgie aparte cand e vorba de fabricile patriei mele. Si eu mi-am adus aminte de mamele guvernantilor, ca si tata-meu (ce interesant e tata meu, mananca numa nu cotlete!), cand am vandut \"otelul tzarii!\" indienilor si aluminiul rusilor.\r\n\r\nIeri, ma roaga un prieten din Sibiu sa ma duc pana la Armatura sa cumpar un-regulator-de-gaz-de-20-mc-si-un-tzol-cu-tot-cu-filtru - sau ceva de genu\' (la comercianti costa triplu, traiasca patria mea!) Pentru ca sunt un tip prevazator si aterizez tot timpul in trei picioare (pt ca numai trei picioare am), ajung in fabrica cu cca. o ora inainte de a pleca autocarul cu care urma sa trimit agregatul in teritoriu. Risipesc pretz de o secunda ca sa admir poarta mare, muncitoreasca, si monumentalismul patratzos al kikinetzei portarului. Intru si comunic portarului, ca unei fiinte inteligente, pohta ce-o pohteam. Urmeaza, in ordine cronologica, dar complet iLogica:\r\n1. Sunt trimis la \"Desfacere\", pe ulita interna inainte si la dreapta, pana ajung la o cladire inalta de 4 etaje. Si acolo, la ultimul etaj, trebuie sa discut cu \"cei de la desfacere\".\r\n2. Nimic mai simplu. Raman in cele trei picioare, si admirand peisajul industrial (asa se kema tabloul din camera de la Mamaia cand am fost cu ai mei si aveam 10 ani) ma indrept spre cladirea care este. Ma asigur ca acolo e \"Desfacerea\", si intru in biroul \"Desfacere\" la etajul 4, dupa ce am urcat pe un coridor bicisnic de ingust si de prost luminat (noroc ca nu a trecut o gasca de muncitoare tinere, guralive si sexual-abusing pe coridor odata cu mine, ma insuram in 30 de secunde).\r\n2. Bat si intru in acelasi timp la \"Desfacere\", sperand sa ii prind pe angajati ca nu lucreaza. Ma uit. Camera goala. Nici macar parchet. Munti de moloz. Bat la usa de langa. \"Desfacerea\" s-a mutat in cealalta camera, uite aia de unde iese acuma domnul acela. Vreau sa platesc ACUM. Nu se poate.\r\n3. Intru si bat cu tupeu a doua oara. Le spun doleantza inimii mele care dolea un-regulator-de-gaz-de-20-mc-si-un-tzol-cu-tot-cu-filtru, dupa care astept sa vad agitatie si sa ma bucur ca ce pupat in cur is ca si client. Un domn intre trei varste se uita la mine pe deasupra ochelarilor (cred ca m-a si deochiat) si-mi spune: \"Da\' nu la noi, baiatu\'! La \"Facturare\"! Cum cobori, la dreapta.\" Vreau sa platesc ACUM. Nu se poate.\r\n3. Scari inguste din nou, aceleasi fantezii cu muncitoare. Normal ca o iau gresit, si dupa un sfert de ora de circulat prin fabrica in cautarea unui-regulator-de-gaz-de-20-mc-si-un-tzol-cu-tot-cu-filtru sau macar a unui grup de nimfete guralive in halat si mirosind a shpan de otzel ma indur sa intreb un ifronist (hehe, pun pariu ca nu stiti ce e aia!), care ma indruma indarapt, la o cladie in fatza careia zace un BMW gri. Vreau sa platesc ACUM. Nu se poate.\r\n4. Intr-un final glorios, ajung la Facturare. Bat, si intru. Si imi dau seama ca am gresit profund cand am declarat in acte ca am douaj... aaa... douaj... si ceva de ani. Ma aflam nici mai mult nici mai putin in anii de glorie de imediat dupa ce am picat la facultate prima data, in anii nouaj... aaa... nouaj... cam asa ceva. Birou de 4X4 (metri, baaah, nu tractiune!), tavan scund, pardoseala mirosind a vechi, scaunele de fier si PAL iti dadeau dureri de spate numa ce te uitai la ele, un nene cu o geaca chinezeasca fumand sub anuntul de \"Fumatul Strict Oprit!\", plansele de PSI si Protectia Muncii ascunzand lungi crapaturi in perete, personalul TESA grupat in jurul singurei femei - si aceea cu cu gratii indoielnice - dar grabindu-se sa treaca la cele 4 birouri imediat ce intru. Aceiasi, scribalind cu pixul niste formulare din cea mai infecta hartie posibila, sau belind ochii la monitoare second cu tastaturi antice de 30.000 ROL fara tasta de \"win\", vopseaua crapata pe usa, figuri tipice anilor 70. Ma simteam ca si cand nu m-as fi nascut inca.\r\nMi se preia comanda, si 4 indivizi sar sa ajute. Comportament tipic celor care se lictisesc de moarte la serviciu si nu au Yahoo Messenger. Mi se preia comanda si sunt rugat sa iau loc. Nu, zic eu, sunt un pic pe fuga. Se uita la mine stramb si zic, cu un oftat indelung: \"Dureaza un pic!\". Iau oamenii comanda si o inmaneaza printr-un geam celor din hala.\r\nSi stau.\r\nSI stau.\r\nSI Stau.\r\nSI STau.\r\nSI STAu.\r\nSI STAU.\r\nSi incepe sa ma stranga casca! 25 de minute de admirat normele PSI. De ascultat cele mai idioate bancuri care mi-au luminat copilaria, in anii optz... aaa... opt... nevermind. Incercari sustinute de a ma desprinde din bucla temporala. Imi repet ca suntem in anii 2000, pt ca ieri auzisem la radio o melodie din \'95 categorisita drept goldie, but oldie. Beeey, pe muzica asta am apsolvit, bey! (oops, m-am deconspirat). Incerc sa-mi imaginez monitoare plate, oameni cu parul pieptanat, reclame luminoase si cladiri cu termopane. Modernitate. In zadar. Gandul imi e captiv in camarutza cu gratii la geam. Se zbate, si nu scapa. Ma simt ca la scoala dupa ce faceam o boacana si trebuia sa il astept pe director si el nu mai venea. Ma gandesc la dirigu\'. Ma trec sudori reci. Imi vine sa icnesc.\r\n5. Intr-un final glorios, mi se spune: mergeti langa sa ridicati pachetul. Nu am curajul sa intreb de ce nu mi-l da pur si simplu prin gemuletz. Vreau sa platesc ACUM. Nu se poate.\r\n6. Ajung la hala de impachetare. Trebuie sa vina shefa. Shefa nu vine. Ba vine. Dar intr-un tarziu. Isi muta cu greu greutatea de pe un picior pe altul, nu raspunde la timidul meu \"Sarumanaaaaaaa\" si merge la un birou de fier. O urmez ca un catzelush. \"Da, copile\" zice ea. Sarumanaaaa, zic, m-au trimis de la facturare sa ridic un un-regulator-de-gaz-de-20-mc-si-un-tzol-cu-tot-cu-filtru. Da, zice ea. Asteapta un pic. Vreau sa platesc ACUM. Nu se poate.\r\n\r\n7. Glorios, cu pachetul sub mana, ma indrept spre poarta, ferindu-ma cu dibacie de ifroniistii si motostivuitoristii (fork lift, in engleza) care se credeau Ayrton Sena pe circuitul de la Monza. Fusesem indrumat la CasErie. Vreau sa platesc ACUM. Nu se poate. Ca doamna care incaseaza e plecata la Desfacere sau la Facturare. Dar nu puteti incasa dumneavoastra? Intreb. Vreau sa platesc ACUM. Se poate? Haideti, zic, ca sunt din Sibiu, si vom fi capitala europeana a culturii in 2007, zic eu. Bine, zice o voce de dincolo de ceatza din fatza ochilor mei, mergeti la colega.\r\nMa indrept izbindu-ma de mobile catre colega. Colega zacea intr-o camera de 2X1,50 m, fara geam, numai cu un neon care palpaia (to flicker). 103 ^&amp;%^&amp;(*&amp;(, spune ea. Scot ca prin vis 2 milioane si ii dau. Nu mai vreau decat sa ma vad plecat cu al meu regulator-de-gaz-de-20-mc-si-un-tzol-cu-tot-cu-filtru. Doamna repeta, acum mai insistent, ca doreste 103 ^&amp;%^&amp;(*&amp;@##(. Ma caut sa ii mai dau bani, nu mai am, ma uit la ea ca un pui de gaina gripat. Nu mai stiu ce e cu mine. Platesc, si apoi intreb: pot plati ACUM?\r\n\r\nGata. S-a terminat. Ies glorios pe poarta fabricii. Si multumesc lui Dumnezeu ca nu a trebuit sa iau o comanda de patru bucati, altfel ar fi trebuit sa stau si acum acolo. Si oamenii aia nu cred ca se prea omoara cu dusul!','Industria lu\' Ceausescu',0,'','publish','open','open','','industria-lu-ceausescu','','','2007-03-12 20:43:47','2007-03-12 18:43:47','',0,'http://www.groparu.ro/?p=17',0,'post','',0),(18,1,'2007-03-12 20:34:35','2007-03-12 18:34:35','','Copsa Mica',0,'','inherit','open','open','','copsa-mica','','','2007-03-12 20:34:54','2007-03-12 18:34:54','',-1173724266,'http://www.groparu.ro/wp-content/uploads/2007/03/copsa-mica.jpg',0,'post','image/jpeg',0),(19,1,'2007-03-12 20:37:23','2007-03-12 18:37:23','','Cheile Turzii',0,'','inherit','open','open','','cheile-turzii-2','','','2007-03-12 20:37:23','2007-03-12 18:37:23','',15,'http://www.groparu.ro/wp-content/uploads/2007/03/64774.jpg',0,'post','image/jpeg',0),(20,1,'2007-03-12 20:39:41','2007-03-12 18:39:41','','Copsa Mica',0,'','inherit','open','open','','copsa-mica-2','','','2007-03-12 20:39:41','2007-03-12 18:39:41','',17,'http://www.groparu.ro/wp-content/uploads/2007/03/copsa-mica.jpg',0,'post','image/jpeg',0),(21,1,'2007-03-12 20:40:41','2007-03-12 18:40:41','','Copsa Mica',0,'','inherit','open','open','','copsa-mica-3','','','2007-03-12 20:40:41','2007-03-12 18:40:41','',17,'http://www.groparu.ro/wp-content/uploads/2007/03/copsa-mica_.jpg',0,'post','image/jpeg',0),(33,1,'2007-03-12 22:47:48','2007-03-12 20:47:48','<dl class=\"body\"><dt class=\"post-head\">Copy-paste din YM:</dt><dt class=\"post-head\">Show Recent Messages (F3)\r\n</dt><dd class=\"post-body\">\r\n<p class=\"image-wrapper\">&nbsp;</p>\r\n\r\n<p class=\"content-wrapper\">\r\nCalin Marian: http://www.danishmuhammedcartoons.com/Apology.html\r\nRadu Bazavan: muie ba\r\nRadu Bazavan: acum 50 de ani ne prajeam evreii prin lagare\r\nCalin Marian: e\r\nRadu Bazavan: suntem mai rai ca ei\r\nCalin Marian: ha?\r\nCalin Marian: tu tii cu arabii?\r\nCalin Marian: da-i dracu\r\nRadu Bazavan: nu mah\r\nRadu Bazavan: trebe sa ne intelegem\r\nRadu Bazavan: ca n-avem decat o planeta\r\nCalin Marian: da ma\r\nRadu Bazavan: capiche?\r\nCalin Marian: da aia nu is de inteles\r\nRadu Bazavan: sh io vreau sa vad ruinele din babilon fara sa ma ia careva ostatic\r\nCalin Marian: poa sa zica ce or vrea sa zica de d-zo, ca nime nu o sa le atace ambasadele\r\nCalin Marian: daca is tembeli\r\nRadu Bazavan: poi da\r\nRadu Bazavan: da nu-i mai zgandarim\r\nRadu Bazavan: ca nu ie bine\r\nRadu Bazavan: facem razboi la ei acasa\r\nRadu Bazavan: si tot noi ne ofuscam\r\nRadu Bazavan: nu?\r\nCalin Marian: io vreu sa ii vad sapun\r\nRadu Bazavan: ca sa cum as baga de vina taurului ca se crizeaza cand vede roshu\r\nRadu Bazavan: si ei pe noi\r\nRadu Bazavan: si nush care are mai multa dreptate\r\nCalin Marian: da ba\r\nCalin Marian: tauru ii animal\r\nCalin Marian: is si astia animale?\r\nCalin Marian: ca daca da, atunci perfect de acord cu tine\r\nCalin Marian: daca nu, la sapun cu ei\r\nRadu Bazavan: nu\r\nRadu Bazavan: lumineaza-i, in pula mea\r\nRadu Bazavan: ca si noi ar trebui sa fim exterminati\r\nRadu Bazavan: ca suntem boi\r\nRadu Bazavan: in gaura europei\r\nRadu Bazavan: ]si ne furam si ne mintim\r\nCalin Marian: e\r\nCalin Marian: da nu dam in cap pt chestii idioate\r\nRadu Bazavan: nu\r\nRadu Bazavan: numa la betie\r\nRadu Bazavan: si avem si pedofili in lumea asta superba a noastra\r\nRadu Bazavan: ai auzit?\r\nRadu Bazavan: 550.000 inregistrati in SUA\r\nRadu Bazavan: no, tjanks\r\nRadu Bazavan: :D\r\nCalin Marian: da man... da nu ii chestie de popor.\r\nCalin Marian: scursori sint peste tot\r\nCalin Marian: da acolo toti is\r\nRadu Bazavan: ce?\r\nRadu Bazavan: teroristi?\r\nRadu Bazavan: nu pre\r\nRadu Bazavan: :|\r\nCalin Marian: nu\r\nCalin Marian: dusi cu pluta\r\nCalin Marian: gata sa iti dea in cap\r\nCalin Marian: daca tu zici ca-ti bagi pula in coran\r\nCalin Marian: na\r\nRadu Bazavan: da\' cine te pune?\r\nRadu Bazavan: ?\r\nRadu Bazavan: vizitator la cineva acasa\r\nRadu Bazavan: sa faci pe nesimtitu\'?\r\nRadu Bazavan: hai la mine acasa\r\nRadu Bazavan: si zi ceva de maica-mea\r\nRadu Bazavan: am sa ma bucur\r\nRadu Bazavan: si daca legea e de partea mea, te si fac caltabosh\r\nCalin Marian: da nu o fost la ei acasa\r\nCalin Marian: o fost in danemarca\r\nRadu Bazavan: da\' daca scrie de maica-mea in ziar, ii dau in judecata\r\nCalin Marian: si in state, si mai nu stiu unde...\r\nCalin Marian: nu or fost la ei acasa\r\nCalin Marian: vezi mail mai bine\r\nCalin Marian: :D\r\n(imi trimite un mail porno, si ma amuz o vreme, sunt un porc sovin)\r\nRadu Bazavan: lol\r\nRadu Bazavan: ideea e ca\r\nRadu Bazavan: oricum lucrurile is aprinse pan la d-zeu\r\nCalin Marian: da\r\nRadu Bazavan: si numa ca noi nu mai avem nimic sfant\r\nCalin Marian: da asta nu ii scuza ca is tembeli\r\nRadu Bazavan: nu ne permite sa dam cu rahat de cutzu p-unde apucam\r\nCalin Marian: zii ce ii sfant\r\nRadu Bazavan: nu mah\r\nCalin Marian: da nu ma aburi ca biblia\r\nRadu Bazavan: noi suntem tembeli\r\nRadu Bazavan: de ce nu ne facem mashini pe aer sau apa?\r\nCalin Marian: pt ca astia stim bine ca is chestii de manipulat in masa\r\nRadu Bazavan: ce ne traba noo rezbel in Iraq?\r\nRadu Bazavan: ...sau poate nu\r\nRadu Bazavan: nu uita ca esti injiner\r\nRadu Bazavan: deci mai supus greselii\r\nRadu Bazavan: ca restu furnicarului\r\nCalin Marian: ne\r\nCalin Marian: atita timp cit s-o ucis pt. un kakat de jhirtie\r\nCalin Marian: nu ii ceva sfint\r\nRadu Bazavan: nimic nu justifica crima\r\nRadu Bazavan: nici petrolu\', nici hartia\r\nCalin Marian: o religie (vezi definitia) e ceva ce nu te obliga\r\nCalin Marian: ori ce avem amu sau de cind ii lumea\r\nCalin Marian: ii doar obligatie\r\nCalin Marian: si agresiune\r\nRadu Bazavan: a noastra nu e de agresiune mah\r\nRadu Bazavan: zice sa dai si alalalt obraz\r\nCalin Marian: e\r\nRadu Bazavan: si noi\r\nRadu Bazavan: pula\r\nCalin Marian: cruciadele or fost chefuri de fapt\r\nRadu Bazavan: razboinicii luminii si ai pulii\r\nRadu Bazavan: pai da\r\nCalin Marian: iara\r\nCalin Marian: cu obrazul 2\r\nRadu Bazavan: ca le trebia mirodenii sh aur si petre pretioase\r\nCalin Marian: un kakat mai mare nu se poate\r\nRadu Bazavan: i-auzi\r\nRadu Bazavan: is milioane care se ghideaza dupa teoria asta\r\nCalin Marian: adica vine ala, imi fute 3 pumni, si sa mai stau, ca de, ii aproapele meu?\r\nRadu Bazavan: si s-o gasit calin marean mai dajtept\r\nCalin Marian: nu\r\nCalin Marian: dar asta o aparut amu 1500 de ani\r\nRadu Bazavan: ma gandeam eu, ca n-are cum\r\nCalin Marian: teoria asta idioata\r\nRadu Bazavan: asa\r\nCalin Marian: ca inainte nu era\r\nRadu Bazavan: nu e idioata ma\r\nRadu Bazavan: nu\r\nRadu Bazavan: inainte eram animale\r\nCalin Marian: asa ca nu ma aburi ca asta o fost\r\nCalin Marian has signed back in. (3/14/2006 2:32 PM)\r\n\r\nRadu Bazavan: si ne trebia alta leje\r\nRadu Bazavan: dupa aia ne-am revenit la ratiune si la hertz\r\nCalin Marian: da da\r\nCalin Marian: povesti\r\nCalin Marian: deci egiptenii or fost animale\r\nRadu Bazavan: poi nu?\r\nCalin Marian: mesopotamiemii, si ei\r\nCalin Marian: numa noi nu sintem animale\r\nRadu Bazavan: in egipt? se futeau acolo fratii cu sorile mai mult ca caminu\' 6 cu 16\r\nCalin Marian: amu te contrazici cu ce ziceai mai inainte\r\nRadu Bazavan: nu ma contrazic\r\nRadu Bazavan: cand o aparut zeu\' nost, o adus cu el o noua lege\r\nRadu Bazavan: si gata\r\nCalin Marian: a nostru?\r\nRadu Bazavan: nu mai bateti doba de razboi\r\nCalin Marian: da a chinezilor?\r\nRadu Bazavan: da aia e treaba lor\r\nCalin Marian: ala nu e?\r\nRadu Bazavan: trebe sa ne toleram\r\nCalin Marian: pai cum ma?\r\nRadu Bazavan: ca alta planeta nu pre avem\r\nCalin Marian: ca doar toti sintem oameni\r\nRadu Bazavan: exact\r\nCalin Marian: si aia daca nu au dzo\r\nRadu Bazavan: ce ma pishca pe mine sa fut bance cu profetu lor?\r\nRadu Bazavan: ha?\r\nCalin Marian: da ce te-ar deranja?\r\nRadu Bazavan: io am ditai barna la mine in cultura in oki\r\nCalin Marian: amu hai si ia-mi gitu\r\nRadu Bazavan: da\' rad d-aia\r\nCalin Marian: ca si eu\r\nCalin Marian: am jignit biblia la greu\r\nCalin Marian: daca ii vorba\r\nRadu Bazavan: auto-ironia e altceva, Nelu (apelativ generic folosit de mine cu succes)\r\nCalin Marian: noa\r\nRadu Bazavan: nu e aceeasi kestie cu restu\'\r\nCalin Marian: si arabii nu or inteles?\r\nRadu Bazavan: nu cred ca au fost foarte fericiti\r\nRadu Bazavan: si cu arabii\r\nRadu Bazavan: si danejii\r\nRadu Bazavan: iti spui io\r\nRadu Bazavan: ca am stat acolo 5 luni\r\nRadu Bazavan: danejii is mameluci\r\nRadu Bazavan: si danezele is baietzoase\r\nCalin Marian: las sa fie\r\nRadu Bazavan: si la estea nu le mere cu arabocii\r\nRadu Bazavan: astea is innebunite ca le calareste un mascul pe care nu prea pot sa il domine\r\nRadu Bazavan: si ei, fatalaii, se oftica\r\nRadu Bazavan: si fac caricaturi din kizda, ca alceva nu poa sa face\r\nRadu Bazavan: noa\r\nRadu Bazavan: muie\r\nRadu Bazavan: reprimarea masculinitatii\r\nRadu Bazavan: si o cam iau pe coaja de la tuciurii\r\nRadu Bazavan: asta e tot\r\nRadu Bazavan: si amu\r\nRadu Bazavan: cu voia matale\r\nRadu Bazavan: am sa te fac personaj de blog\r\n\r\n</dd></dl>','Caricaturi, Blog si Yahoo Messenjer asezonat cu injiner + filolog',0,'','publish','open','open','','caricaturi-blog-si-yahoo-messenjer-asezonat-cu-injiner-filolog','','','2007-03-12 22:47:48','2007-03-12 20:47:48','',0,'http://www.groparu.ro/?p=33',0,'post','',0),(23,1,'2007-03-12 20:47:13','2007-03-12 18:47:13','','Tiganiada_1',0,'','inherit','open','open','','tiganiada_1','','','2007-03-12 20:47:13','2007-03-12 18:47:13','',-1173725069,'http://www.groparu.ro/wp-content/uploads/2007/03/tiganiada_11.jpg',0,'post','image/jpeg',0),(29,1,'2007-03-12 22:43:53','2007-03-12 20:43:53','\r\n<p class=\"content-wrapper\"><a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/politia.jpg\" title=\"Politia prin vizor\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/politia.jpg\" alt=\"Politia prin vizor\" height=\"375\" width=\"498\" /></a></p>\r\nAiaiai.\r\n\r\nTrei kefuri consecutive cu tot tacamu\'. 11, 12, 13.\r\n\r\nCluj: Mi-e si frica sa zic cata lume a venit. Ceva pe la 60 de oameni si femei.\r\nCreca de cand cu Danemarca m-a luat o frica atavica sa nu raman singur de ziua mea. Desi - Dumnezeu mi-e martor - niciodata nu am pus pretz pe aniversarea-mi. Si ca dovada, sorella mea a uitat ce zi e si cat e ceasul samd si mi-a dat mesaj de LMA pe 11 <img src=\"http://us.i1.yimg.com/us.yimg.com/i/mesg/tsmileys2/18.gif\" alt=\"Image\" />. M-am distrat si am sunat-o inapoi fara sa-i zic nimica, pentru ca, pe 13, cand era cu adevarat ziua mea, sa imi dea alt mesaj, care suna in felul urmator: \"Dupa o masa buna la italieni am plecat la Salsa disco si acum la culcare. Dana\" (mama ei de treaba, acuma nu mai semneaza cu \"sor-ta\", ci cu \"Dana\", germanizata lu peshte!)\r\nNacazul e ca nu a iesit keful pe care il asteptam din simplul motiv ca, pe cand ne kefuiam mai abitir, cine apare? Politia <img src=\"http://us.i1.yimg.com/us.yimg.com/i/mesg/tsmileys2/04.gif\" alt=\"Image\" />! (vezi poza de mai sus, facuta prin vizor, oare cui trebuie sa ii multumesc pentru ca s-a gandit sa imortalizeze momentul? Nu, perversilor, nu e o pasarica, e un vizor de usa!) Si nu Politia Primariei... Careva dintre vecinii binevoitori s-a gandit sa imi faca un cadou. Noroc ca inca eram foarte coerent si, dupa indelungi dezbateri si negocieri, am obtinut un avertisment scris din partea meseriashilor (fara implicatii financiare), si promisiunea ca daca mai primesc telefoane de reclamatii, sa imi dea bip la numarul de pe cartea mea de vizita (apropos, poate o sa aveti si dvs. vreodata nevoie de o traducere, ceva - <em>anytime is a giood time to do business</em>) - si vom evacua toata shandramaua in 2 minute. Puteau sa imi vaduveasca bugetul de 10 milioane. Ar fi fost pacat, banii aia puteau merge pe cauze caritabile, cum ar fi ciubucele date surorilor medicale care ma vor trata cand berile baute pe parcursul vietii mele se vor razbuna. Noroc ca am gasit intelegere, desi mi-a fost foarte greu sa vorbesc inteligibil, mai ales ca eu ma inteleg destul de greu ce spun chiar si cand sunt treaz. De ziua mea, cineva imi furase tigarile. Multumesc in gand lu Shafu\' ca nu sunt totusi in Danemarca, singur. Fiind roman, nu puteam da afar\' oaspetii, asa ca ne-am multumit sa concertam din chitara. Noroc ca Misu canta fain. Eu nu mai cantam decat ragete. Oare de ce am primit aproape numai cadouri cu tenta sexuala si beutura? Oare asa ma percepe oamenii si femeile?\r\n\r\nSibiu: Ce s-a gandit atunci Groparu, amu ca ramasese cu doua lazi de bere pe stoc? Nici mai mult  nici mai putin decat sa le transfere in Sibiu, la partea a doua a petrecaniei. Asa ca - hopa sus cu ele in autocar, si tarash grapish cu ele pana in Sibiu (normal ca bravul sofer a lui nea Carabulea a primit si dansul o glaja, sa fie de sufletelul meu, manca-ti-as!). Clar ca am mai parlit neshte beri pe drum. Sa fie primit! Ajungem in Sibiu unde, la onor. casa de vacantza a onor. parintii mei, s-a petrecut a doua petrecanie. M-am fortat, m-am chinuit (dormisem ceva de genu 3 ore noaptea precedenta) si m-am culcat ultimul. Stie cineva cum de telefonul meu a ajuns tocmai in buzunarul Mitroiului, si a doua zi aveam 15 minute vorbite in Spania? (va spune ca nu e asa. Sa nu-l credeti, toti masculii sunt niste mincinosi si porci. Toti!)\r\n\r\nA treia zi - soare, frumos, vreme de stat in tricou afara, desi e miezul lunii noiembrie. Doamne, ce buna a fost zama de verisoare facuta de o mama grijulie! Seara am ramas singur, asteptandu-l pe Utzu sa vina sa ma duca acasa. Si am adormit cu tigarea intr-o mana si cu berea in cealalta. Senzatie extraordinara de implinire, de parca mana mea tocmai pusese piciorul pe Luna a 9-a. Stratosfere. Licurici.\r\n\r\nUltima amintire: zeama de burta la Bistro. Stau la masa cu o trupa de manelisti pe care nu-i cunosc. Cel mai galagios dintre ei are cate trei ghiuluri babane de aur pe fiecare mana. Ma uit: primul e cu simbolul Mercedesului, al doilea are o sirena de aur, iar al treilea are un nume. Unisex.\r\n\r\nS-a terminat. Ziua mea. Noroc ca mai e si la anu\'.','Ziua mea 2005',0,'','publish','open','open','','ziua-mea-2005','','','2007-03-14 17:22:59','2007-03-14 15:22:59','',0,'http://www.groparu.ro/?p=29',0,'post','',0),(30,1,'2007-03-12 22:42:53','2007-03-12 20:42:53','','Politia prin vizor',0,'','inherit','open','open','','politia-prin-vizor','','','2007-03-12 22:42:53','2007-03-12 20:42:53','',-1173732028,'http://www.groparu.ro/wp-content/uploads/2007/03/politia.jpg',0,'post','image/jpeg',0),(31,1,'2007-03-12 22:45:50','2007-03-12 20:45:50','','Manfred',0,'','inherit','open','open','','manfred','','','2007-03-12 22:45:50','2007-03-12 20:45:50','',32,'http://www.groparu.ro/wp-content/uploads/2007/03/manfred.jpg',0,'post','image/jpeg',0),(32,1,'2007-03-12 22:46:04','2007-03-12 20:46:04','<a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/manfred.jpg\" title=\"Manfred\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/manfred.jpg\" alt=\"Manfred\" /></a>\r\n\r\nNu am chef de nimic\r\n\r\nN-am chef sa beau azi nici o bere\r\nN-am chef sa gust astazi nimica\r\nN-am chef de somn, de invatat, de stat,\r\nN-am chef de agatat\r\nN-am chef sa vad acum pe nimeni\r\nNici chiar pe mine in oglinda.\r\nAcum prin mine se perinda\r\nUn lung suvoi de chef de nefacut nimica.\r\nN-am nici macar vreo pofta sa respir\r\nNici sa mananc, nici sa transpir\r\nFacand amor.\r\nN-am nici un dor. Nimic. Sunt gol.\r\nN-am chef sa vad vreun film, s-ascult radioul,\r\nN-am chef s-ascult tacerea,\r\nSi nimanui sa-i spun parerea-mi\r\nCa-mi pare ca n-am nici un chef.\r\nVoi fi blasfemitor, dar nici de ruga\r\nNu am chef. Si nici sa-njur\r\nSperjur\r\nPe ma-sa, ta-su, si nepotii.\r\nM-au napadit, omizi, netotii\r\nSi nu am chef de ei sa scap\r\nCa nu am chef sa ridic mana -\r\nSa-i scutur doar asa, otara, sa-mi dea pace.\r\nMa uit cum trece saptamana\r\nSi nu am chef sa-i spun \"Arr^ete!\"\r\nDesi n-am chef sa vad cum timpul trece.\r\nN-am chef maine sa merg la scoala\r\nN-am chef acuma sa adorm\r\nN-am chef sa vad ca pula mi se scoala\r\nN-am chef sa vad ratiunile cum dorm\r\nN-am chef sa fie var-acuma\r\nN-am chef sa vie iarna in troieni\r\nN-am chef, din flori de pom, sa beau din primavara spuma,\r\nN-am chef, iubito, sa ma chemi,\r\nE toamna, dar n-am chef de ea,\r\nLa fel cum nu am chef de voi,\r\nN-am chef acuma nici de cheful meu\r\nCare se cheama ca de nimic n-am chef.\r\nN-am chef sa vad cum tot mereu\r\nLa hoitul vietii lasi se-aduna\r\nN-am chef sa spun \"Eu nu sunt eu!\"\r\nSi nu am chef ca altii sa mi-o spuna.\r\nM-am saturat de draci si sfinti\r\nSi nu am chef nici de parinti\r\nSa-mi spuna ce si cum sa fac\r\nCe sa vorbesc, ce sa imbrac,\r\nLa fel cum nu am chef de Danemarca.\r\nEu sunt Naufragiatul ce refuza barca,\r\nParasutistul fara parasuta,\r\nUn giggolo ce nu vrea sa se futa!\r\nSunt marinarul care nu mai bea,\r\nSunt eu, cinstitul, mincinos sadea,\r\nSunt fermierul ce cu mana ara,\r\nSunt apa moarta-n foc si para!\r\nSunt sictiritul vesnic de pamant,\r\nDe Dumnezeu, de draci - de toti eu sunt!\r\nN-am chef sa scriu poeme seara\r\nSi nici sa stau degeaba-n pat,\r\nN-am chef sa mai respir,\r\nSa-nsir\r\nPe fir\r\nOre si zile ca margele,\r\nSatul de ele\r\nSi de ne-cheful meu.\r\nSatul de mine\r\nSi de Dumnezeu.\r\nMinusculul gandac de Colorado\r\nCare sunt eu\r\nSatul este de Dumnezeu!\r\nEu, parazit, capusa, scarabeu\r\nM-am saturat.\r\nNu sunt nici derbedeu\r\nNici filosof, nici chiar poet.\r\nNu-s nici macar un chef enorm\r\nSa ma specializez. Si sa ma fac\r\nAscet.\r\nSa stau mereu, si sa n-am chef\r\nSa misc. Sa stau. Sa stau.\r\nSi sa n-am chef de stat. Nici de cascat.\r\nNici de cacat. Nici de-adorat.\r\nDar s-ar putea sa vie clipa\r\nPe nesimtite ca pisica\r\nCand voi lasa acest nimica\r\nSi voi fi iara, eu (nu sunt eu)\r\nCel care-l stiti.\r\nDar pan-atunci, n-am chef chiar de nimica.\r\n\r\nPoezia asta am compus-o cand eram departe de cei dragi (oricine ar fi fost ei), hapt in innorata, vantoasa si ploioasa Danemarca. Jur ca fara nici o legatura cu Vama Veche. Am compus-o tocmai in seara cu ziua mea. Ce seara era? A, da, era anul 2000, duminica spre luni. Plouase. Normal, era noiembrie. In seara aceea am furat:) Am vazut, cu ochii mei de vultur, unde danezii lasau electricele stricate, si cu vreo doua saptamani inainte furasem, in plina puterea noptii, cu toata rusinica, o combina muzicala. Fara boxe si fara cablu de alimentare. Si duminica, in 12, vad doi danezi blonzi cum lasau de izbeliste o mandrete de televizor de lemn, probabil usor mai tanar ca mine, si pleaca in treaba lor. Ce credeti ca facea un anume student roman in aceeasi noapte pe la 2? Cioplea cu furie cu cutitul din dotare (maner negru de plastic) la ladoi. Asa ca in aceeasi seara, dupa un efort sustinut de o ora si jumatate si cu mainile amortite si congelate m-am trezit cu cablu de alimentare si boxe, si am inceput sa ascult de zor RADIO RUSIA.\r\nCa sa fie cireasa peste budinca asa cum trebuie: in seara aceea mi-am facut cea mai adevarata mancare papata de mine in Danemarca (exceptand queue de boef-ul lui Iki): am facut pireu cu cotlete de porc ramase de la colegul de apartament, salata de rosii, masline si ciuperci (primele le primisem de la Ali, irakianul la care marunteam cascaval) si m-am apucat de scris ganduri de roman la 3X86-le primit de la Habip, libanezul, my best friend. Si mi-am dat seama ca niciodata nu ma simtisem intr-atata de liber si de implinit. Niciodata. Sau de singur. Niciodata.\r\nAnu asta am avut un gramadau de preteni si cunoscuti tocma cand mai adaugam un scaiete la ierbarul vietii mele trandafirii. Dar despre aceasta - dupa o scurta pauza publicitare.','My B-Day in Denmark',0,'','publish','open','open','','my-b-day-in-denmark','','','2007-03-12 22:46:05','2007-03-12 20:46:05','',0,'http://www.groparu.ro/?p=32',0,'post','',0),(25,1,'2007-03-12 20:49:31','2007-03-12 18:49:31','','Tiganiada 2005',0,'','inherit','open','open','','tiganiada-2005','','','2007-03-12 20:49:31','2007-03-12 18:49:31','',0,'http://www.groparu.ro/wp-content/uploads/2007/03/tiganiada_11.jpg',0,'post','image/jpeg',0),(27,1,'2007-03-12 22:40:00','2007-03-12 20:40:00','','Tiganiada 2005',0,'','inherit','open','open','','tiganiada-2005-2','','','2007-03-12 22:40:00','2007-03-12 20:40:00','',28,'http://www.groparu.ro/wp-content/uploads/2007/03/tiganiada_11.jpg',0,'post','image/jpeg',0),(28,1,'2007-03-12 22:40:27','2007-03-12 20:40:27','\r\n<p class=\"content-wrapper\"><a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/tiganiada_11.jpg\" title=\"Tiganiada 2005\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/tiganiada_11.jpg\" alt=\"Tiganiada 2005\" height=\"300\" width=\"399\" /></a></p>\r\nIn weekend am fost la Sibiu si am mers la munte cu cortul, numai baieti (6), intr-o kefuiala planificata de anul trecut, si pe care o asteptam de cateva luni bune. Cheful are loc in fiecare an, in aceeasi locatie: Valea Caselor, langa Rasinari. Am cazut de comun acord sa il facem tematic: tema de anul asta - tiganii rromi.\r\n\r\nDupa indelungi eforturi, am reusit sa fac rost de o palarie din piatza, de la o tiganca borata si urata ca in Kusturica. Alte accesorii: pantaloni de stofa, pantofii lu\' taica-mio negri, cu modele pe ei, camasa de matase mov descheiata si haina de piele, neagra. Bineinteles, pe cap, palaria. Sub nas, mustatza - netunsa de 3 saptamani. Lipsuri: nu am avut ghiul sau lant de\r\naur.\r\n\r\nSambata dimineatza: ora 9, vin Flaviu si Remus la mine \"sa bem o cafea\". De fapt, venisera numai sa ne batem in toalete. Am auzit afara, spargand linistea diminetii, muzica de tigani data la maximum, si din Matizul rosu apare o mustata acoperita de o palarie de tigan-tigan-tigan. Ne-am salutat zgomotos, eu de la etaj, ei de jos. Mi s-a spus ca domnul si vecinul Stoian, iesit pe geam, a intors degraba privirea de la tiganoi, dar a continuat sa priveasca cu coada ochiului. Balaurii au urcat, ne-am pupat zgomotos pe coridor. Pret de o jumatate de ora, ne-am studiat toaletele. Ca domnisoarele. Eram cei mai reusiti tigani din bloc.\r\n\r\nAm terminat bagajul, si am coborat, vociferand si vorbind tiganeshte. Domnul Bernhardt, ultimul sas de pe scara, a deschis usa sa vada ce e cu zgomotul. A inchis-o degraba cand a trecut Flaviu pe langa el, si nu mi-a raspuns la salut.\r\n\r\nAm plecat prin orash sa cumparam de-ale gurii si inimii, cu muzica data la maximum (muzica lautareasca, bineinteles!). Prima oprire: macelaria. Macelarul, comerciant adevarat, a inceput sa vorbeasca cu noi pe tiganeshte. L-am repezit in romana si a inteles ca nu e de gluma cu noi. Apoi am cedat si ne-am imprietenit cu el.\r\n\r\nUrmatoarea oprire: magazinul Univers\'All. Iata cum descrie Flaviu etapa Univers\'All: \"o mamica statea cu sticla de suc de morcovi in mana si se uita impreuna cu baietelul ei de vreo 4-5 anisori, amandoi cu gura cascata... la cei trei ciudati.... ce se plimbau ostentativ printre rafturi, varsand in cosuri fara pic de bun simtz fata de necazul omului de rand, tot ce prindeau, bauturi si mancaruri din cele mai alese, fara macar a se uita la pretul atat de important pentru voi toti... iar, cand privirea celui mai rotofei dintre tigani ii tinti intamplator si ii fixa pe amandoi..... sticla de suc de morcovi se lovi brutal de suratele ei din raft, iar mamica smuci minutza baietelului care ramasese pironit cu privirea in grupul celor ce pareau a veni din filmeeee... tarandu-l parca pe luciul greisiei de import a supermarketului, ...\"nu te mai uita!!!! lasa-i in pace!!!\"\r\n\r\nIn supermarket m-am intalnit cu: verisoara-mea Manuela, o fosta colega de liceu pe care nu mai stiu cum o cheama, domnul Davidoiu, vecinul de sub noi, care s-a uitat la mine luuuuuung, o tipa din vasile Aaron pe care o cheama Dana si care e si ea tiganca, dar din asta de orash, nu cum eram noi, si pe care o cunosc de la un bal al bobocilor, si am ramas consternat sa vad atunci ca avea mustata mai mare ca mine, care aveam 16 ani. Afara din supermarket am facut poze. Am vrut sa mergem langa un Mercedes urat-urat-urat, ca sa dam veridicitate pozelor, dar cand sa ajungem langa el, apare - ghici! - o tiganca ADEVARATA, care se uita la noi lung, la Matizul nostru; noi ne uitam la ea lung, ea la noi, apoi se urca in Mertzan si pleaca, glorios, pe sub nasul nostru.\r\n\r\nBestial! am simtit ca lumea evita sa ne priveasca. Eram \"balaurii\". Baragladinele. Ciorile. Ne-am comportat galagios, am rasturnat neshte produse in cart de-a valma, ne-am blastamat unii pe altii in supermarket. Hehe! Nici un comentariu, nimic. Eram respectati ca niste adevarati bulibashe. La casierie, angajata bolovaneshte ochii cand vrem sa platim cu cardul.\r\n\r\nUrmatoarea oprire: cartierul Strand, de unde am mai luat ce nu am gasit in Univers\'All. Inauntru - surpriza! promotie la iaurt. Ma duc la domnisoara aia, ea ma evita, ma intorc inspre ea din nou, ea se intoarce iar, si nu ma mai rabd si o intreb: \"Dha lha ceh fahci acia prhomotie, domnisoara draga?\" \"La iauuuurt!\" imi zice draga de ea. Gust, si zic: \"HUnde ii iaurt din hasta?\" \"Aici, zice domnisoara zambind cu gura pan la ureki, dar cu ochii reci-reci-reci. Cred ca ii placea foarte, foarte mult de mine in momentele acelea. \"Uitati, avem aici mic, cu 13 mii... si mare, da\' asta e scump, e 36.000!\" \"Si ce! zic io, semetz. Tiganii are bani\" Insfac cu tupeu un iaurt mare, si ma duc la cassa. In fatza mea, trei cupluri, cu de-ale gurii pentru gratar. Se uita lung la mine, ma uit lung la ei, imi musc mustata. Zic ei: \"Numai iaurtul acesta il aveti?\" \"Da!\", zic eu, gutural. \"Dar haideti, poftiti in fatza, poftiti in fatza!!!\" Multumesc, le tzutzui din varful buzelor cu un aer de casa rregala.\r\n\r\nAm ajuns in munte, dupa ce am trecut prin cartierul tiganesc din Rasinari, cu muzica la maxim. Ne-am salutat cu toti coloratii. Eram de-ai lor. Numai ca noi aveam poleiala, eram de orash.\r\n\r\nAm pus corturile, am jucat rugby toti 6 cu sticla de vin. In bustul gol si desculti, clar. Stef si-a luxat umarul rau de tot, dar a jucat pana la capat. Am sters si cateva balegi de pe teren, dar ne-am spalat in raul din apropiere. Dupa care am baut repede gin, sa ne incalzim. Cipi o dadea cu\r\nvodca - pana cand a fost prea mult pentru el, si a adormit pe movila, aceeasi movila pe care adorm de regula \"obositii\" festivalului. I-am batut o cruce la capatai, ca de obicei, si i-am pus ceaunul de tuci pe cap, de semana cu un neamt din al doilea razboi mondial. Cand ne plictiseam, loveam cu securea ceaunul, sa vedem cum rezoneaza capul lui in ceaun. Fara efect. Dormea mai departe.\r\n\r\nAm facut gratarele, am mancat. Am facut fight club cu verii familiei Mitroi. La un moment dat ginul si-a spus cuvantul. Afara era plina zi. M-am trezit a doua zi, tot in plina zi. Oare cine m-a imbracat si m-a bagat in sacul de dormit? Tu singur, mi s-a spus. As vrea totusi sa stiu.\r\n\r\nAm revenit la viata mea bicisnica de zi cu zi, cu inima improspatata de teribilitatea experientei. Memorabil! Memorabil. Merita sa fii tigan, chiar si numai pentru o zi.','Tiganiada 2005',0,'','publish','open','open','','tiganiada-2005','','','2007-03-22 15:36:59','2007-03-22 13:36:59','',0,'http://www.groparu.ro/?p=28',0,'post','',0),(34,1,'2007-03-12 22:50:08','2007-03-12 20:50:08','\r\n<p class=\"content-wrapper\">\"Despre Florinel ce sa-ti spun/Ce cuvinte sa adun/Ca-n adevarul lor sa creeeeeezi...\"</p>\r\nNu pot sa dau prea multe detalii despre el, ca unii il mai si stie p-asta.\r\n\r\nFlorinel (zis Benone) e un haiduc. In sensul rau al cuvintului. Bea, fumeaza, fute, inseala, minte, fura, ia bani imprumutzi si nu-i mai da, injura de sfinti, se da la prietenele prietenilor pe fatza - deci cam ca mine. Desi la o scara mai redusa.\r\n\r\nEram in caminu 14, si ma trezesc odata cu un telefon de la el. Ci fa mah, ui bine, tu, cum mai esti, is in Cluj. IN CLUJ? Pai musai sa ne vedem. Ce faci acilea? Ui, am vint cu socru-mio sa-l opereze. Da\' ci-are? Nada grav, cieva polipi or something, dreq stie ce organ o mai fi sh-asta, ca cica e in plus si traba scos. Hai sa ne vedem. Gata, zice, vezi ca is intr-o Dacie alba parcata ezac in fata intrarii spitalului, pe Clinicilor (sau clinciurilor).\r\n\r\nMa duc, ma scobor, vb cu el, etc. Plec acasa la camin.\r\n\r\nMa suna dupa doua saptamani: ba, zice, am pizdit-o, zice. Rau. Rau-rau!! Da\' rau-rau-rau!!! Zice. Si numa\' tu ma poti ajuta, zice. Dic: Ba pula, io bani imprumutzi nu-ti mai dau! Da\' taci ma fraiere, zice el, ca nu d-aia te sun. Inregistreaza ce-am patit, zice el. Inregistrez, zic io. Ce pula mea era sa zic altceva?\r\n\r\nFlorinel venise cu socru-so sa-l opereze de polipi (oare am mai zis asta?). El, socru-so, si cumnatu-so. Operatie de rutina, nu de ruina. Fiind in Romania, daca nu ma insel, tzara in care trebe sa dai shpaga si ca sa te ingropi, batrinocu\' sh-o pregatit o mica atentie, \"ceva\", acolo, sa fie, pt dom\' doftor. Sa nu-i tremure mana prea tare la operatie, ca era cam stafidit omu\' in halat alb, mai avea o beshina si se curatza. Si - din pensia amarului sau - prepara omu 2 milioane de lei, ii baga-n pizda masii in plik, si le zice la astia: Ba, fitz atentz la mine-aci! Io n-o sa pot vorbi dupa operatie, ca ma opereaza la polipi, dreq stie ce organ o mai fi sh-asta, ca cica e in plus si traba scos. Dupa operatie o sa vie dom\' profesor (n.n. - vraciu\') sh io o sa fiu mahmur. Asha ca ii datz voi pliku\', sa hie omu multumit, sa ma trimeata acasa tot azi! Ne-am intzales? Da\' ii dai tu malaiu\', zice cata Florin, ca daca ii las lu cumnatu-to asta ii be. Vai, tata socrule, cum, n-ai incredere in noi, zice Florinel, cu ochi sclipitori. Du-te matale de-ti scoate polipii, ca banii sunt in sigurantza.\r\nZis si facut, omu paseste catre incaperea de unde urma sa iasa mai sarac de polipi decat intrase, operatia reuseste, numa ca bolnavu\' nu mai poate vorbi deloc o vreme - numa cu mainile; si astia stau ce stau sa se faca ora 5, cand dom\' profesor o promis ca vine si verifica starea agregatului, sa-l trimita acasa la el. Si astia stau sa se faca ora cinci. Si se face ora 6, 7, 8, 9. Si profu\' - canci.\r\nSi-atunci, ce le trece lor razant prin idei? Un gand! Ba, zice Florinel, ce pula mea. Asta isi bate joc de noi. Sa ma f. Hai sa nu-i mai dam 2 milioane! Ii dam numa un mileon, si unu il impartim cumnatzeshte intre noi, sa avem si noi banuti de o tigara, de-o maslina. Da-l in ma-sa, ca oricum are bani, si tac-tu nu poate vorbi cu el dupa operatie! Asa. Tine, si da. Boooon. Ba, da\' oare ce are asta in dulapele astea? (astia il asteptau pe doc in cabinet la el). Uau! ce carti de medicina groase, cu desene si coperti legate, si - pun pariu - scumpe. Uau. Ba. Hai sa il futem, ca si el ne fute, ne face sa dormim in masina o noapte. Hai ia tu cate poti duce, si iau si eu, si le ducem la masina, ca s-a bucura niscai anticar de ele, sarmanu\'! Si mai facem si bani de-o votculitza mica (ati opservat ca tot timpul cand se face o manarie, se face pentru \"o cafea, un coniac, o bere\"?).\r\n\r\nBooooon. Sh baietii cara vreo doua plase pline cu carti in masina, si se pregatesc confortabil sa doarma in Dacie, nu inainte de a-i spune Florinel lu cumnatu-so cum i-o mai tras-o lu soru-sa, in ce pozitii, de cate ori si in ce gauri, si cat de greu se pot fute ei cand comnatu\' doarme langa ei si sforaie, ca ii pufneste rasu si ii moare pula. Boooon.\r\n\r\nDimineatza, se scoala baietii mei dis-de, se indreapta cu fatza carpita de somn catre salonu\' unde era cazat nenea cu polipii in alta camera, si au placuta surpriza de a-l vedea pe tata socru in picioare, vorbind pe soptite cu doftoru\', ca mai mult nu putea, decat <em>sotto voce</em>. Cand ii vede, se bucura, ce era sa faca mosu\'! Nu mai avea polipi, da ii avea p-aia. Cred ca tot mai bine ar fi fost cu polipi, da\' fara aia. Si mere catre ei, si le zice perplecshilor: Ba, zice, ia da-ncoa plicu\'! si mai repeta de vreo trei ori, ca astia nu credeau ca-si aud urekilor. Impietrit de frica, Florinel al meu isi indreapta mana spre buzunaru de la piept, scoate plicu\', si mosu il insfaca ca un uliu. Il flutura triumfator pe la nasu doftorului, si ii gajaie din gat: dom doftor, zice, uitati aici, o mica atentie, bla-bla. Nu, nu trebuie zice doftorul, cu ochi sclipitori. Ba, nu, dom\' doftor, zice mosu, e o nimica toata, <strong>2 milioane e bine</strong>? Cred ca Florinel arata ca un pastel de Picasso. Da, da, e bine, zice doftoru, preluand mica avere si depunand-o cu grija printre celelalte plicuri ale halatului sau.\r\n\r\nNu are rost sa va spun ca, dupa intrevedere, Florinel si cumnatu-su or batut recordul mondial de viteza la coborit treptzile spitalului cu moshneag fara polipi. Si cred ca nu a fost Dacie mai rapida la iesit din Cluj ca Dacia lor, acum mai usoara cu o familie de polipi.\r\n\r\nDa ba pula, zice Florinel in continuare, moshu s-o dilit! Zice. Vrea sa vina la Cluj sa il vada doftoru\', sa ii dea nush ce analize o facut el la iesirea din spital, si alea i le trebe la medicu de famelie! Si ba, zice, abia il pot tine-n frau! Ba, zice, te rog ca pe profet: zice, ba, te implor meri tu acolo si ia analizele pulii, ca, zice, de vine asta si vorbeste cu doftoru, m-am fript in fericire! Zi-le dreq ca esti varu-mio, sau nepotu-so, sau ce vrei tu, zi-le ca esti lieutenant-commander Worf, din partea mea, numa PUNE DREQ MANA PE ANALIZELE ALEA, CA DACA NU MA BELESHTE ASTA! Ba, zic. Daca nu e vorba de bani, te ajut cu draga inima, zic.\r\n\r\nSi uite asa mere Groparu\' nostru la spital, ca proaspat nepot a lu\' Zgabeatza Iftode. Si il intreb pe Stelea... aaa... pe portar: ba shefu\', zic. De unde pot ridica analizele la polipi? La camera trei, zice el. Booon, zic eu. Sanatate. Si ma indrept catre camera trei. Si bubui in usha. Nu se aude nimic, si dau buzna inauntru.\r\n\r\nAmu, astia care or dat bacu\' din Rascoala lu Liviu Rebreanu, isi amintesc cu sigurantza scena in care Petre da buzna si ii trage un viol lu\' Nadina, care era imbracata in pielea si parul ei, si nimic mai mult. Noa. In camera trei in care tocma am dat buzna, camera care - am aflat atunci, ad-hoc - era si vestiar, se rasfatza o dragutza de sora medicala in tzitzele goale, care se skimba, presupun. Faine tzitze! Faine. Stil pere, usor ridicati in sus, usor inegali, cu o alunita pe cel stang, cu pielea gainii ca era usor racoare in cabinet, si butonasele erau ridicate in sus, de puteai atarna camasi la uscat in ele. Si fara urme de plaja de sutien. Si clar ca am mormait ceva scuze cu o voce care nu era a mea, de parca io nu mai aveam polipi. Si dupa o secunda luuuunga de playboyit, fac 180 grade si ies.\r\n\r\nSi ma gandesc: Tiii, Florinele, bata-te pula! Furi, inseli, si amu fut si eu meciu\', ca mi-o ramas ochii lipiti in bustiera lu tipesa aia! Pula analize, imi zic. Infunzi pushcaria. Si stau un minut afara, cu ochii sticlosi. Si vine o d-ra si da sa intre in camara trei. D-ra scumpa, zic io, un pic neobisnuit sa vad si sore medicale imbracate, zic, am de ridicat analizele lu Zgabeatza Iftode, va rog a binevoi sa. Da, sigur, zice ea, haideti inauntru. Multumesc, zic, ricaind de pe fundul oalei bruma de bun simtz pe care am mai avut-o, prefer sa astept afara.\r\n\r\nTanti a revenit, cu un zambet pe care se kinuia fara folos sa il ascunda de pe fatza si cu un set de analize in mana stanga. Florinele, ii zic, ai luat-o-n mana, prietene. Asta te costa o gramada de fiole de bere. Te-am scapat, ma pula.','Florinel',0,'','private','open','open','','florinel','','','2007-03-14 17:21:12','2007-03-14 15:21:12','',0,'http://www.groparu.ro/?p=34',0,'post','',0),(145,1,'2007-03-16 02:01:54','2007-03-16 00:01:54','\r\n<p class=\"MsoNormal\"><a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/800px-rumunia_5806_resize.jpg\" title=\"http://en.wikipedia.org/wiki/Shepherd\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/800px-rumunia_5806_resize.jpg\" alt=\"http://en.wikipedia.org/wiki/Shepherd\" /></a></p>\r\n<p class=\"MsoNormal\">Zice <a href=\"http://uk.reuters.com/article/worldNews/idUKL1532336820070315\" target=\"_blank\">aici</a> ca cel mai batran om din lume este un cioban ucrainean, care pe deasupra nici nu e femeie, cum se-ntampla de obicei cu unele dame care nu se grabesc sa se reuneasca in <em>afterlife</em> cu barbatii lor ingropati in 1968 si se incapataneaza sa stea la mine in bloc si sa bata in tzeava cand ma fut. Nu, e un nene de data asta, care are nu mai putin de 116 trandafiri la buchetul vietii, trandafiri pe care - lucru foarte important - ii miroase la pistil, nu la radacina. <o:p></o:p></p>\r\n<p class=\"MsoNormal\">Si ca pe langa faptul ca a fost de-a dreptul cioban, nenea Savciuk zice ca nu a fost niciodata casatorit. Cum sa nu traiesti 116 ani cand nu esti intrebat de 116 ori pe zi unde te duci, de unde vii, de ce nu mergi la ala micu\' la sedinta cu parintii, ca numa ea tre\' sa se ocupe de educatia copiilor, si cine-i colega aia care o dansat cu tine la cheful firmei, de ce Ioneasca are inel de aur cu diamant si ea are tot bijuteriile de la mama, ca de ce vecinul stie sa repare masina de spalat si tu nu esti in stare sa ii pui un amarat de toc la sandalele alea stricate, da-o dreq de treaba, ca stau asa cu ele de 4 luni de zile, mai omule, ca nu m-ai mai dus intr-un concediu mai de Doamne-ajuta din luna de miere, uite, Georgeasca o fost cu sotul in Iugoslavia in concediu sa vanda slapi chinezesti si lighene de plastic!, si tu flori ii cumperi numa de 8 Martie, si de ziua ei i-ai cumparat un aspirator, ma, ASPIRATOR, ala-i cadou?, si mai si sforai ca un nesimtit noaptea, parca n-ai sti ca asta ii provoaca migrene, iara ti-o bagat sora aia a ta in cap prostii! si nu mai fi asa somnolent, te simti rau, draga? foarte bine, ca iar ai baut ca un porc azi-noapte; si nu ma intereseaza ce meci e - hai si curata usturoi, ca doara iti plac chiftelele!!!, si ca de ce nu esti de acord ca Popeasca s-a ingrasat ca un sarpe boa lasat singur in pepenarie, stie ea ca tot timpuâ€™ ti-a placut de ea, asa-i ca sanii nu mi s-au lasat deloc in ultimii 12 ani??, mai lasa, draga, calculatoru\' ala-n pace, ca numa la ala iti sta capu\', puiutz, asa-i ca dupa ce ne-am casatorit ai sters toate numerele de telefon ale fostelor din agenda?, iara vrei sa ma pupi si nu esti barbierit?, vino si tine-ma-n brate si transforma-te in Sean Connery ACUM, asa-i ca eu arat mai bine ca toate uratele alea de la nunta lu\' Mimi?, de ce te-ai schimbat dupa ce o aparut ala micu\'?, ca niciodata nu ai fost bun la afaceri, ca niciodata nu te mai timit in piatza ca te fraieresc toate precupetele cu 4 clase, ce, ala-i patrunjel?, Doamne, cu ce tantalau m-am maritat!, vreau sa fac drsgoste cu un negru â€“ macar o data, de fapt ea stie ca nu atata or costat portocalele, dar te-ai oprit la birt sa bei una mica cu baietii - ia sufla-ncoa!, ce poate sa-ti placa atata la bautura, mai omule?, tu cand ai sa castigi suficient ca sa ne permitem si noi alta masina?, de ce te-ai schimbat dupa casatorie?, de ce nu esti un model pentru copiii tai?, neamurile tale au de gand sa se civilizeze odata si-odata?, hai ca e Bahmuteanca la OTV, toata lumea zice ca sunt mai meseriasha ca fostele tale prietene, de ce nu vrei sa intelegi ca azi am avut o zi grea la serviciu?, tu niciodata nu m-ai inteles, nici nu stiu ce mi-o placut la tine, Doamne, iarta-ma, trebuia sa ma marit cu Sandel, ca ala ma iubea cu adevarat, bueeeeeey, ma iubea!, anuâ€™ asta nu mai facem vin de casa ca vreau sa ma duc la tratament cosmetic, pentru tine ma fac frumoasa, mai, si tu nu apreciezi, niciodata nu apreciezi, ca si mama o observat!, la Opera ai de gand sa ma mai duci macar o singura data pana mor?, de azi inainte iti speli singur ciorapii si sosetele,tu te-ai bate cu alti barbati pentru mine?, anu asta m-am hotarat ca vei tine post!, cand ai de gand sa te lasi de fumat?, nu mai ai nici un pic de ambitie!, ia mai spala si tu vasele, dragul meu!, te rog frumos sa nu te mai uiti la Procesul Etapei ca vreau sa dorm!, te rog sa nu mai mananci grasimi si mezeluri si gratare ca nici nu sunt sanatoase, Doamne, ce poaâ€™ sa-ti puta picioarele, AJUTOOOR, NU MA INGROPA DE VIE CA NU MAI FAAAAC!!!!!!!!!</p>','Longeviv ciobanel, scapat de inel!',0,'','publish','open','open','','longeviv-ciobanel-scapat-de-inel','','','2007-03-16 02:59:48','2007-03-16 00:59:48','',0,'http://www.groparu.ro/?p=145',0,'post','',5),(35,1,'2007-03-12 22:53:43','2007-03-12 20:53:43','<a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/leucemie.jpg\" title=\"Leucemie\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/leucemie.jpg\" alt=\"Leucemie\" height=\"603\" width=\"457\" /></a>\r\n\r\nDa.\r\n\r\nSinucide-te, bou sau capra ce esti. Pune-ti capul pe sine si asteapta, rabdator (adverb), sa treaca personalul, ca nu meriti sa te ucida Sageata Albastra.\r\n\r\nDeprimarea e boala generatiei mele.\r\n\r\nSuntem tineri, suntem frumosi. Mai icnim din cand in cand, da\' e ok. Nu toti avem locuri de munca, aia care avem nu suntem toti multumiti, ne mai kinuie un shaf, nu suntem apreciati la justa valoare, ne mai fute cand un pretin ca nu ne-o sunat de ziua de nastere sau nu ne-o dat un SMS patetic de LMA de sarbatori (partea asta am scos-o ca cineva drag mie s-o ofuscat). Ne enerveaza aglomereala din autobuzele ma-sii, grobienii, aia care or primit apartamente de la Ceausescu moca si amu le vand pe miliarde, hamalii din piatza care te darama cand circula cu carucioarele pline de castraveti importati, casieru\' de la Billa care are o zi proasta, Nastase cu matushile si nesimtirea lui, ziua de salariu in care vrei sa zbori si iti dai seama ca ai aripi de ceara. Proprietarul apartamentului meu, parintii care nu mai is tineri si nu te mai poti certa cu ei, sistemul sanitar din \"Moartea domnului Lazarescu\", vremea asta cetzoasa, barurile in care vezi femei care nu se vor uita niciodata la tine, varsta asta care galopeaza spre dreq stie ce, ca nu tot timpul Dumnezeu are vreun plan cu tine. Filmele americane despre colegiu si tineri cretini pe care le plac jumatate din populatia Romaniei. Camera in care stai in chirie si pentru care plateshti un salariu de profesor. Pe luna. Starurile din firma. Rosiile importate care au gust de acru, iarna. Peshtele de la Profi, crescut prin haznalele oceanului, si care pute a caminul 16.  Intretinerea.  Aia care is pe dincolo, castiga o carutza de banuti, si se perpelesc de dorul patriei asteia imputite. Traian Basescu. Tariceanu. Geoana. Brucan (seamana cu o iguana). VADIM (daca tot ce spune el e adevarat???) Lenea mea (nu eram asa inainte, jur). Munca asta care nu pare sa se mai termine. Aia care se uita la mine si ma invidiaza ca castig o jumatate de salariu minim pe economie occidental. Cioran. Agentii imobiliari care se distreaza cand le zic ca nu dau 44.000 E pe un apartament de 46 mp, confort unic. Statul la ocazie. Aia care cumpara Piatza luni si golesc oferta de  apartamente bune. Piloshii care intra in fatza la doctor. Taximetristu\' de la Diesel care ii injura pe olteni. Orasul asta cenusiu in care nu se va intampla niciodata nimic. Englezoii care habar nu au cum sa-si administreze afacerea. Bocancii luati la reducere si cu care alunec iarna. Izvorul Minunilor. Pretul la banane care e mai mic decat pretul merelor romaneshti. Caminul 16 in care nu poti sa lasi un partz. Faptul ca nu s-au inventat oglinzi pentru suflet. Uniunea Europeana care ne va lasa fara telemea si sorici. Smantana Napolact care nu se topeshte in ciorba. Pensia alor mei. Singuratatea lor. Oamenii de care ti-e dor. Corpul meu care trebuie hranit. Dan Diaconescu. Andreea Esca. Pretenu\' meu Niatza, la culme. Cel mai vechi. Din nou, apartamentele. Calculatoru meu care se blocheaza cand joc counter, desi am placa video de 256 Mb pe 128 biti. Aia de la cablu din cauza carora nu pot vedea CNN. Masterele pe care le-am picat. Faptul ca nu m-am nascut bogat. Capitalismu\' asta de imprumut clonat pe o economie bolnava. Oamenii imbracati in geci negre care iti controleaza biletul in autobuzele ticsite. Faptul ca nu mai stiu canta la chitara ca pe vremuri, si vocea care nu mai suna ca la 16 ani. Imi creste tensiunea cand trag din tigara. Am insomnii, pt ca urasc momentul ala de dinainte de adormire cand raman singur cu gandurile mele. Faptul ca mai sunt oameni care mor de frig sau de foame in Romania. Si in lume. Aia cu piercing in spranceana care nu pot duce o conversatie inteligenta mai mult de 20 de secunde. Fauna Music Pub-ului. Partile de lume pe care nu cred ca apuc sa le mai vad. Faptul ca ma cam doare la banana de ele si nici nu vreau sa le vad. Razboiul din Irak, care costa un miliard de $ pe zi. In Franta nu mai ai voie sa mergi la scoala cu voal daca esti musulmanca. Oamenii care nu inteleg sa fie umili. Aroganta mea cand mai cac un text ca asta. Durerile de spate. Oamenii hipersensibili la gesturile gresite ale celorlalti. Faptu\' ca pretenii mei care au firma nu castiga miliardu\' pe an. Si, in final, toti aberatii care isi trec texte pesimiste pe blog. \"Viata e un butoi\", \"Incerc sa descopar sensu vietii\", pizde d-astea. Mesurile alea cu se inkide yahoo, un copil primeshe bani de la AOL daca dai mailul mai departe, daca iti trebe penis mai mare ia bumbii astia. Nepotii mei care sunt la distanta si nu apuc sa ii vad numa in MMS-uri. Cumnatu\'-meu e neamt get-beget. Nationalismul exacerbat al clujenilor. Vorbirea cu \"are decat 3 milioane salariu\". Se zice serviciu, nu servici. Nu petrec suficient timp cu oamenii dragi si imi pare rau, dar uneori kiar nu am kef. Blow me. Un sut in fund e un pas inainte spre hemoroizi la amigdale. Oamenii mai si mor. Pana sa iti moara cineva drag, faci bancuri. Dupa care nu mai faci. Dimineata vin cu taxiul, seara ma inghesui in Ratucuri. Berea din Jay\'s are gust ca pixu\', nush unde dreq o tin astia. A, si muzica e neschimbata de 4 ani. Microbistii. Gunoaiele. Trotuarele asfaltate prost, care nu vor arata a occident nici in 15 ani. Copiii vor rade de mine cand le voi explica Romania in 2006. Comu-istii pulii carora le-a esuat experimentul destinat esecului, si asta la scara planetara. Capitalistii astia care se mananca intre ei pentru un botz de mamaliga. Rusii. Daaaa, rusii anytime. Efectul de sera, ne ducem pe pula toti. Vremea din Romania, in tzara asta nici clima nu mai mere cum trebe. Vreau apartament. Si pensie mare, de 2000 E pe luna. Acum. Oamenii care sunt foarte buni cu mine si ma fac sa ma simt ca un vierme ce mi-s. Politaii care urla la tine cand nu parchezi cum trebuie. Bisericile romanesti sunt penale comparativ cu cele sasesti sau unguresti, si iti gadila isteric si negativist sentimentu\' nationalist. \"Fara noi, erati inca vanatori-culegatori\". Faptul ca uneori fac bine din orgoliu. Oare asa fac si ceilalti? Uneori ma dau mare cu ce sfaturi de viatza dau. Ai, destept mai sunt! Mi-as lua si masina, daca as avea chef de scoala de soferi. Daca instructoru\' nu e amabil cu mine, a belit-o, jur. Nu mai am chef sa fac miscare, si asta e un semn naspa de ramolire. Sunt dependent de calculator.\r\n\r\nDaca ai vreodata o depresie, gandeshte-te la copila asta din imagine. Cei dragi tie is sanatosi, sau de bine de rau mai sufla. Am vazut-o acum doi ani la sectia de Leucemie din Cluj. Anul asta nu am mai vazut-o. Te simti mai bine?','Deprimati din toate tarile, sinucideti-va',0,'','publish','open','open','','deprimati-din-toate-tarile-sinucideti-va','','','2007-03-12 22:54:41','2007-03-12 20:54:41','',0,'http://www.groparu.ro/?p=35',0,'post','',3),(36,1,'2007-03-12 22:53:05','2007-03-12 20:53:05','','Leucemie',0,'','inherit','open','open','','leucemie','','','2007-03-12 22:53:05','2007-03-12 20:53:05','',-1173732642,'http://www.groparu.ro/wp-content/uploads/2007/03/leucemie.jpg',0,'post','image/jpeg',0),(37,1,'2007-03-12 22:56:18','2007-03-12 20:56:18','','Ou',0,'','inherit','open','open','','ou','','','2007-03-12 22:56:18','2007-03-12 20:56:18','',38,'http://www.groparu.ro/wp-content/uploads/2007/03/ou.jpg',0,'post','image/jpeg',0),(38,1,'2007-03-12 22:56:30','2007-03-12 20:56:30','<a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/ou.jpg\" title=\"Ou\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/ou.jpg\" alt=\"Ou\" /></a>\r\n\r\nAti auzit de oul lui Columb? E, vax albina. Pana si eu am auzit de el. A dreq Columb, mono-coios, si descopera ditai continentu\', pitit cale de trei zile de exasperarea echipajului!\r\n\r\nNoa, da\' ou\' lu Mitroa e mult mai poietic.\r\n\r\nClar, eram in caminu\' 16. Abatorul de minti fragede. Armata mea. Stagiul meu militar. Si cand plecam din camin in vacantza de iarna din anul de gratiela 1997, ramane un ou nespart, pe care nimeni nu il mai poate papariza, ochiza, fierbiza, papa, arunca. Un ou stravechi. Pe care cineva (aka Mitroa, ca e cineva!) are ideia geniala de a-l lasa pe calorifer pentru a se coace peste vacantza de iarna. Sau incuba. Sau whatever. Ideia era sa iasa primul pui din expresia \"ce puii mei\".\r\n\r\nDin pacate, Dumnezeul puilor a avut fericita inspiratie de a nu lasa vreun exemplar aripatÂ  sa se nasca in cazarma 16. Am aflat acest lucru dupa exact patru saptamani, cand ne-am adus aminte de el. Oul deja capatase niste nuantze albastrii, si niste miasme emanand din porii personali care depaseau cu mult aroma bocancilor nostri in spatele carora se ascunsese nelegitimul prins de razie in odaia noastra. Dar era OK. Oricum aveam narile atrofiate de la gatit papare cu ceapa in slanina topita (shunca, pentru sudishti) si de la aroma dulapelor unde pastram kilotii. Asa ca l-am mai lasat sa fiarba in albush propriu pana in sesiune.\r\n\r\nEi bine, in sesiune, dupa o repriza furioasa de invatzat, cautam la marea disperare ceva de facut. ORICE. Si intr-o duminica dimineatza mohorata de ianuarie, pe la vreo orele 13, Fla\' Mitroa\' regaseshte oul. Care cam zvacnea. Parerea mea e ca deja isi dezvoltase un intelect propriu. Ce sa faci? Nu era decat o singura solutie. De aruncat la cosh nu puteam, ca iesea noaptea din gunoi si ne sugruma pe toti. Asa ca ne-am hotarat sa il facem cosmonaut orbital. Asa ca mytroianul l-a inshfacat viguros cu mana cu care isi tinea putzulica cand facea peepee si s-a catzarat pe masa din curul camarei, pentru a-l promova in proiectil inteligent (cum dreq atz traduce voi homing missile???) spre o tinta demna.\r\n\r\nSi tinta s-a aratat.\r\n\r\nIn spatele caminului (deci in partea de est, partea opusa intrarii, adeca a plaformei unde se stransesera cioabele de la meciul romano-croat) existau neshte cashi, locuite de neshte bashtinashi super pashnici. Nush ce cultivau aia vara in gradinile lor generoase, deoarece nu mai puteai vedea culoarea pamantului de cate desheuri arunca un camin intreg de studentzashi pe gem. Ptiu, pe geam. Sticle de bere, borcane cu zacusca inflorita, cutii de plastic cu pilaful de acum doua saptamani, pungi cu apa, coji de cartofi, pixuri, ceapa, pantofi scalciati, inca un televizor, doua chiuvete care s-au facut tzandari pe pavaj, o tzeava de dush, un pat, o saltea care a aterizat pe acoperisul de deasupra intrarii si a ramas acolo, innegrita de la ploaie, pana anul urmator, carti, cursuri arzande diafan prin aer, izmenele de-asta iarna, vreo patru coshuri de gunoi de plastic rosu, un lighean portocaliu, tacamuri, paine mucegaita, frigiderul de la etajul opt, tot gunoiul de pe palier, blugii vechi ai colegului de camera, cojile de la ceapa, mamaliga scorojita, rezerva de slanina. Toate, intr-o avalansha tinereasca de proiectile pe care propitarii renuntasera de la a le mai indeparta. Ei bine, nacazul mare nu il reprezenta covorashul de desheuri, ci toaleta (ptiu, buda!) aflata - ati ghicit! - in curte. Buda clasica, cotetz de lemn.\r\n\r\nEi bine, in acea duminica, intr-o ora post-slujba-de-duminica-de-la-biserica, Flaviu cantarea un outz de gaina proasta intr-o mana, si cu cealalta fixa tinta, orice tinta, precum discobolul din caminul 16. Ce tinta? Pai sa va spun. Unul din nefericitii locatari ai cashilor din spatele caminului, unde soarele nu rasare nici daca-l mituieshti, tocmai mergea voios spre cotetzul rustic de lemn pentru a se exprima fiziologic.\r\n\r\nBad idea jeans!!!\r\n\r\nIn aceeashi nanosecunda, creierul berizat al mitroiului meu a fixat tinta, a procesat binar GPS-izat informatia, a stabilit coordonatele si a slobozit incarcatura hepatica catre nefericitul pisharcos. Bineinteles, cu aceeasi acuratetze cu care ai incerca sa nimereshti o angiosperma cu un proiectil de un micron (nush de unde comparatia asta, da\' iubesc cuvantul \"angiosperma\"). Daca nu l-a nimerit, nu a fost vina lui; cert e ca in aceeasi nanosecunda, inca alte trei minti luminate din camin s-au gandit sa ii trimita nefericitului niscai mancare stricata, in asa fel ca omu isi putea hrani in sfarsit o saptamana familia cu bucata zdravana de paine mucegaita, crihanul de slana afumata si branza cu mucegai ne-nobil pe care cele trei minti semi-treze s-au gandit sa i le arunce, spre indestularea gintei sale. Ca l-au nimerit sau nu, nu pot sa va spun; cert e ca omul si-a atins scopul final - atingerea americii sale cotetzeshti si buzeshti - dupa care a tzashnit intr-un sprint olimpic inapoi spre zidurile cashii sale acoperite de tabla, tabla aia infecta care suna ca dreq cand aruncam cu sticle de bere (evident, goale!) noaptea pe la 4.\r\n\r\nToate bune si frumoase si grase, sesiunea continua, si asa continua si studentia.\r\n\r\nDupa 2 saptamani, un zvon scutura caminul. Urmeaza sa ne puna zabrele la fereshti! Sa nu mai aruncam desheuri radioactive pe ferestre. Caminul a inceput brusc sa arate ca penitenciarul de la Vascautzi.\r\n\r\nIn ziua in care au ajuns la noi la etajul 5 cu zabrelele, Flaviu revine acasa dupa o cina copioasa (si altceva, probabil la fel de copios!) de la prietena lui, care dispunea si de televizor in dotare. Meseriashu\' tocmai vazuse pe NCN (postul local) un interviu luat locatarilor de supt ferestrele est, din partea opusa intrarii, cu ocazia zabrelirii caminului. Locatari, intre care un personaj foaaaarte dubios si mincinos se plangea ca \"D-ra reporter, da\' nu pot nici macar sa merg la toaleta din cauza deseurilor pe care le arunca studentii pe geam! This is outrageous!!!\"\r\n\r\nSi amu stau si ma intreb: oare o fi vreo legatura???\r\n\r\n\r\n\r\n\r\nDin acel moment, nu am mai putut arunca desheuri pe geam decat strezurandu-le printre ochiurile de plasa de metal de la geam. Ce pierdere! Pana atunci, la orele 9 dimineatza si 9 seara, cand caminul pleca la faculta in Pub sau revenea seara de la \"studii\", nu numarai pana la 6 pana sa vezi o punga, un ambalaj, o sticloantza goala sau ceva mancare putrezita plutind voios catre coordonata telurica - o data la 3-4 secunde. Din acel moment nu am mai avut ce numara. Decat ghemotoacele perseverentilor, pe care ajtia se incapatanau sa le arunce printre ochiurileÂ  de sarma, in ciuda autoritatii.','Oul lui Mitroa',0,'','publish','open','open','','oul-lui-mitroa','','','2007-03-12 22:56:30','2007-03-12 20:56:30','',0,'http://www.groparu.ro/?p=38',0,'post','',1),(39,1,'2007-03-12 22:58:13','2007-03-12 20:58:13','','Camin 16',0,'','inherit','open','open','','camin-16','','','2007-03-12 22:58:13','2007-03-12 20:58:13','',40,'http://www.groparu.ro/wp-content/uploads/2007/03/camin-16.jpg',0,'post','image/jpeg',0),(40,1,'2007-03-12 22:58:45','2007-03-12 20:58:45','<a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/camin-16.jpg\" title=\"Camin 16\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/camin-16.jpg\" alt=\"Camin 16\" height=\"291\" width=\"434\" /></a>\r\n\r\nDa, tot caminul 16. Parca era ieri. De fapt, ieri si era.\r\n\r\nCred ca, per total, a fost cea mai tare experientza traita in anul I. In afara de balul bobocilor organizat de mucea din Sibiu, anu I, care vede si el prima data orash mare cu tramvaie, in afara de bataia cu basarabenii si de eternul Ivan.\r\n\r\nDeci, sa o luam pe indelete.\r\nCupa mondiala la fotbal, sau campionatul european, vara \'98, juca si Romania; ca si acum, eram super microbist cand juca echipa patriei mele, ca aveam motiv sa beau, de necaz sau de bucurie.\r\nEi bine, asa se facu, ca din toata camera de 4+1, fiecare s-o inshurubat pe la cineva cu televizor in camera, pe la o terasa cu ecranare, pe undeva de unde se putea vedea meciu\' vietii. Romania-Croatia, daca mai tin bine minte, si mai tin, ca circumvolutiunile nu se indreapta de la beutura (oricine spune contrariul, minte!!).\r\nEi bine, si fac eu ce fac, ma plantez intr-o terasa langa B-uri (caminele medicinei), vecina cu Paco, prind si loc la masa, comand cele 6 beri care trebuiau sa imi umezeasca gura uscata de la \"Hai Romaniaaaa!\" Si incepe meciul. Si privesc. Si sufar. Si Romania o ia (Croatia, daca nu ma insel, o si castigat cupa anu\' ala). Si, amarat, dar optimist ca am motiv intemeiat sa imi beu iara mintile, cobor Piezisa sa merg in camera 109 din caminul 16, sa-mi iau tovarashii. Ajung la intrarea caminului dupa ce am inotat in suvoiul de multime furioasa care iesea din camin sa isi curete nisipul de la rinichi. La poarta caminului, ma intalnesc cu cel mai bun prieten al meu, un ucrainean (copilu\' asta iesea iarna la minus 15 imbracat in sandale, pantaloni scurti si un cojoc de blana neincheiat peste bustul gol sa isi cumpere tigari, si mai si zabovea in fatza caminului la o discutie cu aia care curatau zapada; ultima data cand l-am vazut isi trecuse UN SURUB prin nas si era mare bodyguard prin Bianco&amp;Nero - era ceea ce eu numesc un <em>tough motherfucker</em>, cam 2 metri si 10, la sport). Era genul de om pe care era bine sa il cunosti. Odata auzisem ca ridicase doi inamici de cureaua de la pantaloni si ii aruncase doi metri in spate, si il cred in stare. Nu apuc sa ii strang mana lui intinsa ( <img src=\"http://blog.360.yahoo.com/blog-4GGYEewzfq_d2Jj8sESMNj8-?cq=1&amp;l=61&amp;u=65&amp;mx=71&amp;lmt=5#%5CDOCUME%7E1%5CJupan%5CLOCALS%7E1%5CTemp%5Cmsohtml1%5C01%5Cclip_image001.gif\" alt=\"Image\" height=\"18\" width=\"18\" />) ca aud de sus \"Roomaniiiaaaaaaaa...!\"Â Â Â Â Â Â Â Â Â Â Â Â Â Â Â Â Â Â Â Â Â Â Â Â Â  pauzaÂ Â Â Â Â Â Â Â Â Â Â Â Â Â Â Â Â Â Â Â Â Â Â Â Â  BUUUUUUM! Metal, sticla, lemn. Un televizor aruncat de la etajul patru. Tzandari, aschii, ace. Basarabenii de langa meseriashu\' meu: \"Blea! O aruncat tilivizoaru\', blea! Niebunu\'!!!\"\r\n\r\nUrc cele cinci etaje, aleg cu grija pe drum injuraturile cu care sa impartasesc amarul cu colegii de camera, si ajung in odaie.Â  Camera â€“ inca goala. Oftez, si plec sa dau un flipper asa, de amareala (era un flipper meseriash cu gagici futuriste, cu lenjerie intima de otzel si sfarcuri de laser). Stau acolo 15 minute, si ma hotar sa plec inapoi sa-mi culeg tovarashii.\r\n\r\nSi atunci s-a intamplat.\r\n\r\nAti vazut vreodata tot caminul 16 iesit pe ferestre? 1000 de suflete inghesuite la vreo 70 de geamuri? Eu am vazut. Dar 1000 de suflete care iti fac semn TIE (mama, cum se transparea liderul din mine, de la distantza!) \"Hai! Hai!! Hai!!!\" ati vazut vreodata? Absorbit de multimea care isi cauta lider, pasesc precum un Dumnezeu pe mare inspre cladirea cenusie, pregatindu-mi discursul despre starea natiunii, cand observ si vreo cateva maini si guri cunoscute care strigau si faceau semne, cu incetinitorul, sa plec, sa nu ma apropii. Nu am mai avut vreme sa ezit. Din inaltul ceriului au aterizat langa mine vreo patru pungi cu apa, vreo doua sticle, un scutec de copil, si alte cca 32 de obiecte neidentificate. Prosti lunetisti! Un fleac, nici macar nu m-au ciuruit. Sar ca un cerb 16 metri mai in spate, si ma uit nedumerit in jur. Fac o corelatie destul de SF dintre televizorul care inca mai fumega, covorul de cioburi de pe jos, multimea in delir care racnea de la etaje, si patria mea care o luase pe coaja, ca de obicei. Mai stau pret de cateva minute sa ii vad pe altii cum o fura original (nu toti au fost la fel de pe faza ca mine, si unul cu gajica-sa chiar facuse un dush scurt), dupa care o iau pe langa caminul doishpe, si zig-zaghez prin foc prin shpagi prin glonti prin fum pana ajung sa intru in camin prin partea cu salile de lectura (coltul dinspre caminul 17), teafar si nevatamat. Urc intr-un suflet scarile, semnalizez si depasesc patru camarazi de arme care se kinuiau sa urce un frigider pana la etajul opt, aveam sa aflu mai tarziu, si intru in camera de vizavi, aia care dadea inspre intrarea in camin.\r\n\r\nMai, frate, mai, ce am vazut de acolo intrecea orice carte de Asimov. De sus, de la etaje, se aruncau orice fel de lucruri care puteau sau nu puteau fi aruncate. Sticle de bere, borcane cu zacusca inflorita, cutii de plastic cu pilaful de acum doua saptamani, pungi cu apa, coji de cartofi, pixuri, ceapa, pantofi scalciati, inca un televizor, doua chiuvete care s-au facut tzandari pe pavaj, o tzeava de dush, un pat, o saltea care a aterizat pe acoperisul de deasupra intrarii si a ramas acolo, innegrita de la ploaie, pana anul urmator, carti, cursuri arzande diafan prin aer, izmenele de asta-iarna, vreo patru coshuri de gunoi de plastic rosu, un lighean portocaliu, tacamuri, paine mucegaita, frigiderul de la etajul opt, tot gunoiul de pe palier, blugii vechi ai colegului de camera, cojile de la ceapa, mamaliga scorojita, rezerva de slanina. In orice moment pluteau prin aer cel putin 2-3 chestii, care cadeau pe pamant cu o cadentza de una la 2-3 secunde. Portarul a iesit afara si a incercat sa urle, dar si-a dat seama ca are toate sansele sa moara ca un erou din filmele coreene care se lupta cu invadatorul japonez, asa ca s-a refugiat rapid inapoi in camin, dupa ce eschivase, tinereste, cateva proiectile. Asteptam cu interes sa vedem si primul cosmonaut sarit din camin, dar nu am avut noroc. Cert este ca intreg cheful a durat de la 7 fara vreo 20 pana seara la 9,30, cand efectiv nu se mai vedea nimic afara. Si nu mai era cool sa arunci nimic daca nu ii puteai urmari triectoria. Mai ales ca aparuse si garcea de Hasdeu sa investigheze.\r\n\r\nDupa o jumatate de ora, am coborit cu Stelica sa bem o bere in Nico. Jur ca talpile mele nu au atins asfaltul, care oricum nu se vedea sub covorul de cioburi, pungi si hartii moarte. Si am facut si poza pe frigiderul cazut la datorie, dar trebuie scanata.','Cum a luat Romania bataie de la Croatia',0,'','publish','open','open','','cum-a-luat-romania-bataie-de-la-croatia','','','2007-03-12 22:58:45','2007-03-12 20:58:45','',0,'http://www.groparu.ro/?p=40',0,'post','',4),(41,1,'2007-03-12 23:02:10','2007-03-12 21:02:10','<dl class=\"body\"><dt class=\"post-head\">So, we decides to go on this trip, right? </dt><dt class=\"post-head\">Â </dt><dt class=\"post-head\">Me and some of me buddies, right? So, we do it. I says, we do it, and we done it. And everybody says we do it, and we done it! Right now we\'re right at the end of it, in dear Bratislava, the beloved European capital with cheaper beer than Cluj. But before, we has to cross the Slovenian border, and we has to stop at this capital city, called Ljublijana (nice city, by the way). And so we says, since we\'s decided to do it, why not sip a beer or two in Slovenia? And so by God we decided. And so by God almighty we did. We just headed out to the first pub that emerged from amidst old buildings and outdoor advertising. And so we goes in, and we orders. Four beers, and nothing less. And we waits. And then ze devil on me right shoulder spake: \"Yo, brother! Wasssaaaaa... why not play a trick or smth, like a good brother! Why, it\'s the first of April! Your day!!\" And then my left shoulder angel comesÂ  out in a fluffy cloud, yelling: \"True!True!\" And I says, like good old Zorba: \"Who the hell am I to choose?\" And so I goes to the tender - bartender, that is - and I says: \"Yo, brother, you and I, u know, u and I, yo, we were meant to be together, bro! So here\'s the thingie: see that table with those funny looking characters who couldn\'t even star the film on their own life, dawg? So, here\'s the deal: you, my man, you hand them, I mean, really hand them a fake bill, u know whatt\'I\'m sayin\'? You just do that. Produce a fake bill worth 200 freakin\' euros for that shit you just brought us over, and we\'ll have some good time!\" And zen ze friikin\' tender - bartender, that is - looks at me and sez \"I am sorry! Ich bin not allowed to do that! It is against club hrrre... hrrre... hrregulationz!\" \"Yo, bro, says I, u know what, do the right thin\', bro! Here\'s the deal: u just produce a fake hand-written bill, and I myself with my own both right arms will hand it over to my colleagues, is that cool to you? C\'mon, bro, gimme smth!\" And he says: \"Ich can trhhry\" \"At a boy, spake Radu, at a boy. Me knew you and I had this thin\' goin\' on between you and me, u know whatt\'I\'m sayin\', u and me? \'Course u do, you even look smart. U just lemme know when you wants to do it\", so I walk back to the table, only to return a minute later and say \"Bro, u knows what? Just make it 90 euros, that\'s more down to earth, or something\", and I winks at him. And he winks back, with a sadistic smile. And 10 minutes later, when we ask for the bill, ze guy hands it over to me, and I produce the biggest eyes the size of onions Ljublijana has ever seen: \"My, oh, my, this looks pretty expensive!\" And with a nervous grim I hand it over to ze guyz. And they looks at it, and they goes all at once: \"Freaaaaaakiiin\' huuuuge biiiiilllll\" And believe me, that was no Monica talking about no Bill Clinton, no, they wasn\'t! So I start chuckling and I grabs me camera, and I puts it all on film. And so they spends 8 minutes comparing prices on the menu to prices on the bill, they are! </dt><dt class=\"post-head\">Â </dt><dt class=\"post-head\">Â </dt><dt class=\"post-head\">And then I laughed on their faces, on their faces I did, \'cause they deserved it! And some of them even deserved communism, 50 years, they did!</dt></dl>','This year\'s 1st of April',0,'','publish','open','open','','this-years-1st-of-april','','','2007-03-12 23:02:10','2007-03-12 21:02:10','',0,'http://www.groparu.ro/?p=41',0,'post','',0),(42,1,'2007-03-12 23:07:19','2007-03-12 21:07:19','So, he walks into the questioning room, sits down with a sigh, places his papers on the table, and blinds me with the lamp.\r\n\r\n- You see, Radoo, it\'s nothing personal. But you\'ve been on this trip through half of Europe and we just need to ask you a bunch of questions. You realise at this stage you are denied the right to any legal representative. Is that OK with you?\r\n- Sir, as much as I love my country, which I don\'t, except for its people, rivers, mountains, Sibiu, UBB, the dorms in the campus, the friends I\'ve got here and quite a million other stuff, like my family and the really really cheap beer, I do believe this inquiry to be useless. I did not expose any national secrets, ask for political asylum or any such shit.\r\n- Let\'s start with the very beginning, Mr Bazavan, aka \"Groparu\", as some of your friends like to call you. And I would really appreaciate if you dropped any colloquialism from your language... you see, us here at the Intelligence Service do not take kindly to the likes of you, foul-speakers. You started off to... Amsterdam, if I recall, is that right?\r\n\r\nGee, it seemed almost real! 2 weeks off work, paid leave, a whole European map to scour with Amsterdam as the G-spot, a reliable (yeah, right) car with decent consumption (just 14 litres/100km, at times of ~70USD/oil barril), some cash to dispose of, nice sidewalks, expensive beer, a page ripped off Josh\'s passport, the rest of us Europeans with Romanian passports... Yes, it almost seemed real. Now I realize it was just in my imagination.\r\n\r\n\r\n<strong>Day 0. Where the #$%^&amp;*() is my passport?????</strong>\r\nIt\'s 4 o\'clock in the morning and I can\'t seem to find my passport, after a desperate 4 hours\' search through my socks supply, stash of CDs, google... whatever. Am I going to Amsterdam, after all? I haven\'s been so pissed in a looong time. Eventually it turns out the American dude has it. Long hours of waiting, he\'s not answering the phone to confirm.\r\n\r\n\r\n<strong>Day 1. Take off</strong>\r\nFound my passport. We set off 6 hours later than originally planned. Tibby\'s front seat is busting my knee caps, and he does not understand plain Romanian when I tell him to pull it forward. We have no jack for the car in case we have a flat tyre, no tool box, notÂ  even a screwdriver, and when I myself pull Tibby\'s seat forward to make more room for my long legs (for he does not understand Romanian, again) Josh exclaims \"Wow, we have a first aid kit!\" with reference to the black box sliding from underneath the seat. Dunno why, but I\'m growing anxious with this trip. We arrive at the border. The guard frowns at our passports (gee, that\'s new! never seen a bordergurd frown before in my life.) He then asks: where\'s the page? Bribe, I think, greedy bastard! bribe. And I have no change, and I bet the others don\'t have it either. Josh grins: ah, ze page? Here it is! And he miraculously extracts from his wallet a page that had been ripped off from his American passport, and he hands it to the guard. Hmmm, I see, pursues the borderguard. I do see. Duuuude, we rage at him and the machine, why didn\'t you tell us you had a ripped page from your passport? It wouldn\'t have changed anything, he says. We was still going in the trip no matter what! And besides, that\'s an American official business Romanians should never get involved into. Capiche?\r\n\r\nSo we drive on, cross the Hungarian frontier uneventfully and finally feel at home, in the heart of Greater Romania. We drive on, and on, and on, and dawn cracks. And since Tibby is always hungry, we have breakfast at a Hungarian petrol station (home-made sandwiches from the trunk) and eveybody is staring at us like we were Romanians having breakfast in a petrol station (home-made sandwiches from the trunk.) And we couldn\'t care less, since we had a whole Europe to scour. And then we drive on, and we get lost. And seeing how stupid we looked, an indigen walks to us and says something in Hungarian. We say \"Nie panimayu!\", and then he says \"Unde vreti sa mergeti? Ljublijana? A, o luati la stanga si tineti taaat inante!\" We thank the friendly Romanian-speaking native, and we head on. And we exit Hungary.\r\n\r\nBut first - we transit the Hungarian border again. What in the world are three retarded Romanians doing in a car with an American driver doing here, in no man\'s land? They must be really rich, thinks the guard, since they can afford an American driver for - I\'m sure - no less than 20$/hour. Lemme see your passports. And he sees the passports, and Josh, polite, as usual, goes: If you want the missing page, it\'s right here, officer, and he hands him the pitiful sheet. Ever seen a fat borderguard laugh his lard out? Make that two, for he\'s calling in a colleague to see it. They look conspicuous, they decide, let us see your bags. Sure, officer, goes I in my best German whose only words are <em>toilet</em>, <em>I\'m hungry</em>, and <em>Hey, wanna fuck? </em>Whose bag is this? Mine, says I. Take it out. Shoo, goes I, I only have food and cigarettes, plenty of them! And I unpack. Cigarettes everywhere. And cans. My hands are shaking. We are not supposed to bring non-EU food inside. What do you have here? I get pissed. Condoms, says I. Condoms? Yeah, condoms. The kind you roll down your erect penis while holding the upper tip with your thumb and index finger. Wanna see them? No, says the guard, turning to his colleague, they don\'t look like no terrorists to me, look how lame they are. You can go now. Off! You\'ve wasted my country\'s vital supply of oxygene for too long now, and we have no mountains here, yeah, I know, it kinda sucks. But our GDP is still 20 times more than Romania\'s, so we\'re still better off, you and your rivers, mountains, Sibiu, UBB, the dorms in the campus, the friends you\'ve got there and quite the million other stuff, like the really really cheap beer. And besides, this Tibby friend of yours looks realy hungry, feed him, for Christ\'s sake! Yes, sir, boss, sir, aback horsepower we\'re a-riding, says I, c\'mon, guys, let\'s hit the road.\r\n\r\nAway we go, and we hit the border. Slovenian border. Amazing, Slovenian border guards wear Hungarian uniforms! And they speak Hungarian, too! Where are you going? Ljublijana, says we. Can\'t go to Ljublijana. Why, it is closed this time of the year? Funny guy wanna die, screeches the border guard, this here is the Hungarian border. To go to Ljublijana you have to go back, and turn left or right at the circle you\'ve just passed. How on Earth did you think the Slovenian border is 7 kilometres away from the Hungarian border? It makes more sense than having two Hungarian borders 7 km away from each other, thinks my right lobe, but my mouth is inspired enough to refuse to utter. Thank you, sir, we are most obliged. And by the way, says the guard, is your friend alright? \'Cause he looks kinda hungry to me.\r\n\r\n19 minutes we spend driving around in circles. I guess road signs were not invented in that country.\r\n\r\n- Officer, I pause, the Ljublijana episode is in my previous blog entry, do you want me to go through that again?\r\n-No, just carry on. You arrived in... Venice, is that correct?\r\n\r\nVenice. What a lovely city! Gondolas, Italians, cigarette buds everywhere. And water. And bridges. We head out for a snack. I order what on the menu read sea horse, but it turns out it\'s just horse meat. I do hope it\'s someody\'s pet, thinks my stomach while I\'m gulping. Or a stud. Preferably both.\r\n\r\nWe take British Rob over with us. Probably Italians are really crappy (which they\'re not) since he\'s so exhilarated to see us. We hug a minute longer than decency allows. But we\'re going to Amsterdam, the European capital of sex and gay pride, so we\'re just warming up. But first - we must hit Bologna, where we\'ll spend the night at Claudiu\'s friend. Not Bologna proper, but a world-renowned little place called I-can\'t-remember-the-name, and-I\'m-prety-sure-its-inhabitants-can\'t-either. And again I\'m amazed at how fast Italians speak, especially since the only words I know in Italian are <em>Yes, I think gay is ok</em>, <em>horse meat</em>, which to me sounds like sea horse, <em>Rroma</em>, and <em>pizza</em> <em>quattro formaggi, ti prego</em>. Nonetheless, I am the designated linguist of the road trip, so I have to squeeze my brains real hard to remember the Italian I knew when I was watching Canale 5 shows hosted by huge titted porn stars. But we manage to reach our destination, not before getting lost 14 times. Thank God for huge titted TV hosts and a really, really horny adolescence.\r\n\r\n\r\n<strong>Day 2. Headlong to Amsterdam via Milan</strong>\r\nWe exit Claudiu\'s friend\'s house, not before a generous meal (thank you, Claudiu! Be sure to charge Tibby for all he ate, \'cause he sure ate like a carnivorous elephant), and we drive to Milan. Gaping, we was! Cool, cool city. We find a store with incredibly cheap unconfortable shoes, and we buy two pairs each. We receive fliers with next week\'s elections, and we decide to vote for that very party. Then we see a concert with really pretty dancing girls, and we decide to vote for their party, too. And then we decide to vote for the communists as well (yes, there is an Italian Communist Party!), and then with Mussolini\'s granddaughter, herself the leader of right-wing party, \'<a href=\"http://www.iconlandia.it/foto/alessandra_mussolini.asp\">cause she looks kind of hot</a>. Then we decide to make our own American-British-Romanian leftist-centrist-right-wing party, and become MPs and hire only hot lesbian secretaries and rig tenders and get indecently rich and feed Tibby all he wants. Then we leave before any other evil happens.\r\n\r\nWe reach Switzerland at night. Bordergurds speak French worse than I can, which indeed is a record. They warn us of the 30E motorway tax. Romanian is what Romanian does at the American\'s \"suggestion\", so we just cross Switzerland majestically - without paying. And we hit Amsterdam the next noon.\r\n\r\n\r\n<strong>Day 3, 4, 5. Amsterdam </strong>\r\nNothing really worth telling. Really, nothing.\r\nAn African-Amsterdamian is tempting us with coke. Tibby jumps \"Can you order fries and chicken breasts with that, too?\" but soon realizes the guy was not selling the kind of coke he wanted. We get our car booted and we pay 100E in fine. Amsterdam is where British Rob has to leave us. So long, bud!\r\n\r\n\r\n<strong>Day 6, 7. Bruxelles, then Bad Harzburg</strong>\r\nBruxelles. Hmmm. That\'s where all the EU money goes, right? Yeah, that\'s right. Despite its friendly people, we get lost for 4 hours, but we manage to get out in the middle of the rush hour. We are bound to get to my sister in due time, \'cause I wanna surprise her. And my German brother-in-law. And my two sweet little nephews. And I talked to my sister\'s sister-in-law to make sure they are at home, with warm food for Tibby. And we get to Bad Harzburg, and the Police car driving by is looking at us with the biggest eyes the size of onions Bad Harzburg has ever seen. And I rush to them toÂ  show them just how friendly we are with the indigens. And I tell them I want to get to see my brother-in-law. In return, they say our car\'s hind lights are not working. I\'m telling them I don\'t speak such good a German and I don\'t understand (playing the dumb tourist, I was!) They say they drive us to my brother-in-law provided we spend the night there and we get the car fixed in the morning. My knowledge of German somehow miraculously gets back to me I say: \"Officer, you just got yourself a deal!\" What\'s in it for me, is my right lobe asking, but again my mouth refuses to comply. He is driving us to my sister\'s home, and we scare the living hell out of her, walking inside shrieking \"Multi Ani Traiascaaaaa\" (it was my brother-in-law\'s B-day), looking like all the shit in the world, after a 14 hours\' journey, and withÂ  hungry Tibby who was fancying to eat a full whale with any crunchy <em>hors-d\'oeuvres</em> he could find - pencils, shoes, us.\r\n\r\nStrange how time flies, we have to get going to Zirndorf, at Tibby\'s friend, not before Tibby swallows up all the food in the house and leaves my sister threatening to call <em>Kriminal Polizei</em> if we don\'t scram, buster.\r\n\r\n\r\n<strong>Day 8. Zirndorf\r\n</strong>Just in case your knowledge of geography amounts to 33 grams,Â Zirndorf is a small town in Germany. Germany is a big country in Europe, which in its turn is a small continent on a planet called Baza, in the Bazavan galaxy. Also, just in case you didn\'t know, for some people \"crane\" is the same with \"bulldozer\", \'cause in order to find him Tibby\'s friend told us to look for the former while he actually meant the latter.\r\n\r\n\r\n<strong>Day 9. Salzburg\r\n</strong>Straight to Salzburg we go! For all of you geography illiterates, Salzburg is a city in Austria, notÂ  Germany, as I mistakenly wrote in a cover letter which cost me a scholarship there in my senior year in college. Salzburg is the kind of city I want to live in. Mozart, cool tourists, mountains, statues, Mozart, music, fortresses and castles, and Mozart, monuments, memorials, Mozart, Mozart, Mozart and - again, you guessed it - Mozart. Oh, yes, and Mozart was <strong>Austrian</strong>, not <strong>German</strong>, as I again wrote in the same cover letter which I\'m sure must have gotten the admission board rolling on the floor with laughter, although I do believe they wouldn\'t have felt so comfortable if I had asked them where Zirndorf or <a href=\"http://www.listafirme.ro/harta/poplaca.htm?id=2619\">Poplaca</a> was! So long, Salzburg! You\'ve left me with a picturesqe image and a horrible indigestion from the freakish expensive sea food I ate there. And I bet there was no sea horse in the sea mix, either.\r\n\r\n\r\n<strong>Day 10,11,12. Bratislava</strong>\r\nAs we were riding our vehicle towards friendlier Romanian soils, Tibby goes out saying what everyone felt: Dudes, let\'s go and see Bratislava! Bratislava is just a right turn from Austria, and there we go, and we set foot there, and we stroll, and we take pictures. I love the Slovenian capital, goes I, look, they even have <a href=\"http://en.wikipedia.org/wiki/Image:Petr%C5%BEalka_apartment_blocks_in_Bratislava.jpg\">blocks</a> just like <a href=\"http://ro.wikipedia.org/wiki/Imagine:Manastur_3.jpg\">Manastur</a>! Let\'s go have some Slovenian beer. Can I have some Slovenian beer, please, I ask a cute waitress whose eyes roll out into the biggest onions Bratislava has ever seen. Sure you can, <a href=\"http://en.wikipedia.org/wiki/Strabo\" style=\"font-weight: bold\">Strabo</a>, you father of geography, my friends tell me, only THIS IS SLOVAKIA, WHICH IS JUUUUUST A BIT DIFFERENT FROM SLOVENIA! And Budapest is not the same with Bucharest, you know, which in its turn is different from Belgrade! I hate geography, I retort (I don\'t, but there was nothing else for me to say), and you can\'t expect me to know how to tie my shoes <strong>and</strong>Â know where I am at the same time! Dude, that\'s common knowledge, they say.\r\n\r\nWe have our beer, and away we go, \'cause we wanted to get home to Cluj in the morning. But - I won\'t tell you what happened at the border, only the fact that the prickiest, son-of-a-bitchiest, bastardest Hungarian border guard denied us the entry. Take a guess why? Here\'s a hint: a particular missing page from a particular passport which happened to belong to a particular American guy who was riding in a particular car we were in, too. Deny the entry - that\'s OK, I guess, no underling with ripped passports should be allowed to defile the green meadows of Hungary. But his on purpose bitchy way he had us return, and his refusal to speak anything else than Hungarian to us to justify such a measure is I think worthy of a <strong>FUCK YOU!</strong> from the bottom of my heart, especially since his colleagues one week ago had not sen this as a threat to world security and peace.\r\n\r\nAnyways, we drive back to Bratislava to the consulate to change the passport, and we can\'t help feeling like lowlife gypsies (that\'s why I am totally against discrimination, for I have been discriminated against in the past.) And there we stay for three long days waiting for Josh to solve his passport issue, and all we do is prevent our kidneys from gettign sick by staying 12 hours a day in the <a href=\"http://www.slovakpub.sk/\">Slovak Pub</a> in Bratislava and sipping on their delicious beer. Some voices say these days were lost, but I say on behalf of our kidneys these days were gained, especially if I ever want to sell one for a good price. I especially liked the friendly people - former communist block, just like us. So friendly, that when we had to bribe the Slovakian border guard with 50E for not having paid the road tax I felt the guy was actually doing me a favour.\r\nAnyways, we eventually cross the Hungarian border (with more incidents again that I would like to remember, but I really felt like killing somebody with the death of a thousand cuts!) and we head straight to the booth to buy a vignette for Hungarian roads (all at our friend\'s Slovakian border guard\'s advice.) Again we get this nasty feeling of not being wanted - the booth worker literally slams the door in Josh\'s nose and refuses to give us a vignette for God knows what reason, after having him wait in the wind for 4 minutes, 46 seconds, andÂ 98 decimals. They can\'t be all like that, we think, and fortunately we meet a very friendly staff at a OMV petrol station despite our communications issue. There! Now we feel better about HungaryÂ <img src=\"http://us.i1.yimg.com/us.yimg.com/i/mesg/tsmileys2/03.gif\" alt=\"Image\" />\r\n\r\nWanna know how we crossed the border? I bought myself 3 litres of whiskey from the duty free, which I intend to drink all by myself as soon as an opportunity pops in.\r\n\r\n\r\n- Long story, says the intelligence officer, stifling a yawn. And you expect me to believe all this?\r\n- It\'s all in the picures, anyways. Now if you\'ll excuse me, I have a sleep to catch and a long way to go tomorrow: my parents are dying to see the pictures with my nephews. Oh, and by the way: just wanted to know I don\'t hold any grudge against anyone. It\'s been a wonderful trip which you ought to make sometimes.\r\n- So you haven\'t told them <em>the secret</em>, he said. Very good. That\'s very good. You are free to go now.','EuroTrip',0,'','publish','open','open','','eurotrip','','','2007-03-12 23:08:30','2007-03-12 21:08:30','',0,'http://www.groparu.ro/?p=42',0,'post','',0),(43,1,'2007-03-12 23:13:57','2007-03-12 21:13:57','<a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/micutzu.jpg\" title=\"Micutzu\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/micutzu.jpg\" alt=\"Micutzu\" /></a>\r\n\r\nEra in anu de gratie nu mai stiu care, io elev, tocmai ma barbieream printre primele dati, Mitroa elev, urma sa se barbiereasca pentru prima data mult mai tarziu. Io cu bani, el fara bani, eu cu sora in Jermania, el cu sora mai mica ca el, ea copil reusit, el defel. Eu nu beam, nu fumam, bani in poker nu bagam. De la sora marci primeam. Banii nu mi-i keltuiam!\r\n\r\nVine Mitroa la mine odata si zice: Ba, zice, il stii pe Micutzu, ala pe care toata lumea-l urashte, ca e urat, mare, slab, prost, loser, ratat, betiv, negricios, gaunos, coshuros, chel, bubos, miroase a caine plouat, isi va bate nevasta si are si putza mica desi are nasu\' mare, si are o sora care seamana cu Jana Gheorghiu, aia de te-ai combinat tu la kefu\' ala cu ea, \'ai prost esti! Stii ca mi-i preten, ca io numa cu din eshtia umblu, si am acuma o afacere cu el cu sacouri furate din fabrica, mina de aur, frate, ce mai! Da\'-mi traba 20 DM imprumut, si-am vint la tine sa-ti cer ca stiu ca tu-mi dai ca ti-i mila de mine, ca ui\' la mine cum arÄƒt. Nu-s pentru mine, is pentru Micutzu\'. Hai ca nu e suma mare, numa un rucsac de-ala mare si fain iti poti cumpara de ei, haaaai, ma! Hai ca asta e in nush ce buda financiara si tre\' sa-l ajut, ti-i da inapoi in 2 luni, jur pe roshu, dacÄƒ nu imi vand bunurile.\r\n\r\nTrec doua luni, trec trei. Bani - de unde, nici sa vrei. Vine Mitroa si, pan\' sa-i sar de beregatzi, zice: ba, zice, am cam mierlit-o cu asta, futa-l in gura de prajina, ca numa\' nu mai dau de el, si tre sa iti dau banii! Ba, mai mult, mi-o zis ca il doare-n apendicita de tine si de cartieru\' tÄƒu, si ca asa fraieri ca tine nu o mai vÄƒst. Desi sunt de acord cu el, dupa cum perspectivez io, avem doua solutii.\r\n\r\n1. Vii cu mine seara, si il asteptam cand vine de la serviciu. Ne imbracam cum am vazut in \"Tigrul din Hong-Kong\", si ne lom stelutzele de Ninja. Il bushim ca pe shnitzel si ii lom portofelu, si vedem ce are in el. Nu incalcam decat vreo patru infractiuni, lovituri cauzatoare de moarte, talharie, tentativa de omor in circumstante agravante, extorcare. Scapam ca suntem minori, si poate avem noroc de ne ÅŸi incuie astia intr-o inchisoare de femei curate si parfumate.\r\n\r\n2. Vii cu mine ziua, la el acasa. Cacam un dosar plic inregistrat fictiv la Judecatoria Tribunalului Curtii De Apel Anti-Coruptie si Casatie si le spunem parintilor sa vina a doua zi de dimineatza la proces, si ca ii evacuam din imobil cu executoriu\' judecatoresc ca sa ne recuperam paguba, si vedem ce iasa! Ce zici? Fals si uz de fals, scapam in 6 luni.\r\n\r\nBa gulie, zic, e sub demnitatea mea sa atac catarge; mai ales ca suntem si doi, si asta e si slab ca un tzipar electric. In schimb, a doua varianta suna a excrocherie dublu rafinata! Hai, ca oricum io am inceput de mult sa ma cred James Bond. Cand incepem?\r\n\r\nSi lom, mancati-as, un dosar plic, pe care il stergem temeinic (era scris cu creon), si ne apucam sÄƒ caligrafiem, cu carioca<font size=\"4\"><span style=\"font-size: 10pt\"></span></font> <em>a la secretarÄƒ</em> plictisitÄƒ, rujatÄƒ violet ÅŸi Ã®mbrÄƒcatÄƒ Ã®n bluza de mohair tricotatÄƒ kiar de ea: Judecatoria Procuraturii Cabinetului, procuror Dejeu Vasile, grefier Rodica Persiflare, cauza civila 69/19nouazecisi-nu-mai-stiu-cat-era, prin prezenta sunteti convocat sa va prezentati, numele si pronumele lu\' asta, sus-numitul in calitate de pÃ¢rÃ¢t, recuperarea prejudiciului, Ã®n caz contrar Ã®nchisoare la penitenciar de la 6 luni la 3 ani. Semnat: mÃ¢zgÄƒliturÄƒ nervoasÄƒ, ref. conf. stoc. html.\r\n\r\nDouÄƒ ore mai tÃ¢rziu, sunÄƒm la Äƒsta acasÄƒ, la casÄƒ. LatrÄƒ cÃ¢inii, sculÄƒm oamenii din somn. Flavius, numa\' miere: sÄƒr\'na, zice, e acasÄƒ prelungu\'? Nu, zice tanti Ã®n capot, e la serviciu. Putem vorbi un pic? UitaÅ£i cum stÄƒ lucrurile: sÄƒ-i spuneÅ£i lu\' Äƒsta micu\' sÄƒ vinÄƒ mÃ¢ine la trebonal la 9, ca bÄƒiatu Äƒsta l-o dat Ã®n judecatÄƒ.\r\n\r\nIo am Ã®nceput sa ma scutur violent de rÃ¢s, da\' aveam totuÅŸi faÅ£Äƒ de cioclu. Tanti - albÄƒ ca un halat de chirurg de la sala de naÅŸteri. Flaviu zice: Da! da. CÄƒ i-am dat 20 de mÄƒrci acum trei luni, ÅŸi cÃ¢nd i-am cerut mi-o spus ceva foarte urÃ¢t de mama. Mama mea, zice Flavius, care de fapt e-o doamnÄƒ. Acuma - nu e bai, da\' banii Ã®s a lu\' bÄƒiatu Äƒsta, care e nepot cu procurorul Rodica Persiflare, zice mirobolantul, ÅŸi aratÄƒ spre mine. Åži mÃ¢ine se judecÄƒ cauza! CÄƒ unchiu-s-o s-o sopÄƒrat taaare mult, cÄƒ el e un om fain, cÄƒ o zis cÄƒ cazu\' asta se ÅŸi judecÄƒ mÃ¢ine, ÅŸi-l ÅŸi condamnÄƒ. Åži m-am gÃ¢ndit sÄƒ vin sÄƒ vÄƒ spun, sÄƒ ÅŸtiÅ£i ÅŸi dumneavoastrÄƒ.\r\n\r\nCred cÄƒ dacÄƒ aÅŸ fi vrut sa fac sex cu mama lu\' Micutzu\' Ã®n acel moment, si ta-su sa priveasca, ea mi s-ar fi dÄƒruit sincer ÅŸi curat, ca Ã®n noaptea nunÅ£ii, si el mi-ar fi indrumat fiecare pas, sa nu ma pierd. Dispuneam dupÄƒ bunul meu plac de doi oameni muncitori ÅŸi aÅŸezaÅ£i la locu\' lor. Eram un mic Caesar care tocmai Ã®i Ã®nvinsese pe gali - galii Äƒia din care s-or nÄƒscut mai tÃ¢rziu mÃ¢ncÄƒtorii de <em>fromage</em>. Tanti o Ã®nceput sÄƒ deÅŸurubeze verigheta, ÅŸi vru sÄƒ mi-o depunÄƒ la soclu\', s-o ÅŸi oferit sÄƒ mÄƒ spele eventual pe picioare cu mir ÅŸi cu pÄƒrul ei. TaicÄƒ-su\' o zis cÄƒ nimic nu l-ar face mai fericit decÃ¢t sÄƒ le iau Dacia din curte, fiica de soÅ£ie ÅŸi jumate de Ã®mpÄƒrÄƒÅ£ie numa sÄƒ le las copilu\' Ã®n pace. Åži amÃ¢ndoi au spus Ã®ntr-un glas cÄƒ altceva nu-ÅŸi doresc decÃ¢t sÄƒ-mi treacÄƒ casa pe numele meu, in schimbul graÅ£ierii nemernicului! Flaviu i-o oprit tocmai cÃ¢nd se ofereau sÄƒ facÄƒ ei Ã®nchisoare la penitenciar ÅŸi sÄƒ rÄƒmÃ¢nÄƒ o viaÅ£Äƒ sclavii mei, ÅŸi le-o zis: Tanti ÅŸi nenea, noi nu vrem sa va futem, deÅŸi eu nu aÅŸ zice nu unei partide cu nenea. Tot ce vreau eu e ca prietenul meu sÄƒ Ã®ÅŸi recupereze investiÅ£ia integral, ÅŸi el vÄƒ promite cÄƒ facem uitatÄƒ Ã®ntreaga afacere. Putem reveni Ã®ntr-o orÄƒ sÄƒ luÄƒm banii?\r\n\r\nÃŽntr-o orÄƒ, am pÄƒÅŸit pe cel mai roÅŸu covor de sub tÄƒlpile mele. Am luat prÃ¢nzul, am bÄƒut cu oamenii un pahar de vin excelent, deÅŸi aveam numa vreo 15 ani, ne-am Ã®mprietenit la cataramÄƒ, apoi am sunat la un numÄƒr inexistent, mi-am liniÅŸtit un unchi procuror inexistent ÅŸi l-am rugat sÄƒ nu demareze cazul inexistent, apoi, sub privirile tribale ale unor oameni tare cumsecade, am ars un dosar penal al unui caz inexistent. Apoi am Ã®ndesat 20 de mÄƒrci foarte existente Ã®ntr-un buzunar al blugilor mei din Germania - foarte existenÅ£i - ÅŸi ne-am dus la prima casa de schimb, pentru ca sÄƒ-i prÄƒpÄƒdim pe toÅ£i la un biliard foarte existent. Nu de alta, da\' cred cÄƒ ÅŸi muream dacÄƒ nu dÄƒdeam o bilÄƒ Ã®n ziua aia.','Micutzu\'',0,'','publish','open','open','','micutzu','','','2007-03-12 23:21:27','2007-03-12 21:21:27','',0,'http://www.groparu.ro/?p=43',0,'post','',0),(44,1,'2007-03-12 23:15:39','2007-03-12 21:15:39','','Mnitroa',0,'','inherit','open','open','','mnitroa','','','2007-03-12 23:15:39','2007-03-12 21:15:39','',43,'http://www.groparu.ro/wp-content/uploads/2007/03/f373.jpg',0,'post','image/jpeg',0),(45,1,'2007-03-12 23:21:11','2007-03-12 21:21:11','','Micutzu',0,'','inherit','open','open','','micutzu','','','2007-03-12 23:21:11','2007-03-12 21:21:11','',-1173733710,'http://www.groparu.ro/wp-content/uploads/2007/03/micutzu.jpg',0,'post','image/jpeg',0),(46,1,'2007-03-12 23:23:06','2007-03-12 21:23:06','','Tiganu!',0,'','inherit','open','open','','tiganu','','','2007-03-12 23:23:06','2007-03-12 21:23:06','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/tiganu.jpg',0,'post','image/jpeg',0),(47,1,'2007-03-12 23:23:22','2007-03-12 21:23:22','<a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/24-imaginile-si-zambetul-zice-totul.jpg\" title=\"24-imaginile-si-zambetul-zice-totul.jpg\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/24-imaginile-si-zambetul-zice-totul.jpg\" alt=\"24-imaginile-si-zambetul-zice-totul.jpg\" height=\"322\" width=\"427\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/55-tigan-cazut-la-datorie.jpg\" title=\"55. Tigan cazut la datorie\">\r\n</a>S-a intamplat din nou. Si a fost mai rau ca niciodata. Pe scurt, de 6 luni numaram AMR-ul. Mai avem 4 luni! mai sunt 2. Inca o saptamana si 6 ore. Pentru a fi in ton cu evenimentul, Comitetul de Organizare a Vaii Caselor s-a reunit de mai multe ori pentru a hotari detaliile organizatorice. Ma suna Flaviu marti seara, la 10: Ba, zice, am intrunit celula de criza! Ma suna doua ore mai tarziu: Ba, zice, s-a imbetat celula de criza, hihihi!!!\r\n\r\nPlec vineri la 13:30 din Cluj sa ajung cat mai repede acasa, sa prind operatiunea \"Pete pe Ficat\" editia a III-a in plina desfasurare. Iau autocarul si fiecare secunda mi se pare infernal de lunga. Fiindca fiecare secunda conteaza, vorbesc cu Utzu sa ma ia din Alba, sa ajung mai repede. Eram constant amenintat la telefon ca daca nu ajung la timp se defileaza pe centru, la Spital, la Tribunal si la Politie fara mine. Asta nu se putea intampla! Asa ca dupa artificii soferiale (saraca masina...), Utu ma depoziteaza frumos acasa. Unde leapad ciocul\' crescut de mic, de vreo 2 luni, si fiindca turbam de gelozie (anul trecut toata lumea l-a decretat pe Mitroa aka Rramon drept cel mai tigan dintre rromi) m-am hotarit sa rezolv problema mustatii mele roscovane, ca sa iasa cat mai bine in evidenta. Si am rezolvat-o vopsind-o cu Kiwi Prattico.\r\n\r\nNe sunam non-stop, colectez informatii de pe teren. Suntem la XXL, striga bulibasa. Utzu, zic, haidam! ce sa mai... O sperii pe tanti Stoian, vecina pe care am vrut sa o bat, si nu o data. Mustatza <em>a la Tiriac </em>imi gÃ¢dilÄƒ buricu\'<em>.</em> Ajungem la XXL. In parcare. Si incepem sa radem ca projtii. Nelu avea o bluza inflorata care se inkidea intr-un singur nasture, bluza de mers la nuntzi a lu\' gajica-sa, mi-am dat seama. Flaviu avea in mana o bucata de burlan, era incaltat in ciorapi rupti in calcaie si slapi chinezesti. Mustata mea mirosea a Clujana. Si radeam ca cretinii! Cipi - eternul nemultumit - se pune pe urlat la noi sa ne grabim. Ne da noua ordine ce sa facem, la mine-n tzara, Rromania! Atata ne-a trebuit! Am inceput sa zbieram ca tiganii. Masinile s-au oprit din loc sa vaza bataie intre tigani! Ah, de i-ar durea, suspina o tanti.\r\n\r\nUrmatoarea oprire - sa luam guitzÄƒtorul. 30 de kile de carne cu shorlic. Fara maÅ£e. IntrÄƒ Mitroii in piaÅ£Äƒ sub pÄƒlÄƒriile lor, efectiv toatÄƒ lumea paralizeazÄƒ! Au cules carnea moartÄƒ si au adus-o in Matiz. Mai luÄƒm ceva legume, nu se stie de ce. Si plecÄƒm la MÄƒrginean.\r\n\r\nAjungem la MÄƒrginean. ParcÄƒm in faÅ£Äƒ, pornim manelele la maxim, si intrÄƒm in curte. MÄƒrginene, zbier io, unde esti, MÄƒrginene??? Hai de da banii, ca ti-o trecut termenu! Unde esti mah??? MÄƒrginene, iesi afara ca stiu ca esti acolo! Da-mi aia 600 de euro, ca nu ti-a fi usor de nu... (cainele firmei incepe sa latre demential.) Apare o domnisorica. Frumoasa, de alfel, da cu ochii umflati de emotie, se vedeau vinisoarele purpurii, cam 43 la numar. Buna ziua, zice, printre latraturile dementiale ale cainelui. Ce buna ziua! Nici o buna ziua, zic io muscand-mi mustata si scuipand un scuipat cu gust de incaltaminte. Mie sa-mi deie banii, ca d-aia am venit! Cainele confirma latrÃ¢nd demenÅ£ia. Cine, zice domnisoara perplexa. MÄƒrginean! Stiu ca e acolo. E la toaleta, zice domnisoara, incercand sa acopere cainele care latra demential. Va rog nu mai racniti. Ce sa nu mai racnesc, zic eu demential! Io urlu cat poftesc, ca tre\' sa-mi deie banii. Banii mei! Du-te, ba, zice Flaviu, ca asta fuge pe geamu de la baie. Marginene, urla si el, nu ai cum sa scapi! Iesim sa verificam geamul de la baie, si radem ca cretinii. Intram iara. Cainele firmei latra demential, dupa care da inapoi si se ascunde sub fustele domnisoarei.  Apare Marginean, prefacandu-se ca se sterge pe maini, desi stiu sigur ca nu se spala dupa pipi, nu e genu\'. Uite-l, ma apuca pe mine racnitu\', asa strident ca <strong>mie</strong> mi se zgariau timpanele ca un cui pe tabla. Marginene, hai numa sa vorbim, ca nu-ti facem nimic!!! Hai sa vorbim. Si il lom pe sus ca pe-o mireasa, evitam privirea uimita a domnisoarei, si plecam sa \"discutam\", presarand traseul cu \"Tine-l bine sa nu scape!!!\". Bem un gat de coniac si plecam.\r\n\r\nFanfare Ciocarlie vibreaza boxele. Nici macar o privire inspre noi, nici la semafor, nici nicaieri. Ni se acorda insistent prioritate la intersectii unde nu avem dreptul. Oamenii isi privesc pantofii. Domnisoarele fac entorse de gat uitand-se in partea opusa noua. Batranii devin brusc preocupati de sacose. Luam carnatii de la macelar si ne oprim la cea mai sordida crajma din Sibiu, la \"Nelu si Klein\", vizavi de internatul de veci, cimitirul orasenesc. Ne apucam sa facem calcule financiare cu o votca Saniuta originala 100% (20.000 suta) si o bere Balea in fatza, the cheapest there is, si tanti refuza vehement 2000 ROL ciubuc. Apare cuiul din pula aka Cipi. Ce scandal iasa! Asta vrea sa plecam, si isi sustine argumentele cu trei octave mai sus. Noi vrem sa ne certam, si nu ne lasam mai prejos. Cei doi betivi seculari din stabiliment se evapora, si tanti nu mai poate sa ne zambeasca decat foarte foarte fals, ca am vazut. Plecam, nu inainte de a-i suiera fioros \"Asa-s romanii astia!!!\", si dansa se grabeste sa aprobe scuturand in cap si nechezand.\r\n\r\nUrmatoarea oprire: Rasinari, sa luam lemnul de fag, atat de util porcului la tzepusha. Carutasii ne ignora cu dispret. Se strang copiii in jurul nostru ca la masini americane. Bem. Bem mult. In mijlocul satului. Codanele ne privesc cu coada ochiului, si rad. Incalecam un cal si facem poze. Plecam. Adi se imprieteneste cu vacariul satului, bea coniac dupa el si si eu fac la fel.\r\n\r\nAjungem ragusiti de chiote in valea noastra draga. Se decreteaza rapid: \"Let the hostilities begin!\" Ne punem corturile, strangem lemne. Mituim taietorii sa ne dea cativa busteni.\r\n\r\nFacem porcu\'. Nu se face porcu\'. Mancam porc de carne cruda si sorlic sfarog pe la 3 dimineaÅ£a. Am cazut de vreo 4 ori in valea raului, la doar 40 cm de vatra foculi. Nu mai stiu daca inainte sau dupa ce incepusera astia sa faca pipi in ea. Am vrut sa il omoram pe Flaviu, nu mai stiu de ce, dar el sigur stia si oricum nu mai conta.\r\n\r\nDimineata. Dorm singur in cort, si ma visez pe Valea Caselor. Zic, Doamne, fa sa nu se mai termine visul asta! Aud pasi. Se striga: Cort Groparesc, drei wetter taft. Vant (si zineva zgaltaie cortul). Cortul rezista! Ploaie. Aud susurul vesel al unui jet de pipi stropindu-mi folia exterioara. Cortul rezista! Ceatza, si vibreaza un pÃ¢rtz. Cortul rezista! Hai ba sa-i dam cafeaua. Imi inclestez pumnii si sar in genunchi in cort. Zic in gand, Doamne, primul care intra o incaseaza! Domnul cu coasa ma fac, jur... cineva trage fermoarul de la usa. 10 centimetri. Astept infrigurat momentul sa slobod stanga-stanga-dreapta ucigasa. Se strecoara o doza de Timisoreana inauntru. In acel moment m-am trezit de-a binelea! Si am inceput sa rad fericit.\r\n\r\nIes afara un minut mai tarziu, toata satra e la soare, ora 8 dimineatza, dezbracati. Hai ba, zic astia, tu esti prost? Poti sa bei si tu dormi ca prostu\'? Nu ba, zic io, da\' dati-mi o bere ca pe asta am beut-o.\r\n\r\nTransam porcul. Cipi e artist. Se mananca carne cruda! Jucam fotbal care degenereaza repede intr-o batalie generalizata, sub ochii altor grÄƒtÄƒriÅŸti care se uitÄƒ cu jind la valea noastra, dar se hotarasc sa plece. Toata lumea vrea in echipa cu Adi, cÄƒ are 1,90 m si bate suta de kile. Åžtergem placintele de balegÄƒ de pe teren in doi timpi si trei miscari. Stef colapseaza si adoarme, plin de muste. Il dezbracam si il acoperim cu grataru\' - sa nu-l arda soarele - si cu roata de rezerva, facem poze. Remus vrea sa facem fight club, si descopar uimit ca destiu mic de la picior e  mai sensibil decat bustenii, pietrele si masinile de care-l lovesc.  Mai ciugulim un muschiulet crud. Baie! Se striga. Paraul e mai rece ca Boboteaza. Ne stropim ca bebelusii, vine Huby: beeeeeey, muÅŸte beÅ£ive, avem bulboanÄƒ mai sus! Bulboana e cat o cada, lepadam rapid orice textila si la curu\' gol ne inghesuim partile intime in suvoiul arctic. Bem coniac si urlam ca nebunii. Murim de cald. Facem concurs care are cea mai mica putza. Toti castigam!\r\n\r\nFacem concurs de infipt cutite - am infipt cutitul in pamant cu putulica, cu buricul, cu sfarcul stang. Am iesit campion. Eu si Suciu. Avocatii se pricepe cu chestiile care taie, cum ar fi onorarii si tarife.\r\n\r\nBeau cola si sting cu whisky, colapsez in cortul meu drei wetter taft. Ma trezesc ca sunt purtat pe sus, cu cort cu tot, sunt depus si simt ca ma balansez cu spinarea pe marginea rÃ¢pei cu pipi. Sar in sus ca un taur cÃ¢nd vede roÅŸu. Mitroii! da\' astia is deja la vreo 2 metri distanta, drecu-i mai prinde! Insfac un umar si il lovesc cu fatza. Raspund cu pumnii, dau ca fetele. Bad idea. Huby tocmai ne batuse pe toti la scandenberg cu vreo doua ore inainte. Are prezenta de spirit sa nu riposteze, alfel muream de gatu\' lui. Imi inec nervii si frustrarile in alcool, ca un betiv ce sunt. A doua zi m-am purtat supect de politicos cu Huby, de s-o si gandit ca poate vreau sa-l fut in cur.\r\n\r\nRadem de Stef care incarcase sa se imbrace si o adormit cu un crac de pantaloni tras pe el. Ne jucam cu pietrele de la vatra focului si primesc o kiatra fix in fluier, ca jur am si auzit cimpoaie sunÃ¢nd, ca-n ScoÅ£ia, aÅŸa cÃ¢ntau! Am crezut ca innebunesc de durere. Dimineatza nu mai aveam nimic. Adormim.\r\n\r\nA treia zi eram cocosati, bronzati de arsi. Ne dureau pana si firele de par! Facem concurs de palmi pe spate. Ne ferim de soare ca vampirii. Facem traditionala mamaliga si tochitura, si mancam pana aratam toti ca anaconzile. Facem concurs cine musca cainii ciobanesti care ne dadeau tarcoale, dar sunt mai rapizi ca noi. Deveniseram experti in mahmureala, puteam scrie tratate intregi. Facem rapid inventarul leziunilor, eu eram deja campion de la o posta. Piciorul meu drept putea fi folosit ca motiv de pensie de boala.\r\n\r\nAu mai venit sibieni in valea noastra draga la un grÄƒtar, dar toti au pastrat distanta regulamentara. Cine dreq vrea sa-si lase copiii langa 8 masculi cu palarie, fara nici macar urma de muiere langa ei, care se joaca cutite si asculta muzica tiganeasca la maxim?\r\n\r\nAm plecat profund fericiti din Vale, locul unde timpul are mult mai multa rabdare cu tiganii. Probabil s-au mai intamplat evenimente in perioda asta, dar toti avem versiuni diferite si las in sarcina istoricilor sa dezlege itzele.\r\n\r\n...si ma doare, efectiv, FIZIC, sa-mi amintesc.\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/01-tigani-in-parcare.jpg\" title=\"01. Tigani in parcare\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/01-tigani-in-parcare.thumbnail.jpg\" alt=\"01. Tigani in parcare\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/02-tigani-in-parcare-ii.jpg\" title=\"02. Tigani in parcare II\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/02-tigani-in-parcare-ii.thumbnail.jpg\" alt=\"02. Tigani in parcare II\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/03-tiganii-si-porcul.jpg\" title=\"03. Tiganii si porcul\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/03-tiganii-si-porcul.thumbnail.jpg\" alt=\"03. Tiganii si porcul\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/04-tiganii-si-porcul-ii.jpg\" title=\"04. Tiganii si porcul II\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/04-tiganii-si-porcul-ii.thumbnail.jpg\" alt=\"04. Tiganii si porcul II\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/06-porcul-tiganilor-se-invatza-cu-lemnu.jpg\" title=\"06. Porcul tiganilor se invatza cu lemnu\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/06-porcul-tiganilor-se-invatza-cu-lemnu.thumbnail.jpg\" alt=\"06. Porcul tiganilor se invatza cu lemnu\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/07-na-du-te-sa-te-tzuce-porcu-tigane.jpg\" title=\"07. Na du-te sa te tzuce porcu, tigane!\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/07-na-du-te-sa-te-tzuce-porcu-tigane.thumbnail.jpg\" alt=\"07. Na du-te sa te tzuce porcu, tigane!\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/08-sa-nu-inerveze-careva-pe-tiganu-de-mandea.jpg\" title=\"08. Sa nu inerveze careva pe tiganu de mandea!\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/08-sa-nu-inerveze-careva-pe-tiganu-de-mandea.thumbnail.jpg\" alt=\"08. Sa nu inerveze careva pe tiganu de mandea!\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/09-tiganu-si-matizu.jpg\" title=\"09. Tiganu si Matizuâ€™\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/09-tiganu-si-matizu.thumbnail.jpg\" alt=\"09. Tiganu si Matizuâ€™\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/10-tiganu-ca-leguma.jpg\" title=\"10. Tiganu ca leguma\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/10-tiganu-ca-leguma.thumbnail.jpg\" alt=\"10. Tiganu ca leguma\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/11-tiganii-ca-legumele.jpg\" title=\"11. Tiganii ca legumele\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/11-tiganii-ca-legumele.thumbnail.jpg\" alt=\"11. Tiganii ca legumele\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/12-crajma-vizavi-de-cimitir-unde-bea-tigani-ca-noi.jpg\" title=\"12. Crajma vizavi de cimitir unde bea tigani ca noi\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/12-crajma-vizavi-de-cimitir-unde-bea-tigani-ca-noi.thumbnail.jpg\" alt=\"12. Crajma vizavi de cimitir unde bea tigani ca noi\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/13-hai-sa-ti-vindem-un-cal-tiganesc-fara-cip.jpg\" title=\"13. Hai sa-ti vindem un cal tiganesc fara cip!\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/13-hai-sa-ti-vindem-un-cal-tiganesc-fara-cip.thumbnail.jpg\" alt=\"13. Hai sa-ti vindem un cal tiganesc fara cip!\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/14-tigan-calare.jpg\" title=\"14. Tigan calare\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/14-tigan-calare.thumbnail.jpg\" alt=\"14. Tigan calare\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/15-bulibasa-calare.jpg\" title=\"15. Bulibasa calare\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/15-bulibasa-calare.thumbnail.jpg\" alt=\"15. Bulibasa calare\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/16-tiganii-bea-lapte-numa-daca-vacile-bea-coniac.jpg\" title=\"16. Tiganii bea lapte numaâ€™ daca vacile bea coniac!\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/16-tiganii-bea-lapte-numa-daca-vacile-bea-coniac.thumbnail.jpg\" alt=\"16. Tiganii bea lapte numaâ€™ daca vacile bea coniac!\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/17-noul-nostru-prekin-mai-tigan-ca-noi.jpg\" title=\"17. noul nostru prekin mai tigan ca noi\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/17-noul-nostru-prekin-mai-tigan-ca-noi.thumbnail.jpg\" alt=\"17. noul nostru prekin mai tigan ca noi\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/18-ce-pisha-tiganii-aia-de-beau-coniac.jpg\" title=\"18. Ce pisha tiganii aia de beau coniac\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/18-ce-pisha-tiganii-aia-de-beau-coniac.thumbnail.jpg\" alt=\"18. Ce pisha tiganii aia de beau coniac\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/19-let-the-hostilities-begin-pe-muzica-tiganeasca.jpg\" title=\"19. Let the hostilities begin! Pe muzica tiganeasca\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/19-let-the-hostilities-begin-pe-muzica-tiganeasca.thumbnail.jpg\" alt=\"19. Let the hostilities begin! Pe muzica tiganeasca\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/20-tigan-de-vierme-de-matase.jpg\" title=\"20. Tigan de vierme de matase\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/20-tigan-de-vierme-de-matase.thumbnail.jpg\" alt=\"20. Tigan de vierme de matase\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/21-valea-noastra-plina-de-muzica-tiganeasca.jpg\" title=\"21. Valea noastra plina de muzica tiganeasca\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/21-valea-noastra-plina-de-muzica-tiganeasca.thumbnail.jpg\" alt=\"21. Valea noastra plina de muzica tiganeasca\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/22-porcu-tiganesc-incepe-indeplinirea-misiunii.jpg\" title=\"22. Porcuâ€™ tiganesc incepe indeplinirea misiunii\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/22-porcu-tiganesc-incepe-indeplinirea-misiunii.thumbnail.jpg\" alt=\"22. Porcuâ€™ tiganesc incepe indeplinirea misiunii\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/23-porc-pe-umar-de-tigan.jpg\" title=\"23. Porc pe umar de tigan\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/23-porc-pe-umar-de-tigan.thumbnail.jpg\" alt=\"23. Porc pe umar de tigan\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/24-imaginile-si-zambetul-zice-totul.jpg\" title=\"24. Imaginile si zambetul zice totul!\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/24-imaginile-si-zambetul-zice-totul.thumbnail.jpg\" alt=\"24. Imaginile si zambetul zice totul!\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/25-porc-tiganesc.jpg\" title=\"25. Porc tiganesc\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/25-porc-tiganesc.thumbnail.jpg\" alt=\"25. Porc tiganesc\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/26-nu-il-mai-prajim.jpg\" title=\"26. Nu il mai prajimâ€¦\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/26-nu-il-mai-prajim.thumbnail.jpg\" alt=\"26. Nu il mai prajimâ€¦\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/27-valsul-tiganesc.jpg\" title=\"27. Valsul tiganesc\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/27-valsul-tiganesc.thumbnail.jpg\" alt=\"27. Valsul tiganesc\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/28-orgie-in-stil-rrom-anesc.jpg\" title=\"28. Orgie in stil rrom-anesc\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/28-orgie-in-stil-rrom-anesc.thumbnail.jpg\" alt=\"28. Orgie in stil rrom-anesc\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/29-orgie-in-stil-rrom-anesc-ii.jpg\" title=\"29. Orgie in stil rrom-anesc II\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/29-orgie-in-stil-rrom-anesc-ii.thumbnail.jpg\" alt=\"29. Orgie in stil rrom-anesc II\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/31-porc-tiganesc-crestat-pt-usturoi.jpg\" title=\"31. Porc tiganesc crestat pt usturoi\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/31-porc-tiganesc-crestat-pt-usturoi.thumbnail.jpg\" alt=\"31. Porc tiganesc crestat pt usturoi\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/32-incepe-marea-sfaraiala.jpg\" title=\"32. Incepe marea sfaraiala\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/32-incepe-marea-sfaraiala.thumbnail.jpg\" alt=\"32. Incepe marea sfaraiala\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/33-pic-pic-stalactita-de-slanina.jpg\" title=\"33. Pic, pic, stalactita de slanina!\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/33-pic-pic-stalactita-de-slanina.thumbnail.jpg\" alt=\"33. Pic, pic, stalactita de slanina!\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/34-imagine-explicita.jpg\" title=\"34. Imagine explicita\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/34-imagine-explicita.thumbnail.jpg\" alt=\"34. Imagine explicita\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/35-ranjet-imposibil-de-reprodus.jpg\" title=\"35. Ranjet imposibil de reprodus\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/35-ranjet-imposibil-de-reprodus.thumbnail.jpg\" alt=\"35. Ranjet imposibil de reprodus\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/36-trei-doamne-si-toti-trei-insetati.jpg\" title=\"36. Trei, doamne, si toti trei insetati!\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/36-trei-doamne-si-toti-trei-insetati.thumbnail.jpg\" alt=\"36. Trei, doamne, si toti trei insetati!\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/37-nu-suntem-vegetarieni-nici-nu-vom-fi.jpg\" title=\"37. Nu suntem vegetarieni. Nici nu vom fi\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/37-nu-suntem-vegetarieni-nici-nu-vom-fi.thumbnail.jpg\" alt=\"37. Nu suntem vegetarieni. Nici nu vom fi\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/38-manca-i-ai-coada-nelule.jpg\" title=\"38. Manca-i-ai coada, Nelule!\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/38-manca-i-ai-coada-nelule.thumbnail.jpg\" alt=\"38. Manca-i-ai coada, Nelule!\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/39-cocoshat-de-atata-munca.jpg\" title=\"39. Cocoshat de atata munca\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/39-cocoshat-de-atata-munca.thumbnail.jpg\" alt=\"39. Cocoshat de atata munca\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/40-nelu-suciu-tigani-porc-love.jpg\" title=\"40. Nelu, Suciu, Tigani, Porc, Love\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/40-nelu-suciu-tigani-porc-love.thumbnail.jpg\" alt=\"40. Nelu, Suciu, Tigani, Porc, Love\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/41-parca-tai-din-saddam-asa-mi-place.jpg\" title=\"41. Parca tai din Saddam, asa-mi placeâ€¦\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/41-parca-tai-din-saddam-asa-mi-place.thumbnail.jpg\" alt=\"41. Parca tai din Saddam, asa-mi placeâ€¦\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/42-imagine-exxxplicita.jpg\" title=\"42. Imagine exxxplicita\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/42-imagine-exxxplicita.thumbnail.jpg\" alt=\"42. Imagine exxxplicita\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/43-ce-daca-arde-si-stomacu-meu-tiganesc-arde.jpg\" title=\"43. Ce daca arde! Si stomacuâ€™ meu tiganesc ardeâ€¦\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/43-ce-daca-arde-si-stomacu-meu-tiganesc-arde.thumbnail.jpg\" alt=\"43. Ce daca arde! Si stomacuâ€™ meu tiganesc ardeâ€¦\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/44-tiganii-mananca-cu-ochii-gura-nasul-urechile.jpg\" title=\"44. Tiganii mananca cu ochii, gura, nasul, urechile..\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/44-tiganii-mananca-cu-ochii-gura-nasul-urechile.thumbnail.jpg\" alt=\"44. Tiganii mananca cu ochii, gura, nasul, urechile..\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/45-pe-nailon-sa-nu-ne-murdarim-cu-iarba.jpg\" title=\"45. Pe nailon, sa nu ne murdarim cu iarba\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/45-pe-nailon-sa-nu-ne-murdarim-cu-iarba.thumbnail.jpg\" alt=\"45. Pe nailon, sa nu ne murdarim cu iarba\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/46-oare-tiganu-asta-se-gandeste-la-ceva-sau-oare-numa-sta.jpg\" title=\"46. Oare tiganu asta se gandeste la ceva, sau oare numaâ€™ staâ€¦\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/46-oare-tiganu-asta-se-gandeste-la-ceva-sau-oare-numa-sta.thumbnail.jpg\" alt=\"46. Oare tiganu asta se gandeste la ceva, sau oare numaâ€™ staâ€¦\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/47-bulibasa.jpg\" title=\"47.Bulibasa\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/47-bulibasa.thumbnail.jpg\" alt=\"47.Bulibasa\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/48-tigan-mort-de-beutura.jpg\" title=\"48. Tigan mort de beutura\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/48-tigan-mort-de-beutura.thumbnail.jpg\" alt=\"48. Tigan mort de beutura\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/49-stau-tigani-la-foc-focu-i-la-mijloc-huby-cu-ghioc.jpg\" title=\"49. Stau tigani la foc, focu-i la mijloc, Huby cu ghioc\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/49-stau-tigani-la-foc-focu-i-la-mijloc-huby-cu-ghioc.thumbnail.jpg\" alt=\"49. Stau tigani la foc, focu-i la mijloc, Huby cu ghioc\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/50-natura-moarta-de-beata.jpg\" title=\"50. Natura Moarta. De beata\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/50-natura-moarta-de-beata.thumbnail.jpg\" alt=\"50. Natura Moarta. De beata\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/51-tiganii-mananca-carne-cruda-post-transare.jpg\" title=\"51. Tiganii mananca carne cruda, post-transare\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/51-tiganii-mananca-carne-cruda-post-transare.thumbnail.jpg\" alt=\"51. Tiganii mananca carne cruda, post-transare\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/52-tigan-cu-carne-cruda-in-gura.jpg\" title=\"52. Tigan cu carne cruda in gura\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/52-tigan-cu-carne-cruda-in-gura.thumbnail.jpg\" alt=\"52. Tigan cu carne cruda in gura\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/53-maini-tiganesti-flamande-burti-tiganesti-insetate.jpg\" title=\"53. Maini tiganesti flamande, burti tiganesti insetate\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/53-maini-tiganesti-flamande-burti-tiganesti-insetate.thumbnail.jpg\" alt=\"53. Maini tiganesti flamande, burti tiganesti insetate\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/54-natura-moarta-tiganeasca-cu-paine-alba-si-balega-vie.jpg\" title=\"54. Natura moarta tiganeasca cu paine alba si balega vie\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/54-natura-moarta-tiganeasca-cu-paine-alba-si-balega-vie.thumbnail.jpg\" alt=\"54. Natura moarta tiganeasca cu paine alba si balega vie\" /></a>\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/55-tigan-cazut-la-datorie.jpg\" title=\"55. Tigan cazut la datorie\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/55-tigan-cazut-la-datorie.thumbnail.jpg\" alt=\"55. Tigan cazut la datorie\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/56-la-umbra-de-cruce-deasa.jpg\" title=\"56. La umbra de cruce deasa\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/56-la-umbra-de-cruce-deasa.thumbnail.jpg\" alt=\"56. La umbra de cruce deasa\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/57-daca-berea-sta-vertical-e-suficient.jpg\" title=\"57. Daca berea sta vertical, e suficient!\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/57-daca-berea-sta-vertical-e-suficient.thumbnail.jpg\" alt=\"57. Daca berea sta vertical, e suficient!\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/58-doamne-nu-l-omori-acum-pe-robul-tau-tigan-ca-si-mor.jpg\" title=\"58. Doamne, nu-l omori acum pe robul Tau tigan! Ca si morâ€¦\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/58-doamne-nu-l-omori-acum-pe-robul-tau-tigan-ca-si-mor.thumbnail.jpg\" alt=\"58. Doamne, nu-l omori acum pe robul Tau tigan! Ca si morâ€¦\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/59-trec-tigani-prin-colb.jpg\" title=\"59. Trec tigani prin colb\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/59-trec-tigani-prin-colb.thumbnail.jpg\" alt=\"59. Trec tigani prin colb\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/60-gratar-cu-porc-de-tigan.jpg\" title=\"60. Gratar cu porc de tigan\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/60-gratar-cu-porc-de-tigan.thumbnail.jpg\" alt=\"60. Gratar cu porc de tigan\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/61-juganind-tiganul.jpg\" title=\"61. Juganind tiganul\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/61-juganind-tiganul.thumbnail.jpg\" alt=\"61. Juganind tiganul\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/62-tigan-rapus-de-beutura.jpg\" title=\"62. Tigan rapus de beutura\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/62-tigan-rapus-de-beutura.thumbnail.jpg\" alt=\"62. Tigan rapus de beutura\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/63-tiganoi-pe-dacioi.jpg\" title=\"63. Tiganoi pe Dacioi\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/63-tiganoi-pe-dacioi.thumbnail.jpg\" alt=\"63. Tiganoi pe Dacioi\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/64-tiganoi-in-cieloi.jpg\" title=\"64. Tiganoi in Cieloi\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/64-tiganoi-in-cieloi.thumbnail.jpg\" alt=\"64. Tiganoi in Cieloi\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/65-tigani-betivi.jpg\" title=\"65. Tigani betivi\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/65-tigani-betivi.thumbnail.jpg\" alt=\"65. Tigani betivi\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/66-tigan-beutor-nu-borasc-niciodata-rog-seriozitate.jpg\" title=\"66. Tigan beutor, nu borasc niciodata. Rog seriozitate\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/66-tigan-beutor-nu-borasc-niciodata-rog-seriozitate.thumbnail.jpg\" alt=\"66. Tigan beutor, nu borasc niciodata. Rog seriozitate\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/67-m-a-facut-muica-tigan-oltean-betzivan.jpg\" title=\"67. M-a facut muica tigan oltean betzivan!\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/67-m-a-facut-muica-tigan-oltean-betzivan.thumbnail.jpg\" alt=\"67. M-a facut muica tigan oltean betzivan!\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/68-atata-jar-aveam-si-n-burta-a-doua-zi.jpg\" title=\"68. Atata jar aveam si-n burta a doua zi\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/68-atata-jar-aveam-si-n-burta-a-doua-zi.thumbnail.jpg\" alt=\"68. Atata jar aveam si-n burta a doua zi\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/69-cine-si-cand-a-facut-poza-asta-nu-mai-tine-minte-nime.jpg\" title=\"69. Cine si cand a facut poza asta, nu mai tine minte nimeâ€™!\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/69-cine-si-cand-a-facut-poza-asta-nu-mai-tine-minte-nime.thumbnail.jpg\" alt=\"69. Cine si cand a facut poza asta, nu mai tine minte nimeâ€™!\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/70-tigan-adormit-in-plin-proces-de-imbracare-super-tare.jpg\" title=\"70. Tigan adormit in plin proces de imbracare - super tare\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/70-tigan-adormit-in-plin-proces-de-imbracare-super-tare.thumbnail.jpg\" alt=\"70. Tigan adormit in plin proces de imbracare - super tare\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/71-a-doua-zi-tiganii-se-feresc-de-soare-ca-vampirii.jpg\" title=\"71. A doua zi, tiganii se feresc de soare ca vampiriiâ€¦\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/71-a-doua-zi-tiganii-se-feresc-de-soare-ca-vampirii.thumbnail.jpg\" alt=\"71. A doua zi, tiganii se feresc de soare ca vampiriiâ€¦\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/72-tigan-urat-tigan-urat-tigan-urat-tigan-urat-tigan-urat-tigan-urat-tigan-urat-tigan-urat.jpg\" title=\"72. Tigan urat, tigan urat, tigan urat, tigan urat, tigan urat, tigan urat, tigan urat, tigan urat\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/72-tigan-urat-tigan-urat-tigan-urat-tigan-urat-tigan-urat-tigan-urat-tigan-urat-tigan-urat.thumbnail.jpg\" alt=\"72. Tigan urat, tigan urat, tigan urat, tigan urat, tigan urat, tigan urat, tigan urat, tigan urat\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/73-tigani-fermentand-departe-de-soare.jpg\" title=\"73. Tigani fermentand departe de soare\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/73-tigani-fermentand-departe-de-soare.thumbnail.jpg\" alt=\"73. Tigani fermentand departe de soare\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/74-tigan-clocind-coniac.jpg\" title=\"74. Tigan clocind coniac\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/74-tigan-clocind-coniac.thumbnail.jpg\" alt=\"74. Tigan clocind coniac\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/75-epilog-deshtiu-mi-era-ca-pruna.jpg\" title=\"75. Epilog. Deshtiu mi-era ca pruna!\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/75-epilog-deshtiu-mi-era-ca-pruna.thumbnail.jpg\" alt=\"75. Epilog. Deshtiu mi-era ca pruna!\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/76-mamaliga-tiganeasca-de-final.jpg\" title=\"76. Mamaliga tiganeasca de final\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/76-mamaliga-tiganeasca-de-final.thumbnail.jpg\" alt=\"76. Mamaliga tiganeasca de final\" /></a>','Tiganiada 2006',0,'','publish','open','open','','tiganiada-2006','','','2007-03-22 15:36:42','2007-03-22 13:36:42','',0,'http://www.groparu.ro/?p=47',0,'post','',2),(48,1,'2007-03-12 23:26:49','2007-03-12 21:26:49','<a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/maini-si-palinca.jpg\" title=\"Maini si palinca\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/maini-si-palinca.jpg\" alt=\"Maini si palinca\" height=\"364\" width=\"484\" /></a>\r\n\r\n<p class=\"content-wrapper\">Sunt mai mandru ca sunt roman decat daca as fi fost orice alta natie. La urma urmei, ultimul mare filozof \"francez\" s-a nascut la 8 km de orasul meu natal!\r\n\r\nIo zic numa\' ca noi, romanii, nu futem copii ca <a href=\"http://www.google.ro/search?q=paedophilia+catholic&amp;sourceid=mozilla-search&amp;start=0&amp;start=0&amp;ie=utf-8&amp;oe=utf-8&amp;client=firefox-a&amp;rls=org.mozilla:en-US:official\">preotii catolici</a>. Noi nu am ars evrei decat obligati. Nu am colonizat popoare primitive ca sa-i belim in numele Crucificatului. Genocidul nu ne place! Si nici razboiul, desi Mackensen si Sinan (ca sa nu mai zic de Baiazid!) cred cu tarie contrariul, dupa ce le-am tabacit posterioru\' - e drept, nu eu inca, ci bunu\' meu si bunu\' lui. Noi si gandacii de bucatarie vom fi ultimele supravietuitoare ale unui cataclism atomic. Noi avem cele mai frumoase fete din tropic. Carnatzul de aici face orice Leber sa para buburuze de strutz. Poate nu ne oprim tot timpul sa ajutam un strain care se uita dezorientat pe harta in miezu\' Clujului, da\' suntem gata sa ii oferim un pat cald si o bere rece la nevoie (parol, io fac asta fest!) Asijderea daca are Golf-ul in pana, si nu ne trebuie banii lui. Suntem chiar in stare sa ii intrebam \"La voi in tzara cum e?\", si asta zice mult. Aici in tzara masculii nu creapa de politete, si tocma\' de-asta pun pariu ca avem cu 200 milioane de spermatozoizi pe cap de pula mai mult decat are oricine de la granitza maghiara pana pe plajele Albionului. Nu ne altoim femeile decat daca ele cred cu tarie ca daca nu le batem nu le iubim. Si ne plac manelele pentru ca inca ne refacem dupa Enescu - hey, da\' macar nu ascultam Eins, zwei, Polizei! Pentru ca era cat p-aci sa numim noi imperator in Imperiul Roman, da\' Burebista o zis ca mai bine moare decat sa se amestece in politica interna a altora. Si-o si murit! Imi place despre romani pentru ca Vlad Tepes o fost roman. Pentru ca avem cea mai buna telemea din lume. Pentru ca aici numai esecurile genetice iau tzapa. Chiar si numai pentru ca nu suntem rusi. Pentru ca daca mai traia Ceausescu...\r\n\r\nPentru ca avem tigani si ii toleram mai bine decat tolereaza nemtii turcii. Pentru ca nu pornim razboaie pentru titei. Pentru ca nu avem nevoie de bomba atomica. Pentru ca am un prieten care are un prieten care stie pe cineva. Pentru ca nu am facut pogromuri. Nu prea multe. Pentru ca avem cei mai multi certificati <a href=\"http://www.brainbench.com/\">Brainbench</a> din lume, si pt ca cel mai bun certificat Brainbench e un american pe care-l kiama Vasilescu. Sau Georgescu. Pentru ca anul trecut sau acum doi ani am castigat Olimpiadele Internationale de Limba Franceza. Pentru ca Borsec a fost decretata cea mai buna apa minerala din lume. Pentru ca petrolul romanesc e de calitate mai buna decat ala arabesc sau rusesc. Pentru ca suntem crestini. Pentru ca patrunjelul are gust de patrunjel, nu de punga. Pentru ca bunica-mea framanta painea cu fatza la icoana. Pentru ca facem semnul crucii pe paine cand taiem prima felie. Pentru ca spunem \"Doamne-ajuta!\" in loc de \"Prost\" (!) Pentru ca \"inchinam\" cand bem. Pentru ca un taran din Rasinari m-o lasat sa-i incalec calu\', desi eram costumat in tigan. Pentru ca alor nostri copii nu le e frica de straini. Pentru ca ma ia lumea la ocazie, de la fandositi in Rover la soferi de tir, si unii chiar fara sa-mi ia bani. Pentru ca spunem \"Pofta buna!\" si \"Sa-ti fie de bine!\" (na, traduceti voi asta din urma in ce limba vreti!) Pentru ca stiu ca daca raman in pana in Suceava nu trebuie sa-mi anunt cu doua zile inainte prietenii ca am nevoie de cazare peste noapte - la noi, vizitele inopinate sunt surprize placute. Pentru ca la munte se da binetze. Pentru ca daca vecinul meu are casa mai mare ca a mea, mi-o reconstruiesc din temelii. Pentru ca am ajuns inaintea nemtilor la Stalingrad. Pentru ca abia reusiram si noi sa avem o batalie intre suporteri si jandari, nu ca civilizatii aia de engleji! Pentru ca avem bunul simt sa ne furam mai mult intre noi, si mai putin pe altii. Pentru ca daca toti romanii vin inapoi, Spania si Italia intra in recesiune necontrolata. Pentru ca facem bancuri care tin de foame. Pentru ca fosta Germania de Est arata mai urat ca Sibiul. Pentru ca spaniolii isi omoara nevestele ca disperatii - noi le iubim mult inainte. Pentru ca la noi divortul dureaza 2 minute. Pentru ca daca trebuie muncim si mult, si bine. Mai ales daca e pentru noi. Pentru ca mama-sa lu Utzu o cumparat 30 de borduri cu un milion de lei de la drumari. Pentru ca am invatzat si noi ca se pot jecmani asigurarile. Pentru ca si in Bratislava sunt blocuri, da\' ale noastre is mult mai urate. Pentru ca avem Muzeul Satului. Pentru ca la noi in tzara se putea cumpara o ordonantza guvernamentala. Pentru ca ortografia e a naibii de grea! Pentru ca am avut o flota de 200 de nave. Pentru ca filmele istorice romanesti au avut scenarii extraordinare, multumim, Eugen Barbu! Pentru ca stim sa ne bucuram de viatza.\r\n\r\n\r\nPentru ca nu am trait in viatza mea doua zile la fel.\r\n\r\n(va urma)\r\n\r\nPS: am scris aberatia ca raspuns la http://stancelsilvan.blogspot.com; (c) pe poza de la intrarea asta ii apartine tot lui. Cand avetz vreme, intratz si pe pajina lui, ca atata ma bate la cap, ghe Doamne, feri!<span><a href=\"http://blog.360.yahoo.com/blog/compose.html?msgid=yIo1p9FoKA--\" id=\"edit-tag-93\" class=\"edit-tags\">\r\n</a></span>','Caine de roman pana la moarte - partea I',0,'','publish','open','open','','caine-de-roman-pana-la-moarte-partea-i','','','2007-03-12 23:26:49','2007-03-12 21:26:49','',0,'http://www.groparu.ro/?p=48',0,'post','',0),(49,1,'2007-03-12 23:25:42','2007-03-12 21:25:42','','Maini si palinca',0,'','inherit','open','open','','maini-si-palinca','','','2007-03-12 23:25:42','2007-03-12 21:25:42','',-1173734602,'http://www.groparu.ro/wp-content/uploads/2007/03/maini-si-palinca.jpg',0,'post','image/jpeg',0),(50,1,'2007-03-12 23:28:31','2007-03-12 21:28:31','','Coada',0,'','inherit','open','open','','coada','','','2007-03-12 23:28:31','2007-03-12 21:28:31','',51,'http://www.groparu.ro/wp-content/uploads/2007/03/coada.jpg',0,'post','image/jpeg',0),(51,1,'2007-03-12 23:28:47','2007-03-12 21:28:47','<a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/coada.jpg\" title=\"Coada\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/coada.jpg\" alt=\"Coada\" /></a>\r\n\r\nPaine de Pasti, sambata mare.\r\n\r\nMa duc la magazin, ma pun la coada. Avetz paine? Vine, zice tanti, acuma o plecat masina.\r\nStau.\r\nStau.\r\nVine masina. In spatele meu, coada. Sunt cam al cinspelea. Ma uit in jur. Cam 60 de oameni. Media de varsta - 65 de ani. Plin de pensionati. Sacose. Palarii. Se discuta de compensate, de gigacalorii, de uzina mecanica IPAS in 1970.\r\nSe descarca painea.\r\nTanti incepe sa serveasca. Serveste 5 persoane, si zice: nu am suficienta paine pentru toata lumea!\r\nUrmeaza 3 evenimente care m-au lasat ca la dentist:\r\n1. \"Sa dea numai una, sa ajunga la toata lumea!\" striga un pensionar zanganind sacosa, in asentimentul gloatei.\r\n2. \"Nu te baga, dom\'ne-n, fatza! Nu ti-e rusine? Am copil mic acasa!\", striga un ficior de vreo 70 catre un mosneag de vreo 30 (altul decat mine), si intreaga coada se mobilizeaza impotriva bagaretzului. Acesta renunta, rusinat, si pleaca la alt magazin.\r\n3. La o suieratura, s-a petrecut cel mai de gura cascator eveniment pe care l-am vazut anul asta. Coada s-a impartit in doua, apoi s-a comasat EXACT in fatza mea. Din al patrulea, am ajuns al patruzecilea. Nu am vazut pe Animal Planet bancuri de sardele mai agile fatza in fatza cu un rechin. Nu am vazut stol de pasari mai vioi in reorganizare in fatza uliului. Se intind maini cu bani, se striga la vanzatoarea perplexa care vinde paine ca teleghidata. Sunt inconjurat de maini care agita bani. Pensionarul de sub palaria din fatza mea pune mana pe ultima paine si dispare efectiv ca teleportat.\r\n\r\nRaman mut de uimire. Toti pensionarii au paine si se imprastie ca soriceii. Efectiv nu-mi cred ochilor. Sunt perfect inadaptat cozilor. In jungla urbana, pensionarii sunt in varful piramidei tropice (era sa scriu trofice, noroc ca mi s-o atras atentia!!<img src=\"http://us.i1.yimg.com/us.yimg.com/i/mesg/tsmileys2/31.gif\" alt=\"Image\" />)','Ce coada mea!',0,'','publish','open','open','','ce-coada-mea','','','2007-03-12 23:28:47','2007-03-12 21:28:47','',0,'http://www.groparu.ro/?p=51',0,'post','',1),(52,1,'2007-03-12 23:29:45','2007-03-12 21:29:45','E beton de Pasti. E plin de ooo rosii care nu te dor - si asta e mare lucru. E si postul, in timpul caruia simti ca ai manca si vietuitoarele alea care provoaca SIDA, asa, cu halba bavareza le-ai manca. E si lumea aia care mere la biserica numa ca sa se afle in treaba, fetele sa se mai uite si sa fie privite, baietii ca sa lege prietenii strajnice cu gardienii care ii legitimeaza cand ii vad beti. E si babele care isi gasesc de lucru shhh-indu-i pe tinerii astia din ziua de azi, care nu e ca noi cand eram ca ei! Noi am mers cu aceeasi sperantza care ne ghideaza vietile, si anume cum ca Domnul ne vede, ne retine minte si nu a urmat cursuri de psihologie cognitiva sa ne ceteasca gandurile dupa modul in care cascam, mutam greutatea de pe un picior pe altul si ne facem numa ca pupam crucea, ca doar n-oi pupa unde-o pus buzele tanti aia batrana,Â  zbarcita si smochinita, care doar in ochii Domnului e frumoasa.\r\n\r\nFaza nasoala e ca m-am hotarit pe ultima suta de metri sa tin post. Nush de ce, ca de evlavie nici gand, de slabit nu e cazu, de boala - Doamne multzam, nici atat, ce microb e intr-atata de prost sa stea in mine? In 2 saptamani moare de coma alcoolica. Cert e ca a fost una dintre cele mai grele clipe din viata mea. Post - adeca fara sex, tigari, carne, ganduri rapciugoase, privit decoltee, injuraturi (aici mi-am permis sa nu fiu kiar asa habotnic) etc. Am ajuns cu maruntaiele protestand in Sibiu cu trenul, aceleasi 4 ore pentru 160 km de cand eram boboc, desi calatoream acum cu Sageata Albastra. Era Vinerea Mare. Am iesit in oras si mi-am permis sa ma indop cu bere de post, 8 la numar in 3 ore jumate. Bere de post - adeca de soferi. Adeca fara alcool. Si am numarat ceasurile ramase, si am incercat sa ma multumesc cu fumul de la alte mese in timp ce-mi promiteam ca voi lua pashtile cu bricheta aprinsa, pentru ca imediat ce iau paine cu vin sa pot sa aprind tigarea si sa trag cel mai adanc fum din viatza mea.\r\n\r\nDeci vine si ziua de sambata, Mitroa zice: bai candidat la viatza vesnica, uite ce e. Deci eu sunt in postura asta prea-teoctista de 6 saptamani. Deci am pregatit acasa 6 kile de carne de gratar, costita, carnati, ceafa de porc, am cladit un foc cu 3 kile de carbuni, am o lada de bere, palinca lu socru-meu (stii tu, d-aia de nu ti-i rau dupa ea). Deci eu si crap daca apuc sa intarzii momentul suprem de carne+papa+tigari+beutura+Doamne multzam - ca ma mai tine inca - sex. Deci orice minut intarziere este inshishi mana satanei! Deci trebe sa merem undeva unde se dau Pastile mai repede. Deci musay. Deci uite ce propun eu: mergem intr-un sat cu 10 locuitori langa Sibiu. Il stiu pe preot, e super evlavios si destul de divortat (!!!) de nevasta-sa, si sigur nu se va intinde la povesti. Deci hai sa merem!\r\n\r\nSi am mers. Si am ajuns in satul Poenitza, langa satul Nou Roman, 10 locuitori. Si cand un cantor i-o facut semn unui tanar sa-i reaprinda luminarea, asta o dat cu capul de candelabrul din biserica de MIE mi-or vajait urechile. Si cand dupa ce am pupat crucea popa o atins candelabrul sa-mi faca semn sa nu dau si eu in el cu mansarda, io am crezut ca vrea sa pup si candelabru\'. Si l-am pupat! Si avea gust de matreatza. Si toti nesimtitii din biserica or izbucnit in ras. Si pana si popa o ras. Si am ras si eu.','Ati mers de-ati luat lumina?',0,'','publish','open','open','','ati-mers-de-ati-luat-lumina','','','2007-03-12 23:29:45','2007-03-12 21:29:45','',0,'http://www.groparu.ro/?p=52',0,'post','',2),(53,1,'2007-03-12 23:32:53','2007-03-12 21:32:53',' <a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/stilian.jpg\" title=\"Stilian\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/stilian.jpg\" alt=\"Stilian\" height=\"290\" width=\"385\" /></a>\r\n\r\nCa unui Cezar Galia, asa mi s-a desfasurat mie Bulgaria.\r\n\r\nFaina tzara! Faina.\r\n\r\nIn primu\' rand, blocurile lor sunt tot de ciment. Si BCA. Si locuite de oameni. Care cere tigari strainilor. Groapele lor exista chiar de-a dreptul pur si simplu in pavaj. Si parcarea lor unde am oprit intre Burgas si Varna era plina de moloz, iar in mijlocul ei trona un colac de buda. Si umflatura lor din slip e de fapt telefonul. Dar mi-a placut la nebunie ca am vazut un mascul care asculta muzica la walkman pe plaja, nu la Mp3 Playa d-ala cu fitze.\r\n\r\nSi bulgarii sunt manelishti, ca si noi, dar asculta decat Gutza si Adi de la Valcea de-ai lor (caruia ii spun Adi de la Plovdiv). Stau cam prost la capitolul masini, pentru ca am vazut mai mult Lada, cu sau fara castraveti. Sportul national: sa nu vorbeasca nici o limba  (pana la aceasta ora nu va pot confirma daca vorbesc bulgara, macar). Plaja nu se curatza decat de reziduuri umane, si e tot plina de scoici si de ramurele de plopi, aruncate de bulgarii care sunt in plop, ca si noi. Guvernul se afla in plima reforma a pretului berii - cea mai scumpa Kamenitza cumparata la o terasa cu fitze de pe plaja m-a lasat mai lefter cu 1 euro. Meniurile sunt si in engleza, daca esti norocos, si soiurile de peste au denumiri misterioasa, cum ar fi Zipura fish sau Cernokop. Burgas-ul e plin de broajte kamikaze, care ies noaptea la plimbare si sunt strivite de talpi bulgaresti in slapi chinezesti. Si mai e si plin de apa calda, da numa in mare sau la dush. Si politaii nu te hartuiesc daca ai masina cu numar german. Si nu cer spaga. Si preturile nu se umfla daca intrebi \"How much?\"\r\n\r\nIn poza: eu cu Stilian, cel mai bun prieten al meu din Bulgaria pe care l-am vazut o singura data in viatza mea si amu nu ai raspunde la e-mail dupa ce l-am imprumutat cu 600 leva. Oare n-am procedat bine?','De Bulgariae',0,'','publish','open','open','','de-bulgariae','','','2007-03-13 11:19:48','2007-03-13 09:19:48','',0,'http://www.groparu.ro/?p=53',0,'post','',2),(54,1,'2007-03-12 23:32:10','2007-03-12 21:32:10','','Stilian',0,'','inherit','open','open','','stilian','','','2007-03-12 23:32:10','2007-03-12 21:32:10','',-1173734986,'http://www.groparu.ro/wp-content/uploads/2007/03/stilian.jpg',0,'post','image/jpeg',0),(55,1,'2007-03-12 23:34:40','2007-03-12 21:34:40','','Coprea',0,'','inherit','open','open','','coprea','','','2007-03-12 23:34:40','2007-03-12 21:34:40','',56,'http://www.groparu.ro/wp-content/uploads/2007/03/coprea.jpg',0,'post','image/jpeg',0),(56,1,'2007-03-12 23:35:12','2007-03-12 21:35:12','<a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/coprea.jpg\" title=\"Coprea\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/coprea.jpg\" alt=\"Coprea\" height=\"371\" width=\"494\" /></a>\r\n\r\nVa spun eu: nimic.\r\n\r\n\r\nNimic rau.\r\n\r\n\r\nDa, mah, Calin, cavalerul din Turda, printul cimentului, floarea BLS-ului, spaima coniacului si junele prim al unei intregi generatii de crajmari s-a agatzat ca un peshte remora de Corina, despre care nu mai am epitete. Cine o stie, stie si de ce!\r\n\r\nRelatia asta simbiotica arbore-lichen a inceput cu ceva vreme in urma, cand Corina a fost fascinata ca mai tot timpu asta venea la serviciu inarmat cu bancuri noi din perioada interbelica, pungi sub ochi si nebarbierit, desi, uneori, curat. Relatia a degenerat cu mutarea impreuna, prajituri la cofetarie platite de ea si lungi seri de pizza oferite unor prieteni la fel de dubioshi ca personajul, traficanti de slapi chinezesti in Serbia, vanzatori in piatza si chiar technical writeri. Si deoarece Corina era convinsa ca in alta viatza a fost Regina Maria sau tanti aia care a inventat Crucea Rosie, si simtea ca trebuie sa se dedice unui scop nobil - gen oprit razboiul din Kosovo si Secuime, gasirea unui leac impotriva cancerului la testicule sau (si mai ambitios) sa-l aduca pe Calin pe drumul cel bun, s-a hotarat sa il ceara de sotz, ca de barbat nu putea fi vorba. Dupa ce i-a cerut voie mamicii sale (o meseriasha cu care nu are apsolut nimic in comun), Calin a racnit cu o jumatate de gura: \"Da!\"\r\n\r\nSi i s-o dat! I s-o dat o nunta in Jibou. Tata socru ar fi vrut sa ii mai dea si el una cu cotul in frunte, da\' l-o oprit mama soacra si - cu greu - inca 9 nuntashi, atata era de otzarat. Cert e ca intr-o zi de vara rulam voioshi spre Jibou - la beut, mancat, beut si dormit, si beut. Pe drum nu ne-am putut abtine sa nu facem bancuri despre Calin. Ziceam ca daca as fi eu Marele Sysadmin, l-as loga pe Calin pe invisible, ca la prea multa lume le strica ziua cand il vad. Si mai ziceam ca nu se stie cine i-o dat lu Calin IP in reteaua asta a lumii, ca mare inconstient o mai fost. Plus ca fiecare zi are creierul formatat. Da\' am ajuns cu bine in Jibou (eu mai greu, ca veneam hapt de la Bulgari!!! ce, ejbou?) si ne-am instalat direct la capatul suptire al unei sticle de bere cu o oratanie pictata pe eticheta, parca era ceva urs, daca bine mai tin minte. Vrusesem sa intram in plina nunta (ca clar ca am intarziat vreo 3 ore) in pantaloni scurti, sandale si ochelari de soare, dar mirii erau afara si nu i-am putut oripila.\r\n\r\nCert e ca la un moment dat ne-am hotarat sa furam miriasa. Si am furat-o. Pe mireasa, vreau sa zic. Si am dus-o acasa la ea si am inceput sa racnim in telefon catre Calin ca ar face bine sa se conformeze cererilor nuastre, ca daca nu, va primi zilnic mireasa prin posta, o ureche azi, un deget maine! Si am fost invitati la negocieri. Si am cerut, in fatza unui public numeros, sa ne dea 600 de metri patrati de teren in centrul Clujului, cu utilitati si front mare la strada. Sau macar 600 de metri liniari. Dupa care am cerut ca viitoarea fata a unuia dintre nasi sa se numeasca dupa numele noastre, ale rapitorilor (ar fi trebuit sa se cheme Aditza Misha Rada, un nume frumos pentru o domnisoara, totusi!) Si cand am vazut ca nu avem cu cine negocia, am cerut cu nesimtire o sticla de Zaraza de 7 stele (din care, pana la urma, 4 au fost facute cu pixul, ca n-avea numa trei), si noi sa o bem in timp ce mirele canta la microfon \"Ma iubeshte femeile\" cu voalul miresei pe cap, iar cei doi nasi (nota bene, masculii celor doua perechi de nasi!) danseaza pe masa tango dupa melodia mirelui. Si s-au conformat.\r\n\r\nCu astfel de amintire am ramas dupa nunta la care toata lumea a aratat mai bine decat mirele. Si decat nasii. Si decat mine. Si asteptam amu cu nerabdare sa ne spuna Calin cum s-a descurcat in luna de miere, ca nesimtitu nu raspunde la telefon, nici mort-copt. Da\' mai asteptam si urmasi. Ca is oameni faini.','Ce poate iesi din nunta a doi programatori de sex opus?',0,'','publish','open','open','','ce-poate-iesi-din-nunta-a-doi-programatori-de-sex-opus','','','2007-03-12 23:35:12','2007-03-12 21:35:12','',0,'http://www.groparu.ro/?p=56',0,'post','',2),(57,1,'2007-03-12 23:36:42','2007-03-12 21:36:42','...written on a toilet in Odense, Denmark, read once, never forgotten:\r\n\r\n\"I fuck my girlfriend\r\nSitting, standing, lying,\r\nAnd when she jumps\r\nI fuck her flying.\r\n\r\nAnd when she\'s dead\r\nAnd long forgotten\r\nI\'ll dig her up\r\nAnd fuck her rotten!\"\r\n\r\n+\r\n\r\n\"When you answer nature\'s call\r\nMust you write upon this wall\r\nOr is it that your feeble wit\r\nOnly shines where others shit\"','Somebody else\'s art genius',0,'','publish','open','open','','somebody-elses-art-genius','','','2007-03-12 23:36:42','2007-03-12 21:36:42','',0,'http://www.groparu.ro/?p=57',0,'post','',6),(58,1,'2007-03-12 23:37:49','2007-03-12 21:37:49','In camasa mea a murit bunicul meu, si l-au descoperit primavara, cand se dezgheta. Camasa mea e cumparata de la un second cu haine din Republica Moldova. In camasa mea gainile cloceau ouale. Gripa aviara a iesit din camasa mea. In camasa mea se depozitau scutelece murdare de copil. Sobolanii o foloseau drept cartier general. Camasa mea are un secol vechime. Miroase a haine vechi de dulap si a pipi de soricel. Camasa mea e respingatoare ca un chihuahua. Uneori are o aroma de caine comunitar udat de ploaia acida. Camasa mea are culoare fecal-verzuie. Uneori, sconcshii refuza sa se apropie. Alteori, cand o miros, lesin. Drogatii o prefera ciupercilor halucinogene. Camasa mea miroase a Armata Rosie. Intr-o vreme, camasa mea era carpa de bordel. Din camasa mea s-a gatit cea mai buna musaca de conopida. Camasa mea are iz de frunze de telina uitate in borcanul cu apa cateva anotimpuri. Camasa mea are propriul ei microclimat, fiindca din camasa mea cresc plante carnivore. Daca s-ar arde camasa mea, s-ar auzi un vaier prelung. Din camasa mea ies mustele verzi, vara. Camasa mea a omorit dinozaurii. Camasa mea e responsabila de efectul de sera. Camasa mea emana caldura. Camasa mea e singura forta capabila sa il ucida pe Superman. Camasa mea a fost folosita intr-un atentat terorist cu bomba in Sicilia. Din cauza camasii mele, Romania nu va organiza niciodata Campionatul Mondial de Fotbal. Camasa mea era mortul din Tacerea Mieilor, gasit in cada lu\' Buffalo Bill. Pe camasa mea s-a scris Mein Kampf. Camasa mea ar lua Oscaru-ul Camasilor la Bollywood. Camasa mea provoaca cutremure. Camasa mea are o centura de asteroizi proprie. Camasa mea si-a rezervat dreptul de a ataca preventiv pentru a-si pastra suveranitatea. Cu camasa mea am luat bataie cand eram mic. Camasa mea a colaborat cu Securitatea. Camasa mea a chemat minerii. Camasa mea a votat cu Constantinescu. Camasa mea provoaca celulita. Camasa mea a fost avorton intr-o viatza anterioara. Camasa mea vaneaza mistreti. Camasa mea se uita la \"Surprize, Surprize\". Camasa mea s-a pronuntat impotriva integrarii europene. Camasa mea a stabilit cote la lapte pentru taranii romani. Camasa mea scrie bloguri despre ea. Camasa mea seamana cu Tom Hanks. Camasa mea gandeste pentru mine. Camasa mea bea bere si injura la meciuri. In camasa mea dispare acoperirea GSM. Camasa mea poate fi vazuta pe Google(TM) Earth.Â  Camasa mea poarta sandale cu sosete. Camasa mea va darama Zidul Chinezesc. Camasa mea a lansat varianta de Yahoo!(R) Messenger 8 Beta. Camasa mea conduce iresponsabil. Camasa mea asculta manele. Camasa mea vrea sa invete ping-pong. Camasa mea floodeaza servere. Atat.','Camasa mea',0,'','publish','open','open','','camasa-mea','','','2007-03-12 23:37:49','2007-03-12 21:37:49','',0,'http://www.groparu.ro/?p=58',0,'post','',9),(59,1,'2007-03-12 23:39:41','2007-03-12 21:39:41','','Eye of God',0,'','inherit','open','open','','eye-of-god','','','2007-03-12 23:39:41','2007-03-12 21:39:41','',60,'http://www.groparu.ro/wp-content/uploads/2007/03/eye-of-god.jpg',0,'post','image/jpeg',0),(60,1,'2007-03-12 23:39:50','2007-03-12 21:39:50','<a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/eye-of-god.jpg\" title=\"Eye of God\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/eye-of-god.jpg\" alt=\"Eye of God\" /></a>\r\n\r\nZice Biblia cÄƒ suntem fÄƒcuÅ£i dupÄƒ chipul si asemanarea lui Dumnezeu. ÃŽnseamnÄƒ cÄƒ Dumnezeu seamÄƒnÄƒ  cu fiecare dintre noi, desi eu imi doresc mai mult sÄƒ semene cu Demi Moore, asa cum arata ea in The Ghost, prin anii \'80.\r\n\r\nDupa cum vad eu lucrurile la afacerea asta, exista doua solutii:\r\n\r\n1. Eu sunt ca un fel de siamez mai mic al lui Dumnezau, si acuma ar trebui sa va indeplinesc dorinte pe banda rulanta, ca un crapcean de aur, asa mai mic; sau\r\n2. Dumnezeu e un fel de Radu Valentin Bazavan mai mare, care acuma e ocupat scriindu-si blogu\' sh nu prea are timp de galetile voastre de rugaciuni cu loteria.\r\n\r\nVarianta 1: Eu sunt ca un fel de siamez mai mic al lui Dumnezau\r\n\r\nE clar,  daca ma enervez va inec pe toti, da\' va zic de pe-acuma ca nu vrun Noe va fi singuru\' supravietuitor, ci maica-mea, ca daca nu am cu cine ma certa mor de plictiseala. Si dupa ce va prefac pe toti in submarine, despart marea in doua si ma distrez in cel mai mare Aqua Park din lume. Oricum, pe fiu-meu nu vi-l dau in grija, ca kinderii crescuti fara parinti fac lucruri traznite, si pe deasupra poate va mai si paleshte gandu\' sa mi-l crucificati, sh-apa ati cam rupt-o-n fericire, dragii mei. Da\' sa va iasa din cap ca primiti numa\' 10 legi, pentru ca o sa va dau un Cod Penal stufos ca un par pubian de aborigena. Si daca nu il respectati intocmai va cam ia dracu\'. Apropos de dracu\', s-ar putea sa am chef sa va joc sufletele la poker, si va previn ca nu prea ma stiu la jocuri de noroc, si ala sigur triseaza ca un nesimtit.\r\n\r\n2. Dumenzeu e kiar un Groparu siamez de-al meu mai mare, care si-o picat doua admiteri la facultate si pe deasupra si fiecare master posibil, da\' care Ã®ncÄƒ se crede cu incapatinare destept si carismatic cat galaxia. Varianta asta imi place mai mult, mai ales ca de fiecare data cand urc pe Negoiu ma simt mandru ca un secui, si Ii mai si zic de la egal la egal \"Am facut o treaba buna, nu?\"\r\n\r\nDa\' tot nu ma pot abtine sa nu ma intreb, dacÄƒ eu sunt fÄƒcut dupÄƒ chipul ÅŸi asemÄƒnarea Sa, oare Dumnezeu are ÅŸi El cearcÄƒnele mele dupÄƒ o noapte de beuturÄƒ? Oare douÄƒ perechi de cearcÄƒne pot exista concomitent Ã®n acelaÅŸi interval fizico-temporal? CÄƒ dacÄƒ da, Ã®nseamnÄƒ cÄƒ Dumnezeu nu respectÄƒ legile fizicii, pe cÃ¢nd io imi dau seama de ele tot timpu, mai ales de legea gravitaÅ£iei supusÄƒ acÅ£iunii unui numÄƒr individual compus de beri (singura lege fizica valabila pentru mine e legata de atractia fizica). Oare si Dumnezeu cauta apartament in perioada asta, si e scarbit de chirii? Oare si Dumnezeu face traduceri care Ii ies naspa uneori? Oare si Lui ii miroase gura dimineatza, si se enerveaza cand sta la ocazie? Face ocazia ca sa mearga unde, acasa? Unde e casa Lui, si ce face El acasa, mere la parinti, isi spala rufele, si dupa aia bea cu varu-so si cu Mitroa pana se macheshte? Oare si Dumnezeu vrea sa mearga vara asta la festivalul de la Sighisoara, si nu are unde sta? Cand isi ia concediu si ajunge la mare, mananca oare si El hamsii si mititei si se holbeaza la studente pe furish?\r\n\r\nOricum, is aproape sigur ca Dumnezeu are si El are o lista de Yahoo Messenger pe care intra pe invisible. Da\' nu-s sigur daca are sau nu pe cineva pus pe <em>ignore</em>. Oare se supara cand Ii da lumea Buzz, si oare crede si El ca Yahoo se inchide? Cat de des isi verifica mailul? Primeste si trimite si El bancuri si chestii haioase la arhangheli si serafimi? Cu ce nick intra cand joaca Counterstrike si Bomberman? Ce placa video are, NVidia sau Radeon, procesor AMD sau Intel? Oare e scump abonamentul la net, acolo in rai, si si acolo se injura gamerii?\r\n\r\nMai cred cu tarie ca si El merge la pescuit, si sta la umbra sub nimb, da\' nush la ce momeala da (poate pune manÄƒ, mai stii?), ÅŸi dacÄƒ da la rapitor sau la crap. Da\' oare cine ii da Lui permis sau amenda? Si daca nu prinde nimic, tot la cherhana se opreste? Cum ii place pestele, saramura sau plachie? Si salata o face tot cu rosii turcesti?\r\n\r\nS-ar putea ca atunci cand face baie sa se incordeze in oglinda, sa vada daca nu i-au mai crescut muschii. Da\' daca ia o teapa de la un taximetrist, face si El scandal ca Silvan?\r\n\r\nMie oricum imi pare bine ca e dupa chipul si asemanarea mea, nu dupa chipul si asemanarea lu Marius Tuca. CÄƒ desi nu prea-mi surÃ¢de ideea de a mai exista unu la fel de iresponsabil ÅŸi de urÃ¢t ca mine prin Univers, mai bine ca mine decat ca think tank-ul din Caracal.','Dumnezeu si eu',0,'','private','open','open','','dumnezeu-si-eu','','','2007-03-14 17:02:12','2007-03-14 15:02:12','',0,'http://www.groparu.ro/?p=60',0,'post','',0),(61,1,'2007-03-12 23:40:24','2007-03-12 21:40:24','Da, stim cu tatzii. In Romania, oricat de tare ti se scoala si indiferent cati pui la skandenberg, nu esti BARBAT daca nu stii sa pui faiantza, gresie, parchet, sa dai cu lavabila sau sa zugravesti - si mai ales sa repari Dacia in fatza blocului. Stiu, finca asta e cazu\' meu. Stiu. Stiu.\r\n\r\nIo, in afar\' de apasat tastele w, a, s, d, si dat click stangaÂ  la mouse cand joc Counter Strike , mai stiu numa cum se zice la \"mojar\" si \"pistil\" in engleza. Si mai stiu sa imbarlig neni la ocazie sa nu platesc, da\' aia numa cand ma plictisesc si fac pe zgarcitu\'. Si mai stiu ca palinca tre\' sa faca margele, si cam atata. Poate mai stiu si alte kestii, da\' asta e subectu\' unui alt blog, da\' niciodata nu voi fi ca Meshteru\'. Meshteru. Hmmm.\r\n\r\nDeci o rima se kiama cand consoanele de dupa ultima vocala a ultimei silabe a ultimului cuvant se potrivesc cu consoanele de dupa ultima vocala a ultimei silabe a ultimului cuvant din randul sau ghiersul care urmeaza. Nu stiu alte kestii despre poezii decat sa compun unele cu adevarat najpa cand sunt de ziua mea in Danemarca departe de pretenii care imi bea banii si imi kinuie ficatu (ca tre sa beau in rand cu iei, ce pana mea), dar io sunt ferm convins ca (virgula) cuvantul meshter in romana a fost inventat pentru a rima cu shmecher. Finca shmecherii sunt meshteri, sau invers.\r\n\r\nMeshteru e un tip care miroase a tocanitza de cartofi la subsoara. E tipul care vine cuÂ  bancuri care te obliga sa razi la ele. E tipul cu lant de aur la gat si iti cere sa ii dai sa bea inainte de a se apuca de treaba. E tipul care iti vorbeste despre lucrarile lui la omeni cu adevarat avuti, care l-au cinstit si pretuit cand lucrarea a fost gata, si care l-au tinut numa cu votca poloneza si suc de portocale de la Kaufland. E tipul care iti spune ca are lucrari pana in martie, si tie iti face o favoare ca iti face inaintea directorului de la HVB. E tipul care are telefon mai destept ca al tau, si creca si ca el. E tipul care urla cand vorbeste la telefon, chiar daca iti doarme copilu. E tipul care injura de Dumnezei de fatza cu nevasta-ta. E tipul care o lucrat pe dincolo, si stie cum se lucreaza, dar o plecat de acolo finca nu vroia sa fie diriginte de santier. E tipul care iti spune ca nu gresie de aia trebuia sa iei, ca e najpa, cat despre adezivul de faiantza, ala e bun pentru chituit cotetze. E tipul pe care nu ai cum si ce sa-l inveti. E tipul care iti cere sa ii dai scula de langa el, desi tu esti la 9 metri distantza. E tipul ale carui adjective favorite sunt \"nemteste\" si \"chirurgical\". E tipul care isi va cumpara apartament mai mare ca al tau luna viitoare. E tipul pe care nu il poti acoperi cu vocea, indiferent cat de tare vorbesti. E tipul care te sileste sa dai mereu din cap ca \"da\" cand iti graieste. E tipul care iti seamana nesiguranta in inima cand ii dai indicatii si el se resemneaza cu un \"Cum vreti! E casa voastra!\", si ofteaza. E tipul de om caruia i se vede curu\' cand se apleaca sa iti puna faiantza.\r\n\r\nE tipul de om care este Basescu.','Mesterul',0,'','publish','open','open','','mesterul','','','2007-03-12 23:40:24','2007-03-12 21:40:24','',0,'http://www.groparu.ro/?p=61',0,'post','',0),(62,1,'2007-03-12 23:41:53','2007-03-12 21:41:53','','Soimii',0,'','inherit','open','open','','soimii','','','2007-03-12 23:41:53','2007-03-12 21:41:53','',63,'http://www.groparu.ro/wp-content/uploads/2007/03/soimii.jpg',0,'post','image/jpeg',0),(63,1,'2007-03-12 23:42:30','2007-03-12 21:42:30','<a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/soimii.jpg\" title=\"Soimii\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/soimii.jpg\" alt=\"Soimii\" height=\"298\" width=\"443\" /></a>\r\n\r\nAmu la ora 11 am scoborat cu Calin Marian (noi ii spunem Marean, ca asta e numele de familie, si l-am felicitat de Sf. Maria toti colegii, de s-o emotionat tot) pana la mahazin, sa lom ceva d-ale gurii pantru brunch. Si trecem pe langa sosea, si auzim o frana de o sunat ca o unghie pe tabla, si vedem o tipesa ca pedaleaza voios pe o trotineta, cu sudori reci pe frunte, si in spatele ei tocma se oprise un Mercedes - faina mashina, neagra, al carei sofer franase ca sa nu incalece domnisoara - ca nu se cade sa calareshti o demoazela cu masina. Recunosc cu fatzarnica modestie ca mi-as fi cules inimioara din chilotzei daca eram in locu\' lu tanti, da\' firoscoasa amazoana lasa ghidonul, face deshtele mainii pumn, mai putin ala din mijloc, si racneshte odata,Â  de am si intepenit:\r\n\r\n<font size=\"5\">MUIEEEEEEEEEE!!!!!\r\n\r\n<font size=\"2\">Am ramas interzis, ce mai. </font></font>In primu rand ca tinara nu specificase de care parte a pulii dorea sa se afle. Soferul Mercedes-ului s-o uitat disperat in jur sa caute pe cineva cu care sa rada de toata faza, ca se stie ca nu are nici un farmec sa razi singur. Si m-o vazut si am ras amandoi ca cretinii.\r\n\r\nAmu, toate bune si frumoase, dar am ceva de comentat cu privire la deshtiu asta ridicat in sus (ca nu se poate ridica in jos). Faza cu deshtiu a aparut - orice inginer stie, doara - in perioadele in care se bateau frantzujii cu englezoii prin Evul Mediu, pentru ca nu se intelesesera care sa aiba preotii pedofili si care sa piarda un razboi mondial in 2 saptamani. In Evul Mediu, arcasii aveau un statut aparte in armata, pentru ca puteai efectiv castiga o batalie numai din sagetile aruncate de la 300m. Pentru ca o sageata sa strabata 300m si sa si faca un tunel in trupul dusmanului, aveai nevoie de ceva tarie-n glanda, ce mai. Asa ca arcasii aveau un deshti mijlociu cat o putzulica erectata de ghibol, pentru ca era degetul principal in incordarea strunei (gurile rele spun ca foloseau degetul si in alte scopuri...). Asa ca atunci cand englejii prindeau un frantuz si viceversa, prima masura luata era decapitarea degetului mijlociu, ca nenea sa nu mai ajunga in tabara adversa si sa traga cu sageti, ca nu e frumos. Asa ca atunci cand armatele se confruntau de la distantza, in semn de respect reciproc, toti combatantii isi fluturau degetele mijlocii, intreband partea adversa de sanatatea mamelor. De aici, ulterior, salutul traditional s-a degradat si a ajuns sa insemne ce inseamna azi: fuck you!\r\n\r\nSi apropos de fuck you, sa stiti ca circula pe net o falshitate monstruoasa referitoare la cuvantul asta geto-dacic. Se spune ca, in Anglia medievala, cuplurile trebuiau sa ceara voie regelui ca sa se joace de-a animalul cu doua spinari; cand regele le dadea regescul acord, atarnau la usa o tablitza pe care scria \"Fornication under the Consent of the King\". Dar nu e kiar asha. Triaba e ca dupa Marea Ciuma din 1665 si Marele Incendiu din 1666, populatia Londrei se cam injumatatzise cu doua treimi. Disperat ca nu mai are supusi, rejele o scos un edict prin care ii obliga pe toti posesorii de parti anatomice in stare de functionare sa le puna la treaba, ca sa aiba si el peste cine domni, ca electoratul lui deja semana cu a lu Iliescu - mojnegi si babutze duioase, fascinati ca ghinIon Iliesc e \"sarac, da\' cinshtit!\" Asa ca atunci cand se cautau la scutece, sexoshii supusi engleji atarnau o tablitza pe care scria \"Fornication under the Command of the King\" - hence, f.u.c.k. Dar, ca sa fim si mai semanticoshi, de fapt verbul \"fuck\" vine de la germanicul \"flichen\" - care inseamna \"a lovi\".\r\n\r\nOricum, Mitroa, cand era prof de gradinitza, a cercetat prin anale si a gasit o varianta mai istorica a ce inseamna degetzelul semetz: ca sa-i faca pe copii sa nu-si mai arate unu altuia deshtiu, le-a zis ca semnu ala inseamna ca bagi carpienele in fund la coleg si dupe aia le miroshi. No comment.','Ia uite ce deget iti arat!',0,'','publish','open','open','','ia-uite-ce-deget-iti-arat','','','2007-03-12 23:42:30','2007-03-12 21:42:30','',0,'http://www.groparu.ro/?p=63',0,'post','',1),(64,1,'2007-03-12 23:44:15','2007-03-12 21:44:15','','Hack',0,'','inherit','open','open','','hack','','','2007-03-12 23:44:15','2007-03-12 21:44:15','',65,'http://www.groparu.ro/wp-content/uploads/2007/03/hack.jpg',0,'post','image/jpeg',0),(65,1,'2007-03-12 23:44:50','2007-03-12 21:44:50','<a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/hack.jpg\" title=\"Hack\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/hack.jpg\" alt=\"Hack\" height=\"342\" width=\"454\" /></a>\r\n\r\nDin fericire pt. ghisei, si-or remediat defecatiunea instant. Dar nu suficient de repede ca sa nu-si dea seama Groparu :D','www.ghiseulbancar.ro a fost hackuit!',0,'','publish','open','open','','wwwghiseulbancarro-a-fost-hackuit','','','2007-03-12 23:44:50','2007-03-12 21:44:50','',0,'http://www.groparu.ro/?p=65',0,'post','',1),(66,1,'2007-03-12 23:46:15','2007-03-12 21:46:15','','Peste',0,'','inherit','open','open','','peste','','','2007-03-12 23:46:15','2007-03-12 21:46:15','',67,'http://www.groparu.ro/wp-content/uploads/2007/03/peste.jpg',0,'post','image/jpeg',0),(67,1,'2007-03-12 23:47:24','2007-03-12 21:47:24','<a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/peste.jpg\" title=\"Peste\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/peste.jpg\" alt=\"Peste\" height=\"365\" width=\"484\" /></a>\r\n\r\nDom\'ne, deci la pescuit trebe sa mergi pregatit, nu gluma.\r\n\r\nIn primu rand, peshtele nu trage daca nu esti nitel abtiguit. Te poti afuma cu ce vrei - bere, vin, sau, daca e frig, cu tarie. De asemenea, se stie ca pestii nu se dezonoreaza pe ei,  pe familiile si pe imparatu\' lor  lasandu-se prinsi de nefumatori.\r\n\r\nToti pescarii de pe balta dau la momeli misterioase. Cand esti pe balta nu-ti spune nimeni la ce da. \"La ce dai?\" \"A, la ce am, la minursjtehska\", se zice, ultimul cuvant rostit in mandibula, cu mana scarpinandu-si barba. \"La ce???\" \"La tjrukleswegrasmdfee\", se raspunde, de data asta cu cealalta mana in nas, mormaind, si intorcand brusc ochii catre bambina (cand am fost ultima data la pescuit, o venit un pustan sa ne ceara imprumut o bambina. I-am spus ca nu avem, mai ales ca nici nu stiam ce e aia), semn ca discutia a luat sfarsit. Tu nu te lasi: \"Si ai prins ceva?\" \"A, slab... slab!\" Si degeaba mai stai, discutia s-a incheiat.\r\n\r\nCand vine nenea cu cainii sa ia taxele, raspunsul e acelasi: uite, acum 5 minute am venit. Pai da, da\' 300.000 e pe zi de dimineatza pana seara. Deja e ora 12, deci jumatate din ziua de pescuit s-a dus, uite, va dau 100.000 si nu-mi traba chitantza, sanatate multa!\r\n\r\nCand prinzi primul peste, il injuri si il arunci in punga cu obida. Nu e ca in \"Batranul si marea\", in care moshnegila trateaza pestele cu respect, ca pe egalul lui, ca toreadorul pe taurul pe care urmeaza sa il intzapa. \"Ai luat ceva?\", sar repede coekipierii care aud pleoshcait, ca se zbate peshtele, saracu! \"Da-l in pizda ma-sii, ca asta e de gradinitza!\" - asta chiar daca peshtanu\' e de un kil shi. Daca e mai mare de 4 kile, atunci te enerveaza la culme ca trebe sa il oboseshti 10 minute pana sa il scoti. Si cand il scoti, urli: \"Pula me, ca asta o sa puta a mÃ¢l!!! Si i-am si speriat pe ceilaiti, de nu mai prind nimic azi!\"\r\n\r\nDaca e liniste, trebe sa pui manele. Daca face altu galagie, urli la el \"Ba, aici esti la pescuit! Inchide zgomotu!\" Daca ai scaun, pescarii comenteaza imediat: \"Apai cu scaunu\' asta nu ai cum sa prinzi peshte, nenicule! Asta nu-i bun, iti trebe de la Metro, scaun d-ala facut la Baia Mare!\"\r\n\r\nNici un pescar nu mananca pestii pe care i-o prins. E o chestiune de onoare dintre om si peste.\r\n\r\nNu e bine sa ii intrebi pe pescari cat de mare e cel mai mare prins de ei. NU E BINE DELOC. Vei afla cu surprindere ca orele de biologie de clasa a sasea au uitat sa populeze apele tzarii mele cu rechini ciocan, balene albastre, orca si baracude. Lostritza viermuieshte in Dunare, si somnul traieshte cu precadere in apele de munte, dar numai daca are peste 30 de kilograme. Pastravul ajunge lejer la 12 kile mai ales in parauri cat un pipi de porcushor de Guineea, stiuca aia de doi metri se prinde numai la purcelush de lapte intreg, iar marmota invelea ciocolata. Rapitorii epocali se prind cu bob de porumb sau cu paine. Pentru crapul ala de 40 de kile, batran de 200 de ani, am chemat tractoru\', sa moara mama, ca nu-l puteam trage afara 4 barbati. Ca sa nu mai vorbim ca atunci cand am pescuit la mare stateaucalcaniipefundulbarciidenumaicalcaipelemn.\r\n\r\nUnii pescari au si neveste, cu care vin la pescuit. O nevasta de pescar este deosebit de grasa, si umbla numai in costum de baie, pentru ca ea vine la plaja, nu la pescuit, ca deja si-o agatzat peshtele. O femeie la pescuit este cea mai sexy creatura de pe pamant, pentru ca e singura pe o raza de 50 de hectare de luciu de apa.\r\n\r\nEu, unu, ma duc la pescuit ca sa prind sirene, si d-aia dau tot la ruj de buze. Da\' nush cum se face ca prind numa peshti cu oase multe si matze imputzite. Dar perseverez. A, si mai este ceva - pentru connoisseuri. Pe lumea asta sunt doua chestii cu miros de peste. Unul e pestele...','La pescuit',0,'','publish','open','open','','la-pescuit','','','2007-03-13 11:20:25','2007-03-13 09:20:25','',0,'http://www.groparu.ro/?p=67',0,'post','',1),(68,1,'2007-03-12 23:47:00','2007-03-12 21:47:00','','Peste',0,'','inherit','open','open','','peste-2','','','2007-03-12 23:47:00','2007-03-12 21:47:00','',-1173735890,'http://www.groparu.ro/wp-content/uploads/2007/03/peste.jpg',0,'post','image/jpeg',0),(69,1,'2007-03-12 23:50:21','2007-03-12 21:50:21','','La Radu',0,'','inherit','open','open','','la-radu','','','2007-03-12 23:50:21','2007-03-12 21:50:21','',70,'http://www.groparu.ro/wp-content/uploads/2007/03/la-radu.jpg',0,'post','image/jpeg',0),(70,1,'2007-03-12 23:50:52','2007-03-12 21:50:52','<a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/la-radu.jpg\" title=\"La Radu\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/la-radu.jpg\" alt=\"La Radu\" height=\"367\" width=\"488\" /></a>\r\n\r\nStateam si ma gandeam cine ar merita titlul de cel mai mare roman, si am ajuns, dupa o indelungata cearta cu trei sticle de bere, la acelasi raspuns consensual: Dumnezeu.\r\n\r\nDumnezeu e cel mai mare roman care este. Inca nu e roman, pentru ca inca nu are cetatenie romana, dar daca vorbeste bine limba eu propun sa i-o dam. Nu va fi nevoie sa se insoare cu o romanca, pentru ca Dumnezeu e celibatar, si astfel ramane o femeie in plus de iubit pentru noi, lesbienii. Dumnezeu e mai tare ca <a href=\"http://stiri.itbox.ro/stiri-citeste/Showbiz-si-Fun/stiri-Nicolae-Guta-are-trei-palate.html\">Nicolae Gutza</a> pentru ca asta din urma are numai trei palate, si Dumnezeu are un univers intreg. Dumnezeu uneste mai multi romani decat a unit Mihai Viteazu: din 22 milioane, jumate se unesc cu cealalta jumatate aproape saptamanal sau chiar mai des, nu numa o singura data in istorie. Dumnezeu nici nu e fustangiu ca regele <a href=\"http://ro.wikipedia.org/wiki/Carol_al_II-lea_al_Rom%C3%A2niei\">Carol al II-lea</a>. Nici nu e neamt, ca restul regilor Romaniei, si asta deja e un mare plus. Desi e legionar ca Mircea Eliade (are doar la legiuni de ingeri...), nu face Yoga, nu fumeaza si nu a emigrat in Americaca ca savantul nostru - plus ca Biblia bate \"Istoria Religiilor\" la capitolul best seller. Desi are El ce are cu evreii, nu i-o imbarcat in vaguane pentru vite sa ii trimita sa adulmece gaz, ca Antonescu - cel mult i-o trimis de-a lela prin desert si i-o cazat in singura pata de teren din zona unde nu se gasea petrol. Cu sigurantza a domnit mai multi ani decat a domnit Stefan cel Mare si Sfant, si fiul Sau a fost mai tare ca Petru Rares. Si nici nu s-o batut cu turcii, pentru ca dupa 400 de ani sa faca cu ei trafic cu blugi, guma Turbo si treninguri Sergio Tacchini.\r\n\r\nIs aproape sigur ca nimeni nu il confunda cu Constantin Brancoveanu, ca pe Brancusi, si daca i s-ar vinde la licitatie vreo opera de-a Sa, cum ar fi Nicoleta Luciu, s-ar lua un pret mai bun decat pe \"D-ra Pogany\". Este mai bun decat Nadia Comaneci prin singurul fapt ca nu e femeie (sau e?) Plus ca, daca Dumnezeu nu vroia, Cuza nu mai ajungea domnitor, pe cand Cuza putea sa tot faca opozitie, ca Dumnezeu tot presedintele lumii ramanea. Cat despre Mihai Eminescu, Dumnezeu nu merge la bordel.\r\n\r\nMai am ceva dubii despre Becali, dar tot nu-mi vine a crede ca e mai tare decat Dumnezeu. Da\' apropos, voi ati auzit de Richard Wumbrandt?','Cel mai caine de roman pana la moarte II si dincolo de ea',0,'','publish','open','open','','cel-mai-caine-de-roman-pana-la-moarte-ii-si-dincolo-de-ea','','','2007-03-12 23:50:52','2007-03-12 21:50:52','',0,'http://www.groparu.ro/?p=70',0,'post','',2),(75,1,'2007-03-13 00:03:47','2007-03-12 22:03:47','','Filtru',0,'','inherit','open','open','','filtru','','','2007-03-13 00:03:47','2007-03-12 22:03:47','',76,'http://www.groparu.ro/wp-content/uploads/2007/03/filtru.jpg',0,'post','image/jpeg',0),(76,1,'2007-03-13 00:03:58','2007-03-12 22:03:58','<a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/filtru.jpg\" title=\"Filtru\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/filtru.jpg\" alt=\"Filtru\" /></a>\r\n\r\nMie imi place despre MLM*-uri.\r\n\r\nIn primu\' rand ca respect oamenii care incearca sa se foloseasca de cercul de prieteni ca sa faca bani. Prietenii mei se folosesc de mine numai ca sa-si produca bere si dureri de cap, a doua zi. Si sa aiba de la cine cere bani imprumutzi. Si pe prietenii mei ii respect.\r\n\r\nIn al doilea rand, respect oamenii care incearca se ridice financiar nivelul prietenilor lor. Prietenii mei nu is asha. Ei nu se incearca sa ma ajute cu nimic, dimpotriva. Prietenii mei, cand or aflat ca mi-am cumparat garsoniera, or zis fie: \"A, interesant. Ba, sa vezi ce-am patit pe troleibuz...\", sau \"Aha. Io niciodata nu cred ca-mi iau garsoniera, io vreau sa-mi iau direct casa, ca nu se renteaza alfel!\" Si, cel mai tare (invariabil, aceeasi reactie): \"Cand dai de baut?\", in nici un caz \"Te pot ajuta cu ceva?\"\r\n\r\nIn al treilea rand, imi plac oamenii care mai cred cu disperare ca daca isi fixeaza un tzel in viatza cu o data limita, tzelu\' ala se va si implini negreshit. Asta respect cel mai mult. Io nici macar nu am curajul sa imi fixez ca tzinta a carierei sa prind autobuzul 30 la ora 9 fara 20, sa ajung si eu ca botezatii la 9 la serviciu.\r\n\r\nDar insa, am avut o experientza ciudata cu un MLM-eu. O tipesa, de fapt, fata faina de alfel, da\' care tinea mortis sa intru si io in bijnitz, la recomandarea unui fost coleg de facultate care stia ca vorbesc multe sh imbarlig femei, de preferintza grase si singure si si bete. Dar in fine. Stabilim o intalnire sh ne intalnim la un suc.\r\n\r\n- Trebe sa traim sanatos, nu-i asa? incepe d-ra.\r\n- Da, zic eu, tragand adanc din tigare si sufland fumul pe ea. Imi cer scuze 2 secunde mai tazriu, nu is kiar asha de nesimtit.\r\n- Cata apa bei pe zi? ma intreaba, direct, cu o privire de peste mort.\r\n- Cam... puii mei, zic io. Dimineatza cand ma arde stomacu\' de la bere beau sh 2 kile de suc.\r\n- Nu suc, zice, apa. Stii cate toxine sunt in suc? intreaba ea, luand o gura de Cola.\r\n- Cum sa nu, zic io, da mi-i sete. Da\' sa stii ca io am grija sa compensez. Astia de la serviciu dau apa minerala gratis, si ma imbuib.\r\n- Da, zice ea, dar asta nu e foarte bine.\r\n- Ba, zic io, ca mai duc si acasa si economisesc aproape 8.000 ROL pe zi, zic eu tragand din tigare. Cand te invit la o apa plata?\r\n- Nu de asta, zice ea, eschivand cu arta al doilea shumuiog de fum trimis inspre ochii ei. Dar stii ca poti face calculi.\r\n- Pai tocmai asa mi-am calculat io, zic, 8.000 ROL X 365 zile pe an = 2.920.000 ROL, care inseamna o groaza de bere.\r\n- Nu calcule, mai, zice ea, <strong>calculi</strong>. Renali.\r\n- A, zic io, pai d-aia cumpar bere, ca sa spal rinichii.\r\n- Interesant, zice ea. Dar nu faci decat sa creezi o problema care poate scapa de sub control. Tu stii ca trebuie sa bei 2 kile de apa pe zi?\r\n- Aha, zic eu, si m-apuc de meditat. Finca gandesc repede, continuu imediat:\r\n- Si beduinii cata apa bea?\r\n- Cine?\r\n- Beduinii, zic io. Aia de umbla prin desert sh se calaresc cu camilele. Aia n-are cum sa bea 2 kile de apa pe zi. Cu aia ce ne facem?\r\n- ...\r\n- Vezi? zic io.\r\n- Da, zice ea, dar noi trebuie sa ne vedem de viatza noastra. Uite, zice ea. Si scoate o brosura din aia lucioasa, cu urechi de magar. Uite-te un pic aici la beneficii.\r\n\r\nSi se apuca Groparu sa scaneze pajinile. Da. Filtru de apa care retine intemperii sh mozoale sh polipi sh namoale.\r\n\r\n- Dar asta nu face bine, zic io. Ca apa fara namol nu are nush ce puii mei de argile care e benefice la intestinu\' gros, unde se formeaza cacatu\'. Sh daca nu se mai formeaza cacatu\' e mare bai, zic eu, ca te umpli de cacat si mori sau ajungi ziarist la Antena3.\r\n- Nu-i adevarat, zice ea, shefa mea de la MLM e doftor. O dat sa mance apa filtrata sh nefiltrata la matza ei, sh matza o stiut sa bea apa din aia nefiltrata, ca e mai sanatoasa.\r\n- Intotdeauna am zis ca matzele is neshte animale facute sa iti faca in ciuda.\r\n- Very funny, zice ea, tragandu-mi o privire de Polu Nord, varianta cu crivatz. Dar sa stii ca dupa un an de la folosire shefa mea o scos filtru de apa, si avea peste o juma de kil numa\' depuneri.\r\n- Ce bine ca ne integram in UE, zic io, ca or sa fie astia obligati sa schimbe conductele si sa ne si dea apa mai curata, ca asa e Directiva Consiliului, zic io.\r\n- Crezi? Si cum ramane cu sanatatea noastra pana atunci?\r\n- Ne-o tinem cu bere, zic io. Apropos. Un filtru de bere nu ai? Glumesc, glumesc. Numa atata vreau sa te rog intrebandu-te. Cat coasta asa un filtru?\r\n- Da, zie ea, da. Ai facut vreodata un calcul cat dai pe apa minerala pe un an de zile?\r\n- O secunda si iti spun, zic io. Daca la firma am apa minerala, inseamna caaa... intr-un an dau... 0 (zero) lei, 0 (zero) bani.\r\n- Da, zice ea, dar daca nu mai lucrezi la firma?\r\n- Da, zic eu, dar daca mai lucrez?\r\n- Oricum nimic nu e sigur pe lumea asta, decat moartea, impozitele si filtrul meu de apa. M-ai intrebat cat costa. Sa stii ca nici nu costa mult, zice ea.\r\n- Depinde ce intelegi prin mult, zic eu.\r\n- E, o nimica toata. 42.000.000 ROL.\r\n- E moca, zic eu. 42.000.000 ROL. Da stii ca il ai pe viatza.\r\n- Da, zice ea, filtrul anual costa 8.000.000 ROL.\r\n- Tare, zic eu. 8.000.000 ROL : 18.000 ROL cat e o sticloantza de doo kile de apa rezulta 444 de sticle de 2 kile pe an. Insamna 2 kile de apa minerala pe zi. Si mai si raman aproape o suta de sticle pentru pretenii mei betivani. Sa ne dregem cand ne saturam de atata bere pura.\r\n- Nu gandeshti bine, zice ea.\r\n- E! zic io. Nu-mi spui nimica nou. Da\' chiar nu-mi convine sa cumpar asa un filtru pentru colegii mei de apartament, ca io oricum is toata ziua plecat sh nu pot umbla prin orash cu ditamai filtru de 5 kile in straitza.\r\n- Sa stii ca mai devreme sau mai tarziu vei ajunge la concluzia mea, zice ea.\r\n- Draga mea, zic, daca aveam 42.000.000 ROL ma insuram de mult. O ceream pe Metaxa in casatorie sh stiam o treaba.\r\n- Tu nu-ti dai seama ca apa de la robinet are aceeasi componenta chimica cu apa din WC?\r\n- S-orbesc, zic, apa asta cu doi atomi de hidrogeni si unul de oxigen e kiar nesimtita! Dar stii ce e cel mai socant? zic. Pana si nesimtitii aia de pa Marte cica beau aceeasi molecula de apa, cu aceeasi compozitie ciudata: doi atomi de hidrogen si una de oxigen, cum zice ungurii. E fascinant Discovery Civilisations.\r\n\r\nAs fi vrut sincer sa o ajut pe fata. Mai ales finca anul trecut mi-o si urat LMA de ziua mea, ca cica asha trebe, ca trebe mentinut contactu\' cu clientii, si mie imi place cand primesc mesaje gen \"cu ocazia zilei de nastere, iti urez din inima bla blea buek\". Dar bag de sama ca destinele noastre nu s-au intrepatruns nici de data asta, ca daca se intrepatrundeau i-as fi cumparat filtru ca sa ii filtrez ce iasa de-acolo dinauntru cand se rupe apa, si i-as fi dat sa bea.\r\n\r\n________________________________________________________\r\n*pentru ingineri: <a href=\"http://www.amway.com/en/default.aspx\">Multi Level Marketing</a>','Filtru de apa Euro 4',0,'','publish','open','open','','filtru-de-apa-euro-4','','','2007-03-14 16:57:06','2007-03-14 14:57:06','',0,'http://www.groparu.ro/?p=76',0,'post','',0),(72,1,'2007-03-12 23:53:21','2007-03-12 21:53:21','','Venus',0,'','inherit','open','open','','venus','','','2007-03-12 23:53:21','2007-03-12 21:53:21','',-1173736253,'http://www.groparu.ro/wp-content/uploads/2007/03/venus.jpg',0,'post','image/jpeg',0),(73,1,'2007-03-13 00:00:50','2007-03-12 22:00:50','','Femeii',0,'','inherit','open','open','','femeii','','','2007-03-13 00:00:50','2007-03-12 22:00:50','',74,'http://www.groparu.ro/wp-content/uploads/2007/03/venus.jpg',0,'post','image/jpeg',0),(74,1,'2007-03-13 00:00:59','2007-03-12 22:00:59','<a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/venus.jpg\" title=\"Femeii\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/venus.jpg\" alt=\"Femeii\" /></a>\r\n<p style=\"text-align: right\">Lui <a href=\"http://www.cotidianul.ro/index.php?id=6404&amp;art=15952&amp;cHash=b86a57a671\">Emil Brumaru</a></p>\r\nSunt creÅŸtin, nu sunt pÄƒgÃ¢n,\r\nDar tot am sa te muÅŸc de sÃ¢n,\r\nÅži-am sÄƒ-l gust ÅŸi-am sÄƒ-l rÄƒscoc\r\nRotund ca un poloboc\r\nÃŽnspicat de-un sfÃ¢rc maro\r\nViÅŸiniu-negru caro;\r\nRotunjimea-i exemplarÄƒ\r\nAm sÄƒ o sÄƒrut cu-o narÄƒ\r\nÅži cu gura-nfometatÄƒ\r\nMai mult lungÄƒ decÃ¢t latÄƒ\r\nSforÄƒind de-anticipaÅ£ie\r\nAm s-o mozolesc cu graÅ£ie!\r\nPeriÅŸorii dintre sÃ¢ni\r\nSe vor revolta, pÄƒgÃ¢ni,\r\nÃŽncercÃ¢nd aÅŸa,-ntr-o doarÄƒ\r\nSÄƒ inÅ£epe a mea narÄƒ!\r\nPuful am sa Å£i-l ridic\r\nÃŽntr-un fel cum nu-mi explic\r\nDar cu brizÄƒ de vulcan\r\nIeÅŸita din trestie de Pan\r\nÃŽl voi adormi pe datÄƒ\r\nCu o pofta imbÄƒtatÄƒ\r\nDe atata bogaÅ£ie\r\nDatÄƒ mie, datÄƒ mie!\r\nScoborÃ¢ndu-mÄƒ la vale\r\nMai acolo, catre poale\r\nIscoding a tale coapse\r\nPocÄƒnind tot din sinapse\r\nDescoperi-voi regatul\r\nUnde trebuie palatul.\r\nCaci palatul gurii mele\r\nCautÄƒ grave belele\r\nCu miros de adormealÄƒ\r\nDrog curat de toropealÄƒ\r\nDrog stÃ¢rnit de-mbratiÅŸare\r\nTot mai strÃ¢nsÄƒ ÅŸi mai tare.\r\nDup-o vreme, mai tÃ¢rziu\r\nCand nu pot sÄƒ mÄƒ mai Å£iu\r\nFebrile mÃ¢ini ÅŸi amprente\r\nOr sa vrea sa te dezmierde\r\nRecreÃ®ndu-te intreagÄƒ\r\nMicÄƒ EvÄƒ, toatÄƒ goalÄƒ.\r\nCu ÅŸoapte, blestem ÅŸi cÃ¢nt\r\nTrupul am sa ti-l descÃ¢nt\r\nCu limba l-oi dezmierda\r\nSa nu fii a altuia!','Femeii',0,'','publish','open','open','','femeii','','','2007-03-13 00:02:42','2007-03-12 22:02:42','',0,'http://www.groparu.ro/?p=74',0,'post','',1),(77,1,'2007-03-13 00:06:03','2007-03-12 22:06:03','Umbla vorba prin targ ca noi, romanii, nu vom fi niciodata bogati. Ca pentru a fi bogat, trebuie sa fii comerciant, finca de acolo pica banu\', ori noi, noi suntem doar o natie de agricultori. In afara de scos un buchet de flori si un cos de rosii la poarta, in strada, nu stim sa facem comert. Cel mai elocvent exemplu in acest caz sunt hipermarketurile lanturilor internationale de retail, care vin in Romania... sa vanda produse romanesti. Si isi fac si un titlu de glorie din asta. \"Venim la voi in tzara, beeey, loserilor, sa va vindem voua produsele pe care tot voi le faceti!\"\r\n\r\nProblema marketingului romanesc nu e o problema de <strong>fond</strong>, ci una de <strong>adresare</strong>. Carui segment de piata se adreseaza intermediarul (tigan sau rroman) care vinde legume in piatza, care cumpara strugurii cu 8.000 lei de la tarani si ti-i vinde cu un euro jumate? Cand cumperi de la ei, iti vine sa le dai cu legatura de morcovi in cap sh sa le-o bagi in cur. Chiar daca iti face cel mai discount mare, te simti jecmanit. Sh il urasti. De moarte il urashti. Finca nu stie sa se faca placut. Si te plangi ca de-amu iti cumperi cumparaturile numa de la Kaufland, ca ai vazut tu, intr-o reclama, ca au numa legume pruaspete, tot din Turcia si Macedonia. \"Io nu le mai bag bani in buzunar la samsarii astia, sa-i ia dreq!\"\r\n\r\nOare chiar asa sa fie?\r\n\r\nA trebuit sa imi golesc portofelul in piatza ca sa imi dau seama de varful se sulita al marketingului romanesc. Marketing invatzat nu pe bancile scolii, la traininguri, team-buildinguri de dumineca sau la ASE, ISE, nu in piatza, ca negociatorii turci de talie internationala din bazar - ci la coada sapei (ceteshte mai jos).\r\n\r\n&lt;Pauza publicitara/&gt;\r\n\r\nBatranica.\r\n\r\nExact.\r\n\r\nBatranica e arma secreta a marketingului romanesc. De ce zic asta? Finca vreau sa imi aratati VOI pe cineva care sa aibe inima sa refuze o batranica de la tzara de la care vrea sa cumpere NUMAI oua si de la care pleaca cu:\r\nmorcovi,\r\nceapa,\r\nzacusca,\r\nlapte,\r\nnuci,\r\nmere,\r\ntelemea,\r\nridichi negre,\r\nfrunze de patrunjel si telina,\r\nhrean,\r\ncatina,\r\nstruguri,\r\nslanina,\r\nbaitzuri pentru incaltaminte\r\nun lacat chinezesc fara cheie\r\no mulineta din Vietnam cu rulmentu\' spart\r\no pereche de pantaloni scurti, dar patatzi cu ulei de motor\r\no pasta de dinti inceputa\r\nadidashi \"Uluslararasi\", unul verde, altul din piele de animal roz cu verde\r\nciorapi\r\nzarzavat de ciorbe\r\ndoua mileuri\r\npatru pungi albastre de-un leu cu 10.000 bucata\r\nun volum de poezii de un poet anonim rus, netradus\r\ngogoshar\r\nsireturi pentru intreaga familie\r\nun casetofon \"Ponasonic\"\r\nhrean\r\no coada de coasa lucrata manual, la strung\r\naceeasi miere ca la Billa, da\' mai scumpa\r\nun set intreg de ace de gamalie\r\ngulii\r\nsandale de plaja de dama\r\nun metru patrat de mocheta\r\nun spray Axe\r\nun Kalashnikov de jucarie, cu luminitze\r\no carcasa de Nokia 5110, desi am Motorola C385\r\no pereche de cizme de guma, usor dezlipite\r\no icoana cu Iisus, cu leduri, fara baterii\r\nun kil de turta dulce\r\nun Playboy din 2002\r\nridichi albe\r\npolen\r\no consola de jocuri cu caseta, cu joystick-ul rupt\r\no husa de telefon, decolorata si coapta de soare\r\n\r\nDaca vroia, batranica ne-ar fi bagat in UE din 1991. Dar n-a vrut, ca n-a intrebat-o nimeni. Si e si saraca si bolnava.','Baba si marketingul la romani',0,'','publish','open','open','','baba-si-marketingul-la-romani','','','2007-03-14 16:08:26','2007-03-14 14:08:26','',0,'http://www.groparu.ro/?p=77',0,'post','',0),(137,1,'2007-03-13 22:55:08','2007-03-13 20:55:08','Cand sarbatorea Revelionul la Sibiu, domnul presedinte Basescu declara ca, odata cu integrarea in UE, tranzitia s-a incheiat. O vreme am fost sigur ca tranzitia se incheia doar la pantaloni.\r\n\r\n<span>De ce? Pentru ca in Romania nu s-a schimbat nimic dupa aderare - nici la noi, nici la ei.</span>\r\n\r\nPentru ca odata ce am integrat Europa in Romania, membrii Comisiei Europene NU au inceput sa se certe cum se cearta onor premierul cu onor presedintele: soferul se cearta cu marinerul.\r\n\r\nPentru ca - exact ca pe vremea defunctei guvernari albastre - premierul tocmai a trecut o ordonanta prin care unui numar oarecare de companii de stat li se iertau datorii care insumau cam 1 miliard. Euro, dolari - ce mai conteaza? Propun schimbarea numelui in PNLSD.\r\n\r\nPentru ca toate balbele legislative si-au pastrat aceeasi scuza: \"directivele europene ne cer asta\". Vezi interzicerea transhumantzei. Ciobanii de politicieni au devenit gelosi si incearca sa isi pastreze mioarele la ei in judet, sa nu mai umble pe la alti berbeci, curvele dreq.\r\n\r\nDar daca a aparut anul acesta o stire care imi da o oarecare urma de speranta, iat-o: un hot i-a furat senatorului PNL Lupoi scuterul. Scuter simplu, nepoleit cu aur, fara motor de Hummer, fara girofar. Gestul hotului mi se pare normal deoarece daca onor domnu\' parlamentar folosea scuterul pentru a merge la munca, nu avea cum sa aiba nevoie de motorizare, deoarece parlamenterii nu muncesc.\r\n\r\n<span> </span>\r\n\r\n<span>De ce este asta o stire buna?  </span>\r\n\r\n<span>- daca in Romania parlamentarii nu mai pot ajunge la serviciu, atunci sunt sanse ca tara asta lasata de capul ei sa se dezvolte de la sine;\r\n- dupa furt pe drumurile patriei va circula un scuter parlamentar mai putin (deci putem rasufla usurati cand traversam zebrele pe verde);\r\n- am primit cel mai bun indiciu ca tranzitia e pe care sa se incheie: hotii au ajuns sa se fure intre ei.</span>\r\n\r\nSi apropos, s-a crezut multa vreme ca imunitatea parlamentara functioneaza si impotriva SIDA. Dar daca romanii incep sa se molipseasca de la o boala grea? DACA AM INCEPUT SA LUAM INAPOI CE NI S-A FURAT???:D','Cronica unei tranzitii nefinalizate',0,'','publish','open','open','','cronica-unei-tranzitii-nefinalizate','','','2007-03-13 23:07:13','2007-03-13 21:07:13','',0,'http://www.groparu.ro/?p=137',0,'post','',0),(78,1,'2007-03-13 00:07:05','2007-03-12 22:07:05','','Kitty',0,'','inherit','open','open','','kitty','','','2007-03-13 00:07:05','2007-03-12 22:07:05','',79,'http://www.groparu.ro/wp-content/uploads/2007/03/kitty.jpg',0,'post','image/jpeg',0),(79,1,'2007-03-13 00:07:48','2007-03-12 22:07:48','<a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/kitty.jpg\" title=\"Kitty\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/kitty.jpg\" style=\"width: 433px; height: 285px\" alt=\"Kitty\" /></a>\r\n\r\nA fost odata o domnisoara. Care domnisoara avea blog. Care domnisoara avea si prieteni care stie engleza. Care domnisoara stia si ea engleza, la un nivel decent, de alfel. Care domnisoara avea si vreo 16 milieoane ROL in poseta si o camera digitala, nu pentru placeri digitale, ci pentru facut poze digitale, aflata intr-o poseta analoaga dintr-o camera cu 4 paretzi, la fel de analoaga.\r\n\r\nIntr-o buna zi pe cand dormea au napadit-o hotii. Nu, nu  guvernantii, hotii de buzunare. Sau de apartamente. Sau de camere din camere. Si i-au furat tot ce au putut. Daca i-au facut mai mult decat atat, asta decide-ti dv.s din blogu-l dse-i.\r\n\r\nPS: for reference only,\r\n\r\n- rub = 1.a. To subject to the action of something that moves back and forth with friction and pressure. b. To cause to move along a surface with friction and pressure, adeca - <strong>a freca</strong>;\r\n\r\n- rob = 1. Law. To take property from (a person or persons) illegally by using or threatening to use violence or force; commit robbery upon. 2. To take valuable or desired articles unlawfully from: rob a bank, adeca <strong>a fura</strong>.','From the series: \"Yesterday, I couldn\'t spell \'educated\'. Now I are it!\"',0,'','publish','open','open','','from-the-series-yesterday-i-couldnt-spell-educated-now-i-are-it','','','2007-03-13 00:19:36','2007-03-12 22:19:36','',0,'http://www.groparu.ro/?p=79',0,'post','',3),(80,1,'2007-03-13 00:08:52','2007-03-12 22:08:52','','Ciai',0,'','inherit','open','open','','ciai','','','2007-03-13 00:08:52','2007-03-12 22:08:52','',81,'http://www.groparu.ro/wp-content/uploads/2007/03/ciai.jpg',0,'post','image/jpeg',0),(81,1,'2007-03-13 00:09:09','2007-03-12 22:09:09','Â <a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/ciai.jpg\" title=\"Ciai\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/ciai.jpg\" alt=\"Ciai\" /></a>\r\n\r\nEram in anu\' I de fuckultate. Proaspat cazat in caminu\' 16, cea mai WTC cladire din tata chestia aia la care americanii ii zic campus si noi ii spunem Hajdeu, ca se urca greu, pute ca un penteleu si e batrana ca Dejeu.\r\n\r\nDumnezeul studentilor, intr-o clipita de buna dispozitie (bag sama ca era dupa fo 3-4 beri bagate supt nas prin Niko), s-a impiedicat deasupra Romaniei, si din sacul cu daruri mi-or tat cazut sh loc in camin, si prima masina de ocazie ca student neplatita, si - si mai si, semn ca Atotputernicul era chiar in toate foarte bune - o amarata de bursa studenteasca, ce s-a oprit tocma in dreptul numelui meu pe lista. Supt mine - inca o persoana, chiar gajica (din pacate, numa\' pe lista sub mine) amandoi fericiti ca, din toti prostii sectiei, noi mai eram si platiti de prostii de contribuabili ai proastei de Romania.\r\n\r\nEi bine, \"pe vremea mea\" se statea la coada dupa bursa. Se statea vreo 2 ore. Si era noiembrie, si studentii atrageau burnitza. Si tat ploua si mazarikia peste noi, si degeaba ne inghesuiam ca in autobuz, ca eram numa palton frecat pe palton. Da\' pe toti ne incalzea caloriferul gandului ca punem labutzele pe imensa suma de 400.000 lei, ce mai, o mica avere in anii aia de glorie ai guvernului Vacaroiu! Kilu de lapte era mai ieftin ca berea, da berea nu-ti dadea gaze, numa iti presa vezica, de-ti trebuia batiscaf sa supravietuiesti acolo, daca erai parazit, parol!\r\n\r\nSi normal ca stateam cu cine altu\' decat dragutzu\' de Mitroa sa ÃŽMI iau bursa ca sa ÃŽI fac cinste, in virtutea unui mecanism logic foarte complicat, care functiona dupa principiile \"ai intrat la faculta, dai de baut\";Â  \"ai loc in camin, dai de baut\"; \"e marti, dai de baut\"; \"iei bursa, dai de baut!\" Si dupa ce m-am tot frecat de paltoanele unor domnisoare dragutze si foarte feminine din Basarabia care deja imi suradeau bovin, m-am trezit stapanul comorii - bursa pe doua luni, ca asa se dadeau pe vremea aia, se statea la coada si se primea retroactiv. Cand nu mai razbeam numarandu-i, pune laba pe mine un grizzly, de am si crezut ca ii peshtele din Tighina a lu\' tantile alea - noroc ca era Flaviu, flamand ca un urs, insetat ca un peshte si fara chef de glume. \"Ba, zice, fii antena: da mie banii sa ti-i tin, ca tu esti prost si ii baji in pokere; si de ei cumparam un pui si o sticla de vin, si merem la gajica-mea sa facem o friptura, si iti dam si tie!\"\r\n\r\nPuiul si vinul se cumpara, in tzara mea, de la Alimentara; asha ca purcedem spre un asemenea stabiliment si intram cu tupeu de bijnitzar inauntru. Inauntru - doua domnisoare, una urata si grasa, alta urata si slaba. Coshuri, ochelari, halat soios cu sange inchegat, paine servita direct cu mana. Coc cu fire de par rebele, presupun cu lindeni, ureche innegrita. Scurmat in nas si taiat parizer cu aceeasi manutza, dat rest o lama Orbit sau o caramea. \"Formula As\" sub tejghea. Tot tacamu. Da\' tinere si cu chef de ras.\r\nIncep:\r\n-  Puiutz!\r\n-??\r\n- Puiutz!!!\r\nSe hlizeshte, si chiar rade.\r\n- Imi  dai?\r\n- Ce sa-ti dau?\r\n- Pai ce poti primi de la un puiutz?\r\nIara rade,  de parca is Stan si Bran.\r\n- Hai, ca am planuri mari, zic io.\r\n- Ce  planuri, icneshte domnisoara.\r\n- Vreau sa iau ce-mi dai tu si sa il pun sa  faca sex cu o sticla. Serios.\r\nSe uita intrebatoare la mine. Ii explic:\r\n- Mai puiutz, iau puiul si il fac la cuptior cu o sticla bagata-n intrarea de sub spate. Iese bestial. Se rumeneshte si ramane carnea cu crusta si totusi moale. Clar ca nu are ce iesi rau daca e vorba de chestii bagate in maruntaie.\r\nAmandoo rade.\r\n- Si pe noi nu ne inviti?\r\n- Cum sa nu, zic, sa vezi ce puiutz o sa am! E bestial, v-ar place, zic io, facand cu ochiu ca imi intrase o musca, fix in mijlocu\' lunii noiembrie, intre iris, stelute si bastonase.\r\nDeja eram servit cu o felie de parizer si o maslina din partea  casei. Aia mai grasa isi ascundea firele rebele supt boneta.\r\nMai vin doi pensionari sa isi ia parizer, pleaca. Noi ne lom o bere si ne asezam la masutza din inauntru si sorbim. Pe-ndelete. Din bursa mea. Ursus verde.\r\nIntra o babojnitza preistorica. \"Mama mea, zice una dintre ele, mama, uite, ei sunt studenti!\" Venerabila doamna vrea sa ne pice la picioare sa ne spele picioarele cu parul ei, dar o oprim la timp. Glumeste cu noi.\r\n\r\nTerminam berea, si merem sa platim. Flaviu scoate portofelu LUI cu bursa MEA si le lasa ciubuc gras. Cand scotea mai abitir bancnotele de hartie, aluneca un pliculetz. Pe asta il podideshte rasul de o si facut baloane pe nas si imi arata: \"Ceai Laxativ\". Pe asta il constipau tigarile si berea, si statea cate un deceniu la buda. Vad plicul si clar ca rad si io si le aratam si lor. Tipele, pe spate de extaz:\r\n- Ceai <strong>relaxativ</strong>??? Cum e  asta?\r\n- Te relaxeaza, zice Flaviu,Â  cu fatza de sculptura.\r\n- Cum te relaxeaza???\r\n- Bine, zice sfantul din vitraliu, te asezi... si te relaxezi de n-ai nici o treaba! E pentru sesiune, zice el, dandu-si seama rapid de potentialul fazei. E de la mama, care e medic ginecolog, si care m-a invatzat tot ce stiu.\r\n- Vai ce fain de voi, zice tanti, ca va puteti relaxa band ceai, zice, ca aici la noi la servici e atata stress... ghe numa!\r\nFlaviu si-a asezat ochii stramb si a judecat drept. Oricum ajung in iad, se gandeshte, oricum. Orice as mai face de acuma incolo. Nu mai am scapare. Si atunci s-a exprimat cum se exprima porcu\' ala care intra vara in beserica pentru ca podelele de lemn ii tzin racoare, si de fericire se caca langa altar.\r\n- Fetelor, zice el, uite ce e. Asta e un ceai foarte scump, luat pe reteta.\r\n\r\nSi facu o pauza. Strategica.\r\n\r\n- Vi-l dau voua. Va rog sa-l primiti. E foarte bun.\r\n- Nu, ca nu ne trebe.... lasa, poate iti trebe tie, mai ales daca e scump.\r\n- Fetelor, zice Flaviu, si le fixeaza ca un boa care ataca un pui de caprioara. Mai incerca o data sa reziste tentatiei, dar Flaviu nu poate niciodata sa reziste tentatiei. Nici eu.\r\n\r\nSi mai face o pauza.\r\n\r\n- Va rog. Din partea noastra.\r\n\r\nSi tace din gura. Si o mai si inchide.\r\n\r\nLinistea cobori ca o mantie a inserarii peste borcanele de mustar. In puterea incremenirii, auzeam cum se strange membrana necomestibila a parizerului peste tubul rozaliu, si cum se deshidrateaza maslinele turcesti. Dintr-o data, telemeaua nu mai vorbea cu icrele de crap, iar sticlele de bere Ursus verde priveau undeva, in zare, spre pesmet.\r\n\r\nIn mintea negustoreselor se dadea o batalie surda. Si muta. Si retardata. Intr-un final apoteotic, privirea heruvimica a Flaviului le-a indemnat spre catehism. Nu se refuza darul unui crestin. Nu. Asa ceva nu. Batalia din capul lor lua sfarsit.\r\n\r\n- Dar il beti aici, si acum, zice Flaviu, subtilizand prospectul pliculetului. Credeti-ma. E foarte bun la gust. Santalul de portocale rosii de Sicilia o sa vi se para apa de la robinet.\r\n\r\nStam si ne uitam teleghidati cum domnisoarele umplu un ibric cu apa, si zburda ca niste iele in spate (niciodata nu am stiut ce se intampla acolo unde scrie \"Accesul Interzis\"). Auzim un aragaz ca isi da drumu cu un oftat, si un chibrit cum scapara. E gata. Pliculetul nu mai are scapare.\r\n\r\nAm mai stat in magazin numai pana cand i-au dat si batranei sa bea, si tanti a baut prelung, ca afara era frig, si ceaiul era cald. Si bun. Noi am refuzat, politicos. Fetele au topit doua linguritze de zahar in cana si s-au suparat una pe alta ca una a baut mai mult decat cealalta. Noi ne-am luat puiul si sticla de vin si am plecat cu promisiunea de a reveni, convinsi ca Dumnezeu va trimite o masina sa ne calce peste mainile care au dat si gura care a mintit. Inca o asteptam sa vina si in ziua de azi.\r\n\r\nIn seara aceea am papat cel mai bun pui facut pe sticla din viatza mea. Si ii multumesc lui Flaviu ca mi-a dat si mie. Ca asa m-am ales si eu cu ceva din bursa mea, ca restul banilor nu i-am mai vazut nici in ziua de azi. Presupun ca or sa vina odata cu mashina aia. Da\' l-am batut la table pe Flaviu si pedeapsa a fost sa mearga a doua zi la magazin sa vada daca tipele nu erau cumva in concediu medical. Dar nu s-a mai dus. Presupun ca va merge dupa ce ne va calca masina aia.','Ceai re-laxativ',0,'','publish','open','open','','ceai-re-laxativ','','','2007-03-13 00:09:09','2007-03-12 22:09:09','',0,'http://www.groparu.ro/?p=81',0,'post','',1),(82,1,'2007-03-13 00:09:54','2007-03-12 22:09:54','<span style=\"font-family: Georgia,Helvetica\">Jean Francois Duclos era lectoru\' francez de la Litere. Un soi de Domnu\' Trandafir.</span>\r\n\r\n<span style=\"font-family: Georgia,Helvetica\">Era tip de treaba. Avea 29 de ani, sh colegele mele erau moarte dupa el. Ca sa te placa studentele, trebe numa\' sa fii tinar si timid. Si sa le predai. Stiu, finca si pe mine m-or iubit studentele cand predam. Unele asa de mult, ca nici acuma nu-mi raspund la salut pe strada.</span>\r\n\r\n<span style=\"font-family: Georgia,Helvetica\">Io ii eram prekin bun (desi vorbeam franceza aproape exclusiv cu mainile), normal, doara imparteam povara de sex symbol cu nenea. Si am mai si avut curajul nebun de anu\' I sa il scot la bere dupa curs. </span>\r\n\r\n<span style=\"font-family: Georgia,Helvetica\">Ei bine, si finca inca de cand eram student amarit si vai de natia mea in anu\' I aveam mania de a trece pragul de batrinete dintre ani anesteziat cu votca eftina, si inconjurat de oameni care ma dispretuiesc, mi-am chemat toata sectia de engleza la cheful de ziua mea. Si la cererea publicului l-am chemat si pe Jean Francois. Care Jean Francois nu a binevoit sa isi faca aparitia. Rezonul - \"am adormit fara scapare pe la 9 seara!\"</span>\r\n\r\n<span style=\"font-family: Georgia,Helvetica\">Dar finca Jean Francois era baiat finutz, mi-o adus o sticloantza de vin luni, ca sa isi indulceasca scuzele. Asa ca i-am promis ca aia o vom bea impreuna. Promisiune pe care am uitat-o in momentul in care am ajuns cu sticloantza la camin si un palier intreg a inceput sa saliveze din abundentza, si am decis sa o sacrificam ca pe un fond nerambursabil. Asa ca - ca sa ma scot - i-am zis lu nenea din Languedoc ca il chem la mine la camin sa papam ceva si sa bem vin de casa. La care domnu\' imi zice ba, Gropare, da\' io is cu girlfriendu\' meu care e american si o venit sa ma vaza in Cluj, poci pentru ca sa vin cu ea? Sh io am zis \"the more, the merrier!\" in franceza, sh am tzajnit acasica sa ii fac lu nenea si lu tanti papa.</span>\r\n\r\n<span style=\"font-family: Georgia,Helvetica\">Amu, astia care ati stat in 14 stiti ce greu se punea labutza pe un ochi de aragaz la oficiu. Si io aveam planuri mari pentru cuplu franco-american: tocanitza de ceapa, mamaliga si chiftele. Dupa ce m-am luptat din greu, am reusit. Atata numa ca tocanitza de ceapa nu s-o fiert indeajuns si cam pisca ochii, mamaliga s-o prins pe fund si avea gust de peste, iar chiftelele or iesit doar ce erau ele cu adevarat: carne tocata din fabricatie si prajita cu ceapa. Da\' nu era stress, ca pe atunci mancam orice. Si si acuma. Numa sa aibe alcool.</span>\r\n\r\n<span style=\"font-family: Georgia,Helvetica\">Si - pe la 9 si 15 minute seara fix - se aude o bataie timida in usa caminului. Gospodaru\' de mine tzajneste la usa, pe care o si deschide cu un zambet larg si cu mana dreapta, si ii saluta pe Francois si prekina-sa. </span>\r\n\r\n<font style=\"font-family: Georgia,Helvetica\" size=\"4\">Gafa nr. 1.</font><span style=\"font-family: Georgia,Helvetica\"> </span>\r\n<span style=\"font-family: Georgia,Helvetica\">Jean Francois, fiind baiat subtire, avea cu el inca o sticloantza de vin si o sticla de apa minerala pentru consum intern, apa al carei nume nu am de gand sa il scriu, ca dupa aia zicetz ca fac reclama la Izvorul Minunilor. Dar clar ca prima mea reactie a fost: \"Ba, Jeane, ba, proz esti! Asta nu e apa minerala, ma! Asta e sifon, ma! Sa nu mai dai banii pe asa ceva...\"</span>\r\n\r\n<font style=\"font-family: Georgia,Helvetica\" size=\"4\">Gara nr. 2.</font>\r\n<span style=\"font-family: Georgia,Helvetica\">Insfac sticla de vin din manutza omului, ca sa imi treaca jena ca disconsiderasem cadou\' omului. Caut in disperare un tirbuson pe care stiam ca nu il aveam. Tot la disperare o tzajnesc prin camin sa caut un tirbushon pe care stiam cu sigurantza ca nu il avea nimeni, ca erau vremuri grele, hai! nu se bea decat vin la badoc de plastic, din melasa, nu vin la sticla cu dop de pluta, tot din melasa. Urmare a esecului sa descopar un asemenea instrument demn de Homo Sapiens Diluvialis, ca un roman ce sunt, ce fac? Improvizez! Iau lingura de lemn plina de mamaliga, si ii infig cu putere coada pe gatul sticlei, sa bag dopu inauntru, ca in afara nu il puteam baga. Jean tinea cu amandoua cracile de gatul sticlei. Si cum impingeam eu si el tinea, zborsht!!!!! crapa gatul sticlei in 8934 de tzandari, pica un crihan zdravan de mamaliga intarita in vin si il si tai la manutza pe delicatul lector francez. Care lesina cand vede sange.</span>\r\n\r\n<span style=\"font-family: Georgia,Helvetica\">Amu, nu puteam arunca bunatate de vin numa finca cazuse neshte mamaliga in el. Si cioburi de sticla, care cica perforeaza burtile. Asa ca am filtrat vinoasele printr-un servetel de nas putin folosit, cu miros de menta. Si toata seara am baut vin romanesc cu sange de francez cu mamaliga din malai unguresc si aroma de servetel de nas tot unguresc. Cred ca le-a placut, finca s-or strambat de placere.</span>\r\n\r\n<font style=\"font-family: Georgia,Helvetica\" size=\"4\">Gafa nr. 3.</font>\r\n<span style=\"font-family: Georgia,Helvetica\">(stiu ca nu se pune punct dupa titlu, da\' io-s mai jmeker)</span>\r\n<span style=\"font-family: Georgia,Helvetica\">Deci, papam, astia refuza politicos sa mai bage sub nas dupa primele trei dumicaturi - cica nu le era foame, tocmai mancasera - si ne apucam sa discutam. Nu, gafa asta nu am facut-o cand am ras de accentul lui cand vorbea engleza (cine a auzit francezi vorbind engleza, stie despre ce vorbesc!), si nici cand i-am intrebat daca au de gand sa se marite unu cu alta si daca e OK ca Frantza s-a predat in al doilea razboi mondial si ca de ce au francezii ce au cu americanii si ca vinurile franceze is zero in comparatie cu vinurile noastre din melasa sh pastile contraceptive sh ca n-s putea trai niciodata in Franta sau America si ca francezii is perfizi si increzuti si americanii neste inculti si ca de ce franceza suna gay si ca daca e adevarat ca frantuzoaicele is neste flusturatice si ca de ce toti starletii de cinema francezi is la fel de sau si mai urati ca Belmondo. Nu. Gafa a fost cand le-am zis bancu ala fara perdea. Cu Oedip. Oedip, no! Ala a lu\' Laius, a lu\' Cadmus, si a lu\' Iocasta, aia de-o tinea in palat. Si no! Bancu e vechi, ca intra Oedip intr-un bar si zice la baieti \"Hello, guyz!\", si baietii ii zice \"Hello, motherf^*&amp;%$!\"</span>\r\n\r\n<span style=\"font-family: Georgia,Helvetica\">4 minute mai tarziu eram singur, gandindu-ma ca sloganurile revolutiei franceze \"C</span><span style=\"font-size: 10pt; font-family: Georgia,Helvetica\">Ã©</span><span style=\"font-family: Georgia,Helvetica\">ap</span><span style=\"font-size: 10pt; font-family: Georgia,Helvetica\">Ã©</span><span style=\"font-family: Georgia,Helvetica\">, mamaligu</span><span style=\"font-size: 10pt; font-family: Georgia,Helvetica\">Ã©, chiftelÃ©\" nu mai sunt ce erau odata. Bag sama ca daca ii dadeam sa pape melci si broaste era mai bine!!!</span>','Trei gafe cu Jean Francois Duclos',0,'','publish','open','open','','trei-gafe-cu-jean-francois-duclos','','','2007-03-14 16:56:10','2007-03-14 14:56:10','',0,'http://www.groparu.ro/?p=82',0,'post','',6),(83,1,'2007-03-13 00:11:36','2007-03-12 22:11:36','','Vaca sexuala',0,'','inherit','open','open','','vaca-sexuala','','','2007-03-13 00:11:36','2007-03-12 22:11:36','',84,'http://www.groparu.ro/wp-content/uploads/2007/03/13e0.jpg',0,'post','image/jpeg',0),(84,1,'2007-03-13 00:12:07','2007-03-12 22:12:07','Â <a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/13e0.jpg\" title=\"Vaca sexuala\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/13e0.jpg\" alt=\"Vaca sexuala\" /></a>\r\n\r\nZice-se ca, vazand conditiile in care sunt tratate bovinele la mine-n tzara, europenii s-au hotarat sa ia taurul de coarne si sa intervina. Si sa emaneze ca dupa integrare telemeaua de la mine din Sibiu nu va mai fi buna, ca cica nu mai ai voie sa mamelesti oile cand le mulgi, trebe sa le curentezi cu mulgatoare electrica.\r\n\r\n\r\n\r\nBullshit.\r\n\r\n\r\n\r\nCine o decretat chestia asta bag sama ca o avut ceva copilarie de asfalt fara gropi. Se juca vara in locuri special amenajate cu nisip prin parc, si miorlaia cand ii intra o pietricica in sandalutze. Care mergea la mall cu mamica lui in masina combi cu scaunel special de copii, manca ciocolata din aia cu E-uri si OB-uri si se caca pe el de fericire ca il lasa mami sa-si tina ziua la McDo. Care incurca oile cu duliile si caprele cu bujiile. Care face diarie severa cand papa lapte nepasteurizat. Sa mance ma-ta branza din aia, ba!\r\n\r\nEu propun sa il luam pe nenea ala ca sa ne explice si noo cum trebuie sa obtinem lapte pentru telemea, in viziunea domniei sale. Propun prima data sa scoata vaca la o cofetarie, la un suc si o prajitura. Dupa aia, sa iasa cu ea la un film (recomand \"Pacientul englez\"), sa o tina duios de o copita si sa se abtina sa ii pipaie ugerul, ca un nesimtit, de la prima intalnire. Sa plece apoi cu ea acasa, in grajdiul ei, si acolo sa o mangaie duios, intre coarne, si sa o lase sa ii linga drobul de sare. Sa ii faca apoi un dush cu noul spumant de baie de la L\'Oreal cu extract de migdale amare si sa o dea cu crema aia care cica are efect de double-lifting - pana vacutza ajunge fericita pana la ultima shuvitza. Nu va avea voie sa isi faca cruce inainte de a se repezi la tzatzele ei, cum fac romanii, ca s-ar putea ca vaca sa fie musulmana, atee sau scientologica (asta din urma mai ales daca e fana <a href=\"http://www.scientology-kills.org/celebrities/cruise.htm\">Tom Cruise</a>), si nu e politically correct. Nu are voie sa se stearga pe labe cu prosoape, ca Europa e nervoasa cand e vorba de voaluri. Apoi va trebui sa incerce sa convinga vacutza ca intre mainile viguroase si fierbinti ale ciobanului si capacele alea reci ale mulgatoarei e de preferat a doua optiune. Adeca fetelor, nu mai faceti amor cu cartilagiu\' masculului, infigeti-va dreq o tija de fier rece prin locurile moi si cretze si vedeti ce bine o sa va fie.\r\n\r\nSi inca ceva. Daca totusi vacile (acum cu 12,4% mai fericite) vor avea chef si de altceva, nenea poate sa foloseasca cu mare incredere unul din urmatoarele produse, ca va trebui, ca un bou ce este, sa le consoleze el insusi pe mugitoare, dar numai daca vitzica e majora:\r\n<ul>\r\n	<li><a href=\"http://www.sextoys.co.uk/Fun-Vibrators.asp\">Fun Vibrators<span class=\"red\"></span></a></li>\r\n	<li><a href=\"http://www.sextoys.co.uk/Classic-Vibrators.asp\">Classic Vibrators<span class=\"red\"></span></a></li>\r\n	<li><a href=\"http://www.sextoys.co.uk/Jelly-Vibrators.asp\">Jelly Vibrators<span class=\"red\"></span></a></li>\r\n	<li><a href=\"http://www.sextoys.co.uk/Rabbit-Vibrators.asp\">Rabbit Vibrators<span class=\"red\"></span></a></li>\r\n	<li><a href=\"http://www.sextoys.co.uk/Kits-and-Eggs.asp\">Kits and Eggs<span class=\"red\"></span></a></li>\r\n	<li><a href=\"http://www.sextoys.co.uk/Strap-On-Vibes.asp\">Strap On Vibes<span class=\"red\"></span></a></li>\r\n	<li><a href=\"http://www.sextoys.co.uk/Realistic.asp\">Realistic<span class=\"red\"></span></a></li>\r\n	<li><a href=\"http://www.sextoys.co.uk/G-Spot.asp\">G Spot</a></li>\r\n</ul>\r\nDar distractia numa amu incepe. Daca tot ce e vaca trebe mulsa electric, cum dracu\', Doamne, iarta-ma, racordam si Vaca Domnului la intranetul european al mulgatoarelor electrice? Daca importam vaci sacre din India, nu trebuie sa binecuvantam prima data mulgatoarele? Ce ne facem cu vacile lesbiene care vor vrea sa adopte vitei? Daca unele vaci vor vrea sa asculte manele in grajd? Producatorii de vaci gonflabile nu vor trebui sa plateasca Â©copyright vacutelor? Pola me!','Vaca sexuala',0,'','publish','open','open','','vaca-sexuala','','','2007-03-13 00:12:07','2007-03-12 22:12:07','',0,'http://www.groparu.ro/?p=84',0,'post','',0),(85,1,'2007-03-13 00:12:46','2007-03-12 22:12:46','<font size=\"4\">Nu</font>\r\n\r\n- Hainele ei costa dublu. Mai ales daca trebuie sa ii cumperi doua perechi de blugi din care sa isi faca una singura.\r\n- Daca ai masina mica, s-ar putea sa fii nevoit sa schimbi amortizoarele cam des. Asta e scump.\r\n- Daca e genul care se imbata la chefuri, trebuie dusa acasa. Ca sa faci asta de unul singur trebuie sa mergi la sala.\r\n- Se poate rostogoli in somn cand dormi cu ea in pat si sa te inabuse. Asta nu e prea bine.\r\n- Daca o omori, e mai greu sa o bagi intr-un sac si sa o ingropi in gradina sau in pivnita. Trebe ciopartita, si deja se complica lucrurile. Daca o ingropi in pivnitza, trebuie scos pamantul afara, si e greu pentru ca se prind vecinii. Numa cand te gandesti te cuprinde un sentiment de neputinta geaman cu ce am simtit eu cand eram in Danemarca si romanii aveau de ales intre Vadim si Iliescu.\r\n\r\n\r\n<font size=\"4\">Da</font>\r\n\r\n- Are forme, mai copii. Are!\r\n- Daca ai masina mica, castigi spatiu cu covata pe care o face in scaun. Din acest moment poti transporta mai mult ciment si mai multi cartofi cu masina.\r\n- Daca nu incape pe la casele de marcat in Cora, poate iesi pe intrarea principala, si atunci ii mai poti strecura produse pe care sa nu le platesti.\r\n- Arabii. Pentru arabi, o femeie care nu arata cat 4 sclave din fatza si cat 6 din spate nu e femeie. Si nu are voie sa se poata ridica din pat fara ajutorul unei sclave. Intrebati-o pe Seherezada daca nu ma credeti!\r\n- Daca ti-e teama ca o sa te inabuse in somn, poti pune o jumatate de duzina de arici sa doarma cu voi in pat.\r\n- Are sanse sa devina prima femeie politician pentru grasani. Asta inseamna fonduri Phare deturnate, deci mai multa shunca pe masa.\r\n- Daca naufragiezi cu ea pe o insula pustie, ai papa pentru o luna.\r\n\r\nARGUMENTUL FINAL\r\nShakespeare. Ma reproduc si parafrazez din memorie: \"mai bine sa fii inconjurat de oameni dolofani, cu par carliontzat, decat de din aia slabi, slabanogi, uscati, etc!\"\r\n\r\n\r\n\r\nEu sunt un tip care ar face bine sa mai puie ceva kile pe oase.','Nevasta grasa - da sau nu?',0,'','publish','open','open','','nevasta-grasa-da-sau-nu','','','2007-03-13 00:12:46','2007-03-12 22:12:46','',0,'http://www.groparu.ro/?p=85',0,'post','',0),(86,1,'2007-03-13 00:13:12','2007-03-12 22:13:12','Ca un stol de popice in care intra o bila de bowling din aia neagra, cu trei gauri, aruncata de un jucator furios ca rad pretenii de el ca e handicapat.\r\n\r\nCa o oaie care cade in prapastie si in cadere se sparge toata de stanca, plesnindu-si incheieturile de parca ar fi umpluta cu rumegus.\r\n\r\nCa un os aruncat de un vultur de o stanca de la 400 de metri, ca sa-l sparga sa-i poata bea maduva, ca la inaltimi nu se serveste bere.\r\n\r\nCa un accident la 120 km/h, in care mor o printesa englezeasca sh un egiptean putred de indragostiti, si masina se face armonica de un stalp. Si se mai si aude ecoul in tunel ca o impuscatura.\r\n\r\nCa un muflon care ii arde un cap intre coarne rivalului care vrea sa se joace de-a animalu\' cu doua spinari cu femelele din gashca.\r\n\r\nCa un bob de grindina de 2 kile care cade in parbrizul masinii sh il face praf.\r\n\r\nCa doua turnuri gemene care se prabusesc.\r\n\r\nCa podul de pe River Quai.\r\n\r\nCa o tasta izbita cu furie de doua maini care scriu in stil \"vultur\".\r\n\r\nCa un parasutist caruia nu i se deschide parasuta, fir-ar a dreq.\r\n\r\nCa un alpinist care coboara in rapel sh i se rupe cordelina.\r\n\r\nCa o veveritza din aia australiaca de se arunca dintr-un copac in altu\'.\r\n\r\nCa copilu ala din reclama la purtat centura de sigurantza, de iese prin parbriz si ii ramane pantofu.\r\n\r\nCa un stejar din Borzesti care pica supt drujba ilegala.\r\n\r\n\r\n\r\n\r\n\r\n\r\nCam asta va fi impactul preconizat dintre mine si pat, in seara asta.','Ca un Hiroshim mai mic',0,'','publish','open','open','','ca-un-hiroshim-mai-mic','','','2007-03-13 00:13:12','2007-03-12 22:13:12','',0,'http://www.groparu.ro/?p=86',0,'post','',0),(87,1,'2007-03-13 00:14:17','2007-03-12 22:14:17','Normal ca cel mai faimos citat despre nume care imi vine amu in minte ii ala din Shakespeare, actul II scena 2 cand Julieta (nume pe care l-am intalnit si in patria mea) se planje la luna ca\r\n\r\n\"What\'s in a name? That which we call a rose\r\nBy any other name would smell as sweet\"\r\n\r\nsau\r\n\r\n\"Un nume ce-i? Un trandafir, oricum\r\nIi spui, iti da acelasi scump parfum\" (traducere Dan Dutescu, cred...)\r\n\r\nDupa ce am stat o vreme sh m-am gandit adinc, mi-am zis: numele sunt o chestie interesanta. Mie nu prea-mi pasa de nume, dovada ca pentru mine pe toti masculii ii kiama \"Nelu\", iar femeilor ma adresez adesea dupa prenumele fostelor mele prietene. Lor le place asta, ca se inrosesc si le sclipesc ochii de parca-s de laser sh devin mai focoase, asa, mai ales daca is pretenele mele actuale.\r\n\r\nUite, in schimb, un nume pe care nu as avea cum sa il confund este <a href=\"http://www.hotnews.ro/articol_38581-Doina-Jalea-redactor-sef-la-Radio-Romania-Actualitati.htm\">Doina Jalea</a>, care nu are rolul de substantiv sh atributul sau. Cred ca Jalea e numele de familie, dar clar ca nu m-as adresa ei cu \"Doina\". Alte exemple de folosire a numelui de familie in loc de prenume: Pacu\' (shafu\' meu - de la Pacurar), cindre, coprea (colegi de serviciu, denumiti ca atare dupa numele calculatorului din retzea), sysAlin (coleg de serviciu care lucreaza ca SysAdmin), bineinteles, Mitroa (de la Mitroiu) sh Groparu (care de fapt nu e numele meu). Despre ultimu pot zice ca i se mai spune sh Gropower, Groppyko, Groapa, Gropescu, iar penultimului i se mai zice si Greuceanu.\r\n\r\nOricum, daca ar fi sa am maine un copil (pe care sper sa nu-l nasc eu) in nici un caz nu l-as numi Stelutza, Moise, Jesus, Logan, Zorro, Rozalia, Mugurel. Si nici nu as incredintza alegerea unui nume urmatoarelor personaje:\r\n\r\n1. Unui armean. Nu as vrea sa aiba ca prenume Varujan, Pambuccian, Horasangian, Vosganian, Tavitian, Horasangian.\r\n\r\n2. Unui roman din partea rurala a Olteniei. S-ar putea sa il boteze Ion (nume de sluga) sau Marin (si atunci il vedem pe Al Jazeera, cum ca irakienii au prins un <em>Romanian Marine</em> pe care vor sa-l egorjeze)\r\n\r\n3. Unui anume profesor de istorie pe care nu am avut fericirea sa-l cunosc. Dar ii stiu copiii gemeni. Pe ea o cheama Memoranda Supplexa, iar pe el Memorandum Supplex. Fara vraja. Prescurtare: Mema sh Memo.\r\n\r\n4. Familiei fostului meu elev Strugurel Comitel Cutzitar. Ten un pic cacaniu, dar baiat de treaba. Cerseste si acum in fatza la Music Pub.\r\n\r\n5. Familiei fostei mele colege de clasa Patricia. Sefa de promotie. Care are doua surori - Constantza sh Sperantza.\r\n\r\n6. Familiei prietenului meu Silvan. Care merita o dezbatere aparte. Ma rog, Silvan cred ca e singura persoana sau om din Romania pe care o/il cheama asa, si el e taaaare mandru de asta.\r\n\r\nPartea cea mai faina numa\' amu urmeaza. Silvan are doo surori. Pe una o cheama Izvora, si pe cealalta StÃ¢niÅŸoara.\r\n\r\nDar partea cea mai si mai faina abia acum urmeaza. Izvora are acum un baietel pe care l-a botezat Zeus.\r\n\r\nAsta ca sa nu sufere numai ea.','Despre nume',0,'','publish','open','open','','despre-nume','','','2007-03-14 16:54:55','2007-03-14 14:54:55','',0,'http://www.groparu.ro/?p=87',0,'post','',3),(88,1,'2007-03-13 00:15:17','2007-03-12 22:15:17','','kika',0,'','inherit','open','open','','kika','','','2007-03-13 00:15:17','2007-03-12 22:15:17','',89,'http://www.groparu.ro/wp-content/uploads/2007/03/kika.jpg',0,'post','image/jpeg',0),(89,1,'2007-03-13 00:15:33','2007-03-12 22:15:33','<a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/kika.jpg\" title=\"kika\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/kika.jpg\" alt=\"kika\" /></a>\r\n\r\n<strong>Da. De ce asiatica?</strong>\r\n1. Daca esti urat, urat-urat, si nu te vrea nimeni, DA\' NIMENI, speri ca femeile asiatice au ochii mijiti, nu vad bine cu ei, ele te vad frumos, cand de fapt nu esti, ca ele au ochii mijiti si nu vad bine cu ei.\r\n2. Daca vezi o gajica mai faina, ii spui ca asiatica e fiica-ta (ca astea is mici) si ii ceri un numar de telefon.\r\n3. Isi poate gasi oricand job in domenul textil.\r\n\r\n<strong>De ce negresa?</strong>\r\n1. Buzele. Daca se infunda buda nu mai trebe vidanjor.\r\n2. Daca nu ai chef de sex, stingi lumina, te ascunzi si a doua zi ii spui ca nu ai mai gasit-o in intunericul negru.\r\n3. Iti da senzatia ca ai pula mare. Ca doar de-aia te-o preferat unui negru!\r\n\r\n<strong>De ce araboaica?</strong>\r\n1. Nu apuci sa ii vezi fatza dimineatza.\r\n2. Nu apuci sa ii vezi fatza dimineatza.\r\n3. Nu apuci sa ii vezi fatza dimineatza.\r\n+\r\n4. (bonus) - nu bea alcool, deci poate conduce masina acasa.\r\n\r\n<strong>De ce evreica?</strong>\r\n1. Are unchi bijutier in Antwerp.\r\n2. Iti lasa tie sa mananci tot porcu\', piftiile si carnatii de Craciun.\r\n3. Daca protocoalele inteleptilor Sionului sunt adevarate, vei avea o pila in Noua Ordine Mondiala.\r\n\r\n<strong>De ce unguroaica?</strong>\r\n1. Ai un sentiment de mandrie nationala cand faci dragoste cu ea.\r\n2. Oricat de beat esti, nu te poti inscrie in PRM ca nu te primesc aia.\r\n3. Inveti sa injuri in ungureste, ceea ce se poate dovedi util intr-o buna zi cetzoasa in care treci vama.\r\n\r\n<strong>De ce rusoaica?</strong>\r\n1. Te indeamna sa bei.\r\n2. Daca o iei in goarna intr-un bar ii in stare sa ii omoare pe derbedeii aia.\r\n3. Daca vrea sa te omoare, o face curat si fara durere, cu Poloniu 210.\r\n\r\n<strong>De ce eschimosa?</strong>\r\n1. Daca ai putza mica ii explici ca \"e de la frig\".\r\n2. Nu te bate la cap sa nu mananci grasimi.\r\n3. Poti face <em>swinging</em> cu  nevasta vecinului, sh asta numa daca ii faci o vizita.\r\n\r\n<strong>De ce Maori?</strong>\r\n1. Nu mai pierzi vremea cu dezbracatul: pur si simplu dai de o parte si de alta fusta de ierburi.\r\n2. Vezi toti sanii prietenelor ei.\r\n3. Daca vrei sa scapi de ea o trimiti la pescuit intr-o zona infestata de rechini, si ii faci o gaura mica in piroga.\r\n\r\n<strong>De ce tiganca?</strong>\r\n1. Dai ceva bani pe ea, dar o iei fata mare si ramane a ta indiferent cat de porc esti.\r\n2. Daca te supara vreun nesimtit, vorbesti cu fratii ei sa vina cu iataganele + nu platesti impozite.\r\n3. Fusta aia sexy te provoaca si la 90 de ani.\r\n\r\n<strong>De ce romanca?</strong>\r\n1. Sarmale, carnatz, ciorba, sters prafu\', gatit, spalat.\r\n2. Mori inaintea ei cu mult.\r\n3. Le canta fain copiilor tai sa adoarma.','De ce asiatica?',0,'','publish','open','open','','de-ce-asiatica','','','2007-03-13 00:15:33','2007-03-12 22:15:33','',0,'http://www.groparu.ro/?p=89',0,'post','',0),(90,1,'2007-03-13 00:15:57','2007-03-12 22:15:57','Ba, si numa ce-mi apare Mos Nicolae in vis, si se apuca sa dialogheze cu mine tocma cand aveam un vis erotic cu negrese din Tailan-dala, si eram sultanu\' din Brunei, in anii in care petrolu\' era mai scump ca amu. In visu meu, Mosu\' avea barbia lu\' Becali.\r\n\r\n- Ba, zice, Gropare, vezi ca daca iti pui o dorintza in noaptea asta magica se indeplineste, ca io indeplinesc dorinti. Una pe cap de vita furajata.\r\n- Mosule, zic io, e clar. Stii ce imi doresc eu cel mai mult pe lumea asta. Sa mi se indeplineasca orice dorintza, normal.\r\n- Nu, ma pacatos uscat de focul iadului ce esti, care vei arde in focu gheenei ca-n crematoriu, si din cenusa aia a ta s-a mai face unu tot ca tine de pacatos care si ala va fi ars. Trebe una singura, ma. Una si gata. De restu\' dorintelor se ocupa alti sfinti, cum ar fi Sf. Asteapta.\r\n- Ba, mosule, zic io, fii atent. Io amu dorm, si lobu\' ala cerebral ocupat cu dorintele carnalo-materiale e latent. Nu se iriga, pur si simplu, ca or furat astia tevile, hotii dreq, Doamne iarta-ma. Asa ca: ba mosule, nu imi alegi tu o dorinta sa-mi indeplinesti? Amu noi ne stim, ca aproape ca avem aceeasi varsta; plus ca tu poate stii mai bine ca mine ce vroiesc, ca voi stiti tat, si io de cand mi-am cumparat rucsac fara cadru in clasa a 11-a nu prea mai imi doresc multe kestii.\r\n- Mai impiedicatule in treapta pacatului, agatzatule de cuierul desertaciunii, dependentule in ale raului! Eu pot alege sa nu mai poti fuma neam, sa iti faca beutura greatza, sa nu poci manca decat de post sau sa vorbesti in pilde, fara a mentiona parti ale corpului - partile alea cu care mamiferele isi marcheaza teritoriu. Ce zici? ?\r\n- Doamne iarta-ma, dar foarte departe de mine gandul asta! Oricum ma indoiesc ca asemenea comportamente degenerative vor face casa buna cu pohtele mele. Da\' daca trebe musay io sa imi aleg, vreau o fantana care indeplineste dorinte, si o bascula de fise.\r\n- Ba, zice Mosu, usor rosu in obraji, bag sama ca tu nu pricepi romaneste, limba sfintilor primordiali ai Pamantului, dupa cum zicea insusi Vadim Tudor. Aici nu mere ca pe troleu cand te-or prins fara belet. Tu alegi o dorintza, faci o cerere pe A4, o supui comitetului, noi o inregistram, o dezbatem, si o indeplinim in limita stocului. Ca e oferta din aia cu stelutza.\r\n- Ma sfinte, zic io, sa-mi bag moshu\' pe horn! Auzi aci: noi doi suntem neamuri, ma.\r\n- Ce neamuri, ma, ca doara nu te kiama Nicolae!\r\n- Nu, zic io, e drept, da si io is mosh. Asa ca suntem neamuri. Si mai e o chestie: faza cu Nicolae e rasuflata. Ca in engleza la Nicolae se zice Nick, si toata lumea stie ca \"Nick\" inseamna \"porecla\". Ce sfantu poreclei esti tu, ma? Asa ca te rog frumos sa faci bin...\r\n\r\nPola me. O sunat ceasu\'.','Sfantul (Nicolae, nu Roger Moore)',0,'','publish','open','open','','sfantul-nicolae-nu-roger-moore','','','2007-03-14 16:48:25','2007-03-14 14:48:25','',0,'http://www.groparu.ro/?p=90',0,'post','',0),(91,1,'2007-03-13 00:17:06','2007-03-12 22:17:06','','Fute',0,'','inherit','open','open','','fute','','','2007-03-13 00:17:06','2007-03-12 22:17:06','',93,'http://www.groparu.ro/wp-content/uploads/2007/03/fute.jpg',0,'post','image/jpeg',0),(92,1,'2007-03-13 00:17:38','2007-03-12 22:17:38','','Fute',0,'','inherit','open','open','','fute-2','','','2007-03-13 00:17:38','2007-03-12 22:17:38','',93,'http://www.groparu.ro/wp-content/uploads/2007/03/fute.jpg',0,'post','image/jpeg',0),(93,1,'2007-03-13 00:18:12','2007-03-12 22:18:12','<a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/fute.jpg\" title=\"Fute\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/fute.jpg\" alt=\"Fute\" height=\"511\" width=\"388\" /></a>\r\n\r\nBelgia, tzara negrilor. \"Negri\" se scrie cu un singur i, in afara de cazurile in care  accentuezi cuvantu\': \"Tu ai face dragoste cu negri?\" se intreaba asa cum am scris eu.\r\n\r\nBelgia mai e si tzara valonilor si flamanzilor. Cica astia nu se suporta unii pe altii (opservati va rog cum am scris \"altii\") nici macar deloc. Si asa de tare nu se suporta, ca mai degraba s-ar insura cu verisoarele lor decat intre unii cu altii. Ceea ce si fac. De vreo 200 de ani.\r\n\r\nBelgia mai e si tzara berii scumpe, a ciocolatii si a ochelaristilor. 3.50EUR/33 cl - in afara de cazu\' nefericit in care dai aceeasi suma pe 0.25 cl.\r\n\r\nBelgienii au trotuare rulante in aeroport, ca sa nu isi arda caloriile. Au un centru foarte fain iarna, in care ard becuri multe si se aude muzica de Craciun. Belgienilor nu le place cand Volkswagen inchide fabrici la ei in tzara, si atunci fac demonstratii si il numesc pe CEO de la VW \"muitor\" si \"in-alte-feluri\", si agita steaguri cu El Che sh secera si ciocanu\'. In Belgia era sarbatoare in perioada asta, si se vand melci. Eu zm mancat melci si nu mi-au placut. Au gust de alge cu caca de pescarush in ele. Cum sade bine unei capitale de pedofili, simbolu\' orasului e un baietel care face pishu: <em>Manneken Pis</em>.\r\n\r\nIn Belgia se pierd avioane. Eu am pierdut unul, ca nu m-am trezit la timp. In Belgia se asteapta 9 ore in aeroport pana vine urmatoru avion spre Romania. In Belgia in aeropoarte is tot felu de romani care injura la telefon in gura mare finca nu ii lasa la aeroport sa aiba bagaj mare. Alti romani din aeroport se ofera sa ii ajute, sa le preia ei o parte din bagaj. Asa o facut Groparu cu o tipa din Deva. In Belgia in aeroport te controleaza si la kilotz sa nu ai ceva gel de dush sau lichid pe care sa-l iei cu tine in aveon. Eu am trecut de control cu 5 baterii de camera foto si o bricheta, basca trei (3) pixuri cu care puteam injunghia cate stewardeze vroiam + o carte despre UE care i-ar fi omorit pe toti de plictiseala. Dar, dupa cum aveam sa aflu in avion de la ucraineanul cu care partajam voiajul, eram mic copil. Nenea si-a scos linistit <strong>brisca</strong> din buzunar ca sa desfaca o ciocolata, tocmai cand atingeam 10.000 m altitudine. Brisca cu lama taioasa. Bine macar ca nu avea gel la el. Ca era interzis.','Daca e weekend, e Belgia',0,'','publish','open','open','','daca-e-weekend-e-belgia','','','2007-03-14 16:43:45','2007-03-14 14:43:45','',0,'http://www.groparu.ro/?p=93',0,'post','',0),(94,1,'2007-03-13 00:28:04','2007-03-12 22:28:04','<a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/papa.jpg\" title=\"Papa\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/papa.jpg\" alt=\"Papa\" height=\"359\" width=\"476\" /></a>\r\n\r\nDeci, era vineri: era clar ca era Belgia.\r\n\r\nCica Amsterdam e capitala din lumea asta cu cei mai multi negri si cei mai putini albi.\r\n\r\nSi Bruxellu\' e capitala din lumea asta cu cei mai multi negri si cei mai putini albi.\r\n\r\nVizavi de hotel, scrie mare: \"Restaurant. Cuisine Africaine\".\r\n\r\nAici e de mine, Gropare, zic io, hai sa incercam ceva exxxotic, gen carnitza de mulatra, ca de pizza sh macaruane m-am saftirit! Zis si facut. Ma opresc in fatza, imi aprind o pipa si o fumez preocupat, ma preumblu prin jur sa investighez, ca sa nu ma fac de ras, cum ma fac io de regula cand intru intr-un mediu ostil. Investighez cum se deschide usa, cate trepte sunt la intrare si cat de inalt e pragu\' usii.\r\n\r\nArunc mucu\', si imi string cureaua la pantaloni. Scuip ca un magrebian, reusesc sa nu ma impiedic sau sa-mi agatz haina, imping usa de sticla cu putere masculina, si raman cu maneru usii in mana. Inauntru - intuneric. Intuneric negru, maro-inchis - exact ca in chilotii negri ai unei negrese. Stau prostit si ma uit in jur. Nu vad decat ochi si dinti. Atat. Ma mai uit o data. Numar vreo 18 ochi si vreo 10 perechi de dinti. Albi. Lati ca lopetile.\r\n\r\nNoa! Ce pula sa faci cu maneru? Ca de iesit nu mai puteam sa ies afara si sa o intind, curajos, la fuga. Zic: jur ca imi infig mainile in paru lor ala cretz ca paru pubian si ii musc de nasu ala turtit! Macar iau vreo doua nasuri cu mine in infern daca imi vor sangele. Cum dintii nu se ridica de la masa, asez maneru pasnic pe masa de langa. Zic: bou esti, gropare! macar de aduceai si tu ceva margele, o oglinda, ceva! Asa - frectie, te baga astia in kukta sh fac friptura de roman verde. Noa! Mai scapa de canibali amu! Ma pun jos, cu curaj, la masa unde statea maneru.\r\n\r\nBa, si se uita astia la mine ca la desert! Io - finca sh io am crescut prin Manajtur - ma uit si eu la ei. La albu ochilor. Si numa ce vad ca o pereche de felinare se ridica de la masa, cu tot cu dintii de sub ei, si vine spre mine. Bazavane, zic io clantzanind energic, amu o sa papi nari de congolez! Bonsoar, zic io, comment ca va. Keske vu vule, zice o voce ca de tambur. Manger, zic io. Repas. J\'ai faim. Je voudrais manger quelque chose de la cuisine africaine, zic io, preferabil fara carne de colonist, gandesc. Qu\'est-ce que vous me recommandez?\r\n\r\nAmu, toata lumea stie. Un chelner bun stie tot timpul sa raspunda la intrebarea asta. Si tanti ma lasa paf: incepe sa-mi insire, ma, tot felu de cuisinuri. Io zic: Avez-vous un menu, s\'il vous plait? Non, zice dama. Si continua sa vorbeasca. Si io zic: viande? oui, poisson sau nush ce pana mea o zis, ca se auzea muzica din aia tribala la maxim. Zic io - viande-ul alalant sigur e ceva carne de apartheidist, ia adu la nenea neshte poisson! Asa, zic io. Si sa fie traditionnel, si cu orez, ca paine bag sama ca n-atz ave p-acolo, prin continentu\' negru.  Tanti mai bolboroseste o serie de incantatii, la care raspund  fara echivoc: oui, oui, oui. Non, nu vreau sa beau rien.\r\n\r\nSi astept. Si fac concurs cu ochii din sala care se uita mai mult la celalalt fara sa clipeasca. Si pierd. Asa ca astept, si ma uit cu interes crescand la unghiile mele, la varful pantofilor si la telefonul meu julit si vai de curu\' lui.\r\n\r\nSi dintr-o data un miros gretzos de peste prajit invadeaza incaperea, de depaseste mirosu\' de marijuana, pe care uitai sa-l mentionez. Bag pixu! ma gandesc. Pun pariu ca is ceva pesti de acvariu pescuiti din buda, amu vreo 2 luni, si niciodata bagati la rece! Amu clar ca nu mai puteam da inapoi. Si incep sa ma socotesc la ce mancare sa ma gandesc cand voi mesteca chestia aia la care ei ii spun papa si noi ii spunem Chappi, pentru catei voiosi si sanatosi. Mirosul insa imi amuteste orice pocanitura de sinapse. Icnesc. Sunt pierdut. Va trebui sa ma fac ca ma suna careva sh sa o sterg.\r\n\r\nSi dupa vreo 10 minute, mai frate, numa ce vine bucatareasa aia ma cu o tavoaie, de m-am si crezut stapanul sclavei Isaura! Un farfuroi urias cu doua capitze de orez, fiert ireprosabil. Sos de soia, moartea mea, un bol cu spanac (de care o zis ca nu e epinard) din care se iteau neshte carnaraie albe, si un pahar generos cu ceea ce aveam sa aflu mai tarziu ca era 4 linguritze de piper fiert in tabasco, sau cam asa ceva. Cert este ca - dupa un varf de cutit de sos din ala, am infulecat toata papa pe nemestecate. Papa de nota 10. Respect.\r\n\r\nPS: si Groparu stie ca Tupac Amaru o fo amerindian, da\' tot el mai stie ca nu e nici o diferenta intre popoarele care traiesc in afara Romaniei.','Groparu in restaurantu lu Tupac Amaru',0,'','publish','open','open','','groparu-in-restaurantu-lu-tupac-amaru','','','2007-03-14 16:46:36','2007-03-14 14:46:36','',0,'http://www.groparu.ro/?p=94',0,'post','',2),(95,1,'2007-03-13 00:27:06','2007-03-12 22:27:06','','Papa',0,'','inherit','open','open','','papa','','','2007-03-13 00:27:06','2007-03-12 22:27:06','',-1173737893,'http://www.groparu.ro/wp-content/uploads/2007/03/papa.jpg',0,'post','image/jpeg',0),(96,1,'2007-03-13 00:29:35','2007-03-12 22:29:35','','God',0,'','inherit','open','open','','god','','','2007-03-13 00:29:35','2007-03-12 22:29:35','',97,'http://www.groparu.ro/wp-content/uploads/2007/03/god.jpg',0,'post','image/jpeg',0),(97,1,'2007-03-13 00:30:03','2007-03-12 22:30:03','<a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/god.jpg\" title=\"God\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/god.jpg\" alt=\"God\" height=\"325\" width=\"440\" /></a>\r\n\r\nAzi am tradus asta, si mi-am rugat moartea sa vie sa ma duca in focul Gheenei, unde sa ma lase pana la a doua venire.\r\n\r\n\"<span>Viata crestina este viata liturgica Ã®n Biserica. Biserica este Organismul viu, Trupul lui Hristos condus de Dumnezeu-Tatal si Ã®nsufletit de Duhul SfÃ¢nt. </span>ÃŽntru acest har treimic sunt toate cÃ¢ntarile, slujbele si rugaciunile bisericii. <span>Ele slavesc pe Dumnezeu-Tatal prin Hristos-Cuvantul, facandu-se simtite prin Duhul sfant. </span><span>CÃ¢ntarile slujbei unui Praznic Ã®mparatesc vestesc iubirea, bunatatea si maretia lui Dumnezeu, smerita pÃ¢na Ã®n adÃ¢ncul iadului de dragul fapturii Sale â€“ Omul. CÃ¢ntarile liturgice cuprinse Ã®n acest album fac parte din slujba Utreniei Praznicului Taierii ÃŽmprejur a Domnului Nostru Iisus Hristos si a SfÃ¢ntului Ierarh Vasile cel Mare.</span>\r\n\r\n<span>RabdÃ¢nd taierea Ã®mprejur dupa Legea mozaica, MÃ¢ntuitorul Ã®si arata disponibilitatea persoanei Sale iubitoare pentru suferinta Ã®nca din sfÃ¢nta Sa pruncie. ÃŽn ciclul liturgic al celor sapte laude, utrenia ocupa un loc central. RÃ¢nduita Ã®n primele ceasuri ale zilei, slujba Ã®mpleteste armonios citiri si cÃ¢ntari din psalmi, tropare, canoane, irmoase. Dupa cÃ¢ntarea mariologica destinata Preasfintei Nascatoare de Dumnezeu, sfÃ¢rseste cu cÃ¢ntarea Laudelor si Doxologia Mare. Alcatuirea ei genereaza Ã®n suflet o stare de bucurie, multumire si slavire a lui Dumnezeu Treimic, pregatitoare pentru dumnezeiasca si SfÃ¢nta Liturghie. </span>\r\n\r\n<span>Aflati la al treilea CD, membrii Grupului Psaltic SfÃ¢ntul Roman Melodul ne aduc bucuria venirii lui Dumnezeu Ã®ntre noi oamenii ca Prunc, pregatit sa sufere si sa ne mÃ¢ntuiasca. ÃŽntr-un autentic si dulce cÃ¢nt bizantin ne aduc Ã®n suflet bucuria fireasca de a-l slavi pe Hristos StapÃ¢nul si ÃŽmparatul Nostru precum si pe sfintii Lui. ÃŽntre acestia, un loc aparte Ã®l ocupa \'\'omul cel ceresc \'\', \'\'Ã®ngerul cel pamÃ¢ntesc\'\', dumnezeiescul si marele ierarh Vasile, Arheipiscopul Cezareii Capadociei. Dorim celor ce vor asculta aceste cÃ¢ntari sa primeasca ajutor de la stapÃ¢nul Hristos,cu rugaciunile si mijlocirile SfÃ¢ntului Ierarh Vasile. (</span>Ieromonah Andrei Coroian, staret al Sfintei MÃ¢nastiri RÃ¢sca Transilvana)\"\r\nLa final, am batut cu creionul in masa si l-am chemat pe Dumnezeu la apel si i-am zis: \"Duamne, iarta-ma ca te intretup tocma\' amu cand poate vrei sa dai cu ceva tsunami in asiatici sau cu vrio inundatie la paganii aia de americani din New Orleans, da\' amu stii ca trebe sa imi ierti niscai gafe pacatoase facute de mine de-a lungul existentei mele mizere, finca am tradus acest text din pasiune, fara vreo rasplata omeneasca. Iata-le. Is numa 17. Se poate?\"\r\n\r\n1. Doamne, iarta-mi betia aia colosala trasa de ziua mea la 19 ani, cand sarbatoream prima mea picare la facultate si stateam cu mainile dupa capu lu Niatza (ne luasem reciproc de dupa cap cand stateam ingenuncheati langa buda) in baru\' Cleopatra, ca ne bagaseram toti banii in pochere si am baut vodca, si nu mancasem de vreo 18 ore. Si amandoi vorbeam engleza unu cu altu, si era 6 dimineatza. Si Calin ne-o bagat cu capu\' in zapada, sa ne trezim, si erau -12 grade afara. Si tot nu ne-am revenit.\r\n\r\n2. Doamne, iarta-mi betia aia colosala din anu I cand Mitroa era sa o ia in gura de la badi-gardurile din Bianco ca s-o rastit la ei, si io am zis ca daca o ia in gura ii dau si io un picior in bot, da\' in shimb ne-am ales cu un permis de intrare libera timp de un an studentesc.\r\n\r\n3. Doamne, iarta-mi bataile pe care i le-am administrat lu Cristoff in copilarie. Nu am fost niciodata xenofob, nu am nimic cu ungurii, sasii sau tiganii. Cristoff e sas, si noi radeam de el zicandu-i \"Cristofor Columb\", si el plangea.\r\n\r\n4. Doamne, iarta-mi capul ala pe care l-am dat in stalp cand pacatuiam cu gandul si cu inima la vederea unei eleve de la Industrial 3. M-a durut capul trei zile si orgoliul doua saptamani, ca aia m-o vast si o ras. Aveam 17 ani.\r\n\r\n5. Doamne, iarta-mi data aia cand eram prof si am ajuns la scoala dupa ce bausem pana la 4 noaptea in Jay\'s. Si nu mi-am putut tine orele, si copiii or trebuit sa copieze din manualu\' ala najpa.\r\n\r\n6. Asijderea, cand eram prof si am mers la scoala unde predam dupa ce am mers in Wake Up si am stat langa boxele la maxim si a doua zi nu mai auzeam nimic, si l-am pus din greseala absent pe un elev care strigase prezent, si i-am promis ca il motivez, da\' n-am mai apucat ca am uitat. Doamne, iarta-ma!\r\n\r\n7. Doamne, iarta-ma ca am votat cu Constantinescu. Jur ca la vremea aia mi se parea ca e cel mai bun.\r\n\r\n8. Vreau sa te rog frumos sa ma ierti ca am dormit ca porcu\' intins pe bancheta de tren atunci cand eram student si veneam de la Sibiu, si pe hol era plin de oameni care nu s-or putut aseza jos.\r\n\r\n9. Vreau sa ma ierti cand am mintit-o pe fosta mea directoare de la scoala, ca am intarziat din cauza ca imi rupsesem picioru cu o zi inainte.\r\n\r\n10. Doamne, iarta-ma ca l-am urecheat pe elevul Astilean, dar efectiv m-o scos din minti. Si iarta-ma ca nu-mi pare rau nici macar azi.\r\n\r\n11. Doamne, iarta-ma ca tot timpu in autobuz ma pun langa fete frumoase. Ca daca ma pun pe doua scaune goale, langa mine se pun numa babete.\r\n\r\n12. Doamne, iarta-ma ca injur ca un sergent de la Campina. Jur ca atunci cand imi aduc aminte a tot chinui sa ma stapanesc, da cum dre sa nu ma enervez cand primesc de lucru la firma?\r\n\r\nDoamne, is numa 14, mai is trei pacate, dar vreau sa Te rog frumos sa ma pasuiesti cu astea trei, ca va veni vremea sa completez lista. Se poate? Te rog frumos.','17 pacate capitale',0,'','publish','open','open','','17-pacate-capitale','','','2007-03-13 00:30:03','2007-03-12 22:30:03','',0,'http://www.groparu.ro/?p=97',0,'post','',2),(98,1,'2007-03-13 00:33:06','2007-03-12 22:33:06','<a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/matza.jpg\" title=\"Matza\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/matza.jpg\" alt=\"Matza\" height=\"345\" width=\"459\" /></a>\r\n\r\nDa, revelion. Rimeaza cu bulion.\r\n\r\nEra sa-l sinucid pe Mitroa ca mi-o infipt un mop sub nas, mop cu care tocmai se stersesera ceva boraturi. Sau oare numa\' dupa aia s-or sters boralele...? Creca da, finca singuru\' care o borat de Rev o fost Cipala (aka \"Cuiu\' din pula\"), si o borat numa in 1 ianuarie, ori noi eram in 31 inca, si Cipala o borat numa dupa ce o mancat trei portii ori 500 ml de zama de burta. Zama o fost beton, da\' stomahu\' lu asta o fo varza. Da, in mod sigur, o fost inainte de a se sterge borala lu asta. Da\' tot am dat cu o doza de bere dupa cretinu de Mitroa, da\' nu l-am nimerit, cert e ca s-o bufnit de dulap cu atata putere, ca astia din cabana s-or gandit ca sigur e miezu noptii si se aud jocuri de artificii si or inceput sa se pupe. Drept pedeapsa, o trebuit sa primeasca cinci shuturi in cur de la mine in cele mai neprielnice momente, gen de fiecare data cand se apleca. Alea cinci s-or transformat in trei, de fapt, dar nu mai putin ucigatuare. Cu sete. Sa-l doara cand se caca.\r\n\r\nOricum, am ajuns la cabana porniti pe fapte mari, sa ne euroimbatam la eurorevelion. Asa de porniti, ca am beut 10 sticle de 750 ml de coniac basca 100 doze de bere pana dimineatza. 9 masculi, ca fetele s-or tras pe cur. Si a doua zi (adeca 1 ianuarie) pe la vreo 9 dimineatza am pornit in Avrig sa cautam de beut! Si intrebam batranele care mereau la sljuba unde putem gasi ceva de beut in Avrig. Si am gasit numa Passion, care in afara de chimicale mai avia sh alcool intr-insa. Si a doua seara ne-am machit cu Passion.\r\n\r\nDa nu despre asta e vorba, finca nu povestirile unei gajti de betivani ar trebui sa fie piatra din coroana. Faza e ca mie imi plac pisicutele. Si nu vreau sa pateasca ceva rau, nici una din ele. Cine ma cunoajte stie ca aveam si eu matzoc, una, de fapt, Ciuciuca ii ziceam. Finca ma iubea, ciuciu. Cand stateam pe pat, venea parshiva pana langa mana mea, dar in asa fel incat trebuia sa ma ridic ca sa o mangai, ca sa depun efort. A dreq matza! Cand am plecat din apartament, a intrat in calduri; si am dat-o la casa unei prekine, ca sa aiba libertate. Si o plecat cu altu. Alt motan. Da\' o revenit si nu o intrebat de mine!\r\n\r\nSi apropos de matze, una bucata matza de revelion, lihnita de fuame ca era in stare sa vina la mine singura (!) si sa ma miaune, apare in seara de 1. Si atata s-o frecat de mine de mi s-o facut mila. Clar ca am loat euro-matza si am mers cu ea la fete (9 la numar) si le-am dat-o. Matza aia a mancat 4 crenvursti cum papa Jenna Jameson cartilagii de barbat. Si tot mai vroia. La care noi, betivii (eu cu Huby, care e un tip extraordinar) ne-am hotarat sa salvam matza. Finca putea sa moara de indigestie, si Mitroa vroia sa o faca barbechiu. Asa ca am hranit pisicutza cu putin hrean (inainte mestecasem in hrean cu o linguritza care se ofilise, atata era de puternic). Si pisica nu vroia hrean, dar era mai bine pentru ea, ca sa nu i se faca rau dupa patru crenvursti cat o putzuloaie de negru inghititi pe nemestecate. Si pisi a primit doua linguritze de hrean si nu a fost foarte fericita. Dar pisi era lacoma, si dupa ce a stranutat bine de vreo patru ori, a revenit printre noi. Tocmai la timp ca sa incapa in mainile flamande ale lu Flaviu, care o aruncat-o pe casa. Clar ca Mitroa a primit un alt shut in posterior, ca nu se leaga nimeni de matzele care ma baga pe mine in seama! Tocmai cand rasfoia prin creier manualul cu \"1001 de moduri de a administra o pisica\"\r\n\r\nDar matza era apucata. O coborat dintre tigle si iara, pe la picioarele noastre. Noroc ca tocmai cand sa puna Mitroa mana pe ea, var-su (Nelu, o pujlama de om meseriash!) s-o hotarat sa o centreze, ca sa o scape din ghearele netrebnicului. Si matza a decolat in virtutea shutului, si nu a mai revenit! Ca o facea gratar netrebnicu\'.\r\n\r\nA doua zi nu am mai revazut-o. Dar matzele is tot timpu ok. Ceea ce nu se poate spune despre curu Mitroiului. Ca l-o durut pana in ziua de azi. Si sper sa il mai doara.','Revelieon 2007',0,'','publish','open','open','','revelieon-2007','','','2007-03-13 00:33:06','2007-03-12 22:33:06','',0,'http://www.groparu.ro/?p=98',0,'post','',0),(99,1,'2007-03-13 00:32:41','2007-03-12 22:32:41','','Matza',0,'','inherit','open','open','','matza','','','2007-03-13 00:32:41','2007-03-12 22:32:41','',-1173738604,'http://www.groparu.ro/wp-content/uploads/2007/03/matza.jpg',0,'post','image/jpeg',0),(100,1,'2007-03-13 00:33:42','2007-03-12 22:33:42','Jart! Jart! DouÄƒ palme peste falcutza Ã®ngheÅ£atÄƒ.\r\n\r\nGaÅŸca de 24 de colindaci (jumate masculi betzi, cealalta jumatate eu) se opreste ÅŸi se uita. Pe jos, o femeie se zvÃ¢rcolea ca o likitoare cand ii dai sare. BunoacÄƒ femeia. TinericÄƒ, din aia cu cercei in buric sh tatuaj tribal pe posterior, sau deasupra bucilor, ca nu am putut vedea de unde ii incepea curu\'. PÃ¢n\' la buric ii urca asa, uÅŸurel, un ÅŸir negru-negru de pÄƒr de la pÄƒsÄƒricÄƒ - ÅŸi nush cum puii mei la buric se termina asa, dintr-o data. Langa ea, o aratare de mascul cu geaca cu Chicago Bulls. Cercel si freza de 3rei Sud-Est. \"Curvo\", ne auzira urechile noastre, reci ca varza murata congelata, \"te-ai futut cu Nelu!\" - si urmara doua propozitii in care numele Domnului fu pomenit, dar nu cu conotatie ecumenica. Langa ei, inca vreo 2 cupluri, care erau cu ei. Nici unu nici o miscare.\r\n\r\nJosh se cÄƒca pe el de bÄƒrbÄƒÅ£ie.\r\n- Ba, zice, io ma bag sa ii dau Ã®n gurÄƒ la nemernic.\r\n- Te bagi pe pizda la muma-ta. Da-le pace, ca lupta asta nu e lupta noastra (vinul de casa imi apela cu succes un cuplet din Byron - \"The thirst of their ambition was not mine / The aim of their existence was not mine\")\r\n- O rupe pe biata gaina! Tu nu vezi???\r\n- Mai taci ma, asta e cartier din Romania. Daca nu o bate inseamna ca nu o iubeshte.\r\n- Ba odorizant de buda, zice asta, tu esti cretin, sau carpa? Ca sa stiu. Ca pruna asta si le ia de la barba-su si tu stai si te uiti!\r\n- Da\' taci ma, zic, io am incredere in sibience (cÄƒ uitai sÄƒ vÄƒ zic, eram in Sibiu), si ca dovadÄƒ - fii antena cat de surprinzatoare pot fi galele gratis de K1.\r\n\r\nUrmeaza scena pe care o anticipasem. Gajica se ridica de jos ca o shaolincÄƒ, sh huarshht!!! O loviturÄƒ de picior la Äƒsta Ã®n burtÄƒ, aproape din intoarcere. Fuhuhjjuuuu!!! Åži numa ce mi Å£i se Ã®ntinde mititelu Äƒla agresiv, dar indesat pe trotuar, da o frÃ¢nÄƒ cu bÄƒrbia, sh dupa aia nush cum dreq da cu dovleacu\' de asfaltu\' ala cu foarte putina zapada pe el, de o sunat ca un ketroi din ala greeeeu, greu de tat care cade la vale de pe creasta Fagarasului. Boc! Boc! Se aude. Tipesa, Ã®ncordatÄƒ ca o ghepÄƒrditzÄƒ.\r\n\r\n- Vezi, ba erete, ii zic lu Josh, femeile din Sibiu is din alea, ma, pastoritze, astea fac wrestling cu urshii si beau lapte de lupoaica! Pariez pe ea.\r\n\r\nMititelu se sprijina in cap, Ã®ÅŸi aduna picioarele sub el ÅŸi se balanseaza pÃ¢nÄƒ ajunge Ã®ntr-o staturÄƒ relativ bipeda, numa atÃ¢ta cÄƒ ii atarnau mÃ¢inile pe langa corp, ca la cimpanezeu. Si se apuca de-ÅŸi reface freza, in timp ce doamna il scuipa cu dÄƒrnicie. ÃŽl scuipa ÅŸi Ã®i face pomelnicu\' familiei lui: ca sa se duca la dracu cu ma-sa care se ÅŸtie cÄƒ e o chitra de femeie si cu tac-su care e un alcoolic fara sperantza care o picat de doua ori la admiterea la facultate (kizda masii, zic io, oare Äƒsta de-o ia Ã®n gura e copilu\' meu???), cÃ® nici macar carnet de conducere nu are (e clar, zic io, haiti! Äƒsta mi-ar putea deveni cel mai bun prekin Ã®n alte circumstanÅ£e) si ca Ã®i atÃ¢ta de prost cÄƒ nici la ocazie nu ÅŸtie sÄƒ stea cu cartonu\' cum trebe.\r\n\r\n- Acum, dupa cum vedeti, stimaÅ£i telespectatori (ii explic lu Josh), printr-o surprinzatoare manevra reprezentanta sexului frumos ia situatia in ambele maini ÅŸi, dupa cum ar spune un mare clasic in viatza - despre mine era vorba - intre ambele picioare, ÅŸi Ã®ÅŸi loveste consortul cu picioare, pÄƒlmi ÅŸi invective. Campionul nostru e un pic ametit, dar asteptam riposta. Riposta care iata, nu intarzie, noroc ca buna doamna nu e atinsa decat razant de dosul palmei dumnealui, totusi suficient cat sa o dea (cu bufnitura) cu scalpul de acel gard de beton. Sa urmÄƒrim acum ce urmeaza, deoarece nu cred ca challengerul nostru isi poate auzi gandurile din cauza spurcaturilor cu care il tinteshte gura dumneaei. Doamna revine intr-o clipita, si cu velocitatea unei toporiÅŸti Ã®i imparte omului patru carate - numarate - la baza gatului, unde-i e greu voinicului, de i-o si feliat marul lui Adam. Si ca si cand asta nu ar fi fost de ajuns, il prinde cu o manoacÄƒ de freza aia de 3rei Sud-Est, si cu cealalta il prinde de limba, i-o lungeste si incearca sa i-o bage - tot lui - in cur.\r\n\r\nDar - ce se vede??? Valer si Flaviu se indreapta sa ii desparta??? Fuck, fuck, fuck, zic io, astia nu is normali.\r\n\r\nAmu situatia se complica. Io stiam ca nu am ce cauta in bataia aia, desi imi rodeam pumnii sa intervin. Si nu aveam ce cauta intre ei, finca gajica aia:\r\n\r\n1) nu incerca sa fuga;\r\n2) nu striga \"Ajutor!\";\r\n3) pe langa toate astea, ii mai si cara la bietu betivan cate una din fundul grÄƒdinii, de numa asa se auzea: trosc! trosc!! trosc!!!\r\n\r\nDaca gajica\r\n1) o lua in clantzÄƒ pe tacute ca in filmele mute, fara sa il mustreze verbal;\r\n2) o rupea la fugÄƒ sh betivu fugea dupa ea;\r\n3) striga \"Ajutor!\" - fie si numa cu juma\' de gura, ca ii prindeam si cea mai mica vocala pe care o scotea, ca numa atata asteptam ca sa intervenim, da\' nu auzeam decat \"u\" si \"a\" cu \"L\" in mijloc; p-orma \"i\" si \"a\", cu \"zd\" in mijloc; p-orma o suita de cuvinte ce incepeau cu \"p\" sh \"f\", si care sigur nu se gasesc in cartile de la editura Christiania,\r\n\r\ndeci daca una din astea 3 kestii de mai sus s-ar fi intamplat, aÅŸ fi intervenit. Si am fi salvat femeia aia cu pÄƒr pana la buric, ca sÄƒ nu il mai bata pe nemernic, si am fi dus-o la un azil militar plin de soldatzei in termen, unde ar fi cunoscut adevarata iubire. Dar asa, o intervenit Flaviu sh Valer. Astia erau suficient de curajosi, tot de la vin, incat sa se creada si consilieri maritali. Si am asteptat sa vad ca zboara macar un pumn catre beregatile astora, dar masculu\' nostru feroce era redus la o masa diforma de carnitza care gÃ¢lgÃ¢ia. Åži astia ai mei, de curajoÅŸi ce erau, ÅŸi-or scos telefoanele - care oricum nu mai aveau baterie - si i-or zis, bÄƒlÄƒnganindu-ÅŸi-le: \"MÄƒmÄƒliga mÄƒtii, daca nu te opresti, aici kem politia! Rezolvati-va problemele acasa, gura mÄƒtii de pastarnac!\"\r\n\r\nOmul o Ã®nÅ£eles. Åži femeia cu pÄƒr pubian pÃ¢nÄƒ la buric s-a aplecat, ÅŸi ÅŸi-a ridicat consortul. Åži ÅŸi l-a azvÃ¢rlit pe un umar, ce pe o batistuÅ£Äƒ. Åži a plecat cu el in tenebrele cartierului muncitoresc. AcelaÅŸi cartier unde am locuit ÅŸi eu o vreme. Strashnica femeie! Strashnica.','Daca n-o batzi, n-o iubesti',0,'','publish','open','open','','daca-n-o-batzi-n-o-iubesti','','','2007-03-13 00:33:42','2007-03-12 22:33:42','',0,'http://www.groparu.ro/?p=100',0,'post','',6),(101,1,'2007-03-13 00:35:42','2007-03-12 22:35:42','Amu, faza cu revelionu e grea. La toti ni-i greu.\r\n\r\nIn primu rand, finca nush cum sa ii mai zic: A-Nou, sau Revelion?\r\n\r\nIn al doilea rand finca urasc sa planuiesc din vreme. La mine toate se rezolva in ultimul moment, si din cauza aia nu se prea rezolva. De-aia ma tot plang ca nu am prea am avut noroc in viatza, decat cu caru\', si cand se rezolva, de regula, meritele le atribui unei entitati mai superioare mie, careia unii ii spun Buda, care le e mai superioara lor, si eu ii zic DumnezEU care, dupa cum stiu eu bine, ca am citit pe net, m-a creat dupa chipul si asemanarea Lui, cu mici retusuri, ca doara Dumnezeu nu face diarie si nici carii!\r\n\r\nIn al treilea rand finca daca te intreaba cineva \"Ce faci de Revelion?\" trebe sa ii eviti privirea cand ii raspunzi, si, cand ii spui ce planuri ai, trebuie sa strecori si aluzia ca nu mai are loc sa vina cu tine. Finca:\r\n\r\n1) ti-i anticapit... ptiu, antipatic de nu l-ai putea suporta nici poleit cu aur si expus in mausoleu, ca Lenin;\r\n2) pur si simplu nu s-ar integra cu gasca ta de prekini betivani care se imbata ca porcii la fiecare chef si iau cartonase galbene de la prekinele lor si-apai tre\' sa faca blat si concesii inca doua-trei etape, pana uita aia.\r\n\r\nSi mai nasol e cand chiar ai vrea sa il iei cu tine, da\' chiar nu mai ai unde sa il iei si p-ala, si atunci trebe sa ii explici cu lux de amanunte din ce cauza nu poti, si cu cat explici mai mult cu atat iti dai seama ca cine se scuza se acuza, si simti ca in ochii lui te apropii de punctele 1) si 2). Si atunci te simti ca un mizerabil, si zici ca soarta e nedreapta ca tu ai avut mai multe sanse in viatza decat el, si pe vremea lu Ceausescu nu era asa, ca erau oamenii mai buni, desi uleiu\' era la ratie.\r\n\r\nCand intr-adevar lururile incep sa curga la vale, atunci incepe distractia. Suna gasca mare la telefon, la 2 noaptea: ba calugaritzule, ti se zice, da\' tu cu cine vii la rev? Cu ma-ta, zici tu, sperand ca ala sa rada si sa uite. Da finca ala nu rade si nici nu uita, ii zici: cu Pompieru\' si cu Glezna, aia doi prekini de-ai mei, tovarasi buni. Ba beshica, fii atent la mine-aci. Noi ne-am hotarat ca numa cu un prekin poti sa vii, ca nu mai e loc (de regula hotararile astea se iau unilateral cu o saptamana inainte de rev, in asa fel incat prekinu ala care tre \' sa pice sa nu fi avut vreme sa isi faca alte planuri de backup, finca se stie refuzatii la revelion dezvolta un sentiment cald, de prietenie, fatza de cei care trag tzepe de rev). Nu mai poti sa vii cu ala ca tre\' sa vina verisoara lu\' unu, gazda, si ala asa o zis, ca tu tre\' sa renunti la un prekin, ca deja suntem 42. Eu as vrea, sincer, da\' uite ca nu se poate. Am vrut numa sa iti zic cum stau lucrurile, na. Noapte buna. Si iti inchide telefonu, si si-l si inchide si p-al lui, sa nu ai pe cine injura in direct, plus ca e doua noaptea si e tarziu.\r\n\r\nNormal ca tu te simti ca un jucator de fotbal danez de 2 metri si 10 caruia un arbitru turc i-o dat un galben la el acasa, pe nedrept (toate cartonasele galbene se dau pe nedrept). Si si mai nasol e ca tocma\' prekinii aia buni iti fac asa o faza nedreapta, si tocmai finca amu tre\' sa renunti la unul din prekinii tai cu care vii, care ti-s la fel de buni, faza ii si mai nedreapta. Si si mai nedrept e ca nu ai cum sa te apuci sa faci gÃ¢t, cÄƒ dupa aia si tu pierzi, pe nedrept, locu\' cu verdeatzÄƒ cu gajca, si apai ajungi la mÃ¢na alora pe care-i refuzasesi, aia de la punctul 1) ÅŸi 2). Si atunci te gandesti: ba, nici Pompieru nici Glezna nu is Iisusi, asa ca daca ii tradez nu-s Iuda. Asta e, unu\' tre sa pice, viatza e nedreapta. Si dupa ce dai cu banu, zici: asta e. Ba Glezna ba, nu se mai poate, ba, cu revelionu\', io ma duc la bunici, ca o picat faza aia. Pompierule, ii zici dupa aia, vezi ca Glezna nu poa sa mai vina, sa nu-i zici nimic, pola me, asta e. Numai pentru tine mai e loc. Ba, zice Pompieru, io nush ba daca mai vin! Serios. Ca n-am chef (de regula, cand la mine-n tzara iti spune cineva asa ceva, sa fiti siguri ca ala avea alt plan in cap de cel putin 6 luni, dar nu ti-o zis nimic, finca tu erai varianta de backup). Asa ca il suni pe Glezna, care deja are alt plan de backup in desfasurare, si il convingi sa renunte la el, ca ti-ai pus obrazu\' pentru el, si ca o sa fie super, ca ii toata gajca acolo. Si numai dupa ce il implori cu lacrimi amare sa te ierte si sa vina acceptasi Glezna (finca daca mergi fara nici un prieten cu tine la revelion aialalti nu te mai lasa sa aduci pe nimeni la anu\', ca ai numa prekini neseriosi, care promit si nu vin); dar asta nu vine oricum, ci numai si numai dupa ce iti smulge promisiuni pe care stii sigur ca nu ai cum sa i le indeplinesti, gen ca o sa aiba patul cel mai bun, ca o sa fie cald la cabana, ca 100% ca o sa fie distractie si ca sa ii gasesti o masina in 1 ianuarie la 6 dimineatza sa il aduca in orash, ca tre\' sa mai mearga la un chef in dimineatza aia, fara tine, ca o promis (cheful ala e tocmai la altcineva care lui ii e prekin, dar care la tine se inscrie in punctele 1) si 2).\r\n\r\nSi pentru ca Groparu face orice pentru prieteni, inclusiv le da bani imprumut, le da cazare le ia si bere si ii si injunghie pe la spate daca trebe, promiti si juri numai sa fie bine. Numai sa inceapa revelionu ala despre care ai promis ca o sa fie dickstractie mare, si multe gajici singure care il vor p-ala si care se saruta una cu alta, si dorm dezbracate. Care revelion - ca amu ii faza cea mai tare, cand discoperi uluit atata frumusetze care strapunge taina nepatrunsului ascuns - se reveleaza a fi ca gasca aia de 42 de oameni is de fapt 6 baieti si o gajica, care e prekina unuia dintre voi. Si gajica e si din aia cu toane, care ia locul cel mai bun in pat, care nu suporta sa fie cald la cabana, care adoarme la 1 noaptea si nici nu il lasa pe prietenul ei - singurul sofer, si care nici nu bea, ca o avut hepatita de curand - sa plece de langa ea in 1 ianuarie dimineatza la ora 6. Asa ca ramai sa te distrezi cu masculii aia care is disponibili, si care, intr-o lume normala, intra toti la punctle 1) si 2) din clasificarea ta. Chiar si Glezna!','BÄƒ, care-i faza cu revelionu\'?',0,'','publish','open','open','','ba-care-i-faza-cu-revelionu','','','2007-03-13 01:19:10','2007-03-12 23:19:10','',0,'http://www.groparu.ro/?p=101',0,'post','',0),(102,1,'2007-03-13 00:36:36','2007-03-12 22:36:36','','Fire!',0,'','inherit','open','open','','fire','','','2007-03-13 00:36:36','2007-03-12 22:36:36','',103,'http://www.groparu.ro/wp-content/uploads/2007/03/fire.jpg',0,'post','image/jpeg',0),(103,1,'2007-03-13 00:37:04','2007-03-12 22:37:04','<a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/fire.jpg\" title=\"Fire!\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/fire.jpg\" alt=\"Fire!\" /></a>\r\n\r\nO cooperativa agricola de productie are grija de porcii ei. Ii vrea acolo in cocina, grasi, sanatosi, feriti de pesta, frig, satui, lalala. O firma seamana cu o ferma, finca si porcii de angajati cresc, au senzatia sigurantei, se satura cu papa in cutii de plastic de la catering si fac pishu la doi pashi de birou. Diferenta dintre o ferma si o firma este ca porcii celei dintai nu prezinta riscuri de manipulare, pe cand porcii de angajati, da. In America, porcii de angajati vin la firma cu Kalashu\' si impusca sefii si secretarele dezbracate de sub ei. In Romania, suinele carpatine nu pot face mai mult decat sa dea foc cooperativei cu bricheta aia de 12.000 lei, si aia vechi.\r\n\r\nNenea care se ocupa de incendii si care face instructaju\' PSI de la pompierii clujeni (ne tot zice ca nu e frumos sa dam foc firmei) e grasun si frumos ca un Pokemon. Sau urat ca un Pokemon. E grasun si cu gusha si vorbeste ca un caprar, si nu suporta cand lumea il completeaza - probabil se crede prea complet. Poarta pantaloni de stofa, pulover (<em>sveter</em>) si adidasi cu ciorapi de lina.\r\n\r\nLa ultima sedintza de PSI, ne-o certat ca de ce e strada asa ingusta. Ca daca lom foc, masina pompierilor nu are cum intoarce ca sa ne stropeasca, ca pe demonstranti. Si ca vom muri arsi ca niste sobolani ce suntem. Si ca oricum nu e nimic de capu nostru si ca o vom pizdi intr-o buna zi.\r\n\r\nDa\' primu ajutor stim sa-l dam? ne intreaba, lingandu-si buzele cu un icnet in timp ce se uita la vreo doo colege care-si aranjau sutienele, in sala mare. Programatorimea tasta de zor, ca nu se uita nimeni la el. N-asa, zice el. Sa va zic. Primul ajutor se acorda atunci cand victima nu mai poate respira, si se acorda cu respiratie gura-la-gura, zice el, dezmierdandu-le cu privirea pe colegele mele.\r\n\r\nIo ridic doua deshte sus, si imi permit sa tusesc, sa imi dreg vocea, si sa il corectez suav:\r\n- Nu va suparati, zic, da in primu rand victima trebuie dusa departe de locul accidentului, intr-un loc sigur.\r\n- Da, zice el, fericit ca isi pierduse sirul gandurilor si amu trebuia sa se uite in brosura, si apai se aplica gura-la-gura.\r\n- ...si nu oricum, zic eu, ci numai daca ramanerea in perimetrul accidentului nu se dovedeste periculoasa. Pentru ca in mod normal trebuie sa asteptam pana soseste ajutorul calificat - ambulanta sau, preferabil SMURD-ul, finca SMURD-ul e calificat sa acorde primul ajutor la locul accidentului, pe cand ambulanta se ocupa numai de transportul la cel mai apropiat spital.\r\n- Da, zice el, da, da. Si daca nu vine paramedicii, dupa indepartarea victimei se aplica respiratia gura-la-gura.\r\n- Da, zic eu, perfect de acord, dar in cazul indepartarii de locul accidentului, victima nu trebuie trasa de sub masina rasturnata sau grinda arzanda, ci trebuie ridicata si extrasa de acolo in brate, sau cu foarte mare atentie rostogolita pe targa/patura, si numai apoi scoasa din accident. Ca daca are vreun membru rupt, ii gata, am pizdit-o, zic eu.\r\n- Exact, zice el, si apoi se aplica respiratia gura-la-gura.\r\n- Imediat, daca-mi permiteti, zic eu. Se ia o batista sau un tifon, si se curata gura victimei. Poate avea reziduuri in gura care fie impiedica transferul de aer, fie sunt toxice, si atunci o pizdim si noi.\r\n- Da, zice el, dar a sosit momentul sa ii aplicam o limba... ma-sa, zice el, mi-o scapat, respiratia\r\ngura-la-gura.\r\n- Nu, zic eu, nu. Nu e bine. Victima e pizdita, sta intinsa pe jos, cu capul dat pe spate. Numai dupa ce ii prindem cu degetele nasul si cu cealalta mana barbia se aplica respiratia gura-la-gura.\r\n- Da, zice el, se aplica respiratia gura-la-gura.\r\n- Nu, zic eu, fiindca riscam sa pizdim victima si mai tare ca ii putem sufla aer in stomac in loc de plamani, si atunci o pizdeste si mai rau. Cea mai eficienta metoda e respiratia gura-la-nas.\r\n- Da, zice nenea, si asa se poate.\r\n- De ce? Zic eu. De ce. Va spun eu de ce. Finca e mult mai usor sa intre aerul in plamani daca il sufli pe caile respiratorii.\r\n- Da, zice el.\r\n- Si sa aveti de grija ca daca e copil, sa nu suflati prea tare, ca ii rupeti plamanii!\r\n- Da, zice el. Si ia o pauza.\r\n\r\nContinua.\r\n\r\n- Dar sa nu uitam ca un alt element la fel de important e masajul cardiac. In acest scop, zice el, cu ochi sclipitori, se dezbraca victima de la bust in sus, si se maseaza incet-incet dar cu fermitate pieptzii... aaa... pieptul victimei.\r\n- Nu, zic eu, nu. Nici gand. Prima data se verifica sa nu aibe vreo coasta rupta sau ceva intzapatura de metal in kept, ca daca ii apesi o pizdeste iara, definitiv de data asta.\r\n- Da, zice el, da. Oricum, acum, ca s-a incheiat sedintza noastra de prim ajutor ÅŸi eu trebuie sÄƒ plec, dati-mi voie sa va arat iesirea de incendiu.\r\n\r\nEra foarte fericit ca ii intrerupsesem visele lui adanci.\r\n\r\nDupa cum vedeti, iesirea de incendiu dÄƒ exact in curtea vecinului, care e pÄƒzitÄƒ de acest magnific exemplar de ciobanesc mioritic sau carpatin. Acesti caini, dupa cum se stie, sunt foarte prietenosi cu programatorii care le invadeaza teritoriul urland si tropaind panicati, in caz de incendiu. Veti fi in siguranta - daca latra violent e semn ca vrea sa fie prietenos. Eu acum trebuie sa plec. La revedere.','In caz de incendiu, sparge-i gura',0,'','publish','open','open','','in-caz-de-incendiu-sparge-i-gura','','','2007-03-13 00:37:04','2007-03-12 22:37:04','',0,'http://www.groparu.ro/?p=103',0,'post','',0),(104,1,'2007-03-13 00:38:29','2007-03-12 22:38:29','','Eat less chickin',0,'','inherit','open','open','','eat-less-chickin','','','2007-03-13 00:38:29','2007-03-12 22:38:29','',105,'http://www.groparu.ro/wp-content/uploads/2007/03/b220.jpg',0,'post','image/jpeg',0),(105,1,'2007-03-13 00:39:03','2007-03-12 22:39:03','<a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/b220.jpg\" title=\"Eat less chickin\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/b220.jpg\" alt=\"Eat less chickin\" /></a>\r\n\r\nPrima zi de post a fost un fleac.\r\n\r\nPrima mea zi de post a fost de Lasatul DemiSecului. Finca eram rupt de mahmur, finca fusesem la a treia noapte consecutiva de chef, si cand esti ca frunza toamna de mahmur pana si aerul pe care il inspiri iti face rau. Asa ca daca oricum nu puteam fuma, si nici bea bere, si nici papa nimic, am zis ca e OK sa incep de ieri postul. Si de ieri am si inceput.\r\n\r\nAzi, in schimb, azi e altfel.\r\n\r\n<img src=\"http://us.i1.yimg.com/us.yimg.com/i/mesg/emoticons7/102.gif\" /><img src=\"http://us.i1.yimg.com/us.yimg.com/i/mesg/emoticons7/102.gif\" /><img src=\"http://us.i1.yimg.com/us.yimg.com/i/mesg/emoticons7/102.gif\" /><img src=\"http://us.i1.yimg.com/us.yimg.com/i/mesg/emoticons7/102.gif\" /><img src=\"http://us.i1.yimg.com/us.yimg.com/i/mesg/emoticons7/102.gif\" /><img src=\"http://us.i1.yimg.com/us.yimg.com/i/mesg/emoticons7/102.gif\" /><img src=\"http://us.i1.yimg.com/us.yimg.com/i/mesg/emoticons7/102.gif\" /><img src=\"http://us.i1.yimg.com/us.yimg.com/i/mesg/emoticons7/102.gif\" /><img src=\"http://us.i1.yimg.com/us.yimg.com/i/mesg/emoticons7/102.gif\" /><img src=\"http://us.i1.yimg.com/us.yimg.com/i/mesg/emoticons7/102.gif\" /><img src=\"http://us.i1.yimg.com/us.yimg.com/i/mesg/emoticons7/102.gif\" /><img src=\"http://us.i1.yimg.com/us.yimg.com/i/mesg/emoticons7/102.gif\" />\r\n\r\n\r\n\r\n\r\nMa asteptam sa fie greu, dar NU CHIAR ASA DE GREU!!!\r\n\r\n1. In primu rand ca am un gust anormal si neobisnuit de placut in gura dimineatza cand ma trezesc. Care se mentine si dupa ce trece prima ora din buna dimineatza mea, perioada pana la care in mod normal as fi bagat pana la tri tigari intre pleure.\r\n\r\n2. Nu mi se mai usuca narile, si nu ma mai scurm in nas de fatza cu tot biroul. Asta imi permite sa socializez si cu colegii aia mai sensibili care imi evitau privirea din cauza asta.\r\n\r\n3. Fiindca nu mai beau, riscul sa fac prostii mari cand is ametit scade considerabil. Asta imi permite sa socializez si cu masculii ale caror prietene erau indragostite de mine, dar care nu aveau voie sa socializeze cu mine, ca cand is beat nu mai fac discriminari sexuale.\r\n\r\n4. Faptul ca mananc numai rodul gliei, nu si al grajdului, imi permite sa restabilesc relatii diplomatice cu Tara Viermelui de Galbeaza, cu Statele Unite ale Gripei Aviare si in Fosta Republica Yugoslava a Pestei Porcine. Voi semna noi tratate diplomatice ca bolile astea sa atace numa masculii, ca sa ramana mai multe femele de iubit pentru noi, heterosexualii.\r\n\r\n5. De cand nu mai am voie sa ma bucur nici macar de o Sana, am redescoperit alte placeri esentiale ale vietii, cum ar fi:\r\n- scarpinatul;\r\n- cumparatul unei masini de spalat Samsung in rate;\r\n- puterea de a refuza din priviri toate femeile care se uita la tine in troleu - e post, doara (nimic nu se compara cu placerea asta);\r\n- placerea de a le spune colegilor ca fumatul ucide (asta iti da senzatia ca tu vei trai mai mult, ceea ce va elibera mai multe endorfine prin vene, si in cele din urma chiar vei trai mai mult);\r\n- placerea de a rontai seminte Nutlain pana limba devine o halca mov si crapata, cu papilele gustatile umflate cat sa iti zgarie cerul gurii;\r\n- ...? (sunt sigur ca mai sunt)','A doua zi de post',0,'','publish','open','open','','a-doua-zi-de-post','','','2007-03-13 00:39:03','2007-03-12 22:39:03','',0,'http://www.groparu.ro/?p=105',0,'post','',3),(106,1,'2007-03-13 00:39:35','2007-03-12 22:39:35','Finca is Scorpion, asadar prin urmare oleaca 90% sadic si 100% masochist, m-am hotarat sa tin post anu\' asta inainte de Paste.\r\n\r\nPostul, in viziunea Groparului, nu prea are de-a face cu Dumnezeu. Adica sunt suficient de ne-fariseu incat sa admit ca Dumnezeu nu are nici o treaba (aproape) in toata afacerea asta care e mai degraba personala si autodistructiva. Undeva, asa, la capatul tunelului intunecat in care ma preumblu zilnic si in care am loat hotararea se intrevede un pkik de Dumnezeire, dar eu incerc sa nu prea am treaba cu Ea, ca nici Ea nu prea are treaba cu mine si nu ma lasa in ruptu\' capului sa castig la Loterie, mai ales (probabil) din cauza ca nu joc.\r\n\r\nNu - postul in viziunea Groparului are ca tzel primordial autocunoasterea pe mine insushi. Sa vad cata vreme rezist fara: tigari + beutura + carne + lapte + oua + telemea de Sibiu (care, dupa cum se stie, e singurul motiv care ma mai tine in patria mea). Si daca mai pot furisha cate un gand ecumenic despre cat de bine o sa-mi fie pe lumea ailanta, cu atat mai bine.\r\nDeci:\r\n\r\n1. Adio Kent Silver, tigari de femei pe care le fumez sperand in zadar ca le voi intelege mai bine (ce teapa uriasha!). Adio. Eventual pasiv.\r\n\r\n2. Adio bere, bine ai venit, Schlossgold! (bag pula..)\r\n\r\n3. Adio chiftele, jnitzele, zama de burta, sarmale, pui, sanvici Safari sau Kebap, sunculitza de pui, Kaizer cu ceapa si cu zacusca, si, bineinteles, SLANA. Si carnatzi.\r\n\r\n4. Adio, lactate Napolact! Nu te teme, or sa ma omoare alte chestii, daca E-urile din produsele matale nu reusesc. Adio si tu, batranica din piatza care imi vinzi lapte de bivolitza 100%, cu 20% lapte de vaca si 80% napolact inauntru, si eu nu am curaj sa te evit, ba iti las si ciubuc!\r\n\r\nAdio si tie, iaurt \"natural\" cu Biffidus Essensis (TM) pe care te tot ingurgitez a doua zi, sperand sa ma scapi de starea naturala de mahmureala, si tot iau tzapa, ca in afara de diarie nu castig nimic de la tine.\r\n\r\n5. Adio, papara de sambata si duminica dimineatza, cand mancam ca porcu\' si apai zaceam gemand intins in pat, uitandu-ma la American Chopper (I hate that freakin show...)\r\n\r\n6. Telemea. Shit. Telemea. Uite cum stau lucrurile: it\'s not you, it\'s me. Trebuie sa ne despartim. Relatia noastra nu mai poate continua asa, si vreau sa ma ierti ca te-am incurcat atata vreme. Am sperat ca vom fi nedespartiti, m-am rugat la Dumnezeu sa nu ne desparta niciodata, dar se pare ca nu mai merge. Asta e. Vei gasi pe altcineva care sa te iubeasca la adevarta valoare. Nu, te rog nu plange cu lacrimi sarate de zÄƒr, e in zadar. Plus ca te-am mai si inselat cu cascaval afumat de fiecare data cand nu erai acasa. Imi pare rau. Hotararea mea e definitiva, irevocabila si inatacabila. O perioada.\r\n\r\nSi tu, ba ficatu\' pulii, sa nu te bucuri! Ca dupa Pasti te vad io cum te umpli iara de pete!','Incepe pRostu\'',0,'','publish','open','open','','incepe-prostu','','','2007-03-13 00:39:35','2007-03-12 22:39:35','',0,'http://www.groparu.ro/?p=106',0,'post','',0),(107,1,'2007-03-13 00:41:03','2007-03-12 22:41:03','','RobinSON of a Bitch',0,'','inherit','open','open','','robinson-of-a-bitch','','','2007-03-13 00:41:03','2007-03-12 22:41:03','',108,'http://www.groparu.ro/wp-content/uploads/2007/03/robinson-of-a-bitch.jpg',0,'post','image/jpeg',0),(108,1,'2007-03-13 00:41:28','2007-03-12 22:41:28','<a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/robinson-of-a-bitch.jpg\" title=\"RobinSON of a Bitch\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/robinson-of-a-bitch.jpg\" alt=\"RobinSON of a Bitch\" /></a>\r\n\r\nIo, daca ar fi sa imi aleg ce cariera (nu ce femei) sa imbratisez cand o sa fiu mare, as alege sa fiu Robinson Crusoe.\r\n\r\nIn primu rand ca faceam vin din strugurii aia de pe insula si beam si nu ma faceam de kko la prekini si nu-mi auzeam discutii prin firma, si era vin fara E-uri, si facut din struguri adevarati, nu din apa cu melasa si pastile, si nu mai trebuia sa ma stresez ca vine UE si imi taie vitza. Basca ca nu mai trebuia sa dau 80.000 pe sticla cu cel mai poshircos vin. Plus ca nu mai cumparam vinul pe criteriul \"care e cea mai faina gajica din reclama la vin?\"\r\n\r\nP-orma ca nu ma mai apucam de fumat.\r\n\r\nIn al treilea rand ca in fiecare dimineatza vedeam Vineri. Si si seara vedeam Vineri.\r\n\r\nSi sa nu uitam ca as fi avut un papagal care nu era director de scoala cand eu eram profesor. Si care nu ma punea sa fac planuri de lectie si sa scad nota la purtare la neghiobul clasei numa si numa pentru ca s-o uitat la fete sub fusta, si ele or ras ca niste capritze. Ca asa-i la 14 ani.\r\n\r\nSi as fi avut la capre - ai, mama! Plin de capre. Si as fi mancat telemea de capra cu rosii, si m-as fi simtit ca acasa in Sibiu. Si nu as mai fi fost nevoit sa merg in piatza sa iau branza, si nu m-as fi simtit vinovat ca un mic hitler genocidos ca am luat de la oieritza aia blonda si tinerica si cu pielea alba, in loc sa iau de la babatia aia de langa ea cu neg paros pe nas care ma intreaba cu repros \"Da\' de la mine de ce n-ai vrut sa iei, domnu\'?\", si eu sa ma simt ca un mizerabil care, de alfel, chiar este.\r\n\r\nSi daca veneau negrese sa manance oameni pe insula, eu le-as fi ajutat, si am fi mancat si am fi cacat toti masculii din arhipelag (oricum toti masculii is niste porci, si mie imi place carnea de porc), si as fi ramas singuru\' iubitor de negrese din peticul ala de tropic, si m-as fi bucurat de statutu\' asta pana vedeam negru de la popa in fatza ochilor. Si negresele m-ar fi venerat, ca si eu cand ma vad in oglinda imi vine sa-mi ridic altar intr-un templu cu calugaritze lezbiene si virgine, sau cartilofage. Si pe unele negrese le-as fi pus sa isi mijeasca ochii, si ziceam ca is chinezoaice, si iata cum isi mai indeplinea Groparu un alt vis din copilarie.\r\n\r\nSi nu as mai fi dat o straitza de bani pe pantofi de mers la nunti, si as fi papat multa mamaliga cu peshte, taragotu\' se-ntareste. Si nu m-as mai fi ofticat de Becali, sau ca Vantu e actionar majoritar la Catavencu, sau ca Vanghelie ar putea candida la presedintie. Si nu m-as fi ofticat ca gresia mea din baie are un coltz iesit. Si cand naufragia corabia aia, a doua, de pe care am luat o gramada de scule si chestii, m-as fi jucat pe ea de-a piratii cu prietenii mei imaginari - si as fi castigat. Si as fi jucat si poker pe dezbracatelea cu prietenele mele imaginare, si am fi pierdut impreuna. Si as fi facut baie in mare PE GRATIS. Si as fi facut si pishu in apa, fara sa ma simt vinovat. Si as fi pescuit zi si noapte, pana m-as fi saturat, si nu m-as fi saturat, si as fi pescuit chiar si dupa ce m-as fi saturat, si ar fi fost beton.\r\n\r\nSi cand, la final de cariera de Robinson, as fi simtit ca se apropie o negresa cu o coasa in mana, as fi zis: \"Doamne, cat m-ai nedreptatit! Ce viatza NAJPA am avut! Ce? Aud? Ma trimiti in rai finca vrei sa iti rascumperi greseala? No, ce sa zic... bine, is de acord, treaca de la mine! Uf...\"','RobinSON of a Bitch',0,'','publish','open','open','','robinson-of-a-bitch','','','2007-03-13 00:41:28','2007-03-12 22:41:28','',0,'http://www.groparu.ro/?p=108',0,'post','',0),(140,1,'2007-03-14 15:28:18','2007-03-14 13:28:18','','porc.jpg',0,'','inherit','open','open','','porcjpg','','','2007-03-14 15:28:18','2007-03-14 13:28:18','',133,'http://www.groparu.ro/wp-content/uploads/2007/03/porc.jpg',0,'post','image/jpeg',0),(110,1,'2007-03-13 00:43:01','2007-03-12 22:43:01','<a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/kitty-bebe.jpg\" title=\"kitty-bebe.jpg\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/kitty-bebe.jpg\" alt=\"kitty-bebe.jpg\" height=\"148\" width=\"447\" /></a>\r\nImaginile zice totul.\r\n\r\nCuvintele zice ca BeBe nu a dat nici un raspuns la apelurile fetei, nick-uite Josephine, de a-si schimba statusul. La recomandarea Groparului, Josephine si-a schimbat si ea statusul.\r\n\r\nRestul e tacere. Finca io rÃ¢d in tacere.','Imaginile zice totul',0,'','publish','open','open','','imaginile-zice-totul','','','2007-03-14 16:05:45','2007-03-14 14:05:45','',0,'http://www.groparu.ro/?p=110',0,'post','',0),(111,1,'2007-03-13 00:44:04','2007-03-12 22:44:04','','Kitty bebe',0,'','inherit','open','open','','kitty-bebe-2','','','2007-03-13 00:44:04','2007-03-12 22:44:04','',110,'http://www.groparu.ro/wp-content/uploads/2007/03/kitty-bebe.jpg',0,'post','image/jpeg',0),(112,1,'2007-03-13 00:46:55','2007-03-12 22:46:55','','Commission',0,'','inherit','open','open','','commission','','','2007-03-13 00:46:55','2007-03-12 22:46:55','',113,'http://www.groparu.ro/wp-content/uploads/2007/03/commission.jpg',0,'post','image/jpeg',0),(113,1,'2007-03-13 00:47:18','2007-03-12 22:47:18',' <a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/commission.jpg\" title=\"Commission\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/commission.jpg\" alt=\"Commission\" /></a>\r\n\r\nNu-i greu. Deloc. Eu am fost printre cei 30% care trebuiau sa pice. Daca 30% trebuiau sa intre, ma numaram printre admisi, finca tot timpul am facut parte dintre elite. Part of the chosen few.\r\n\r\nIntru inuntru, si zambesc stramb la cei sapte calai si calaitze. Si cand ma pun pe scaun in fatza lor scap un partz micutz, de emotie. Ei surad, intelegatori.\r\n\r\nIncep sa mi se prezinte, si repet numele fiecaruia dintre ei pronuntandu-l distorsionat in mod intentionat. Asta ii face sa se foiasca. Insist asupra numelor care incep cu \"F\" sh \"Sh\". Pe ultima doamna o intreb cati ani are, si ma uit la corpul ei. Ma intreaba \"Why do you want to know?\", si ii raspunz \"OK, forget it! I don\'t care, anyway...\". Mi-am dat seama ca are vreo 52.\r\n\r\nIntreb daca se fumeaza acolo la ei, si zic ca nu. E OK.\r\n\r\nIncep sa ma prezint. Si le zic ca ma cheama Napoleon Bonaparte, ca sunt reincarnarea unui calugar budist Kama Sutra, si ca \"Sunt cea mai desteapta persoana pe care am vazut-o vreodata in oglinzi! Jur!\", si ei nu se rad. Ma prezint in cele mai pastelate culori de tablou plin de nimfe guale-pushca prin padure, toate lesbiene. Ma intreaba unu, suedez, cica, un spalacit:\r\n\r\n- Hmmm, Mister Groparu, vaz ca ai stat vo ceva vreme prin Danemarca. Cum a fost?\r\n<em>- E! Zic io, mai nene. Aia is neshte cretini pesimisti. O gasca urieasa de alcoolici cretini si pesimisti. Prea multa depresie intr-o tzara asa de mica si de plata ca pieptu\' lu doamna asta de 52 de ani!</em>\r\n\r\nNormal ca nu i-am zis asta. In schimb, am fost suficient de pe faza ca sa ii dau lu nenea pantalonii jos, sa il intorc cu popo-ul la mine si sa ii ard un mozol tovarasesc tocma\' pe gaura aia maro de evacuare:\r\n\r\n- Domnul meu... danezii is niste oameni extraordinari!!! Extraordinari... am dat peste cap orice mit despre cat ar fi ei de reci. Is foarte calzi! Si femeile lor is calde. Foarte calde, si numa bune de incalzit asternuturi. Si mi-am facut o gramada de prieteni (nu le-am mai scris de vreo 2 ani batuti pe muchie la nici unu, dar in clipa aia imi erau frati de cruce).\r\n- Aha! zice suedezu. Ai invatzat ceva daneza?\r\n<em>Pizda mati, zic, atata m-o intrebat danezii chestia asta ca mi se dau ochii peste cap cand o aud iara!</em>\r\n\r\n- Cum sa nu, zic io, stiu sa zic \"Doo beri!\", asa, si \"Autobuzul asta merge la garaj\" (asta scria pe autobuzele care mereau sa se parcheze - \"Ikke y route\", parca...)\r\n\r\nNici macar nu or plescait. De regula lumea zambea condescendent cand auzea asta.\r\n\r\n- Oricum, zic, cred ca daneza e limba cea mai neplacuta sfantului profet Mahommed. Si nu am vrut sa o invatz finca stiam ca vor publica caricaturile alea de 2 lei. Oricum, daca vreodata pun mana pe autorii caricaturilor, pe numele lui Allah, vor plati cu sange! (si am scrashnit din dinti, cu flacari de aragaz in privire).\r\n\r\n- Bun, zice ei, haide acuma sa trecem la partea aia in care te intrebam despre traduceri.\r\n- Ce nu stiti? intreb eu. Sunt dispus sa va invatz.\r\n- Hahaha, you\'re funny, se gandesc ei - sau nu - si ma intreaba: daca ai de facut o traducere pe care nu o poti termina la termenul limita, ce faci: ceri sa se mareasca termenul de predare, ceea ce e imposibil, sau faci un rabat de la calitate?\r\n- Mai copii, zic io, hai sa va explic, ca voi nu prea stiti cu cine aveti de-a face. Ba, io traduc si repede si bine! Chiar bine. Si chiar repede. Mai repede decat repede. The repedest. The most and the best repedest!\r\n- Bine, suiera o tanti care era grecuaica si avea limba bifurcata si bag sama ca nu ii placeau baietii tineri, si nici aia otzara mai copti, cum is io, daca pana si marele Groparu (v-ati dat seama ce ironie fina) are un termen limita pe care nu il poate respecta, ce va face?\r\n\r\nIncep sa ma gandesc. Si ii spun, inocent:\r\n- Incerc sa imi dau seama ce raspuns ati vrea sa va dau ca sa iau punctajul maxim, si nu-mi dau seama. Ati putea va rog bifa ca am raspuns perfect?\r\n\r\nNush de ce, dar oamenii nu pareau sa fie foarte cooperanti.\r\n\r\n- Ce crezi ca ar trebui sa faca lumea si UE ca sa incetineasca incalzirea globala?\r\n- Pai e simplu, zic io. Ce provoaca incalzirea globala?\r\n- ?\r\n- Cine e raspunzator de incalzirea planetei mele?\r\n-??\r\n- Soarele!!! E simplu de tot. Tre\' sa stam la umbra si nu ne mai incalzim.\r\n- Hmmm - humuiesc ei. Cum sa pui o planeta intreaga la umbra?\r\n- <em>Ba, boi sunteti.</em> Cu o umbrela de plaja!\r\n\r\nN-am vazut in viatza mea oameni mai nauci. Poate numa\' cersetoru\' ala tigan care o venit in metrou in Statia Leopold nush care si mi-o cerut bani in franceza, si io i-am zis \"N-am, ba, du-te dracu!\" in cea mai hamaita limba romana pe care am scos-o din anale. Sau din anal.\r\n\r\n- Vad ca aveti un CV impresionant, spun ei.\r\n(chiar am!)\r\n- Da, zic io, daca ar fi si adevarat ar fi super! OOOOPS!!!\r\n(ma-ta de bou, Gropare! imi soptesc in romana)\r\n\r\n- Vedem aici ca stii si putin germana, zic ei.\r\n- Da, zic io, dar io nu prea ii suport pe nemti. Pornesc razboaie si se insuara cu surorile mele.\r\n\r\nM-am ridicat de pe scaun, am intins bratul drept, si am inceput sa bat pasu\' de defilare prin birou\' lor cu salutu nazist pe mine, si vorbind ca Fuehrerul, harshait, pe nas: \"Springen sprongen zu heimat radikal solutzion Nazi gut Juden raus Hottentotenschwiegermutterattentater!\", si m-o bufnit rasu, si m-am pus la loc.\r\n\r\n- Da, zic io. Nemtii is neshte tantalai. Dar stiti ce popor nu suport io de nici o coloare? M-am uitat drept in ochii lor. Se uitau la mine ca la o ciuperca atomica pe care o descoperit-o la picior. Inainte sa se sperie ca vine suflu\' ala de 4000 grade celsius care topeste nisipu\' si il face sticla.\r\n\r\n- Pai - zic - e simplu. Hai, ca stiti.\r\n- Domnule Groparu, spun ei, ne vedem obligati sa terminam mai devreme interviul.  Ne pare rau.\r\n\r\n- Ba, zic io, da\' io numa peste 20 de minute am metrou. Hai sa mai stam la o barfa! Apropos, pot sa va invit la o bere dupa asta? Hai ma! Sh inca ceva. Daca ma bagati aci la voi si imi dati 4000 EUR cum tot promiteti, facem jumi-juma. Ce ziceti? Ha? Stai ma pula, nu pune mana pe mine ca te sparg, hai sa ne intelegem, suntem oameni, doara! Shit, nu-mi da cu sprayu ala cu piper in oki! Ce dreq aveti? AAAAaa....\r\n\r\nSi atunci m-am enervat, si dupa ce m-or dat afara din birou, am iesit in strada, si m-am racorit. Am pus mana pe o piatra de pavaj, am aruncat-o in geam, si am urlat cat am putut de tare, sa auda toata lumea ce sunt ei:\r\n\r\n<font style=\"font-weight: bold\" size=\"5\">PEDOFILILOR!!!!!</font>\r\n\r\nSi apai am scos camera si am facut o poza la geamu\' spart. Si m-am tirat. Si am si pierdut avionu, dupa 2 zile. Din cauza lor, normal!','Cum se pica un examen la Bruxelles',0,'','publish','open','open','','cum-se-pica-un-examen-la-bruxelles','','','2007-03-14 16:21:39','2007-03-14 14:21:39','',0,'http://www.groparu.ro/?p=113',0,'post','',1),(114,1,'2007-03-13 00:47:55','2007-03-12 22:47:55','Citeam ieri in presa cum ca flatulatiile (da, flatulatiile! sau partzurile, aerele, vanturile, bashinile/beshinile, gazoasele, puturoasele, imputitele, metanoasele, aerul stricat, romgazele, \"balegile\", E.On gazele, austrul, viscolul/crivatzul, putrezitele, carbogazoasele, gazele rare si nobile, fasuri etc., etc., etc.) contribuie la efectul de sera. Dupa cum vad eu lucrurile, solutia asta are mai multe probleme, sau invers.\r\n\r\nDaca as fi Autoritatea Nationala de Reglementare a Gazelor Alimentare, as decreta scoaterea in afara legii a urmatorilor:\r\n\r\n1. Sorin Ovidiu Vantu. Cel mai partzaitor nume.\r\n2. Bashinosii de Becali, Vadim, Basescu, Tariceanu, Voiculescu, Iliescu, Geoana, senatorii, deputatii, cacaciosii, izmenitii, lingurarii, inspectorii OPC, inspectorii veterinari care interzic transhumantza, popii ortodocsi mai preacurvari ca mine, bivolarii, delapidatorii, sex turistii, vice-primarii, medicii spagari;\r\n3. Varujan. Cel mai bashit nume. Ca cand il reciti parca iese aeru\' cu furie dintre 2 buci, asa, jjjjjjjJJJJJJJJjjjj!!!!\r\n4. Izvorul Minunilor. O besina de apa carbogazoasa minerala imbuteliata la sifonerie.\r\n5. Ofiterii starilor civile, pentru ca stiu ce fasaiala e casatoria, dar nu fac nimic pentru a preveni tinerele cupluri visatoare, sau macar sa le zica sa ceteasca dreq cu atentie prospectu\'! Si la manifestari neplacute sa nu mearga la soacra. Mai bine sa mearga la farmacist sau pe Calea Turzii.\r\n6. Soia modificata genetic. Cel mai bashinos aliment modificat genetic, alaturi de celelalte alimente modificate genetic.\r\n\r\nDar nu ma pot impiedica sa nu ma gandesc: Doamna cu coasa are vanturi? Da\' ingerii? Flatulatiile vaginale au vreo contributie la efectul de sera? Pestii sunt besinosi? Delfinii se partzaie sonor unii catre altii si apai rad, cand beau o halba de alge de bere si se uita la un film porno cu balene? Daca lasi un partz in apa, se purifica de metanol in H2O? Daca am omori toti besinosii de politicieni din lume, nu ne-ar paste o glaciatiune? Desenele animale se partzaie? De ce \"a calca pe broasca\" e sinonim cu \"a se beshi\"? De ce \"a se beshi\" e verb reflexiv? Ca doara uneori te besheshti pe altii! De ce unii se beshesc cand ii tragi de degetul mic?','dEfectul de sera',0,'','publish','open','open','','defectul-de-sera','','','2007-03-13 00:47:55','2007-03-12 22:47:55','',0,'http://www.groparu.ro/?p=114',0,'post','',1),(115,1,'2007-03-13 00:50:32','2007-03-12 22:50:32','Â <a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/companie.jpg\" title=\"Companie\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/companie.jpg\" alt=\"Companie\" height=\"277\" width=\"457\" /></a>\r\n\r\nPentru ca in Romania somajul atinge uluitoarea cota in scadere de cca 6%, ma vad nevoit sa imi renegociez contractul individual de munca. Deci: draga firma, pentru a te putea bucura in continuare de prezenta mea incantatoare, da-mi voie sa iti prezint lista mea de revendicari.\r\n\r\n1. Masina de serviciu editie de lux, laptop de 3.000 EUR, asigurare de sanatate, telefon mobil, abonament la clinici medicale si sali de sport, domeniu gratuit de internet; doresc sa cumpar autoturismul de serviciu, nepoteii mei sa aiba ca babysitter o maseuza thailandeza si programe \"after school\" (cu posibilitatea de a urmari copiii on-line), burse in strainatate, joburi pentru ceilalti membri ai familiei: o sora in Germania care vrea sa fie pensionara, doi parinti pensionari care vor in Germania - basca doi nepotei de 5 si 3 ani care vor ferma lui Michael Jackson, Neverland, dar fara Michael. Mai doresc buget pentru haine, asistenta medicala la domiciliu si vacante platite; personal care sa-mi plateasca facturile, sa-mi duca hainele la curatatorie, sa-mi faca piata, sa-mi plimbe cainele; doresc sa pot alege eu cum sa arate biroul meu, chiar daca asta inseamna un scaun verde cu portocaliu, un perete negru cu verde si cu roz sau tablouri cu gandaci de bucatarie si floricele de porumb.\r\n\r\n2. Doresc sa am vedere asupra monitorului sefului 8h/zi, doresc ca atunci cand intarzie la serviciu sa vina sa imi explice de ce a intarziat. Doresc sa strig la el si sa il mustruluiesc in fatza altor sefi, si el sa zica: \"Iarta-ma, Radu, nu se va mai intampla!\"\r\n\r\n3. Vreau ca echipa mea de fotbal sa castige campionatul, cupa UEFA, Cupa Campionilor si toate cupele. Vreau ca galeriile echipelor adverse sa ia bataie de la galeria echipei mele. Si mai vreau locuri la peluza si bilete la meciurile in deplasare.\r\n\r\n4. Vreau ca americanii sa produca filme culturale, si mai vreau sa inteleg mesajul ascuns din filmele lui Tarkovski.\r\n\r\n5. Vreau ca Britney Spears sa fie internata intr-o clinica de de-britneyspears-izare. Si cand iese de acolo sa fie transformata in Maia Morgenstern. Si mai vreau ca Jiji sa fie internat intr-o clinica de de-jijizare, si cand iese de acolo sa fie transformat in Ion Cristoiu. Sau sa fie congelat, ca sa nu mareasca efectul de sera cu infierbantarile lui. Si mai vreau ca Demi Moore sa nu imbatraneasca.\r\n\r\n6. Vreau sa am un tablou cu mine in marime naturala expus in holul institutiei, pozand ca Napoleon.\r\n\r\n7. Vreau ca institutia sa aibe un portar imbracat numai fireturi, care sa isi ridice palaria cand trec pe langa el, si care sa desfasoare un covor rosu la intrare cand ma vede.\r\n\r\n8. Vreau ca ziarele sa vorbeasca despre mine ca despre urmatorul presedinte al Romaniei.\r\n\r\n9. Vreau inapoi Basarabia, Bucovina, Cadrilaterul, Crimeea si Norvegia. Si Japonia. Si Bahrein. Si Antarctica, intreaga America Latina, Extremul Orient si Polul Nord de pe Marte.\r\n\r\n10. Vreau ca votul meu sa hotarasca cine va conduce tzara, si mai vreau ca alegerile sa aiba loc de fiecare data cand cred eu de cuviintza.\r\n\r\nAcestea fiind spuse, draga firma, astept e-mailul prin care imi aprobi revendicarile. In caz contrar, te concediez!!!!','Ce-mi doresc eu mie, dulce Corporatzie!',0,'','publish','open','open','','ce-mi-doresc-eu-mie-dulce-corporatzie','','','2007-03-13 00:50:32','2007-03-12 22:50:32','',0,'http://www.groparu.ro/?p=115',0,'post','',0),(116,1,'2007-03-13 00:50:17','2007-03-12 22:50:17','','Companie',0,'','inherit','open','open','','companie','','','2007-03-13 00:50:17','2007-03-12 22:50:17','',-1173739676,'http://www.groparu.ro/wp-content/uploads/2007/03/companie.jpg',0,'post','image/jpeg',0),(117,1,'2007-03-13 00:51:19','2007-03-12 22:51:19','E a cincea zi in care traiesc intr-o lume de soia.\r\n\r\nMa dezbrac dintr-o pijamaua de soia, si incerc fara succes sa-mi potolesc erectia de soia, de dimineatza. Scot scama de soia din buric.\r\n\r\nFac un dush cu apa calda ca aia in care-o fiert soia, fac pishu in cada mea fara sa-mi pese si ma spal pe dinti cu pasta de dinti de soia.\r\n\r\nCobor din bloc intr-un lift de soia.\r\n<span> In troleu, ma inghesuie batranici de soia. Batranicile de soia miros a naftalina si a haine vechi uitate in dulap din 1972, si ma inghesuie chiar daca restul troleului e gol pujca. Si unele imi si zambesc surasuri stirbe, sau de aur si de soia.\r\nMicul dejun e din covrigi cu susan, tot cu gust de soia. Si sarea de pe ei are gust de soia. Cand iau micul dejun, gandurile mele is din soia.\r\n</span>\r\n\r\n<span>Stau pe un scaun ergonomic de soia </span><span>8-9 ore pe zi</span><span>, si un tricou de soia se muleaza de spatele meu, tot de soia. Citesc mailuri de soia, si presa de soia. Uneori scriu si documente de soia. Alteori nu. Cetesc bloagele mele de soia. Si mai cetesc despre Uniunea Europeana care uneori e de toata soia. Si mai cetesc despre scandaluri politice, intre un prim-ministru de soia si un presedinte numa zgarciuri.</span>\r\n\r\n<span></span>Plec in pauza de masa, ma uit pe strada dupa cururile de soia ale studentelor, da\' numa cand nu ma vede ele, ca cica e rusinos, asa zice taica-meu. Daca nu te vede, nu e rusinos.\r\nIn pauza de masa mananc ce apuc, eventual mai platesc si rate la o banca de soia.\r\nRevin la documentele mele de soia, scandalurile politice de soia si eventual o mana de seminte de floarea soarelui, ca in post nu fumez. Nici macar soia.\r\n\r\nPlec acasa la o anumita ora, ajung acasa, ma dezbrac si bag deshtele de la mana intre deshtele de la picioare si scot soia dintre ele. Ma uit la Dan Negru si la invitatele lui cu sani de soia modificata genetic. Pap soia. Si ma intind la loc in patu ala de soia, cu asternuturi de soia, si visez campuri de soia.\r\nSi incerc sa inlocuiesc \"Sa moara capra vecinului\" cu \"Sa se ofileasca lanul lui de soia!\"\r\nCe soia mea!','O lume minunata, toata de soia',0,'','publish','open','open','','o-lume-minunata-toata-de-soia','','','2007-03-13 00:51:19','2007-03-12 22:51:19','',0,'http://www.groparu.ro/?p=117',0,'post','',0),(118,1,'2007-03-13 00:52:02','2007-03-12 22:52:02','Bag sama ca ma apropii de momentul critic. De sevraj.\r\n\r\nIs destul de foarte iritabil.\r\n\r\nCea mai mica adiere de vant ma scoate din minti, mi se pare ca toata lumea ma vorbeste pe la spate, imi sar mucii din nimic (io-s kiar un ficior pajnic), ma comport ca o femeie presedinte la ciclu si cu o manutza pe tamponu roshu si cu ailanta pe butonu roshu, vad conspiratii peste tot - in trolee, in magazin, in ochi, pe flori, pe buze ori morminte.\r\n\r\n\r\n<strong>I.</strong> In primu\' rand ca am facut febra musculara la falci de la mestecat fara pofta cate trei ore mancarea scarboasa fara carne; nij nu mai pot pronunta cum trebe cuvintele.\r\n\r\n<strong>II. </strong>In al doilea rand ca simt nevoia destul de DISPERATA sa bag o pipa in gura. Stiu ca la primu\' fum m-as ineca si as renuntza la reapucat (noa,..... poate de la al treilea, nu chiar de la primul), dar de doua chestii is covins 100%:\r\n\r\n1. SUNTEM ROMANI, SI PUNCTUM;\r\n2. NU VREAU SA BAG TIGARA IN GURA IN POST, SI PUNCTUM (desi am inceput cu d-alea \"amu e o prostie sa renuti 100% dintr-o data, trebuie treptat etc\" - numa de-a dreq nu ma las! nu ma si nu ma si nu ma las de renuntat);\r\n\r\n<strong>III. </strong>In al treilea rand ca mi-am umplut frigideru\' de bunatati (buek...):\r\n- lapte de soia cu 5 arome (capshuni, cacao, ciocolata, regular, banana shake) - numa 68.000 kilu\';\r\n- pateu de soia de vreo 4 feluri, cu verdeatza, cu ciuperci, cu masline si cu marar, adica cu E445, E234, E853 si E896 (ultimu\', dupa cum se stie, este un delicios substitut al mararului);\r\n- branza de soia de vreo patru feluri - cu verdeatza, cu ciuperci, cu masline si cu marar, adica cu E445, E234, E853 si E896 (ultimu\', dupa cum se stie, este acelasi delicios substitut al mararului);\r\n- nush ce fel de porcarie de porumb conservat pe undeva prin Ungaria, care in zilele cand haleam carne si fumam avea gust mortal, da\' amu are gust de caca de pisicutza care o papat mancare granulata de Shinshilla;\r\n- margarinaaaa!!! (nu am mai papat asa ceva de vreo cativa ani buni, si inca nu am avut curaju\' sa ma apuc de ea);\r\n- paine - musai d-aia cu multe seminte pe ea, de arata ca un baton pentru papagali;\r\n- broccoli.\r\n\r\nDaca as fi caricaturist, as face haz de necaz desenand un OZN care coboara pe gazonu\' de la Casa Alba, si cand sa dea extraterestru\' ambasador plenipotentiar de pe Venus manutza cu George W Bush si sa comunice omenirii mesaju\' de prekenie, Groparu ar tzajni din multime si l-ar baga intr-o kukta si s-ar face nevazut si l-ar duce intr-o kimnitza si ar incepe sa il rontaiasca si sa il crontzaneasca (extraterestru e de post, ca nu e animal sau lapte!) Si as spune chiar \"You chose the wrong solar system to make new friends in, ET!!!\" (fuck, daca si ET are E-uri? E-uri de tip \"T\"?!?!)\r\n\r\n\r\nOricum ar fi, la anu\' m-am hotarat: o sa tin post exclusiv cu ciuperci halucinogene.','A patra zi de post',0,'','publish','open','open','','a-patra-zi-de-post','','','2007-03-13 00:52:02','2007-03-12 22:52:02','',0,'http://www.groparu.ro/?p=118',0,'post','',0),(119,1,'2007-03-13 00:52:22','2007-03-12 22:52:22','Am rupt gura Targ-Napoca, am masina de spalat Samsung Silver <strong>Onano</strong> Technology!!!\r\n\r\nMasina are:\r\n\r\n- program antistoarcere\r\n- program haine delicate/cacate/pishate, depinde de tipul intalnirii: cu gajica/cu urs/cu caine comunitar\r\n- trapa detergent\r\n- cuva (dama de companie) de aluminiu\r\n- GPS\r\n- Teo Show\r\n- SMS/MMS\r\n- ABS\r\n- .pdf\r\n- GPRS\r\n- program anti-Becalizare rufe albe\r\n- HDD 160 Gb\r\n- geamuri electrice\r\n- buton anti-penis captivus\r\n- 3G\r\n- atentat sinucigas cu bomba in Bagdad\r\n- MP3 Player\r\n- POP 3\r\n- USB\r\n- handsfree\r\n- Klimatronic\r\n- modem\r\n- Times New Roman, Verdana &amp; Microsoft - Sans Serif\r\n- infrarosu pe bluetooth\r\n- ABS\r\n- 4 usi/5\r\n- SQL Server\r\n- absorbant de panza\r\n- referendum pentru introducerea votului uninominal\r\n- Internet broadband\r\n- EKG\r\n- tehnologie anti-hackeri\r\n- smf fmm pm\r\n- Google<span style=\"font-size: 10pt\">Â® </span>Earth\r\n- sistem anti-taxa de prima inmatriculare\r\n- benzina Efix de la Rompetrol\r\n- credit nesubventionat de la CEC pentru tinerii necasatoriti\r\n-  arme de distrugere in masa\r\n- spatiu comercial de 10x12 mp\r\n- Babylon Blue (pentru cunoscatori)\r\n- programe scolare alternative\r\n- Yahoo!<span style=\"font-size: 10pt\">Â®</span> Messenger 8.1 live, care cam crapa, d-aia va si recomand sa nu vi-l instalati\r\n- Kanal D\r\n- .jpg\r\n- tehnologie anti-spam\r\n- optiune de pus pe ignore\r\n- 7 ani de acasa\r\n- calculator rata schimb â‚¬/$/Â¥\r\n- brain (and, if not available) retina scan\r\n- biscuiti de post (apropos, sunt in ziua a treia)\r\n- sutien push-up\r\n- sistem Surround\r\n- program de curatzat gainaztul de pescarush\r\n\r\n\r\n\r\n+ bonus, un coreean mic care locuieste in masina si care de fapt el spala rufele.','Am masina de spalat 9',0,'','publish','open','open','','am-masina-de-spalat-9','','','2007-03-13 00:52:22','2007-03-12 22:52:22','',0,'http://www.groparu.ro/?p=119',0,'post','',3),(120,1,'2007-03-13 00:54:22','2007-03-12 22:54:22','<a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/eskimo.JPG\" title=\"eskimo.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/eskimo.JPG\" alt=\"eskimo.JPG\" /></a>\r\n<table style=\"width: 1px; height: 22px\" align=\"right\" border=\"0\" cellpadding=\"0\" cellspacing=\"0\">\r\n<tr>\r\n<td></td>\r\n</tr>\r\n<tr></tr>\r\n<tr></tr>\r\n<tr></tr>\r\n</table>\r\n<span class=\"arial12negru\">Cica - preluare de pe <a href=\"http://www.hotnews.ro/articol_66521-Eschimosii-dau-in-judecata-Statele-Unite.htm\">hotnews.ro</a>: <font>\"e</font></span><font>schimosii si inuitii din nordul Canadei si Alaska dau in judecata statul american din cauza degradarii mediului prin emisiile mari de gaze cu efect de sera in atmosfera. \"</font>\r\n\r\nCorect. Dar cu totii stim ca americanii merita sa plateasca si pentru ca:\r\n- prima mea gajica Teo m-o parasit pentru un prieten de-al meu, cu care s-o si maritat, si eu nu aveam decat 16 ani, si eu am trecut peste asta, finca urmau alte esecuri amoroase;\r\n- am picat de doua ori la facultate, si am picat si doua mastere dupa aia, si tot nu m-am lasat (scorul oricum ramane 3&gt;1 pt mine), ba am inceput si un master de care nu am mai avut chef dupa aia, ca era de programare (buek!!!);\r\n- am stat in caminul 16, cel mai imputit, 2 ani de zile din studentie, cei mai bestiali;\r\n- am refuzat mereu cu obstinatie sa ma depilez pe picioare, si ii incurajez si pe alti masculi sa faca la fel;\r\n-  ascult manele uneori cand sunt praf de beat; si uneori chiar si cand nu sunt;\r\n- Dan Negru bate toate ratingurile pe fusul lui orar;\r\n- pe Discovery e numai si numai aceeasi emisiune despre American Chopper;\r\n- pe Animal Planet e numai si numai aceeasi emisiune despre veterinarii aia care au mai multa grija de catzalushii aia bagabonti decat au medicii de la Oncologie din Romania de pacientii lor;\r\n-  in 1996 <span class=\"arial12negru\">Constantinescu a fost ales </span><span class=\"arial12negru\">presedinte;\r\n- rodiile costa prea mult pentru cat fruct au in ele;\r\n- nu mi se aproba ca garsoniera mea sa devina paradis fiscal, sau macar paradis de nudiste, sau macar sanctuar de virgine lesbiene;\r\n- cand evacuez apa din cada mea de acasa bolboroseste de parca ar fi mancat fasole cu iaurt;\r\n- porcii de pe domnuleprimar.ro nu mi-au postat blog entry-ul anterior;</span>\r\n\r\nDe fapt, eu provoc efectul de sera mai mult decat americanii - prin faptul ca schimb ciorapii, chilotii si tricoul zilnic - in afara de cazurile cand nu ii schimb zilnic. Asa ca astept eskimoasele alea sexy cu ochi oblici sa ma dea in judecata si sa ma condamne la un viol in grup cu untura de balena.','Eschimosii dau in judecata Statele Unite',0,'','publish','open','open','','eschimosii-dau-in-judecata-statele-unite','','','2007-03-14 15:48:11','2007-03-14 13:48:11','',0,'http://www.groparu.ro/?p=120',0,'post','',0),(121,1,'2007-03-13 00:54:40','2007-03-12 22:54:40','Stimate Domnule Primar,\r\n\r\nNu stiu daca ati mers mileniul acesta cu autobuzul in Cluj-Napoca (nu ma refer la autobuzul special catre aeroportul Someseni). Ce stiu insa e ca de cand cu (laudabila?) initiativa a dumneavoastra de a acorda pensionarilor fara discriminare abonamente gratuite pentru transportul in comun, autobuzele si trleibuzele RATUC au intrat in Europa, mai exact in Suedia, tara renumita pentru saunele sale. Nu sunt pentru renuntarea la gratuitatea acordata pensionarilor, dar niciodata traficul in oras nu se va decongestiona atata vreme cat autobuzele seamana cu un banc de sardele. De ce nu ati:\r\n\r\n- asigura transportul pensionarilor in intervale orare bine determinate, nu si in orele de varf? (autobuzele si troleibuzele gem de pensionari care se urca o statie si coboara la urmatoarea, mai ales la orele la care lumea merge la sau vine de la serviciu/scoala)\r\n- asigura transportul pensionarilor in autobuze speciale, destinate numai si numai acestora?\r\n- mari, pur si simplu, numarul de autobuze??? autobazele (cel putin ce se poate vedea intr-o zi normala de lucru) trimit numai jumatate din efectivul de autobuze pe traseu, restul raman nefolosite.\r\n\r\nSau DE CE NU ATI TICSI PUR SI SIMPLE AUTOBUZELE CU ELEVE DE LICEU DE CLASA A XII-A???\r\n\r\nVa salut, Groparu, pui de pensionari.','Scrisoare intredeschisa D-lui Primarele',0,'','publish','open','open','','scrisoare-intredeschisa-d-lui-primarele','','','2007-03-14 16:17:53','2007-03-14 14:17:53','',0,'http://www.groparu.ro/?p=121',0,'post','',0),(122,1,'2007-03-13 00:55:02','2007-03-12 22:55:02','Urla presa! Canta ziarele! Tariceanu ii cheama inapoi in tzara mea pe romanashii plecati pe dincolo. Zice ca le va pregati un pachet special de beneficii compensatorii. Eu cred ca numai din cauza ca vrea sa devina un Tito al Romaniei, pentru ca numai dictatorul iugoslav mai aplicase cu succes formula asta.\r\n\r\nDom\' prim-ministru, hac, laudabila intentie, hac. Dar partidul Groparia Mare avea de mult in platforma program initiativa asta. Permiteti-mi sa o detaliez:\r\n\r\nEu as propune ca in primul val sa se intoarca in tzara o armata de vidanjori, ca sa scoata Romania din rahat.\r\n\r\nIn a doua etapa, vidanjorii sa fie angajati ca brutari si clowni; astfel, Romania va avea parte de paine si circ.\r\n\r\nIn a treia etapa, trebuie sa asiguram Romaniei un sistem de sanatate performant. De aceea, toti medicii si toate cadrele medicale din Dubai, Kuweit, Franta, Germania, America, Marea Britanie care vor dori sa revina in tzara vor fi scoliti cum sa isi faca treaba numai pe baza de spaga; si cum sa inghita bancnotele marcate \"spaga\" cu cerneala fluorescenta, in caz de flagrant.\r\n\r\nIn a patra etapa, guvernul se va ocupa de reforma sistemului de educatie. Vor avea prioritate profesorii plecati in Italia si Spania la cules de capsuni si in Canada la condus taxiuri. Un loc aparte il vor ocupa rromii care revin din Germania si care vor fi repartizati catedrelor de germanistica care se vor deschide in fiecare scoala.\r\n\r\nIn a cincea etapa, cultura. Rromilor care canta prin metrourile pariziene li se vor crea locuri la Filarmonica de Stat \"Vali Vijelie\" din Ramnicu Valcea;\r\n\r\nIn a sasea etapa, va trebui reformata una din slabiciunile economiei romanesti: romanilor plecati la cersit in Italia li se vor asigura posturi de marketing and communication managers si public relations experts.\r\n\r\nAl saptelea pas va fi reprezentat de promovarea turismului. In acest scop, sex-lucratoarele romance revenite de pe plaiuri europene vor reusi sa transforme Romania in noul punct fierbinte pe harta turismului sexual. Si ce nu vor reusi ele, vor reusi turistele suedeze de la Marea Neagra.\r\n\r\nNu vor fi bineveniti programatorii romani de la Microsoft. Decat daca sunt dispusi sa lucreze in noul call center din Bucuresti, pentru 200 dolari pe luna.\r\n\r\nSi astfel, eu, Groparu, va jur ca voi face o Romanie frumoasa ca soarele sfant de pe cer!!! Si daca planul meu nu va reusi 100%, tot va fi bine. Ca daca eu nu razbesc sa va fur cu 2 maini, or sa ma ajute proaspat intorsii din Europa. Sa fur. Mai mult si mai bine.','Romani, va ordon, reveniti AcasaTV!',0,'','publish','open','open','','romani-va-ordon-reveniti-acasatv','','','2007-03-13 00:55:02','2007-03-12 22:55:02','',0,'http://www.groparu.ro/?p=122',0,'post','',0),(123,1,'2007-03-13 00:56:32','2007-03-12 22:56:32','','Porumb',0,'','inherit','open','open','','porumb','','','2007-03-13 00:56:32','2007-03-12 22:56:32','',124,'http://www.groparu.ro/wp-content/uploads/2007/03/porumb.jpg',0,'post','image/jpeg',0),(124,1,'2007-03-13 00:56:39','2007-03-12 22:56:39','Â <a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/porumb.jpg\" title=\"Porumb\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/porumb.jpg\" alt=\"Porumb\" /></a>\r\n\r\nDeci Iisus a fost, conform unor oameni mult mai luminati si mai avizati decat hoardele de oameni de stiintza care de cateva mii de ani studiaza Biblia si nu ii gasesc cusururi, un muritor de rand. Ba mai mult, a fost si insurat cu o nevasta, si ar fi avut si soacra. Ba mai mult, a avut si copii. Ba mai mult, a si murit. De-a binelea.\r\n\r\nDin moment ce ar fi fost om ca noi toti, si meseriasii astia stiu mai bine ca noi toti, eu totusi vreau ca GENIALII sa aduca urmatoarele dovezi despre Iisus, si anume cum ca:\r\n\r\n- circula pe RATUCu\' ala al lor evreiesc fara sa plateasca bilet, si cand era prins dadea spaga la rabinii controlori;\r\n- chiulea de la scoala, si isi facea rost de scutire medicala in alb pentru rabina-diriginta;\r\n- mergea in OSER sa isi cumpere insigne comuniste;\r\n- la teza de limba ebraica copia; si cand pe vremea lui se fraudau testele de capacitate, ministrul educatiei de atunci le transmitea pe Internet;\r\n- trebuie ca si-a filmat pe video sau tras pe DVD presupusa sa nunta; sau macar un anunt mic la rubrica de felicitari din \"Racnetul Ierusalimului\", editia <em>anno 28 e.n.</em>?\r\n- expre\' si-a ascuns mormantul tocmai pentru a prinde etapa asta a vietii lui Dan Brown cand avea mai mare nevoie sa devina multimilionar (cica $250 .000.000 o facut nenea cu cartulia lui!)\r\n- si-a dus copiii la gradinita  particulara sau de stat; si mai tarziu, i-a dat la medicina, sau la Drept;\r\n- pestii pe care i-a facut ca sa hraneasca multimea erau cumparati de la Metro;\r\n- cand a transformat in direct apa in vin era in <em>prime time</em>, si a fost transmis <em>live</em> pe Prima TV la emisiunea aia cu nuntile (nu mai stiu cum o cheama);\r\n- e adevarat ca luase lectii de la David Copperfield atunci cand a umblat pe apa;\r\n- multimea de oameni care a preferat sa-l salveze pe Baraba in locul Sau erau suporteri proaspat iesiti de la meciul FC Bunul Samaritean - Deportivo Galileea;\r\n\r\nSi, in sfarsit, dovada ca nu sta chiar acuma de la dreapta Tatalui si suspina usurel in barba-i \"Doamneee, mare e gradina Ta! Dar multi mai sar gardul cand e poarta deschisa...\"\r\n\r\nSe-aude, domnu\' Dan Brown???','Despre mormantul lui Iisus',0,'','publish','open','open','','despre-mormantul-lui-iisus','','','2007-03-13 00:56:39','2007-03-12 22:56:39','',0,'http://www.groparu.ro/?p=124',0,'post','',4),(125,1,'2007-03-13 00:57:03','2007-03-12 22:57:03','<a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/uncle-sam.jpg\" title=\"uncle-sam.jpg\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/uncle-sam.jpg\" alt=\"uncle-sam.jpg\" height=\"506\" width=\"407\" /></a>\r\n\r\nDupa parerea mea, e bine sa fii American din cel putin doua motive:\r\n1) pentru ca poti cumpara cel mai ieftin bilet la cea mai generoasa loterie din lume; si\r\n2) pentru ca si daca nu ai castigat la loterie, daca vii in Romania o sa ai senzatia ca esti un mic nabab inr-o lume de fellahi (sau felatzi) permanenti.\r\n\r\nAmu la al doilea motiv nu aduc ca rezon decat larghetea si marinimia cu care justitia romaneasca, oarba, surda, proasta, agustatila si nici macar tactila, ci numai gros-cutanata iarta infractori americani. Oricum, faza cu Treptow tot a picat ca o mica bomba, si a revarsat a suta oara proverbialul paharel cu palinca. Pentru ca daca nu avem nevoie de delapidatori americani, soferi americani beti ranga sau bechteli care sa preia fara licitatii proiecte de miliarde de $, cu atat mai putin avem nevoie de americani care sa transforme Romania intr-o destinatie a turismului sexual, si care sa fie facuti scapati.\r\n\r\nAcum, daca pana si Treptow a fost eliberat pe rezon de buna purtare, propun urmatoarele:\r\n- toti pedofilii din inchisorile romanesti si belgiene sa fie eliberati, reabilitati si propulsati in cursa pentru Cotroceni si pentru Parlamentul European, sau, la cerere, Consiliul Suprem al Magistraturii;\r\n- Armata romana sa devina o caprarie minuscula a United States Army, Navy and Air Force; generalii romani sa faca scoala de soferi cu geamantanul pe sub paturile suprapuse, iar maresalii si comandorii sa fie trecuti in randul personalului auxiliar folosit la curatenie, aprovizionare si bucatarie;\r\n- George W. Bush sa il promoveze pe Basescu seful flotei de lebede de la ferma sa din Texas;\r\n- tot George W Bush sa urmareasca SuperBowl-ul American din loja VIP-urilor cu Becali, acum proaspat proprietar al echipei Red Sox peste Picioare Negre, Crestine si Nespalate;\r\n- Biserica Ortodoxa sa fraternizeze cu mormonii din USA, iar preotii nostri rotofei si barbosi si fustangii, acum cu placute cu numele lor prinse in piept, sa propovaduiasca multigamia in piatza publica si din usa in usa;\r\n- Elena Udrea si Condoleeza Rice sa declare razboi Transnistriei, Cubei si Insulei Serpilor intr-o pauza de shopping prin mall-urile din Dubai;\r\n- Petre Roman, Bill Clinton, Irinel Columbeanu si Howard Stern sa puna bazele asociatiunii \"Cum sa practici libertinajul sexual chiar si la o varsta grizonata\".\r\n\r\nAstfel incat atunci cand poporul asta mic si tanar de 2.000 va fi din nou incalecat de perversi, vom avea sigurantza ca macar avem de-a face cu profesionisti, nu cu diletantii care de ceva vreme isi fac de cap prin tzara mea. Si a ta. A noastra.','De ce e bine sa fii Yankeu in Romania',0,'','publish','open','open','','de-ce-e-bine-sa-fii-yankeu-in-romania','','','2007-03-14 15:44:56','2007-03-14 13:44:56','',0,'http://www.groparu.ro/?p=125',0,'post','',1),(126,1,'2007-03-13 00:58:13','2007-03-12 22:58:13','Dupa ce - cum zicea un clasic in viatza - s-a ajuns la vanzarea Basarabiei, un nenea foarte dezolat si ranit in amorul sau (propriu) s-a hotarat sa isi vanda pe e-bay DRAGOSTEA. Exact. DRAGOSTEA. Nush daca fac bine ca scriu cu majuscule mari, finca nush cati centimetri are dragostea lu\' nenea (de parca marimea ar mai conta, Doamne, iarta-ma, dupa tot arsenalu\' ala de jucarioare sexuale nucleare disponibile pe piatza, ca poti linistit sa te uiti la meci in timp ce iubita ta face dragoste cu tine!) Oricum, licitatiunea s-a incheiat fara ca cineva sa ii ofere mai mult de 99 eurocenti, inainte ca e-bay sa opreasca licitatia.\r\n\r\nAmu, m-am hotarat sa imi fac si eu cont pe e-bay, si sa imi vand ura. Da. URA. Si asta o pot scrie cu majuscule mari, pentru ca de asta pot sa va zic cu manutza pe inimioara: E MARE, FRATILOR, SI GROASA. Tot timpul am zis despre mine ca sunt o persoana care poate iubi gros si lung - in consecinta pot si uri gros si lung. Ce uraste Groparu?\r\n\r\n- cozile la banca, cand unei fashnetze care are si impertinentza de a nu fi bunoaca ii trebuie 20 minute pentru a completa un formular persoanei dinaintea ta;\r\n\r\n- pe tanti de la cUrPC care iti zice, nonsalanta, ca \"nu ni se renteaza sa facem promotie cu abonament pe mai putin de 12 luni\" - nu inke, draga mea, \'r-atz ai dreq de monopolisti, da\' de-abia astept momentul in care voi zice \"Corporatii din toata lumea, pupati-ma in chestia aia care seamana cu o gura maro de lipitoare, atata numa ca n-are dinti!\"\r\n\r\n- pe ratucii de orice culoare, cu orice fel de geaca neagra de piele. Fara discriminare. Pe autobuzele pe care isi desfasoara activitatea. Pe batranele care ma pipaie in troleu.\r\n\r\n- pe fatza aia lunga si urata care se uita la mine cu uimire dimineatza din oglinda, cine dreq e uratu ala nebarbierit???\r\n\r\n- pe aia care prind mai mult peste decat mine, cand merg la pescuit;\r\n\r\n- pe salariul meu, ca nu naste pui vii mai mari ca el, vine o data pe luna si  nici nu primeste mosteniri;\r\n\r\nPret de inceput de licitatie - un milion de coco. Moca. Dai un milion si unu si e a ta!!!','Amor de vanzare pe e-bay, nu se stie cati centimetri',0,'','publish','open','open','','amor-de-vanzare-pe-e-bay-nu-se-stie-cati-centimetri','','','2007-03-13 00:58:13','2007-03-12 22:58:13','',0,'http://www.groparu.ro/?p=126',0,'post','',0),(141,1,'2007-03-14 15:30:52','2007-03-14 13:30:52','','putin.jpg',0,'','inherit','open','open','','putinjpg','','','2007-03-14 15:30:52','2007-03-14 13:30:52','',128,'http://www.groparu.ro/wp-content/uploads/2007/03/putin.jpg',0,'post','image/jpeg',0),(128,1,'2007-03-13 01:01:44','2007-03-12 23:01:44','<a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/putin.jpg\" title=\"putin.jpg\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/putin.jpg\" alt=\"putin.jpg\" /></a>\r\n\r\nEu cred ca o presa nu poate fi si libera, si ruseasca in acelasi timp.\r\n\r\nIn Rusia, ziaristii mor din mai multe motive. In primul rand mor linistiti, in pat. In pat de pusca.\r\n\r\nIn Rusia, ziaristii mor si de idei. Dupa cum s-a reconfirmat acum relativ recent in cazul Annei Politovskaia, ideile nu pot convietui pasnic cu gloantele in spatiul din aceeasi calota craniana. Fenomenul - inca neexplicat - ii tulbura si acum pe oamenii de stiinta.\r\n\r\nIn Rusia, speranta de viatza depinde si de alimentatie, mai exact de mezeluri, mai exact de crenvursti si de polonezi. <font size=\"-1\">Alexander Litvinenko si-a dat seama prea tarziu ca vremea studentiei a trecut si nu poti sta la nesfarsit cu un poloniu in cafenele.</font>\r\n\r\n<font size=\"-1\">Tot in Rusia, gravitatia nu poate coexista cu jurnalismul. Cand a descoperit acest lucru, </font>Ivan Safronov, cel mai recent Icar rus, era prea tarziu. Desi sperase sa aiba suficienta vreme sa isi compuna scrisoarea de adio in plina cadere de la etajul 5, se pare ca s-a inselat. Distanta pana jos era nu numai daunatoare sanatatii, ci si deosebit de foarte mortala - mai ales daca esti ziarist.\r\n\r\nDaca ar fi sa facem o lista cu trei tari care mai au doar un punct de atins pana la perfectiune, lista ar arata cam asa:\r\n- Anglia - fostul imperiu ar trebui sa interzica vanatoarea de vulpi, femeile urate si alcoolul;\r\n- Japonia - fostul imperiul ar trebui sa interzica pescuitul industrial de balene;\r\n- Rusia - fostul imperiu ar trebui sa scoata in afara legii uciderea de ziaristi ca sport national, si sa se indrepte, Putin cate Putin, spre democratie.\r\n\r\nUn singur lucru mai adaug: dom\'le Putin, hac,\r\n\r\n\"The New York-based Committee to Protect Journalists said in January that 13 Russian journalists have been murdered in contract-style killings since 2006, making Russia the third-deadliest country for journalists after Iraq and Algeria in the past 15 years.\"<a href=\"http://www.chron.com/disp/story.mpl/world/4602741.html\">*</a>\r\n\r\n...vez\' ca 13 e numar cu ghinion, hac. Ori il imbalsamezi p-unu dintre ziaristi ca pe Lenin, sa ramana numa 12, ori mai omori vreo 10, hac, ca sa scapi de blestem. Parerea mea...','Dar ziaristii rusi cum mor, cand mor?',0,'','publish','open','open','','dar-ziaristii-rusi-cum-mor-cand-mor','','','2007-03-14 15:31:06','2007-03-14 13:31:06','',0,'http://www.groparu.ro/?p=128',0,'post','',0),(129,1,'2007-03-13 01:02:26','2007-03-12 23:02:26','','Putin',0,'','inherit','open','open','','putin-2','','','2007-03-13 01:02:26','2007-03-12 23:02:26','',128,'http://www.groparu.ro/wp-content/uploads/2007/03/putin.jpg',0,'post','image/jpeg',0),(342,1,'2007-04-23 22:47:50','2007-04-23 20:47:50','','buda_0.jpg',0,'','inherit','open','open','','buda_0jpg','','','2007-04-23 22:47:50','2007-04-23 20:47:50','',-1177356744,'http://www.groparu.ro/wp-content/uploads/2007/04/buda_0.jpg',0,'post','image/jpeg',0),(343,1,'2007-04-25 00:16:55','2007-04-24 22:16:55','<a href=\"http://www.groparu.ro/wp-content/uploads/2007/04/bocitoare.jpg\" title=\"http://www.gandul.info/articol_11260/profesia_mea___bocitoare.html\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/04/bocitoare.jpg\" alt=\"http://www.gandul.info/articol_11260/profesia_mea___bocitoare.html\" /></a>\r\n\r\nDe cand m-am reapucat de fumat, dimineatza ma simt ca o Dacie berlina promotia 1979, hranita cu ulei de rapitza. Da\' nu despre asta vreau sa scriu.\r\n\r\nIo... pula me, nu mai am bunici. S-or tat dus. Aia din Sibiu - cand aveam o varsta de o cifra, sh nu mai stiu decat ca mancam struguri stropiti, sh buna-mea din Turnishor ashe s-o crizat, ca am crezut ca acolo da coltzu\': mi-o spalat cu detergent cea mai bengoasa ciorchina, mi-o pus-o intr-o farforie cu chenar codabiu sh m-o silit sa o inghit, ca sa nu mai rÃ¢mniesc la Äƒia strokiÅ£i. Am bÄƒgat la duoden ce am bÄƒgat, ÅŸ-apÄƒ am ieÅŸit afarÄƒ ÅŸi m-am dus aÅ£Äƒ Ã®n vie unde am continuat, netulburat, sÄƒ ma otrÄƒvesc cu boabe strokite cu pieatrÄƒ vÃ¢nÄƒtÄƒ. A, ÅŸi mai ÅŸtiu ca la mormÃ¢ntarea lu bunica Lili, cÄƒtzaua familiei, atÃ¢ta o hÄƒulit la popÄƒ, ca nu s-o lÄƒsat pÄƒnÄƒ nu ÅŸi-o cÄƒpÄƒtat o duzinÄƒ de picioare la spinare de la un alt unchi de-al meu care ÅŸi elÂ  iubea animalele; dupÄƒ o vreme, ÅŸi el o murit. DumnezÄƒu sÄƒ-i ierte. Åži Lili o murit, da\' mai incolo. Åži cre cÄƒ ÅŸi puricii lu\' Lili or murit.\r\n\r\nÃŽn fine, distracÅ£ia cea mare (o pula, distractia, nu credeti tot ce scrie Groparu!) o fost cÃ¢nd o murit ÅŸi bunica din Oltenia, Mama RiÅ£a Ã®i ziceam eu. SÄƒraca! S-o dus ÅŸi ea. TatÄƒ-mio (olteanu\' familiei, ca si mine, de altfel - stiti de ce? finca pe olteni ii boteaza asa, cand se nasc: \"<em>In numele Tatalui s-al Fiului, ia drumu\' Sibiuluuuuui... Aaaaaamiiiiin!</em>\") ne-o suit Ã®n faetonul familiei (Skoda 120 L, eee... ce maÅŸinÄƒ! ce amintiri de neuitat, cu radiatoare Ã®ncinse, smucituri furioase ÅŸi pene de motor la fiecare 8,2 km!!) ÅŸi ne-o cÄƒrat Ã®n Oltenia, sÄƒ o Ã®ngropÄƒm.\r\n\r\nAmu, amu cu Oltenia -Â  io tot timpu am zis cÄƒ is jumate oltean - jumatea buna, cÄƒ aia najpa, preponderentÄƒ, aia care fumeazÄƒ, se Ã®mbatÄƒ, preacurveÅŸte ÅŸi nu dÄƒ bani la ocazie e ardeleanÄƒ, Å£ine-o, Doamne! Noa, da\' Ã®n Oltenia, cÃ¢nd dÄƒ unu colÅ£u\', se face <em>paranghelie </em>mare. Cu bocitoare and shit. Åži cÃ¢nd am ajuns la mama RiÅ£a acasÄƒ, era liniÅŸte: vrÄƒbiile ciripeau, vacile mugeau - cÄƒ veneau de la pÄƒÅŸune danga-langa, ce mai! Peisaj pastoral fÄƒrÄƒ boi. Da\' linÅŸte fu pÃ¢nÄƒ ajunserÄƒm Ã®n curte la Mama RiÅ£a, fii iertat\'; cÄƒ numa ce pÄƒtrunserÄƒm, ÅŸi toate neamurile, vecinele, prekinele, colegele de ceapeu (da, ÅŸi Ã®n Oltenia femeile trÄƒiesc mai mult decÃ¢t bÄƒrbaÅ£ii) numa ce s-or pornit sÄƒ chirÄƒie, mÄƒi tatÄƒ, da sÄƒ chirÄƒie ca la festival! Au, uÄƒu, ÄƒÄƒjjjjj, mama mea, mÄƒmica meaaa... team leader peste bocitoare - mÄƒtuÅŸ-mea, tanti Sonia, o femeie care o fo aÅŸa de fainÄƒ la viaÅ£a ei, ca or furat-o tiganii cÃ¢nd era micÄƒ (Äƒsta nu e bullshit! o trebuit sÄƒ scoale bunu-meu, fii iertat, juma\' de sat sÄƒ-i prinzÄƒ pe ÅŸÄƒtrari!)\r\n\r\nAmu, Ã®n sufletul lu Tanti Sonia bag samÄƒ cÄƒ se dÄƒdu un conflict de erou clasic - Ã®ntre datorie ÅŸi sentiment. Datoria - trebia sÄƒ boceascÄƒ, cÄƒ aÅŸa se Ã®ntÃ¢mpinÄƒ Äƒia de vin Ã®n priveghi; sentimentu\' - na, o vint frati-su\', tata-mio, de, cu tat cu nepotii aia de nu-i mai vazuse de mai an! Asa ca tanti Sonia bocea, mai mama, bocea de-ti transpirau sosetele, mai, sosetele, da\' nu se abtinea si tot ne zicea \"Aooooleeeoo, mama meaaa, maicuta meaaa,... <em>Ilie, ati venit cu bine</em>?\" (Ilie e tata-mio, tine-l, Doamne!) \"Unde te duuuci, unde te duuuci... <em>Ilie, pune sacosele acolo, da, acolo in prispa, ati adus ceva care se strica? baga-le in beci, mai, in beci</em>, asa, aooleeeuuuu, vaaaaaii, aoleeeeuuu....\"\r\n\r\nNush cum e in Ardeal, desi stiu sigur ca e la fel ca in sud, da\' in Oltenia traditia cere ca mostenitorii sa sara sa se certe pe mostenire pana sa se raceasca cadavru\'.  Asa ca in aceeasi seara toti cei vreo 4 sau 5 frati cati erau, mai putin taica-meu (asta iara nu e bullshit) si-or disputat <em>cotiga</em>, porumbu din <em>pÄƒtul</em>, <em>tiuciu</em>\', bucatele, iahnia de fasole, pula mea! tat ce era de loat. Si nu le pot decat recunoaste, cu deferentza, retorica exemplara. Cand i-am auzit zbierand unu la altu ca o herghelie de capre in calduri, io m-am gandit ca as fi incapabil sa le refuz vreodata vreo doleantza, indiferent de imprejurare. Finca se zice ca d-aia e bine sa iti iei nevasta olteanca, ca cu aia te certi, mai frate, te certi, nu gluma!!! Te certi!!! Si pacat ca nu intrara in politica neamurile astea ale mele, finca astia ar fi recuperat Insula Serpilor, tezauru\' de la rusi si tot Cadrilateru\' (oare cum e corect: <strong>Cadrilateru</strong>, sau <strong>CadrilateruL</strong>?), baÅŸca Transnistria la oferta speciala  cu tot cu Armata aia sovietica cazata la Tiraspol! Ca sa nu mai zic ca am fi anexat Ungaria inca din \'45.\r\n\r\nPunctul culminant al unei inmomantari in Oltenia e doua: cand se pleaca din prispa mortului, vine o baba la tine si iti zice \"Prinde de nasalie, si trage de trei ori de ea, si spune <em>Eu trag de \'mata, da \'mata sa nu tragi de mine! - </em>de trei ori, puiule, de trei ori!\" (si ar fi bine sa o asculti, ca nu e de joaca cu strigoiu!); si al doilea punct culminant, sau a doua virgula culminanta e cand TOT SATU\', DA\' TAT! IN BISERICA, PUPA MANA MORTULUI. Aia galbina, tzapana, cu vinisoare vinetii si unghii deja crescute peste masura (la faza asta ii multumesc lu taica-meu mai mult decat pentru bataia aia pe care trebuia sa o iau intr-a 3-a ca am loat un 4 la matematica ca am copiat, si n-am mai loat-o: Ilie m-o prins de o areapÄƒ si m-o tÃ¢rÃ¢t afara sa-mi zica nush ce, si pana m-am intors si io la pupat astia deja bateau cuiele).\r\n\r\nDupa aia - se lasa cu chef si palinca d-aia moale, olteneascÄƒ, si cu un vin care creeazÄƒ dependenÅ£Äƒ, de mai mare dragu\' sÄƒ meri la inmormantari.\r\n\r\nPS: Postarea asta am scris-o finca az, marti, 24.03.2007, o murit nevasta lu varu-meu, aia de la Craiova. S-o ierte DumnezÄƒu!','Moartea la olteni',0,'','publish','open','open','','moartea-la-olteni','','','2007-04-25 00:16:55','2007-04-24 22:16:55','',0,'http://www.groparu.ro/?p=343',0,'post','',6),(142,1,'2007-03-14 15:44:09','2007-03-14 13:44:09','','uncle-sam.jpg',0,'','inherit','open','open','','uncle-samjpg','','','2007-03-14 15:44:09','2007-03-14 13:44:09','',125,'http://www.groparu.ro/wp-content/uploads/2007/03/uncle-sam.jpg',0,'post','image/jpeg',0),(133,1,'2007-03-13 01:11:44','2007-03-12 23:11:44','<a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/porc.jpg\" title=\"porc.jpg\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/porc.jpg\" alt=\"porc.jpg\" /></a>\r\n\r\nZice stirea <a href=\"http://www.smh.com.au/news/unusual-tales/this-little-piggys-just-weird/2007/03/07/1173166769353.html\">asta</a> ca undeva prin lume s-a nascut un porcusor cu un singur cap, cum e si normal,  dar si cu doua rÃ¢turi si cu trei ochi.\r\n\r\nVax albina! Mare fÃ¢s.\r\n\r\nIn patria mea, porcii de politicieni se nasc de multa vreme cu tot felul de anomalii genetice. De exemplu, unii dintre ei se nasc cu limba bifurcata, ca de sarpe. Spun una, si fac alta. Cei care nu au ajuns inca politicieni au o limba speciala, pliata pe buze care pupa in fund pe cei care sunt deja sefi de cocina.\r\n\r\nAltii, desi se nasc porci 100%, nu au deloc creier. Si asta se vede de la o posta: guita agramat, strident, ofera gratis case sinistratilor, curent in Ferentari si sponsorizari intr-un mod cat mai vizibil, sau chiar construiesc biserici. Conduc campionate de fotbal, sunt invitati la talk-show-uri si lumea rade cand ii aude cum guita, dar tot se uita. Dar porcii acestia nu guita tot timpul: cand sunt investigati penal, toti tac... ca porcii in cucuruz. Si cand ies in public, pastreaza asa, o oarecare rezerva, o distinctie pseud0-aristocrata, ca doara n-au pascut porcii impreuna cu pulimea!\r\n\r\nCei mai importanti porci de politicieni din Romania nu respecta normele sanitare elementare de transhumanta: circula in jeep-uri, in masini cu girofar, si sunt inconjurati de catei in costume negre care ii apara.\r\n\r\nDe asemenea, unii dorm in Parlament si mana porcii la jir in plina sedinta.\r\n\r\nAltii nu sunt 100% porci; vorbesc de porcii de caine si de porcii spinosi. Primii schimba partidele in functie de cine se ofera sa le aduca laturile. Porcii spinosi sunt cei care trag tepe. Dacia Felix, Cornu, Bancorex, BIR, Columna, Credit Bank, Bankcoop, FNI. Am uitat ceva?\r\n\r\nCand vin alegerile, porcii de politicieni incearca sa ingrase porcul in ajun; unora le iese. Cand ii pui unii langa altii, se fac troaca de porci reciproc. Imediat, jumatatea ne-pensionara din tara asta se gandeste cu drag la Canada.\r\n\r\nIar noi, astialalti, asteptam cu nerabdare Ignatul, dar nu unul dupa norme UE, cu anestezie totala inainte de taiere, ci unul traditional, cu porcul care sa se streseze inainte de sacrificare. Cu belit de porc, si mare veselie.','Pentru mine tot un porc ramaneti, domnule politician',0,'','publish','open','open','','pentru-mine-tot-un-porc-ramaneti-domnule-politician','','','2007-03-14 15:29:11','2007-03-14 13:29:11','',0,'http://www.groparu.ro/?p=133',0,'post','',0),(134,1,'2007-03-13 01:14:22','2007-03-12 23:14:22','\r\n<p class=\"content-wrapper\"><a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/ele.jpg\" title=\"ele.jpg\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/ele.jpg\" alt=\"ele.jpg\" /></a></p>\r\n\r\n<p class=\"content-wrapper\"><span>Omul </span><a href=\"http://www.thesun.co.uk/article/0,,2001320029-2007110053,00.html\"><span>asta</span></a><span> de stiinta a avut un ghinion extraordinar. Citise prea mult poezia \"Noi\" de Nichita Stanescu (care incepe cu \"Noi suntem seminte si pamantul e al nostru\"); si incercand sa provoace o erectie unui elefant in captivitate, pentru a-i pune in captivitate samantza, pentru a fecunda cu ea o femela din captivitate pentru ca aceasta sa nasca alti elefantei in captivitate, a fost lovit in fata de strumeleagul invartosat - cum ar fi spus Stefan cel Mare â€“ al blandului gigant, si s-a ales cu un ochi vanat.\r\n\r\nMotivul? un madular de pachidern masoara un metru si jumatate, si cand sta infoiat se balangane in fata si in spate intr-o miscare necontrolata, atata de puternica incat poate darama pana si un om de stiinta german.\r\n\r\nElefantul avea toate motivele sa ingreuneze nasterea unui mostenitor. Nu avea de unde sa stie ca nu va fi trimis la o gradina zoologica din RO ca proaspat tatic. Pentru ca daca ajunge aici, mama elefantica ar fi primit numai 600 RON ca pensie de concediu maternal - dupa cum permite dl. Gheorghe Barbu, ministrul Muncii si al Solidaritatii Sociale. Mai mult, puiul elefantel ar fi gasit cu greu un loc la gradinita, si doar cu spaga un loc intr-o scoala decenta. Si ar fi fost invatzat de alti colegi elefantei sa fumeze din frageda pruncie si sa scuipe coji de seminte pe jos si sa tina cu Rapiduâ€™. Si sa chiuleasca, si sa dea cu tifla profesorului ca nu are telefon cu clapeta, ca el.\r\n\r\nOricum, omul de stiinta expert in fornicare pachidermica ar trebui sa fie recunoscator pana la moarte ca dinozaurii si dinozauritele nu mai traiesc.</span>','Cazi din elefant in putz',0,'','publish','open','open','','cazi-din-elefant-in-putz','','','2007-03-13 01:14:22','2007-03-12 23:14:22','',0,'http://www.groparu.ro/?p=134',0,'post','',0),(135,1,'2007-03-13 01:14:03','2007-03-12 23:14:03','','ele.jpg',0,'','inherit','open','open','','elejpg','','','2007-03-13 01:14:03','2007-03-12 23:14:03','',-1173741105,'http://www.groparu.ro/wp-content/uploads/2007/03/ele.jpg',0,'post','image/jpeg',0),(136,1,'2007-03-13 01:14:50','2007-03-12 23:14:50','Ce companie romaneasca NU investeste in Romania mai mult decat produce, si nu e Petrom? Si de ce nu se ocupa Petrom de pet-uri???\r\n\r\nUPC rimeaza cu UTC, pentru ca netu\' se pune ca pe vremea comunismului.\r\n\r\nIn primu rand, nici un provider de net din zona mea (locul unde s-a nascut vesnicia: Manastur) nu ofera net cat de cat de calitate, cu instalare rapida (nu \"inainte de urmatoarea glaciatiune ajungem si in zona dumneavoastra!\") si la pret rezonabil.\r\n\r\nPentru erdeesh trebia sa am rabdare inca o luna. Si la fel mi-au zis si acum o luna cand am mers la ei.\r\n\r\nRomTelecom - ha! vo 6-70 ROn/luna, la paket cu telefonie. Instalare? Maxim 2-3 luni. Da\' va dam Dolce cu AcasaTV sj Dogan, televiziunea cu nume de biscuiti.\r\n\r\nRetele de car-tier? Nu, ca vin de dupa blocurile gri. Si nu am kef de copilushi cu veleitati de AOL. Nacar sa fiu la keremu unora care se stiu mai bine la retele decat eu la engleza - ceea ce nici macar nu e chiar asa de greu.\r\n\r\nDeci: UPC in sus, UPC in jos, ce nu or reusit sa ma convinga prekinii m-or convins o pereche de sÃ¢ni semi-dezveliti, care se bombau cÄƒtre mine dinspre tanti aia de la caseria UPC, o pushtoaica slabaaaaaaa, slaba, da\' in pieptu-i de arama cu doo rotocoale si rotundeeee, si bombateeee! Un fel de Nicoleta Luciu care lucra la UPC, da\' numa ca nu avea nici pe departe balizele lu\' tanti Merluciu, fatza nici pe-atat, sh la personalitate n-avea cum. Da\' - chestie la care ma uitam mai holbat ca atunci cand te uiti la musca aia desenata pe pisoar, expre\' pusa acolo ca sa tintesti cu jetu de pipi inauntru vasului, sa nu dai pe jos si sa faci strat din ala de galbenoshenie pe jos prin pardoseala budei clubului, de ti-i si scarba sa-ti ridici telefonu\', daca iti pica din greseala pe gresia aia luata cu 29 RON din Praktiker, mai ales ca dupa aia cu aceeasi mana o ajuti pe gajica aia de danseaza pe bar sa se scoboare de pe tejghia - deci, dupa cum spuneam, intre tzatzele alea cat un caputz de nou-nascut, da\' mult mai frumoase finca nu plang, ci rad la soare ca copilu\' cu paru\' balai, nush cum se facuse de se pricopsise domnisoara aia de la vanzari cu o cicatrice. De-ti si venea sa pui mana pe cicatrice, ca pe cocoasa, sa ai noroc! Da io am fentat-o, ca daca s-o gandit vreodata ca m-am uitat la tzitzili mitzili, apai sa afle ca de fapt cicatricea ma magnetiza. Ca sani are oricine. Pana si Oana. Zavoranu.\r\n\r\nIn fine, dupa ce am pus-o sa jure regulamentar cu mana pe piept(i) ca or sa vie upecishtii joi, in 2 rate succesive una dupa alta (prima pt cablu, a doa pentru net) intre 6 fix si 9 fix, m-am tirat, si am reusit sa intarzii joi, la6. Ca era 8 martie. Si am ajuns acasa pe la 6 si 20.\r\n\r\nSurpriza, de mi-era sa cad de la etaju\' 4, ca femeile alea bogate si proaste din filmele de groaza din anii \'50 care mor de la stafii: upeceii nu numa ca ajunsesera inaintea mea, da\' si instalasera pana sa ajung eu acolo, si si plecasera! Si lasasera si bilet in usa. Ceva ca in reclama cu VW Golf, ca welcome to the UPC family, happy marriage - no divorce, sau ceva de genu\'.\r\n\r\nNo - finca upeceii nu avusesera cheia de la garso\', nu putusera sa traga cablaraia pana in camera. Asa ca aveam TV prin cablu, da numa pan\' la usa, si netu\' nu era internetizat, ca era pe aceeasi tzava. Cum am rezolvat cu oamenii sa vie sa ma implementeze la autostrada informationala - veti afla in episodul urmator.\r\n\r\n\r\nTraducere: Sanda TARANU. Consultant stintific: Razvan Theodorescu aka Cap-de-Cauciuc.','U-PCR',0,'','publish','open','open','','u-pcr','','','2007-03-13 01:14:50','2007-03-12 23:14:50','',0,'http://www.groparu.ro/?p=136',0,'post','',0),(144,1,'2007-03-14 15:53:57','2007-03-14 13:53:57','','kitty-bebe.jpg',0,'','inherit','open','open','','kitty-bebejpg','','','2007-03-14 15:53:57','2007-03-14 13:53:57','',110,'http://www.groparu.ro/wp-content/uploads/2007/03/kitty-bebe.jpg',0,'post','image/jpeg',0),(138,1,'2007-03-14 01:07:54','2007-03-13 23:07:54','','bedroommainfloor.JPG',0,'','inherit','open','open','','bedroommainfloorjpg','','','2007-03-14 01:07:54','2007-03-13 23:07:54','',139,'http://www.groparu.ro/wp-content/uploads/2007/03/bedroommainfloor.JPG',0,'post','image/jpeg',0),(139,1,'2007-03-14 01:08:12','2007-03-13 23:08:12','<a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/bedroommainfloor.JPG\" title=\"bedroommainfloor.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/bedroommainfloor.JPG\" alt=\"bedroommainfloor.JPG\" /></a>\r\n\r\nCica parlamentarii nostri, vazand ce curvasaraie e in politica, vor sa-si legifereze prostitutia.\r\n\r\nDati-mi voie sa <img src=\"http://us.i1.yimg.com/us.yimg.com/i/mesg/emoticons7/77.gif\" />. Mi se confirma o teorie mai veche.\r\n\r\nMi se confirma inca o data ca Parlamentul Romaniei e un bordel de idei putrede iscate de o mana de <span class=\"def\">pÃ¢rÅ£oline. </span>Ca <span class=\"def\">tÃ¢rnoaÅ£ele astea</span> se prefac ca le place cand ne fut - ca la un bordel cu <span class=\"def\">magopaÅ£e </span>profesioniste. Ca in Parlament gandirea unora seamana cu niste nonagenari care merg la tractir si nu le reuseste nici macar semi-erectia. Si ca desi fornicarea nu are finalitate, tot ni se iau banii.\r\n\r\nMi se confirma ca ierarhia asta a shuleandrelor, terfeloagelor, pupezelor si madarantzelor noastre politice e structurata pe codosi. <span class=\"def\">Ca telÄƒliÅ£ele, lelele, scorÅ£otinele f</span>ac front comun in jurul unui proxenet cu nume de rezonanta, cu vechi state in politica. Ca <span class=\"def\">miÅŸarcele si </span><span class=\"def\">tÄƒlaniÅ£ele </span><span class=\"def\">nu fac rau fleorÅ£otinelor, buleadrelor, tÃ¢rÃ¢turilor din alte partide.  Si ca  haitele, gudele, maimuÅ£ele si </span>fleoartzele schimba bordelul politic fara nici un fel de procese de constiinta. Si, pentru ca <span class=\"def\">bandurele, bulele, landrele </span>nu isi pot pune oglinda pe tavan, cheama presa sa se filmeze in desfasurarea actului sexual.\r\n\r\n<span class=\"def\"></span>Asteptam inchiderea <span class=\"def\">mastroacelor politice rasuflate </span>intr-un sanatoriu de <span class=\"def\">teleleice pensionate</span>. Si sa nu isi impoziteze colegele de meserie. Si sa aprinda luminii rosii la geamurile Parlamentului - care va deveni cea mai mare garsoniera de toleranta confort III din lume.','C\'est le bordel',0,'','publish','open','open','','cest-le-bordel','','','2007-03-14 01:08:12','2007-03-13 23:08:12','',0,'http://www.groparu.ro/?p=139',0,'post','',0),(143,1,'2007-03-14 15:47:48','2007-03-14 13:47:48','','eskimo.JPG',0,'','inherit','open','open','','eskimojpg','','','2007-03-14 15:47:48','2007-03-14 13:47:48','',120,'http://www.groparu.ro/wp-content/uploads/2007/03/eskimo.JPG',0,'post','image/jpeg',0),(146,1,'2007-03-16 02:01:27','2007-03-16 00:01:27','','http://en.wikipedia.org/wiki/Shepherd',0,'','inherit','open','open','','httpenwikipediaorgwikishepherd','','','2007-03-16 02:01:27','2007-03-16 00:01:27','',-1174001750,'http://www.groparu.ro/wp-content/uploads/2007/03/800px-rumunia_5806_resize.jpg',0,'post','image/jpeg',0),(147,1,'2007-03-18 22:27:40','2007-03-18 20:27:40','Â <a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/9177.jpg\" title=\"9177.jpg\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/9177.jpg\" alt=\"9177.jpg\" /></a>\r\n\r\n11 motive pentru care as vrea mai degraba sa fiu caine comunitar occidental decat intelectual roman, inspirate de siteul RSPCA:\r\n\r\n1. Animalele occidentale au dreptul la asistenta medicala de nota 10 fara spaga. Romanii sunt fericiti sa dea spaga pentru asistentza medicala de nota minus zero.\r\n\r\n2. Animalele occidentale nu trebuie chinuite cand apar in filme sau poze. Romanii trebuie sa zambeasca foarte frumos si chinuitor in fata camerei cand este ziua sefului.\r\n\r\n3. Animalele occidentale nu trebuie expuse in situatii care pot parea ridicole sau injositoare. In schimb, romanii se auto-umilesc la stirile de la ora 5, Dan Negru show si la Dan Diaconescu in direct.\r\n\r\n4. Animalele occidentale mananca mancare speciala, echilibrata, in pungi care arata frumos, nu ca studentii care mananca la cantine studentesti. O stiti pe aia cu cantinele studentesti? \"Studentul oferi cersetorului un tichet de masa la cantina din Hasdeu. Cersetorul refuza cu demnitate\".\r\n\r\n5. Unele animale sunt sterilizate. Unii romani nu, desi ar trebui. Propun sa incepem cu cei care stau pe banchetele masinilor cu girofar, cu numar cu -GUV.\r\n\r\n6. Animalele de la gradina zoologica trebuie cazate in conditii care seamana cu cele naturale. Eu as vrea sa-l intalnesc pe stramosul meu de Neanderthal care locuia intr-un bloc in Manastur, sa-i zic vreo doua.\r\n\r\n7. Aproape nici un animal nu isi cunoaste soacra. Aproape toti romanii ar vrea ca soacra sa nu-i mai recunoasca.\r\n\r\n8. Animalele pot migra unde vor. Romanii, pana sa fie primiti in haita europeana, NU. Si uneori am impresia ca au plecat toti cainii de rasa, si au ramas numai corciturile. Alea ca mine.\r\n\r\n9. Animalelor din ferme trebuie sa li se asigure un spatiu adecvat. Romanilor care se inghesuie in autobuzele RATUC ca paiele intr-o matura, NU.\r\n\r\n10. Animalele nu pun alte animale sa asculte manele.\r\n\r\n11. Cainii periculosi poarta botnita. Politicienii periculosi pun botnita procurorilor periculosi.','Animal occidental sau romÃ¢n intelectual?',0,'','publish','open','open','','animal-occidental-sau-roman-intelectual','','','2007-03-18 22:27:40','2007-03-18 20:27:40','',0,'http://www.groparu.ro/?p=147',0,'post','',3),(148,1,'2007-03-18 22:26:30','2007-03-18 20:26:30','','9177.jpg',0,'','inherit','open','open','','9177jpg','','','2007-03-18 22:26:30','2007-03-18 20:26:30','',-1174249411,'http://www.groparu.ro/wp-content/uploads/2007/03/9177.jpg',0,'post','image/jpeg',0),(149,1,'2007-03-18 23:49:19','2007-03-18 21:49:19','\r\n<p align=\"center\"><a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/tanti-de-pe-tir.jpg\" title=\"tanti-de-pe-tir.jpg\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/tanti-de-pe-tir.jpg\" alt=\"tanti-de-pe-tir.jpg\" /></a></p>\r\n<p align=\"right\">Â Â Â  Â Â Â  Â Â Â  Â Â Â  Â Â Â  Â Â Â  Â Â Â  Â Â Â  Â Â Â  Â Â Â  Â Â Â  Â Â Â  Â Â Â  Â Â Â  Â Â Â  Â Â Â  Motto: <em>\"Tu rÃ¢zi singur la propriile tale bancuri?\" \"Normal, sunt singurul care le-nÅ£elege!!!\"</em></p>\r\n<p align=\"left\">&nbsp;</p>\r\n\r\n<p align=\"left\">1.1 Preludiu: Ai o prietena din copilarie la care tii. Mult. Prietena ta din copilarie s-a ingrasat. Mai mult chiar decat tii tu la ea. A devenit o balena ucigasa, o <span style=\"font-style: italic\">vache qui rit</span>, o Casa Poporului, un mini-tanc rusesc, un avion <a href=\"http://en.wikipedia.org/wiki/C-130_Hercules\" target=\"_blank\">Hercules</a>, o sala de conferintze, o megaboxa de concert Rolling Stones, o radiografie a spagii din Romania, o centrala de termoficare, opt butoaie cu iaurt, o padure amazoniana, asteroidul din <a href=\"http://imdb.com/title/tt0120591/\" target=\"_blank\">Armageddon</a>, patru flote de submarine nucleare care vor sa bombardeze Iranul, o moara de vÃ¢nturi, afumaturia de la fabrica de mezeluri din Salonta, o herghelie de <a href=\"http://en.wikipedia.org/wiki/Iguanodon\" target=\"_blank\">iguanodoni</a>, <span style=\"text-decoration: underline\"></span>cat o pupatura de la bunica si cat de mult ti-ai iubi tu tzara, daca tzara ta ar fi curata ca Irlanda si plina de chinezoaice mici si sexy si lesbiene si gospodine si dragastoase si dornice de a incerca lucruri noi cu tine, stapanul lor alb.\r\n\r\n1.2 Copulatie: Te intreaba \"Nu ti se pare ca m-am ingrasat?\"\r\n\r\n1.3 Penis Captivus: Tu tii post cu sfintenie. In post nu ai voie sa minti. Ce ii raspunzi?\r\n\r\n2.1. Preludiu: Stai la ocazie. E seara tarziu, e toamna si e frig si tu esti in tricou, la 300 km de casa, nu stii pe nimeni in orasul de unde faci ocazia, nu ai nici bani mai multi decat deloc si telefonul ti s-a descarcat. I se face mila de tine unui sofer de tir care te ia cu el. Ca sa-i faci pe plac, incerci sa-l distrezi; asa ca incepeti o discutie in care te lauzi cat de cocos esti tu, cate gajici ai avut in viata ta, si iti faci si un titlu de glorie laudandu-te ca nu ai iertat nimic, oricat ar fi fost ea de stirba, ciunga, oloaga, pensionara, schioapa, cocosata, larga sau stramta, minora sau bunica prietenei tale - ba ca te-ai si dedat la carnitza de vanzare de pe Calea Turzii. Pe drum, nenea mega-amuzat mai opreste si mai ia la ocazie o tanti care ar putea sa-ti fie tie mama, dar e stirba, schioapa, cocosata, ciunga, oloaga. Si nu se prea omoara dupa interactiuni intime cu apa. Si se si scarpina cu furie printre buci.\r\n\r\n<p align=\"left\">2.2 Copulatie: Soferul iti ordona sa te joci cu domnisoara de-a animalul cu doua spinari chiar acolo, in spatele lui, ca doara asa te-ai laudat, ca tu faci asta non-stop. Si daca nu il asculti te da afara din TIR intr-un camp unde e intuneric ca in chilotii unei negrese si masinile merg cu 120km/h si tu nu ai pix sa iti faci un carton cu destinatia.\r\n\r\n2.3 Penis Captivus: Esti virgin si iti si iubesti prietena si ai si principii morale din cauza carora nu vei intra niciodata in politica, desi nenea iti ofera prezervative cu generozitate. Cum te scoti?\r\n\r\n3.1 Preludiu: Ai 200 vizitatori pe zi care sunt convinsi ca blogul asta e 100% despre tine si despre ce ai patit tu.\r\n\r\n3.2 Copulatie: Poate ca nici una din situatiile de mai sus nu ti s-au intamplat, dar colegii si cunoscutii se uita la tine de parca asa a si fost.\r\n\r\n3.3 Penis Captivus: E vreo sansa sa le explici ca punctul 1 nu se refera la nici una din prietenele si amicele tale? (desi ele se simt dintr-o data subiectul tau de blog si se uita toate la tine cÃ¢ÅŸ si isi verifica cercurile de sub burta)\r\n<p align=\"left\">Poti spera ca prietenii si cunoscutii tai isi vor da seama caÂ  punctul 2 nu ti s-a intamplat niciodata, nici macar in imaginatie? (deÅŸi se uitÄƒ la tine ca grecii la Platon, filosoful revelat, pentru ca ai avut o intalnire de gradul 0 cu o intelectuala din industria sexului)</p>','Trei situatii fara scapare',0,'','publish','open','open','','trei-situatii-fara-scapare','','','2007-03-18 23:49:19','2007-03-18 21:49:19','',0,'http://www.groparu.ro/?p=149',0,'post','',0),(150,1,'2007-03-18 23:48:50','2007-03-18 21:48:50','','tanti-de-pe-tir.jpg',0,'','inherit','open','open','','tanti-de-pe-tirjpg','','','2007-03-18 23:48:50','2007-03-18 21:48:50','',-1174251250,'http://www.groparu.ro/wp-content/uploads/2007/03/tanti-de-pe-tir.jpg',0,'post','image/jpeg',0),(151,1,'2007-03-19 20:32:51','2007-03-19 18:32:51','<a href=\"http://www.princeofwales.gov.uk/personalprofiles/princeharry/\" target=\"_blank\" title=\"princeharry.jpg\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/princeharry.jpg\" alt=\"princeharry.jpg\" /></a>\r\n\r\nNu stiu daca din cauza ca <a href=\"http://www.lambic.co.uk/blog/archives/2005/10/prince-kook/\" target=\"_blank\">taicÄƒ-su</a> e cu mult mai urÃ¢t decat mine (si asta e un record european). Nu stiu daca din cauzÄƒ cÄƒ <a href=\"http://en.wikipedia.org/wiki/Camilla,_Duchess_of_Cornwall\" target=\"_blank\">mÄƒ-sa vitregÄƒ</a> e chiar mai urÃ¢tÄƒ ca ta-su, ÅŸi mai are si nume de camila. Nu stiu daca din cauza ca maica-sa bunÄƒ - aia cu nume de DianÄƒ - se tÄƒvÄƒlea cu un musulman, de-l chema Dodi Al FuckÃ¨d, de-o si murit din cauza asta, sau nu. Ce stiu e ca printul William al Albionului <a href=\"http://www.pr-inside.com/prince-harry-s-big-send-off-r69107.htm\" title=\"cel mai William print din Anglia\" target=\"_blank\">s-a hotarat sa plece in Irak</a> pentru a lupta alaturi de trupele coalitiei anti-Sadam, pro-petrol, si alaturi si de Ionicii si Vasilicii care slujesc patria mea prin deserturile irakiene.\r\n\r\nOricat de putin i-am iubi pe englezi din cauzÄƒ cÄƒ se bat ca chiorii pe stadioane, vand cola cu 9 lire butelia a\' micÄƒ si au ÅŸi cele mai respingÄƒtoare ÅŸi vulgare femei din toata insula (Ã®n afara numa daca nu sunt romÃ¢nce imigrante*), la faza asta trebuie sa recunosc cÄƒ ne-au dat clasa. Cu faza asta, si in multe altele. Dar cu asta - cel mai recent.\r\n\r\nAsta fiindca eu nu stiu nici un prunc de parlamentar care sa slujeasca sub arme in cel mai fierbinte loc de pe glob - si nu vorbesc de solarii. Nici macar vreun copil de Å¢iriac care sÄƒ lase prafurile albe de pe burta vreunei Tantze pentru prafurile galbui ale deÅŸertului. Åžtiu numa ditai guvernantu\' pe care  daca il doare degetu\' mic de la piciorush o zbugheste prin alde strainÄƒtÄƒÅ£uri (care nu Ã®s deloc mai amare ca moartea). Radu Vasile (stiti voi, nenea ala cu ghiul supt nas, si musteatza pe geget - sau invers) cÃ¢nd nu l-a mai lasat inima (sa fure, probabil) a uÅŸchit-o in Israel. Ca in Romania nu se putea cauta la doftori. Cand Basescu se rÄƒÅ£oise atÃ¢ta de tare la premier de i se stricase hernia Ã®n el, a zburat cu prima cursÄƒ comunalÄƒ fix Ã®n Austria. Åži TÄƒricicÄƒ, dupa ce si-a bagat picioarele intr-un acident de circulaÅ£ie, s-a ascuns aÅ£Äƒ Ã®n FranÅ£a - care il aÅŸtepta cu braÅ£ele foarte deschise Ã®ntr-o clinicÄƒ cu circuit foarte Ã®nchis.\r\n\r\nCred totuÅŸi ca cele trei cazuri ale romÃ¢nasilor si cel al micului englezuÅ£ au ceva Ã®n comun. PrinÅ£iÅŸorul probabil cÄƒ nu a avut suficient de mulÅ£i bani pentu a da ÅŸpagÄƒ Ã®ntr-un sistem aproap perfect ca sÄƒ scape de Ã®ncorporare. CÃ¢t despre cei trei drÄƒgÄƒlaÅŸi, cred cÄƒ sumele care se cer ca ÅŸpagÄƒ prin spitalele romÃ¢neÅŸti sunt prea mari pÃ¢nÄƒ ÅŸi pentru ei.\r\n\r\n*Apropos de englezoaice urÃ¢te ÅŸi vulgare: eram odatÄƒ cu un englezoi tare cumsecade prin te miri ce bodegÄƒ fecalÄƒ ÅŸi ne uitam la cururile care se zbÃ¢nÅ£uiau prin raza noastrÄƒ vizuala, foarte beatÄƒ la ora aia. Åži Ã®i zic lu\' Äƒsta \"One day I\'m going to fuck a  really vulgar woman!\" Si el Ã®mi zice: \"You should come to Britain!\"<img src=\"http://us.i1.yimg.com/us.yimg.com/i/mesg/emoticons7/22.gif\" />','Micul Print si micul rezbel',0,'','publish','open','open','','micul-print','','\nhttp://www.lambic.co.uk/blog/archives/2005/10/prince-kook/','2007-03-19 23:16:02','2007-03-19 21:16:02','',0,'http://www.groparu.ro/?p=151',0,'post','',2),(152,1,'2007-03-19 20:32:15','2007-03-19 18:32:15','','princeharry.jpg',0,'','inherit','open','open','','princeharryjpg','','','2007-03-19 20:32:15','2007-03-19 18:32:15','',-1174327416,'http://www.groparu.ro/wp-content/uploads/2007/03/princeharry.jpg',0,'post','image/jpeg',0),(153,1,'2007-03-20 22:45:47','2007-03-20 20:45:47','Cred cÄƒ nu imi pot imagina o meserie mai nirvanicÄƒ decÃ¢t gardian la o Ã®nchisoare de femei din alea prin care aleargÄƒ hormonii ca prin hipodrom. DeÅŸi nenea <a href=\"http://www.miamiherald.com/459/story/46556.html\" target=\"_blank\">Äƒsta</a> nu cred ca e de acord: gardian la o pÃ¢rnaie de femei, omul fusÄƒ ispitit de o deÅ£inutÄƒ din aia ne-lesbianÄƒ care nu mai avusese barbat de prin 2001, de cÃ¢nd eram eu student, mult mai sÄƒrac ÅŸi mult mai fericit decÃ¢t acum. Si el - suflet slab, amarul lui! -  s-a gÃ¢ndit sÄƒ ii facÄƒ un bine domnisoarei. Exact ce m-aÅŸ fi gÃ¢ndit ÅŸi eu, ÅŸi Bill Clinton, si - sper - toÅ£i ceilalÅ£i 3 miliarde de purtatori de puÅ£ulicÄƒ din lumea asta care se tot Ã®ncÄƒlzeÅŸte, fir-ar el efectu\' de serÄƒ azi ÅŸi mÃ¢ine!\r\n\r\nCum au ajuns cei doi sÄƒ isi exploreze de comun acord partile anatomo-morfologice care ne diferentiazÄƒ, la urma urmei, de rÃ¢me, care nu au nici un fel de sex ÅŸi sunt ÅŸi asexuate pe deasupra? Cum de cele douÄƒ organe Ã®nmulÅ£itoare, cu miros distinct Ã®nainte dar cu miros specific ÅŸi unic de peÅŸte mai apoi au ajuns sa facÄƒ schimb de pÄƒr cÃ¢rlionÅ£at? Simplu: tanti, dupÄƒ modelul unei strÄƒbunici de-a ei de pe Venus care vroia neaparat sa pape salatÄƒ de fructe cu mere interzise, nu a precupeÅ£it nici un efort regulÃ¢ndu-l pe nenea Äƒsta Adam la cap sÄƒ se joace de-a cÄƒlÄƒritea. Åži asta timp de o lunÄƒ Ã®ntreagÄƒ, zilnic. VÄƒ daÅ£i seama ce autocontrol de invidiat avea gardianu\'? Eu unu\' ÅŸtiu cel putin 600 de masculi care ar fi cedat dupa primele 3 minute. Oricum, dupÄƒ o lunÄƒ de aluzii indirecte gen \"MÄƒ, mÄƒ fuÅ£i odatÄƒ?\" pÃ¢nÄƒ ÅŸi el a cedat, mai ales cÄƒ tanti nu Ã®l bÄƒtea la cap sa ducÄƒ gunoiul, sÄƒ repare uÅŸa sau <a href=\"http://www.groparu.ro/?p=145\" target=\"_blank\">sÄƒ cureÅ£e usturoi pentru chiftele</a>. AÅŸa cÄƒ s-a hotÄƒrÃ¢t sÄƒ o incalece pe femeia-mustang, fÄƒrÄƒ sÄƒ se mai oboseascÄƒ sÄƒ o scoatÄƒ la o cafea la cofetÄƒria din localitate.\r\n\r\nCe ne dezbinÄƒ pe noi, ca rasÄƒ, Ã®nsÄƒ, este gelozia ÅŸi invidia. CÄƒci cÃ¢nd ÅŸÄƒfii bravului astupÄƒtor de gÄƒuri, curajosului potolitor de sete trupeascÄƒ ÅŸi astÃ¢mpÄƒrÄƒtor de nesaÅ£uri telurice au aflat de schimbul de mirosuri ÅŸi fluide dintre el ÅŸi domniÅŸoara captivÄƒ Ã®n turn, au luat mÄƒsuri, l-au dezonorat, mi Å£i l-au investigat pe la apus de soare ÅŸi amu vor sÄƒ Ã®l pedepseascÄƒ pentru abuz de putere asupra unei deÅ£inute. AÅŸa cÄƒ acum oscilez: sÄƒ schimb la CV-ul meu partea cu \"scopul carierei\", sÄƒ scriu acolo cÄƒ vreau sÄƒ mÄƒ fac gardian de femei inchise, sau sÄƒ rÄƒmÃ¢nÄƒ Äƒsta aÅŸa, un vis secret de-al meu, de care sÄƒ nu afle nimeni?','Cum se manipuleaza un gardian pudic',0,'','publish','open','open','','cum-se-manipuleaza-un-gardian-pudic','','\nhttp://www.groparu.ro/?p=145','2007-03-21 02:37:13','2007-03-21 00:37:13','',0,'http://www.groparu.ro/?p=153',0,'post','',2),(154,1,'2007-03-21 12:07:36','2007-03-21 10:07:36','\r\n<p class=\"MsoNormal\"><font face=\"Arial\" size=\"2\"><span style=\"font-size: 10pt; font-family: Arial\" lang=\"IT\">Sa te scalzi in  sanatate,</span></font></p>\r\n<p class=\"MsoNormal\"><font face=\"Arial\" size=\"2\"><span style=\"font-size: 10pt; font-family: Arial\" lang=\"IT\">Sa ai cele mai mici  rate,<o:p></o:p></span></font></p>\r\n<p class=\"MsoNormal\"><font face=\"Arial\" size=\"2\"><span style=\"font-size: 10pt; font-family: Arial\" lang=\"IT\">Sa-ti prisoseasca  iubirea,<o:p></o:p></span></font></p>\r\n<p class=\"MsoNormal\"><font face=\"Arial\" size=\"2\"><span style=\"font-size: 10pt; font-family: Arial\" lang=\"IT\">Sa nu bei coniac  â€œUnireaâ€,<o:p></o:p></span></font></p>\r\n<p class=\"MsoNormal\"><font face=\"Arial\" size=\"2\"><span style=\"font-size: 10pt; font-family: Arial\" lang=\"IT\">Paste (fainoase) s-ai zilnic la  pranz,<o:p></o:p></span></font></p>\r\n<p class=\"MsoNormal\"><font face=\"Arial\" size=\"2\"><span style=\"font-size: 10pt; font-family: Arial\" lang=\"IT\">Sa fii iute ca un  manz,<o:p></o:p></span></font></p>\r\n<p class=\"MsoNormal\"><font face=\"Arial\" size=\"2\"><span style=\"font-size: 10pt; font-family: Arial\" lang=\"IT\">Bani sa ai pe  saturate,<o:p></o:p></span></font></p>\r\n<p class=\"MsoNormal\"><font face=\"Arial\" size=\"2\"><span style=\"font-size: 10pt; font-family: Arial\" lang=\"IT\">Sa nu bei pe  nemancate,<o:p></o:p></span></font></p>\r\n<p class=\"MsoNormal\"><font face=\"Arial\" size=\"2\"><span style=\"font-size: 10pt; font-family: Arial\" lang=\"IT\">S-ai copii vreo  douazeci,<o:p></o:p></span></font></p>\r\n<p class=\"MsoNormal\"><font face=\"Arial\" size=\"2\"><span style=\"font-size: 10pt; font-family: Arial\" lang=\"IT\">Noptile calde, nu reci,  <o:p></o:p></span></font></p>\r\n<p class=\"MsoNormal\"><font face=\"Arial\" size=\"2\"><span style=\"font-size: 10pt; font-family: Arial\" lang=\"IT\">Sa fii dulce ca o  ceapa,<o:p></o:p></span></font></p>\r\n<p class=\"MsoNormal\"><font face=\"Arial\" size=\"2\"><span style=\"font-size: 10pt; font-family: Arial\" lang=\"IT\">Si curata ca o  apa,<o:p></o:p></span></font></p>\r\n<p class=\"MsoNormal\"><font face=\"Arial\" size=\"2\"><span style=\"font-size: 10pt; font-family: Arial\" lang=\"IT\">Vesela ca  cinteza,<o:p></o:p></span></font></p>\r\n<p class=\"MsoNormal\"><font face=\"Arial\" size=\"2\"><span style=\"font-size: 10pt; font-family: Arial\" lang=\"IT\">Ocosha ca  pupaza,<o:p></o:p></span></font></p>\r\n<p class=\"MsoNormal\"><font face=\"Arial\" size=\"2\"><span style=\"font-size: 10pt; font-family: Arial\" lang=\"IT\">La Multi Ani si penteleu,<o:p></o:p></span></font></p>\r\n<p class=\"MsoNormal\"><font face=\"Arial\" size=\"2\"><span style=\"font-size: 10pt; font-family: Arial\" lang=\"IT\">Sananate, bani  mereu!<o:p></o:p></span></font></p>','De ziua Andreei',0,'','publish','open','open','','de-ziua-andreei','','','2007-03-21 12:07:36','2007-03-21 10:07:36','',0,'http://www.groparu.ro/?p=154',0,'post','',1),(155,1,'2007-03-22 00:25:58','2007-03-21 22:25:58','<a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/cutezatorii_1970_02_05_electronica.jpg\" title=\"cutezatorii_1970_02_05_electronica.jpg\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/cutezatorii_1970_02_05_electronica.jpg\" alt=\"cutezatorii_1970_02_05_electronica.jpg\" /></a>\r\n\r\n<a href=\"http://www.evz.ro/article.php?artid=297410\" target=\"_blank\">Evenimentul Zilei</a> zice (de fapt nu zice, ci scrie; de fapt nu scrie, ci este scris in el; de fapt, e-coieshte, sau e-coiaza - cum se zice cand face ca ecoul? - pur si simplu de la <a href=\"http://www.reuters.com/article/inDepthNews/idUSL1958469720070321\" target=\"_blank\">Reuters</a>) cum ca generatia mea (sau, ma rog, a lor, a voastra) nu este\r\n\r\n- patrioata\r\n\r\n- loiala fata de societate\r\n\r\n<span class=\"artbody\">- interesata de politica </span>\r\n\r\n<span class=\"artbody\">- implicata in societate</span>\r\n\r\nIn schimb, tinde sa fie\r\n\r\n- <span class=\"artbody\">stresata</span>\r\n\r\n<span class=\"artbody\">- individualista </span>\r\n\r\n<span class=\"artbody\"></span>\r\n\r\nMultumesc lui Dumnezeu pentru asta.\r\n\r\nPentru ca <em>pe vremea mea</em> noi eram hiper patrioti si ne exprimam patriotismul plimband pancarte din polistiren expandat cu secera si ciocanul, amenintati cu nota 7 la purtare daca gaseam altceva mai bun de facut de 23 August. Si trebuia sa purtam inel la cravata si numar matricol pe brat. Si bereta aia ridicola cu care nu am aratat niciodata sexy.\r\n<em>Pe vremea mea</em> eram loiali fata de societate aducand la scoala haine si fier vechi si castane (tot timpul trebuia sa le culegem cu fix 2 zile inainte de a incepe sa cada!) si plante medicinale si te miri ce mai trebuia sa aducem.\r\n\r\nSi <em>pe vremea mea</em> eram interesati in politica de fiecare data cand ne gandeam cu drag la conducatorul suprem, si la portocalele de pe masa lui. Si cand votam unicul candidat al unicului partid, caci in ziua aia aveam Stefan cel Mare sau Mihai Viteazu laTV.\r\n\r\nCat despre implicarea in societate, <em>pe vremea mea</em> eram atata de implicati ca de abia ieseam din randul ei, daca stateam la coada la carne si trebuia sa iesim pana afara din rÃ¢nd ca sa nu facem pipi pe colegii de suferintza.\r\n\r\nAzi - da. Suntem mai stresati. La ce sa ne uitam, la Discovery sau la National Geographic? Sa ne abonam la Orange sau Vodafone? La RDS sau la UPC? Nokia, sau Samsung? Puma, sau Adidas? shaorma sau kebap? baietel, sau fetita? Basescu, sau Tariceanu? biliard, sau bowling? club, sau discoteca?  Drept, sau ISE? Leonardo, sau Socrates? Franta, Anglia sau Germania? VW, sau Opel? SMS, sau MMS? Bulgaria, sau Grecia?','Groparu va prezinta vremea. \"Pe vremea lui...\"',0,'','publish','open','open','','groparu-va-prezinta-pe-vremea-mea','','','2007-03-22 00:26:31','2007-03-21 22:26:31','',0,'http://www.groparu.ro/?p=155',0,'post','',1),(156,1,'2007-03-22 00:25:44','2007-03-21 22:25:44','','cutezatorii_1970_02_05_electronica.jpg',0,'','inherit','open','open','','cutezatorii_1970_02_05_electronicajpg','','','2007-03-22 00:25:44','2007-03-21 22:25:44','',-1174513632,'http://www.groparu.ro/wp-content/uploads/2007/03/cutezatorii_1970_02_05_electronica.jpg',0,'post','image/jpeg',0),(157,1,'2007-03-22 01:50:59','2007-03-21 23:50:59','','dsc02294.JPG',0,'','inherit','open','open','','dsc02294jpg','','','2007-03-22 01:50:59','2007-03-21 23:50:59','',160,'http://www.groparu.ro/wp-content/uploads/2007/03/dsc02294.JPG',0,'post','image/jpeg',0),(158,1,'2007-03-22 01:52:46','2007-03-21 23:52:46','','kfc-albena_1.jpg',0,'','inherit','open','open','','kfc-albena_1jpg','','','2007-03-22 01:52:46','2007-03-21 23:52:46','',160,'http://www.groparu.ro/wp-content/uploads/2007/03/kfc-albena_1.jpg',0,'post','image/jpeg',0),(159,1,'2007-03-22 01:54:09','2007-03-21 23:54:09','','kfc-albena_11.jpg',0,'','inherit','open','open','','kfc-albena_11jpg','','','2007-03-22 01:54:09','2007-03-21 23:54:09','',160,'http://www.groparu.ro/wp-content/uploads/2007/03/kfc-albena_11.jpg',0,'post','image/jpeg',0),(160,1,'2007-03-22 02:04:25','2007-03-22 00:04:25','<a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/kfc-varna_1.jpg\" title=\"kfc-varna_1.jpg\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/kfc-varna_1.jpg\" alt=\"kfc-varna_1.jpg\" /></a>\r\n\r\nPoza facuta in Varna, la KFC. Ghici unde era poza pusa? Fix langa locul de joaca a copkiilor. Exact acolo unde mamicile asteapta cand isi cheama odraslele sa vina, ca e timpul sa plece acasa. Si pana ala micu se mai da pe tobogan \"inca o data, mami!\", privirile lu\' mami aluneca pe manutza lu\' derbedeu\' asta capitalist, care isi tine pulpitza, sau puiutzul, sau cartilagiul foarte sugestiv, si foarte delicat.\r\n\r\nUite aici un close-up:\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/kfc-varna_2.jpg\" title=\"kfc-varna_2.jpg\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/kfc-varna_2.jpg\" alt=\"kfc-varna_2.jpg\" /></a>','Poza subliminala',0,'','publish','open','open','','poza-subliminala','','','2007-03-22 02:04:25','2007-03-22 00:04:25','',0,'http://www.groparu.ro/?p=160',0,'post','',0),(161,1,'2007-03-22 01:56:51','2007-03-21 23:56:51','','kfc-varna_1.jpg',0,'','inherit','open','open','','kfc-varna_1jpg','','','2007-03-22 01:56:51','2007-03-21 23:56:51','',-1174521031,'http://www.groparu.ro/wp-content/uploads/2007/03/kfc-varna_1.jpg',0,'post','image/jpeg',0),(162,1,'2007-03-22 02:03:56','2007-03-22 00:03:56','','kfc-varna_2.jpg',0,'','inherit','open','open','','kfc-varna_2jpg','','','2007-03-22 02:03:56','2007-03-22 00:03:56','',-1174521031,'http://www.groparu.ro/wp-content/uploads/2007/03/kfc-varna_2.jpg',0,'post','image/jpeg',0),(163,1,'2007-03-22 02:10:35','2007-03-22 00:10:35','','calinpopescutariceanu.jpg',0,'','inherit','open','open','','calinpopescutariceanujpg','','','2007-03-22 02:10:35','2007-03-22 00:10:35','',164,'http://www.groparu.ro/wp-content/uploads/2007/03/calinpopescutariceanu.jpg',0,'post','image/jpeg',0),(164,1,'2007-03-22 02:57:11','2007-03-22 00:57:11','<a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/calinpopescutariceanu.jpg\" title=\"calinpopescutariceanu.jpg\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/calinpopescutariceanu.jpg\" alt=\"calinpopescutariceanu.jpg\" /></a>\r\n\r\nDupa cum zicea SfÃ¢ntul Ioan Damaschin despre Tariceanu Cel-de-Sus, si tARICEANU cEL de jOS este totul intru toate si intru nimeni, nimic...!\r\n\r\nDupa hotararea ca nu e nimeni mai bun decat el insusi la cÃ¢rma Ã®nseÅŸi a guvernului Ã®nsuÅŸi, TaricicÄƒ tocma\' ce ÅŸi-o dat seama amu cÄƒ nu e nimeni mai potrivit decÃ¢t Ã®nsuÅŸi eL pentru a fi si insuÅŸi ministru de externe. Nu stim daca TaricicÄƒ vÃ¢neazÄƒ o dublÄƒ leafa, cu dublÄƒ diurnÄƒ ÅŸi porÅ£ie dublÄƒ de papa la bufetul pARLAMENTULUI, sau pur ÅŸi simplu e prima mutare a premierului Ã®n Ã®ncercarea sa de a-ÅŸi extinde autoritatea. Poate oare TÄƒriceanu deveni din clipÄƒ-n clipÄƒ ÅŸi BÄƒsescu (hÄƒÄƒÄƒ, hÄƒÄƒ, hÄƒ!), ÅŸi Vadim ÅŸi ÅŸi Becali? Nush, da\' dacÄƒ are chef, merge la Hollywood ÅŸi Ã®l Ã®nlocuieÅŸte pe Charlie Chaplin. Åži dacÄƒ vrea muzicÄƒ de calitate, poate deveni Celine Dion mintenaÅŸ. Pentru forÅ£Äƒ de muncÄƒ ieftinÄƒ, mÄƒ aÅŸtept din clipÄƒ-n clipÄƒ sÄƒ ia locul poporului chinez; de asemenea, e binevenit sÄƒ prezinte \"Surprize, Surprize!\", sÄƒ se transforme in grÄƒdini zoologice ecologice, in monitor cu plasma ÅŸi globule rosii, Ã®n eticheta vinului de voie bunÄƒ Babanu\', Ã®n Ã®ntÃ¢iul blogger al Å£Äƒrii, Ã®n noul sistem de TV Pal Secam, in taxa ecologicÄƒ pentru electrocasnice, in credit doar cu buletinul - fara avans, Ã®n bila neagrÄƒ a lui Turcescu, in bebelusha aia minorÄƒ de la cÄƒrcotashi, Ã®n Äƒla care Ã®i dÄƒ bipuri noaptea prietenei mele, Ã®n fondatorii Googleâ„¢, Ã®n voievodul muÅŸtelor, Ã®n salvatorul litoralului romÃ¢nesc, Ã®n ÅŸeful meu care mÄƒ ceartÄƒ mereu cÄƒ Ã®ntÃ¢rzii dimineaÅ£a, ÅŸi - de ce nu - Ã®n chiar importatorul Citroen in RomÃ¢nia.\r\n\r\nPÃ¢nÄƒ atunci, Ã®nsÄƒ, m-aÅŸ declara hipermulÅ£umit daca ar deveni, pur ÅŸi simplu, un premier adevÄƒrat, inainte de a lua locul lui Lenin prin vreun mausoleu.','Noul ministru de sex-terne',0,'','publish','open','open','','noul-ministru-de-sex-terne','','','2007-03-22 02:58:59','2007-03-22 00:58:59','',0,'http://www.groparu.ro/?p=164',0,'post','',2),(165,1,'2007-03-22 14:14:45','2007-03-22 12:14:45','','01-tigani-in-parcare.jpg',0,'','inherit','open','open','','01-tigani-in-parcarejpg','','','2007-03-22 14:14:45','2007-03-22 12:14:45','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/01-tigani-in-parcare.jpg',0,'post','image/jpeg',0),(166,1,'2007-03-22 14:15:26','2007-03-22 12:15:26','','02-tigani-in-parcare-ii.jpg',0,'','inherit','open','open','','02-tigani-in-parcare-iijpg','','','2007-03-22 14:15:26','2007-03-22 12:15:26','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/02-tigani-in-parcare-ii.jpg',0,'post','image/jpeg',0),(167,1,'2007-03-22 14:16:26','2007-03-22 12:16:26','','01-tigani-in-parcare.jpg',0,'','inherit','open','open','','01-tigani-in-parcarejpg-2','','','2007-03-22 14:16:26','2007-03-22 12:16:26','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/01-tigani-in-parcare.jpg',0,'post','image/jpeg',0),(168,1,'2007-03-22 14:16:43','2007-03-22 12:16:43','','02-tigani-in-parcare-ii.jpg',0,'','inherit','open','open','','02-tigani-in-parcare-iijpg-2','','','2007-03-22 14:16:43','2007-03-22 12:16:43','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/02-tigani-in-parcare-ii.jpg',0,'post','image/jpeg',0),(169,1,'2007-03-22 14:17:15','2007-03-22 12:17:15','','Tigani, Tiganiada, Tigani, Tiganiada, Tigani, Tiganiada, ',0,'','inherit','open','open','','tigani-tiganiada-tigani-tiganiada-tigani-tiganiada','','','2007-03-22 14:17:15','2007-03-22 12:17:15','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/03-tiganii-si-porcul.jpg',0,'post','image/jpeg',0),(170,1,'2007-03-22 14:18:05','2007-03-22 12:18:05','Tigani, Tiganiada, Tigani, Tiganiada, Tigani, Tiganiada, Tigani, Tiganiada, Tigani, Tiganiada, Tigani, Tiganiada, Tigani, Tiganiada, Tigani, Tiganiada, Tigani, Tiganiada, ','Tigani, Tiganiada, Tigani, Tiganiada, Tigani, Tiganiada, ',0,'','inherit','open','open','','tigani-tiganiada-tigani-tiganiada-tigani-tiganiada-2','','','2007-03-22 14:18:05','2007-03-22 12:18:05','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/04-tiganii-si-porcul-ii.jpg',0,'post','image/jpeg',0),(171,1,'2007-03-22 14:19:25','2007-03-22 12:19:25','Tigani, Tiganiada, Tigani, Tiganiada, Tigani, Tiganiada,Tigani, Tiganiada, Tigani, Tiganiada, Tigani, Tiganiada,Tigani, Tiganiada, Tigani, Tiganiada, Tigani, Tiganiada,Tigani, Tiganiada, Tigani, Tiganiada, Tigani, Tiganiada,','Tigani, Tiganiada, Tigani, Tiganiada, Tigani, Tiganiada,',0,'','inherit','open','open','','tigani-tiganiada-tigani-tiganiada-tigani-tiganiada-3','','','2007-03-22 14:19:25','2007-03-22 12:19:25','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/06-porcul-tiganilor-se-invatza-cu-lemnu.jpg',0,'post','image/jpeg',0),(172,1,'2007-03-22 14:19:55','2007-03-22 12:19:55','Tigani, Tiganiada, Tigani, Tiganiada, Tigani, Tiganiada,Tigani, Tiganiada, Tigani, Tiganiada, Tigani, Tiganiada,Tigani, Tiganiada, Tigani, Tiganiada, Tigani, Tiganiada,Tigani, Tiganiada, Tigani, Tiganiada, Tigani, Tiganiada,','Tigani, Tiganiada, Tigani, Tiganiada, Tigani, Tiganiada,',0,'','inherit','open','open','','tigani-tiganiada-tigani-tiganiada-tigani-tiganiada-4','','','2007-03-22 14:19:55','2007-03-22 12:19:55','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/07-na-du-te-sa-te-tzuce-porcu-tigane.jpg',0,'post','image/jpeg',0),(173,1,'2007-03-22 14:21:20','2007-03-22 12:21:20','Tigani, Tiganiada, Tigani, Tiganiada, Tigani, Tiganiada,Tigani, Tiganiada, Tigani, Tiganiada, Tigani, Tiganiada,Tigani, Tiganiada, Tigani, Tiganiada, Tigani, Tiganiada,Tigani, Tiganiada, Tigani, Tiganiada, Tigani, Tiganiada,','Tigani, Tiganiada, Tigani, Tiganiada, Tigani, Tiganiada,',0,'','inherit','open','open','','tigani-tiganiada-tigani-tiganiada-tigani-tiganiada-5','','','2007-03-22 14:21:20','2007-03-22 12:21:20','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/08-sa-nu-inerveze-careva-pe-tiganu-de-mandea.jpg',0,'post','image/jpeg',0),(174,1,'2007-03-22 14:21:41','2007-03-22 12:21:41','Tigani, Tiganiada, Tigani, Tiganiada, Tigani, Tiganiada,Tigani, Tiganiada, Tigani, Tiganiada, Tigani, Tiganiada,Tigani, Tiganiada, Tigani, Tiganiada, Tigani, Tiganiada,Tigani, Tiganiada, Tigani, Tiganiada, Tigani, Tiganiada,','Tigani, Tiganiada, Tigani, Tiganiada, Tigani, Tiganiada,',0,'','inherit','open','open','','tigani-tiganiada-tigani-tiganiada-tigani-tiganiada-6','','','2007-03-22 14:21:41','2007-03-22 12:21:41','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/09-tiganu-si-matizu.jpg',0,'post','image/jpeg',0),(175,1,'2007-03-22 14:23:13','2007-03-22 12:23:13','Tigani, Tiganiada, Tiganesc, Tiganeasca, Gipsy, Roma, Tigani, Tiganiada, Tiganesc, Tiganeasca, Gipsy, Roma, Tigani, Tiganiada, Tiganesc, Tiganeasca, Gipsy, Roma, Tigani, Tiganiada, Tiganesc, Tiganeasca, Gipsy, Roma, Tigani, Tiganiada, Tiganesc, Tiganeasca, Gipsy, Roma','Tigani, Tiganiada, Tiganesc, Tiganeasca, Gipsy, Roma',0,'','inherit','open','open','','tigani-tiganiada-tiganesc-tiganeasca-gipsy-roma','','','2007-03-22 14:23:13','2007-03-22 12:23:13','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/10-tiganu-ca-leguma.jpg',0,'post','image/jpeg',0),(176,1,'2007-03-22 14:23:40','2007-03-22 12:23:40','Tigani, Tiganiada, Tiganesc, Tiganeasca, Gipsy, Roma, Tigani, Tiganiada, Tiganesc, Tiganeasca, Gipsy, Roma, Tigani, Tiganiada, Tiganesc, Tiganeasca, Gipsy, Roma, Tigani, Tiganiada, Tiganesc, Tiganeasca, Gipsy, Roma','Tigani, Tiganiada, Tiganesc, Tiganeasca, Gipsy, Roma ',0,'','inherit','open','open','','tigani-tiganiada-tiganesc-tiganeasca-gipsy-roma-2','','','2007-03-22 14:23:40','2007-03-22 12:23:40','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/11-tiganii-ca-legumele.jpg',0,'post','image/jpeg',0),(177,1,'2007-03-22 14:24:14','2007-03-22 12:24:14','Tigani, Tiganiada, Tiganesc, Tiganeasca, Gipsy, Roma, Tigani, Tiganiada, Tiganesc, Tiganeasca, Gipsy, Roma, Tigani, Tiganiada, Tiganesc, Tiganeasca, Gipsy, Roma, Tigani, Tiganiada, Tiganesc, Tiganeasca, Gipsy, Roma','Tigani, Tiganiada, Tiganesc, Tiganeasca, Gipsy, Roma',0,'','inherit','open','open','','tigani-tiganiada-tiganesc-tiganeasca-gipsy-roma-3','','','2007-03-22 14:24:14','2007-03-22 12:24:14','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/12-crajma-vizavi-de-cimitir-unde-bea-tigani-ca-noi.jpg',0,'post','image/jpeg',0),(178,1,'2007-03-22 14:24:43','2007-03-22 12:24:43','Tigani, Tiganiada, Tiganesc, Tiganeasca, Gipsy, Roma, Tigani, Tiganiada, Tiganesc, Tiganeasca, Gipsy, Roma, Tigani, Tiganiada, Tiganesc, Tiganeasca, Gipsy, Roma, Tigani, Tiganiada, Tiganesc, Tiganeasca, Gipsy, Roma','Tigani, Tiganiada, Tiganesc, Tiganeasca, Gipsy, Roma',0,'','inherit','open','open','','tigani-tiganiada-tiganesc-tiganeasca-gipsy-roma-4','','','2007-03-22 14:24:43','2007-03-22 12:24:43','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/13-hai-sa-ti-vindem-un-cal-tiganesc-fara-cip.jpg',0,'post','image/jpeg',0),(197,1,'2007-03-22 14:47:53','2007-03-22 12:47:53','Tigan, tiganesc, tiganeasca, gipsy, Roma, gitan','13. Hai sa-ti vindem un cal tiganesc fara cip!',0,'','inherit','open','open','','13-hai-sa-ti-vindem-un-cal-tiganesc-fara-cip','','','2007-03-22 14:47:53','2007-03-22 12:47:53','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/13-hai-sa-ti-vindem-un-cal-tiganesc-fara-cip.jpg',0,'post','image/jpeg',0),(198,1,'2007-03-22 14:48:19','2007-03-22 12:48:19','Tigan, tiganesc, tiganeasca, gipsy, Roma, gitan','14. Tigan calare',0,'','inherit','open','open','','14-tigan-calare','','','2007-03-22 14:48:19','2007-03-22 12:48:19','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/14-tigan-calare.jpg',0,'post','image/jpeg',0),(199,1,'2007-03-22 14:49:39','2007-03-22 12:49:39','Tigan, tiganesc, tiganeasca, gipsy, Roma, gitan','15. Bulibasa calare',0,'','inherit','open','open','','15-bulibasa-calare','','','2007-03-22 14:49:39','2007-03-22 12:49:39','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/15-bulibasa-calare.jpg',0,'post','image/jpeg',0),(179,1,'2007-03-22 14:25:38','2007-03-22 12:25:38','Tigani, Tiganiada, Tiganesc, Tiganeasca, Gipsy, Roma, Tigani, Tiganiada, Tiganesc, Tiganeasca, Gipsy, Roma, Tigani, Tiganiada, Tiganesc, Tiganeasca, Gipsy, Roma, Tigani, Tiganiada, Tiganesc, Tiganeasca, Gipsy, Roma','Tigani, Tiganiada, Tiganesc, Tiganeasca, Gipsy, Roma',0,'','inherit','open','open','','tigani-tiganiada-tiganesc-tiganeasca-gipsy-roma-5','','','2007-03-22 14:25:38','2007-03-22 12:25:38','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/14-tigan-calare.jpg',0,'post','image/jpeg',0),(180,1,'2007-03-22 14:26:02','2007-03-22 12:26:02','Tigani, Tiganiada, Tiganesc, Tiganeasca, Gipsy, Roma, Tigani, Tiganiada, Tiganesc, Tiganeasca, Gipsy, Roma, Tigani, Tiganiada, Tiganesc, Tiganeasca, Gipsy, Roma, Tigani, Tiganiada, Tiganesc, Tiganeasca, Gipsy, Roma','Tigani, Tiganiada, Tiganesc, Tiganeasca, Gipsy, Roma',0,'','inherit','open','open','','tigani-tiganiada-tiganesc-tiganeasca-gipsy-roma-6','','','2007-03-22 14:26:02','2007-03-22 12:26:02','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/15-bulibasa-calare.jpg',0,'post','image/jpeg',0),(181,1,'2007-03-22 14:26:23','2007-03-22 12:26:23','Tigani, Tiganiada, Tiganesc, Tiganeasca, Gipsy, Roma, Tigani, Tiganiada, Tiganesc, Tiganeasca, Gipsy, Roma, Tigani, Tiganiada, Tiganesc, Tiganeasca, Gipsy, Roma, Tigani, Tiganiada, Tiganesc, Tiganeasca, Gipsy, Roma','Tigani, Tiganiada, Tiganesc, Tiganeasca, Gipsy, Roma',0,'','inherit','open','open','','tigani-tiganiada-tiganesc-tiganeasca-gipsy-roma-7','','','2007-03-22 14:26:23','2007-03-22 12:26:23','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/16-tiganii-bea-lapte-numa-daca-vacile-bea-coniac.jpg',0,'post','image/jpeg',0),(182,1,'2007-03-22 14:26:58','2007-03-22 12:26:58','Tigani, Tiganiada, Tiganesc, Tiganeasca, Gipsy, Roma, Tigani, Tiganiada, Tiganesc, Tiganeasca, Gipsy, Roma, Tigani, Tiganiada, Tiganesc, Tiganeasca, Gipsy, Roma, Tigani, Tiganiada, Tiganesc, Tiganeasca, Gipsy, Roma','Tigani, Tiganiada, Tiganesc, Tiganeasca, Gipsy, Roma',0,'','inherit','open','open','','tigani-tiganiada-tiganesc-tiganeasca-gipsy-roma-8','','','2007-03-22 14:26:58','2007-03-22 12:26:58','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/17-noul-nostru-prekin-mai-tigan-ca-noi.jpg',0,'post','image/jpeg',0),(183,1,'2007-03-22 14:27:35','2007-03-22 12:27:35','Tigani, Tiganiada, Tiganesc, Tiganeasca, Gipsy, Roma, Tigani, Tiganiada, Tiganesc, Tiganeasca, Gipsy, Roma, Tigani, Tiganiada, Tiganesc, Tiganeasca, Gipsy, Roma, Tigani, Tiganiada, Tiganesc, Tiganeasca, Gipsy, Roma','Tigani, Tiganiada, Tiganesc, Tiganeasca, Gipsy, Roma',0,'','inherit','open','open','','tigani-tiganiada-tiganesc-tiganeasca-gipsy-roma-9','','','2007-03-22 14:27:35','2007-03-22 12:27:35','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/18-ce-pisha-tiganii-aia-de-beau-coniac.jpg',0,'post','image/jpeg',0),(184,1,'2007-03-22 14:28:27','2007-03-22 12:28:27','Tigani, Tiganiada, Tiganesc, Tiganeasca, Gipsy, Roma, Tigani, Tiganiada, Tiganesc, Tiganeasca, Gipsy, Roma, Tigani, Tiganiada, Tiganesc, Tiganeasca, Gipsy, Roma, Tigani, Tiganiada, Tiganesc, Tiganeasca, Gipsy, Roma','Tigani, Tiganiada, Tiganesc, Tiganeasca, Gipsy, Roma',0,'','inherit','open','open','','tigani-tiganiada-tiganesc-tiganeasca-gipsy-roma-10','','','2007-03-22 14:28:27','2007-03-22 12:28:27','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/19-let-the-hostilities-begin-pe-muzica-tiganeasca.jpg',0,'post','image/jpeg',0),(185,1,'2007-03-22 14:28:42','2007-03-22 12:28:42','Tigani, Tiganiada, Tiganesc, Tiganeasca, Gipsy, Roma, Tigani, Tiganiada, Tiganesc, Tiganeasca, Gipsy, Roma, Tigani, Tiganiada, Tiganesc, Tiganeasca, Gipsy, Roma, Tigani, Tiganiada, Tiganesc, Tiganeasca, Gipsy, Roma','Tigani, Tiganiada, Tiganesc, Tiganeasca, Gipsy, Roma',0,'','inherit','open','open','','tigani-tiganiada-tiganesc-tiganeasca-gipsy-roma-11','','','2007-03-22 14:28:42','2007-03-22 12:28:42','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/20-tigan-de-vierme-de-matase.jpg',0,'post','image/jpeg',0),(189,1,'2007-03-22 14:40:13','2007-03-22 12:40:13','Tigan, tiganesc, tiganeasca, gipsy, Roma, gitan','04. Tiganii si porcul II',0,'','inherit','open','open','','04-tiganii-si-porcul-ii','','','2007-03-22 14:40:13','2007-03-22 12:40:13','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/04-tiganii-si-porcul-ii.jpg',0,'post','image/jpeg',0),(190,1,'2007-03-22 14:42:36','2007-03-22 12:42:36','Tigan, tiganesc, tiganeasca, gipsy, Roma, gitan','06. Porcul tiganilor se invatza cu lemnu',0,'','inherit','open','open','','06-porcul-tiganilor-se-invatza-cu-lemnu','','','2007-03-22 14:42:36','2007-03-22 12:42:36','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/06-porcul-tiganilor-se-invatza-cu-lemnu.jpg',0,'post','image/jpeg',0),(191,1,'2007-03-22 14:43:04','2007-03-22 12:43:04','Tigan, tiganesc, tiganeasca, gipsy, Roma, gitan','07. Na du-te sa te tzuce porcu, tigane!',0,'','inherit','open','open','','07-na-du-te-sa-te-tzuce-porcu-tigane','','','2007-03-22 14:43:04','2007-03-22 12:43:04','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/07-na-du-te-sa-te-tzuce-porcu-tigane.jpg',0,'post','image/jpeg',0),(192,1,'2007-03-22 14:43:24','2007-03-22 12:43:24','Tigan, tiganesc, tiganeasca, gipsy, Roma, gitan','08. Sa nu inerveze careva pe tiganu de mandea!',0,'','inherit','open','open','','08-sa-nu-inerveze-careva-pe-tiganu-de-mandea','','','2007-03-22 14:43:24','2007-03-22 12:43:24','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/08-sa-nu-inerveze-careva-pe-tiganu-de-mandea.jpg',0,'post','image/jpeg',0),(193,1,'2007-03-22 14:45:18','2007-03-22 12:45:18','Tigan, tiganesc, tiganeasca, gipsy, Roma, gitan','09. Tiganu si Matizu\'',0,'','inherit','open','open','','09-tiganu-si-matizu','','','2007-03-22 14:45:18','2007-03-22 12:45:18','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/09-tiganu-si-matizu.jpg',0,'post','image/jpeg',0),(194,1,'2007-03-22 14:45:56','2007-03-22 12:45:56','Tigan, tiganesc, tiganeasca, gipsy, Roma, gitan','10. Tiganu ca leguma',0,'','inherit','open','open','','10-tiganu-ca-leguma','','','2007-03-22 14:45:56','2007-03-22 12:45:56','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/10-tiganu-ca-leguma.jpg',0,'post','image/jpeg',0),(195,1,'2007-03-22 14:47:07','2007-03-22 12:47:07','Tigan, tiganesc, tiganeasca, gipsy, Roma, gitan','11. Tiganii ca legumele',0,'','inherit','open','open','','11-tiganii-ca-legumele','','','2007-03-22 14:47:07','2007-03-22 12:47:07','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/11-tiganii-ca-legumele.jpg',0,'post','image/jpeg',0),(196,1,'2007-03-22 14:47:32','2007-03-22 12:47:32','Tigan, tiganesc, tiganeasca, gipsy, Roma, gitan','12. Crajma vizavi de cimitir unde bea tigani ca noi',0,'','inherit','open','open','','12-crajma-vizavi-de-cimitir-unde-bea-tigani-ca-noi','','','2007-03-22 14:47:32','2007-03-22 12:47:32','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/12-crajma-vizavi-de-cimitir-unde-bea-tigani-ca-noi.jpg',0,'post','image/jpeg',0),(186,1,'2007-03-22 14:35:21','2007-03-22 12:35:21','Tigan, tiganesc, tiganeasca, gipsy, Roma, gitan ','01. Tigani in parcare',0,'','inherit','open','open','','01-tigani-in-parcare','','','2007-03-22 14:35:21','2007-03-22 12:35:21','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/01-tigani-in-parcare.jpg',0,'post','image/jpeg',0),(187,1,'2007-03-22 14:36:01','2007-03-22 12:36:01','Tigan, tiganesc, tiganeasca, Roma, gipsy, gitan','02. Tigani in parcare II',0,'','inherit','open','open','','02-tigani-in-parcare-ii','','','2007-03-22 14:36:01','2007-03-22 12:36:01','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/02-tigani-in-parcare-ii.jpg',0,'post','image/jpeg',0),(188,1,'2007-03-22 14:37:40','2007-03-22 12:37:40','Tigan, tiganesc, tiganeasca, gipsy, Roma, gitan','03. Tiganii si porcul',0,'','inherit','open','open','','03-tiganii-si-porcul','','','2007-03-22 14:37:40','2007-03-22 12:37:40','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/03-tiganii-si-porcul.jpg',0,'post','image/jpeg',0),(200,1,'2007-03-22 14:53:05','2007-03-22 12:53:05','Tigan, tiganesc, tiganeasca, gipsy, Roma, gitan','16. Tiganii bea lapte numa\' daca vacile bea coniac!',0,'','inherit','open','open','','16-tiganii-bea-lapte-numa-daca-vacile-bea-coniac','','','2007-03-22 14:53:05','2007-03-22 12:53:05','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/16-tiganii-bea-lapte-numa-daca-vacile-bea-coniac.jpg',0,'post','image/jpeg',0),(201,1,'2007-03-22 14:53:33','2007-03-22 12:53:33','Tigan, tiganesc, tiganeasca, gipsy, Roma, gitan','17. noul nostru prekin mai tigan ca noi',0,'','inherit','open','open','','17-noul-nostru-prekin-mai-tigan-ca-noi','','','2007-03-22 14:53:33','2007-03-22 12:53:33','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/17-noul-nostru-prekin-mai-tigan-ca-noi.jpg',0,'post','image/jpeg',0),(202,1,'2007-03-22 14:53:52','2007-03-22 12:53:52','Tigan, tiganesc, tiganeasca, gipsy, Roma, gitan','18. Ce pisha tiganii aia de beau coniac',0,'','inherit','open','open','','18-ce-pisha-tiganii-aia-de-beau-coniac','','','2007-03-22 14:53:52','2007-03-22 12:53:52','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/18-ce-pisha-tiganii-aia-de-beau-coniac.jpg',0,'post','image/jpeg',0),(203,1,'2007-03-22 14:54:17','2007-03-22 12:54:17','Tigan, tiganesc, tiganeasca, gipsy, Roma, gitan','19. Let the hostilities begin! Pe muzica tiganeasca',0,'','inherit','open','open','','19-let-the-hostilities-begin-pe-muzica-tiganeasca','','','2007-03-22 14:54:17','2007-03-22 12:54:17','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/19-let-the-hostilities-begin-pe-muzica-tiganeasca.jpg',0,'post','image/jpeg',0),(204,1,'2007-03-22 14:54:35','2007-03-22 12:54:35','20. Tigan de vierme de matase','20. Tigan de vierme de matase',0,'','inherit','open','open','','20-tigan-de-vierme-de-matase','','','2007-03-22 14:54:35','2007-03-22 12:54:35','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/20-tigan-de-vierme-de-matase.jpg',0,'post','image/jpeg',0),(205,1,'2007-03-22 14:54:54','2007-03-22 12:54:54','21. Valea noastra plina de muzica tiganeasca','21. Valea noastra plina de muzica tiganeasca',0,'','inherit','open','open','','21-valea-noastra-plina-de-muzica-tiganeasca','','','2007-03-22 14:54:54','2007-03-22 12:54:54','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/21-valea-noastra-plina-de-muzica-tiganeasca.jpg',0,'post','image/jpeg',0),(206,1,'2007-03-22 14:55:17','2007-03-22 12:55:17','Tigan, tiganesc, tiganeasca, gipsy, Roma, gitan','22. Porcu\' tiganesc incepe indeplinirea misiunii',0,'','inherit','open','open','','22-porcu-tiganesc-incepe-indeplinirea-misiunii','','','2007-03-22 14:55:17','2007-03-22 12:55:17','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/22-porcu-tiganesc-incepe-indeplinirea-misiunii.jpg',0,'post','image/jpeg',0),(207,1,'2007-03-22 14:55:37','2007-03-22 12:55:37','Tigan, tiganesc, tiganeasca, gipsy, Roma, gitan','23. Porc pe umar de tigan',0,'','inherit','open','open','','23-porc-pe-umar-de-tigan','','','2007-03-22 14:55:37','2007-03-22 12:55:37','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/23-porc-pe-umar-de-tigan.jpg',0,'post','image/jpeg',0),(208,1,'2007-03-22 14:56:02','2007-03-22 12:56:02','Tigan, tiganesc, tiganeasca, gipsy, Roma, gitan','23. Porc pe umar de tigan',0,'','inherit','open','open','','23-porc-pe-umar-de-tigan-2','','','2007-03-22 14:56:02','2007-03-22 12:56:02','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/23-porc-pe-umar-de-tigan.jpg',0,'post','image/jpeg',0),(209,1,'2007-03-22 14:57:42','2007-03-22 12:57:42','Tigan, tiganesc, tiganeasca, gipsy, Roma, gitan','24. Imaginile si zambetul zice totul!',0,'','inherit','open','open','','24-imaginile-si-zambetul-zice-totul','','','2007-03-22 14:57:42','2007-03-22 12:57:42','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/24-imaginile-si-zambetul-zice-totul.jpg',0,'post','image/jpeg',0),(210,1,'2007-03-22 14:58:08','2007-03-22 12:58:08','Tigan, tiganesc, tiganeasca, gipsy, Roma, gitan','25. Porc tiganesc',0,'','inherit','open','open','','25-porc-tiganesc','','','2007-03-22 14:58:08','2007-03-22 12:58:08','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/25-porc-tiganesc.jpg',0,'post','image/jpeg',0),(211,1,'2007-03-22 14:58:27','2007-03-22 12:58:27','Tigan, tiganesc, tiganeasca, gipsy, Roma, gitan','26. Nu il mai prajim...',0,'','inherit','open','open','','26-nu-il-mai-prajim','','','2007-03-22 14:58:27','2007-03-22 12:58:27','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/26-nu-il-mai-prajim.jpg',0,'post','image/jpeg',0),(212,1,'2007-03-22 14:58:55','2007-03-22 12:58:55','Tigan, tiganesc, tiganeasca, gipsy, Roma, gitan','27. Valsul tiganesc',0,'','inherit','open','open','','27-valsul-tiganesc','','','2007-03-22 14:58:55','2007-03-22 12:58:55','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/27-valsul-tiganesc.jpg',0,'post','image/jpeg',0),(213,1,'2007-03-22 14:59:14','2007-03-22 12:59:14','Tigan, tiganesc, tiganeasca, gipsy, Roma, gitan','28. Orgie in stil rrom-anesc',0,'','inherit','open','open','','28-orgie-in-stil-rrom-anesc','','','2007-03-22 14:59:14','2007-03-22 12:59:14','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/28-orgie-in-stil-rrom-anesc.jpg',0,'post','image/jpeg',0),(214,1,'2007-03-22 14:59:39','2007-03-22 12:59:39','Tigan, tiganesc, tiganeasca, gipsy, Roma, gitan','29. Orgie in stil rrom-anesc II',0,'','inherit','open','open','','29-orgie-in-stil-rrom-anesc-ii','','','2007-03-22 14:59:39','2007-03-22 12:59:39','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/29-orgie-in-stil-rrom-anesc-ii.jpg',0,'post','image/jpeg',0),(215,1,'2007-03-22 15:00:58','2007-03-22 13:00:58','Tigan, tiganesc, tiganeasca, gipsy, Roma, gitan','31. Porc tiganesc crestat pt usturoi',0,'','inherit','open','open','','31-porc-tiganesc-crestat-pt-usturoi','','','2007-03-22 15:00:58','2007-03-22 13:00:58','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/31-porc-tiganesc-crestat-pt-usturoi.jpg',0,'post','image/jpeg',0),(216,1,'2007-03-22 15:03:04','2007-03-22 13:03:04','Tigan, tiganesc, tiganeasca, gipsy, Roma, gitan','32. Incepe marea sfaraiala',0,'','inherit','open','open','','32-incepe-marea-sfaraiala','','','2007-03-22 15:03:04','2007-03-22 13:03:04','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/32-incepe-marea-sfaraiala.jpg',0,'post','image/jpeg',0),(217,1,'2007-03-22 15:03:53','2007-03-22 13:03:53','Tigan, tiganesc, tiganeasca, gipsy, Roma, gitan, poze cu tigani, gipsy pictures','33. Pic, pic, stalactita de slanina!',0,'','inherit','open','open','','33-pic-pic-stalactita-de-slanina','','','2007-03-22 15:03:53','2007-03-22 13:03:53','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/33-pic-pic-stalactita-de-slanina.jpg',0,'post','image/jpeg',0),(218,1,'2007-03-22 15:04:19','2007-03-22 13:04:19','Tigan, tiganesc, tiganeasca, gipsy, Roma, gitan, poze cu tigani, gipsy pictures','34. Imagine explicita',0,'','inherit','open','open','','34-imagine-explicita','','','2007-03-22 15:04:19','2007-03-22 13:04:19','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/34-imagine-explicita.jpg',0,'post','image/jpeg',0),(219,1,'2007-03-22 15:04:48','2007-03-22 13:04:48','Tigan, tiganesc, tiganeasca, gipsy, Roma, gitan, poze cu tigani, gipsy pictures','35. Ranjet imposibil de reprodus',0,'','inherit','open','open','','35-ranjet-imposibil-de-reprodus','','','2007-03-22 15:04:48','2007-03-22 13:04:48','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/35-ranjet-imposibil-de-reprodus.jpg',0,'post','image/jpeg',0),(220,1,'2007-03-22 15:06:03','2007-03-22 13:06:03','Tigan, tiganesc, tiganeasca, gipsy, Roma, gitan, poze cu tigani, gipsy pictures','36. Trei, doamne, si toti trei insetati!',0,'','inherit','open','open','','36-trei-doamne-si-toti-trei-insetati','','','2007-03-22 15:06:03','2007-03-22 13:06:03','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/36-trei-doamne-si-toti-trei-insetati.jpg',0,'post','image/jpeg',0),(221,1,'2007-03-22 15:06:25','2007-03-22 13:06:25','Tigan, tiganesc, tiganeasca, gipsy, Roma, gitan, poze cu tigani, gipsy pictures','37. Nu suntem vegetarieni. Nici nu vom fi',0,'','inherit','open','open','','37-nu-suntem-vegetarieni-nici-nu-vom-fi','','','2007-03-22 15:06:25','2007-03-22 13:06:25','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/37-nu-suntem-vegetarieni-nici-nu-vom-fi.jpg',0,'post','image/jpeg',0),(222,1,'2007-03-22 15:06:48','2007-03-22 13:06:48','Tigan, tiganesc, tiganeasca, gipsy, Roma, gitan, poze cu tigani, gipsy pictures','38. Manca-i-ai coada, Nelule!',0,'','inherit','open','open','','38-manca-i-ai-coada-nelule','','','2007-03-22 15:06:48','2007-03-22 13:06:48','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/38-manca-i-ai-coada-nelule.jpg',0,'post','image/jpeg',0),(223,1,'2007-03-22 15:07:12','2007-03-22 13:07:12','Tigan, tiganesc, tiganeasca, gipsy, Roma, gitan, poze cu tigani, gipsy pictures','39. Cocoshat de atata munca',0,'','inherit','open','open','','39-cocoshat-de-atata-munca','','','2007-03-22 15:07:12','2007-03-22 13:07:12','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/39-cocoshat-de-atata-munca.jpg',0,'post','image/jpeg',0),(224,1,'2007-03-22 15:07:31','2007-03-22 13:07:31','Tigan, tiganesc, tiganeasca, gipsy, Roma, gitan, poze cu tigani, gipsy pictures','40. Nelu, Suciu, Tigani, Porc, Love',0,'','inherit','open','open','','40-nelu-suciu-tigani-porc-love','','','2007-03-22 15:07:31','2007-03-22 13:07:31','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/40-nelu-suciu-tigani-porc-love.jpg',0,'post','image/jpeg',0),(225,1,'2007-03-22 15:08:33','2007-03-22 13:08:33','Tigan, tiganesc, tiganeasca, gipsy, Roma, gitan, poze cu tigani, gipsy pictures','41. Parca tai din Saddam, asa-mi place...',0,'','inherit','open','open','','41-parca-tai-din-saddam-asa-mi-place','','','2007-03-22 15:08:33','2007-03-22 13:08:33','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/41-parca-tai-din-saddam-asa-mi-place.jpg',0,'post','image/jpeg',0),(226,1,'2007-03-22 15:08:50','2007-03-22 13:08:50','Tigan, tiganesc, tiganeasca, gipsy, Roma, gitan, poze cu tigani, gipsy pictures','42. Imagine exxxplicita',0,'','inherit','open','open','','42-imagine-exxxplicita','','','2007-03-22 15:08:50','2007-03-22 13:08:50','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/42-imagine-exxxplicita.jpg',0,'post','image/jpeg',0),(227,1,'2007-03-22 15:09:08','2007-03-22 13:09:08','Tigan, tiganesc, tiganeasca, gipsy, Roma, gitan, poze cu tigani, gipsy pictures','43. Ce daca arde! Si stomacu\' meu tiganesc arde...',0,'','inherit','open','open','','43-ce-daca-arde-si-stomacu-meu-tiganesc-arde','','','2007-03-22 15:09:08','2007-03-22 13:09:08','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/43-ce-daca-arde-si-stomacu-meu-tiganesc-arde.jpg',0,'post','image/jpeg',0),(228,1,'2007-03-22 15:10:13','2007-03-22 13:10:13','Tigan, tiganesc, tiganeasca, gipsy, Roma, gitan, poze cu tigani, gipsy pictures','44. Tiganii mananca cu ochii, gura, nasul, urechile..',0,'','inherit','open','open','','44-tiganii-mananca-cu-ochii-gura-nasul-urechile','','','2007-03-22 15:10:13','2007-03-22 13:10:13','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/44-tiganii-mananca-cu-ochii-gura-nasul-urechile.jpg',0,'post','image/jpeg',0),(229,1,'2007-03-22 15:10:46','2007-03-22 13:10:46','Tigan, tiganesc, tiganeasca, gipsy, Roma, gitan, poze cu tigani, gipsy pictures','45. Pe nailon, sa nu ne murdarim cu iarba',0,'','inherit','open','open','','45-pe-nailon-sa-nu-ne-murdarim-cu-iarba','','','2007-03-22 15:10:46','2007-03-22 13:10:46','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/45-pe-nailon-sa-nu-ne-murdarim-cu-iarba.jpg',0,'post','image/jpeg',0),(230,1,'2007-03-22 15:11:07','2007-03-22 13:11:07','Tigan, tiganesc, tiganeasca, gipsy, Roma, gitan, poze cu tigani, gipsy pictures','46. Oare tiganu asta se gandeste la ceva, sau oare numa\' sta...',0,'','inherit','open','open','','46-oare-tiganu-asta-se-gandeste-la-ceva-sau-oare-numa-sta','','','2007-03-22 15:11:07','2007-03-22 13:11:07','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/46-oare-tiganu-asta-se-gandeste-la-ceva-sau-oare-numa-sta.jpg',0,'post','image/jpeg',0),(231,1,'2007-03-22 15:11:39','2007-03-22 13:11:39','Tigan, tiganesc, tiganeasca, gipsy, Roma, gitan, poze cu tigani, gipsy pictures','47.Bulibasa',0,'','inherit','open','open','','47bulibasa','','','2007-03-22 15:11:39','2007-03-22 13:11:39','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/47-bulibasa.jpg',0,'post','image/jpeg',0),(232,1,'2007-03-22 15:12:13','2007-03-22 13:12:13','Tigan, tiganesc, tiganeasca, gipsy, Roma, gitan, poze cu tigani, gipsy pictures','48. Tigan mort de beutura',0,'','inherit','open','open','','48-tigan-mort-de-beutura','','','2007-03-22 15:12:13','2007-03-22 13:12:13','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/48-tigan-mort-de-beutura.jpg',0,'post','image/jpeg',0),(233,1,'2007-03-22 15:13:02','2007-03-22 13:13:02','Tigan, tiganesc, tiganeasca, gipsy, Roma, gitan, poze cu tigani, gipsy pictures','49. Stau tigani la foc, focu-i la mijloc, Huby cu ghioc',0,'','inherit','open','open','','49-stau-tigani-la-foc-focu-i-la-mijloc-huby-cu-ghioc','','','2007-03-22 15:13:02','2007-03-22 13:13:02','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/49-stau-tigani-la-foc-focu-i-la-mijloc-huby-cu-ghioc.jpg',0,'post','image/jpeg',0),(234,1,'2007-03-22 15:13:28','2007-03-22 13:13:28','Tigan, tiganesc, tiganeasca, gipsy, Roma, gitan, poze cu tigani, gipsy pictures','50. Natura Moarta. De beata',0,'','inherit','open','open','','50-natura-moarta-de-beata','','','2007-03-22 15:13:28','2007-03-22 13:13:28','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/50-natura-moarta-de-beata.jpg',0,'post','image/jpeg',0),(235,1,'2007-03-22 15:14:19','2007-03-22 13:14:19','Tigan, tiganesc, tiganeasca, gipsy, Roma, gitan, poze cu tigani, gipsy pictures','51. Tiganii mananca carne cruda, post-transare',0,'','inherit','open','open','','51-tiganii-mananca-carne-cruda-post-transare','','','2007-03-22 15:14:19','2007-03-22 13:14:19','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/51-tiganii-mananca-carne-cruda-post-transare.jpg',0,'post','image/jpeg',0),(236,1,'2007-03-22 15:14:41','2007-03-22 13:14:41','Tigan, tiganesc, tiganeasca, gipsy, Roma, gitan, poze cu tigani, gipsy pictures','52. Tigan cu carne cruda in gura',0,'','inherit','open','open','','52-tigan-cu-carne-cruda-in-gura','','','2007-03-22 15:14:41','2007-03-22 13:14:41','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/52-tigan-cu-carne-cruda-in-gura.jpg',0,'post','image/jpeg',0),(237,1,'2007-03-22 15:15:07','2007-03-22 13:15:07','Tigan, tiganesc, tiganeasca, gipsy, Roma, gitan, poze cu tigani, gipsy pictures','53. Maini tiganesti flamande, burti tiganesti insetate',0,'','inherit','open','open','','53-maini-tiganesti-flamande-burti-tiganesti-insetate','','','2007-03-22 15:15:07','2007-03-22 13:15:07','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/53-maini-tiganesti-flamande-burti-tiganesti-insetate.jpg',0,'post','image/jpeg',0),(238,1,'2007-03-22 15:15:30','2007-03-22 13:15:30','Tigan, tiganesc, tiganeasca, gipsy, Roma, gitan, poze cu tigani, gipsy pictures','54. Natura moarta tiganeasca cu paine alba si balega vie',0,'','inherit','open','open','','54-natura-moarta-tiganeasca-cu-paine-alba-si-balega-vie','','','2007-03-22 15:15:30','2007-03-22 13:15:30','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/54-natura-moarta-tiganeasca-cu-paine-alba-si-balega-vie.jpg',0,'post','image/jpeg',0),(239,1,'2007-03-22 15:15:54','2007-03-22 13:15:54','Tigan, tiganesc, tiganeasca, gipsy, Roma, gitan, poze cu tigani, gipsy pictures','55. Tigan cazut la datorie',0,'','inherit','open','open','','55-tigan-cazut-la-datorie','','','2007-03-22 15:15:54','2007-03-22 13:15:54','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/55-tigan-cazut-la-datorie.jpg',0,'post','image/jpeg',0),(240,1,'2007-03-22 15:18:20','2007-03-22 13:18:20','Tigan, tiganesc, tiganeasca, gipsy, Roma, gitan, poze cu tigani, gipsy pictures','55. Tigan cazut la datorie',0,'','inherit','open','open','','55-tigan-cazut-la-datorie-2','','','2007-03-22 15:18:20','2007-03-22 13:18:20','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/55-tigan-cazut-la-datorie.jpg',0,'post','image/jpeg',0),(241,1,'2007-03-22 15:20:06','2007-03-22 13:20:06','Tigan, tiganesc, tiganeasca, gipsy, Roma, gitan, poze cu tigani, gipsy pictures','55. Tigan cazut la datorie',0,'','inherit','open','open','','55-tigan-cazut-la-datorie-3','','','2007-03-22 15:20:06','2007-03-22 13:20:06','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/55-tigan-cazut-la-datorie.jpg',0,'post','image/jpeg',0),(242,1,'2007-03-22 15:26:26','2007-03-22 13:26:26','Tigan, tiganesc, tiganeasca, gipsy, Roma, gitan, poze cu tigani, gipsy pictures','56. La umbra de cruce deasa',0,'','inherit','open','open','','56-la-umbra-de-cruce-deasa','','','2007-03-22 15:26:26','2007-03-22 13:26:26','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/56-la-umbra-de-cruce-deasa.jpg',0,'post','image/jpeg',0),(243,1,'2007-03-22 15:26:48','2007-03-22 13:26:48','Tigan, tiganesc, tiganeasca, gipsy, Roma, gitan, poze cu tigani, gipsy pictures','57. Daca berea sta vertical, e suficient!',0,'','inherit','open','open','','57-daca-berea-sta-vertical-e-suficient','','','2007-03-22 15:26:48','2007-03-22 13:26:48','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/57-daca-berea-sta-vertical-e-suficient.jpg',0,'post','image/jpeg',0),(244,1,'2007-03-22 15:27:14','2007-03-22 13:27:14','Tigan, tiganesc, tiganeasca, gipsy, Roma, gitan, poze cu tigani, gipsy pictures','58. Doamne, nu-l omori acum pe robul Tau tigan! Ca si mor...',0,'','inherit','open','open','','58-doamne-nu-l-omori-acum-pe-robul-tau-tigan-ca-si-mor','','','2007-03-22 15:27:14','2007-03-22 13:27:14','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/58-doamne-nu-l-omori-acum-pe-robul-tau-tigan-ca-si-mor.jpg',0,'post','image/jpeg',0),(245,1,'2007-03-22 15:27:36','2007-03-22 13:27:36','Tigan, tiganesc, tiganeasca, gipsy, Roma, gitan, poze cu tigani, gipsy pictures','59. Trec tigani prin colb',0,'','inherit','open','open','','59-trec-tigani-prin-colb','','','2007-03-22 15:27:36','2007-03-22 13:27:36','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/59-trec-tigani-prin-colb.jpg',0,'post','image/jpeg',0),(246,1,'2007-03-22 15:27:52','2007-03-22 13:27:52','Tigan, tiganesc, tiganeasca, gipsy, Roma, gitan, poze cu tigani, gipsy pictures','60. Gratar cu porc de tigan',0,'','inherit','open','open','','60-gratar-cu-porc-de-tigan','','','2007-03-22 15:27:52','2007-03-22 13:27:52','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/60-gratar-cu-porc-de-tigan.jpg',0,'post','image/jpeg',0),(247,1,'2007-03-22 15:28:18','2007-03-22 13:28:18','Tigan, tiganesc, tiganeasca, gipsy, Roma, gitan, poze cu tigani, gipsy pictures','61. Juganind tiganul',0,'','inherit','open','open','','61-juganind-tiganul','','','2007-03-22 15:28:18','2007-03-22 13:28:18','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/61-juganind-tiganul.jpg',0,'post','image/jpeg',0),(248,1,'2007-03-22 15:28:37','2007-03-22 13:28:37','Tigan, tiganesc, tiganeasca, gipsy, Roma, gitan, poze cu tigani, gipsy pictures','62. Tigan rapus de beutura',0,'','inherit','open','open','','62-tigan-rapus-de-beutura','','','2007-03-22 15:28:37','2007-03-22 13:28:37','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/62-tigan-rapus-de-beutura.jpg',0,'post','image/jpeg',0),(249,1,'2007-03-22 15:28:56','2007-03-22 13:28:56','Tigan, tiganesc, tiganeasca, gipsy, Roma, gitan, poze cu tigani, gipsy pictures','63. Tiganoi pe Dacioi',0,'','inherit','open','open','','63-tiganoi-pe-dacioi','','','2007-03-22 15:28:56','2007-03-22 13:28:56','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/63-tiganoi-pe-dacioi.jpg',0,'post','image/jpeg',0),(250,1,'2007-03-22 15:29:15','2007-03-22 13:29:15','Tigan, tiganesc, tiganeasca, gipsy, Roma, gitan, poze cu tigani, gipsy pictures','64. Tiganoi in Cieloi',0,'','inherit','open','open','','64-tiganoi-in-cieloi','','','2007-03-22 15:29:15','2007-03-22 13:29:15','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/64-tiganoi-in-cieloi.jpg',0,'post','image/jpeg',0),(251,1,'2007-03-22 15:29:35','2007-03-22 13:29:35','Tigan, tiganesc, tiganeasca, gipsy, Roma, gitan, poze cu tigani, gipsy pictures','65. Tigani betivi',0,'','inherit','open','open','','65-tigani-betivi','','','2007-03-22 15:29:35','2007-03-22 13:29:35','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/65-tigani-betivi.jpg',0,'post','image/jpeg',0),(252,1,'2007-03-22 15:29:58','2007-03-22 13:29:58','Tigan, tiganesc, tiganeasca, gipsy, Roma, gitan, poze cu tigani, gipsy pictures','66. Tigan beutor, nu borasc niciodata. Rog seriozitate',0,'','inherit','open','open','','66-tigan-beutor-nu-borasc-niciodata-rog-seriozitate','','','2007-03-22 15:29:58','2007-03-22 13:29:58','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/66-tigan-beutor-nu-borasc-niciodata-rog-seriozitate.jpg',0,'post','image/jpeg',0),(253,1,'2007-03-22 15:30:25','2007-03-22 13:30:25','Tigan, tiganesc, tiganeasca, gipsy, Roma, gitan, poze cu tigani, gipsy pictures','67. M-a facut muica tigan oltean betzivan!',0,'','inherit','open','open','','67-m-a-facut-muica-tigan-oltean-betzivan','','','2007-03-22 15:30:25','2007-03-22 13:30:25','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/67-m-a-facut-muica-tigan-oltean-betzivan.jpg',0,'post','image/jpeg',0),(254,1,'2007-03-22 15:31:12','2007-03-22 13:31:12','Tigan, tiganesc, tiganeasca, gipsy, Roma, gitan, poze cu tigani, gipsy pictures','68. Atata jar aveam si-n burta a doua zi',0,'','inherit','open','open','','68-atata-jar-aveam-si-n-burta-a-doua-zi','','','2007-03-22 15:31:12','2007-03-22 13:31:12','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/68-atata-jar-aveam-si-n-burta-a-doua-zi.jpg',0,'post','image/jpeg',0),(255,1,'2007-03-22 15:31:35','2007-03-22 13:31:35','Tigan, tiganesc, tiganeasca, gipsy, Roma, gitan, poze cu tigani, gipsy pictures','69. Cine si cand a facut poza asta, nu mai tine minte nime\'!',0,'','inherit','open','open','','69-cine-si-cand-a-facut-poza-asta-nu-mai-tine-minte-nime','','','2007-03-22 15:31:35','2007-03-22 13:31:35','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/69-cine-si-cand-a-facut-poza-asta-nu-mai-tine-minte-nime.jpg',0,'post','image/jpeg',0),(256,1,'2007-03-22 15:32:06','2007-03-22 13:32:06','Tigan, tiganesc, tiganeasca, gipsy, Roma, gitan, poze cu tigani, gipsy pictures','70. Tigan adormit in plin proces de imbracare - super tare',0,'','inherit','open','open','','70-tigan-adormit-in-plin-proces-de-imbracare-super-tare','','','2007-03-22 15:32:06','2007-03-22 13:32:06','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/70-tigan-adormit-in-plin-proces-de-imbracare-super-tare.jpg',0,'post','image/jpeg',0),(257,1,'2007-03-22 15:32:32','2007-03-22 13:32:32','Tigan, tiganesc, tiganeasca, gipsy, Roma, gitan, poze cu tigani, gipsy pictures','71. A doua zi, tiganii se feresc de soare ca vampirii...',0,'','inherit','open','open','','71-a-doua-zi-tiganii-se-feresc-de-soare-ca-vampirii','','','2007-03-22 15:32:32','2007-03-22 13:32:32','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/71-a-doua-zi-tiganii-se-feresc-de-soare-ca-vampirii.jpg',0,'post','image/jpeg',0),(258,1,'2007-03-22 15:32:52','2007-03-22 13:32:52','Tigan, tiganesc, tiganeasca, gipsy, Roma, gitan, poze cu tigani, gipsy pictures','72. Tigan urat, tigan urat, tigan urat, tigan urat, tigan urat, tigan urat, tigan urat, tigan urat',0,'','inherit','open','open','','72-tigan-urat-tigan-urat-tigan-urat-tigan-urat-tigan-urat-tigan-urat-tigan-urat-tigan-urat','','','2007-03-22 15:32:52','2007-03-22 13:32:52','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/72-tigan-urat-tigan-urat-tigan-urat-tigan-urat-tigan-urat-tigan-urat-tigan-urat-tigan-urat.jpg',0,'post','image/jpeg',0),(259,1,'2007-03-22 15:33:21','2007-03-22 13:33:21','Tigan, tiganesc, tiganeasca, gipsy, Roma, gitan, poze cu tigani, gipsy pictures','73. Tigani fermentand departe de soare',0,'','inherit','open','open','','73-tigani-fermentand-departe-de-soare','','','2007-03-22 15:33:21','2007-03-22 13:33:21','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/73-tigani-fermentand-departe-de-soare.jpg',0,'post','image/jpeg',0),(260,1,'2007-03-22 15:33:45','2007-03-22 13:33:45','Tigan, tiganesc, tiganeasca, gipsy, Roma, gitan, poze cu tigani, gipsy pictures','74. Tigan clocind coniac',0,'','inherit','open','open','','74-tigan-clocind-coniac','','','2007-03-22 15:33:45','2007-03-22 13:33:45','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/74-tigan-clocind-coniac.jpg',0,'post','image/jpeg',0),(261,1,'2007-03-22 15:34:02','2007-03-22 13:34:02','Tigan, tiganesc, tiganeasca, gipsy, Roma, gitan, poze cu tigani, gipsy pictures','75. Epilog. Deshtiu mi-era ca pruna!',0,'','inherit','open','open','','75-epilog-deshtiu-mi-era-ca-pruna','','','2007-03-22 15:34:02','2007-03-22 13:34:02','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/75-epilog-deshtiu-mi-era-ca-pruna.jpg',0,'post','image/jpeg',0),(262,1,'2007-03-22 15:34:19','2007-03-22 13:34:19','Tigan, tiganesc, tiganeasca, gipsy, Roma, gitan, poze cu tigani, gipsy pictures','76. Mamaliga tiganeasca de final',0,'','inherit','open','open','','76-mamaliga-tiganeasca-de-final','','','2007-03-22 15:34:19','2007-03-22 13:34:19','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/76-mamaliga-tiganeasca-de-final.jpg',0,'post','image/jpeg',0),(263,1,'2007-03-22 15:35:01','2007-03-22 13:35:01','','24-imaginile-si-zambetul-zice-totul.jpg',0,'','inherit','open','open','','24-imaginile-si-zambetul-zice-totuljpg','','','2007-03-22 15:35:01','2007-03-22 13:35:01','',47,'http://www.groparu.ro/wp-content/uploads/2007/03/24-imaginile-si-zambetul-zice-totul.jpg',0,'post','image/jpeg',0),(264,1,'2007-03-22 21:53:22','2007-03-22 19:53:22','Hai sa emigram in <a href=\"http://www.comedica.ro/\" target=\"_blank\">Comedica</a>-haha...\r\n\r\nAm emigrat. Si am vazut, si am invatzat.\r\n\r\nCa sa intri  in tzara la Comedica trebe sa treci de o granitza cu vamesitze dragutze. Daca drumul spre iad e pavat cu bune intentii, drumul spre comedica e marginit de fete frumoase care distribuie pliante, ale caror fetze nu mi le mai amintesc finca 1. purtau minijupe; 2. aveau decoltee; 3. puhoiul in care inotam era prea puhoi si prea rapid; 4. eram cu prietena.\r\n\r\nSunt foarte surprinzÄƒtor de multi cei care incearcÄƒ sÄƒ intre Ã®n Å£arÄƒ la Comedica. Asa de multi, ca trebuie sa te inghesui. Partea nasoala e ca nu numai fete te inghesuie. Partea buna e ca nu te inghesuie pensionatele perverse din Ratuc.\r\n\r\nComedica are doi presedinti mai mult simultani decat concomitenti, care intra in si ies din scena pe rand. Presedinti sunt Iancu (ca in Avram Iancu Jianu) si Nicu (da, very funny, nu e nici Nicu de la ProTV si nici ala de facea armata la Sovata, se aude?). Tot ei sunt si tariceni fruntaÅŸi la ei in oraÅŸ.\r\n\r\nPentru Comedica nu ai nevoie de viza de reÅŸedinÅ£Äƒ. Dar e recomandabil sÄƒ vii supÄƒrat, ca sÄƒ Ã®Å£i treacÄƒ. Si sÄƒ ai de grijÄƒ sa nu vii prea deÅŸtept. AdicÄƒ se nu faci pe deÅŸteptu\' cand preÅŸedinÅ£ii vorbesc pe scenÄƒ. AÅ£i mai fost la teatru cÃ¢nd deÅŸtepÅ£i din salÄƒ se Ã®ngÃ¢nÄƒ cu oamenii depe scenÄƒ? Sigur cÄƒ da, doar sunteÅ£i Ã®n RomÃ¢nia. AÅ£i mai vÄƒzut cum deÅŸtepÅ£ii sunt ridiculizaÅ£i, anihilaÅ£i ÅŸi ÅŸterÅŸi de omul de pe scenÄƒ? Sigur cÄƒ da, doar suntem Ã®n RomÃ¢nia. Dar aÅ£i  mai vÄƒzut cum replicile anoste ale sÄƒlii sunt imediat culese, ca banuÅ£ii de pe fundul fÃ¢ntÃ¢nii de o cÄƒlugÄƒriÅ£Äƒ cu poalele suflecate, ÅŸi valorificate Ã®n replici de durut burta de rÃ¢s, dar fÄƒrÄƒ a insulta jignind auditoriul? DacÄƒ nu aÅ£i fost pÃ¢nÄƒ acum la Comedica, nu cred.\r\n\r\nDacÄƒ vreodatÄƒ am sÄƒ mÄƒ fac hoÅ£ de buzunare, am sÄƒ pÃ¢ndesc stand-up comediile Comedica precum doreÅŸte cÄƒprioara apÄƒ dulce de izvor. Pentru cÄƒ la ieÅŸirea din Å£ara Comedica turiÅŸtii nu mai au alt gÃ¢nd in minte decÃ¢t sÄƒ Ã®mpÄƒrtÄƒÅŸeascÄƒ unii cu alÅ£ii experienÅ£a revelatorie. Åži dacÄƒ vrei, le poÅ£i umbla prin buzunare ÅŸi le poÅ£i chiar fura ÅŸi prietenele, cÄƒ nu le mai pasÄƒ, finca prea bine s-au distrat.\r\n\r\nAcesta este un advertorial, dar nu ar fi dacÄƒ nu aÅŸ menÅ£iona ca Nicu, deÅŸi e profesor de matematicÄƒ, este disponibil acum ÅŸi Ã®n varianta zilnicÄƒ pe 94.5 Fm Ã®n fiecare dimineaÅ£Äƒ, la echipa de distracÅ£ie de pe <a href=\"www.radiotransilvania.eu\" target=\"_blank\">Radio Transilvania</a>. Iar acum voi fi dat Ã®n judecatÄƒ cÄƒ am folosit numele Comedica fÄƒrÄƒ licenÅ£Äƒ ÅŸi probabil voi fi amendat cu o bere. Ce nu ÅŸtIu ei Ã®nsÄƒ e cÄƒ - dacÄƒ va fi sÄƒ fie aÅŸa - berea va fi de post. De post de alcool, nu de post coit.','Comedica-ha-ha',0,'','publish','open','open','','comedica-ha-ha','','','2007-03-23 11:48:10','2007-03-23 09:48:10','',0,'http://www.groparu.ro/?p=264',0,'post','',0),(265,1,'2007-03-23 16:04:58','2007-03-23 14:04:58','<strong>La <a href=\"http://www.domnuleprimar.ro/index.php?module=sesdetail&amp;ids=14140\" target=\"_blank\">asta</a>...:</strong>\r\n\r\n<strong>18 Martie 2007, Un pensionar</strong>\r\nTUTUROR, CARE NU INCAP DE PENSIONARI PE MIJLOACELE DE TRANSPORT: Cei, care in frunte cu dl. primar au acordat pensionarilor gratuitatea de calatorie, au avut in vedere: - majoritatea pensionarilor nu au nici jumatatea pensiei de 10 mil. (suma stabilita probabil arbitrar) - din pensiile mici o buna parte se cheltuie pe medicamente - majoritatea pensionarilor sufera de diferite boli reumatice, ce face imposibila deplasarea pe jos pe distante mai mari -daca la ore de varf sunt si cativa pensionari in mijloacele de transport, ei probabil se duc la policlinici, spitale, etc. IN CONSECINTA SPER, CA DOMNUL PRIMAR BOC EMIL SA NU ASCULTE DE BAZACONIILE LUI GROPARU SI DE COMENTARIILE PLINE DE INVIDIE SI RAUTATE A CELORLALTI ! NU UITATI, SI VOUA VA VINE RANDUL ! DORESC, CA ATUNCI SA NU AVETI NEVOIE DE ABONAMENT GRATUIT !\r\n\r\n...am scris asta...:\r\n\r\nStimate domnule pensionar,\r\n\r\nAm si eu acasa doi pensonari. Reumatici, dar plimbareti, si nu pe autobuze. Si cu pensie mica. Si daca cititi cu atentie postarea mea, am spus in dulcele stil clasic ca \"Nu sunt pentru renuntarea la gratuitatea acordata pensionarilor\". Si sunt constient ca dl. Boc nu va renunta la gratuitate, pentru ca reprezetati un capital politic mult prea important pentru domnia sa; si - mai mult - deoarece o consider o masura oarecum binevenita in conditiile in care  pensiile celor care nu au fost militari, politisti sau procurori sunt infime.\r\n\r\nCe ma deranjeaza e ca (repet)\r\n1. NU SE SUPLIMENTEAZA NUMARUL DE AUTOBUZE, asta in conditiile in care la ore de varf imi balacesc narile in mirosurile intregului Manastur inghesuit in 3 trolee venite din sfert in sfert de ora, Manastur care nu vrea tot timpul sa consume mai mult de un metru cub de apa pe trimestru; si platim cele mai scumpe abonamente din Romania!\r\n2. Pensionarii care circula sunt cu precadere oameni vioi, guralivi, si care par a fi sanatosi ca un om de 40 de ani.\r\n3. Nu ma pot abtine sa nu observ o lipsa de disciplina bovina tipica acelor cozi la carne de pe vremea cand dumneavoastra aveati varsta mea. Nimeni nu va vrea locul, nimeni nu va vrea scaunul, nimeni nu vrea sa va imbranceasca. Credeti-ma pe cuvant.\r\n\r\nSper ca acum m-am facut mai bine inteles, domnule pensionar anonim. Si va doresc - sincer! - multa sanatate! Si o pensie care sa va ajute sa nu aveti nevoie de abonament gratuit. Semnat: Groparu, BAZACONITORUL.\r\n\r\n...dupa ce aparuse <a href=\"http://www.groparu.ro/?cat=10\" target=\"_blank\">asta</a>.','Da\' de ce tot eu ma simt vinovat?',0,'','publish','open','open','','da-de-ce-ma-simt-naspa','','','2007-03-23 16:10:25','2007-03-23 14:10:25','',0,'http://www.groparu.ro/?p=265',0,'post','',1),(266,1,'2007-03-24 19:45:24','2007-03-24 17:45:24','...ma gandeam la urmatoarele chestii:\r\n\r\nDaca Dumnezeu vroia sa avem putza mai mare sau mai mica, ne-o facea telescopica, sa ne-o putem ajusta in functie de locul umed, intunecos si mai mult sau mai putin strÃ¢mt a lu\' aia care ne duce acasÃ¢ cÃ¢nd suntem beÅ£i ÅŸi ne ceartÄƒ a doua zi. DeÅŸi dacÄƒ era telescopicÄƒ, atunci avea vÃ¢rful subÅ£ire. Oare cum e sÄƒ te fuÅ£i cand ai puÅ£a cu vÃ¢rfu\' subÅ£ire, retractil? Ce tare ar fi sa ai putza ca un bratz de robot! SÄƒ se Ã®nvartÄƒ si sa se contorsioneze pe-acol, prin adÃ¢ncimi. Oare cum dracu Petrom investeste mai mult decat are profit? ÃŽnsamnÄƒ cÄƒ eu cu Petrom avem ceva important Ã®n comun, cÄƒ ÅŸi io beau mai mult decÃ¢t caÅŸtig. Oare celalalt <em>alter ego</em> al meu is tot eu? Cica astia vor sa bage pastile in furajele vacilor, ca sa nu mai producÄƒ metan cÃ¢nd iÅŸi dau vÃ¢nturi, cÄƒ se mÄƒreÅŸte efectul de serÄƒ. DacÄƒ se mÄƒreÅŸte efectul de serÄƒ, Ã®nseamnÄƒ cÄƒ se micÅŸoreazÄƒ preÅ£ul porodicilor crescute la Codlea ÅŸi la DumbrÄƒveni? DacÄƒ la bucÄƒtÄƒrie mi-am pus blat, Ã®nseamnÄƒ cÄƒ sunt blatist? Oare e OK daca ar avea cineva numele Mircea Bea-conu? Futui, iar am ramas fara hartie igienica?','Cand stateam pe buda...',0,'','publish','open','open','','cand-stateam-pe-buda','','','2007-03-25 01:30:03','2007-03-24 23:30:03','',0,'http://www.groparu.ro/?p=266',0,'post','',0),(267,1,'2007-03-26 00:08:54','2007-03-25 22:08:54','<a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/normal_curse-cu-oi.jpg\" title=\"http://www.pozehaioase.ro/displayimage-search-0-0.html\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/normal_curse-cu-oi.jpg\" alt=\"http://www.pozehaioase.ro/displayimage-search-0-0.html\" height=\"301\" width=\"460\" /></a>\r\n\r\nSi nu ma refer la Clone DVD. Ma refer la nenii aia imbracati in ochelari si halat alb si care in filmele americane is inconjurati de blonde cu tzatze mari care is triple PhD in biochemistry si care urzesc in eprubete armate intregi de clone hranite prin tub de aspirator Phillips pentru un guvern secret al unei tari cu steagu\' cu dungi alb-rosii (ca dimanovistii) si stele, da nu d-alea evreiesti in 6 colturi, ci din alea sovietice, si nu-s rosii stelele, ci is albe pe fond albastru. Åži pÃ¢nÄƒ la urma Ã®i omoarÄƒ pe toti Van Damme.\r\n\r\nDeci: oamenii in halate albe (nu aia care vin tot timpu\' sa imi dea medicatia  si sa ma intrebe daca mai aud vocile)  au reusit sa creeze/creeeze (niciodata nu am fost sigur, da\' cred ca e una din ele) <em><strong><a href=\"http://www.dailymail.co.uk/pages/live/articles/news/news.html?in_article_id=444436&amp;in_page_id=1770&amp;ito=newsnow\">o oaie  care este 15% umanÄƒ</a>. </strong></em>Dap! Da. CicÄƒ oile astea clonate cu umanitate vor fi folosite pentru transplant de ficaÅ£i (ÅŸi creieri, sper io) la unii oameni.\r\n\r\nDe amu,  stimaÅ£i coplanetari ÅŸi coplanetare, asteptaÅ£i-va ca viatza noastrÄƒ sÄƒ evolueze in bine, ca doarÄƒ Ã®n rÄƒu nu are cum, cÄƒ ar dispÄƒrea pleonasmu\'.  Pentru ca dupÄƒ ce oile astea cu IQ de maimutze bipede ÅŸi chiar mai mare vor Ã®ncepe sÄƒ Ã®ÅŸi facÄƒ veacul printre noi, stand la coada la bancomate si votand cu noi schimbarile, vom avea parte de semeni cu 15% mai umani. Veti fi inghesuiti cu 15% mai putin in  autobuze, iar guvernantii vor fi cu 15% mai putin berbeci ÅŸi vor fura cu pana la 15% mai putin.\r\n\r\nVeti deveni cu 15% mai canibali cand papati mieluÅ£ de Paste, ÅŸi veÅ£i avea cu 15% mai multe sanse sÄƒ scrieÅ£i \"ve-Å£i\". Or sa va placa filmele lui Quentin Tarantino cu 15% mai mult. Veti da cu 15% mai puÅ£inÄƒ ÅŸpagÄƒ la doftori ÅŸi la politai. Copiii vostri vor face  cu 15% mai putine meditatii. O sa va fie cu 15% mai usor sa tineti post, iar lupii or sÄƒ vÄƒ manance cu 15% mai cu scarba pe cei 99% dintre noi care fumam si curvim sau preacurvim, sai bem ca spartii.\r\n\r\nCiobanilor, veti reedita lagÄƒrele de concentrare cand veÅ£i duce la abator o turmÄƒ cu 15% mai umanÄƒ, ÅŸi poate vreo mioriÅ£Äƒ o sÄƒ vÄƒ ÅŸi vorbeascÄƒ dacÄƒ simte nevoia: \"Daca mai stai in crÃ¢ÅŸme pÃ¢nÄƒ la ora 3 dimineatza mÄƒ duc la mama!\" Probabil ca productia de lÃ¢nÄƒ, lapte ÅŸi carne de oaie se va muta in India si China, unde oile lor dau randament cu 60% mai mare mÃ¢ncÃ¢nd  numai patru linguritze de iarbÄƒ pe zi, ÅŸi vor si accepta sÄƒ locuiascÄƒ Ã®n saivane care seamÄƒnÄƒ cu MÄƒnÄƒÅŸturul. Vom fi mai puÅ£ine oi care vom juca la Loto; ÅŸi vom asculta cu 15% mai puÅ£ine manele.\r\n\r\nO sÄƒ ne intereseze cu 15% mai putin cu cine are Steaua meci, si de ce retrogradeazÄƒ Rapidu. Åži ne vom uita cu 15% mai puÅ£in la ProTV ÅŸi Antena3,  la Iri ÅŸi Moni, la emisiunile cu Pepe sau DanuÅ£ SRL. Åži ne vom da seama cÄƒ toate alianÅ£ele ÅŸi partidele cu nume care se terminÄƒ Ã®n SD ne servesc bomboane agricole. Si vom rumega mai mult Ã®nainte de a merge la urne. Åži probabil cÄƒ ne vor viola ele ciobanii, ÅŸi Ã®i vor face pe cÃ¢inii ciobÄƒneÅŸti sÄƒ stea ei ordonaÅ£i Ã®n pluton ca sÄƒ fie mulÅŸi.\r\n\r\nCe mai,  Ã®s convins cÄƒ Ã®ntr-o bunÄƒ zi oile astea mai deÅŸtepte ca o grÄƒmadÄƒ dintre semenii voÅŸtri se vor apuca sÄƒ ne cloneze ele pe noi.','Clonistii or facut-o de oaie',0,'','publish','open','open','','clonistii-or-facut-o-de-oaie','','','2007-03-26 08:48:15','2007-03-26 06:48:15','',0,'http://www.groparu.ro/?p=267',0,'post','',3),(268,1,'2007-03-26 00:08:24','2007-03-25 22:08:24','','http://www.pozehaioase.ro/displayimage-search-0-0.html',0,'','inherit','open','open','','httpwwwpozehaioaserodisplayimage-search-0-0html','','','2007-03-26 00:08:24','2007-03-25 22:08:24','',-1174844189,'http://www.groparu.ro/wp-content/uploads/2007/03/normal_curse-cu-oi.jpg',0,'post','image/jpeg',0),(269,1,'2007-03-26 01:18:20','2007-03-25 23:18:20','','Money Channel',0,'','inherit','open','open','','money-channel','','','2007-03-26 01:18:20','2007-03-25 23:18:20','',270,'http://www.groparu.ro/wp-content/uploads/2007/03/44-2007-03-22_025238.jpg',0,'post','image/jpeg',0),(270,1,'2007-03-26 01:18:54','2007-03-25 23:18:54','Â <a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/44-2007-03-22_025238.jpg\" title=\"Money Channel\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/44-2007-03-22_025238.jpg\" alt=\"Money Channel\" height=\"360\" width=\"449\" /></a>\r\n\r\n...pe nenea asta, de arata asa jumulit?','Oare cat de tare l-or paruit sefii...',0,'','publish','open','open','','oare-cat-de-tare-l-or-paruit-sefii','','','2007-03-26 01:18:54','2007-03-25 23:18:54','',0,'http://www.groparu.ro/?p=270',0,'post','',1),(271,1,'2007-03-26 18:33:59','2007-03-26 16:33:59','<a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/bad-day.jpg\" title=\"bad-day.jpg\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/bad-day.jpg\" alt=\"bad-day.jpg\" /></a>\r\n\r\n<strong>1. UPC? De ce???</strong>\r\n\r\nIo n-am nimica cu tine, bÄƒ UPC, da\' m-o pus Groparu\'. Serios. Z\'ce cÄƒ cÃ¢nd s-o abonat v-o zis expre\' cÄƒ ii trebe Discoveriurile tÄƒtie, fÄƒrÄƒ Civilisations, cÄƒ Äƒla e pentru gay, ÅŸi voi i le-aÅ£i dat prin gurÄƒ - adicÄƒ DELOC. Åži Äƒsta e si bou d-Äƒla ardelenesc, care stÄƒ ÅŸi rabdÄƒ cÃ¢te-o lunÄƒ Ã®ntreagÄƒ, ÅŸi-apÄƒi numa\' ce ii sar mucii dintr-o datÄƒ de ÅŸi trÃ¢nteÅŸte cu ei de podea de omoarÄƒ insectele cu ei.\r\n\r\nSi nu-i numa\' asta. Mai Ã®i cÄƒ pune Groparu azi mana pe telefon si suna la voi, la call center, sÄƒ afle cÄƒ de ce nu i-aÅ£i pus discoveriurile, cÄƒ doarÄƒ d-aia ÅŸi-o bagat cablu-n gaurÄƒ. Si in loc de voce din aia de nubirÄƒ de la celÄƒlalt fir, i-aÅ£i rÄƒspuns, mÄƒ, cu o voce d-aia mÄƒ de foarfecÄƒ ruginitÄƒ. Åži cÃ¢nd vÄƒ zice ce problemÄƒ are, ÅŸtii ce o zis vocea?\r\n\r\n<em>\"<strong>ApÄƒi io nu ÅŸtiu ce i-aÅ£i spus colegei mele</strong>, cÄƒ aici nu figuraÅ£i cu cerere!\"</em>\r\n\r\nBÄƒ, Äƒsta ÅŸtii cÄƒ e cam nesimÅ£it ÅŸi nu se prea enerveazÄƒ el, mÄƒ, da\' aÅŸa l-aÅ£i zÄƒhÄƒtuit, mÄƒ, cÄƒ  o crezut cÄƒ Ã®nghite receptoru! ÃŽn secunda aia pun pariu cÄƒ nu o mai vÄƒzut el femei dezbrÄƒcate de cÃ¢t roÅŸu vedea Ã®n faÅ£a ochilor. Åži-o cerut scuze (era vina lui, clar!) ÅŸi s-o cÄƒrat la voi la sediu - ca cicÄƒ din telefon nu se poate rezolva, cÄƒ numa din Ungaria Ã®nspre vest e secolu\' 21! - sÄƒ Ã®ÅŸi puie omu\' canalele. Åži acolo i-aÅ£i dat, mÄƒ BOILOR, un decodor vechi, mÄƒ, vechi din 1984, mÄƒÄƒÄƒ, pe care cu 6 minute Ã®nainte o damÄƒ bine Ã®l preda cÄƒ era nemultumitÄƒ de el. Åži cÃ¢nd o Ã®nceput Groparu sÄƒ comenteze, <strong><em>ÅŸtiind ce le zice la tantile de la UPC</em></strong>, madama aia o zis cÄƒ nu Ã®i dÄƒ decodor nou. CÄƒ nu are de unde. De unde sÄƒ-i dea, dacÄƒ nu are de unde? Ha? Zi tu! Åži sÄƒ nu vÄƒ puie dreq sÄƒ renunÅ£aÅ£i la abonamnt mai RPD, cÄƒ plÄƒtiÅ£i de vÄƒ iese prin nas. Unde puteÅ£i face reclamaÅ£ie, cÄƒ pe site nu merge ÅŸi la call center is dobitoci? NicÄƒieri. UrmÄƒtorul, vÄƒ rog!\r\n\r\n<strong>2. MobSexpert </strong>\r\n\r\nDe la ÄƒÅŸtia o rezervat amu vreo 5 sÄƒptÄƒmÃ¢ni o canapea. Care vine Ã®n o sÄƒptÄƒmÃ¢nÄƒ, mÃ¢nca-Å£i-aÅŸ, maxim 10 zile. Care trec fÄƒrÄƒ sÄƒ mai zicÄƒ nimeni nimic. Åži trec ÅŸi mai multe, fÄƒrÄƒ sÄƒ zicÄƒ nimeni nimic, numa Groparu, cÃ¢nd se ruga noaptea, mai strecura cÃ¢te un \"...ÅŸi adu-i, Doamne, canapeaua robului tau nevrednic Ã®nainte de alegerile parlamentare din 2016!\" Si cum pÃ¢nÄƒ ÅŸi gropile ÅŸi rÄƒbdarea Groparului au un fund, Groparu ÅŸi-a cumpÄƒrat de la Staer ceva colÅ£ar, care tre sÄƒ-i vie sÄƒptÄƒmÃ¢na asta. Dar cine-mi sunÄƒ la ora 13:00 azi, sÄƒ-l anunÅ£e cÄƒ i-o venit canapeaua? Un mic mobsexpert, care mai era ÅŸi Ã®ncÃ¢ntat nevoie mare. Åži atunci Groparu o zis \"DouÄƒ secunde, vÄƒ rog!\", ÅŸi-o slobozit gura ÅŸi o Ã®nceput:\r\n\r\n- \"Stimate domn, CÃ‚ND v-a zis Groparu cÄƒ are nevoie de canapea? Aud? Amu-s 5 sÄƒptÄƒmÃ¢ni! AÅŸa-i? Dom\'ne, da\' cÃ¢t crezi tu cÄƒ mÄƒ pot io fute pe jos, cÄƒ n-am canapea? Ha??? CÃ¢t? ÃŽÅ£i zic io: puÅ£in! Åži deja mÄƒ fut aÅŸa de vreo 4 luni, mÄƒ, 4 luni! Åži dacÄƒ nu pot sÄƒ mÄƒ fut cumsecade, devin stresat ÅŸi cedez la Äƒia de la UPC. ÃŽÅ£i pare rÄƒu? Mie nu. Serios. Kiar nu. VÄƒ doresc o zi bunÄƒ, cu renunÅ£Äƒri la taxa de Ã®nmatriculare la maÅŸini second.\r\n\r\n<strong>3. NumÄƒrul de telefon </strong>\r\n\r\nTocma\' cÃ¢nd Ã®mi era acru dintele Äƒla care se Ã®ncalecÄƒ peste molari de ziua asta, mÄƒ sunÄƒ 0314126758 ÅŸi dupÄƒ ce Ã®ÅŸi dÄƒ seama cÄƒ nu io Ã®s Äƒla pe care Ã®l cautÄƒ, Ã®mi Ã®nchide pur ÅŸi simplu telefonu\' Ã®n nas! Åži am Ã®ncercat de 16 ori sÄƒ Ã®i sun Ã®napoi ÅŸi sÄƒ le zic una de dulce. Dar nu rÄƒspunde nimeni. Åži asta mÄƒ cam inerveazÄƒ.\r\n\r\nPS: Nu v-am zis nimic de shafu care m-o bestelit - pe drept! recunosc, de aia cu kartingu\' de la care vrem sa inchiriem sala si nu stiu sa faca afaceri decat pe win-lose (tu esti pe lose), de telecomanda de la decodoru\' de la UPC, de somnu din glandÄƒ de azi si de contu de card care nu se mai umple odata!','O zi fecalÄƒ',0,'','publish','open','open','','o-zi-fecala','','','2007-03-26 19:05:55','2007-03-26 17:05:55','',0,'http://www.groparu.ro/?p=271',0,'post','',0),(272,1,'2007-03-26 18:26:16','2007-03-26 16:26:16','','bad-day.jpg',0,'','inherit','open','open','','bad-dayjpg','','','2007-03-26 18:26:16','2007-03-26 16:26:16','',-1174923006,'http://www.groparu.ro/wp-content/uploads/2007/03/bad-day.jpg',0,'post','image/jpeg',0),(273,1,'2007-03-26 19:17:01','2007-03-26 17:17:01','','hotnews-26032007.JPG',0,'','inherit','open','open','','hotnews-26032007jpg','','','2007-03-26 19:17:01','2007-03-26 17:17:01','',274,'http://www.groparu.ro/wp-content/uploads/2007/03/hotnews-26032007.JPG',0,'post','image/jpeg',0),(274,1,'2007-03-26 19:20:59','2007-03-26 17:20:59','<a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/hotnews-26032007.JPG\" title=\"hotnews-26032007.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/hotnews-26032007.JPG\" alt=\"hotnews-26032007.JPG\" /></a>\r\n\r\nPentru a vedea poza in toata splendoarea ei, click mai jos:\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/hotnews-26032007-large.JPG\" title=\"hotnews-26032007-large.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/hotnews-26032007-large.thumbnail.JPG\" alt=\"hotnews-26032007-large.JPG\" /></a>','Imaginile zice totul',0,'','publish','open','open','','imaginile-zice-totul-2','','','2007-03-26 19:45:41','2007-03-26 17:45:41','',0,'http://www.groparu.ro/?p=274',0,'post','',0),(275,1,'2007-03-26 19:30:52','2007-03-26 17:30:52','','hotnews-26032007.JPG',0,'','inherit','open','open','','hotnews-26032007jpg-2','','','2007-03-26 19:30:52','2007-03-26 17:30:52','',274,'http://www.groparu.ro/wp-content/uploads/2007/03/hotnews-26032007.JPG',0,'post','image/jpeg',0),(276,1,'2007-03-26 19:33:19','2007-03-26 17:33:19','','hotnews-26032007.JPG',0,'','inherit','open','open','','hotnews-26032007jpg-3','','','2007-03-26 19:33:19','2007-03-26 17:33:19','',274,'http://www.groparu.ro/wp-content/uploads/2007/03/hotnews-26032007.JPG',0,'post','image/jpeg',0),(277,1,'2007-03-26 19:39:34','2007-03-26 17:39:34','','hotnews-26032007.JPG',0,'','inherit','open','open','','hotnews-26032007jpg-4','','','2007-03-26 19:39:34','2007-03-26 17:39:34','',274,'http://www.groparu.ro/wp-content/uploads/2007/03/hotnews-26032007.JPG',0,'post','image/jpeg',0),(278,1,'2007-03-26 19:41:13','2007-03-26 17:41:13','','hotnews-26032007.JPG',0,'','inherit','open','open','','hotnews-26032007jpg-5','','','2007-03-26 19:41:13','2007-03-26 17:41:13','',274,'http://www.groparu.ro/wp-content/uploads/2007/03/hotnews-26032007.JPG',0,'post','image/jpeg',0),(279,1,'2007-03-26 19:44:21','2007-03-26 17:44:21','','hotnews-26032007-large.JPG',0,'','inherit','open','open','','hotnews-26032007-largejpg','','','2007-03-26 19:44:21','2007-03-26 17:44:21','',274,'http://www.groparu.ro/wp-content/uploads/2007/03/hotnews-26032007-large.JPG',0,'post','image/jpeg',0),(280,1,'2007-03-27 16:18:43','2007-03-27 14:18:43','<a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/prosop-pe-calorifer.JPG\" title=\"prosop-pe-calorifer.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/prosop-pe-calorifer.JPG\" alt=\"prosop-pe-calorifer.JPG\" height=\"330\" width=\"436\" /></a>\r\n\r\nSi nu oricui.\r\n\r\nAzi dimineatza, impins de un elan patriotic mai putin, snob mai mult si certamente atras de grasutele care vin dimineatza la bazin sa isi etaleze bunastarea, m-am hotarat sa merg la piscina olimpica din Cluj. Dupa cateva ture de balaceala si glume proaste la care numa io am rÃ¢s, am venit la firma, unde aveam de predat un document. Stress, etc.\r\n\r\nLa mine la firma, kiar in spatele meu, este o camera de conferintze. Acolo se inghesuie manajerii cand se plictisesc si mai pun de-o ÅŸedinÅ£Äƒ dupa care ne tot scade salariu\'.\r\n\r\nAzi nu era sedinta.\r\n\r\nFinca nu puteam pastra slipii si prosopu\' meu second jilavi in rucsac, mi i-am intins in toata splendoarea lor pe caloriferu\' din dotarea salii de conferintze: una bucata slip cu manecutze (cumparati din Bulgaria, made in China, 60 mii/buc) si una bucata prosop vargat, nu exagerat de nou si nici din cale-afara de curat. Si acolo or stat pana cand ceva manajer strain o venit pe la noi cu o gasca de lupi tineri, si ei straini. Si toti s-or dus cu manajeru\' strain atza-n  sala de conferintze din spatele meu, unde se etalau la loc de mare cinste slipii mei si prosopu vargat - repet, nu prea curat si nici exagerat de nou. Si acolo or stat vreo doua ore, si or tot negociat. Si cand or iesit zambeau toti sase, fericiti.\r\n\r\nFinca is sigur ca slipii si prosopu\' meu vargat (nu exagerat de nou si nici din cale-afara de curat) is de bun augur si aduc noroc (pe probatea!), nu mai am acum decat un dubiu: cand merg sa iau bilet la loterie, sa ma duc imbracat in slip si cu prosopu\' in cap, sau si cu prosopu\' si cu slipii in cap? Sau mai bine sa smulg de-a dreptu\' caloriferu\' asa cum e si sa il bat pana imi spune 6 numere norocoase, cand e report mare?\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/27_03_07_1726.jpg\" title=\"27_03_07_1726.jpg\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/27_03_07_1726.thumbnail.jpg\" alt=\"27_03_07_1726.jpg\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/27_03_07_1727.jpg\" title=\"27_03_07_1727.jpg\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/27_03_07_1727.thumbnail.jpg\" alt=\"27_03_07_1727.jpg\" /></a>','Groparu o aruncat prosopu\'',0,'','publish','open','open','','groparu-o-aruncat-prosopu','','','2007-03-27 17:10:28','2007-03-27 15:10:28','',0,'http://www.groparu.ro/?p=280',0,'post','',5),(281,1,'2007-03-27 16:16:17','2007-03-27 14:16:17','','prosop-pe-calorifer.JPG',0,'','inherit','open','open','','prosop-pe-caloriferjpg','','','2007-03-27 16:16:17','2007-03-27 14:16:17','',-1175003900,'http://www.groparu.ro/wp-content/uploads/2007/03/prosop-pe-calorifer.JPG',0,'post','image/jpeg',0),(282,1,'2007-03-27 17:09:59','2007-03-27 15:09:59','','27_03_07_1726.jpg',0,'','inherit','open','open','','27_03_07_1726jpg','','','2007-03-27 17:09:59','2007-03-27 15:09:59','',280,'http://www.groparu.ro/wp-content/uploads/2007/03/27_03_07_1726.jpg',0,'post','image/jpeg',0),(283,1,'2007-03-27 17:10:15','2007-03-27 15:10:15','','27_03_07_1727.jpg',0,'','inherit','open','open','','27_03_07_1727jpg','','','2007-03-27 17:10:15','2007-03-27 15:10:15','',280,'http://www.groparu.ro/wp-content/uploads/2007/03/27_03_07_1727.jpg',0,'post','image/jpeg',0),(284,1,'2007-03-28 22:12:29','2007-03-28 20:12:29','Da. Eram retardat.\r\n\r\nAveam retard la CCF. De 4 luni. FincÄƒ din decembrie nu mai dusesem revistele la Centre Culturel Francais. Din decembrie. Nu trebuia sÄƒ fiu un strateg vizionar ca sÄƒ-mi dau seama cÄƒ amenda pentru trei reviste (doua de modÄƒ ÅŸi una de decoraÅ£iuni interioare) era cam cÃ¢t datoria externa a Rusiei, plus programul spatial martian american - ce mai, aproape cÃ¢t salariu\' lu\' Esca. Eram sigur cÄƒ mÄƒ vor reÅ£ine ÅŸi Ã®mi vor extirpa un rinichi ca pedeapsÄƒ. AÅŸa cÄƒ mi-am loat rÄƒmas bun de la tastatura, monitor si ficusu ala in ghiveciu\' caruia scuip cojile de seminte. Si am plecat in pauza de masa cu Cindre - colegu, mÄƒ. HÃ¢tru. SÄƒ duc revistele.\r\n\r\nAm plecat cu aceleaÅŸi gÃ¢nduri cu care am plecat la vot Ã®n 2000, cÃ¢nd trebuia sÄƒ aleg Ã®ntre Corneliu V ÅŸi Iliescu. Convins cÄƒ voi fi violat cu mÄƒtura. CÄƒ voi fi uns cu miere la cur ÅŸi lÄƒsat lÃ¢nga un stol d-Äƒla de muÅŸte verzi. Åži ProTV-ul va fi de faÅ£Äƒ sÄƒ mÄƒ filmeze Ã®n timp bibliotecarii pun Cheeky Girls la maxim, sÄƒ nu se audÄƒ cum zbier. Åži cÄƒ Ã®mi vor face transplant de mÄƒduvÄƒ de la solamezi din Äƒia cu burta mare, ÅŸi apÄƒi mÄƒ aruncÄƒ Ã®ntr-un autobuz Ratuc plin de pensionari sÄƒ mÄƒ Ã®nghesuie, ÅŸi sÄƒ mÄƒ lase acolo pÃ¢nÄƒ mi se dezumflÄƒ burta.\r\n\r\nÅži cÄƒ mÄƒ Ã®mbracÄƒ Ã®n haine de femeie, mÄƒ boteazÄƒ Tatiana ÅŸi mÄƒ pun sÄƒ mÄƒ mÄƒrit cu Irinel. Åži sÄƒ mÄƒ pup cu Åžtefan BÄƒnicÄƒ Ã®n direct ÅŸi sÄƒ dansez cu Costi IoniÅ£Äƒ. Åži nu o sÄƒ mai am prieteni, cÄƒci nu o sÄƒ mai fie nimeni amic cu cineva care va fi pus sa Å£inÄƒ cu Noua DreaptÄƒ. Sau cu cineva care - Ã®n mod sigur - va fi fi pus sÄƒ doarmÄƒ Ã®ntr-un dormitor comun de militari Ã®n termen care au fost serviÅ£i cu o porÅ£ie zdravÄƒnÄƒ de ridichi negre (genul <em>Brassica rapa</em>, care induce flatulatii violente - <em>ventus</em>).\r\n\r\nMai citisem cÄƒ Äƒia cu retard la returnÄƒri Ã®ÅŸi pierd brusc optimismul cÃ¢nd sunt transportaÅ£i Ã®ntr-un portbagaj de Lada Ã®ntr-una din Å£Äƒrile fostei URSS, la ceas de noapte. Exagerez? CÃ¢nd aÅ£i vÄƒzut voi vreodatÄƒ o profÄƒ de francezÄƒ zdravÄƒnÄƒ la cap? (Ã®n afarÄƒ de alea care chiar sunt, bine-ntzÄƒles). AÅŸa cÄƒ eram sigur cÄƒ nu voi avea de-a face cu vreo Andree Raicu bibliotecarÄƒ. Plus cÄƒ Ã®n dimineaÅ£a aia ascultasem la horoscop ca dacÄƒ am Ã®ntÃ¢rziat cu revistele la bibliotecÄƒ aÅŸ face bine sÄƒ plec Ã®n Madagascar, sÄƒ nu mai folosesc cartea de credit ÅŸi sÄƒ nu Ã®ncerc sÄƒ contactez familia Ã®n nici un fel, mÄƒcar vreo 16 ani.\r\n\r\nDar cel mai tare mÄƒ inerva cÄƒ Cindre, colegu\', Å£inea morÅ£iÅŸ sÄƒ vie ÅŸi el la bibliotecÄƒ. Pen\' cÄƒ - zicea el - vroia musai sÄƒ le spunÄƒ la tantile alea cÄƒ el m-o prevenit cÄƒ nu e de joacÄƒ cu bibliotecile, mai ales franceze, ÅŸi cÄƒ nici nu citesc de fapt revistele, ci numa mÄƒ dau snob, ÅŸi cÄƒ le ÅŸi Ã®nÅŸel ca nesimÅ£itu, fincÄƒ am ÅŸi la BritiÅŸ Council abonament, ÅŸi cÄƒ odatÄƒ aÅŸ fi comentat cÄƒ CCF vine de la Centre Commerciel Francais, la cÃ¢t costÄƒ abonamentu\' pe lunÄƒ, ÅŸi cÄƒ odatÄƒ am de gÃ¢nd sÄƒ viu cu un <a href=\"http://fr.wikipedia.org/wiki/Voile_islamique_en_France\" target=\"_blank\">voal musulman</a> pe cap sÄƒ vÄƒd dacÄƒ Ã®mi interzic sÄƒ intru la ele-n bibliotecÄƒ, ca sÄƒ le pot da dupa aia Ã®n judecatÄƒ, ÅŸi cÄƒ de ce nu se face Andreea Raicu bibliotecarÄƒ?\r\n\r\nAÅŸa cÄƒ am intrat la tanti alea Ã®nÄƒuntru ÅŸi, smerit ca o fecioarÄƒ la patul conjugal, i-am spus, cu un nod gordian Ã®n gÃ¢Å£i:\r\n\r\n- MamÄƒ scumpÄƒ, sorÄƒ Ã®ntru credinÅ£Äƒ, ce mai: doamnÄƒ! DoamnÄƒ dragÄƒ, zic, io nu vreau sa fiu violat cu mÄƒtura, ÅŸi nu Ã®mi plac muÅŸtele verzi; cu atÃ¢t mai puÅ£in voalurile musulmance. De armatÄƒ (beÅŸinoasÄƒ sau nu) am fugit ca de orice femeie cumsecade din viaÅ£a mea, Ã®ncepÃ¢nd cu maicÄƒ-mea; iar Cheeky Girls sunt groteÅŸti. Rinichii mi-i vreau Ã®n duet, ca ÅŸi pÃ¢n-acuma, cÄƒ le-am promis cÄƒ-i Ã®nec cu bere cÃ¢nd se gatÄƒ postu Äƒsta; ÅŸi nu cÃ¢ÅŸtig nici cÃ¢t Esca pe minut. AÅŸa cÄƒ luaÅ£i-vÄƒ revistele pe care, da, nu am apucat sÄƒ le citesc, fincÄƒ le iau numa de snob, ÅŸi voalul musulman mi se pare Ã®ntr-adevÄƒr cea mai sexy Å£oalÄƒ fincÄƒ acoperÄƒ gura, doamnÄƒ, gura, dar luaÅ£i-le odatÄƒ, ÅŸi dacÄƒ totuÅŸi trebe sÄƒ mÄƒ auto-exilez Ã®n Madagascar, o voi face!\r\n\r\n- E bine, zice doamna. CÃ¢nd vÄƒ gÄƒsiÅ£i abonamentul sÄƒ Ã®mi spuneÅ£i sÄƒ vi-l schimb, cÄƒ asta e fÄƒcut pe adresa veche.','Retardo',0,'','publish','open','open','','retardo','','','2007-03-29 08:48:14','2007-03-29 06:48:14','',0,'http://www.groparu.ro/?p=284',0,'post','',0),(285,1,'2007-03-29 13:32:26','2007-03-29 11:32:26','<a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/antrax.jpg\" title=\"Blog romanesc Romanian blog\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/antrax.jpg\" alt=\"Blog romanesc Romanian blog\" height=\"406\" width=\"540\" /></a>\r\n\r\n<strong>Mi-am spart capul de trei ori</strong>\r\n\r\nPrima data ca nu am vrut sa fac pipi in olitza, si am fugit din bratele sora-mii care incerca sa stoarca pishu\' din mine pana m-am proptit cu bostanu\' in dunga de la pat. Sor-mea o lesinat. Urgente, pansament, asistente medicale care m-or pipait.\r\n\r\nA doa oara cand m-o lovit Elke (i.e., nume sasesc feminin) cu un picior de scaun sau cu sete in moalele tzestei; aveam 7 ani, si Elke o fugit in casa si nu o mai avut voie sa iasa afara 2 saptamani afara din cauza mea. Urgente, pansament, asistente medicale care m-or pipait.\r\n\r\nA treia oara am vazut o matza neagra de pe geam, si am facut skydiving in pat sa nu ma mai uit la ea, ca aduce ghinion, dar am alunecat pe cearshaf si m-am tamponat cu prostu\' tot in dunga de la pat. Bubuitura s-o auzit pana la etajul patru. Sange, apa rece. Aveam 14 ani, si as fi vrut sa ma pipaie neshte asistente mustacioase, dar nu m-o mai dus nimeni la spital.\r\n\r\n<strong>M-am lovit de bara</strong>\r\n\r\nNe jucam de-a Tarzan; io exploram granitele transsexualitatii zoofile in rolul lui Judy, maimutzica lu\' Tarzan. La un moment dat, Tarzan o trimis-o pe Judy pe cealalta liana sa aduca banane, dar lui Judy i-a alunecat espadrila chinezeasca si s-o lovit cu barbia de bara baobabului. Judy nu a putut vorbi 2 zile cum trebe, si a ramas si cu o cicatrice in forma de clitoris sub buza inferioara. Cand ma intreaba gajicile de unde o am, le zic ca e de la prima mea bataie de strada, si automat le arat si cicatricile de pe pumni (pe care, intre noi fie vorba, mi le-am facut cu plastic incins la 12 ani).\r\n\r\n<strong>Am dat foc la casa</strong>\r\n\r\nDar nu o ars decat perdeaua. Si un pic din masa.\r\n\r\n<strong>Tata e inginer</strong>\r\n\r\n...\r\n\r\n<strong>Soru-mea s-o maritat cu un neamtz\r\n</strong>\r\n\r\n!!!\r\n\r\n<strong>Am lucrat ca prof 2 ani</strong>\r\n\r\nVrei adrenalina, Gropare? Na adrenalina!\r\n\r\n<strong>Nu m-am spovedit decat o singura data</strong>\r\n\r\n...si si aia pe jumate. Ca dupa ce am tot raspuns cu \"Da!\" la intrebarile la nenea popa, mai trebuia sa mai raman sa iau nush ce impartashanie, da\' am plecat ca ma asteptau colegii de liceu la bere.\r\n\r\n<strong>Am supravietuit Cernobilului</strong>\r\n\r\n...dar nu fara sechele. Si acuma m-as mai juca o tura cu indienii.\r\n\r\n<strong>Fac ocazia frecvent </strong>\r\n\r\nIn 10 ani de facut ocazia, am urmatorul palmares: un dulau omorat de soferul TIR-ului la intrarea in Turda, oras european; 6 puncte la intrarea in Alba, acum 5 saptamani, acordate lu soferu\'; accident cu iesire in decor, avocat din Deva; o spaga de 100.000 lu\' Garcea acum un an pentru ca soferul ma luase la ocazie (\"transport de persoane fara licentza\");\r\n\r\n<strong>Am mancat tot felu</strong>\r\n\r\nIn studentie, am mancat caltabos lasat pe pervaz, care avea urme de ciuguleli.  De la ciori. Si ma ghidez dupa sloganul \"Nu exista mancare stricata!\"\r\n\r\n<strong>Beau orice</strong>\r\n\r\n...dar am fost refuzat in MISA ca am refuzat o halba de pishu rece, cu exact doua degete de spuma, finca nu era pipi de la bere, ci de la suc de morcovi si pastarnac. Dar uneori beau chiar si apa minerala!\r\n\r\nProbabil ca va urma.','I shouldn\'t be alive',0,'','publish','open','open','','i-shouldnt-be-alive','','','2007-03-29 15:50:34','2007-03-29 13:50:34','',0,'http://www.groparu.ro/?p=285',0,'post','',6),(286,1,'2007-03-29 12:57:26','2007-03-29 10:57:26','','antrax.jpg',0,'','inherit','open','open','','antraxjpg','','','2007-03-29 12:57:26','2007-03-29 10:57:26','',285,'http://www.groparu.ro/wp-content/uploads/2007/03/antrax.jpg',0,'post','image/jpeg',0),(287,1,'2007-03-29 12:58:36','2007-03-29 10:58:36','Blog romanesc Romanian blog','Blog romanesc Romanian blog',0,'','inherit','open','open','','blog-romanesc-romanian-blog','','','2007-03-29 12:58:36','2007-03-29 10:58:36','',285,'http://www.groparu.ro/wp-content/uploads/2007/03/antrax.jpg',0,'post','image/jpeg',0),(288,1,'2007-03-29 16:28:10','2007-03-29 14:28:10','<a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/stalagmita-din-tavan.jpg\" title=\"stalagmita-din-tavan.jpg\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/stalagmita-din-tavan.jpg\" alt=\"stalagmita-din-tavan.jpg\" /></a>\r\n\r\n- A (se) stalacti = <span class=\"def\"><em>(mÄƒ) stalactesc, </em>vb. IV. <strong>I. 1.</strong> refl.</span> A se tot pisha de la bere din 5 in 5 minute, de parcÄƒ vrei ca fiecare picÄƒturÄƒ de pipi sÄƒ Å£i se sedimenteze pe puÅ£Äƒ ÅŸi sÄƒ o facÄƒ sÄƒ creascÄƒ ÅŸi sÄƒ ajungi la mÄƒrimea stalactitelor din PeÅŸtera UrÅŸilor. Ex: \"<em>Nush ce pm era-n berea aia, cÄƒ atÃ¢ta ne-am mai stalactit...</em>\" Suporta diateza activa daca esti prea beat sa te pishi si te pisha altcineva: <em>\"O trebuit sÄƒ mÄƒ stalacteascÄƒ fetele, spuse Gregorian\". </em>\r\n\r\n- A (se) gropÄƒri = <span class=\"def\"><em>(mÄƒ) gropÄƒresc, </em>vb. IV. <strong>I. 1.</strong> tranz ÅŸi activ/reflexiv</span> Activitatea pe care o desfÄƒÅŸori Ã®nainte ca altceva mai important sÄƒ Å£i se Ã®ntÃ¢mple. Ex:  \"<em>ÃŽnainte de a lua palma, gropÄƒream prin autobuz. Pune ÅŸoferu\' o frÃ¢nÄƒ, mÃ¢nca-Å£i-aÅŸ, de fix Ã®n piepÅ£ii lu\' una am aterizat cu mÃ¢na dreaptÄƒ!</em>\"\r\n\r\n- seminÅ£ie = s.f., cÃ¢nd te apuci sÄƒ mÄƒnÃ¢nci seminÅ£e ÅŸi nu te mai poÅ£i opri pÃ¢nÄƒ nu Ã®Å£i putrezeÅŸte limba.\r\n\r\n- Speolog, -oagÄƒ = s.m., specialist Ã®n speologie, ramurÄƒ nouÄƒ a sportului Ã®n care participanÅ£ii se spalÄƒ sau fac duÅŸ zilnic. ÃŽn Å£ara noastrÄƒ sunt mai mulÅ£i jucÄƒtori de golf decÃ¢t speologi.\r\n\r\n- A (se) berÄƒri = <span class=\"def\"><em>(mÄƒ) berÄƒresc, </em>vb. IV. <strong>I. 1.</strong> tranz ÅŸi activ/reflexiv</span> - activitatea desfÄƒÅŸuratÄƒ Ã®nainte de a te stalacti.','Cuvinte nouÄƒ Ã®n limba romÃ¢nÄƒ',0,'','publish','open','open','','cuvinte-noua-in-limba-romana','','','2007-03-30 10:08:41','2007-03-30 08:08:41','',0,'http://www.groparu.ro/?p=288',0,'post','',4),(289,2,'2007-03-30 10:08:23','2007-03-30 08:08:23','','stalagmita-din-tavan.jpg',0,'','inherit','open','open','','stalagmita-din-tavanjpg','','','2007-03-30 10:08:23','2007-03-30 08:08:23','',288,'http://www.groparu.ro/wp-content/uploads/2007/03/stalagmita-din-tavan.jpg',0,'post','image/jpeg',0),(290,1,'2007-03-31 02:00:06','2007-03-31 00:00:06','...care nu era umed, ÅŸtiu, ÅŸi io m-am mirat. Åži care nu era despre kirghize care fÄƒceau baie goale Ã®n copcÄƒ de Oceanul Arctic GÄƒeÅŸti. Åži nu era nici visul Äƒla al meu, mai vechi, sÄƒ poÅ£i sÄƒ te fuÅ£i, sÄƒ pescuieÅŸti ÅŸi sÄƒ te ÅŸi joci pe calculator simultan.\r\n\r\nNu, Äƒsta era un vis inocent avut la vÃ¢rsta de 12 ani. Da, la vÃ¢rsta asta alÅ£ii au copii ca mine, ÅŸtiu. Eu numa atÃ¢ta ÅŸtiam - cÄƒ trebuia sÄƒ mÄƒ scol la 7 fara 20, sÄƒ adorm la loc, cÄƒ la 7 si 10 venea sor-mea de la tura de noapte de la spital, ÅŸi ma trezea, ÅŸi pÄƒpam Ã®mpreuna, ÅŸi apai ea se punea sÄƒ doarmÄƒ ÅŸi eu plecam la ÅŸcoalÄƒ, sÄƒ mai vÄƒd cu cat le-o mai crescut la colege sÃ¢niÅŸorii, Doamne, cum se mai Ã¢nfoiau de la o zi la alta, ca aluatu\' de cozonac! Unele colege aveau ÅŸi mustati, aia Å£in minte, da\' le-or pierdut mai tÃ¢rziu, cÃ¢nd li s-o gÄƒtat pubertatea, pe la 28 de ani. Cel mai tare era cÄƒ la vÃ¢rsta aia nu te considera nimeni pedofil.\r\n\r\nLasÃ¢nd la o parte pornetele, Ã®n dimineatza aia kiar nu aveam chef sÄƒ mÄƒ trezesc, darmite sÄƒ mÄƒ scol din pat, darmite sa ma duc la ÅŸcoalÄƒ, mai ales ca nu imi dadeam seama care era scopu\' mersului la ÅŸcoala. La ÅŸcoalÄƒ trebuia sÄƒ merg din doua motive: 1) puteam sÄƒ mÄƒ uit la tzatze noi pe gratis; 2) dacÄƒ Ã®nvÄƒÅ£am sÄƒ fac ceva bun cu viaÅ£a mea, mai tarziu aveam suficienti bani sÄƒ mÄƒ uit la tzatze noi cat poftesc. Dar degeaba am tot mers, la ÅŸcoalÄƒ (ÅŸi liceu ÅŸi facultate ÅŸi mastere) mÄƒ interesau indienii de plastic ÅŸi gumele Turbo, nu tzatzele colegelor, si mai tarziu tot nu mi-am permis sa am suficienti bani cat numa sa stau ziulica intreaga sa ma holbesc la balcuane.\r\n\r\nCe o fost cel mai cool o fost urmatorul episod: sunÄƒ ceasu\', 7 fara 20, Ã®l opresc, ÅŸi incepe visu\'. Visez cÄƒ mÄƒ rÄƒdic din pat, casc, mÄƒ Ã®ntind, trag jaluzelele. Bag deshtele-n nas, fac curaÅ£enie Ã®nÄƒuntru.  MÄƒ scarpin la shezutÄƒ, scot kilotii dintre buci, casc iarÄƒ, termin cÄƒscatu\' cu un oftat. ÃŽncerc sÄƒ fac o jumate de flotare, mÄƒ rÄƒzgÃ¢ndeshte pishu. MÄƒ duc la WC-ul de serviciu, cÄƒ masculii de la mine din familie numa acolo aveau voie sÄƒ se slobozascÄƒ. Si visez io asha cum, Ã®n timp ce mÄƒ rÄƒzemam de pÄƒrete ÅŸi pishu - niagarÃ¢ndu-se vesel - susura o rapsodie, vÄƒd un ziar lÃ¢nga budÄƒ, cÄƒ io mai citesc Formula As cÃ¢nd scot cÄƒcatu\' din mine. Si pun labutza pe ziar, ÅŸi in ziar scrie, <em><u></u>nota bene</em>, cÄƒ CINE O FOST LA CULES DE CIRESI ARE VOIE SA INTARZIE LA PRIMA ORA.\r\n\r\nEu, de regula, nu am nevoie de multe imbolduri pentru a lua decizii finale - cum ar fi sÄƒ mÄƒ apuc  sÄƒ Å£in un blog cu o adresa de net aberantÄƒ si un subtitlu mincinos. AÅŸa cÄƒ am continuat sÄƒ visez ca m-am eliberadio de pishu, am scuturat furtunashu\', am aÅŸteptat ca cele trei ultime picÄƒturi sÄƒ ajungÄƒ - invariabil - Ã®n chiloti, ÅŸi m-am infipt drept intre asternuturi, ca o sonda intre placile tectonice permafrostice.\r\n\r\nAÅŸa ca, cÃ¢nd sor-mea o vint la 7 si 10 sÄƒ mÄƒ trezeascÄƒ, i-am replicat nonÅŸalant - tu, da\' mÄƒ leshi? ÃŽi zic la diriga cÄƒ am fo\' la cules de cireÅŸi, ÅŸi e OK, nu mÄƒ mai duc la prima orÄƒ. Åži nu te mai uita la mine cu ochii Äƒia dilataÅ£i de parca naÅŸti.\r\n\r\nAtat.','Am avut un vis...',0,'','publish','open','open','','am-avut-un-vis','','','2007-03-31 02:00:06','2007-03-31 00:00:06','',0,'http://www.groparu.ro/?p=290',0,'post','',2),(291,1,'2007-03-31 15:51:46','2007-03-31 13:51:46','Sfat pentru femeile alea care isi dezvelesc coapsele (noua, boilor de masculi, ne plac la nebunie, ca vedem pielea gainii, nu puloveru\' ei - oricat de grasune, sunculoase, celulitice sau durdulii sunt ele):\r\n\r\nCand va luati pe voi blugii aia cu talie joasa, si scoateti un pic linia chilotilor in afara ca sa depaseasca nivelul taliei blugilor la spate, plimbati-va palmele pe la spate. Daca in zona sacrala-lombara simtiti fire de par muuuulte, multe-multe-multe-multe, si negre, si cretze, si mai ales lungi, ori luati-va un body, ori luati in considerare cumpararea unei motocositoare de gradina.  Nu sunt foarte scumpe, si efectul e garantat.\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/untitled.JPG\" title=\"untitled.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/untitled.JPG\" alt=\"untitled.JPG\" /></a>','Sfat',0,'','publish','open','open','','sfat','','','2007-03-31 15:55:44','2007-03-31 13:55:44','',0,'http://www.groparu.ro/?p=291',0,'post','',1),(292,1,'2007-03-31 15:52:26','2007-03-31 13:52:26','','untitled.JPG',0,'','inherit','open','open','','untitledjpg','','','2007-03-31 15:52:26','2007-03-31 13:52:26','',291,'http://www.groparu.ro/wp-content/uploads/2007/03/untitled.JPG',0,'post','image/jpeg',0),(293,1,'2007-03-31 23:55:15','2007-03-31 21:55:15','<a href=\"http://www.groparu.ro/wp-content/uploads/2007/03/bere.JPG\" title=\"Blog romanesc Romanian blog chef\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/03/bere.JPG\" alt=\"Blog romanesc Romanian blog chef\" /></a>\r\n\r\nFirma la care lucrez are o lunga si sanatoasa traditie. O data pe luna, isi scoate inginerii la adapat prin crajme, si plateshte cam 80% din cat consuma. Pastorul cirezii este un tip pe care unii il cunosc sub numele Groparu. Care are grija (puii mei, il stiu pe tip cum ma stiu pe mine!) sa trimeata DE FIECARE DATA MAIL cand organizeaza chef, cu toate detaliile pe care trebuie sa le stie Ei. TOATE. Din cauza spatiului restrans, dati-mi voie sa va enumar doar cateva din intrebarile care mi se pun de cca 34 de ori pe luna, de aproape un an, in saptamana in care tinem cheful:\r\n\r\n- ba, care e faza cu cheful?\r\n- ba, care e faza cu cheful?\r\n- ba, care e faza cu cheful?\r\n- ba, care e faza cu cheful?\r\n- ba, care e faza cu cheful?\r\n- ba, care e faza cu cheful?\r\n- ba, care e faza cu cheful?\r\n- ba, care e faza cu cheful?\r\n- ba, care e faza cu cheful?\r\n- ba, care e faza cu cheful?\r\n- ba, care e faza cu cheful?\r\n- ba, care e faza cu cheful?\r\n- ba, care e faza cu cheful?\r\n- ba, care e faza cu cheful?\r\n- ba, care e faza cu cheful?\r\n- ba, care e faza cu cheful?\r\n- ba, care e faza cu cheful?\r\n- ba, care e faza cu cheful?\r\n- ba, care e faza cu cheful?\r\n- ba, care e faza cu cheful?\r\n- ba, care e faza cu cheful?\r\n- ba, care e faza cu cheful?\r\n- ba, care e faza cu cheful?\r\n- ba, care e faza cu cheful?\r\n- ba, care e faza cu cheful?\r\n- ba, care e faza cu cheful?\r\n- ba, care e faza cu cheful?\r\n- ba, care e faza cu cheful?\r\n- ba, care e faza cu cheful?\r\n- ba, care e faza cu cheful?\r\n- ba, care e faza cu cheful?\r\n- ba, care e faza cu cheful?\r\n- ba, care e faza cu cheful?\r\n- ba, care e faza cu cheful?\r\n- ba, care e faza cu cheful?\r\n- ba, care e faza cu cheful?\r\n- ba, care e faza cu cheful?\r\n- ba, care e faza cu cheful?\r\n- ba, care e faza cu cheful?\r\n- ba, care e faza cu cheful?\r\n- ba, care e faza cu cheful?\r\n- ba, care e faza cu cheful?\r\n- ba, care e faza cu cheful?\r\n- ba, care e faza cu cheful?\r\n- ba, care e faza cu cheful?\r\n- ba, care e faza cu cheful?\r\n- ba, care e faza cu cheful?\r\n- ba, care e faza cu cheful?\r\n- Unde e McDonald\'s Manastur?!?!?!?!?','Despre chefurile firmei',0,'','publish','open','open','','despre-chefurile-firmei','','','2007-03-31 23:55:15','2007-03-31 21:55:15','',0,'http://www.groparu.ro/?p=293',0,'post','',2),(294,1,'2007-03-31 23:48:06','2007-03-31 21:48:06','','bere.JPG',0,'','inherit','open','open','','berejpg','','','2007-03-31 23:48:06','2007-03-31 21:48:06','',-1175376023,'http://www.groparu.ro/wp-content/uploads/2007/03/bere.JPG',0,'post','image/jpeg',0),(295,1,'2007-03-31 23:50:10','2007-03-31 21:50:10','Blog romanesc Romanian blog chef','Blog romanesc Romanian blog chef',0,'','inherit','open','open','','blog-romanesc-romanian-blog-chef','','','2007-03-31 23:50:10','2007-03-31 21:50:10','',-1175376023,'http://www.groparu.ro/wp-content/uploads/2007/03/bere.JPG',0,'post','image/jpeg',0),(296,1,'2007-04-01 21:37:57','2007-04-01 19:37:57','Nu, nu finca m-am mai maturizat. Ci pentru ca anu asta o picat duminica. Pe cine sa prostesc, daca nu pe colegii mei de serviciu? Ca doara familia mea nu are nici o vina, si prietenii nici atat.\r\n\r\nOricum, am prins ceva cool anu\' asta pe Wikipedia:\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/04/1-aprilie.JPG\" title=\"Blog Romanesc Romanian Blog Www.Groparu.Ro\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/04/1-aprilie.JPG\" alt=\"Blog Romanesc Romanian Blog Www.Groparu.Ro\" /></a>\r\n\r\nSi pentru ca atunci cand mi-am transfera aberatiunile de pe Yahoo! 360 pe cea mai veche si penala tema de blog Wordpress am uitat ca desteptu\' sa transfer si blog entry-ul asta, o fac amu. Scuze clientilor mai vechi.\r\n\r\n<strong>In fiecare zi e 1 Aprilie</strong>\r\n\r\nNu prea ii inteleg pe oamenii care au nevoie de 1 aprilie ca sa faca o farsa.\r\n\r\nIn 2006 de 1 aprilie m-o palit strechea. Nush de ce. Le-am skimbat colegilor cablurile de la tastatura cu cele de la mouse, i-am lasat fara hartie igienica la toaleta, am pus sprayul de buda la bucatarie si pur universalu\' la buda, le-am skimbat scaunele intre ele, le-am dereglat monitoarele, am scos din priza cuptoru\' cu microunde, am rugat chelneritza de la Maimutza Plangatoare sa le aduca pranzul cu o goanga de plastic in supa, am venit mai repede din pauza de masa si le-am schimbat backgroundul la monitor cu un jpg cu inscriptia \"IS THIS JOB FOR ME???\", faze din astea. Nu eram multumit. Trebuia ceva MARE. MULT MAI MARE. O buzdugana.\r\n\r\nSi atunci, pe scena intra Silvan. Cum care Silvan? Beeeey, Silvan e numa unu\'! Trebe sa-l stiti pe Silvan, cantecaciu\', \"Johnny, Johnny a dat coltzu\'/A-nghitzit aseara glontzu\'...\" Silvan, no!\r\n\r\nSilvan. Ma suna si zice: Ba! zice. Hai sa facem o farsa. Ghiciti ce am zis? Da, ba, zic, gata! La cine te gandeshti? Ba, zice el, am, fii atent aci, am o shefa meseriasha, tinerica, dragutza, shefa teatrului, lucreaza si la Antena 1, deschisa, etc, etc. Hai sa ne prefacem ca vreai sa dai sponsorizare la teatru meu! Ba, zic, gata. Da-mi tu numa telefonul teatrului, si sun io si sa vedem ce iasa.\r\n\r\nprrrrrrrrr (suna). Alo? Zic. Teatrul? Da, zice o voce de 120 de kile. Buna ziua, zic, aaaa.... fac o pauza. Stati o secunda. Zic, uitati ce e, va sun de la Universal Corpse Decomposition Ltd., firma englezeasca, cum alfel? Am aici la mine pe birou o cerere de sponsorizare de la teatrul dvs... inaintata de un anume domn sau doamna Silvan, sau Silva... acum vreo 2 luni, zic. Mai e valabila? Da, zice, Silvan, cum sa nu, Silvan exista, e domn... Bon, zic, pai cum sa facem, zic... Uitati, eu va pot oferi 800 de lire sterline, zic, dar nu stiu cum sa facem...\r\n\r\nMi-o venit sa ma inec in propria voma cand am auzit-o: Aaaaa.... zice ea, pai banii aia ne trebuiau pentru deplasarea la Galati (?!?!?!) de acum doua luni, acum nu stiu daca mai trebuie... Doamna, zic eu coplesit de emotie, cu obrajii de culoarea lenjeriei inroshite, uitati... aaa... firma mea - dupa cum v-am zis, Universal Wet Chicks Ltd. - fiind englezeasca, cum alfel, isi incheie anul fiscal in aprilie. Eu plec in Pussyshter in Marea Britanie maine dimineata. Mai stau in firma pana la 3, astazi, asa ca va rog sa-mi comunicati urgent la numarul asta - dau nr meu de prepay, mai fac si io un bonus - daca aveti nevoie de banii astia, finca cand ma intorc din Pussyshter nu mai pot face alte sponsorizari decat la anu pe vremea asta... Capiche? Da, zice ea, las\' ca va sunam no. Don\'t call us, we\'ll call you. La revedere.\r\n\r\nTzushti la messenger si urlu: Ba dezlegare la peshte, zic, cine e mah portaru ala cu mustatza caruia nu-i traba 800 lire sterline? Ha??? Silvan: Ba, da\' de ce n-ai cerut cu derectoarea direct? Ba, zic, da aia-i inundata? Cum refuzi EUR 1,000? Taci, mah, zice, suna iara si cere-o pe directoare, ca-i acia la 2 pashi.\r\n\r\nIara pun mana pe telefon, si sun. Da, gajaie morsa, Teatrul. Buna ziua, tot eu sunt, zic, uitati ce va rog: dati-mi un fax pe numarul asta cu o cerere de sponsorizare, ca sa pot scoate din contabilitate banii. Dar musai, va rog, sa aiba numar de inregistrare, destinatia banilor, si <strong>semnatura directorului institutiei</strong>. Si asta cat de repede, doamna scumpa, pt ca timpul meu inseamna bani. Aha, zice ea. Vi-l trimitem luni sau marti, ca <em>doamna directoare nu e aici</em>. <em>Mincinoaso</em>, tusesc eu, <em>stiu ca e acolo!</em> Ma scuzati, am tusit, zic, doamna! Acum, daca vreti bani. Nu luni, nu poimarti. Daca nu primesc cererea intr-o ora, donez banii Miscarii pentru Eliberarea Piticilor de Gradina! Va doresc o zi buna, si-i inchid telefonu in nari.\r\n\r\nFug iara la messenger: ba, zic, tanti aia trebe pensionata pe caz de boala! Ba, zice asta, ma pish pe tastatura de ras cand o vad cat e de gÃ¢nsacÄƒ. Ba, zic, sterilizati-o cu azot lichid!!! Lasa, ba, zice, ca vb io direct cu derectoarea.\r\n\r\nStau 4 minute, si suna telefonul, prefixul care trabuia. Imi trag sufletul, si racnesc: MDEAAAAA!!! Alo, domnul Martinescu? Da, zic eu vocii suave. Poftiti. Cu cine am placerea? Stiti, sunt derectoarea teatrului. Am inteles ca firma dumneavoastra ne-ar putea oferi o sponsorizare? Pai da, zic eu, dar am inteles ca nu va mai trebuie. Ca erau pentru plecarea la Galatzi, si alte shele. Aaa, zice, e o neintelegere. Sigur ca ne trebuie banutii. Bun, zic, cum facem? Dati un fax la nr asta, zic, si va rog sa scrieti exact in ce scop aveti de gand sa folositi sponsorizarea, defalcat pana la ultimul penny. Si presto, zic, ca eu am avion maine dimineatza si mai am o groaza de facut. La revedere.\r\n\r\nMa duc la secretariat, si le zic la fete: daca vine vreun fax cu papushi gonflabile, e pt mine, zic. Nu puneti intrebari. Silvane, zic, cum e mah? Ba, zice, astea is pe fast forward. S-or apucat sa faca inventaru sa vada la ce la traba bani. Marfa de marfa, fratica! Tot teatru e supersonic amu. Ii mai las o ora si le spun. I-am incaltzat, mah. Suntem meseriashi.\r\n\r\nPS: De faza asta mi-am adus aminte pt ca vineri seara, cand urla munca in mine, intra Mitroa pe messenger si zice: ba, prietene (e clar, zic io, iar ii traba bani). Ba, zice, fa ba si mie o traducere a unei scrisori de intentie pentru o firma. Ba Nelu, ii zic io, da\' tu ai termenat engleza la Cluj, ce durerea mea vrei sa iti traduc io? Hai, ba, zice el, ca mi-i lene sa o traduc. Hai fa-o tu. Da-o. zic. Na-ti-o, zice. Bon. Si i-o traduc asa exemplar, cum stiu eu, fara sa uit sa introduc in mijlocu\' textului un \"But please don\'t forget that I am a real jackass, a dork and a moron who\'s just after your money and nothing else\". Si i-o trimit, si ii zic: Ba, zic, uita-te peste ea CU MAAAAARE ATENTIE, si vezi sa fie conforma cu originalu! Ai auzit? Poti conta pe mine, prietene, zice el. Zic: e clar. Se va uita peste ea cum m-am uitat io la eclipsa, cu un ochi prin discheta. Si dupa 4 zile, il intreb: ai trimis ba scrisoarea? Da, zice el. Te-ai uitat peste ea? Zice: Ba! Nu. N-am avut vreme, si mi-o fo\' lene. Da\', zice, nici nu o ajuns la firma aia, ca nu le mere la aia mailu. Ui, iti trimit si tie mailu\' care s-o intors, ca zice delivery error.\r\nSi stau si ma intreb: sa ii spun?\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/04/groparu-farsa-1-aprilie.jpg\" title=\"Blog Romanesc Romanian Blog Www.Groparu.Ro\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/04/groparu-farsa-1-aprilie.jpg\" alt=\"Blog Romanesc Romanian Blog Www.Groparu.Ro\" /></a>','De ce nu-mi place 1 Aprilie in 2007',0,'','publish','open','open','','de-ce-nu-mi-place-1-aprilie-in-2007','','','2007-04-01 21:37:57','2007-04-01 19:37:57','',0,'http://www.groparu.ro/?p=296',0,'post','',5),(297,1,'2007-04-01 21:25:17','2007-04-01 19:25:17','Blog Romanesc Romanian Blog Www.Groparu.Ro','Blog Romanesc Romanian Blog Www.Groparu.Ro',0,'','inherit','open','open','','blog-romanesc-romanian-blog-wwwgroparuro','','','2007-04-01 21:25:17','2007-04-01 19:25:17','',-1175454563,'http://www.groparu.ro/wp-content/uploads/2007/04/1-aprilie.JPG',0,'post','image/jpeg',0),(298,1,'2007-04-01 21:34:03','2007-04-01 19:34:03','Blog Romanesc Romanian Blog Www.Groparu.Ro','Blog Romanesc Romanian Blog Www.Groparu.Ro',0,'','inherit','open','open','','blog-romanesc-romanian-blog-wwwgroparuro-2','','','2007-04-01 21:34:03','2007-04-01 19:34:03','',-1175454563,'http://www.groparu.ro/wp-content/uploads/2007/04/groparu-farsa-1-aprilie.jpg',0,'post','image/jpeg',0),(299,1,'2007-04-01 21:36:14','2007-04-01 19:36:14','Blog Romanesc Romanian Blog Www.Groparu.Ro','Blog Romanesc Romanian Blog Www.Groparu.Ro',0,'','inherit','open','open','','blog-romanesc-romanian-blog-wwwgroparuro-3','','','2007-04-01 21:36:14','2007-04-01 19:36:14','',-1175454563,'http://www.groparu.ro/wp-content/uploads/2007/04/groparu-farsa-1-aprilie.jpg',0,'post','image/jpeg',0),(300,1,'2007-04-02 10:48:49','2007-04-02 08:48:49','Romanian blog Blog romanesc www.Groparu.ro','Romanian blog Blog romanesc www.Groparu.ro',0,'','inherit','open','open','','romanian-blog-blog-romanesc-wwwgroparuro','','','2007-04-02 10:48:49','2007-04-02 08:48:49','',301,'http://www.groparu.ro/wp-content/uploads/2007/04/futaye.JPG',0,'post','image/jpeg',0),(301,1,'2007-04-02 10:57:38','2007-04-02 08:57:38','Veste buna pentru amatorii de futaye pe bani buni. Oferta speciala de Pasti, (c) Spike:\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/04/futaye.JPG\" title=\"Romanian blog Blog romanesc www.Groparu.ro\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/04/futaye.JPG\" alt=\"Romanian blog Blog romanesc www.Groparu.ro\" /></a>','Un futaye ceva mai ieftin',0,'','publish','open','open','','un-futaye-ceva-mai-ieftin','','','2007-04-02 11:15:21','2007-04-02 09:15:21','',0,'http://www.groparu.ro/?p=301',0,'post','',0),(302,1,'2007-04-02 10:54:35','2007-04-02 08:54:35','Blog romanesc Romanian blog','Blog romanesc Romanian blog',0,'','inherit','open','open','','blog-romanesc-romanian-blog-2','','','2007-04-02 10:54:35','2007-04-02 08:54:35','',-1175503706,'http://www.groparu.ro/wp-content/uploads/2007/04/futaye.JPG',0,'post','image/jpeg',0),(304,1,'2007-04-02 22:44:19','2007-04-02 20:44:19','Mi-a sosit coltzarul. 14 milieoane, mancatz-ash, moca, mi-o zis tanti aia care vinde coltzare, are paru\' cretz si e apsolventa de Arte, da\' lucreaza ca vanzatoare. Si care pun pariu ca era mai culta ca mine cu 98.9% (ceea ce nici macar nu mai e o chestie iesita din comun). Si care nu putea lucra ca femeie de serviciu ca nu isi terminase inca MBA-ul.\r\n\r\nColtzaru o vinit, da nu m-or sunat ca o sosit. Asa ca o trebuit sa imi car batranetile pana sus in Zorilor sa ii intreb ca de ce nu m-or sunat ca o venit? (puteam sa ii si sun sa ii intreb ca de ce nu m-or sunat si de ce trebuie sa sun eu, da\' nu vroiam sa sun, vroiam sa ii confrunt, ca de cateva zile m-am facut mai al dracului, zise Zdreantza-n gandul lui - ce tare suna!)\r\n\r\nCand o vinit acasica coltzaru\', o vinit - normal - cu vreo 40 minute intarziere, ca deja faceam ca Columb incercand sa obtin de la colegii care trebuiau sa ma ajute la carat inca trei zile de rabdare, si dupa aia ne intoarcem la firma sigur.\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/04/coltzar.JPG\" title=\"Blog Romanesc Romanian Blog Www.Groparu.Ro\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/04/coltzar.JPG\" alt=\"Blog Romanesc Romanian Blog Www.Groparu.Ro\" /></a>\r\n\r\nIn fine, imi vine coltzarul, il cÄƒrÄƒm vitejeÅŸte sus, neuitand sÄƒ Ã®l izbim cu staminÄƒ de toÅ£i peretii ÅŸi usile unde locuiesc studentele la mine-n bloc, Ã®l instalÄƒm, ÅŸi ne apucam - normal - sÄƒ  scotocim prin lada de lenjerie. Pe care o deskid, ÅŸi - surpriza-surpriza! - descopÄƒr, ca un mic Alva Edison de Manashtur, o minicolectie de coji de seminte de floarea soarelui, un adevarat orÄƒÅŸel, un buchet Ã®ntreg, ce mai! un Ã®ntreg covoraÅŸ amestecat ca un manunchi de ÅŸerpi care fac sex Ã®n grup. Wwwwooowwww!!!\r\n\r\nOare la ce meci se uitasera muncitorii cand or depozitat acolo mica galerie de opere de arta, lucrate cu migalÄƒ bucalÄƒ? Oare a castigat Rapidul, sau Poli? Oare muncitorii tineau si ei post si incercau sa se lase de fumat, sau pur si simplu coltarul meu era locul preferat de adunare la pauza de cafea si seminte? Oare muncitorii faceau parte dintr-o sectÄƒ satanicÄƒ, ÅŸi omorÃ¢tul seminÅ£elor - care, dupa cum bine se ÅŸtie, au suflet, mÄƒmici ÅŸi tÄƒtici, cariere ÅŸi opinii politice - fÄƒcea parte din ritualul lor zilnic? Oare seminÅ£ele Å£ineau cu BÄƒse, sau cu TÄƒricicÄƒ, erau membre ale fostului, sau ale actualului govern reformat? (ÅŸi, apropos, noul guvern e reformat, catolic, sau protestant?) Oare seminÅ£ele veneau din Kosovo, ÅŸi trebuie sa informez ONU despre groapa comuna de la mine din lada de lenjerie? Oare ar fi trebuit sÄƒ platesc Ã®n plus pentru coji, sau le-am primit ca bonus pentru cÄƒ o durat O LUNA DE ZILE  sÄƒ primesc un amarÃ¢t de coltzar modular din 6 piese? Oare e semn ca trebuie sa returnez coltzarul, si sa le pun la muncitori cateva pungi  cu surate de bostan, ca sa isi diversifice dieta? Oare coltzarul meu e facut Ã®n ceva lagar de concentrare de la Galati, ÅŸi muncitorii sunt hraniti numai cu seminte de foarea soarelui? Si, nu in ultimul rand, daca ca MUNCITORII ASTIA ERAU SCARABEI, LA CE FEL DE RESTURI ALIMENTARE AR FI TREBUIT SA MA ASTEPT SÄ‚ GÄ‚SESC ÃŽN LADA - caca de vaca, cal, oaie, sau politai???','Cand dai din coltzar in coltzar',0,'','publish','open','open','','cand-dai-din-coltzar-in-coltzar','','','2007-04-02 22:47:15','2007-04-02 20:47:15','',0,'http://www.groparu.ro/?p=304',0,'post','',5),(303,2,'2007-04-02 11:15:00','2007-04-02 09:15:00','Romanian blog Blog romanesc www.Groparu.ro','Romanian blog Blog romanesc www.Groparu.ro',0,'','inherit','open','open','','romanian-blog-blog-romanesc-wwwgroparuro-2','','','2007-04-02 11:15:00','2007-04-02 09:15:00','',301,'http://www.groparu.ro/wp-content/uploads/2007/04/futaye.JPG',0,'post','image/jpeg',0),(305,1,'2007-04-02 22:46:53','2007-04-02 20:46:53','Blog Romanesc Romanian Blog Www.Groparu.Ro','Blog Romanesc Romanian Blog Www.Groparu.Ro',0,'','inherit','open','open','','blog-romanesc-romanian-blog-wwwgroparuro-2','','','2007-04-02 22:46:53','2007-04-02 20:46:53','',304,'http://www.groparu.ro/wp-content/uploads/2007/04/coltzar.JPG',0,'post','image/jpeg',0),(306,2,'2007-04-03 14:50:27','2007-04-03 12:50:27','<a href=\"http://www.groparu.ro/wp-content/uploads/2007/04/ratuc.JPG\" title=\"Romanian blog Blog romanesc www.Groparu.ro\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/04/ratuc.JPG\" alt=\"Romanian blog Blog romanesc www.Groparu.ro\" /></a>\r\n\r\n1. Stai 24 de minute in fatza oglinzii si iti dezvolti cel mai tampit zambet de pe fatza pamantului.\r\n\r\n2. Te muti in mijlocul de transport in comun - inghesuit, asudat, transpirat, anti-Boc si anti Alianta DA.\r\n\r\n3. Se pandeshte prima statie de troleu, tramvai, autobuz.\r\n\r\n4. Se cauta cu privirea oamenii cu geci negre din statie, care se uita furish la calatori in timp ce scriu silabisind nervos intr-un carnetzel.\r\n\r\n5. Se asteapta pana urca in autobuz, troleu, tramvai in cupluri de cate doi (nu pot urca niciodata in cupluride cate 3).\r\n\r\n6. Astepti pana se inchid usile.\r\n\r\n7. ScotiÂ  cu viteza abonamentul sau biletul, si te indrepti catre ei cu petecul de hartie drept intins catre ei. Te scuzi fata de aia pe care ii calci (ma iertati, dar e control).\r\n\r\n8. Le bagi sub nas biletul sau abonamentul inainte ca ei sa apuce sa isi prinda legitimatia de controlor in piept si sa ceara abonamentele la verificat.\r\n\r\n9. Le zambesti cu zambetul de la punctul 1. Efect garantat.','Cum se enerveaza un Ratuc',0,'','publish','open','open','','cum-se-enerveaza-un-ratuc','','','2007-04-03 14:50:27','2007-04-03 12:50:27','',0,'http://www.groparu.ro/?p=306',0,'post','',1),(307,2,'2007-04-03 14:49:34','2007-04-03 12:49:34','Romanian blog Blog romanesc www.Groparu.ro','Romanian blog Blog romanesc www.Groparu.ro',0,'','inherit','open','open','','romanian-blog-blog-romanesc-wwwgroparuro-2','','','2007-04-03 14:49:34','2007-04-03 12:49:34','',-1175597868,'http://www.groparu.ro/wp-content/uploads/2007/04/ratuc.JPG',0,'post','image/jpeg',0),(308,2,'2007-04-03 14:50:11','2007-04-03 12:50:11','Romanian blog Blog romanesc www.Groparu.ro\r\nwww.ratuc.ro','Romanian blog Blog romanesc www.Groparu.ro',0,'','inherit','open','open','','romanian-blog-blog-romanesc-wwwgroparuro-3','','','2007-04-03 14:50:11','2007-04-03 12:50:11','',-1175597868,'http://www.groparu.ro/wp-content/uploads/2007/04/ratuc.JPG',0,'post','image/jpeg',0),(737,1,'2007-10-28 17:42:34','2007-10-28 15:42:34','Da, cica vineri a fost ziua usilor portilor. Intrare la muzee moca, concert Iris moca, aer moca, bere pe bani. Da\' nu-i stress.\r\n\r\nDeci concert Iris, floare de coltz. Organizat de - cine alÅ£ii? Clicknet.\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/10/dsc00187.JPG\" title=\"dsc00187.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/10/dsc00187.thumbnail.JPG\" alt=\"dsc00187.JPG\" /></a>\r\n\r\nIo nush ce formatie e Iris asta, ca niciodata nu or fost in stare sa cante playback!\r\n\r\nCÃ¢nd te apropii de mulÅ£ime, liberalii, simÅ£ind cÄƒ acilea e rost de voturi de studenti beti, iti dau fluturasi cu ei. Le spui sa se potoleasca, fincÄƒ tu Å£ii cu Romania Mare, UDMR ÅŸi Uniunea Armenilor, dar ei insistÄƒ, si daca tot ii refuzi, cheama colegele lor care de alfel te si conving, finca is foarte liberale.\r\n\r\nFrig. La Sala Sporturilor, deci langa Somes, deci frig de faci turturi de ghiatza in gaura curului. Tzurtzuri maro.\r\n\r\nNe-am pus langa Smurzi.\r\n\r\nSmurd Cluj, cand merge la concerte cu Iris si Groparu sta langa ei, pornesc dubitza aia smurdÄƒ a lor, si il obliga pe Groparu sa stea in fumurile de la eÅŸapament. Care pute.\r\n\r\nIn acele clipe, Groparu le zice smurzilor:\r\n\r\n- Deci bÄƒ, io vÄƒd cÄƒ deÅŸi voi ne intoxicaÅ£i cu gaze, nici o studentÄƒ nu o leÅŸinat, deci nici o ÅŸansa de respiraÅ£ie gura-la-gurÄƒ sau de masaj cardiac cu sutienu\' scos; deci nu opriti motoru?\r\n- Ba da, zice Smurdu\', amabil, ma duc sa vorbesc cu soferu, si mere inauntru, si tot nu opreste motoru\', da coboara si imi zambeste de parca l-ar fi oprit. Tu, fiind de bun simptz, renunti.\r\n\r\nCand lucrurile s-or incins, si Cristi Minculesc cÃ¢nta \"Baby\", smurzii nu s-or mai aptinut: or inceput sa topaie si ei cu populatia. Si era cool sa vezi asta.\r\n\r\nJandarmii faceau cordon la scena, ca sa nu intre nimeni sa-l violeze pe Cristi Mincu\' sau sa-i faca poze la burtica aia care este a lui. M-am dus la cel mai rau dintre ei, si i-am zis:\r\n\r\n- Bah, domnu\', zic, daca te rog frumos, nu il bati pe shafu\' meu? Te rog io frumos. Hai ca dau o bere, mai zic.\r\n- Cine-i shafu\' tau?\r\n- Ui ala, zic io, si i-l arat pe Iepurasul Atomic, blogger care nu mai bloggereste, cu care uitai sa va zic ca ma intalnisem cu vreo 20 minute mai devreme; Iepurila are vreo 2 metri inaltime si cred ca 120 kile, deci barbat adevarat, care imi si marturisise ca isi facuse pensia aia, pilonu doi, deci lasati-l in pace, prietenii lui care vreti sa il convingeti sa semneze!\r\n\r\nDupa concert, fiind usa portilor deschise, am mers la Muzeul de Istorie a Transilvaniei, despre care cu mandrie pot spunea ca imi este client la traduceri. Muzeul are inauntru si o sectie de egiptisme, in care se pot admira replici originale de ipsos ale unor statui de pe Nil. Mai are si niscai schelete de hominizi care atesta nu stiu ce, asa, neshte chiupuri de 2 metri inaltime in care vizitatorii or aruncat coji de seminte si pahare de plastic (rusinica, buey!), asa, multe chestii dacice, care mie imi fac o deosebita placere, ca io am tinut cu dacii toata viatza mea, asa, si la etaju\' de sus cand am ajuns deja era ora 12 noaptea, si usa portilor deschise nu dureaza toata noaptea, asa ca meretz acas\'.\r\n\r\nNoi ne-am permis sa nu merem acas\', ci sa merem intr-o crajma. Dupa aia am ajuns acasa si am dormit ca nesimtitu, cÄƒ am deschis larg usile portilor somnului, al carui amant fidel sunt, si care nu prea m-o lasat degraba din gheare! Dar despre visele care l-au erotizat pe Groparele in timpul somnului - cine stie, poate intr-un episod urmator. Sau mai bine nu!','Usile portilor deschise',0,'','publish','open','open','','usile-portilor-deschise','','','2007-10-28 17:42:34','2007-10-28 15:42:34','',0,'http://www.groparu.ro/?p=737',0,'post','',7),(738,1,'2007-10-28 12:18:03','2007-10-28 10:18:03','Vroiam sa imi gatesc niste <a href=\"http://www.gustos.ro/retete-culinare/aperitive-cu-oua/ochiuri-romanesti-1.html\" target=\"_blank\">ochiuri romanesti</a>.\r\n\r\nPentru ochiurile romanesti aveam nevoie de cratita albastra.\r\n\r\nCratita albastra era ocupata cu budinca de orez cu mere.\r\n\r\nDeci nu am mai mancat ochiuri romanesti.\r\n\r\nDar am exclamat:\r\n\r\n\"Oal-albastra, oal-albastra/Totusi este trist in lume!\"','Oala mea albastra',0,'','publish','open','open','','oala-mea-albastra','','','2007-10-28 12:18:03','2007-10-28 10:18:03','',0,'http://www.groparu.ro/?p=738',0,'post','',4),(310,2,'2007-04-03 16:02:46','2007-04-03 14:02:46','Romanian blog Blog romanesc www.Groparu.ro http://www.nobilacasa.ro/romana/despre-compania-imobiliara.php','Romanian blog Blog romanesc www.Groparu.ro http://www.nobilacasa.ro/romana/despre-compania-imobiliara.php',0,'','inherit','open','open','','romanian-blog-blog-romanesc-wwwgroparuro-httpwwwnobilacasaroromanadespre-compania-imobiliaraphp','','','2007-04-03 16:02:46','2007-04-03 14:02:46','',-1175604689,'http://www.groparu.ro/wp-content/uploads/2007/04/nobila-casa.JPG',0,'post','image/jpeg',0),(311,1,'2007-04-03 16:10:38','2007-04-03 14:10:38','<a href=\"http://www.groparu.ro/wp-content/uploads/2007/04/nobila-casa.JPG\" title=\"Romanian blog Blog romanesc www.Groparu.ro http://www.nobilacasa.ro/romana/despre-compania-imobiliara.php\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/04/nobila-casa.thumbnail.JPG\" alt=\"Romanian blog Blog romanesc www.Groparu.ro http://www.nobilacasa.ro/romana/despre-compania-imobiliara.php\" /></a>\r\n\r\n- Buna ziua. Vad aici ca imi oferiti spre vanzare un apartament semifinisat, cu peretii vopsiti in lavabila; dar fara sa scrie ca peretii vor fi mai inainte gletuiti. Vad aici ca nu scrie in ante-contract nici un termen limita de predare a imobilului; si mai mult, nu exista nici o penalizare pentru constructor daca imi preda apartamentul dupa 12 ani de la semnarea contractului. In schimb, daca virez ultima transa la mai mult de o luna dupa ce primesc CF-ul, pierd drepturile asupra apartamentului. In final, vad ca preferati un singur notar public pentru ipoteca - eu prefer sa aleg eu hotzul*. Ei bine, lucrurile astea vreau sa se schimbe. Se poate?\r\n\r\n- Vai, ne scuzati, nici nu am vazut. Da, modificam acuma. Dar nu ar fi mai bine sa mergeti sa vorbiti cu constructorul dumneavoastra in persoana?\r\n\r\n- Nu, asta nu e treaba mea, e treaba agentiei. Haideti, faceti un efort, ca doara va dau 1500 EU, faceti-va macar ca munciti pentru banii astia.\r\n<p align=\"right\">&nbsp;</p>\r\n<p align=\"right\">(cf. Nobila Casa)</p>\r\n<p align=\"right\">&nbsp;</p>\r\n<p align=\"right\">* In viziunea Groparului, notarii publici sunt niste hoti. Daca Groparu ar fi si el notar public, nu ar mai fi hoti, ci baieti destepti.</p>','La agentul imobiliar',0,'','publish','open','open','','la-agentul-imobiliar','','','2007-04-03 16:10:38','2007-04-03 14:10:38','',0,'http://www.groparu.ro/?p=311',0,'post','',0),(312,1,'2007-04-03 17:41:47','2007-04-03 15:41:47','Blog romanesc Romanian blog www.Groparu.ro','Blog romanesc Romanian blog www.Groparu.ro',0,'','inherit','open','open','','blog-romanesc-romanian-blog-wwwgroparuro-2','','','2007-04-03 17:41:47','2007-04-03 15:41:47','',0,'http://www.groparu.ro/wp-content/uploads/2007/04/victima.JPG',0,'post','image/jpeg',0),(315,1,'2007-04-04 00:37:36','2007-04-03 22:37:36','1. Ce nu te omoara, te face mai puternic.\r\n\r\n2. Ce te omoara, te face mai slab.\r\n\r\n3. Omoara-te. Vei slabi.','Reteta de slabit',0,'','publish','open','open','','reteta-de-slabit','','','2007-04-04 00:37:36','2007-04-03 22:37:36','',0,'http://www.groparu.ro/?p=315',0,'post','',0),(316,1,'2007-07-26 15:44:32','2007-07-26 13:44:32','Deci cine n-a vazut filmul \"The Corporation\", nu ar merita sa mai traiasca pe lumea aceasta, decat daca e o blonda tanara cu sanii mari, careia i se iarta tot sh care sh promoveaza in firma (numai) pe baza de IQ. Dixit.\r\n\r\nDe ce? va veti intreba.\r\n\r\nHaidatz sa va zic.\r\n\r\nFinca tot documentaru\' vorbeste despre cat de periculoase is firmele astea de apartament care intr-o buna zi vor prelua lumea: Gaurica SRL, Shlapul SRL, <a href=\"http://www.exxon.com/USA-English/gFM/home_Contact_Us/homepage.asp\" target=\"_blank\">(s)Exxon</a>, <a href=\"http://www.ge.com\" target=\"_blank\"></a><a href=\"http://www.ge.com\" target=\"_blank\">Caporal Electric</a>, <a href=\"http://www.fedex.com/\" target=\"_blank\">Fed(s)Ex</a>.\r\n\r\nClaro ca firmele astea deverseaza sapunuri prin mÄƒrile planetei mele, fac experimente cu gene sh sprancene tÄƒricene pe oameni vii, vand lapte contrafacut sh infestat cu nush ce hormoni de crestere, de o sa ajungem toti o natie de grasuni imbuibati, lucioshi sh fericiti, sh pe langa asta nij nu platesc toate taxele, ca au o gashca de avocati specializati pe neplatit taxe.\r\n\r\nSi pe langa asta firmele sunt populate de o cohorta de corporatisti care nush daca is fericiti, da\' bogati is cat cuprinde. Nu Irinel Columbeanu de bogati. Zic bogati-bogati! Adeca d-aia care isi permit sa cumpere sanvish cand vrea ei; care nu raman la final de luna fara bani de abonament de autobuz, sh care daca vrea sa plece un weekend cu cortu\' singuri, pleaca! Da\' sanvishu\' e din carne de hipopotam care se vinde numa in Nigeria, sh e adus CALD de o firma de catering in maxim 6 ore de la prajire, asa, nu raman fara bani de autobuz, finca le sta la dispozitie Boeingu\' 737 al companiei (apropos, ce nume de companie e Boing asta, din moment ce mimeaza onomatopeic sunetul unei perechi de sani dezveliti care fug cu posesoarea lor pe o plaja bulgareasca scaldata de soarele diminetii?), asa, si daca vrea sa plece cu cortu\' in Antarctica vreme de vreo 4 luni (ca cica atata are un concediu managerial) sa vaza pinguinii, o fac! Fara jena. Ceea ce mie mi se pare super OK.\r\n\r\nA, si mai e o faza: oamenii astia, daca reusesc cumva sa provoace o cadere libera la bursa a actiunilor companiei lor, is eliberati de functie. Cu un cec baban in buzunare. Cand zic baban, zic bani suficienti sa cumperi o juma de InterContinental cu ei. Sh apai sa populezi jumatea ta de hotel cu studente de anu I in pielea goala, sh sa te apuci sa te fugareshti prin cÄƒmari cu ele, Ã®notÃ¢nd prin spuma naturala de capshuni cu Viagra.\r\n\r\nMichael Moore, care nu stiu daca e coproducator sau femeiul de serviciu al serialului, care de alfel e  un tip destul de socialist, se erijeaza instant in vocea celui care striga in pustie la corporatii \"Dati-ne sh noo, ca si vrem malai! Mult!\"\r\n\r\nMnoa, amu sta Groparu, incearca sa gandeshte, nu reusheshte, se mai kinuie, sh zice, intr-un final in care si-o pocanit sinapsele la greu: Ce-avetz mah cu ei? De ce nu incercati sh voi sa ajungeti in spatele unui birou d-ala cat un camion, mare boss de transnationala, care sh el sa se bucure de avantajele unui asemenea job? Ha? Ca io tat asta ma tat kinui sa fac, sh mai am maxim 90 de ani sh asha voi ajunge! Asta daca nu ni se prajesc crierii din capatzana mai devreme, de la efectul de sera!\r\n\r\nPS: Filmul poate fi vizionat gratis de pe video.google.com, dat un search dupa <strong>The Corporation</strong>.','Corporate Respon-senibility',0,'','publish','open','open','','corporate-respon-senibility','','','2007-07-27 10:24:37','2007-07-27 08:24:37','',0,'http://www.groparu.ro/?p=316',0,'post','',22),(314,1,'2007-04-06 12:24:51','2007-04-06 10:24:51','Ajuns la varsta la care mi-am indeplinit cea mai mare parte a fanteziilor mele sexuale (inclusiv sex cu o femeie) si aflat intr-o lipsa acuta de provocari (cu exceptia trezitului la 9 si 10 dimineatza), m-am hotarat  sa tin post. Punct.\r\n\r\nIn cateva zeci de ore l-am terminat. A fost atata de greu, lung si gros (7 saptamani!) si atata lume s-a indoit ca voi reusi, ca amu ca am reusit am ajuns sa ma auto-respect pe mine insumi ca pe un Zaraz. Per total, am invins detasat: cu exceptia unui biscuite cu crema de iaurt mancat fara sa stiu ca era de dulce, nu am calcat stramb deloc. DELOC.  Am rabdat cu stoicism privind la altii cum fumeaza, beau sau mÃ¢ncÄƒ zamÄƒ de burtÄƒ ÅŸi cÃ¢rnati usturoiaÅ£i Ã®n prezenta mea, si am privit cu jind cum le mai ÅŸi ramanea in coltul buzelor cate o firimitura de carne cand vorbeau cu mine!\r\n\r\nAsa ca incepand de azi sa nu mai aud\r\n\r\n- \"eu nu pot tine cura de slabire!\"\r\n- \"eu nu ma pot lasa de fumat!\"\r\n- \"biletele la control!\"\r\n- \"care e faza cu chefu\'?\"\r\n- \"incearca sa vorbesti mai rar!\"\r\n- \"te rog sa nu mai intarzii la serviciu!\"\r\n- \"poti sa-mi traduci 50 de pagini pana maine? dau o bere\"\r\n- \"da\' tu de ce te-ai hotarat sa tii post?\"\r\n- \"in seara asta nu, dragul meu, ca ma doare capul\"\r\n- \"gatesc eu si tu speli vasele, sau vrei sa si gatesti tot tu?\" (nu mancam mai bine un pateu...?)\r\n- \"vecine, la tine in garsoniera cati locuiti de fapt? ca atatea fete am vazut ca ies... \" (una era chiar fiica-ta, asa-i?)\r\n- \"de ce nu ai mai dat nici un semn de viatza?\" (ca nu te suport)\r\n- \"de ce nu mai raspunzi pe YM?\" (finca esti pe ignore de doua semestre!)\r\n- \"fa-ma sa rad, ca am o zi proasta!\" (uite-te in oglinda si o sa te pufneasca rasu\')\r\n- \"da-mi neste bani imprumut\" (n-am! n-am! n-am!)\r\n- \"nu te mai lauda la toti ca tii post\" (dar e ultima mea sansa de a reajunge in centrul atentiei!)\r\n- \"io, daca as fi in locu\' tau...\" (nu esti. shat ap)\r\n- \"cine te-o nominalizat la <a href=\"http://www.clujblogfest.ro/nominalizari/cel-mai-prost-blog/\" target=\"_blank\">cel mai prost blog din Cluj</a>?\" (nu stiu, dar daca aflu ii dau o bere, sunt cu adevarat flatat! <a href=\"https://www2.blogger.com/comment.g?blogID=5296032167142002759&amp;postID=7085249013377349989\" target=\"_blank\">Razvane</a>, nu ai nici o sansa...)\r\n- \"ti-or disparut mah ciupercile alea de pe picioare?\" (da, le-am mancat aseara, is de post)\r\n- \"fa-mi te rog rost de ultimu hit Voltaj\" (incearca un pipi scurt pe priza!)\r\n- \"cand iti schimbi telefonul asta najpa?\" (cand s-or inventa telefoane care sa si futa)\r\n- \"cand imi dai banii aia inapoi?\" (inca nu te-ai prins ca e tzeapa?)','Despre Post - consumatum est',0,'','publish','open','open','','despre-post-consumatum-est','','\nhttp://www.clujblogfest.ro/nominalizari/cel-mai-prost-blog/','2007-04-06 12:44:53','2007-04-06 10:44:53','',0,'http://www.groparu.ro/?p=314',0,'post','',3),(317,1,'2007-04-04 15:31:21','2007-04-04 13:31:21','Hashvebe-mi-ar, ca ma duc la ei sa platesc rata lunar. Sa platesc, nu sa iau creditul ala cu 3,95% dobanda in primele 2 zile, DAE 120,4%. Stau la rand, ma groparesc, ii zambesc superior tipei din spatele meu de la coada, asta nu isi explica ce cauta unu\' imbracat ca un gropar boschetar la coada la depuneri, da din umeri si nu raspunde nicicum.\r\n\r\nImi vine randu\', ii zambesc si tipei de la ghiseu, oarecum fara rost, ghisheitza oricum e verde in obraji si pe mustatza transpirata: tre\' sa mearga sa faca pipi, dar nu poate ca e coada mare. Cand ii intind sutele de euro cu mainile tremurande apare o alta coleguza de-a ei, si ii striga prin geamul blindat cu urme de caca de la mushtele de asta-vara \"Tu, Nico, uite aici iti las actele ^*)(_)_+_+_, le faci tu cand ai vreme, te rog, OK? Mersi frumos! Pa-pa!\"\r\n\r\nNico pune trei stampile pe bonul meu, si pana completeaza actele i se plange lu\' nenea de langa ea, care e chel si ii sta bine plesuv \"mai, Gigi, da\' numa ea imi zice Nico! Toata lumea imi zice Cami, numa ea imi zice Nico, parca dinadins...\"\r\n\r\nAmu, sincer sa fiu, si mie imi place mai mult Nico decat Cami - finca daca zice o femeie Nico, observati ce sexy si ce oral i se rotunjesc buzele, si raman asa pretz de o secunda la finalu cuvantului, de iti trec tot felu\' de idei prin cap, chiar daca e vanzatoarea aia sudoripara si stirba din piatza de pastarnac si ridichi negre (atentie, ridichile negre dau gaze cu efect de sera garantat!!!). Dar daca lu\' domnisoara aia ii place sa i se zi<strong>ca Ca</strong>mi (cu neajunsurile de riguare: daca iti zice un balbait numele, iese <strong>ca-ca-ca-ca-Ca</strong>mi; nu poti zice \"<strong>ca</strong> (precum) <strong>Ca</strong>mi\", nici \"adi<strong>ca Ca</strong>mi\", nici \"sa nu patzeas<strong>ca</strong> <strong>Ca</strong>mi ceva\", nici  \"hai sa te iubeas<strong>ca Ca</strong>mi, etc, etc, etc), atunci Groparu si-a permis, mai ales ca mai erau 8 oameni in spatele lui la coada, sa ii vorbeas<strong>ca</strong> \"<strong>Ca</strong>mi, mersi frumos!\", sa stea pana i se bulbucheaza ochii lu\' Cami, si apai sa plece in treaba lui.\r\n\r\nPun pariu <strong>ca Ca</strong>mi o sunat dupa aia la firma care le-o livrat geamurile blindate de la ghiseu sa ii certe ca de ce le-or mintit ca geamurile is si antifonice, si anti caca de musca de anu\' trecut? Ca ui ca nu-s!','Memoirs of a Ghiseitza, te-astept deseara la portitza',0,'','publish','open','open','','memoirs-of-a-ghiseitza-te-astept-deseara-la-portitza','','','2007-04-04 15:31:21','2007-04-04 13:31:21','',0,'http://www.groparu.ro/?p=317',0,'post','',0),(318,1,'2007-04-04 18:32:20','2007-04-04 16:32:20','El: tinerel, 14-15 ani, freza 3rei Sud-Est, telefon cu speaker  care canta o manea la volum mare, nÄƒsos. Ea: mult prea scunda pentru el, sholduri lataretze, viitoare leliÅ£Äƒ. Eu:\r\n\r\n- Voi aveti de gand sa aveti copii?\r\n- ???\r\n- Daca da, sa ii dati la orfelinat.\r\n\r\nPS: Si sa nu donati niciodata sperma sau ovule. Niciodata.','Voi vreti sa aveti copii?',0,'','publish','open','open','','voi-vreti-sa-aveti-copii','','','2007-04-04 19:01:30','2007-04-04 17:01:30','',0,'http://www.groparu.ro/?p=318',0,'post','',0),(319,2,'2007-04-05 13:23:46','2007-04-05 11:23:46','Oare si la Biserica Ortodoxa Germana e asa haos? Ca la romani nu mai stiai la un moment dat care popa impartaseste, care spala pacate cu 2 in1 sampon de covoare si balsam de gura, care canta pe nas si care tine servetu\' ala cu care se sterg batranele si noi la gura dupa ce molfaie pÃ¢inica cu vin.\r\n\r\nFaza e ca popilor ortodocsi le cam place sa se auda vorbind. Si mie imi place sa ma aud vorbind, dar din respect pentru oamenii in fusta neagra nu am sa ma fac preot niciodata (iarta-ma, mama, ti-am zis ca nu vreau Teologie!)\r\n\r\nP-orma - popa m-o intrebat:\r\n\r\n1. Cand m-am spovedit ultima data. I-am zis ca demuuuuhuuuuuhult, din clasa a 11-a, si am si bufnit olecutza in ras, asa, sa imi ascund rusinea.\r\n2. Cu ce cred eu ca am pacatuit de atunci. I-am zis ca am minciunit si am preacurvit, ca nu stiam de unde sa incep, si am inceput cu cele mai gustoase. Nu i-am zis ca tin cu Dinamo si ca sunt foarte slobod la gura, dar incorsetat la mintea din corp (fie ea testiculara sau cervicala).\r\n3. Ceva, sau si-o zis lui siesi ceva bolborosind ca un shaman. Eram pe punctul de a-l intreba \"Ce faci, parinte, chemi ploaia?\"\r\n\r\nLa final, am vrut sa il intreb asta, dar nu am mai avut timp: parinte, daca un om isi lasa averile bisericii, isi poate lasa si datoriile? Si sunt obligat sa las si cati bani am descoperire de cont, sau ajung aia cash? Si - inca una - aici se poate face donatie cu cardu\'?','La spovedanie',0,'','publish','open','open','','la-spovedanie','','','2007-04-05 13:23:46','2007-04-05 11:23:46','',0,'http://www.groparu.ro/?p=319',0,'post','',6),(321,2,'2007-04-05 15:09:33','2007-04-05 13:09:33','<a href=\"http://blog.pacurar.net/\" target=\"_blank\">Shafu\' meu</a> se tat mira ca amu-s vreo 8 luni o lasat din greseala caciulitza pruncului sau cel mai recent la MOL - si tanti de acolo i-o returnat-o saptamana asta, dupa 240 zile!\r\n\r\nDaca tanti aia e intr-atata de psihedelica, io l-am rugat frumos pe shaf ca cand mai trece pe-acolo sa o-ntrebe pe tanti aia daca nu mi-o gasit cumva din greseala si tineretea mea? Ca mi-o traba... serios... si mi-ar mai trebui asa: papusha lu sor-mea pe care-am pierdut-o cand aveam 9 ani, de am si luat-o pe coaja pentru asta; vreo 3900 de nopti pierdute aiurea prin studentie, le vreau sa le pot pierde din nou; si mintile, ma, mintile pe care mi le-am pierdut pentru unguroaica aia cand aveam 19 ani, Ildiko o chema, mamaaaa, ce fata!','Pierdut caciulitza, nu e ceea ce va ganditi',0,'','publish','open','open','','pierdut-caciulitza','','','2007-04-05 15:11:02','2007-04-05 13:11:02','',0,'http://www.groparu.ro/?p=321',0,'post','',2),(322,2,'2007-04-06 13:40:33','2007-04-06 11:40:33','<a href=\"http://www.groparu.ro/wp-content/uploads/2007/04/everything.jpg\" title=\"everything.jpg\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/04/everything.jpg\" alt=\"everything.jpg\" /></a>\r\n\r\nPaste bani si sanatate,\r\nPaste si prosperitate,\r\nPaste si o viata lunga,\r\nPan\' la Luna sa ajunga!\r\n\r\nHristos va invia!\r\n\r\nPS: Daca ma apuca vreun acces brusc de narcisism, am sa mai scriu, daca nu, ne vedem joi, am urlat dupa ea!','Paste Fainoase!',0,'','publish','open','open','','paste-fainoase','','','2007-04-06 13:40:33','2007-04-06 11:40:33','',0,'http://www.groparu.ro/?p=322',0,'post','',0),(323,2,'2007-04-06 13:40:14','2007-04-06 11:40:14','','everything.jpg',0,'','inherit','open','open','','everythingjpg','','','2007-04-06 13:40:14','2007-04-06 11:40:14','',-1175859317,'http://www.groparu.ro/wp-content/uploads/2007/04/everything.jpg',0,'post','image/jpeg',0),(324,1,'2007-04-10 23:01:11','2007-04-10 21:01:11','<a href=\"http://www.groparu.ro/wp-content/uploads/2007/04/pregnant-man.jpg\" title=\"blog romanesc Romanian blog www.groparu.ro\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/04/pregnant-man.jpg\" alt=\"blog romanesc Romanian blog www.groparu.ro\" /></a>\r\n\r\n100% garantata de nenea pe care nenea maghear care m-o loat la ocazie azi - cel mai maghear dintre soferi si cel mai sofer dintre magheari, cu exceptia, bineinteles, a celor care erau mai magheari si mai soferi decÃ¢t el - l-o loat azi la ocazie (cine se prinde ce am vrut sÄƒ zic aici e mai deÅŸtept decÃ¢t mine cu multiÅŸor).\r\n\r\nDeci azi stau la ocazie. Clar? Clar. Si refuz vreo 2-3 European Drinksuri - ca is TIR-uri ÅŸi dureaza mult pana ajung Ã®n oraÅŸul cu flori de pomana. Clar? IarÄƒ da. Åži in cele din urmÄƒ cedez farmecelor ÅŸi mÄƒ sun Ã®ntr-un microTIR Nissan (care cÄƒra alte doo Nissanuri si un NissÄƒnoi ÅŸi care - aveam sa aflu mai tÃ¢rziu - <strong>zbura</strong> la vale cu 42 km/h, de am fÄƒcut 4 ore jumate pÃ¢nÄƒ Ã®n Cluj).\r\n\r\nNenea maghear ÅŸofer din microNissan (numit, de aici Ã®nainte, <em>ÅŸofer microNissan</em>) se milostiveÅŸte la un moment dat de un alt ÅŸofer care autostopea cu  diagrama Ã®n mÃ¢nuÅ£Äƒ (numit, de aici Ã®ncolo, <em>ÅŸofer autostopist</em>) ÅŸi Ã®l ia la bord din Alba pÃ¢nÄƒ Ã®n Unirea (sat european). <em>Åžoferul autostopist</em> rÄƒmÄƒsese cu un gust foarte amar dupÄƒ ultima lui cursÄƒ, gust Ã®nsoÅ£it de un miros aÅŸijderea, care nu pregeta sÄƒ se Ã®nÅŸurubeze Ã®n urechea mea dreaptÄƒ cÃ¢nd vorbea articulat - eu mÄƒ aflam, cum lesne puteÅ£i ghici, Ã®ntre cei doi vorbÄƒreÅ£i cavaleri ai ÅŸoselelor ÅŸi, probabil, ai parcÄƒrilor ÅŸi centurilor.\r\n\r\nDar nu m-am apucat sÄƒ mÄƒ aberez amu despre parcÄƒri ÅŸi nici despre lighioanele din ele care poartÄƒ fustÄƒ - nu, nu ÅŸi nu, deÅŸi  subiectul mÄƒ inspirÄƒ. Ci despre povestirea 100% adevÄƒratÄƒ a unui accident, spusÄƒ ÅŸi garantatÄƒ de <em>ÅŸoferul autostopist</em>. Accident soldat (sau colonel) cu un climax* destul de ciudat.\r\n\r\nRecte, un alt nene (numit, de aci Ã®nainte, <em>alt nene</em>) se izbeÅŸte cu maÅŸina de sub curul domniei sale Ã®ntr-un  imobil (sau copac imobil, sau parapet imobil); globulele sangvine policolore ale lui <em>alt nene</em> erau OK, atÃ¢ta numa cÄƒ cam Ã®notau Ã®ntr-un mic heleÅŸteu deloc minuscul de bere. AÅŸa cÄƒ acest <em>alt nene</em> Ã®ÅŸi adunÄƒ bruma de luciditate care Ã®i mai dÄƒdea, sfioasÄƒ, tÃ¢rcoale, ÅŸi Ã®ncearcÄƒ sÄƒ ÅŸpÄƒguiascÄƒ pe Garcea. Din nefericire pentru el, la mine Ã®n Å£arÄƒ, poliÅ£aii nu pot fi  corupÅ£i sub nici un chip - decÃ¢t, eventual, cu\r\n\r\n- un telefon cu bluetooth\r\n- un plic barosan\r\n- un vin de colecÅ£ie\r\n- un calculator nou-nouÅ£ pentru fie-sa\r\n- un sejur de neuitat la BÄƒile Felix\r\n- o revizie auto completÄƒ\r\n- un microNissan plin cu Å£igle - pentru viluÅ£a lui din FÄƒget\r\n- o sponsorizare sÄƒ meargÄƒ fie-sa Ã®n FranÅ£a cu ÅŸcoala\r\n- o pilÄƒ la Dimitire Cantemir, unde e student Ã®n anul II\r\n- orice altceva.\r\n\r\nAÅŸa cÄƒ acest <em>alt nenea</em> rezolvÄƒ cu oamenii de sub chipiu ca Ã®n locul sÃ¢ngelui berÄƒrit al domniei sale, la analizÄƒ, sÄƒ se preleveze tot sÃ¢nge, dar de la o altÄƒ persoanÄƒ, neberÄƒritÄƒ - sÄƒ Ã®i iese omului analizele curate. AÅŸa cÄƒ acest <em>alt nenea</em> Ã®ÅŸi cheamÄƒ nevasta ÅŸi Ã®i zice:\r\n\r\n\"FÄƒi muiere, tu ÅŸi aÅŸa pierzi  sÃ¢nge lunar ca proasta! DacÄƒ mÄƒ iubeÅŸti ÅŸi vrei sÄƒ nu mÄƒ Ã®ntorc de la rÄƒcoare peste 4 ani rebotezat  Miranda, ia meri tu, fata tatii, de doneazÄƒ sÃ¢nge la laboratorul Äƒla criminalist Ã®n numele meu, totul e aranjat, ÅŸi o sÄƒ am, mÃ¢nca-Å£i-aÅŸ, niÅŸte analize curat ca blidul ostÄƒÅŸesc - fÄƒrÄƒ pic de alcool Ã®n sÃ¢nge!\"\r\n\r\nZis ÅŸi fÄƒcut, tanti mers, lÄƒsat (Ã®n secret) sÃ¢nge la analizÄƒ Ã®n numele soÅ£ului, aÅŸteptat o orÄƒ sau cam aÅŸa ceva, dupÄƒ care planul lor reuÅŸeÅŸte pe deplin: pe dosarul de la PoliÅ£ie al lui <em>alt nene</em> apare scris, MARE, un NUP (neÃ®nceperea urmÄƒririi penale). Motivul?\r\n\r\n<em>ALT NENE</em> ESTE GRAVIDÄ‚!!!!\r\n\r\n_________________________\r\n*<a href=\"http://dexonline.ro/search.php?cuv=climax\" target=\"_blank\">climax</a> = are mai multe semnificaÅ£ii, dar nu e specie de melc','100% garantata',0,'','publish','open','open','','100-garantata','','','2007-04-10 23:08:46','2007-04-10 21:08:46','',0,'http://www.groparu.ro/?p=324',0,'post','',2),(325,1,'2007-04-10 22:44:56','2007-04-10 20:44:56','blog romanesc Romanian blog www.groparu.ro blog romanesc Romanian blog www.groparu.ro blog romanesc Romanian blog www.groparu.ro blog romanesc Romanian blog www.groparu.ro','blog romanesc Romanian blog www.groparu.ro',0,'','inherit','open','open','','blog-romanesc-romanian-blog-wwwgroparuro-2','','','2007-04-10 22:44:56','2007-04-10 20:44:56','',324,'http://www.groparu.ro/wp-content/uploads/2007/04/pregnant-man.jpg',0,'post','image/jpeg',0),(326,1,'2007-04-11 19:35:24','2007-04-11 17:35:24','<a href=\"http://www.groparu.ro/wp-content/uploads/2007/04/250px-romanian_orthodox_monk.jpg\" title=\"blog romanesc Romanian blog www.groparu.ro\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/04/250px-romanian_orthodox_monk.jpg\" alt=\"blog romanesc Romanian blog www.groparu.ro\" /></a>\r\n\r\nUn popa nu se minte ca sa il convingi sa te voteze, ca sa se futa cu tine sau ca sa iti mareasca salariu. Nici ca sa iti imprumute masina, sa stea cu copiii sau sa iti dea neshte bani pana la salariu.\r\n\r\nEu l-am mintit un popa in fatza altarului, tocma\' cand ma spovedeam.\r\n\r\nSi Mitroa o mintit un popa in fatza altarului.\r\n\r\nIo l-am mintit popa cu inima curata.\r\n\r\nSi Mitroa l-o mintit pe popa cu inima curata.\r\n\r\nPe mine nu ma prea incearca regretele ca l-am mintit pe popa.\r\n\r\nMitroa is sigur 100% ca nu are nicicea mai infima, microbiologic pura parere de rau.\r\n\r\nParerea mea e ca relatia mea cu Dumnezeu - asa, divortzoasa cum e ea - nu are mare lucru de suferit ca l-am mintit pe locotenentul Sau.\r\n\r\nMitroa e super-hiper-mega-arhi-Terra indiferent de relatia lui cu Dumnezeu, cata vreme poa\' sa beie si sa fumeze. A, si cata vreme fiica-sa (cu care ii tot promit io ca ma insor) e sanatoasa.\r\n\r\n<strong>Io.</strong> Ma duc la spovedania, prima data din viatza mea (cÄƒ atunci, in clasa a XI-a, o fo\' incompleta, ca nu m-am si impartasit), ma intreaba popa: \"<em>cu ce crezi tu ca ai pacatuit, cu gandul sau cu fapta, de atunci, din clasa a XI-a?\" - </em>i-am zis: PREACURVIT, parinte, preacurvit, cu ochii, cu salamul barbos, cu deshtele, cu limba, ce mai! orice excrescentza cat de mica, daca am putut sa o bag intr-o femeie, am bagat-o, fara nici cel mai mic regret! si daca puteam  sa ma bag intru cu totu\' intr-o femeie, m-as fi bagat si n-as mai fi iesit veci pururi!\r\n\r\nE OK, am recunoscut, m-a iertat. Dar ulterior am aflat ce mincinos patentat am fost pentru ca am vorbit balarii in fata preasfintiei sale (mi-i lene sa scriu cu initiale mari majusculate). A preacurvi insamna a face sex* in afara casatoriei. Pai ce casatorie, mai frate, ca io la capitolu\' asta is codash! Popa mintit? Popa mintit!\r\n\r\n<strong>Mitroa. </strong>Ce am facut io e nimic pe langa ce o facut Mitroa. Eram acolo. Eram chiar acolo - acolo unde anu\' trecut <a href=\"http://www.groparu.ro/?p=52\" target=\"_blank\">pupasem candelabru, din greseala</a>. Ne Ã®nviam, aÅŸteptam cu nerÄƒbdare sÄƒ se termene slujba, sÄƒ fumam ÅŸi sÄƒ mÃ¢ncÄƒm carne. La un moment dat, popa zice ceva cÄƒ sÄƒ se impartasheasca nush cine, cÄƒ nu am auzit prea bine, cÄƒ toti se foiau oe-acolo, dornici sÄƒ se termine slujba ca sÄƒ poatÄƒ fuma ÅŸi sÄƒ mÃ¢nce carne. Cert e ca Mitroa - pÄƒgÃ¢nu\', dar postitoru\', ca si mine, de altfel - se repede atzÄƒ la popa ca fata mare la maritiÅŸ, de parcÄƒ se termina mantuiala acolo, ni, Ã®n sara aia. Åži stÄƒ otzÃ¢rÄƒ la ÅŸoptite cu popa, ÅŸi dupa aia ia Ã®mpÄƒrtÄƒÅŸania Ã®ntre mandibulÄƒ ÅŸi nas, o da pe gÃ¢t - ca un bÃ¢tlan care Ã®nghite un peste - ÅŸi revine printre noi. Åži Ã®ncearcÄƒ sÄƒ se abÅ£inÄƒ, da\' nu poate, mai incearca o data, dÄƒ kix, ÅŸi ne zice, ÅŸoptind, in timp ce fÄƒcea baloane cu nasu\' de emoÅ£ie si de rÃ¢s: BÄƒ, zice, l-am minÅ£it pe popÄƒ Ã®n noaptea de ÃŽnviere!!! Da\' taci mÄƒ, zic, nu ne minti! BÄƒ, zice, jur pe roshu ca l-am minÅ£it! Jur, ma! M-o intrebat daca m-am spovedit, ÅŸi ghici ce i-am zis! Ghici! Ca Å£-am zis cÄƒ nu m-am spovedit! AÅŸa-i? AÅŸa-i! No! Am uitat ca nu m-am spovedit anu asta! Åži ghici ce i-am zis! Ghici!!!\r\n\r\n________________\r\n* aka a te fute','Cat de dobitoc poti sa fii ca sa minti un popa?',0,'','publish','open','open','','cat-de-dobitoc-poti-sa-fii-ca-sa-minti-un-popa','','\nhttp://www.groparu.ro/?p=52','2007-04-11 19:40:01','2007-04-11 17:40:01','',0,'http://www.groparu.ro/?p=326',0,'post','',11),(327,1,'2007-04-11 19:33:59','2007-04-11 17:33:59','blog romanesc Romanian blog www.groparu.ro blog romanesc Romanian blog www.groparu.ro blog romanesc Romanian blog www.groparu.ro blog romanesc Romanian blog www.groparu.ro','blog romanesc Romanian blog www.groparu.ro',0,'','inherit','open','open','','blog-romanesc-romanian-blog-wwwgroparuro-2','','','2007-04-11 19:33:59','2007-04-11 17:33:59','',-1176308009,'http://www.groparu.ro/wp-content/uploads/2007/04/250px-romanian_orthodox_monk.jpg',0,'post','image/jpeg',0),(328,2,'2007-04-23 15:08:59','2007-04-23 13:08:59','Daca nu am mai zis pe www.clujblogfest.ro, ma repet:\r\n\r\n<strong>Vreau sa castig premiul de cel mai prost blogger din urbe. E musay.</strong>\r\n\r\nFrati romani si maghiari, va scriu cu degetele gÃ¢tuite de emotie ca ma simt literalmente magulit pentru nominalizare, sper ca nimeni sa nu indrazneasca sa imi sufle premiul pe care il merit cu vÃ¢rf ÅŸi Ã®ndesat, de aceea va invit sa ma votati drept cel mai najpa prost si tumpit (fara virgule) blogger din urbea aceasta Boc-ica. Daca ma votati asfaltez strazile, le iau pensionarilor gratuitatea de pe transport, bag metrou pe sub Feleac si tunel pana in America, pe care o vom anexa! AMERICA, PAMANT ROMANESC!!! Ma votati?\r\n\r\nVotati Groparu - cel mai prost blog! There can be only one! E nevoie de un om inteligent ca sa-si dea seama de o scriitura proasta de calitate superioara! Daca ma votati, am sa construiesc moscheea Playboy in Romania si Sinagoga Ursus, daâ€™ fara E-uri! Discoteca studentelor! Congregatia virginelor! PARTIDUL LEZBIENELOR!!! Ma votati?\r\n\r\nAm sa dau cate o chinezoaica la fiecare! Am sa execut cÃ¢te un manelist Ã®n fiecare zi, in PiaÅ£a Mare! Am sÄƒ exilez GuÅ£ii ÅŸi Vitoii ÅŸi Salamii Ã®n Transnistria! Am sÄƒ declar rÄƒzboi Rusiei, ÅŸi am sÄƒ le anexez rezervele de petrol! Am sÄƒ dau gaze gratuite la toata lumea! Am sÄƒ vÄƒ transform ÅŸefii Ã®n atentatori sinucigaÅŸi Ã®n autobuze pline cu alti shefi! Am sÄƒ scot din nou stagiul militar obligatoriu! Am sÄƒ declar obligativitatea jocurilor pe calculator! Am sÄƒ introduc Yahoo! Messenger pe autobuze! Am sÄƒ dau tuturor tinerilor cÃ¢te un Matiz decapotabil! Am sÄƒ vÄƒ tunez prietenele! Am sÄƒ declar burÅ£ile ilegale la femei, afara numa la alea la care le sta bine cu asa ceva! (ca is sh din estea) Ma votati?\r\n\r\nAm sÄƒ interzic Britney Spears, ÅŸi voi importa brazilience! Voi face Love Parade! Seinfeld si Chris Rock vor fi ambasadorii Ã®n Campia Turzii ÅŸi Jucu! Voi interzice sefii! Voi distribui tampoane tricolore cu steagul Frantei gratuit! Va voi de-becaliza! Il suspend si il repun in drepturi pe Basescu si ii re-pun suvitza in cap! Il arestez pe Iliescu! Am sa simplific gramatica limbii maghiare! Voi exporta gaze de fasole in Rusia! Am sa dau un Gripen fiecarui cetatean! Voi interzice minciuna fara scop erotic! Ma votati?\r\n\r\nAm sa il salvez pe ursuletul Knut! Voi acorda tratament gratuit pentru prelungirea penisurilor tzarii! Ceilalti bloggeri au intinat numai nobilele idealuri ale bloggeritului cu idei proaste! Nimeni nu le-a dat celor 322 de parlamentari dreptul sa ma voteze la alte categorii, ei si-au luat mandatul de la oligarhi! Ma votati? Va rog mult, ma votati? N-am facut nimic acolo!\r\n\r\nIntrati pe  http://www.clujblogfest.ro/votare/ si dati-mi votul vostru, ca sa nu fiu nevoit sa aduc oameni cu autocarele din Petrosani. Pls. Pls pls plssssss.\r\n\r\nPS: Uitati-va si voi ce naspa arata blogu\' meu. Nu merit eu titlul de cel mai naspa blogger? Da\' sincer amu!\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/04/p4221307.jpg\" title=\"cel mai naspa blog din Romania\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/04/p4221307.jpg\" alt=\"cel mai naspa blog din Romania\" /></a>','Votati Www.Groparu.Ro, cel mai prost blog din Cluj!',0,'','publish','open','open','','votati-wwwgroparuro-cel-mai-prost-blog-din-cluj','','','2007-04-23 15:23:42','2007-04-23 13:23:42','',0,'http://www.groparu.ro/?p=328',0,'post','',3),(329,1,'2007-04-13 02:46:11','2007-04-13 00:46:11','Noa, binie.\r\n\r\nFaza e ca tocma\' ce am venit din clubu\' Autograf din Cluj, unde joi de joi is numa trupe laiv care canta tÄƒt felu si le prinde bine, mai ales cand apare cate un Gropar ridicol care pune manutza pe microfon si se abereazÄƒ Ã®n octave CozmÃ¢ncÄƒ.\r\n\r\nNoa, ce am observat eu:\r\n\r\n- MiÅŸu cÃ¢ntÄƒ excelent;\r\n\r\n- fetele grase, cand seÂ  imbata, devin de nestapanit; (tot respectul pentru ele, finca m-am dedat la carniÅ£Äƒ de grasuÅ£Äƒ de mai multe ori, ÅŸi e delicioasÄƒ!)\r\n\r\n- MiÅŸu cÃ¢ntÄƒ excelent;\r\n\r\n- cÃ¢nd Groparu pune mÃ¢nuÅ£a pe microfon, are numa baftÄƒ de microfoane eftine, care Ã®i distorsioneazÄƒ vocea de seamÄƒnÄƒ foarte piÅ£igÄƒiat de mult cu aia naturalÄƒ, de aia din jur se stricÄƒ de rÃ¢s; ÅŸi rÃ¢sul e specie protejatÄƒ la mine Ã®n patrie;\r\n\r\n- MiÅŸu cÃ¢ntÄƒ excelent;\r\n\r\n- in afarÄƒ de o chelneriÅ£Äƒ, nu vezi nici mÄƒcar un decolteu mai acÄƒtÄƒrii;\r\n\r\n- MiÅŸu cÃ¢ntÄƒ excelent;\r\n\r\n- Ã®n fct. de cÃ¢t bei, preÅ£ul beuturii se schimbÄƒ;\r\n\r\n- MiÅŸu cÃ¢ntÄƒ excelent;\r\n\r\n- la bar nu vor avea niciodatÄƒ rest sÄƒ Ã®Å£i dea;\r\n\r\n-Â  tipuÅ£a aia grasÄƒ care se abera semÄƒna cu mine cÃ¢nd cÃ¢ntam;\r\n\r\n- cam atata. CÄƒ mi-i somnic.\r\n\r\nA consemnat pt. WwwRadioTransilvania.Eu, acelaÅŸi Groparu, acelaÅŸi privitor nevindecat de decoltee, burice, feÅ£e, pÄƒruri, funde ÅŸi funduri, precum ÅŸi toalete!\r\n\r\nPS: - MiÅŸu cÃ¢ntÄƒ excelent!','Cand se cÃ¢ntÄƒ laiv',0,'','publish','open','open','','cand-se-canta-laiv','','','2007-04-13 02:46:11','2007-04-13 00:46:11','',0,'http://www.groparu.ro/?p=329',0,'post','',1),(330,2,'2007-04-13 14:42:39','2007-04-13 12:42:39','Ma gandeam io azi, asa, daca s-ar face un bordel numa\' pentru mamelit, ce ar fi? Intri inauntru, dai un euro, te speli pe labutze si un minut numa pipai la tzitzi - tari, moi, lasate, rebele, cu sfarc mare sau mic, rozaliu sau negricios ca Becali, inegale, de inaltimi diferite, care sa fie indreptate in directii diferite sau in acelasi sens, grele sau usurele, cu mucul proeminent sau in forma de capshuna, alunitza, pishcatura de tzantzar, nasuc de bebelush, rotunde sau in forma de romb, balconashe feciorelnice, smochine uscate de papornitza, ascunse in gavanul unei mici cocoase, scoase in afara cu mandrie patriotico-biologica, care se dau de o parte si de alta cand sta pe spate, sani cu ochelari, sani cu vinisoare albastrii, care ii ajung pana la barbie cand fuge fara tricou, balcoane ascunse de sutien sau acoperite numai pe jumate, usor uscate in jurul sfarcului, ascunse de un neglijeu transparent (genul de neglijeu care niciodata nu il iei lu nevasta-ta, ca ei ii iei numa aspirator de ziua ei!), in tricou - ud sau uscat, de bumbac sau polistiren, tzatze de fete plinutze si de skeletzi anorexici, cu burtica sau fara, cu cercelushi sau inelashe prin sfarc, care isi trezesc sfarcul care te zgarie pe palma cand le mangai, cu putintel par intre sani sau chiar cu o coafura interesanta, sau deloc, cu putintel par care iese rebel din sfarc, sani tatuati cu sirene si cu inimioare, sani cu implanturi cu solutie salina, sani de femeie care adora palmutele peste balconashe, sani care pot fi unsi cu ce fel de crema isi doreste clientu\', sani de piatra, in forma de pepene, dovleac, piersica, mar+para, sani care adora sa iti cufunzi fatza intre ei, sani dependenti de sarutari, sani care se infioara la atingerea cu o pana de paun, carora le place sa fie nitzelush storshi cand ies din piscina, uzi si picuritori, sani care iti spun o intreaga poveste cand ti se freaca de ureche, sani care trebuie sarutati ca sa iti ia gustul rau din gura, sani, sanishoare, sanutzi, da, da, da...\r\n\r\nD-ra poate pleca acasa dupa 2 ore muncite in care face o suma frumusica, si pana a doua zi numa\' face shopping.\r\n\r\nPentru clientii fideli se pot introduce alte servicii:\r\n\r\n- bagatul deshtiului;\r\n- mirositul fofezei;\r\n- palmuit funfuletzu\';\r\n- mangaiat cu parul domnisoarei pe spatele tau;\r\n- spalat d-ra pe spate cand face baie in spuma;\r\n- tuns si barbierit savarina domnisoarei;\r\n- pupat picioruse mai mult sau mai putin epilate;\r\n- baut sampanie din buricul domnisoarei;\r\n- adulmecat spinare de domnisoara;\r\n- holbat o jumatate de ora la intrepicioareleei;\r\n- mangaiat curba feselor;\r\n- claxonat gajica din mashina;\r\n- suflat aer ca sa i se ridice fusta;\r\n- pus gajica sa se uite urat-urat-urat la tine;\r\n- plimbat frumoasele-i suvitze intr-o broscutza cu fitze;\r\n- dormit pe o saltea de femei goale;\r\n- muscat fetele foarte usor si delicat cu buzele de obraji;\r\n\r\nCaut investitori.','C\'est le bordel',0,'','publish','open','open','','cest-le-bordel-2','','','2007-04-13 14:50:37','2007-04-13 12:50:37','',0,'http://www.groparu.ro/?p=330',0,'post','',2),(331,1,'2007-04-14 09:58:32','2007-04-14 07:58:32','Oricat ar parea de incredibil, au fost si vremuri cand beam numai sifon. Sau vremuri cand in afara de lapte nu puteam baga nimic la duoden.\r\n\r\nDa\' daca ar fi sa ma mai nasc o data, m-as naste karatist, nu abonat Ratuc. Si m-as imprieteni cu toti controlorii, si as scrie \"m-as imprieteni\" asa: \"m-as imprietenii\", si as mere in mertzan cu montura de aur pe keptzi, si as asculta manele si as arunca cu euro in intersectii, ca in Oltenia la mort.\r\n\r\nI-as bate pe toti ochelaristii pe care i-as intalni, si apoi m-as imprieteni cu ei si as incerca sa ii invatz <em>s-a scrie corec</em> si sa fie baieti de comitet. Si m-ar iubi in secret Monicile Gabor, si Andreii Gheorghe ar scrie in zeflemea da\' cu teama de mine.\r\n\r\nMi-as face agentie imobiliara si as trage tzepe cu apartamente facute din caramizi de la demolari. Si as fi prezent non-stop la carcotashi, si as avea succes mai mult la Zavorance.\r\n\r\nAs bea numa bere la care i se face reclama la ProTV, si m-as uita la Dansez cu tine. Si m-as bate pe burta cu clanu Clamparu, si as fi prieten cu Miki Spaga. Si as scoate CNN din grila de canale de pe TV-ul meu plat ca o masa de biliard, cu diagonala cat perdeaua. Si mi-ar sta mai bine cand ma scol dimineatza si ma scarpin in fund prin pijama, si apai m-as zgamai in nas.','Ia toji karatist',0,'','publish','open','open','','ia-toji-karatist','','','2007-04-14 09:58:32','2007-04-14 07:58:32','',0,'http://www.groparu.ro/?p=331',0,'post','',0),(332,1,'2007-04-14 09:59:13','2007-04-14 07:59:13','Azi tot e euro-ceva, ca si EuroBlogu\' asta scris in EuroCluj, finca suntem deja cuprinsi de cee ce eu numesc eur-haristie, pentru ca aceasta integrare poate avea urmari neplacute - cititi cu atentie prospectul.\r\n\r\nVom avea europarlamentari, care ne vor fura euro-pesedeshte, peneleshte si pedeshte, Doamne, miluieshte.\r\n\r\nEconomia noastra nu va mai fi in Aer, va fi in Eur.\r\n\r\nVom papa alimente cu EUR-i, dar vom face cancer fericiti ca nu mai avem coruptie si ca presedintele vorbeste engleza mai bine ca Iliescu.\r\n\r\nBecali si Vadim se vor bate ca un LEUr pentru Romania, lipsi-m-as.\r\n\r\nCopiii nostri orfani care nu se pot injura intre ei de mama (ca n-au, ca mamica e in Italia la cules oarece) vor creste mai eurotraumatozati in cashile alea maternale (si vitreginale).Vom merge la pescuit in eurobalti, si vom da euroshpagi la nenea euro-verificatorul-de-permise-de-pescuit.\r\n\r\nVom folosi in continuare software-uri la fel de piratate, numa\' ca euro-crackuite.\r\n\r\nNe vom euro-injura in trafic.\r\n\r\nPS: Io bag sama ca euro asta se scrie cu un \"0\" (zero) in loc de \"o\" (oo, ca in alea care stau de-o parte si de alta a ****, asa: oIo), si astialantii, fiind de mai mult vreme in UE,\r\niau EUR-ul, si noi ramanem cu0 (zero). Parerea mea...\r\n<p align=\"right\">Semnat: Groparu, un euro-sceptic vindecat, optimist si uscat.</p>','EuroBlog',0,'','publish','open','open','','euroblog','','','2007-04-14 09:59:13','2007-04-14 07:59:13','',0,'http://www.groparu.ro/?p=332',0,'post','',0),(333,1,'2007-04-14 10:11:22','2007-04-14 08:11:22','Groparu isi ia o saptamana de concediu, mere langa Sibiu la cabana unde se va juca toata ziulica \"Nu te supara, frate!\" cu nepotelul lui de 6 ani, si va incerca sa nu se oftice - finca nepotelul lui il umileste constant la jocu\' asta, in vazul intregii familii. In rest, am sa ma scarpin pe burta constant de inactivitate (cand mainile nu mi-s ocupate cu bere si gratar) si voi incerca sa nu urlu la luna de plictiseala.\r\n\r\nNe recitim candva inainte de viitoarele alegeri. Daca patesc ceva si crap, nu uitati:\r\n\r\n- nu votati Becali!!!!\r\n- cumparati albumu lul Silvan! Tre\' s-apara, va da numa\' cate unu ca s-ajunga la toata lumea;\r\n- insistati pe langa parinti sa va faca frati si surori cu nepotei, is fun;\r\n- recomand cu caldura prietena/nevasta din orase mici, la fel cum recomandÂ  prietena/nevasta din oras mare sau de la tzara;\r\n- e OK sa fii gay, mai ales daca esti femeie;\r\n- spalati-va pe dinti macar saptamanal;\r\n- nu mancati usturoi si mergeti la serviciu, asta-i imitatie la ce face Groparu;\r\n- dushul, dushul e important - desi unii nu ma cred;\r\n- invatati sa va puneti singuri faiantza si gresie, e mai sigur;\r\n- cand faceti cadouri aveti grija cum si cui le inmanati.\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/04/gratar.JPG\" title=\"Romanian blog blog romanesc www.groparu.ro\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/04/gratar.JPG\" alt=\"Romanian blog blog romanesc www.groparu.ro\" height=\"379\" width=\"503\" /></a>','Nu te supara, cititorule/oareo (oare?)',0,'','publish','open','open','','nu-te-supara-cititoruleoareo-oare','','','2007-04-14 10:11:22','2007-04-14 08:11:22','',0,'http://www.groparu.ro/?p=333',0,'post','',4),(334,1,'2007-04-14 10:10:54','2007-04-14 08:10:54','Romanian blog blog romanesc www.groparu.ro','Romanian blog blog romanesc www.groparu.ro',0,'','inherit','open','open','','romanian-blog-blog-romanesc-wwwgroparuro-2','','','2007-04-14 10:10:54','2007-04-14 08:10:54','',-1176537554,'http://www.groparu.ro/wp-content/uploads/2007/04/gratar.JPG',0,'post','image/jpeg',0),(338,2,'2007-04-23 11:51:06','2007-04-23 09:51:06','<a href=\"http://www.groparu.ro/wp-content/uploads/2007/04/gold-fish.jpg\" title=\"http://www.wetpetz.com/goldfish.htm\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/04/gold-fish.jpg\" alt=\"http://www.wetpetz.com/goldfish.htm\" /></a>\r\n\r\n<a href=\"http://rottencabbage.ablog.ro/2007-04-14/inca-una.html\">Varza stricata</a>, autorul unui blog care nu e deloc varza, vrea sa afle ce as face io, Groparele, daca as prinde pestisoru\' de aur cu trei dorintze la purtator. Io deja am raspuns <a href=\"https://www2.blogger.com/comment.g?blogID=6345027039307377071&amp;postID=4150657886207927884\" target=\"_blank\">aici</a>, pe blogu\' lu sorella, da\' nitica incercare de gimnastica mintala nu imi face rau, si dorintze mai am pe stoc. Asa ca, daca l-as prinde inca o data pe shtiucoiu\' cu dorintzi, i-as cere fara sa clipesc:\r\n\r\n1. Sa pot sa fac un interviu cu Dumnezau, da\' sa stea fatza in fatza cu mine, sa-l vaz, nu numa\' ashe, sa-I aud cu vocea in capu\' meu, mai ales ca nu is prea sigur ca vocea aia e a lu\' Dumnezeu, finca  vocea ma mai indeamna sa ma si uit supt fuste la coleje si deasupra decolteelor prin autobuze;\r\n\r\n2. Sa am un bazin cu sirene in garsoniera la mine, da\' sirene d-alea cu picioare lungi, care sa nu puta a peste si a scoici in putrefactie ca digu\' din Burgas, si care sa nu aiba mame care sa-mi fie mie soacre;\r\n\r\n3. Hmmm. Sa fac una in ring cu canceru\'. Sa ii fut un cap in gura si doo crosee in testicole in timp ce fumez, si cand plangand il cheama si pe frate-su, sa ii dau si lu ala in gura, sa ii stric jucariile, sa ii zic ca ma-sa-i curva si ca va ramane repetent si ca sa vina cu parintii la scoala. Muie cancerului! Fumati tigari necangerigene, pls.\r\n\r\nDaca mai ceteshte cineva situl asta, il rog sa preia leapsha asta menstruala cu pestisoru\'. Da\' sa nu scrie ca si-ar dori sa nu mai prinda nimeni pestisoru\' in afara de ei. Unii dintre noi mai avem nevoie de vise, si nu avem toti bani de droguri.','Dorintze in coada de peste',0,'','publish','open','open','','dorintze-in-coada-de-peste','','','2007-04-23 11:51:06','2007-04-23 09:51:06','',0,'http://www.groparu.ro/?p=338',0,'post','',2),(335,1,'2007-04-22 20:51:50','2007-04-22 18:51:50','Amu io nu is Arnold,  da jur ca am capacitati nostradamice, finca pot prevedea in viitorul apropiat. D-aia mi-am pus okelarii de suare pe nÄƒnÄƒu, mi-am pus unditza pe umar, cÄƒ gun n-am, si nici giacÄƒ de kele, si am zis \"I will be back!\"\r\n\r\nDupa 5 minute, I was back. Am aterizat acasa amu 4 minute.','Groparu s-ontors, da\' n-o vast nimic',0,'','publish','open','open','','groparu-s-ontors-da-n-o-vast-nimic','','','2007-04-22 20:51:50','2007-04-22 18:51:50','',0,'http://www.groparu.ro/?p=335',0,'post','',1),(336,1,'2007-04-22 21:37:23','2007-04-22 19:37:23','Â \'ce <a href=\"http://www.hotnews.ro/articol_70380-Cele-mai-rele-mosteniri-genetice.htm\" target=\"_blank\">hotnews</a> (preluand livescience.com) cum ca s-o descoperit ca cele mai nasuale 10 mosteniri genetice sunt mostenite genetic: adecatelea defectele si lipsurile pe care le avem cu totii in mai mare sau mai foarte mare masura, cu exceptia mea, care le am pe toate (ca trebe sa si iau penicilina, uneori) sunt izvorate exact din parintii nostri, nush daca mai ales din mama sau din tata, sau din nenea instalatoru\' ala de chiuvete de bucatarie.\r\n1. Alcoolismul:  50% din cauzele care determina alcoolismul sunt genetice, iar restul is determinate de factorii de mediu.\r\n- o sa ma apuc sa beau pana uit ca is alcoolic. Desi mai is 50% sanse ca de vina sa fie efectul de sera (aka <em>factorii de mediu</em>).\r\n\r\n2. Cancerul de san\r\n- am putea scapa de chestia asta inventand o rasa de femei fara sani. Deloc. Dupa cum am vazut in unele poze cu studente topless de la Costineshti, deja or aparut cateva exemplare.\r\n\r\n<span class=\"arial12negru\"><font class=\"arial12negru\">3. Daltonismul\r\n- io is daltonist mai ales dupa 4 beri si 6 tequila, cand imi platesc berea cu 2 bancnote de 1 leu la chelneritza, si cer si rest, si asta cheama badiguardu\'; cand apare badiguardu\', daltonismu\' ma face sa imi vad bicepsii in alta culoare, mai umflati parca. A doua zi daltonismu\' meu imi arata numa\' ochii umflati si vinetzi din oglinda, numa\' ca bicepshii cumva in mod misterios se dezumfla, desi erau super balonati cu 7 ore inainte, parol. Â  </font></span>\r\n\r\n<span class=\"arial12negru\"><font class=\"arial12negru\">4. Violenta\r\n- da\' de ce la unii gena asta cu violentza se manifesta numa la capitolu \"dat in gura\", iar la altii numa \"loat in gura\"?</font></span>\r\n\r\n5. Obezitatea\r\n- dom\'le, cand ceteshti ca de vina is parintii ca esti obez, ti se face foame. Pe cuvant.\r\n\r\n<span class=\"arial12negru\"><font class=\"arial12negru\">6. Bolile de inima\r\n- asta nu se refera la atunci cand nu dai cu aspiratorul prin camerele inimii, da\' as vrea si io mai multe gene de boala de inima cum o avut Ibrahim Ferrer si Gil Dobrica, ca bine de mai ziceau din guritza, dom\'le!</font></span>\r\n\r\n7. N<span class=\"arial12negru\"><font class=\"arial12negru\">asterea unor copii gemeni\r\n- nimic nu poate fi mai cool decat sa nasca femeia-ti doi gemeni in zodia Gemenilor, si numele tau de familie sa fie Geamanu\' - si nici tu, nici ea sa nu fi avut gemeni in familie. Hmmm...\r\n</font></span>\r\n\r\n<span class=\"arial12negru\"><font class=\"arial12negru\">8. Acneea.\r\n- io am un tip  special de acnee, numit \"acneea de evenimente speciale\": imi apare un cosh din ala vizibil de la o posta in chiar ziua in care am de mers la vreo nunta, banchet de absolvire sau prima intalnire cu o gajica de care chiar imi place la nebunie. A doua zi dispare la fel de misterios pe cum a aparut, ca si cand nu as fi avut-o niciodata! Sa-mi spuneti daca o sa-mi apara si la inmormantarea mea, in caz ca nu pot sa ma uit.\r\n</font></span>\r\n\r\n9. I<span class=\"arial12negru\"><font class=\"arial12negru\">ntoleranta la lactoza\r\n- nu are rost sa scriu ca daca suferi de asa ceva, nu ai cum juca in filme cu de trei ori femeie XXX, ca partenera de barbat.</font></span>\r\n\r\n<span class=\"arial12negru\"><font class=\"arial12negru\">10. Chelia.\r\n- chiar, de ce femeile nu chelesc decat pe picioare, si asta numa dupa ce stau in baie 46 de minute cu un bol de ceara fierbinte, de pute tot apartamentu\' ca in morga de hipopotami, si mai si tzipa, asa cum nu or tzipat niciodata in bratzele tale? Noi macar chelim in tacere si cu demnitate!!!!</font></span>','Nu-i mai zice destin, Ã®i zice genÄƒ',0,'','publish','open','open','','nu-i-mai-zice-destin-ii-zice-gena','','','2007-04-22 21:37:23','2007-04-22 19:37:23','',0,'http://www.groparu.ro/?p=336',0,'post','',0),(337,1,'0000-00-00 00:00:00','0000-00-00 00:00:00','Da.\r\n\r\nAm sa merg - cu un ziar si trei tigari - inr-o buda de tzara. Imi voi pune cate o tigare dupa fiecare ureche, si una intre buze.\r\nIn buda, am sa ma deschei la pantaloni si am sa ii las sa cada, precum cortina dupa o piesa de Ionesco (I hate the <em>maricon</em>!). Ulterior, dupa aproximativ 2 secunde, am sa imi cobor si chilotii (nu ca-n poezia aia a mea, \"stau pe buda si ma cac, de chiloti nu ma dezbrac!\").\r\n\r\nApoi am sa ma asez, cu grija, pe scandura. Scandura e rece, finca afara bate vantul, si afara e martie sau aprilie, plina zi, insorita, dar cu vant. Rafalele arctice imi vor mangaia partile corpului meu la care tin cel mai mult, si imi vorÂ  zburli usurel parul de pe fese.\r\n\r\nPe scandura nu vor fi nici un fel de stropi galbeni de la pishurile anterioare, deci nu voi fi nevoit sa ma dezlipesc de colac.','Intr-o buna zi am sa ma ***',0,'','draft','open','open','','intr-o-buna-zi-am-sa-ma','','','2007-04-22 22:37:22','2007-04-22 20:37:22','',0,'http://www.groparu.ro/?p=337',0,'post','',0),(339,2,'2007-04-23 11:50:33','2007-04-23 09:50:33','http://www.wetpetz.com/goldfish.htm','http://www.wetpetz.com/goldfish.htm',0,'','inherit','open','open','','httpwwwwetpetzcomgoldfishhtm','','','2007-04-23 11:50:33','2007-04-23 09:50:33','',-1177320584,'http://www.groparu.ro/wp-content/uploads/2007/04/gold-fish.jpg',0,'post','image/jpeg',0),(340,1,'2007-04-23 15:22:33','2007-04-23 13:22:33','cel mai naspa blog din Romania','cel mai naspa blog din Romania',0,'','inherit','open','open','','cel-mai-naspa-blog-din-romania','','','2007-04-23 15:22:33','2007-04-23 13:22:33','',328,'http://www.groparu.ro/wp-content/uploads/2007/04/p4221307.jpg',0,'post','image/jpeg',0),(341,1,'2007-04-23 22:55:44','2007-04-23 20:55:44','Cand zic \"buda de tzara\", nu ma refer la buda asta de tzara numita Romania. Nu. Nici la politaiu din imagine, ci la ceea ce dezvaluie domnia sa ochiului curios al camerei foto.\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/04/buda_0.jpg\" title=\"buda_0.jpg\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/04/buda_0.jpg\" alt=\"buda_0.jpg\" /></a>\r\n\r\nIo zic ca buzile de tzara is cea mai majora si mai optima inventie a omenirii din ultimii din ultimii - sa zic - 4.000 de ani. Aproape la fel de colosala ca inventarea femeii. De ce viatza noastra nu a mai fost la fel dupa inscaunarea primului asemenea complex recreational?\r\n\r\nE simplu. Pentru ca:\r\n\r\n<strong>1. Ne-a scapat de constipatie.</strong> Afara e frig, bate vantul si un aer rece iti inveleste cu sadism curul alb, nebronzat, nebarbierit, proaspat descoperit. Corpul elimina din start caca si pishu din corp, ca sa nu piarda energie incalzindu-le.\r\n\r\n<strong>2. A dez-conditionat aplicarea neconditionata a reflexului Pavlovian.</strong> Asa cum cutzu\' lu Pavlov saliva din abundentza (nu la vederea  vreunui cur de domnisoara studenta, va rog sa ma scuzati, asa cum salivati unii dintre noi), la fel si la taranii romani  glanda sfinctereala (organ nedescoperit inca de medicina) se relaxeaza si baga turbo in momentul in care nasucul adulmeca curios mireasma primavaratica familiara de <em>toilette</em> (sic!) de curte. Eliberarea devine astfel imediata, fara medicamente care cer citirea cu atentie a prospectului, expresierostitafoarterepededeovocegrabita.\r\n\r\n<strong>3. Taranul roman este ecologist convins.</strong> Pai, mai frate, cu atata rahatzeala ai parte de un depozit inepuizabil de ingrasamant ecologic, bashca combustibil pentru o carutza <em>perpetuum mobile</em> cu metan! Plus ca daca arunci pe ogor ce iese dintr-un tzaran tratat cu vin roshu, iti iasa, bade, un porumb Viagra, de mai mare dragu\' sa beleshti bunatate de tulau!\r\n\r\n<strong>4. Taranul roman e fizician. </strong>El poate afla din start adancimea privatei fara sa masoare ochimetric. Cum? va veti intreba voi. Simplu - voi zice eu. Scapi submarinu\' maro dintre fese. Da? Da. Si incepi sa numeri. In momentul in care face \"pleosc!\" te opresti, calculezi acceleratia gravitationala, forta de frecare cu aerul, viteza de rotatie a Pamantului, variabila vitezei sunetul in functie de curentii de aer pana la receptia in urechea externa, viteza de transmitere a impulsului sonor catre cortex, si gata! ai aflat distantza D de la ochiul maro la luciul toaletei. Simplu.\r\n\r\n<strong>5. Taranul roman e entomolog. </strong>In microlimatul toaletar se dezvolta o mica lume cu rosturile, parlamentarii si presedintii ei - de la tzantzari la muste verzi si paianjeni.\r\n\r\n<strong>6. Se favorizeaza studiul psihologic de caz. </strong>Singuratatea din sala tronului  favorizeaza introspectia. Atunci esti cel mai sincer si mai dispus la a-ti analiza obsesiile compulsive, tendintele homosexuale reprimate, lipsa figurii tatalui si (mai ales, in cazul constipatiei) traumele psihologice.\r\n\r\n<strong>7. Ai sansa de a cunoaste trecutul, prezentul si viitorul Romaniei </strong>- fara horoscop, Brucani, Cristoi, RealitateaTV sau anal-ism politic. Te uiti la ce-ai facut, si gata, stii unde se afla patria mea! Si nici macar nu mai trebuie sa furi cablu.','Eu cred ca vesnicia s-a nascut la sat, intr-o buda de tzara',0,'','publish','open','open','','eu-cred-ca-vesnicia-s-a-nascut-la-sat-intr-o-buda-de-tzara','','','2007-04-23 23:01:59','2007-04-23 21:01:59','',0,'http://www.groparu.ro/?p=341',0,'post','',2),(344,1,'2007-04-25 00:11:01','2007-04-24 22:11:01','http://www.gandul.info/articol_11260/profesia_mea___bocitoare.html','http://www.gandul.info/articol_11260/profesia_mea___bocitoare.html',0,'','inherit','open','open','','httpwwwgandulinfoarticol_11260profesia_mea___bocitoarehtml','','','2007-04-25 00:11:01','2007-04-24 22:11:01','',343,'http://www.groparu.ro/wp-content/uploads/2007/04/bocitoare.jpg',0,'post','image/jpeg',0),(345,1,'2007-04-25 15:01:29','2007-04-25 13:01:29','- Buna ziua, avetz pufuletz?\r\n- Numa\' cu surprize, \'ce domnishoara.\r\n- Si cand primitz din aia fara marketing?\r\n- Nush, \'ce ieara, intrebati-o pe shefa, e doamna aceea de la tejghea.\r\n- Nu, ii zic io, nu o-ntreb. Stii de ce?\r\n-?!?\r\n- Ca e najpa.\r\n- !\r\n- E najpa si se poarta urat cu voi. Am vazut.\r\n- !!\r\n- E najpa si se poarta urat cu voi si niciodata nu zambeste. Dumneavoastra amu ati zambit, ceea ce imi confirma.\r\n- :D\r\n- La...\r\n- ?\r\n- ...revedere!','La MahazÃ¢n',0,'','publish','open','open','','la-mahazan','','','2007-04-25 15:01:29','2007-04-25 13:01:29','',0,'http://www.groparu.ro/?p=345',0,'post','',2),(346,1,'2007-04-25 18:17:19','2007-04-25 16:17:19','                            Io is unchiu:                                                                                                                                                                                                                                                                                              El e nepotu\':\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/04/groparu.JPG\" title=\"www.groparu.ro blog romanesc Romanian blog groparu\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/04/groparu.JPG\" alt=\"www.groparu.ro blog romanesc Romanian blog groparu\" height=\"421\" width=\"226\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/04/nepotu.JPG\" title=\"www.groparu.ro blog romanesc Romanian blog groparu\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/04/nepotu.JPG\" alt=\"www.groparu.ro blog romanesc Romanian blog groparu\" height=\"423\" width=\"220\" /></a>\r\n\r\nNoa, asa stau lucrurile. Nepotu\' e mai destept decat unchiu, si io ma mir cum de.\r\n\r\nM-o batut de 34 de ori la rand la \"Nu te supara, frate!\", pana m-am suparat si am inceput sa plang si s-o chem pe maica-mea. Asa ca ne-am jucat alt joc, tot cu zaru\', cu regulile scrise in germana. Io ii citeam ce scrie la patratica aia rosie cu o mamarutza pe ea, sau la aia cu elefantzelu\', el traducea si ma trimitea de la inceput; cand ajungea in aceleasi casute, pe el il arunca cu 8 pozitii mai in fatza. Dupa 18 victorii, am plans iara si i-am zis ca vreau sa iesim sa jucam folbal.\r\n\r\nLa folbal, nu am avut de ales si l-am faultat - era 17-2 pentru el - tocmai cand facea o foarfeca pe spate (ii purtam rÃ¢cÄƒ finca ma batuse la sudoku in dimineata aceea). Asta desi imi explicase cu o zi inainte cum se agata o gajica in 3 minute, chiar daca e cu prekinu langa ea. Cand s-a stricat faza lunga la Dacie, o ridicat capota, si-o suflecat mainile si o refacut sistemul electric, o rectificat bieletele de directie si o curatzat si bujiile, si ne-o zis ca sa nu mai bagam benzina de la Petrom - statia aia de pe str. Alba Iulia, ca o citit pe forum ca aia o amesteca cu apa.\r\n\r\nIn timpul liber face miniaturi pe bobul de orez, joaca scrabble in latina si face mozaicuri. Nimic nu ii place mai mult decat sa faca puzzle-uri de 14.000 bucati cu reproduceri dupa pictura prerafaelita. Autorii preferati sunt Joyce si Kafka, dar nu ii displac nici eroul byronian sau romanticii germani. Cad se plictiseste, rezolva probleme de fizica cuantica si de trigonometrie, gen aflarea volumului unei semisfere, aflarea volumului unui butoi, geometrie in spatiu si ecuatii de gradul trei.\r\n\r\nRazvan Lucescu il suna frecvent sa il consulte, si odata chiar a acordat asistenta unui avocat din State in timpul unui proces celebru, scapandu-i clientul (OJ Simpson parca il chema) de la injectia letala. El mi-a aratat si punctul G de la femei, mi-a explicat gramatica franceza veche si procesul de fermentare al maltzului de bere. Mi-a demonstrat lipsurile vietii pe baza de carbon si  de ce Cro-Magnon nu merita sa supravietuiasca Neanderthalilor, dar un capriciu al naturii a facut ca rasa alba sa reuseasca, desi vom avea mereu fantezii sexuale cu femelele rasei galbene.\r\n\r\nPasiunea pentru istorie l-a facut cel mai respectat biograf al lui Napoleon, si expertii in elenistica il suna de fiecare data cand nu isi mai amintesc exact cate un vers din Iliada si Odiseea - bine-nteles, in greaca veche. A trebuit sa refuze participarea la studiul manuscriselor de la Marea Moarta deoarece fusese invitat de bulgari sa le ofere consultanta pentru inchiderea centralei atomonucleare de la Kozlodui.\r\n\r\nSi - cel mai important - m-a vindecat de sechelele copilariei mele zbuciumate (lipsa figurii tatalui, tendintele homosexuale reprimate si agorafobie).','Nepotu\' lu unchiu\'',0,'','publish','open','open','','nepotu-lu-unchiu','','','2007-04-25 21:27:44','2007-04-25 19:27:44','',0,'http://www.groparu.ro/?p=346',0,'post','',6),(347,1,'2007-04-25 16:02:53','2007-04-25 14:02:53','www.groparu.ro blog romanesc Romanian blog groparu','www.groparu.ro blog romanesc Romanian blog groparu',0,'','inherit','open','open','','wwwgroparuro-blog-romanesc-romanian-blog-groparu','','','2007-04-25 16:02:53','2007-04-25 14:02:53','',-1177509360,'http://www.groparu.ro/wp-content/uploads/2007/04/nepotu.JPG',0,'post','image/jpeg',0),(348,1,'2007-04-25 16:18:37','2007-04-25 14:18:37','www.groparu.ro blog romanesc Romanian blog groparu','www.groparu.ro blog romanesc Romanian blog groparu',0,'','inherit','open','open','','wwwgroparuro-blog-romanesc-romanian-blog-groparu-2','','','2007-04-25 16:18:37','2007-04-25 14:18:37','',-1177509360,'http://www.groparu.ro/wp-content/uploads/2007/04/groparu.JPG',0,'post','image/jpeg',0),(349,1,'2007-04-26 10:29:44','2007-04-26 08:29:44','<a href=\"http://www.groparu.ro/wp-content/uploads/2007/04/spammer.JPG\" title=\"Www.Groparu.Ro, blog romanesc Romanian blog\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/04/spammer.JPG\" alt=\"Www.Groparu.Ro, blog romanesc Romanian blog\" /></a>\r\n\r\nFinca am o versiune mai veche de wordpress, si finca mi-i lene sa upgradez, si finca nij nu stiu cum se face si nu am kef sa rog pe nimeni sa imi upgradeze (sau finca fostele mele prekine s-or gandit ca nu mi-ar strica), primesc o gramada de spam pe www.groparu.ro, spam legat de lungirea penisului, cumparat Xanax si Cialis, sh alte porcarii sexuale care nu ma intereseaza decat peste 30 de ani (sper).\r\n\r\nAzi am loat o adresa de mail (<tt><span style=\"border-bottom: 1px dashed #0066cc; background: transparent none repeat scroll 0% 50%; cursor: pointer; height: 1em; -moz-background-clip: -moz-initial; -moz-background-origin: -moz-initial; -moz-background-inline-policy: -moz-initial\" id=\"lw_1177519615_0\">bobryan at foreve.com) </span></tt>de la un spammer, si am inscris-o la situri care:\r\n\r\n- vand si ele pastile hermafrodisiace, da\' la jumate pretz;\r\n- vand imitatii de ceasuri originale;\r\n- ofera diplome universitare chiar daca esti parlamentar roman cu IQ de gandac de bucatarie (din soiul ala pitoresc denumiti \"ruÅŸi\");\r\n- ofera un pachet de 4000 de canale TV prin Internet;\r\n- l-am inscris intr-o retea de chat pentru adulti ca si tanara de 19 ani care cauta cuplu;\r\n- l-am abonat la doua loterii pentru Visa card;\r\n- am dat adresa lui la 4 siteuri matrimoniale;\r\n- l-am inscris in 3 online pharmacies, 2 siteuri cu joburi ca IT engineer si pe inca 3 ca angajator;\r\n- i-am dat adresa unui site al martorilor luiIehova;\r\n- l-am inscris ca voluntar pentru testat medicamente la un centru de cercetare impotriva cheliei;\r\n- am trimis o petitie in numele lui in care cerea sa se legalizeze pornografie cu copii la Avocatul Poporului Uniunii Europene.\r\n\r\nSper sa ii prind si nevasta intr-o buna zi, sa o seduc. Fara Xanax.','Spam Spam, I shot you down',0,'','publish','open','open','','spam-spam-i-shot-you-down','','','2007-04-26 10:29:44','2007-04-26 08:29:44','',0,'http://www.groparu.ro/?p=349',0,'post','',4),(350,1,'2007-04-26 10:28:44','2007-04-26 08:28:44','Www.Groparu.Ro, blog romanesc Romanian blog ','Www.Groparu.Ro, blog romanesc Romanian blog ',0,'','inherit','open','open','','wwwgroparuro-blog-romanesc-romanian-blog','','','2007-04-26 10:28:44','2007-04-26 08:28:44','',349,'http://www.groparu.ro/wp-content/uploads/2007/04/spammer.JPG',0,'post','image/jpeg',0),(351,1,'2007-04-26 18:40:58','2007-04-26 16:40:58','...daca ma cauta neshte oameni in halate albe, sa nu le spuneti unde sunt pls.','Am plecat la chef cu firma',0,'','publish','open','open','','am-plecat-la-chef-cu-firma','','','2007-04-26 18:40:58','2007-04-26 16:40:58','',0,'http://www.groparu.ro/?p=351',0,'post','',0),(352,1,'2007-04-27 12:06:52','2007-04-27 10:06:52','Dar-ar DumnezÄƒu sa-ti dea\r\nCasa, bani si-o acadea;\r\nSa nu mÃ¢nci grÄƒsimi si sare,\r\nS-ai si locuri de parcare,\r\nSa nu iei amenzi in veci\r\nSi tot timpul sa petreci!\r\nS-ai tot timpul de mancare,\r\nSi sa fii si rupt din soare,\r\nSa te tina putzulica,\r\nSa fii mandru ca pisica,\r\nS-ai mereu chiloti curati,\r\nBanii sa iti fie frati!\r\nNevasta sa te iubeasca,\r\nSi copii multi-multi sa creasca,\r\nS-ai, ziceam, averi si bani,\r\nHai noroc si la multi ani!','Azi e ziua lu\' Sorinelu',0,'','publish','open','open','','azi-e-ziua-lu-sorinelu','','','2007-04-27 12:06:52','2007-04-27 10:06:52','',0,'http://www.groparu.ro/?p=352',0,'post','',0),(353,1,'2007-04-27 15:46:43','2007-04-27 13:46:43','Ii uram luâ€™ Diana  noastra\r\nMititei si carne  fleici!\r\nGresia sa nu i se  crape,\r\nSa nu sforaie pe  spate,\r\nSa arate bine-n  poze\r\nCa garoafa-ntre mimoze,\r\nSa isi ieie si masina\r\nSa castige daca joaca mima,\r\nSanatate ca la tzara,\r\nSa nu aiba par in <st1:city w:st=\"on\"><st1:place w:st=\"on\">nara</st1:place></st1:city>,\r\nAvere multa sa stranga\r\nToata viatza sa-i ajunga,\r\nSa se reproduce-odata!\r\nS-aibe si baiat si fata,\r\nAsfalt peste toata strada\r\nSi o geanta de la Prada\r\nSa stranute daca-i vine,\r\nFericire s-ai in tine!<font face=\"Times New Roman\" size=\"3\"><span style=\"font-size: 12pt\"> <o:p></o:p></span></font>','Astazi e si ziua lu\' Diana',0,'','publish','open','open','','astazi-e-si-ziua-lu-diana','','','2007-04-27 15:46:43','2007-04-27 13:46:43','',0,'http://www.groparu.ro/?p=353',0,'post','',4),(354,1,'2007-04-27 20:39:37','2007-04-27 18:39:37','Is fazani aia de are conturi la rai-fazan - inclusiv io.\r\n\r\nDe ce, va veti intreba? (opservati ca am scris corect \"veti\")\r\n\r\nEi bine, va zic. Numa sa ma gandesc cum.\r\n\r\nM-am gandit.\r\n\r\nDeci asara, am fost la un chef cu firma, sh m-am cam makit. Nu mult. Suficient cat sa le bat pe chelneritze la cap sa imi viziteze saitu\', suficient cat ma imprietenesc la toarta cu doi mosnegei care tot vroiau sa imi cumpere bere la bar, si io le ziceam sa voteze www.groparu.ro la sectiunea cel mai prost blog dinCluj, si suficient cat sa il innebunesc pe taximetrist sa intre pe acelasi site si sa ma voteze la aceeasi rubrica. Dar seara - cum aveam sa  aflu mai incolo, urma sa ia o intorsura cel putin la fel deÂ  neasteptata precum Intorsura Buzaului.\r\n\r\nAjung acasa, si imi desfac plicu\' de la Raiffeisen. Stimate client, lalala, oferta de M-banking - adeca sa faci viramente de lei de pe mobil. Nu ma dau io in vant dupa gadgeturi, nij macar mp3 player nu am, da\' pe foicica scria un nr. verde apelabil fara taxa de pe Orinj sh Vodafon. Atata mi-o trebuit! Cum aveam chef de vorba la ora aia, tzushti - pun mana pe telefon, formez si sun. Stau, si raspunde o gajica cu un vaier d-ala de iepure domestic prins de outze:\r\n\r\n- Raiffaizan, lalala, bine ati venit.\r\n- Buna diminiatza, zic io, cu chef de vorba, sunt Groparu, vreau sa aflu mai multe, ca am primit un plic in posta cu oferta.\r\n- Da, zice, si se apuca si imi explica ca unui om beat despre fizica cuantica a intregii promotii.\r\n- Bun, zic io dupa vo 2 minute, dar care e adresa de WAP? Ca io n-am 3G pe telefonu\' mobil, si vreau sa raman asa, cu prekina si telefon cu un singur G.\r\n- O secunda, zice.\r\n\r\n<em>Si stau pret de o secunda, si o aud cum ii zice unei colege \"Auzi, tu ce tupeu pe asta!\"\r\n</em>\r\n\r\n- Domnisoara! Ii zic.\r\n\r\nNimic. Se aud taste, si cum se foieshte pe scaun.\r\n\r\nBai frate, o pereche de muci aveam in nas, si in secunda aia mi-or sarit pe pereti!!! \'Tuz ranitii revolutiei azi si mane, d-aia am bagat capitalismu?\r\n\r\n- DOMNISOARAAAA!!!!\r\n- Spuneti, zice domnisoara.\r\n- Am retinut bine, va numiti Luca? O-ntreb.\r\n\r\n(tot timpu\' e bine sa retii numele persoanelor, asa or zis doftorii - mai ales cand suni la call center si te flituiesc astia, adauga Groparu)\r\n\r\n- Da...\r\n- Domnisoara, cum adica \"ce tupeu are asta?\" HAAA???\r\n- ...\r\n- Domnisoara, CUM ADICA \"CE TUPEU ARE ASTA\"???\r\n- ...mergeti la banca, si acolo va vor da ei simul... incearca sa dreaga d-ra Luca busuiocu\', numa\' ca nu prea-i iesea!\r\n- Domnisoara, zic, domnisoara, va stiu numele, si apelul asta e inregistrat, ma gandesc. In primul rand va cheama Luca, si pun pariu ca la scoala colegii faceau misto de dvs, spunandu-va \"Luca si Matei\", desi acest fapt nu are nici o relevanta pentru discutia noastra. Ce are relevanta e faptul ca va permiteti sa vorbiti asa cu mine, eu, care sunt client! D-ra, si eu am mica mea afacere (deja luasem un ton grav, napoleonian), si daca ma suna clientii in miez de noapte nu imi permit sa le dau cu flit. Daca nu va convine jobul, sunt o gramada mai bine platite si mai domnesti. Eu, spre exemplu, intr-o vreme am fost chiar profesor, dar nu mi-am permis sa imi bat joc prea tare de copkii, kiar daca castigam 2 milioane pe luna, si chiar daca unii dintre ei aveau creieru\' cat un pixel si ma loveau intentionat la fluier cand jucam folbal cu ei.\r\n- ...\r\n- NU MI-AM PERMIS!\r\n(nu-mi mai amintesc exact, parca o baiguit ceva scuze de-a lela, de-a toata lela)\r\n- Dumneavoastra va dati pe Internet?\r\n-???\r\n- Internet, d-ra, Internet. Va dati pe Internet?\r\n- Da...\r\n- Ei bine, www.groparu.ro, ii zic. WWW.GROPARU.RO. Asta sunt eu. Daca mai aveti vreodata nefericirea de a vorbi la fel cu mine, va jur ca va fac plangere la sefii dumneavoastra, si va vor beli de vie si va vor pune sa ingrijiti batrani in Spania, de aia care fac caca pe ei. Si mai e ceva, domnisoara Luca.\r\n- ...\r\n- Da, zic eu, mai e ceva. Intrati pe www.clujblogfest.ro, si acolo sa ma votati la sectiunea \"cel mai prost blog\".  Asta o veti face acum, da\' acum-acum! Si vedeti ca monitorizez voturile, daca va pune Zaratustra sa nu vad IP de Bucuresti in 5 minute pe lista de votanti veti mai auzi de mine. Ne-am inteles?\r\n- ... da...\r\n- Va doresc o noapte frumoasa, zic eu, eu ma pun sa dorm (tu nu!). Si sper sa ne re-auzim in conditii mai placute.\r\n\r\nStiu ca ar fi trebuit sa o mai fut la icre pe domnisoara Luca, finca daca pot ierta orice la o femeie, nu pot ierta o chestie:  O FEMEIE TREBUIE SA STIE SA REFUZE FARA SA SE COMPORTE CA OANA ZAVORANU. Dar ca m-am multumit  sa ii tag o tzapa de zile mari: la ora aia, procesul de votare se inchisese. Nu mai avea cum sa ma voteze, hihihi!','Fazan. Rai-fazan',0,'','publish','open','open','','fazan-rai-fazan','','','2007-04-27 20:39:37','2007-04-27 18:39:37','',0,'http://www.groparu.ro/?p=354',0,'post','',7),(355,1,'2007-04-28 12:36:40','2007-04-28 10:36:40','Da. Inca unu se duce...\r\n\r\nTrebe sa ma barbieresc si sa incerc sa par prezentabil, chiloti curati, sa-mi curatz poseta, sa ma dau cu spuma de par, sa imi tai unghiile alea cu negru pe supt ele, sa nu-mi ramana scame de pe prosop in barba sau in buric, tat bullshitu\' - desi stiu ca nu voi reusi in deplinatate.\r\n\r\nAm trei fire de par rebele:\r\n\r\n- unul e pe gat, face tranzitia intre paru\' de pe piept cu ala de pe barba, sh deshi il tot smulg constant, se incapataneaza sa revina, si se vede pe deasupra nodului cravatei;\r\n- unu e in cioc, ca mi-am lasat cioc, ca vine <a href=\"http://www.groparu.ro/?cat=4\" target=\"_blank\">Tiganiada</a>, si acolo chiar trebe sa arat prezentabil: imi sta sculat si incet-incet mi se infige in nas, ca e chiar la mustata, si nu am foarfeca, asa ca inca incerc sa ma gandesc cum sa il tai, mai ales ca nu imi pot urca gura pe scaun sa il retez cu incisivii;\r\n- al treilea e chiar la mijlocu bretonului: cand eram prof, cheleam cu strasnicie in lateral, da\' de cand nu mai is prof nu mai chelesc, o inceput sa imi creasca fix in mijlocu\' fruntii un smoc rebel, si ambasadoru e un fir de par care oricum il pun, tot sta ca la Bela Lugosi, bampiru\'.\r\n\r\nAm o singura intrebare pentru nuntasi: cati dintre ei recomanda cu adevarat Colgate?','Ma duc la o nunta de dentisti',0,'','publish','open','open','','ma-duc-la-o-nunta-de-dentisti','','','2007-04-28 13:03:15','2007-04-28 11:03:15','',0,'http://www.groparu.ro/?p=355',0,'post','',6),(357,1,'2007-04-30 18:06:25','2007-04-30 16:06:25','Zice articolu\' <a href=\"http://uk.reuters.com/article/oddlyEnoughNews/idUKDEL12620520070430?feedType=RSS\" target=\"_blank\">asta</a> cum ca un ginerica, de loc din India, o vint la nunta lui beut, si vajnicii sateni paznici ai decentei hinduse l-au izgonit de pe altarul de sacrificiu. Tot ei or maritat biata (dar pretentioasa) mireasa cu fratele mirelui in chiar aceeasi zi, fratele fiind un pic mai sobru si probabil mai dornic de o feliutza de hindusa decat frati-su\', alcoolic anonim fara nume.\r\n\r\nNoa, iata de ce nu ma insor io in India! In primu\' rand ca iti aleg parintii nevasta. Daca imi alege taica-mio nevasta, pot spera la una ca maica-mea, ceea ce scoate definitiv din discutie institutia sacra a casatoriei. Daca mi-o alege maica-mea, pot spera la una ca taica-mio, ceea ce e si mai fara de speranta. Si daca mi-o aleg amandoi, e jale: va fi o criptocomunista careia ii place Margareta Paslaru si Margareta Similea, o inginera careia trebe sa ii dau tot salaru\' si care si circula fara aer conditionat in masina vara, ca <em>o trage curentu\'</em>.\r\n\r\nIn al doilea rand pentru ca acolo nu se intelege cum trebuie institutia sacra a casniciei. Pai cum phuii mei sa convingi un ficior cumsecade sa se insoare, daca nu-l droghezi??? Aud? Ce tzara e aia in care nu se stie ca daca nu e sotul cherchelit un pic nu e mega-iubitor?\r\n\r\nIn al treilea rand, pentru ca daca furi mireasa, poate singura oferta de rascumparare e o vaca din aia sacra si costeliva, da\' cu coarne mari, de patesti ca ala care o primit mostenire un elefant care manca fructe in valoare de 300 dolarei pe zi, si nij macar nu dadea lapte de elefanta, sa zici ca noa! macar papi si tu o telemea de pachiderma, sa scoti parleala.\r\n\r\nIn al patrulea rand din cauza punctului aluia care si-l picteaza o indianca intre sprancene, semn ca ii maritata, <em>bindi</em> ii zice. Mie nu-mi plac punctele, io i-as impune sa isi puna o virgula acolo,  ea n-ar fi de acord, ar plange si ar face scandal, io as bate-o, sa-i arat cine e barbat in casa, ea ar pleca la ma-sa, s-ar divorta de mine si io as plati o viatza intreaga pensie pentru o loaza care nu intelege importantza ortografiei pe frunte!!!\r\n\r\nIn al cincelea rand, pentru ca daca patesc si io ca luzaru\' asta din poveste, s-ar putea sa imi descopar ca am vreun frate. Io nu am frati, da\' io stiu ce sa mai cred? Ca taica-meu ofteaza cand il intreb.\r\n\r\nIn al saselea rand, pentru ca daca dau coltzu\' inaintea lu\' nevasta, cum de alfel se si intampla in general cu masculii, nevasta trebe gatita. Nu de inmormantare, ci gatita la foc, ca cica p-acolo ii o onoare sa te arda pe rugul funerar a lu\' barbatu-to. Si nu cand moare si ea, ne-ne-ne!!! Inainte, cand e vie, si indoliata de bucurie ca o ramas singura si nu va mai certati pe telecomanda. Asa ca - la ce bun? Tocma cand sperai ca mai prinzi si tu cativa anisori singur prin rai pana sa vie madama, sa mai scoti cate o injerica sau o dracoaica la cate o cafea sau un nectar de portocale, tzanc! Vine si nevasta deodata cu tine, de iti si zice ranjind ca-n Caragiale \"Credeai c-am murit, neica???\"','De ce nu ma insor in India',0,'','publish','open','open','','de-ce-nu-ma-insor-in-india','','','2007-04-30 18:06:25','2007-04-30 16:06:25','',0,'http://www.groparu.ro/?p=357',0,'post','',2),(356,1,'2007-04-29 23:49:38','2007-04-29 21:49:38','Da, am castigat!!!!\r\n\r\nAm castigat titlul de cel mai prost blogger din Cluj. CEL MAI PROST!!! Yesssss...\r\n\r\nDeci in primu\' rand o trebuit sa merg la nunta de dentishti, ca dentistu\'  mire ii fiu\' lu doftoru\'  de famelie a lu\' mama, pe care o iubesc, ca de fapt i-o doamna, si daca nu ma duceam, nu imi mai prescria cu la fel de multa usurintza codeina cu vodca. Si Andrei Crivat ma tat suna, si io aviam emotii, ca nu puteam pleca pana sa nu ma scap de euroii ca cadou, ca cinste (bineinteles ca ai mei or facut cinste cu cinstea, si io mi-am loat din plic partea mea).\r\n\r\nDar am ajuns, si cand am intrat in restaurant, media de varsta de acolo s-o dublat. Nu-i stress, am cunoscut si alti bloggeri din Cluj, inclusiv pe <a href=\"http://jeg.stuffo.info/\" target=\"_blank\">Darius</a>, care o si castigat premiu\' al mare bashca altele, felicitari!\r\n\r\nDragii mei, multumesc celor care m-or votat, insamna ca cel putin 30 de oameni ma cetesc (aia insamna cate voate am strans la categoria de castigare). Sunt super hyper happy ca am loat cel mai prost, finca:\r\n\r\n1. Cele mai cetite bloage din Romania is alea cu folbal. Io la folbal ma stiu ca la fizica  nucleara (chiar si mai putin). Prin extrapolarea corolaului, claro ca cele mai antifolbal is cele mai putin cetite, deci mai pruaste - vezi www.groparu.ro;\r\n\r\nSar peste doi - marketingul. Nu din cauza faptului ca \"cel mai prost blog\" ii cea mai nonconformista forma de marketing, ceea ce ii bine pentru sait: io veci pururi nu voi scoate milioane din sait, una la mana, a doa la mana nu caut celebritatea, finca aia insamna ca nu ma mai pot imbata in public si nu ma mai pot uita la studente prin decoltee, ca imediat scrie in ziare, si a treia la mana nu mai stiu, am uitat;\r\n\r\n3. Maica-mea nu ma citeshte, ca ii par meschin, rauvoitor si anti-iliescian; asa ca daca maica-mea, care de fapt i-o doamna, nu da nij treizeci de arginti pe ce scriu, nu vad de ce ar da jumatea aia mai mare a Manasturului si a cartierului sau, Cluj-Napoca (vox poPULII, vox dei). Se cheama auto-evaluare. La fel nu ma citesc nici var-mio Ovidiu (e workaholic), nici Niatza (prekinu\' meu inca de pe bancile gradinitei), nici Sergiu (sa-l vad io p-ala care il poate capta pe Sergiu sa il citeasca!! s-aude, domnu\' Wittgenstein, esti happy?), si - ceea ce ma si enerveaza - nici fetele alea care pozeaza in Libertatea.\r\n\r\n5. In viatza mea nu am loat premiu\' I, si nu am de gand sa il ieu amu, la batranetze, ca daca coronitze nu mi-o pus nimenea pe cap, mi-am primit coarne destule la viatza mea (sau nu...?)\r\n\r\n6. Io mi-am spart capu\' cand eram (nu cu mult) mai mic, si nu pot presupune ca votantii blogfestului or cazut si ei in cap, ca sa le placa ce scrie o cazatura (in cap) cu state vechi;\r\n\r\n7. Stallone ia constant Zmeura de Aur ca cel mai prost actor, si Stallone e actorul meu cel mai preferat, ca ii bate pe rusii care ne-or furat tezauru\'; Sylvester, tie iti dedic diploma de cel mai f*** blogger! U and me are alike, buddy...\r\n\r\nAndrei, nush ce Crivatz te-o adus p-acilea prin urbe, da\' ii bun vantu\'. Good job pantru organizare! (la anu\' vreau si un kil de masline sa pot bea whiskey-ul primit ca premiu). Felicitari tuturor  celor care au participat, sau n-au participat, celor  care au castigat, sau n-au castigat, si baaa!!! Nu mai nominalizati blogu\' lu shafu\' meu (blog.pacurar.net) la cele mai pruaste bluage, ca va sparg! Ca nu imi mai da concediu daca se supara, sh-apa trebe sa-mi iau medical!','Am castigat!!!',0,'','publish','open','open','','am-castigat','','','2007-04-30 00:11:43','2007-04-29 22:11:43','',0,'http://www.groparu.ro/?p=356',0,'post','',4),(358,1,'2007-04-30 20:04:17','2007-04-30 18:04:17','<a href=\"http://www.visurat.ro\" target=\"_blank\">Vis Urat</a> e - votat - cel mai blogger din tzara. Auzind si el de Groparu, i-a loat un interviu in calitatea mea de cel mai prost blogger din perimetrul Bistritza-Huedin-Cheile Turzii, si si l-a pus pe sait. Avetz aci (nu chiar aici, no! otzara mai jos) transcrierea yahoomessengereasca a intregului dialog dintre doua persoane: cel mai blogger cu cel mai  gropar.\r\n\r\n<strong>Vis Urat</strong>: gata\r\n<strong>Vis Urat:</strong> sa incepem\r\n<strong>Groparu Nemernic:</strong> asa\r\n<strong>Groparu Nemernic:</strong> (inspir adanc)\r\n<strong>Vis Urat:</strong> din start vreau sa te anunt ca absolut ce vei spune va fi pus pe blogul meu, fara cenzura, fara modificari\r\n<strong>Groparu Nemernic:</strong> ashijderea si aci\r\n<strong>Vis Urat:</strong> ok\r\n<strong>Groparu Nemernic:</strong> numa ca varianta mea va fi mai originala\r\n<strong>Vis Urat:</strong> asta inseamna ca o vei modifica\r\n<strong>Groparu Nemernic:</strong> nu, va fi pusa mai cu pasiune!\r\n<strong>Vis Urat:</strong> hehehe\r\n<strong>Vis Urat:</strong> ok\r\n<strong>Vis Urat:</strong> cum te simiti (dupa sticla de whiskey) drept castigator al premiului \"Cel mai prost blog\" din cadrul Cluj BlogFest?\r\n<strong>Groparu Nemernic:</strong> Eu dupa sticla de whiskey primita ca premiu pentru cel mai prost, najpa, non-IQ castigator ma simt asa cum m-am simtit atunci cand maica-mea o urlat la mine cand i-am adus acasa hamsteru\' meu, Lady o chema, ca era o ea: voi continua indiferent de ce se intampla!\r\n<strong>Groparu Nemernic:</strong> prin urmare - umplut de perseverenta\r\n<strong>Vis Urat:</strong> sincer vorbind, ti`ai pus prietenii sa te voteze?\r\n<strong>Groparu Nemernic:</strong> dap, pe toti\r\n<strong>Vis Urat:</strong> deci ai castigat categoria \"cel mai prost blog\" trisand....\r\n<strong>Groparu Nemernic:</strong> de ce? numa finca le-am pus pistolu\' la tampla??\r\n<strong>Groparu Nemernic:</strong> Nuuuu...\r\n<strong>Vis Urat:</strong> ma gandeam eu...\r\n<strong>Vis Urat:</strong> ce ai simtit cand ai aflat ca esti cel mai bun prost blogger din Romania?\r\n<strong>Groparu Nemernic:</strong> nodul de la cravata mi s-o infipt in gat (eram la o nunta) si nu o vrut sa mai iese pana nu l-am fentat cu cateva sticle de bere (gratis, ca erau in meniu). Dupa aceea, mi-am zis: \"deci lucrurile nu stau chiar asa de prost in Romania!\" si mi-am anulat cererea de emigrare in Bulgaria<strong>\r\nVis Urat:</strong> faptul ca ai fost desemnat cel mai prost blogger din Cluj, nu te face sa te intrebi daca restul care n`au castigat au fost mai prosti ca tine si, in concluzie, mai putin cititi decat tine? (tinand cont ca a fost vot de popularitate)\r\n<strong>Groparu Nemernic:</strong> Nu, deoarece asa cum am scris in blog nu cred ca o mai cazut cineva in cap (cand era mic) asa cum am cazut eu, si o supravietuit. Prin urmare, sunt singurul care merita sa ia din cauza ca 1. Ideatzia mea schioapata la greu; 2. Am picat de doua ori la facultate, si nu din cauza ca eram cel mai bun din emisfera; 3. Nu prea se rade la bancele mele decat deloc cand merem la bere, numa\' eventual dupa ce lumea se imbata bine. Clujblogfest-ul fiind festival de oameni treji (si la minte), mi s-a reconfirmat pozitia mea in societatea asta post (sau ante???) pesedista\r\n<strong>Vis Urat:</strong> nu ai nici cea mai mica urma de indoiala cum ca ai castigat pe nedrept?\r\n<strong>Groparu Nemernic:</strong> sunt un om vertical\r\n<strong>Groparu Nemernic:</strong> <em>nu conteaza cine voteaza, conteaza cine numara voturile</em>\r\n<strong>Vis Urat:</strong> corect (din cauza asta astept cu sufletul la gura acest referendum)\r\n<strong>Groparu Nemernic:</strong> inghite repede!!!!\r\n<strong>Vis Urat:</strong> crezi ca JEG a castigat pe nedrept la categoriile la care a fost nominalizat?\r\n<strong>Vis Urat:</strong> (zi da, zi da)\r\n<strong>Groparu Nemernic:</strong> nu cred!\r\n<strong>Groparu Nemernic:</strong> am cetit\r\n<strong>Groparu Nemernic:</strong> scrie fain\r\n<strong>Vis Urat:</strong> in legea lui...\r\n<strong>Groparu Nemernic:</strong> de ce ar fi castigat pe nedrept?\r\n<strong>Vis Urat:</strong> dar nu despre el e vorba, sa vorbim despre tine\r\n<strong>Groparu Nemernic:</strong> asaaaa.... indreptati din nou reflectoarele, va rog...\r\n<strong>Groparu Nemernic:</strong> doi-zece\r\n<strong>Vis Urat:</strong> a fost vreo chermeza unde s`au inmanat premiile?\r\n<strong>Vis Urat:</strong> v`a adunat careva la un loc in cadru festiv, sau ai auzit la telefon?\r\n<strong>Groparu Nemernic:</strong> O fo\', no! O fo. Am si mars acol\', si era purcoi de bloggeri si bloggeritze acolo, de nu mai deosebeai om de femeie\r\n<strong>Vis Urat:</strong> au ras de tine sau au aplaudat in delir?\r\n<strong>Groparu Nemernic:</strong> din pacate, am ajuns la spartul targului, finca am avut de mers la o nunta (Dumnezeu sa-i ierte!), si am mers si cu gajica-mea, care mi-o interzis sa vorbesc cu cineva de pe-acolo (\"Groparu, mai tii minte ce o zis nenea doctoru\'... ca e bine sa eviti multimile zgomotoase? Da? No hai, ia-ti medicatia si stai cuminte langa mine\")\r\n<strong>Vis Urat:</strong> macar ai fost felicitat de cei care mai erau prin zona?\r\n<strong>Groparu Nemernic:</strong> Da!\r\n<strong>Groparu Nemernic:</strong> Ranjetul lor condescendent a fost suficienta felicitare\r\n<strong>Vis Urat:</strong> ce planuri de viitor ai?\r\n<strong>Vis Urat:</strong> (referitor la blog)\r\n<strong>Groparu Nemernic:</strong> Tre\' sa anihilez berea asta care se holba la mine cu nesimtire (am fo la gratar ieri si asta s-o ascuns sub un morman de beri moarte, de o scapat cu viatza)\r\n<strong>Groparu Nemernic:</strong> aaa, la blog?\r\n<strong>Vis Urat:</strong> pentru ca nu ma intereseaza unde vrei sa muncesti sau cati copii (eventual ai cui) vrei sa cresti\r\n<strong>Groparu Nemernic:</strong> ca mai erau\r\n<strong>Groparu Nemernic:</strong> sa platesc rata...\r\n<strong>Groparu Nemernic:</strong> aha\r\n<strong>Groparu Nemernic:</strong> deci la blog\r\n<strong>Groparu Nemernic:</strong> tre\' sa fac un update la wordpress ca imi tot vin spammuri cu Penis Enlargement, si eu nu am nevoie, VisUrat, nu am nevoie!\r\n<strong>Vis Urat:</strong> te cred pe cuvant, pentru ca si mie`mi vin, si nici eu n`am nevoie\r\n<strong>Groparu Nemernic:</strong> (spamming assholes...)\r\n<strong>Vis Urat:</strong> cum te`ai simti daca ai castiga si la editia urmatoare, eventual si peste doi ani acelasi premiu?\r\n<strong>Groparu Nemernic:</strong> ca nu am imbatranit deloc...?\r\n<strong>Vis Urat:</strong> vrei sa transmiti vreo critica sau vreo urare celorlalti participanti, celorlalti castigatori sau celor care te`au votat?\r\n<strong>Groparu Nemernic:</strong> celor care m-au votat\r\n<strong>Groparu Nemernic:</strong> BA PORCILOR!! AM 300 DE OAMENI IN LISTA DE YM, SI ABIA AM COLECTAT 39 DE VOTURI AMARATE, CA IMI SUFLA DARIUS II IN CEAFA (si ii si mirosea urat respiratia) SI IO MA CRIZAM CA NU VOI CASTIGA? PAI D-AIA VA DAU IO BERULE??? HAAA???\r\n<strong>Groparu Nemernic:</strong> (am avut status pe YM 5 zile la rand cu linkul unde ma pot vota la cel mai prost)\r\n<strong>Vis Urat:</strong> multumesc pentru timpul acordat\r\n<strong>Groparu Nemernic:</strong> placerea a fost de partea mea (sa nu uitam sa ne incheiem la shlitze)\r\n<strong>Vis Urat:</strong> nu uitam','Interviu rupt din Vis Urat',0,'','publish','open','open','','interviu-rupt-din-vis-urat','','','2007-04-30 20:33:02','2007-04-30 18:33:02','',0,'http://www.groparu.ro/?p=358',0,'post','',3),(359,1,'2007-04-30 21:51:24','2007-04-30 19:51:24','...m-am tot gandit si m-am socotit, si mi-am dat seama ca, de fapt, masculii  are prea multi creieri, si i se preling in furtunash, d-aia gandesc (si) cu putza!','Stiti de ce masculii gandesc cu putza?',0,'','publish','open','open','','stiti-de-ce-masculii-gandesc-cu-putza','','','2007-04-30 21:51:24','2007-04-30 19:51:24','',0,'http://www.groparu.ro/?p=359',0,'post','',3),(360,2,'2007-05-01 14:05:01','2007-05-01 12:05:01','Recomand www.traianbasescu.ro, e hilar.\r\n\r\nPe www.basescu.ro is o groaza de marinari de apa dulce care il injura pe suspendat. Dar sunt afisati, nu cenzurati.\r\n\r\nPe mirceageoana.blogspot.com i-am lasat un comentariu lui Mirciulica: \"Totusi, de ce l-ati suspendat pe Basescu pe banii nostri, daca Curtea Constitutionala  recomanda ne-suspendarea?\" (cacofonie intentionata).\r\n\r\nComentariul trebuie moderat de administrator. Daca va aparea, jur ca am sa beau o bereÂ  pentru Mirciulica.\r\n\r\nIar acum, scrisoare trimisa lui Basescu in 2004, cand campainiza, si raspunsul primit:\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/05/mail-base.JPG\" title=\"Romanian blog blog romanesc Groparu\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/05/mail-base.JPG\" alt=\"Romanian blog blog romanesc Groparu\" /></a>','Eu, Mirciulica si Traienel',0,'','publish','open','open','','eu-mirciulica-si-traienel','','','2007-05-01 14:05:01','2007-05-01 12:05:01','',0,'http://www.groparu.ro/?p=360',0,'post','',2),(361,2,'2007-05-01 14:00:00','2007-05-01 12:00:00','Romanian blog blog romanesc Groparu','Romanian blog blog romanesc Groparu',0,'','inherit','open','open','','romanian-blog-blog-romanesc-groparu','','','2007-05-01 14:00:00','2007-05-01 12:00:00','',-1178019394,'http://www.groparu.ro/wp-content/uploads/2007/05/mail-basescu.JPG',0,'post','image/jpeg',0),(363,2,'2007-05-01 14:02:39','2007-05-01 12:02:39','Romanian blog blog romanesc Groparu','Romanian blog blog romanesc Groparu',0,'','inherit','open','open','','romanian-blog-blog-romanesc-groparu-2','','','2007-05-01 14:02:39','2007-05-01 12:02:39','',-1178019394,'http://www.groparu.ro/wp-content/uploads/2007/05/mail-basescu.JPG',0,'post','image/jpeg',0),(362,2,'2007-05-01 14:01:55','2007-05-01 12:01:55','Blog romanesc Romanian blog','Blog romanesc Romanian blog',0,'','inherit','open','open','','blog-romanesc-romanian-blog-2','','','2007-05-01 14:01:55','2007-05-01 12:01:55','',-1178019394,'http://www.groparu.ro/wp-content/uploads/2007/05/mail-basescu.JPG',0,'post','image/jpeg',0),(364,2,'2007-05-01 14:03:12','2007-05-01 12:03:12','Romanian blog blog romanesc Groparu','Romanian blog blog romanesc Groparu',0,'','inherit','open','open','','romanian-blog-blog-romanesc-groparu-3','','','2007-05-01 14:03:12','2007-05-01 12:03:12','',-1178019394,'http://www.groparu.ro/wp-content/uploads/2007/05/mail-base.JPG',0,'post','image/jpeg',0),(365,1,'2007-05-01 23:18:17','2007-05-01 21:18:17','Io inteleg arta cand se picteaza sani de femeie, se sculpteaza nuduri sau se fotografiaza herghelii de gajici care fac baie prin rauri goale tun, de le zice \"Nimfe in insula Lesbos\" si e OK sa le arati copiilor de clasa a 6-a, doara e mitologia greaca, ce naiba! Savurez Vagina Monologues, ma delectez cu simfonia gemetelor din jucatul de-a animalu\' cu doua spinari, ma incanta poezia clitoridiana si drama erectiei prelungite, inteleg ca un connoisseur busturi peste busturi peste busturi de fecioare imortalizate pe celuloid si sunt plin de compasiune cand vad viermuielile slinoase ale bietilor gang-bangeri.\r\n\r\nEi bine, nenea <a href=\"http://starbulletin.com/2007/05/01/news/story04.html\">asta</a>:\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/05/arta-pula.jpg\" title=\"http://starbulletin.com/2007/05/01/news/story04.html\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/05/arta-pula.jpg\" alt=\"http://starbulletin.com/2007/05/01/news/story04.html\" /></a>\r\n\r\nare o viziune a artei complet oarecum (100%) diferita de a mea. El intelege sa expuna arta expunandu-se cu o arma expusa in manutza aia cu care se tine de putulica cand face pishu; acelasi nene isi expune si mandrete de bust paros gol, si se plimba incoace si-ncolo printre vizitatorii unei expozitii de arta expusa in nush ce muzeu sau galerie, ca n-am cetit stirea pana la sfarsit.\r\n\r\nAmu daca tot ne-am apucat sa cream noi forme de arta, Groparu propune urmatoarele noi variante de gadilat simtul estetic intr-un mod placut, numite \"arte politice\", la care sa fie supusi parlamentarii nostri:\r\n\r\n- sex on the beach la liber la Polul Sud - cand e iarna;\r\n- somn obligatoriu o ora in fiecare zi in poligonul de la Cincu;\r\n- legat parlamentarii de stalpi, descaltati, dat talpile cu sare si lasat parlamentari in mijlocu\' unui ciopor de capre care sa le linga talpile;\r\n- interzis carnea de vaca nebuna din meniul bufetului Parlamentului;\r\n- bagat nisip in chiloti de parlamentar;\r\n- trimis parlamentari in spatiu, pierdut acolo;\r\n- aruncat parlamentar in turboreactor de Boeing, sa testam rezistenta metalului la impact;\r\n- fortat parlamentar sa scrie articole in Cosmopolitan, Elle, Lumea Femeilor, reviste de deocratiuni interioare;\r\n- trimis parlamentar sa marsaluiasca cu parada gay in mijlocul a 10.000 de suporteri rapidisti;\r\n- hranit parlamentar cu caca modificat genetic;\r\n- tatuat parlamentar pe frunte cu caricaturile cu Mahomed, trimis ambasador in Iran;\r\n-  obligat parlamentar sa bea rachiu din pishu de cartofi putrezi;\r\n- urcat parlamentar in avion cu destinatia World Trade Center, clasa business;\r\n- infestat parlamentar cu boala marinarilor;\r\n-  pus parlamentar sa conduca avion de vanatoare american in Siberia, fara autorizare din partea rusilor\r\n- inzestrat parlamentar cu marsupiu, obligat sa aiba grija de taipani marsupiali.\r\n\r\nOare mai is...?','Art or Fart?',0,'','publish','open','open','','art-or-fart','','','2007-05-01 23:36:57','2007-05-01 21:36:57','',0,'http://www.groparu.ro/?p=365',0,'post','',2),(366,1,'2007-05-01 23:18:02','2007-05-01 21:18:02','http://starbulletin.com/2007/05/01/news/story04.html','http://starbulletin.com/2007/05/01/news/story04.html',0,'','inherit','open','open','','httpstarbulletincom20070501newsstory04html','','','2007-05-01 23:18:02','2007-05-01 21:18:02','',-1178050924,'http://www.groparu.ro/wp-content/uploads/2007/05/arta-pula.jpg',0,'post','image/jpeg',0),(367,1,'2007-05-02 10:52:35','2007-05-02 08:52:35','','wwwgroparuro-traian-basescu-brb.jpg',0,'','inherit','open','open','','wwwgroparuro-traian-basescu-brbjpg','','','2007-05-02 10:52:35','2007-05-02 08:52:35','',368,'http://www.groparu.ro/wp-content/uploads/2007/05/wwwgroparuro-traian-basescu-brb.jpg',0,'post','image/jpeg',0),(368,1,'2007-05-02 10:52:47','2007-05-02 08:52:47','<a href=\"http://www.groparu.ro/wp-content/uploads/2007/05/wwwgroparuro-traian-basescu-brb.jpg\" title=\"wwwgroparuro-traian-basescu-brb.jpg\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/05/wwwgroparuro-traian-basescu-brb.jpg\" alt=\"wwwgroparuro-traian-basescu-brb.jpg\" height=\"497\" width=\"515\" /></a>\r\n\r\n<strong>liviu</strong>: am intrat\r\n<strong>liviu</strong>: la ce ma uit?\r\n<strong>Groparu</strong>: poza cu base\'\r\n<strong>liviu</strong>: asa\r\n<strong>Groparu</strong>: te-ai prins?\r\n<strong>liviu</strong>: ce e cu ea?\r\n<strong>liviu</strong>: nu\r\n<strong>Groparu</strong>: ce scrie pe ea?\r\n<strong>liviu</strong>: brb\r\n<strong>Groparu</strong>: ce insamna aia?\r\n<strong>liviu</strong>: brb\r\n<strong>Groparu</strong>: amu te-ai prins?\r\n<strong>liviu</strong>: habar nu am ce inseamna aia\r\n<strong>Groparu</strong>: \"be right back\"<strong>\r\nGroparu</strong>: :|\r\n<strong>liviu</strong>: aaaaaa\r\n<strong>liviu</strong>: hmmm\r\n<strong>liviu</strong>: nu e clar\r\n<strong>liviu</strong>: altii sau prins?\r\n<strong>Groparu</strong>: altii da\r\n<strong>Groparu</strong>: :|\r\n<strong>liviu</strong>: stai ca am si eu aici 2 romani langa mine\r\n<strong>liviu</strong>: fac sondaj de opinie\r\n<strong>Groparu</strong>: baga-i\r\n<strong>liviu</strong>: sau prins\r\n<strong>liviu</strong>: da a trebuit sa le arat textul brb\r\n\r\nPS: Acelasi Liviu - care e un tip cerebral, fara bullshit - a pornit http://www.petitiononline.com/livium01/petition.html (si cei din strainataturi au dreptul de a vota dupa bunul plac al capului sau al pantalonilor). Daca sunteti democratici de-a dreptul, dati un ochi...','Basescu',0,'','publish','open','open','','basescu','','','2007-05-02 15:56:39','2007-05-02 13:56:39','',0,'http://www.groparu.ro/?p=368',0,'post','',6),(369,1,'0000-00-00 00:00:00','0000-00-00 00:00:00','Super comparatia cu ranga, deoarece ne duce exact la miezul problemei: ranga, ca simbol falic. Simbol falic, ca semn al unei clase politice cu psihic nedezvoltat, cu temeri continue asupra justetei alegerilor lor, cu frici dezvoltate din monstrii din dulap de care ne aparam cu ranga in manutza.\r\n\r\nDragii mei: societatea noastra e bolnava, e incompleta mental, are psihicul atins, afectat. Stiti de ce? De parintii nostri, de parintii parintilor nosri, de viitorii sau actualii nostri copii.\r\n\r\nDragii mei: am fost crescuti (la comun) intr-o lume plina de interdictii. O lume plina de \"nu e voie\", \"te murdaresti\", \"de ce ai pus mana acolo?\", ni s-au inoculat reflexe conditionate si interziceri perpetue, am fost constant hartuiti sa nu putem face ceva dupa bunul plac inca din frageda pruncie: in momentul in care ajungem undeva sus, unde avem mai multa libertate, e normal sa copiem educatorii nostri si sa impunem acelasi univers restrictiv celor de sub noi. Toata lumea se plange ca in Romania nu exista o patura manageriala cumsecade (prin corolar, nici una politica): in momentul in care unul din randul nostru ajunge la fagure, resimte machiavellic teama de a fi detronat. Si atunci pune mana pe ranga (repet, ca simbol falic care confera autoritate nelimitata posesorului) si da in stanga si in dreapta, si i se pare FIRESC ca acuma, dupa o existenta de reprimare deprimanta, sa imparta EL justitia si drepturile si mierea dupa bunul lui plac.\r\n\r\nDaca teoria mea tine, atunci va trebui ca noi, tinerii, viitori sau prezenti mamici sau tatici, sa dam frau liber copiilor, sa puna mana pe ce noroi vor ei, sa se joace cu ce copii vor, sa se murdareasca, sa manance ce ciocolata vor, sa ia de jos bucatica aceea care le-a cazut din maunutza si sa o manance, sa CREASCA FARA INTERDICTII LA FIECARE SECONDA, LA FIECARE GEST! Abia atunci vom avea o clasa politica dezcremenita din legea copilariei lor tardive care evolueaza in jurul lui \"Nu e voie!\", o clasa politica relaxata, olimpiana, cu mintea libera si viziuni largi!\r\n\r\nCat despre interesul in politica, va pot declara cu manutza pe inima ca inca nu am inceput sa ne scarbim complet de politica. Si nu cred ca vom ajunge vreodata. Daca noi da, vor fi altii mai tineri cu mai mult foc in vine!\r\n\r\nCat despre cei care ne conduc... la balamuc cu ei.','Clasa politica',0,'','draft','open','open','','clasa-politica','','','0000-00-00 00:00:00','0000-00-00 00:00:00','',0,'http://www.groparu.ro/?p=369',0,'post','',0),(370,1,'0000-00-00 00:00:00','0000-00-00 00:00:00','Faceti voi o reclama originala la detergent, daca tot suntetz asa de destepti\r\n\r\nReclama la pasta de dinti: saliva trece, dintii raman!\r\n\r\nDeci se zice cÄƒ frumuseÅ£ea vine din interior, dar uneori pute al dreq de rÄƒu dacÄƒ ai mÃ¢ncat fasole!\r\n\r\nDeci nu muÅŸca mÃ¢na care te hrÄƒneÅŸte la rechini!','Idei de inceput',0,'','draft','open','open','','idei-de-inceput','','','2007-12-12 16:57:49','2007-12-12 14:57:49','',0,'http://www.groparu.ro/?p=370',0,'post','',0),(371,2,'2007-05-03 13:40:10','2007-05-03 11:40:10','<a href=\"http://www.groparu.ro/wp-content/uploads/2007/05/troleu.jpg\" title=\"troleu.jpg\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/05/troleu.jpg\" alt=\"troleu.jpg\" height=\"301\" width=\"401\" /></a>\r\n\r\nM-am hotarat sa nu mai cumpar bilet cand eram deja in autobuz, finca nu aveam timp sa si fumez, sa si scot portofelu, sa si iau bilet si sa iau si rest (oare de ce tantile de la ghisee nu dau guma de mestecat daca nu au 10 bani?), si sa ma si gandesc la intriga lui Bulgakov din a doua faza a creatiei sale in raport cu critica postmoderna a lu\' Roland Barthes.\r\n\r\nDe regula ii stiu pe controlori, finca de fiecare data cand apar la controlat sar in fatza, si pana sa isi scoata legitimatiile, le intind abonamentu\' ranjind si strigand de sa auda tot Feleacu\' \"Uitati aici, domnu\' controlor, am abonament la zi! Nu e expirat! Si daca cineva are nevoie de bilet, ii dau io! Gratis!\"\r\n\r\nAzi - am tacut ca crapu\' in heleshteu. Nu am zis nimic, m-am uitat la fiecare statie dupa oamenii in geci negre, care nu au mai aparut (aveam gaura curului cat o gamalie de ac de emotie - eu iubesc gaura curului meu, e tare cumsecade!)\r\n\r\nIntr-un final, am scoborat din troleu neviolat, da\' nu m-am rabdat si i-am zis soferului:\r\n\r\n- Am circulat fara bilet!\r\n\r\n- Nu-i nimic, zice el, io fac asta in fiecare zi.','Azi dimineatza am circulat fara bilet',0,'','publish','open','open','','azi-dimineatza-am-circulat-fara-bilet','','','2007-05-03 13:40:10','2007-05-03 11:40:10','',0,'http://www.groparu.ro/?p=371',0,'post','',4),(372,2,'2007-05-03 13:39:41','2007-05-03 11:39:41','','troleu.jpg',0,'','inherit','open','open','','troleujpg','','','2007-05-03 13:39:41','2007-05-03 11:39:41','',-1178191704,'http://www.groparu.ro/wp-content/uploads/2007/05/troleu.jpg',0,'post','image/jpeg',0),(373,1,'2007-05-03 16:39:22','2007-05-03 14:39:22','<strong>Ratuc:</strong> ii <strong>Regia</strong> (: Sergiu Nicolaescu) <strong>Autonoma</strong> (secuiasca) a <strong>Transportului </strong>sub<strong>Urban Cluj</strong>. De ce nu or pus si N(apoca) in denumire, imi depaseste capacitatile materiei mele cenusii, care se mai si decoloreaza.\r\n\r\n<strong>Amenzi luate:</strong> 2.\r\n\r\n<strong>Amenda 1. </strong>Stau sa vina autobuzu\', eram prof, eram cu vreo patru elevi prin jur, si nu aveam chef de discutii de autobuz cu \"Ce mai face mama ta? Ti-a gasit tatic?\", asa ca ma indrept spre chioscu\' de ziare si imi cumpar Catavencu\'. Imi iau si bilet, si tocma\' cand iau bilet, vine autobuzu, tzushti! in autobuz, desfac Catavencu, cetesc si rad nervos, isteric, nebun, in fine. Ma distrez.\r\n\r\nVine controloru\':\r\n\r\n- Biletele la control, zice, ca v-am vazut ca nu aveti.\r\n- Cum sa nu! Ma ratoiesc io, ca erau si elevii langa mine, si se holbau prelung, si trebuia sa imi demonstrez aptitudinile de leader. Ui aci! Si ii dau biletu\'.\r\n- Asta nu e compostat, ca de cand v-ati urcat v-am urmarit, zice el.\r\n- Cum aica, zic io, trebuie si compostat? Pula me, zic io, cand am fost in Danemarca nu trebuia compostat. Poftiti aici, luati banii de amenda.\r\n- Nu merge asa, zice el. Sunt obligat sa va dau jos din autobuz ca sa va dau amenda.\r\n- <em>Dai pe pizda matii,</em> ma gandeam, cu elevii care se uitau la mine ca la Stan si Bran.\r\n- Foarte bine, zic eu, un adevarat model social, coborÃ¢m. Nu e nici o problema.\r\n\r\nAm ajuns cu 20 minute intarziere, si cand am intrat la prima ora, toti bitangii radeau \"hÄƒÄƒÄƒ, hÄƒÄƒÄƒÄƒ, o loat profu\' amenda!\"\r\n\r\n<strong>Amenda </strong><strong>2.</strong> Eram tot prof, vai de steaua mea, nefericit, imbracat la costum (sau nu) si cu rucsacu\' in spate, ca pula bani de servieta. Si imi expira abonamentu\'. Si aveam bani sa il schimb, da\' n-am apucat sa imi innoiesc cartela. Si imi era si lene.\r\n\r\nIes de la scoala, ma sui in autobuz, dau ochii roata sa caut ceva fete in care sa-mi proptesc privirile, si o vad pe ma-sa lu\' un elev, de ii eram io diriginte. Copilu - loaza, da\' nu se spune asa ceva unei mame. I se spune \"Are o gramada de talente! Ce predau eu nu e unul dintre ele!\" Madama, cand ma vede, incepe sa isi fluture manutzele la dom\' profesor. Oftez, ma indrept catre ea, ma asez lÃ¢ngÄƒ si incepem o conversatie pedagogica despre lumea de azi, Descopery, polenizare, Dacia Logan, restituirea tezaurului, pelteaua de gutui, bateriile NiMh, ce culoare e de fapt magenta, Gica Hagi, suveranitatea pantalonilor de stofa comparativ cu blugii, de ce nu dau meditatii, biserica scientologica, Silviu Prigoana,  mufele USB 2.0, imbogatirea uraniului, spaga care se da la doftori, (cat aveti salariu? numai atata? deci =&gt;) hotii din guvern.\r\n\r\nSi tocma\' cand ajungem la faptu\' ca nu conteaza, doamna, ce salariu are cineva, conteaza sa se descurce pe langa serviciu, ca de-aia avem doua maini si un cap, nu ca sa ajungem acasa la 9 seara si sa ne punem la TV cand mai putem munci 6 ore, pac! \"Biletele si abonamentele la control\", aud din spatele unui ecuson tricolor (in Cluj, ratucii au legitimatie tricolora, cf. funar). Ma uit la doamna, care isi compostase si batista, numa sa fie in regula, si io... pula me, ma fac ca ploua, scot abonamentul, i-l inmanez gecii negre, si mai ca-mi vine sa-l ingÃ¢n pe nenea controloru, ca stiam exact ce urmeaza sa zica:\r\n\r\n- Abonamentul acesta e expirat, zice nenea.\r\n- Da? Ma prefac eu surprins. Cum asa? De cand?\r\n- Din februarie, zice nenea. Anu\' trecut.\r\n- Vaaaai, zic io, sa vezi ca am luat din greseala vechiul abonament! Ntz ntz ntz...\r\n- Va rog sa prezentati un act de identitate, zice nenea.\r\n- Cum sa nu, zic eu, vai, ce regretabila greseala.\r\n\r\nPula buletin, pula bani.\r\n\r\nZic:\r\n\r\n- Haideti mai bine sa coboram la statie, zic eu, ca si asa ma dau jos la urmatoarea (de fapt mai aveam vreo 4 statii pana la punctu\' terminus). No, zic io catre doamna care isi dadea seama de puterea exemplului meu benefic pentru dezvoltarea armonioasa a odraslei ei. Ce ghinion! Oare cum am putut sa incurc abonamentele? In fine, asta e...\r\n\r\nMa scoboara nenea (erau doi) ca pe un pungash, tinut de o areapa, de se uita tot autobuzu\' ca la decapitare de vrajitor. Ajungem jos, si le zic:\r\n\r\n- Ba, pula me. N-am bani la mine. Va las geanta, si asteptati 5 minute, ca revin, zic io.\r\n- Ba, zice unu, ba profule, ca io stiu cine esti. Sa nu ma pui sa stau degeaba!\r\n- Taci, ma, ca vin.\r\n\r\nSi ma duc la Litere, ca acolo oprise autobuzu\'. Si - ce pula sa fac? ma duc la secretare. Saru\'mana, zic io, is Groparu, de la sectia aia de regie porno. Ce mai faceti? Stiu ca nu e program cu publicu\', ma scuzati, va rog nu mai urlati, dar am o problema. Nu, nu ma intereseaza ce nota am la Istoria Limbii Ebraice, nu, nu, si nici nu e nevoie sa sunati la portar, credeti-ma. Serios ca nu. Dati-mi va rog niste bani imprumut, ca m-or prins ratucii fara belet si vor sa ma beleasca. 200.000 ajung. Da. Multumesc. Vi-i aduc maine  (i-am si adus in aceeasi zi. Asa cred)\r\n\r\nSi-apai sa-ti mai placa de ratuci???\r\n\r\nPS: Cu mama lu\' elev\' ala am mai avut cel putin doua momente interesante. Primu: meream pe strada, si mi se infige in gat un scuipat d-ala rau, da\' rau-rau, de de-abia mai puteam respira. Io nu prea scuip pe strada. Da\' atunci o trebuit! Si m-am uitat in jur, nu era nimeni, si am lasat un scuipat din ala albicios, de care scot tebecishtii. Si cand am ridicat privirea - cine era in fatza mea, si zambea? tanti mama lu elevu\'! Si a doua - penala rau. Ma duc cu un prekin la spital, ca il durea tot felu. Cautam sectia de boli interne. Si nimerim la urologie, da\' fara sa stim. Si asta zice - ma duc peste ei, bag pula in ei de doctori, ca alfel nu te baga in sama. Si se duce. Si io stau si il astept pe bancutza aia de stau pacientii la rand pe ea. Si cand stateam io mai abitir - apare tanti mama lu elevu\'! Dom profesor, zice ea tare, aveti probleme acolo jos?','More on RATUC',0,'','publish','open','open','','more-on-ratuc','','','2007-05-03 17:39:53','2007-05-03 15:39:53','',0,'http://www.groparu.ro/?p=373',0,'post','',4),(374,1,'2007-05-03 22:06:02','2007-05-03 20:06:02','<a href=\"http://www.groparu.ro/wp-content/uploads/2007/05/ceausescu-si-comunismul.jpg\" title=\"Ceausescu si comunismul\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/05/ceausescu-si-comunismul.jpg\" alt=\"Ceausescu si comunismul\" /></a>\r\n\r\nTag primit de la <a href=\"http://www.fenomental.com/\" target=\"_blank\">fenomental</a>: ce inseamna comunismul pentru tine?\r\n\r\nEu pentru mine comunismul inseamna:\r\n\r\n- o lume in care oamenii mai interactionau mai ales cu nevestele, ca se lua curentu\' in fiecare saptamana, si trebuia sa cauti lumina fix in tunelashu\' lu\' consoarta (<em>doamna invatatoare, nu mi-am putut face tema ca aseara s-o luat curentu\'!</em> - <em>dar nu ati abut lumanari?</em>);\r\n- o lume in care lumea explora posibilitatile cele mai ab-sconcse ale limbajului, injurand cu mÃ¢(rlÄƒ)nie pe aia care in loc sa dea pe TV meciul difuzau cuvÃ¢ntÄƒrile;\r\n- o lume in care toata lumea venea de la serviciu odihnita, in afara de cazu\' in care nu erai workaholic sau era zi de sedinta maraton la partid;\r\n- o lume in care te spalai cu sapun cheia si nu aveai sampon, si si daca aveai tot nu te dadeai cu el pe cap ca <em>samponu\' face paduchi</em>;\r\n- o lume in care toata lumea cunostea pe toata lumea, finca nu se stia cand aveai nevoie de ei pt o ruda de salam, sa iti pileasca o noua cheie pentru ala micu care o pierdut-o de la gat cand se juca, sa te ajute sa mergi la tzara sa aduci cartofi si mere si porc, sa iti faca o injectie cu polidin,  sa te ajute sa iti repari Dacia (sau Skoda, dupa caz), sa iti imprumute redresoru\' pentru bateria la mashina, sa iti imprumute un pic storcatoru\' ala cehesc de fructe ca e copilu\' bolnav, sa iti imprumute caseta aia video cu <a href=\"http://www.imdb.com/title/tt0085101/\" target=\"_blank\">Pasarea Spin</a> (<em>dar s-o aduci inapoi derulata!</em>) ca s-o vezi la vecinu\' sau la nashii tai care au TV in culori pentru ca cunosc pe cineva la fabrica de televizoare in culori, pe altcineva care sa aduca cafea si KENT de dat la doftori sau pentru uz intern si personal,  etc, etc, etc;\r\n- ma imprumut de la CAR;\r\n- zugraveala facuta de unchiu\' care le cam bea;\r\n- Sicola (culoare neagra, gust usor acrisor, 2 lei cinzeci);\r\n- pufuleti si corabioare;\r\n- Napolitane Margareta, cu glazura de ciocolata, 2 lei 25 bucata;\r\n- vecinu de la 4 iara face tuica, ca pute tot coridoru\';\r\n- zi-i lu muma-ta ca la cofetarie se da margarina Rama si inca nu e coada;\r\n- e ziua lu mama si nu stie de unde phuii mei sa faca rost de salam, sa nu se faca de rusine;\r\n- wow, azi am vazut un VW Golf I cu numar de DDR (Republica Democrata Germana);\r\n- desara merem la furat? (fructe, ma, fructe, nu virginitati!);\r\n- multa, multa, multa, multa muie la TV si la scoala, ore de Constitutie si dirigentie in care efectiv se citea editorialul din Cutezatorii si noi ne cacam pe noi de plictiseala si desenam tancuri;\r\n- apartamentu lu Mihaitza, baiatu\' de securist al clasei, impodobit ca in Neckermann, in care meream dupa ore sa aruncam cu apa pe trecatori de pe balcon;\r\n- jur sa apar tzara si conducatorul suprem lalala (ba fraiere, nu mai scuipa pe steag, ca te vede!);\r\n- cine i-o facut mustati tabloului tovarasului Nicolae Ceausescu?\r\n- tovarasa invatatoare, Groparu trage cu boabe de orez dupa Dragoman in ora;\r\n- compunere: cum mi-am petrecut ziua de 1 mai;\r\n- da-mi guma din gura ca iti dau bomboana pe care o sug (am vazut schimbul, eram acolo! frate cu sora)\r\n- rosii , patrunjel si cartofi cultivati in fatza blocului (bueey, nu va mai jucati aicea cu mingea ca imi rupeti straturile!)\r\n- mamaaaaa, arunca-mi o bucata de sfoara sa imi fac arc;\r\n- radio Gloria;\r\n- o groaza de saÅŸi cu adidasi Puma;\r\n- Dallas;\r\n- PULA ME!!!! MAI IS O GROAZAAAAAAAAA....\r\n\r\nPS: Dau si eu mai departe liapsha asta, daca mai baga careva vrun oki p-acilea si are kef sa scrie despre amintirile alea cu secera si ciocanel e invitat sa o faca, ori la el pi blog, ori acilea, ca spatiu estem...!','Ce inseamna Co-muismul pentru mine - partea I',0,'','publish','open','open','','ce-inseamna-co-muism-pentru-mine','','','2007-05-04 13:46:36','2007-05-04 11:46:36','',0,'http://www.groparu.ro/?p=374',0,'post','',4),(375,1,'2007-05-03 22:05:43','2007-05-03 20:05:43','Ceausescu si comunismul','Ceausescu si comunismul',0,'','inherit','open','open','','ceausescu-si-comunismul','','','2007-05-03 22:05:43','2007-05-03 20:05:43','',-1178220892,'http://www.groparu.ro/wp-content/uploads/2007/05/ceausescu-si-comunismul.jpg',0,'post','image/jpeg',0),(376,1,'2007-05-06 01:20:06','2007-05-05 23:20:06','Finca:\r\n\r\n- femeile nu se imbata decat rar\r\n- femeilor li se scoala indiferent de cine e in spatele aparatului\r\n- noua nu ne place de prietenii vostri\r\n- fostii vosti iubiti se comportau <em>alfel\r\n</em>- aratam sexy cand <em>gatim, dam cu aspiratoru\' sau spalam rufe\r\n</em>- mancati sanatos, pe cand noi suntem dependenti de colesterol\r\n- nu intelegeti de ce ne uitam pe Viasat History\r\n- ne obligati sa invatzam meniul de la o masina de spalat rufele\r\n- ne blocati traficul cand conduceti\r\n- noi nu suntem, \"ursuletul\", \"pufuletele\", \"iubi\", etc, etc, etc.\r\n- nu jucati joace pe calc\r\n- noi nu o uitam niciodata pe aia <em>de dinainte\r\n</em>- nu rÃ¢gÃ¢iti, nu va beshiti, si nu mirositi chiar asa de naspa dimineatza\r\n- pentru ca nu va lasati pupate dimineatza\r\n- dimineatza nu observam cearcanele voastre\r\n- \"ma intepi cu barba!\"\r\n- Andreea Marin, \"Iarta-ma\" si AcasaTV, Cosmopolitan, Playgirl, feng-shui\r\n- exista 300 de reviste pt femei, ai abia una (Men\'s  Health) pt barbati\r\n- citim \"Men\'s  Health\"\r\n- nu sunteti in stare sa operati un telefon mobil\r\n- tac\'tu nu ma place, tu!\r\n- nu va stiti administra un rahat de cont de e-banking\r\n- dupa ce nasteti, sex zero\r\n- va feriti de lumina zilei cand umblati dezbracate prin casa\r\n- ne imbatam singuri\r\n- va trebuie prosoape curate\r\n- nu stiti cine a fost Erwin Rommel\r\n- pentru ca vorbiti in somn chestii pe care nu le intelegem\r\n- pentru sutiene si chiloti si orice alta chestie cu dantelutza pe careÂ  nu stim cum sa o dez-hÄƒmÄƒm\r\n- daca va barfim <em>suntem mai rau ca fumeile\r\n- </em>nu stiti ce e aia AK47, MIG 29 si habar nu aveti de Suhoi\r\n- trebe sa va spalati dupa secs, de parca am fi murdari\r\n- mancati in conditii igienice\r\n- vezica noastra e nemernica si ne uitam cu interes la reclame anti-prostata\r\n- VA PLAC STRAINII!!! (ORICE ROMÃ‚NCÄ‚ PICÄ‚ CU CRACII LA DEAL PENTRU UN NEAMÅ¢, ITALIAN, FRANCEZ - SA MAI ZIC???)\r\n- va ingrasati cu o viteza uluitoare\r\n- va plac dulciurile\r\n\r\n...to be continued...?','De ce ziua barbatului?',0,'','publish','open','open','','de-ce-ziua-barbatului','','','2007-05-06 02:13:40','2007-05-06 00:13:40','',0,'http://www.groparu.ro/?p=376',0,'post','',9),(377,1,'2007-05-07 12:55:12','2007-05-07 10:55:12','...sa scriu un blog...\r\n\r\n...da\'...\r\n\r\n...mi-i prea lene. Il scriu maine. Pa.','Incerc...',0,'','publish','open','open','','incerc','','','2007-05-07 12:55:12','2007-05-07 10:55:12','',0,'http://www.groparu.ro/?p=377',0,'post','',2),(378,1,'2007-05-07 14:57:37','2007-05-07 12:57:37','...azi mi-e o lene isterica.\r\n\r\nAzi dimineata m-am uitat in oglinda, si imaginii mele i-o fost lene sa sa oglindeasca: oglinda arata peretele din spatele meu.Nici macar urdori la ochi nu mai facusem peste noapte, de lene.\r\n\r\nMi-i lene si sa clipesc, si celulele alea bastonase si cornulete cu lapte din retina is toate adormite si dorm unele in bratele altora.\r\n\r\nSunt aproape sigur ca peste weekend nu mi-o crescut barba deloc, tot de lene, asa ca am amenintat-o numa cu Gillette-ul sh i-am dat pace.\r\n\r\nMi-i lene si sa imi sprijin barbia in pumni.\r\n\r\nCred ca plamanii mei nu mai ard oxigenu\' de lene, prin urmare is plin de CO2 ca un sifon sau o apa minerala Biborteni.\r\n\r\nDaca m-as afla intr-un avion deturnat, mi-ar fi lene sa apar in fata camerelor sa le zic americanilor sa iasa dreq din Irak, ca daca nu, ne face nenea asta cu treantza pe cap ingerashi.\r\n\r\nDaca m-ar taia Osama la gat cu baionetu\', sangelui i-ar fi lene sa curga, si pielii i-ar fi lene sa se despice.\r\n\r\nDaca vine controlu\' pe RATUC azi, o sa-mi fie lene sa ma cert cu ei.\r\n\r\nDe lene, m-as uita chiar si la ProTV.\r\n\r\nScamelor li s-o facut lene sa se stranga in buric azi. Nu-i stress, recupereaza ele.\r\n\r\nDaca as fi o limonada, mi-ar fi lene sa fiu acru.\r\n\r\nMi-i lene pana si sa imi iau concediu o zi, ca sa ma bucur cumsecade de lene.\r\n\r\nDaca as fi o constelatie, m-as posta sub semnul Fecioarei si as ramane acolo, da\' mi-ar fi lene sa ma uit sub fusta ei.\r\n\r\nDaca as fi iaurt, n-as fermenta, tot de lene.\r\n\r\nMi-i lene sa ma scarpin, sa ma mangai pe trup si multumesc lui Dumnezeu ca nu is maimutica, ca mi-ar fi lene  sa ii despaduchesc pe colegi, si mi-as pierde o gramada de prieteni.\r\n\r\nDaca m-as pune acuma sa beau o bere, as pune prima data sa mi-o mestece careva.\r\n\r\nVisez sa ma reincarnez intr-un dulap Biedermeyer sau cum puii mei se scrie, sa raman o viatza intreaga plin de lenjerie intima intr-un colt si sa nu ma bage in seama decat fetele cand vin sa se schimbe, si eu sa ma uit la ele cum se dezbraca - in zilele cand nu mi-e lene.\r\n\r\nDaca as fi verb, mi-ar fi lene sa ma declin si sa ma conjug, sa ma impersonez si sa primesc desinentze. Si as face greva si as iesi din toate expresiile verbale.\r\n\r\nDaca as fi Microsoft Word, as scoate Autocorrectu\'.\r\n\r\nDaca as fi o bicicleta, as merge numa la vale.\r\n\r\nAtat.','Si dupa cum spuneam,...',0,'','publish','open','open','','si-dupa-cum-spuneam','','','2007-05-07 14:57:37','2007-05-07 12:57:37','',0,'http://www.groparu.ro/?p=378',0,'post','',6),(379,1,'2007-05-08 11:15:29','2007-05-08 09:15:29','<a href=\"http://www.groparu.ro/wp-content/uploads/2007/05/kartofelki.jpg\" title=\"kartofelki.jpg\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/05/kartofelki.jpg\" alt=\"kartofelki.jpg\" height=\"335\" width=\"445\" /></a>\r\n\r\nGroparu\' o preluat de pe <a href=\"http://www.9am.ro/stiri-revista-presei/Incredibil!/61447/Bautura-micsoreaza-creierul\" target=\"_blank\">9 am</a>, care si ei au preluat de pe <a href=\"http://www.e-click.ro/\" target=\"_blank\">click</a>, cum ca alcoolul <em>micsoreaza creieru\'.</em>\r\n\r\nHmmm.\r\n\r\nIn primu\' rand ca nush daca se aplica creierelor deja release-uite in versiune compacta, ca deterjentii aia care is dupa normele UE. Unu la mÃ¢nÄƒ.\r\n\r\nIn al doilea la mÃ¢nÄƒ, daca esti lungan de 2 metri? Se plictiseste alcoolu\' sa faca pe cliff hanger pana la tine, sus, la mansarda, si crieru\' tot la aceeasi dimensiune ramane, inca Ã®i ÅŸi rÃ¢de Ã®n nas la alcool.\r\n\r\nIn al treilea la mÃ¢nÄƒ, nu cred, pur si simplu. FincÄƒ dacÄƒ Ã®Å£i scalzi cu alcool neuronii, creieru\' se mÄƒreste. Da. Se mareÅŸte fiindca e stimulat intelectual. Finca alfel nu imi explic cum alfel, la beutura, creieru\' devine un artist intelectual desavarsit:\r\n\r\n- vede poezia din cele mai respingatoare femei cu mustatza si te obliga sa te Ã®mperechezi cu ele;\r\n- iti sculpteaza corpul tÄƒu apolonian chiar sub ochii tai uimiti (ti se pare ca bicepsii ti-s mai mari decat in realitate, ÅŸi te pune sa sari la bataie cu suporteri steliÅŸti);\r\n- te inzestreaza cu calitati vocale care l-ar face si pe Traistaru sa se simta neam de traistÄƒ (mai ales cÃ¢nd eÅŸti rangÄƒ ÅŸi interpretezi Ioana Radu, <em>Simfonia Fantastica</em> de Hector Berlioz sau transpui pe manele poeziile medievale cu <em>nonchaloir</em> ale lui Charles d\'Orleans);\r\n- te introduce intr-un fel de transa, in care cuvintele isi pierd noima, plutesc in jurul tau, iar tu devii un vrajitor al metaforelor, simtind nevoia sa vorbesti mentionand organe sexuale masculine in prezenta doamnelor colege mai in varsta;\r\n\r\nSi in al patrulea rand la mana, CREIERU\' NU ARE CUM SE MICSORA, FINCA LA MASCULI CREIERU\' E IN PANTALONI, SI CHIAR DACA SE MICSOREAZA, SE MICSOREAZA DE LA APA RECE (se face <span style=\"font-size: 7pt\" lang=\"EN-GB\">mic-mic-mic</span>), DA\' DUPA AIA SE UMFLA LA LOC.','Alcoolu\' micsoreaza creieru\'!',0,'','publish','open','open','','alcoolu-micsoreaza-creieru','','','2007-05-08 11:19:56','2007-05-08 09:19:56','',0,'http://www.groparu.ro/?p=379',0,'post','',4),(380,1,'2007-05-08 11:19:27','2007-05-08 09:19:27','','kartofelki.jpg',0,'','inherit','open','open','','kartofelkijpg','','','2007-05-08 11:19:27','2007-05-08 09:19:27','',379,'http://www.groparu.ro/wp-content/uploads/2007/05/kartofelki.jpg',0,'post','image/jpeg',0),(381,1,'2007-05-08 12:33:22','2007-05-08 10:33:22','<a href=\"http://www.groparu.ro/wp-content/uploads/2007/05/octavian_paler.jpg\" title=\"http://ro.wikipedia.org/wiki/Imagine:Octavian_paler.jpg\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/05/octavian_paler.jpg\" alt=\"http://ro.wikipedia.org/wiki/Imagine:Octavian_paler.jpg\" /></a>\r\n\r\nPaler se pare ca o cam dat coltzu\' destul de definitiv. Pe bune.\r\n\r\nO expirat, o raposat, o dat banu\' lu Charon, o papat hamburgeru\' suprem, o crapat, morga i-o dat autograf pe certificatu\' de deces, i-o cantat popa, si-o auzit prohodu\', se va plimba cu picioarele inainte, si-o taiat trompa vietii, si-o spart pipa, va creste momeala pentru pesti, isi va dezgoli cu mandrie scheletu\', si-o mancat malaiu\', si-o gatit ultima friptura, se va camufla in giulgiu, va vizita partea romaneasca a Purgatoriului, etc, lalala.\r\n\r\nAmu... Paler, orice s-ar zice despre el, o fost un erudit. Normal ca nu am cetit mai nimic scris de el, si la <em>Interviul cu Dumnezeu</em> redactat de el, care circula intr-o vreme pe mess, m-am plictisit cu brio (m-am si enervat, finca Dumnezeu mi-o promis MIE exclusivitate la interviu). Dar dandu-te pe orice sait care anunta infarctu\' lu\' nenea, nu poti sa nu observi cum 70% din comentarii il fac comunist, PCR-ist, da-l dreq de anti-Basescian, etc, etc.\r\n\r\nMa copii, ca ramoliti nu pot sa va zic.\r\n\r\nIo ii iau apararea. Daca Paler o fost comunist si plin de defecte congenitale, apai aflati ca nici voi, nici io nu am fost mai breji. Io, de exemplu, am tras in keptzi statul roman cu nerusinare, finca am listat in camin pajini la imprimanta. Va rog sa nu uitati sa scrieti despre asta cand pe www.groparu.ro se va agatza o pamblica niagra, pe care va scrie <em>Groparu is now meeting groparii</em> <em>lui</em>. Si sa spuneti ca d-aia nu ati avut voi bani, finca Groparu lista pajini in camin la studente si nu declara venitul la fisc.\r\n\r\nSi sa mai declarati ca va doare la bashca ca io ma hodin cu mainile pe pieptzi, fiindca oricum is un nemernic care o fumat pe strada ca un nesimtit. Si uneori o si halit sanvish si inghetata pe trotuar. Si ca am scris postari cu cuvinte care se refera la arborele ginecologic masculin si feminin, fara osebire, dar cu persistentza (de altfel, acestea au fost cele mai recurente motive din aberatiunile mele). Si adesea m-am holbat fara pic de rusine la gajicile decoltate, chiar daca nu or avut nimic ce arata (ceea ce denota lipsa valorilor mele morale inoculate de o educatie post-prolecultista decadenta).\r\n\r\nDe asemenea, sa spuneti ca de multe ori v-ati dat seama cand am mancat fasole cu o zi inainte. Da. Ma flatulez la greu, si apai tot io zic in gura mare \"Groparu a eliberat stafia!\"\r\n\r\nSper sa nu uitati faptul ca deseori nu am cedat locul din troleu batranelelor, ca ma cert cu controlorii si ca de  muuuhuuulte ori am facut ocazia in studentie, si atata am fost de zgarcit si de sobolan, ca de fiecare data am incercat sa nu platesc. Niciodata nu mi-o reusit. A, numa\' o singura data, da\' aia o sa apara intr-un blog, intr-o buna zi - bine-nteles, daca nu crap pan-atunci de la bere.\r\n\r\nA nu se uita ca am suferit de lene cronica dobandita, si ca am fost pasta la folbal, hochei, poker, si orice implica un efort intelectual cat de minuscul.\r\n\r\nCand o tigare mi-o picat pe jos nefumata, rareori am lasat-o acolo: am luat-o si am bagat-o inapoi in gura, unde ii era locu\'. Si am si aprins-o, si apai am umflat nota asigurarilor de stat de sanatate pe seama nefumatorilor.\r\n\r\nNimic nu mi s-a parut mai amuzant decat sa ragai cu sonoritate evidenta dupa o masa copioasa. Cat despre tolerantza la alte religii, a nu se uita ca in intoleranta si nemernicia mea am facut frecvent misto de MISA, cu dictoane gen \"De la Nistru pan\' la Tisa, toata  MISA pishu-mi-s-a\".\r\n\r\nDaca am putut sa ma cert cu cineva, niciodata nu am precupetit nici un efort. Si cand sunt certat de altcineva pe buna dreptate, dau vina pe certator, cu nerushinare. Si nu suport vamesii maghiari.\r\n\r\nSi pe Dumnezeu, despre care-am zis mereu ca am o relatie privilegiata, l-am loat de multe ori la rost, sh daca nu o zis nimic am continuat si mai abitir, fiindca vreau sa imi zica apara in fatza mea si sa imi dau seama daca e barbat sau femeie, cum zice feministele, si dupa aia sa fac un blog nou \"Dumnezeu - barbat, sau femeie? - Da\".','Smarter, Better, Paler',0,'','publish','open','open','','smarter-better-paler','','','2007-05-08 12:33:22','2007-05-08 10:33:22','',0,'http://www.groparu.ro/?p=381',0,'post','',8),(382,1,'2007-05-08 12:23:05','2007-05-08 10:23:05','http://ro.wikipedia.org/wiki/Imagine:Octavian_paler.jpg','http://ro.wikipedia.org/wiki/Imagine:Octavian_paler.jpg',0,'','inherit','open','open','','httprowikipediaorgwikiimagineoctavian_palerjpg','','','2007-05-08 12:23:05','2007-05-08 10:23:05','',381,'http://www.groparu.ro/wp-content/uploads/2007/05/octavian_paler.jpg',0,'post','image/jpeg',0),(383,1,'2007-05-09 12:07:50','2007-05-09 10:07:50','Cred ca am umplut un lighean de muci.\r\n\r\nAm vrut sa fac o baie fierbinte cu sare, da nu am in casa atata sare. Asa ca am facut o baie fierbinte cu Vegeta.\r\n\r\nSi ca sa mai fie sare pe rana, ascult pe tonomatu\' de pe doi cea mai colosala monumentalitate gigantesco-titanica, un sampling tremendos si uriesesc de Dambovitza English care serpuieste temerar catre emisfera cerebrala responsabila cu traducerea versurilor formatiei Akcent in limba engleza, dar esueaza lamentabil in zona prohabului: versul \"Sunt un cantaretz de 25 de ani\" o fo\' tradus in engleza cu \"I\'m a young singer man aged 25\".','Am racit, baga-mi-as',0,'','publish','open','open','','am-racit-baga-mi-as','','','2007-05-09 12:07:50','2007-05-09 10:07:50','',0,'http://www.groparu.ro/?p=383',0,'post','',3),(384,1,'2007-05-09 14:41:02','2007-05-09 12:41:02','Referendum 2007 (c) Groparu ww.groparu.ro I','Referendum 2007 (c) Groparu ww.groparu.ro I',0,'','inherit','open','open','','referendum-2007-c-groparu-wwgroparuro-i','','','2007-05-09 14:41:02','2007-05-09 12:41:02','',386,'http://www.groparu.ro/wp-content/uploads/2007/05/referendum-2007-c-groparu-wwgroparuro-i.jpg',0,'post','image/jpeg',0),(385,1,'2007-05-09 14:41:57','2007-05-09 12:41:57','Referendum 2007 (c) Groparu ww.groparu.ro I','Referendum 2007 (c) Groparu ww.groparu.ro I',0,'','inherit','open','open','','referendum-2007-c-groparu-wwgroparuro-i-2','','','2007-05-09 14:41:57','2007-05-09 12:41:57','',386,'http://www.groparu.ro/wp-content/uploads/2007/05/referendum-2007-c-groparu-wwgroparuro-ii.jpg',0,'post','image/jpeg',1),(386,1,'2007-05-09 14:42:22','2007-05-09 12:42:22','Mai mult despre referendum:\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/05/referendum-2007-c-groparu-wwgroparuro-i.jpg\" title=\"Referendum 2007 (c) Groparu ww.groparu.ro I\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/05/referendum-2007-c-groparu-wwgroparuro-i.jpg\" alt=\"Referendum 2007 (c) Groparu ww.groparu.ro I\" /></a>\r\n\r\n<a href=\"http://www.groparu.ro/?attachment_id=385\" rel=\"attachment wp-att-385\" title=\"Referendum 2007 (c) Groparu ww.groparu.ro I\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/05/referendum-2007-c-groparu-wwgroparuro-ii.jpg\" alt=\"Referendum 2007 (c) Groparu ww.groparu.ro I\" /></a>','Referendum 2007',0,'','publish','open','open','','referendum-2007','','','2007-05-09 14:42:22','2007-05-09 12:42:22','',0,'http://www.groparu.ro/?p=386',0,'post','',1),(387,1,'2007-05-10 02:28:19','2007-05-10 00:28:19','Draga domnule marionet de oligarh,\r\n\r\nEu sunt bine sanatos, atata numa ca-s racit cobza si ma si doare cu pasiune toata maseaua de minte, nush ce pola de raceala mai e si asta, i-am zis sa se duca la vamesi, da\' numa\' nu vrea, nesimtita, o fi d-aia pesedista!\r\n\r\nBa TÄƒri\', zicea Traienel ca esti pÄƒpuÅŸat, asa ca Ã®-Å£i scriu de la egal la egal. Da, mÄƒ, noi suntem egali, cÄƒ si io is condus de tot felu\' de persoane  din umbra - cum ar fi gajica-mea, maica-mea, sor-mea, si de altele nu mai scriu, ca ma bate prekina, ca e geloasa, si ea da numa\' in cap si la fluier. Fara mila, ca asa o invatzat-o maica-mea, fara mila sa dea, si inca imi mai si mananca sanvisurile dupa aia, si imi ia banii de buzunar.\r\n\r\nDeci: io am inteles ca te vezi cu Patriciu mai des decat ma vad io cu el. Fii antena la ce ma gandesc. Nu-i zici sa imi deie si mie trei benzinarii? Sa mi le deie mie, sa le gospodaresc io, asa cum stiu? Da, numa\' 3. Si sa fie pline cu benzina si motorina. Da. Ar fi super. No, ii zici? Ii zici?\r\n\r\nAia e, sanatate!\r\n\r\nPeSe: Mai avem mult pana devenim ca o republica bananiera? Ca am auzit ca se face o palinca din banane putrede.... mai ceva ca aia din gainatz de curca! Si apropo\' de makialÄƒ, sÄƒ vezi maine ce idee de pozÄƒ am cu Vacaroiu, ca deja rÃ¢d numa\' cÃ¢nd mÄƒ gÃ¢ndesc...','Scrisuare deschisa d-Lui Tariceanu',0,'','publish','open','open','','scrisuare-deschisa-d-lui-tariceanu','','','2007-05-10 02:28:19','2007-05-10 00:28:19','',0,'http://www.groparu.ro/?p=387',0,'post','',6),(391,1,'2007-05-12 14:04:22','2007-05-12 12:04:22','Groparu www.groparu.ro blog romanesc romanian blog diarie','Groparu www.groparu.ro blog romanesc romanian blog diarie',0,'','inherit','open','open','','groparu-wwwgroparuro-blog-romanesc-romanian-blog-diarie','','','2007-05-12 14:04:22','2007-05-12 12:04:22','',389,'http://www.groparu.ro/wp-content/uploads/2007/05/groparu-wwwgroparuro-blog-romanesc-romanian-blog-diarie.JPG',0,'post','image/jpeg',0),(388,1,'2007-05-10 18:02:48','2007-05-10 16:02:48','Intra sor-mea cu romanashii ei de prin doiciland sa mance, intr-un local pe care scria, in cea mai pura limba germana a unui Herrensfolk adevarat doritor de Lebensraum pentru care au fost in stare sa duca doua razboaie mondiale pe trei continente impotriva Untermenschenilor, deci dupa cum ziceam, o pizzerie pe care scria in cea mai pura germana a unei natii care face cele mai fiabile masini din lumea asta, gen Trabant, asadar, germana unei stirpe de oameni nobili si iubitori de evrei, turci, si chiar si romani, ei bine, scria pe pizzeria aia in germana \"Pizzerie Romaneasca\", si sor-mea intra, cum ziceam, cu romanashii ei, sa manance in pizzerie.\r\n\r\nAmu... dupa ce penetrara, le fu foarte greu sa nu se uite la cel mai negru si mai urat negru urat care exista la ora aceea in Germania, unu\' mare, atata de negru ca cred ca omu\' avea depresii. Omu mai avea si dinti atata de albi, mah, atata de albi, ca mobilau foarte feng-shui o gura cel putin solamez de flamanda, cu care rontaia la un blat de pizza plin cu tot felu, da\' vreau sa zic ca cu atata pofta ca - daca erai mama, sau viitoare mama, da\' nu mama Omida! - nu puteai decat sa te umpli, induiosat, de veselia acelei zi de primavara germanica, dar totusi invinsa de rusi. Si de americani. Si - daca ma gandesc otzara - si de romani.\r\n\r\nDintre toti, cel mai induiosat fu un tip Dan, de felul lui padurar (dupa cum se stie, padurarii, dupa ogri si trolli, sunt cele mai blanzi creaturi ale codrului), care Dan nu se putu abtine sa nu ii glasuiasca bland, dar ferm:\r\n\r\n- Mananca, dragutza, ca asta e pizza buna, d-aia, de la Romania... si ofta, asa, nitel, cu o lacramioara in fundul gatului, finca dorul de casa tocmai ii daduse un branci violent intr-o baltoaca cu melancolie.\r\n\r\nLa care negrul dracului, ca alfel nu poci pentru a-i spune, ii raspunde in cea mai congoleza romaneasca de Banatu-i fruncea:\r\n\r\n- Suntetz romani? Eu studiat medicina la Timisoara, frumos oras!','Intamplare la pizzerie',0,'','publish','open','open','','intamplare-la-pizzerie','','','2007-05-10 20:27:55','2007-05-10 18:27:55','',0,'http://www.groparu.ro/?p=388',0,'post','',5),(389,1,'2007-05-11 12:57:42','2007-05-11 10:57:42','Da, s-a intamplat.\r\n\r\nIn cele din urma s-a intamplat.\r\n\r\nMa asteptam la asta.  De mult.\r\n\r\nO mai patisem.  Chiar de cateva ori.\r\n\r\nSi de fiecare data cand mi se intampla, ajung in aceeasi ipostaza jenanta si chircita,  cu capul in maini, gemand, cu lacrimi siroindu-mi de durere pe obraji, ca un mic Gange in care fac baie indienii alaturi de cadavrele vacilor sfinte.\r\n\r\nNu, nu e vorba de Basescu, care il face comunist pe <a href=\"http://jeg.stuffo.info/\" target=\"_blank\">JEG</a> in loc sa il faca un oligarh al bloagelor (prezent si viitor). Nu e vorba nici de  arheologii care nu or prea crezut ca regele Midas (ala cu urechi de magar) ar fi existat vreodata, pana nu i-or descoperit mormantul sapat cu truda si chin si cu osanda de gropari. Nici  ca eram sigur ca pe Discovery vezi numa emisiuni cu American Chopper, ca deja ma gandesc foarte serios sa il inlocuiesc cu DDTV.\r\n\r\nNici de faptul ca mi-am dat seama ca pe lumea asta prietenii te tradeaza, te mint in fatza si se leapada de tine cand le canta cocoshelu\' de trei ori. Si iti mai si infig un stilet in spate, numa\' ca sa se asigure.\r\n\r\nNu. De data asta e vorba de ceva mult mai devastator decat insashi malaria (tocma amu ma uit la un documentar despre malaria care o sters comunitati intregi din Africa, ceea ce inseamna ca media globala a marimii putzulicii a scazut dramatic). Ceva ma abject decat razboiul rece, furtul drepturile de autor asupra Tetrisului si prabusirea Bursei din New York in 1929.\r\n\r\nS-a intamplat exact asa cum preconizasem.\r\n\r\nAntibioticele mi-or dat diarie.\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/05/groparu-wwwgroparuro-blog-romanesc-romanian-blog-diarie.JPG\" title=\"Groparu www.groparu.ro blog romanesc romanian blog diarie\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/05/groparu-wwwgroparuro-blog-romanesc-romanian-blog-diarie.JPG\" alt=\"Groparu www.groparu.ro blog romanesc romanian blog diarie\" /></a>','Da, s-a intamplat',0,'','publish','open','open','','da-s-a-intamplat','','','2007-05-12 14:23:17','2007-05-12 12:23:17','',0,'http://www.groparu.ro/?p=389',0,'post','',3),(390,1,'2007-05-12 01:52:16','2007-05-11 23:52:16','Nu, nu mie mi s-a intamplat. Nu sunt fan pizza.\r\n\r\nApropos, unde se mananca pizza bun in Cluj? Acasa la mama, in Bistrita (daca esti clujean, nu ai cum sa nu fii bistritean).\r\n\r\nDeci... un prekin, fost coleg de camin, fost coleg de apartament (apropos... din Bistrita:D) mere la prekina-sa care se doftorea destul de PhD-ist in Germania, la Gewurzburg.\r\n\r\nFiind roman (si moldovean, deci, ca d-aia e din Bistrita) - clar, i se face foame. Sunt doua circumstante in care i se face foame unui roman in Germania: cand e moldovean si cand nu e moldovean. Omul nostru, dar mai ales al ei, fiind din Bistrita, deci amandoua, deci este inshfacat brutal de brutal de foame de burta de matze; asa ca isi inshfaca una bucata prekina de bratz si o duce, ca la Politie, la un <em>take away</em>, sa umple pardalnicul de gol duodenal cu ceva aluat presarat cu ciuperci si rumegus, sau ce \'mniezau se pune pe blatu\' ala de costa 2 EUR 95 slice-u\'. Si intra amandoi in stabiliment, si incep sa se sfadeasca: ca ea vrea cu ciuperci - ba nu, ca n-ar vrea; ca vrea cu cucuruz - nu, ca nici cu cucuruz; cu fructe de mare - da\' oare is proaspete? si sigur is de mare? ca daca-s de ocean? - in fine, stiti voi, rahatzishurile alea mici de le fac femeile cand comanda ceva, de studiaza meniu\' de parc-ar fi revista de p***e.\r\n\r\nSi cand se hotarau astia cum ne hotaram amu, noi, ca oare sa votez cu Basescu, sau sa votez NU?, asa, numa ce le zice sÃ¢sÃ¢itu\' de ii servea:\r\n\r\n- Da\' putesssi comanda in romunessssste!\r\n- Uau, zice astia, de-a dreptu\' perplecssssi. Un roman la o pizzerie italiana in Germania!\r\n- Nu, zice nenea, nu issss roman.\r\n\r\nAstia or ramas un pic dezorientati, ca la dezbaterile electorale daca li s-ar fi reprosat lor ca de ce e prieteni cu Becali si de ce conduce dupa ce o beut si de ce o luat-o pe Elena Udrea de consilier si poate nu numai, si ca de ce crede ca JEG e comunist,  si ca baga-mi-as, asta e, altu\' mai bun  nu gasim in 2007, asta e, asta e, asta e.\r\n\r\n- Nu, continua nenea, nu sssunt roman.\r\n- Bine, zic astia, intuind (si pe buna dreptate, as zice eu!) ca ceva-ceva tot trebuie sa fie nenea ala sÃ¢sÃ¢it, ce esti?\r\n- A! zice asta. Sunt esssspaniol.\r\n- Cocker, se gandesc astia in mintea lor, joe cocker spaniel o fi nenea!\r\n- Essspaniol, sssi locuiessssc in Valensssssia.\r\n- Bine-bine, zic ei, si noi locuim in Bistrita, da\' nu stim Valensiana.\r\n- A!, sssice omu\', a trebuit ssssa invasss limba romana.\r\n- ?\r\n- Da. A trebuit. Am avut multi, multi-multi, muuuhuhuulti colegi de trabaho romuni, si numai asa eu putut insssseless la iei!\r\n- !!!\r\n- <em>Ketchup iute, sau picant?</em>','Intamplari in pizzerie - episodul doi',0,'','publish','open','open','','intamplari-in-pizzerie-episodul-doi','','','2007-05-12 18:42:08','2007-05-12 16:42:08','',0,'http://www.groparu.ro/?p=390',0,'post','',3),(392,1,'2007-05-12 20:04:18','2007-05-12 18:04:18','Deci.\r\n\r\nDeci se stie ca nemtii au un talent aparte de a porni razboaie pe care le pierd, si in procesu\' asta unele tari o cam muiesc. De exemplu, Romania o ramas vaduvita de un tezaur intreg de moldovence si bucovinence lasate muscalilor, ca sa nu mai punem la socoteala podgoriile alea (uai, sete mi-e!) cu struguri cu boabe maaaari, faine si imbatatoare-fara-de-mahmureala-prea-mare.\r\n\r\nDeci se stie si ca sunt o natie nu tocmai toleranta - mai ales daca esti cafegiu la coloare, nu le stii limba sau esti francez, lucru de care iti poti da seama in orice benzinarie, sau pe autostrada, cand te opreste politia fest daca ai numar de Romunica. De exemplu, o prekina zicea ca o vazut fix in Hamburg (aia e hapt in nord, departe de arealul shutzilor romani) un anunt la magazin, pe care scria, IN LIMBA ROMANA, <em>VA RUGAM FRUMOS NU FURATI</em> (io i-as fi zis patronului - da\' sa perpelim ovreiashi avem voie, mein herr?)\r\n\r\nSe mai stie - daca nu stiati, va zic io - si ca sunt o natie puturoasa (da! sor-mea se plange non-stop de asta, ca cum ii apare un cearcan la o nemtoaica isi ia concediu medical 2 saptamani) si hyper zgarcita. Nu au cultura cadoului. Si mai degraba si-ar scoate un ochi decat sa iti cumpere o bere - chiar daca cand or fo in Romunica i-ai inecat in licoare de maltz.\r\n\r\nSpre norocul lor, au o tzara faina, de care nu pot sa zic decat ca e bine ca e locuita. Finca o sa ne putem muta acolo la masa pusa, cand o sa inceapa romanii al treilea rezbel.\r\n\r\nAmu, finca tot auzim si citim si vedem peste tot ca romanii or batut, violat, furat, omorat si perversionat sexual tot felu de semintii, dati-mi voie sa va atrag atentia asupra unei mici gainarii nemtesti. Nemtesti-nemtesti 100%, nu ca masinile alea de la zice Opel care is facute de turci 100% (daca nu ma credetz, meretz la uzinele din Russelsheim, si daca vedeti vreun blond pe-acolo pe linia de asamblare, eu va donez un testicul, pe ala mai bleg, ala stangu\' parca e, da\' verific, sa fiu sigur).\r\n\r\nDeci: nu e vorba de faptul ca lu cumnatu-meu ii dispar anual vreo 20-30 de stupi. Sau macar cordelina cu care ii leaga. Sau ca i se fura din gradina tat felu\'. E vorba ca amu ii o saptamana, un neamt 100% blond si Herrensfolk o intrat la sor-mea in casa si o furat pusculitele copiilor, ca nu mai avea bani de beutura. Noroc ca l-or prins eins zwei polizei. Norocu\' lui - ca de-l prindea sor-mea, ii taia mana si i-o baga in cur, sa-si fure excrementu\'! Apriga femeie, sor-mea, credeti-ma, si cam musulmanca la faza asta...\r\n\r\nIn rest, as minti daca as zice ca nemtii pe care ii cunosc iz najpa. Dimpotriva.','Care nemti? Aia hotzi?',0,'','publish','open','open','','care-nemti-aia-hotzi','','','2007-05-12 20:17:57','2007-05-12 18:17:57','',0,'http://www.groparu.ro/?p=392',0,'post','',3),(440,2,'2007-05-25 10:25:31','2007-05-25 08:25:31','','dsc02095.JPG',0,'','inherit','open','open','','dsc02095jpg','','','2007-05-25 10:25:31','2007-05-25 08:25:31','',441,'http://www.groparu.ro/wp-content/uploads/2007/05/dsc02095.JPG',0,'post','image/jpeg',0),(394,2,'2007-05-14 14:03:14','2007-05-14 12:03:14','httpwww.doingtheartwork.com www.groparu.ro blog romanesc romanian blog referendum 2007 basescu','httpwww.doingtheartwork.com www.groparu.ro blog romanesc romanian blog referendum 2007 basescu',0,'','inherit','open','open','','httpwwwdoingtheartworkcom-wwwgroparuro-blog-romanesc-romanian-blog-referendum-2007-basescu','','','2007-05-14 14:03:14','2007-05-14 12:03:14','',396,'http://www.groparu.ro/wp-content/uploads/2007/05/wwwdoingtheartworkcom-wwwgroparuro-blog-romanesc-romanian-blog-referendum-2007-basescu.JPG',0,'post','image/jpeg',0),(395,2,'2007-05-14 14:04:38','2007-05-14 12:04:38','httpwww.doingtheartwork.com www.groparu.ro blog romanesc romanian blog referendum 2007 basescu','httpwww.doingtheartwork.com www.groparu.ro blog romanesc romanian blog referendum 2007 basescu',0,'','inherit','open','open','','httpwwwdoingtheartworkcom-wwwgroparuro-blog-romanesc-romanian-blog-referendum-2007-basescu-2','','','2007-05-14 14:04:38','2007-05-14 12:04:38','',396,'http://www.groparu.ro/wp-content/uploads/2007/05/wwwdoingtheartworkcom-wwwgroparuro-blog-romanesc-romanian-blog-referendum-2007-basescu.jpg',0,'post','image/jpeg',0),(396,2,'2007-05-14 14:04:53','2007-05-14 12:04:53','<a href=\"http://www.groparu.ro/wp-content/uploads/2007/05/wwwdoingtheartworkcom-wwwgroparuro-blog-romanesc-romanian-blog-referendum-2007-basescu.jpg\" title=\"httpwww.doingtheartwork.com www.groparu.ro blog romanesc romanian blog referendum 2007 basescu\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/05/wwwdoingtheartworkcom-wwwgroparuro-blog-romanesc-romanian-blog-referendum-2007-basescu.jpg\" alt=\"httpwww.doingtheartwork.com www.groparu.ro blog romanesc romanian blog referendum 2007 basescu\" /></a>\r\n\r\nMunca artistica (c) <a href=\"http://www.doingtheartwork.com/\" target=\"_blank\">http://www.doingtheartwork.com</a>, concept mizerabil (c) www.groparu.ro','Grija ce votati la referendum!!!!',0,'','publish','open','open','','grija-ce-votati-la-referendum','','','2007-05-14 15:10:13','2007-05-14 13:10:13','',0,'http://www.groparu.ro/?p=396',0,'post','',11),(397,2,'2007-05-15 13:30:52','2007-05-15 11:30:52','www.doingtheartwork.com www.groparu.ro blog romanesc romanian blog referendum 2007 vacaroiu ','www.doingtheartwork.com www.groparu.ro blog romanesc romanian blog referendum 2007 vacaroiu ',0,'','inherit','open','open','','wwwdoingtheartworkcom-wwwgroparuro-blog-romanesc-romanian-blog-referendum-2007-vacaroiu','','','2007-05-15 13:30:52','2007-05-15 11:30:52','',398,'http://www.groparu.ro/wp-content/uploads/2007/05/vacaroiu-votca-final.jpg',0,'post','image/jpeg',0),(398,2,'2007-05-15 13:31:02','2007-05-15 11:31:02','<a href=\"http://www.groparu.ro/wp-content/uploads/2007/05/vacaroiu-votca-final1.jpg\" title=\"www.doingtheartwork.com www.groparu.ro blog romanesc romanian blog referendum 2007 vacaroiu\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/05/vacaroiu-votca-final1.jpg\" alt=\"www.doingtheartwork.com www.groparu.ro blog romanesc romanian blog referendum 2007 vacaroiu\" height=\"710\" width=\"322\" /></a>\r\n\r\nMunca artistica: (c) <a href=\"http://www.doingtheartwork.com/\" target=\"_blank\">http://www.doingtheartwork.com</a>, concept mizerabil, da\' curat mizerabil: (c) www.groparu.ro','Ghiciti personajul :D',0,'','publish','open','open','','presedintele-interimar-al-romaniei','','','2007-05-15 22:51:53','2007-05-15 20:51:53','',0,'http://www.groparu.ro/?p=398',0,'post','',1),(399,2,'2007-05-15 13:31:39','2007-05-15 11:31:39','www.doingtheartwork.com www.groparu.ro blog romanesc romanian blog referendum 2007 vacaroiu ','www.doingtheartwork.com www.groparu.ro blog romanesc romanian blog referendum 2007 vacaroiu ',0,'','inherit','open','open','','wwwdoingtheartworkcom-wwwgroparuro-blog-romanesc-romanian-blog-referendum-2007-vacaroiu-2','','','2007-05-15 13:31:39','2007-05-15 11:31:39','',398,'http://www.groparu.ro/wp-content/uploads/2007/05/vacaroiu-votca-final1.jpg',0,'post','image/jpeg',0),(400,2,'2007-05-15 16:16:09','2007-05-15 14:16:09','<p class=\"MsoNormal\">Sa-ti stea pula tare, dreapta\r\nPe cea mai inalta treapta!\r\nSa nu-ti creasca par pe spate,\r\nSa ai cele mai mici rate,\r\nSi cea mai buna masina,\r\nLa whiskey mereu maslina,\r\nCu ceapa mereu slanina,\r\nTrafic liber drept in fatza\r\nSi cafea de dimineatza!\r\nSa nu dai pe la doftori,\r\nSa zbori mai presus de nori,\r\nS-ai chiloti curati mereu,\r\nSi tricouri, si maieu!\r\nSa nu-ti crape codul sursa\r\nCopiii sa-ti primeasca bursa\r\nS-avem si noi bani de-o bere\r\nSi de cate o placere...\r\nSi pe-a tale vietii schema\r\nVedeta sa fii pe scena\r\nCand intri s-auzi un gong\r\nFinca nu uita: Darwin was wrong!\r\n<p class=\"MsoNormal\">PS: Faza cu <em>Darwin was wrong</em> e de atunci de cand ma certam cu el in legatura cu survival of the fittest, si i-am zis: tu esti cea mai buna dovada ca Darwin was wrong, si ca nu cei mai inteligenti si frumosi supravietuiesc. Si i-am si imprimat o pereche de chiloti cuÂ mesajul apoteotic, pe care i-am facut-o cadou de Craciun. In imagine: un crampei din exact acea pereche de chilotz.</p>\r\n<p class=\"MsoNormal\"><a href=\"http://www.groparu.ro/wp-content/uploads/2007/05/coprea-chiloti.JPG\" title=\"www.groparu.ro blog romanesc romanian blog\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/05/coprea-chiloti.JPG\" alt=\"www.groparu.ro blog romanesc romanian blog\" /></a></p>\r\n<p class=\"MsoNormal\">Noroc ca e ficior de treaba.</p>','Az\' e ziua lu COprea',0,'','publish','open','open','','az-e-ziua-lu-coprea','','','2007-05-15 16:16:09','2007-05-15 14:16:09','',0,'http://www.groparu.ro/?p=400',0,'post','',3),(401,2,'2007-05-15 16:15:14','2007-05-15 14:15:14','www.groparu.ro blog romanesc romanian blog','www.groparu.ro blog romanesc romanian blog',0,'','inherit','open','open','','wwwgroparuro-blog-romanesc-romanian-blog-2','','','2007-05-15 16:15:14','2007-05-15 14:15:14','',-1179236672,'http://www.groparu.ro/wp-content/uploads/2007/05/coprea-chiloti.JPG',0,'post','image/jpeg',0),(402,2,'2007-05-15 23:19:20','2007-05-15 21:19:20','Draga domnule Traian Basescu,\r\n\r\nVa multumesc pentru ca imi faceti reclama in aceste vremuri de restriste pentru tzara mea, a bunicii mele si a fostei mele pisici, de asemenea a asociatiei de proprietari din blocul in care locuiesc. Va multumesc pentru ca, din toata gasca de probleme care va bantuie, v-ati facut timp pentru a-mi promova saitu\'.\r\n\r\nV-as ruga totusi sa demontati definitiv vocile care spun ca v-as fi platit ca sa-mi faceti reclama. De aceea, va rog sa emiteti o declaratie oficiala in acest sens cat puteti de repede. Va multumesc anticipat!\r\n\r\nPS: pentru cei care nu stie despre ce e vorba, vizitati <a href=\"http://www.basescu.ro/index.php?o=digital_guerilla&amp;page=4&amp;img=17#poza\" target=\"_blank\">saitu\' lui Basescu</a>.','Traian Basescu face reclama www.groparu.ro!',0,'','publish','open','open','','traian-basescu-face-reclama-wwwgroparuro','','','2007-10-06 11:03:59','2007-10-06 09:03:59','',0,'http://www.groparu.ro/?p=402',0,'post','',6),(406,2,'2007-05-17 10:42:13','2007-05-17 08:42:13','Io am o camera. Nu garsoniera, ca aia e a bancii. O camera digitala. Nu analoaga. Un Sony model mai vechi, cumparat din bazar din Kuala Lumpur, Malaezia, da\' care scotea poze mai mult sau mai putin porno, cum ar fi asta:\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/05/poza-minunata.jpg\" title=\"www.groparu.ro blog romanesc romanian blog\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/05/poza-minunata.jpg\" alt=\"www.groparu.ro blog romanesc romanian blog\" height=\"250\" width=\"331\" /></a>\r\n\r\nIntr-o buna zi, dar rea pentru ea, camera mea s-a hotarat sa ramana fara obsteasca ei husa, cumparata special din Olanda, basca vreo 4 acumulatori, basca micul trepied cu trei picioare, ceea ce facea ca eu si trepiedul meu sa ne asemanam in cel putin o privintza, si aceea esentiala.  Pierzand prezervativul, am fost silit sa ies la colindat  fara husa; ceea ce a facut ca gerul napraznic al lui decemvre, te uita cum ninge, Bacovia si Elefantis, sa mi-o gripeze in asa hal incat sa nu ii mai intre obiectivu\' inauntru. Blocat, intzapenit, obiectivus captivus.\r\n\r\nFinca nu is genu de om care sa lalaie lucrurile, am cautat imediat un atelier de reparat camere digitale aduse din Malaezia. Pe care l-am si gasit 6 luni mai tarziu, langa fabrica de bere aia din Cluj, aia cu nume de animal in latina.\r\n\r\nSi acolo - un mosulica simpatic, la prima poza. Ginecolog de camere. Ii ofer aparatu [aradit, ca pe o ofranda.\r\n\r\n- Ooooooo!!!!!! facu moshu\'.\r\n- :P:P:P:P:P, facui io. Am vrut sa zic si q,r,s, da\' n-am mai apucat.\r\n- Dar ce are????\r\n- D-apoi... obiectivu vrea sa violeze aeru\' de-afara cu orice pretz, zic io, ca nu se mai da bagat inauntru, cum nu mai vrea tata sa iasa din berarie.\r\n- Ce i-ai facut??? ma intreaba mosulica, si jur ca m-am simtit ca in stiu ce-ai facut azi vara cand mi-o fixat intre ochi o privire de inghetat testicule (ochii mei is foarte apropiati unu de altul, ca la un bibelou cu o balerina, de-l are mama pe TV; si cand unu din ei se crizeaza, alalalt se molipseste inaintea lui).\r\n\r\nIo nu prea ma pierd usor cu firea, numa cand is la reparatorul de camere aduse din Malaezia.\r\n\r\n- ... (inghit in demisec, caut cuvinte, gasesc numa injuraturi gen \"p*** me\" - semn al unei ideatzii fragmentare, ma inec in propria saliva, renuntz)\r\n- Ce e asta? Unde e husa?!?!?!?\r\n- Apai... am... pierdut-o...\r\n- I-ai pierdut husa:O:O:O?\r\n- ...ddd-aaaa...\r\n- Unde? Cand???\r\n- ...nu chiar asa de multa vreme, dreg io busuiocu\'...\r\n- Uite ce-i aici! si-si ia nenea lupa, si ma prinde de ceafa, si imi baga nasu in sticla. Uite!\r\n\r\nMa uit - avea dreptate. O urma de amprenta.\r\n\r\n- Stii ce inseamna asta?\r\n\r\nHait! zic io. S-o prins ca io eram violatoru de studente...\r\n\r\n- Ne-gli-jen-tza!!!!\r\n- ...sa stiti ca am mai si dat-o imprumut... zic io.\r\n\r\nDeja nenea horcaia de indignare.\r\n\r\n- Ai dat camera imprumut!!!! Cui???\r\n- ...pai... altora...?\r\n- Altora!!!!! fornai nenea din nas ca un mustang. Altora!!!!\r\n- ...pai... da...\r\n- Scrie! zise nenea catre secretara lui, care aveam sa aflu imediat ca era fiu-su. Camera Sony DHCP HTML lalala, seria 696969. Uite aici!\r\n\r\nSi ma lua de o areapa, si imi deschise dulapul, unde zacea cuminte un orasel de camere digitale de facut poze mai mult sau mai putin porno, ca aia de sus. Din mormanu\' de plastic si fier, lua nenea meu o cutiutza, o scutura viguros sa se asigure ca e cea buna, si apai scoase cu grija din ea neshte matze de camera. Lua unul din ele cu penseta, si racni:\r\n\r\n- Ai aici un exemplu tipic de neglijentza: un amator (nu isi putu stapani o grimasa) a incercat sa repare obiectivul unei camere ramase, ca si a ta, fara husa. Uite aici! si imi vÃ¢rÃ¢ isteric nasu\' in cutiutza, de era sa prizez numa shurupuri. Vezi?\r\n\r\nVedeam.\r\n\r\n- Stabilizatorii sunt dushi; artropozii sunt terminati, graiferele nu mai zic, tasoarele s-or dezlipit de rugozitoare, si luxometru - nici nu mai am cuvinte.\r\n\r\nM-am uitat - si intr-adevar, luxometrul era distrus. Complet distrus.\r\n\r\n- Scrie! racni iara catre secretara de fiu-su. Obiectiv complet distrus! Iar acum, zise uitandu-se iara intre ochii mei, te va costa 2 milioane.\r\n\r\nMa apuca un suras nervos.\r\n\r\n- Plus 500.000 consultatia.\r\n\r\nPizda masii, zic, asta ii mai scump ca venerologu\' ala la care ma tot duc io!\r\n\r\n- Si o sa fie gata in... statu pretz de o clipita. 14 iunie.\r\n- O lunaaaaa???? Mie-mi trebuie... stiti... joia viitoare... ca plec la Tiganiada...\r\n- Joia viitoare??? Si incepu sa se sugrume. De ce toti vor joia viitoare? De ce??? si aproape cazu in genunchi.\r\n- Va rog... ddda-da-cacaca se puate... il luai io, coplesit de mila.\r\n- Uite-te acolo! si ma lua oara de ceafa ca pe un mÃ¢Å£, si imi pironi privirea  intr-un tablou cu tarife. Tarif de urgente: 200% din tariful normal.\r\n- Va rog... implor io, ca ostatecul in mainile gherilelor, va rog... va implor...\r\n- Bine! zice el, gigantesc in marinimia lui. Facem, zice. Facem... da\' cat dai peste? ma intreaba.\r\n\r\nPe scurt: reparatia camerei mele ma costa aproape 120 dolari. Daca mai pun inca vreo 60, pot linistit sa imi cumpar alta camera din Malaezia, cu un an garantie worldwide, cu ceva zoom mai bun, si noua. Nou-noutza.\r\n\r\nDar am acceptat pretul.\r\n\r\nSi acum incerc cu disperare sa nu imi tai venele.','Repar camere digitale, tzapa garantata',0,'','publish','open','open','','repar-camere-digitale-tzapa-garantata','','','2007-05-17 10:42:13','2007-05-17 08:42:13','',0,'http://www.groparu.ro/?p=406',0,'post','',3),(407,2,'2007-05-17 00:40:32','2007-05-16 22:40:32','www.groparu.ro Blog romanesc Romanian blog basescu','www.groparu.ro Blog romanesc Romanian blog basescu',0,'','inherit','open','open','','wwwgroparuro-blog-romanesc-romanian-blog-basescu','','','2007-05-17 00:40:32','2007-05-16 22:40:32','',408,'http://www.groparu.ro/wp-content/uploads/2007/05/basescu.JPG',0,'post','image/jpeg',0),(408,2,'2007-05-17 00:40:50','2007-05-16 22:40:50','<a href=\"http://www.groparu.ro/wp-content/uploads/2007/05/basescu.JPG\" title=\"www.groparu.ro Blog romanesc Romanian blog basescu\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/05/basescu.JPG\" alt=\"www.groparu.ro Blog romanesc Romanian blog basescu\" /></a>','Basescu - again',0,'','publish','open','open','','basescu-again','','','2007-05-17 00:40:50','2007-05-16 22:40:50','',0,'http://www.groparu.ro/?p=408',0,'post','',1),(405,1,'2007-05-16 16:18:50','2007-05-16 14:18:50','[google -4883263944138886935]\r\n\r\nI: Cine vine?\r\nR: Tiganiada vine.\r\n\r\nI: Ce este Tiganiada?\r\nR: Imaginati-va ca va plac prajiturile, si dintr-o data aveti acces la toate prajiturile din lume. Imaginati-va ca dati viatza celor mai adanci, absconse,  reprimate porniri ale voastre (nu si alora sexuale! opsedatilor). Imaginati-va ca va eliberati de kimonoul de gheishe corporatiste si va transformati intr-o bacanta cu drept de viatza si de moarte asupra propriului destin. Un mic Dumnezeu.\r\n\r\nTiganiada e locul unde poti face ce vrei finca stii ca maine nu vor vui colegele si prekinele (\"uai, tu, iara s-o imbatat Groparu si s-o pupat cu noi toate, si ne-o mai si pus sa ne sarutam intre noi!!!!\"). Tiganiada este festivalul destrabalarii, al libertatii apsolute, al descatusarii, al eliberarii. Este locul unde nu exista nici durere, si nici intristare. Da, si are si verdeatza. Nu, nu dureaza o vesnicie.\r\n\r\nPe scurt: a inceput ca un festival de purificare, pre-sesiune. Masculi (NUMAI masculi) care pleaca cu cortul in natura si se destrabaleaza (pe Valea Caselor, langa Rasinari, acolo unde Cioran juca folbal cu craniile primite de la groparu\' - sic! - satului).  Si acolo fac fight club in baltoacele in care se scalda bivolii satului, joaca rugby desculti cu sticla de vin, se bat, se cearta, se impung, fac tot - dar absolut TOT - ce le trece prin cap. De la o vreme, cineva, zis Groparu\', a avut ideea sa faca din aceasta iesire traditionala un festival tematic. Adica cu 2-3 luni inainte ne lasam barbi, nu ne mai spalam pe dinti, ne facem cicatrici pe fatza si NE IMBRACAM IN TIGANI. Cu palarii, cameshi inflorate, pantofi cu toc, geci si veste negre. Ghiul, lanturi, burlane si covoare, site de metal si haine second. Slapi cu ciorapi gauriti in picioare. Si merem prin oras si ne radem de oameni. La tribunal, la spital, la politie si in piata. La macelar si in supermarket. Dup-aia, merem in pustietate si ne facem pulbere, si repetam cam ce am facut si in alti ani: bataie cu urzici, suturi in cur, rugby cu sticla de vin desculti, lapte gros - orice fel de activitate care provoaca durere.\r\n\r\nI: Cine poate veni la Tiganiada?\r\nR: Numai invitatii speciali. Fara pantofari complexati. Ca sa accezi la Tiganiada trebuie 1) sa fii invitat de un membru cu drept de vot, care isi pune obrazuâ€™ pentru curuâ€™ tau 2) sa fii evaluat alcooliceshte de catre intreaga celula de criza (aka â€œoligarhiiâ€); la cel mai mic semn de slabiciune (daca nu poti bea, injura, scuipa la fel de departe sau ai retineri in a ciupi chelneritza de cur, provoca badigarduâ€™ localului la o cafteala sau facut pe homosexualuâ€™ pe langa patron, sau fereasca Dumnezeu ce ne mai coace mintea!) candidatura ti se suspenda, pula Tiganiada, si membrul care te-a invitat isi pierde dreptul de a invita pe altcineva un an; 3) daca pe perioada Tiganiadei reusesti sa nu te imbeti sau cÃ¢rÃ¢ieÅŸti ceva de genuâ€™ â€œio nu fac din astea, ba!â€ la ce face grupuâ€™, vei fi pedepsit. Crunt. Excludere, balegar in bocanci, whiskey turnat pe tine cand dormi si dat foc, aruncat in parau cu sacuâ€™ de dormit, â€œgramada cere varfâ€ - resursele sunt practic infinite. Nu ne testati imaginatia, Calatoriile lui Gulliver is Pepsi in comparatie cu ce putem noi face. Si nu ma mai bateti la cap ca \"vreau sa vin si eu\".\r\n\r\nI: Cine e personajele?\r\nR: Personajele e unice:\r\n- Ielvis;\r\n- CrÃ¢ng aka Nelu\r\n- Rramon aka TÃ¢mp aka Mitroa\r\n- Degeaba aka Cipala aka Cuiu\' din Pula aka Unchiu-to\r\n- DudÄƒ aka Åžtef\r\n- CÃ¢rlanu\' aka Huby\r\n- GanistrÄƒ aka Hinu\'\r\n- GleznÄƒ aka Sugiu\r\n\r\nI: Cand va avea loc Tiganiada de anul acesta?\r\nR: In data de 25-27 mai.\r\n\r\nMai pe romaneshte: AMR-ul descreste. Read last year\'s story <a href=\"http://www.groparu.ro/?p=47\" target=\"_blank\">here</a>.','Tiganiada 2007 - the final countdown',0,'','publish','open','open','','tiganiada-2007-the-final-countdown','','\nhttp://www.groparu.ro/?p=47','2007-05-16 16:27:22','2007-05-16 14:27:22','',0,'http://www.groparu.ro/?p=405',0,'post','',5),(409,2,'2007-05-17 01:19:54','2007-05-16 23:19:54','www.groparu.ro blog romanesc romanian blog','www.groparu.ro blog romanesc romanian blog',0,'','inherit','open','open','','wwwgroparuro-blog-romanesc-romanian-blog-2','','','2007-05-17 01:19:54','2007-05-16 23:19:54','',406,'http://www.groparu.ro/wp-content/uploads/2007/05/poza-minunata.jpg',0,'post','image/jpeg',0),(410,2,'2007-05-17 10:55:13','2007-05-17 08:55:13','...primesc asta pe mes, de la Mariana, piranda lu CrÃ¢ng:\r\n\r\n\"aseara a fost show la noi. S-a intalnit celula de criza, beata turta, si au dezbatut probleme arzatoare: cate gr de carne de mici sa ia, pt ca de bautura se stia deja... cat mai mult. In caz ca nu stiai, acum aveti steag si act de constituire a nucleului \"valea caselor\" - care e mortal. Asemenea limbaj nu am intalnit nici la academicieni. L-am intrebat pe Hubi ce naiba aveti voi nevoie de steag si de status, mai ales ca unicul motiv pt care mergeti acolo este sa va imbatati ca porcii, si pt asta nimeni nu si-a ridicat niciodata statuie. Mi-a bolborosit ceva, dar din cauza izului nu l-am inteles, no, asta e. Sper ca ti-ai lasat si tu barba sa nu fie numai mitroii singurii care se fac de ras. Abia astept sa treaca odata evenimentul si sa se rada CrÃ¢ng, ca tot timpul cand ploua ii ploua si lui din barba cate ceva\"\r\n\r\nAlte comentarii is de prisos.','Tot Tiganiada 2007',0,'','publish','open','open','','tot-tiganiada-2007','','','2007-05-17 10:55:13','2007-05-17 08:55:13','',0,'http://www.groparu.ro/?p=410',0,'post','',0),(411,2,'2007-05-22 01:09:33','2007-05-21 23:09:33','<strong>CrÃ¢ng\r\n</strong><a href=\"http://www.groparu.ro/wp-content/uploads/2007/05/dsc01254.JPG\" title=\"www.groparu.ro tigan gipsy rrom tiganiada blog romanesc romanian blog\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/05/dsc01254.thumbnail.JPG\" alt=\"www.groparu.ro tigan gipsy rrom tiganiada blog romanesc romanian blog\" /></a>\r\nOmu\' asta se tot scarpina, si nu stim de ce. Si ii miros mainile a peste.\r\nE un mascul care pentru coniac si-ar vinde un rinichi. Sau placa video.\r\nAsteptam sa devina miliardar. Prin vanzarea sticlelor goale de beutura.\r\n\r\n<strong>Rramon aka TÃ¢mp\r\n</strong><a href=\"http://www.groparu.ro/wp-content/uploads/2007/05/dsc01154.JPG\" title=\"www.groparu.ro tigan gipsy rrom tiganiada blog romanesc romanian blog\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/05/dsc01154.thumbnail.JPG\" alt=\"www.groparu.ro tigan gipsy rrom tiganiada blog romanesc romanian blog\" /></a>\r\nIl respectam finca ne-a invatzat cum sa ne stergem pe ambele fetze ale hartiei igienice, fara sa ne murdarim prea tare.\r\nE singurul dintre noi care nu merge cu Playboyu\' la buda. Finca nu stie sa citeasca. Nici macar pozele.\r\nDaca ar ramane fara apa in desert, ar functiona mai bine cu coniac.\r\n\r\n<strong>Degeaba aka Cipala aka Cuiuâ€™ din Pula aka Unchiu-to\r\n</strong><a href=\"http://www.groparu.ro/wp-content/uploads/2007/05/dsc01236.JPG\" title=\"www.groparu.ro tigan gipsy rrom tiganiada blog romanesc romanian blog\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/05/dsc01236.thumbnail.JPG\" alt=\"www.groparu.ro tigan gipsy rrom tiganiada blog romanesc romanian blog\" /></a>\r\nUnchiu-to nu vrea a fermenteze cand moare, d-aia bea votca. Zice ca ajuta.\r\nNu foloseste metoda Rramon de stergere la cur cu ambele fetze ale hartiei: pur si simplu sta pana se usuca, si apai culege bucatelele maronii din chiloti cu penseta.\r\nSe potriveste la Valea Caselor ca doua culori complementare de portocaliu fosforescent cu verde.\r\n\r\n<strong> DudÄƒ aka Åžtef\r\n</strong><a href=\"http://www.groparu.ro/wp-content/uploads/2007/05/dsc01237.JPG\" title=\"www.groparu.ro tigan gipsy rrom tiganiada blog romanesc romanian blog\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/05/dsc01237.thumbnail.JPG\" alt=\"www.groparu.ro tigan gipsy rrom tiganiada blog romanesc romanian blog\" /></a>\r\nStef e chel, finca cand era mic ma-sa il spala pe par cu balsam de rufe, nu de par. Ca doara tot balsam e.\r\nStiti burtica lu\' Adi Minune? El e ca buricu\' ei personal.\r\nMa intreb de ce ii apare discret un norisor de spuma in coltul buzelor cand aude ca trag clopotele la biserica.<strong>\r\n</strong>\r\n\r\n<strong>CÃ¢rlanuâ€™ aka Huby\r\n</strong><a href=\"http://www.groparu.ro/wp-content/uploads/2007/05/dsc01220.JPG\" title=\"www.groparu.ro tigan gipsy rrom tiganiada blog romanesc romanian blog\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/05/dsc01220.thumbnail.JPG\" alt=\"www.groparu.ro tigan gipsy rrom tiganiada blog romanesc romanian blog\" /></a>\r\nDiferenta dintre el si ciorapii lui? Ciorapii miros mai bine.\r\nAre o minte ca o fosa septicÄƒ.\r\nE baiat finutz, ca mucegaiul ala care se formeaza uneori pe gemu fara aspirina.\r\nDaca Egiptul a primit 7 plagi, Romania a primit una singura: pe el.\r\n\r\n<strong>GanistrÄƒ aka Hinuâ€™\r\n</strong><a href=\"http://www.groparu.ro/wp-content/uploads/2007/05/dsc01264.JPG\" title=\"www.groparu.ro tigan gipsy rrom tiganiada blog romanesc romanian blog\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/05/dsc01264.thumbnail.JPG\" alt=\"www.groparu.ro tigan gipsy rrom tiganiada blog romanesc romanian blog\" /></a>\r\nE posibil ca parintii lui sa fie veri.\r\nIntr-o alta viatza il suspectez ca a fost furtun de vidanja, la cum le suge din sticla.\r\nDaca Laura a fost inspiratia lui Petrarca, el a fost inspiratia pentru creatorul pokemonilor.\r\nAre o burtica moale ca un covor de Cisnadie.\r\n\r\n<strong>GleznÄƒ aka Sugiu\r\n</strong><a href=\"http://www.groparu.ro/wp-content/uploads/2007/05/dsc01158.JPG\" title=\"dsc01158.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/05/dsc01158.thumbnail.JPG\" alt=\"dsc01158.JPG\" /></a>\r\nDaca s-ar face giggolo, s-ar ruina. Ar trebui sa plateasca din greu clientelor, si din cauza ca are mereu matreatza pe sprancene. Si mai are un coÅŸ purulent permanent sub nas, langa gura aia cu care ne pupa.\r\nCel mai mare rau care i se poate intampla Romaniei: o natie de basesti. Sau inca unul ca el.\r\n\r\n<strong>Ielvis</strong>\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/05/dsc01144.JPG\" title=\"www.groparu.ro tigan gipsy rrom tiganiada blog romanesc romanian blog\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/05/dsc01144.thumbnail.JPG\" alt=\"www.groparu.ro tigan gipsy rrom tiganiada blog romanesc romanian blog\" /></a>\r\nStau circumvolutiunile la el in cap ca taiteii in supa de galuste. Cati taitei ati vazut voi in supa cu galuste?\r\nUn burete cu bere! Stiti tinerii aia frumosi, cu par des, zambet inimitabil, dantura perfecta si ochi duri din reclamele la sampoane? El e perfect opusul lor.\r\nDaca am fi toti parchet, ar fi placa aia de faiantza ciobita.','Tiganiazii',0,'','publish','open','open','','tiganiazii','','','2007-05-22 01:09:33','2007-05-21 23:09:33','',0,'http://www.groparu.ro/?p=411',0,'post','',9),(412,2,'2007-05-23 15:29:18','2007-05-23 13:29:18','Pffuaaai, ce m-am naravat azi-dimineatza!\r\n\r\nDeci. Ma sui intr-un troleu 6, sa mor io, full. Da\' full. Full-full-full! Clar ca inghesuit numa\' de pensionari si cincuagenari care facea economie de apa, ca costa.\r\n\r\nOpreste troleu la urmatoarea statie, se mai urca un lot de bovine. Ma dau, politicos, mai incolo, pana dau de un cincuagenar cu fobie de apa. Si sapun. Care nu se da miscat. Ma impung in el, dau din cur, incerc sa ma strecor, il adulmec, pufai nemultumit, el - tzeapan ca Cheile Turzii. In spatele meu ma inghesuia una grasa, in fata mea era nenea. Ma simteam ca maioneza din shaorma.\r\n\r\nBa - si-mi sar mucii.\r\n\r\nMa strecor in spatele lui. Asta nemiscat. Ma apropii de el. El - nemiscat. Ma lipesc de el. Nici macar nu are bunul simt sa isi clinteasca un floc, macar. Atunci sug burta, pe care n-o am, ma fac covrig, strang din dinti, si il impung cu putulica. Viguros. Nici macar nu tresare!!! Il impung a doua oara. Se uita la mine, ma fac ca ploua.  Il impung a treia oara, cu ochii inchisi. Nimic.\r\n\r\nDeja nu mai suportam. L-am lasat  in pizda ma-sii si am parasit locu\' de batalie. Pensionarii astia chiar nu mai au nici un pic de rusine!\r\n\r\nJur ca-mi iau mashina.','Azi dimineatza in RATUC',0,'','publish','open','open','','azi-dimineatza-in-ratuc','','','2007-05-23 15:37:40','2007-05-23 13:37:40','',0,'http://www.groparu.ro/?p=412',0,'post','',10),(413,2,'2007-05-18 11:14:22','2007-05-18 09:14:22','Asa mergeam noi la Tiganiada:\r\n\r\n[google -4316446448452607029]\r\n\r\nAsa ne batem noi la Tiganiada (aici, CrÃ¢ng s-o lÄƒsat, asa zice el):\r\n\r\n[google -8288591811634220147]','More Tiganiada 2007',0,'','publish','open','open','','more-tiganiada-2007','','','2007-05-18 11:14:22','2007-05-18 09:14:22','',0,'http://www.groparu.ro/?p=413',0,'post','',3),(414,1,'2007-10-12 13:16:38','2007-10-12 11:16:38','Io am tot stat si m-am gandit, si mi-am dat seama, dupa vreo 6 luni, de ce o castigat Baselu\' referendumu\' ala de suspendare.\r\n\r\nDupa cum poate mai tineti minte, trebia sa votati cu DA ca sa-l alungaÅ£i, ÅŸi cu NU daca vroiati sa il reinstaurati la cÃ¢rma patriei mele cu munÅ£i ÅŸi vÄƒi (Ã®ntr-o vreme aparuserÄƒ ÅŸi <a href=\"http://www.groparu.ro/?p=396\" target=\"_blank\">buletine de vot cu a treia opÅ£iune</a>).\r\n\r\nDeci io am aflat de ce lumea o votat cu NU: Å£ara mea are foarte multe femei. 75% din femeile cu care am incercat eu <em>ceva</em> <em>delicios </em>mi-au zis <strong>NU</strong> din start. Unele chiar rÃ¢njind.\r\n\r\nOdatÄƒ cu referendumul, mi-am dat seama ca nu eram io de vinÄƒ: pur ÅŸi simplu populaÅ£ia asta femininÄƒ e Ã®nvÄƒÅ£atÄƒ sÄƒ zicÄƒ NU indiferent de.\r\n\r\nDeja ma simt mult mai bine.','De ce o castigat Baselu referendumu\'',0,'','publish','open','open','','de-ce-o-castigat-baselu-referendumu','','\nhttp://www.groparu.ro/?p=396','2007-10-12 13:16:38','2007-10-12 11:16:38','',0,'http://www.groparu.ro/?p=414',0,'post','',10),(415,2,'2007-05-18 18:28:03','2007-05-18 16:28:03','Mie, in viata asta, cel mai mult si mai mult si mai mult mi-o placut si o sa-mi placa sa ma f**. Sincer, acuma ce sa ne mai ascundem dupa degete, mie asta imi place sa fac, si cand nu mai pot face sa mangai si sa privesc, si sa gust si iara sa privesc. Si chiar si numa daca vad un decolteu fain pe strada, consider ca ziua aia nu e pierduta, dimpotriva.\r\n\r\nNoa. Ganditi-va numa ce de femei or sa fie la vot! Oioioi! Toate membrele alea de partid care is observatoare or sa fie in comisie. Or sa fie ziariste, observatoare la Pro Democratia (bueeey, si au aia neshte colaboratoare, de jos palaria!), or sa fie vecinele voastre studente care se vor  inghesui acolo cu voi, si de plictiseala se vor uita pe pereti si dupa cururi de ficiori, vor fi toate chiriasele care in ziua aia vor roi in juru\' despicaturii din urna ca manelistele la concert cu Florin Maimuta, va fi toata lumea acolo. Toata lumea cool.\r\n\r\nConcluzia: meretz in puii mei la vot! Si dupa aia protestati cu un sex din ala salbatic, de rupt canapele, sau penal, obosit (\"draga mea, treci tu deasupra\"), sau cu ciorapii pe membrele inferioare, sau la geam, din picioare, si ganditi-va ca va bagati p*** in tata clasa politica, care e cam repetenta, apropos. Numa\' meretz la vot. Si Groparu va binecuvanteaza fornicarea.\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/05/basescu1.JPG\" title=\"Basescu vot\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/05/basescu1.JPG\" alt=\"Basescu vot\" /></a>\r\n\r\nPS: Numa atata mai zic, pana nu uit: cand eram membru in comisia de votare in \'96, am facut rost de 2 telefoane de la gajici! V-as spune si ce o iesit din toata treaba aia, but gentlemen and Groparu never tell...','De ce Referendumumu face bine la viata sexuala',0,'','publish','open','open','','referendumumu-final','','','2007-05-19 11:15:35','2007-05-19 09:15:35','',0,'http://www.groparu.ro/?p=415',0,'post','',1),(417,2,'2007-05-19 16:23:12','2007-05-19 14:23:12','Deci: io am cumparat de doo ori in viata mea ProTV mahazÃ¢n, si amandoua exemplarele or ajuns pe masina de spalat. Ati ghicit, ca lectura de buda.\r\n\r\nDar ieri, pe cand faceam ce fac pana si imparatii, si pe cand rasfoiam si eu mahazÃ¢nu ca orice alt manelist din Manajtur, pac! S-a intamplat. Am cetit si m-am minunat: <a href=\"http://www.cinefan.ro/stiri.php?stire_id=430&amp;titlu=In%20copilarie%20Adina%20Galupa%20isi%20dorea%20sa%20devina%20gropar\" target=\"_blank\">Adina Galup vroia sa se faca gropar cand urma sa devina mare</a>.\r\n\r\nImi pare rau sa o dezamagesc. Nu, Adina, niciodata nu vei putea sa bei cat Groparu.','Din seria: regii maimutelor care imi spun \"I wanna walk like you, talk like you...\"',0,'','publish','open','open','','din-seria-regii-maimutelor-care-imi-spun-i-wanna-walk-like-you-talk-like-you','','','2007-05-19 16:23:12','2007-05-19 14:23:12','',0,'http://www.groparu.ro/?p=417',0,'post','',0),(416,2,'2007-05-18 18:27:47','2007-05-18 16:27:47','','Basescu vot',0,'','inherit','open','open','','basescu-vot','','','2007-05-18 18:27:47','2007-05-18 16:27:47','',-1179504623,'http://www.groparu.ro/wp-content/uploads/2007/05/basescu1.JPG',0,'post','image/jpeg',0),(439,2,'2007-05-24 18:18:40','2007-05-24 16:18:40','M-am gandit taaaare mult pana sa ma hotarasc daca sa scriu asta, sau nu.\r\n\r\nDeci.\r\n\r\nVin intr-o dimineatza matinala la scarbiciu, jumate adormit, jumate mahmur si jumate paraplegic mental. Asa.\r\n\r\nCobor din RATUC, ma indrept spre firma, jumate adormit, jumate mahmur si jumate paraplegic mental. Asa.\r\n\r\nLa un moment dat, ma vede un tuciuriu. Si ma pÃ¢sÃ¢ie. Asa: pssssss!\r\n\r\nIo ma fac ca nu vad, da\' deja ma imbracam in costum de victima. Finca tuciuriu\' vine spre mine. Si ma ia, suierand foaaaarte secretos:\r\n\r\n- Shafu\'!\r\n\r\nIo imi vad de treaba.\r\n\r\n- Shafu\'! Hai sa-ti vand o camera.\r\n- Nu-mi traba, zic io, ca stau in chirie, sh e OK.\r\n- Nu, shafu\', zice el, nu camera d-aia. Camera cu film.\r\n\r\nMa opresc, jumatea paraplegica intelectoal din lobu\' temporal preia controlu\', incepe sa se gandeshte. Face un drill-down in baza de date, si extrage de-acolo ce-i spusese Silvan cu 2 saptamani in urma: <em>mi-am cumparat o camera video furata din Germania</em><em>, m-o costat 300 euro, in magazin costa 559!</em> Ma, zic io, Silvane! Uite cum ne infratim noi, cu camere furate cumparate! Ia sa vad, zic io.\r\n\r\nSi-mi arata.\r\n\r\nScria <strong>Olympus</strong>.\r\n\r\nMai sa fie! Zic io. Tare.\r\n\r\n- Ia scoate-o afara, zic io, sa o vad mai bine.\r\n- Shafu\'! Nu pot, zice el ca ma ia Politia, si se uita hicleanu\' prin jur.\r\n- De unde esti? Intreb io.\r\n- Din Spania, zice el.\r\n- Hablas espaniol? Intreb io.\r\n- Ha? zice el\r\n\r\nOricarui om normal i s-ar fi aprins semafoarele din cap. Dar eu nu sunt orice om normal.\r\n\r\n- Amu m-or deportat, zice el si nu am nici un ban sa mananc macar. Da-mi si tu cat crezi ca face.\r\n- Pai cat sa-ti dau? Zic io.\r\n- Pai... 10 milioane? incearca el.\r\n\r\nSta Groparu, se gandeshte cu lobu\' paraplegic. Io nu cumpar camera la fel cu a lu\' Silvan, ii zice lu\' Groparu lobu\' adormit. Io o cumpar mai eftin.\r\n\r\n- Ma! Zic io. Si fac o pauza strategica, de gandit. Il analizez pe fatza si pe spate pe tuciuriu: cu o juma de brand il faceam, deci nu incapea ca daca scot portofelu il ia sh fuge, ca-l faceam curva regimentului.\r\n\r\n- Pula 10 milioane, ii zic, tu ej nebun?\r\n- Pai... zice el, da si matale cat crezi ca face. Si face o fatza, de m-am simtit ca un nemernic capitalist profitor. Hai, continua el, ca sunt din Ialomitza, si suntem X frati, unde X =  variabila, depinde de fraieru\' care asculta.\r\n- Nu-ti dau atata, zic. Ia da-o aici sa o vad.\r\n- Nu pot, shafu\', zice ca ma ia Politia.\r\n\r\nAmu, io toata viatza mea am visat sa fiu Bond, James Bond, sau macar un zero-zero-ceva. Asa ca faza aia cu Politia ma bÄƒga Ã®ntr-un fel de promiscuitate ilegala sexy, ca atunci cand te uiti la curu\' femeii unui prekin de-al tau foarte bun, si ea te vede, si zambeshte.\r\n\r\nAsa ca ii mai iau camera in bratze, ma uit peste ea, ma asigur ca e OK.\r\n\r\n- Ba! Zic io, napraznic. Fii atent la mine-aci.\r\n\r\nEra atent.\r\n\r\n- Io nu-tz dau 10 milioane pe ea, sa fie clar.\r\n- Da\'... cat dai? Zice el.\r\n\r\nFac un calcul rapid-rapid: cu o zi inainte loasem partea mea pe a doua mea carte tradusa, 7 milioane. Si aveam banii la mine. Nu mai stau la discutii, si ii arunc:\r\n\r\n- 7 milioane, sau nimic!\r\n- Aoleo!! Face asta, Blanosz Distruzosz.\r\n- Am plecat, fac eu, si fac o juma de pas.\r\n- NNUUUUUUUUU..... face asta, si ma imbratiseaza de picior. Da-mi macar 8.\r\n- 7, zic eu, cu mana la spate, imperial ca Napoleon.\r\n\r\nSta, se gandeshte.\r\n\r\n- Bine, zice el pierit. E bine 7, ce sa fac...? Ca mi-i foame... si suntem X fratzi...\r\n\r\nScot cashu\', i-l inmanez, iau camera, dispar pana nu vine Politia.\r\n\r\nPS: Nu are rost sa va mai spun ca a fost cea mai mare tzeapa loata de mine in toata vietzishoara mea. Camerele astea ca de jucarie se vand in Europa in Bucale cu 300.000 lei vechi. Si eu am dat pe ea o nimica toata, un pretz de 25 de ori mai mare. Si nu e Olympus, e Olympia, da\' n-am vazut, ca am analizat cu lobu\' ala paraplegic si cu ala adormit. Oricum, am negociat bine de la 10 milioane, nu???\r\n\r\nAm scris patzania asta de care mi-e rushine pentru ca sunt la o etapa a vietii mele la care am ajuns sa imi accept (foaaarte greu, e drept) si derapajele intelectoale. Si pentru ca am sa iau camera aia foto si am sa incerc sa o vand acuma, la Tiganiada, imbracat in tigan. Daca scot pe ea 50 RON insamna ca tot am facut o afacere bunicica, zic eu.','Camera foto Made in Ialomitza',0,'','publish','open','open','','camera-foto-made-in-ialomitza','','','2007-05-24 18:18:40','2007-05-24 16:18:40','',0,'http://www.groparu.ro/?p=439',0,'post','',8),(419,2,'2007-05-21 10:19:51','2007-05-21 08:19:51','Beam o bere cu joshica, care e destul de american.\r\n\r\nJoshica e genu de om care are portofel. In portofelu\' lu joshica este toata viata lui acolo in portofelu\' ala: carduri, pasaport, permis de sedere, instructiuni de cum sa se f**a, abonamentu\' la salonul de cosmetica, legitimatia de handicapat, permisu\' de alcoolic.\r\n\r\nNoi beam bere, si faceam afaceri: ce mogul de presa sa mai instauram, ce guverne din America de Sud sa mai cada, daca sa lichidam minele de diamante sau sa inchidem carierele de uraniu. Tocmai ne aplecam cu vadit interes asupra unor buci si decoltee ale unor cetatence de la o alta masa, care erau cu ceva manelisti, care beau si ei bere si care radeau zgomotos, care ras ne cam deranja, care nu puteam face nimic, ca noi nu vorbim cu manelistii.\r\n\r\nSi atunci, a aparut EL. Cersitoru\'.\r\n\r\nLu Groparu nu prea-i place sa vaza copkii ca strange bani pentru parintii lui, ca sa ii beie; si nu imi place finca si pe mine, cand eram mic, ma punea mama sa cersesc cand nu mai avea bani de codeina cu vodca. Asa ca lu\' una bucata copkil nu i-am dat nici un leutz, mai ales din cauza ca finca io is si zgarcit de tata focului. Am fost foarte inspirat totusi sa nu il trimit in ma-sa sau la munca, cum fac eu de regula cand ma confrunt cu ei si ma erijez in moralist si formator de opinie mai mare ca Voiculescu.\r\n\r\nCopkilu nu se supara, si da o tura de masa. Si numa ce il vad ca se apleaca, si inhaza de jos ditamai portofelu\' lu Joshica. Si mai si zice: nenea, v-o cazut portofelu\'! Si il pune pa masa. Da\' mai sta pana sa primeasca 5 lei finca o fost baiat bun.','Intamplare cu patzanie',0,'','publish','open','open','','intamplare-cu-patzanie','','','2007-05-21 10:19:51','2007-05-21 08:19:51','',0,'http://www.groparu.ro/?p=419',0,'post','',1),(420,2,'2007-05-19 17:46:08','2007-05-19 15:46:08','http://upload.wikimedia.org/wikipedia/commons/4/41/Bones_logo.jpg','http://upload.wikimedia.org/wikipedia/commons/4/41/Bones_logo.jpg',0,'','inherit','open','open','','httpuploadwikimediaorgwikipediacommons441bones_logojpg','','','2007-05-19 17:46:08','2007-05-19 15:46:08','',421,'http://www.groparu.ro/wp-content/uploads/2007/05/bones_logo.jpg',0,'post','image/jpeg',0),(421,2,'2007-05-19 17:50:02','2007-05-19 15:50:02','Deci s-a adeverit: aia 322 de parlamentari erau francmasoni sau neamtz-masoni.\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/05/bones_logo.jpg\" title=\"http://upload.wikimedia.org/wikipedia/commons/4/41/Bones_logo.jpg\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/05/bones_logo.jpg\" alt=\"http://upload.wikimedia.org/wikipedia/commons/4/41/Bones_logo.jpg\" /></a>\r\n\r\nPoza e loata de <a href=\"http://en.wikipedia.org/wiki/Skull_and_Bones\" target=\"_blank\">aci</a>, de unde puteti si afla mai multe despre Skull and Bones.','Suspendarea lui Basescu',0,'','publish','open','open','','suspendarea-lui-basescu','','','2007-05-19 19:55:39','2007-05-19 17:55:39','',0,'http://www.groparu.ro/?p=421',0,'post','',0),(422,2,'2007-05-19 19:02:34','2007-05-19 17:02:34','Am belit p***.','Uraaaaa!!! Basescu a invins!!!!',0,'','publish','open','open','','uraaaaa-basescu-a-invins','','','2007-05-19 19:02:34','2007-05-19 17:02:34','',0,'http://www.groparu.ro/?p=422',0,'post','',0),(423,2,'2007-05-20 02:41:15','2007-05-20 00:41:15','Am cetit <a href=\"http://www.andreicrivat.ro/2007/05/19/ziua-referendumului-amalgam-de-vorbe/\" target=\"_blank\">aici</a>, si nu mi-a venit sa cred. Am mai citit o data, m-am spalat pe ochisorii mei sexy, am bagat si o tigare, am mers la buda sa fac loc in mine, apai am mancat sa umplu locu\', dupa aia iar am cetit.\r\n\r\nBa. Presedintele nostru fura telefuane, ma!!! FURA TELEFOANE. Efectiv pune mana pe ele si le baga in buzunar.\r\n\r\nOare dom\' presedinte are ceva second sau amanet de telefoane ultra-secret? Oare dom\' presedinte raspunde la SMS? Oare cat o fost suspendat, i-or suspendat si abonamentu\' la telefonu\' de firma, sau e pe prepay? Oare ce MTV ringtone are la telefon dom\' presedinte? Oare presedintele da bip? Oare in ce grup o pus numaru\' lu Tariceanu? Oare ce record are la Snake? Cate puncte Thank You are? Oare il are pe Stolojan ca background? Oare telefonu\' e loat cu banii jos, sau in rate? Oare o trimis SMS la 777 sa castige zilnic 10000 $? Oare ce husa de telefon are, sport sau de piele? Oare danseaza pe manele cu telefonu in mana, si ii era jena ca telefonu lui e un pic zgariat?\r\n\r\nDom\' presedinte, imi facetz si mie rost de un iPhone? Plsss...Va dau 5 milieoane pe iel. Serios. Da\' sa n-aibe blututh, ca daca are nu ma mai respecta Zaraza, si io tin la respectu\' lu Zaraza. Ca e credincioasa si incalzeste bine. Serios.\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/05/basescu-telefon.JPG\" title=\"Basescu telefon\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/05/basescu-telefon.JPG\" alt=\"Basescu telefon\" /></a>\r\n\r\nAnunt pt domnul presedinte:\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/05/anunt-basescu.jpg\" title=\"http://fun.bascalie.ro/vizualizare~poze-anuntzuri~poza-anunt-pt-hoti.html\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/05/anunt-basescu.jpg\" alt=\"http://fun.bascalie.ro/vizualizare~poze-anuntzuri~poza-anunt-pt-hoti.html\" /></a>\r\n\r\nUn loc unde presedintele nu este binevenit:\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/05/gi12_domnilor_hoti_1.jpg\" title=\"http://www.resursadefun.ro/gi12_Domnilor_hoti.htm\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/05/gi12_domnilor_hoti_1.jpg\" alt=\"http://www.resursadefun.ro/gi12_Domnilor_hoti.htm\" /></a>\r\n\r\nCica s-a inventat un robot care prinde hoti.\r\nÃŽn China a prins Ã®n 5 minute 100 de hoti, Ã®n America a prins Ã®n 5 minute 200 de hoti, iar Ã®n RomÃ¢nia Ã®n 5 minute Basescu a furat robotul.\r\n\r\nDe ce Basescu nu e niciodata jefuiti de hoti?\r\nCurtoazie profesionala.\r\n\r\n<strong>VIZITATI PALATUL COTROCENI, TELEFONUL DUMNEAVOASTRA ESTE DEJA ACOLO!!!!!</strong>','BÄƒÄƒÄƒ, dati-mi votul inapoi!!! HÄƒ-hÄƒ-hÄƒÄƒÄƒ',0,'','publish','open','open','','baaa-dati-mi-votul-inapoi-ha-ha-haaa','','\nhttp://www.andreicrivat.ro/2007/05/19/ziua-referendumului-amalgam-de-vorbe/','2007-05-20 03:20:29','2007-05-20 01:20:29','',0,'http://www.groparu.ro/?p=423',0,'post','',11),(424,2,'2007-05-20 02:40:34','2007-05-20 00:40:34','','Basescu telefon',0,'','inherit','open','open','','basescu-telefon','','','2007-05-20 02:40:34','2007-05-20 00:40:34','',-1179616186,'http://www.groparu.ro/wp-content/uploads/2007/05/basescu-telefon.JPG',0,'post','image/jpeg',0),(425,2,'2007-05-20 02:55:58','2007-05-20 00:55:58','','anunt-basescu.jpg',0,'','inherit','open','open','','anunt-basescujpg','','','2007-05-20 02:55:58','2007-05-20 00:55:58','',423,'http://www.groparu.ro/wp-content/uploads/2007/05/anunt-basescu.jpg',0,'post','image/jpeg',0),(426,2,'2007-05-20 02:56:11','2007-05-20 00:56:11','http://fun.bascalie.ro/vizualizare~poze-anuntzuri~poza-anunt-pt-hoti.html','http://fun.bascalie.ro/vizualizare~poze-anuntzuri~poza-anunt-pt-hoti.html',0,'','inherit','open','open','','httpfunbascalierovizualizarepoze-anuntzuripoza-anunt-pt-hotihtml','','','2007-05-20 02:56:11','2007-05-20 00:56:11','',423,'http://www.groparu.ro/wp-content/uploads/2007/05/anunt-basescu.jpg',0,'post','image/jpeg',0),(427,2,'2007-05-20 02:57:40','2007-05-20 00:57:40','http://www.resursadefun.ro/gi12_Domnilor_hoti.htm','http://www.resursadefun.ro/gi12_Domnilor_hoti.htm',0,'','inherit','open','open','','httpwwwresursadefunrogi12_domnilor_hotihtm','','','2007-05-20 02:57:40','2007-05-20 00:57:40','',423,'http://www.groparu.ro/wp-content/uploads/2007/05/gi12_domnilor_hoti_1.jpg',0,'post','image/jpeg',0),(428,2,'2007-05-21 14:42:37','2007-05-21 12:42:37','Deci mie nu prea imi put picioarele azi, ca mi-am loat sandale, si si daca ar putzi, pe mine nu ma deranjeaza, da\' astia din jur dintr-o data pufaie si ma evita, si shafu\' ma ameninta ca ma da afara. In fine.\r\n\r\nDa\' daca mi-ar putzi, as mere la Scholl, pe Clinciurilor, ca cica acolo are oamenii ceva spray d-ala dejtept, cu MBA, care se bate cu mirosu\' de sobolan mort din adidas, si il si face cnocaut. In fine.\r\n\r\nDa\' sa ai grija cand meri acolo. Finca desi tanti care vinde e maghieara, stilu\' e cel mai  romanesc tÃ¢mpovitzean posibil, care este. De ce maghiearii ne fura obiceiurile noastre proaste (vezi vamesii, benzinarii, chelnerii din tzara vecina si prietena), si noi nu le furam obiceele alea bune? In fine.\r\n\r\nNoa, da\' sa ii dau inainte. Deci intri inauntru, si inauntru e mai cald ca afara. Nu-i stress, ca azi mi-am loat sandale, si pierd caldura la greu printre gaurile din ele. Da\' vroiam sa vaz de sprayu\' ala. Nu eu, ficioru cu care eram.\r\n\r\nSi stam un pic. Maxim 8 minute. In timpu\' asta, tanti aia unguroaica vanzatoare vorbea cu alta tanti unguroaica ne-vanzatoare asezata pe scaun in fatza ei. Dupa cum am dedus dupa tonu vocii, vorbeau o barfa mica, un jmen, o shushanea. Intre timp, iese afara o domnisoara care tocma\' proba o pareche de pantaloni d-aia albi, de sora medicala. Si zice d-ra: oare nu mi-s largi? Vanzatoarea pufneste, si ii scuipa \"NU! Uita-te in oglinda!\"\r\n\r\nIn fine, ne vine randu\'. Cum ne vine? Pai stam si ne chiorÃ¢m la alea doo barfitoare vreo 4 minute 30. Si intr-un final apoteotic, ii shuier \"FITI AMABILA!\".\r\n\r\n- Da, zice ea, vadit impresionata negativ.\r\n- Stiti, zice colegu\' meu, aveti spray de picioare?\r\n- Da, zice ea. Si continua sa discute cu prekina-sa. Kekeke, rekeke.\r\n- Si putem vedea? Ne facem noi curaj.\r\n- Da, zice ea. Kekeke, rekeke.\r\n\r\nStam 14 secunde. Se ridica de pe scaun, si vine inspre noi.\r\n\r\n- Aici, zice ea, si ne arata cu creanga un raft de dupa tejghea. Kekeke, rekeke.\r\n\r\nNoi intindem crengile sa pipaim  marfa, si ne suiera iara:\r\n\r\n- Nu puneti mana! zbiara. Va arat io. Kekeke, rekeke.\r\n\r\nOfteaza, se deplaseaza catre raftu\' cu pricina, si ia in scÃ¢rba un spray, ni-l flutura pe langa nasurile noastre tinere, da\' fugitiv, si il pune la loc.\r\n\r\n- Cu ce aroma este? indraznim.\r\n- Fresh, scuipa ea. Kekeke, rekeke.\r\n- Putem proba? \'cem noi, ferindu-ne cu grija de scuipat.\r\n- NU! zbiara. Kekeke, rekeke.\r\n- ?\r\n- E sigilat! zbiara tanti. Kekeke, rekeke.\r\n- Aha... da\' din ala (si zice prekinu meu nush ce aroma de bou moscat cu miros de fluturi cu muraturi) nu aveti?\r\n- NU! zbeara din nou. Kekeke, rekeke.\r\n- Da\' in Germania erau... tot Scholl... indrazneshte prekinu.\r\n- E! Aia e in Germania! \'ce tanti. Kekeke, rekeke.\r\n\r\nSta prekinu\' meu, pe buna dreptate, coplesit de atata nesimtire. Isi ia totusi aer in piept, isi activeaza chakra aia de calm si voie buna, si mai face un ultim efort:\r\n\r\n- Da\'... in alelante recipiente... nu e tot spray de picioare?\r\n- NU! Hamaie tanti ca un dulau. NU! Ala e perspirant. Kekeke, rekeke.\r\n\r\nOK, zicem noi, iesim afara, ne bufneste rasu, si io ma intorc - tanti se uita la noi ca somalezu\' la clatite, ca se auzea ca radem - ii zambesc de dincolo de barba mea de mers la Tiganiada, si mimez ca imi trag un glontz in tampla in fatza ei. Si mai si zic: \"HRISTOASEEEEEE!!!!\"\r\n\r\nTanti, jur ca data viitoare o sa imi rup picioru\', si am sa vin la dvs. ca sa ma serviti, ca sa castigati mai mult de pe curu\' meu. Da deocamdata tot ce pot sa fac e sa va ii urez io, din anusul curat al inimii mele foarte incapatoare, un foarte <a href=\"http://www.facemcatavencu.ro/blog.php?id=20&amp;p=801\" target=\"_blank\">istodoresc</a>\r\n\r\n<strong>\"MOOOORI!!!!\"</strong>\r\n\r\nPS: Am cumparat un spray in cele din urma de la SensiBlu cu 3 lei mai mult, si tanti o fo foarte amabila, ne-o lasat sa probam mirosu\', si ne-am si bucurat ca nu am folosit Condica de Reclamatii, care spanzura imbietoare deasupra tejghelei. Deci se puate!!!\r\n\r\nPost-PS: Nu le mere saitu\' Scholl, pajina cu reclamatii. Ata ete.','Fuck you too, Scholl Cluj',0,'','publish','open','open','','fuck-scholl-cluj','','','2007-05-21 15:27:39','2007-05-21 13:27:39','',0,'http://www.groparu.ro/?p=428',0,'post','',0),(429,2,'2007-05-21 23:11:51','2007-05-21 21:11:51','www.groparu.ro tigan gipsy rrom tiganiada blog romanesc romanian blog','www.groparu.ro tigan gipsy rrom tiganiada blog romanesc romanian blog',0,'','inherit','open','open','','wwwgroparuro-tigan-gipsy-rrom-tiganiada-blog-romanesc-romanian-blog','','','2007-05-21 23:11:51','2007-05-21 21:11:51','',411,'http://www.groparu.ro/wp-content/uploads/2007/05/dsc01254.JPG',0,'post','image/jpeg',0),(430,2,'2007-05-21 23:12:23','2007-05-21 21:12:23','www.groparu.ro tigan gipsy rrom tiganiada blog romanesc romanian blog','www.groparu.ro tigan gipsy rrom tiganiada blog romanesc romanian blog',0,'','inherit','open','open','','wwwgroparuro-tigan-gipsy-rrom-tiganiada-blog-romanesc-romanian-blog-2','','','2007-05-21 23:12:23','2007-05-21 21:12:23','',411,'http://www.groparu.ro/wp-content/uploads/2007/05/dsc01154.JPG',0,'post','image/jpeg',0),(431,2,'2007-05-21 23:13:22','2007-05-21 21:13:22','www.groparu.ro tigan gipsy rrom tiganiada blog romanesc romanian blog','www.groparu.ro tigan gipsy rrom tiganiada blog romanesc romanian blog',0,'','inherit','open','open','','wwwgroparuro-tigan-gipsy-rrom-tiganiada-blog-romanesc-romanian-blog-3','','','2007-05-21 23:13:22','2007-05-21 21:13:22','',411,'http://www.groparu.ro/wp-content/uploads/2007/05/dsc01236.JPG',0,'post','image/jpeg',0),(432,2,'2007-05-21 23:13:58','2007-05-21 21:13:58','www.groparu.ro tigan gipsy rrom tiganiada blog romanesc romanian blog','www.groparu.ro tigan gipsy rrom tiganiada blog romanesc romanian blog',0,'','inherit','open','open','','wwwgroparuro-tigan-gipsy-rrom-tiganiada-blog-romanesc-romanian-blog-4','','','2007-05-21 23:13:58','2007-05-21 21:13:58','',411,'http://www.groparu.ro/wp-content/uploads/2007/05/dsc01237.JPG',0,'post','image/jpeg',0),(433,2,'2007-05-21 23:14:44','2007-05-21 21:14:44','www.groparu.ro tigan gipsy rrom tiganiada blog romanesc romanian blog','www.groparu.ro tigan gipsy rrom tiganiada blog romanesc romanian blog',0,'','inherit','open','open','','wwwgroparuro-tigan-gipsy-rrom-tiganiada-blog-romanesc-romanian-blog-5','','','2007-05-21 23:14:44','2007-05-21 21:14:44','',411,'http://www.groparu.ro/wp-content/uploads/2007/05/dsc01220.JPG',0,'post','image/jpeg',0),(434,2,'2007-05-21 23:15:22','2007-05-21 21:15:22','www.groparu.ro tigan gipsy rrom tiganiada blog romanesc romanian blog','www.groparu.ro tigan gipsy rrom tiganiada blog romanesc romanian blog',0,'','inherit','open','open','','wwwgroparuro-tigan-gipsy-rrom-tiganiada-blog-romanesc-romanian-blog-6','','','2007-05-21 23:15:22','2007-05-21 21:15:22','',411,'http://www.groparu.ro/wp-content/uploads/2007/05/dsc01264.JPG',0,'post','image/jpeg',0),(435,2,'2007-05-21 23:17:02','2007-05-21 21:17:02','www.groparu.ro tigan gipsy rrom tiganiada blog romanesc romanian blog','www.groparu.ro tigan gipsy rrom tiganiada blog romanesc romanian blog',0,'','inherit','open','open','','wwwgroparuro-tigan-gipsy-rrom-tiganiada-blog-romanesc-romanian-blog-7','','','2007-05-21 23:17:02','2007-05-21 21:17:02','',411,'http://www.groparu.ro/wp-content/uploads/2007/05/dsc01144.JPG',0,'post','image/jpeg',0),(436,2,'2007-05-22 01:09:17','2007-05-21 23:09:17','','dsc01158.JPG',0,'','inherit','open','open','','dsc01158jpg','','','2007-05-22 01:09:17','2007-05-21 23:09:17','',411,'http://www.groparu.ro/wp-content/uploads/2007/05/dsc01158.JPG',0,'post','image/jpeg',0),(437,2,'2007-05-24 11:20:48','2007-05-24 09:20:48','Mi-s atata de narcisist, ca am ajuns gelos pe mine insumi.\r\n\r\nAm asa o fofoloanca de barba sexy la purtator ca imi vine sa ma pup in oglinda de pe tavan.\r\n\r\nSunt singura persoana de care mi-as face lipeala fara sa fiu nevoit sa ma imbat bine.\r\n\r\nOcazional, imi mangai fundu\' de drag ce mi-s. De regula ma mangai cand ma duc la buda, da\' nu am tot timpu\' curaj sa ma mangai direct: uneori folosesc hartie igienica.\r\n\r\nOricat de frumoasa ar fi o fata, nu ii dau voie sa ma atinga: zilele astea imi apartin numai mie. As fi in stare sa o las sa moara fara sa-i fac respiratie gura-la-gura. Buzele mele is facute sa sarute numai buzele sticlei de bere!!!\r\n\r\nIn autobuze ii fuljer cu privirea pe toti cei care se inghesuie in mine, finca\'s printzes. Printzeshii nu are voie sa fie inghesuiti in autobuze!!!\r\n\r\nAm ajuns sa ma spal pe maini inainte de a pune mana pe putzulica. Si inainte de a pune mana, ii cer voie corpului meu.\r\n\r\nImi rod unghiile, si imi place gustul meu.\r\n\r\nAzi mi-am scris o declaratie de dragoste, dar mi-am rupt-o. Eu nu flirtez cu nimeni, nici macar cu mine.\r\n\r\nCand fac dush, prima data iau apa in gura, sa o innobilez cu ioni pozitivi gropari. Apoi ii dau drumul pe trupul meu gol, care se infioara de placere.\r\n\r\nNici un sapun nu e prea curat pentru mine, asa ca fac dush fara sapun.\r\n\r\nPersonalitatea mea tiganiada o sufoca, incet incet, pe personalitatea mea romaneasca. Probabil din cauza ca prima face mai multi copii.\r\n\r\nCorpul meu de nimfet nu mai suporta hainele, asa ca nu le mai port. Asa am ajuns sa imi dau jos kilotii cand merg la baie.\r\n\r\nIeri am vazut o femeie cum alapta, si mi s-a parut normal sa merg la ea, sa ii feresc copilul de la san, si sa ii binecuvantez sfarcurile cu buzele mele. Si ei i s-a parut normal. Numa\' lu barba-su nu.\r\n\r\nDaca cineva ma intreaba pe strada cum sa ajunga la spital, ii raspund: \"Sorry! No pictures!!!\"\r\n\r\nAtata sunt de narcisist, ca deja si matzele ma iubeshte. Cu tot cu purecii din dotare.\r\n\r\nNici macar monstrii din dulap nu mai indraznesc sa ma necajeasca.\r\n\r\nSunt prea sexy pana si pentru google, asa ca degeaba ma cautati. Nu-s acasa.\r\n\r\nIar acum dati-mi voie, la final, sa imi ofer un tort si sa imi zic:\r\n\r\n<strong>GROPARU, ITI MULTUMESC CA FACI PARTE DIN VIATZA MEA!!!!</strong>','Sunt narcisist',0,'','publish','open','open','','sunt-narcisist','','','2007-05-24 11:20:48','2007-05-24 09:20:48','',0,'http://www.groparu.ro/?p=437',0,'post','',7),(438,2,'2007-05-22 16:26:03','2007-05-22 14:26:03','S-a intamplat.\r\n\r\nHehe! Tiganilor imputiti si golanilor, animalilor ca mine, ce credeati? Ca gata, daca Boc asfalteaza centru\' dupa ce si-o asfaltat strada mariei sale, e gata, e curatzel ca un ingerash? Uite ca numa\' ce o divortzat de liberali, si deja umbla seara pe la poarta pesedeului, ca iara trebe sa iasa norodu\' cu pusca seara pe ulita sa il alunge, sa nu necinsteasca fata.\r\n\r\nCelor care se gandeau ca de-acum vor merge la vot fara sa mai ofteze cand pun stampila, dati-mi voie sa va recomand cu drag inima urmatoarele variante existentiale:\r\n\r\n- emigrare in Chebec,  da\' trebe sa iei meditatii de la profa aia de franceza din liceu, aia care nu te suporta finca nici macar ea nu se suporta pe sine;\r\n- Coreea de Nord, daca obtineti viza sa imi spuneti si mie;\r\n- varianta Lee Harvey Oswald, da\' numa\' ca nici un politician nu merita sa strici un glontz pe el;\r\n- varianta agrafa de aur a lu\' Oedip, aia cu care si-o scos ochii, ca sa nu mai vezi tradarea la TV;\r\n- varianta picatura de otrava in ureche, cum o fost omorat tata lu\' Hamlet, ca sa nu mai auzi tradarea la radio;\r\n- varianta cautat Eva, cautat paradis, dezbracat in coropojnitza goala si implorat Dumnezeu sa deie inapoi Edenul, ca ne cÄƒim ca am muscat fructu\';\r\n- varianta trenul: pui capu\' pe shine, si stai sa vina acceleratu\' pentru decapitat;\r\n- varianta intrat in politichie, sa te bucuri de banii alegatorilor; de recomandat sa treci la baie mai intai, sa faci un pipi galbui pe principiile matale;\r\n- varianta implorat regele sa revina, ca e mai usor sa injuri unu singur;\r\n- varianta Irak: intrat in religia musulmana, pus centura de TNT, intrat in Parlament, detonat scarnaviile, si ajuns in rai la 70 de virgine (numa sa mai aibe Allah);\r\n- varianta cautat Dictionar de Argou, ca sa te descarci cu injuraturi la indemana;\r\n- varianta votat Becali, macar sa ne distram cand ne uitam la TV;\r\n\r\nDaca mai aveti variante mai spuneti, ca io deocamdata ma multumesc cu varianta strutzului: imi mai caut un job, doar-doar le-o ajunge la astia banutii si s-or satura de furat.','PD + PSD = Love',0,'','publish','open','open','','pdpsdlove','','','2007-05-22 17:57:20','2007-05-22 15:57:20','',0,'http://www.groparu.ro/?p=438',0,'post','',2),(441,2,'2007-05-25 10:27:35','2007-05-25 08:27:35','<a href=\"http://www.groparu.ro/wp-content/uploads/2007/05/dsc02095.JPG\" title=\"dsc02095.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/05/dsc02095.JPG\" alt=\"dsc02095.JPG\" height=\"332\" width=\"440\" /></a>\r\n\r\nAti auzit de centrala aia atomo-nuclearo-electrica de o explodat in Rusia, Ucraina si Cecenia? Nimic mai fals. Va exploda weekendul asta, pe Valea Caselor. Finca incepe Tiganiada :D','Weekendul asta nu sunt disponibil',0,'','publish','open','open','','weekendul-asta-nu-sunt-disponibil','','','2007-05-25 10:27:35','2007-05-25 08:27:35','',0,'http://www.groparu.ro/?p=441',0,'post','',4),(442,2,'2007-05-28 11:38:47','2007-05-28 09:38:47','Cand scriu aceste randuri, mai port pe mine mirosul VÄƒii binecuvantate. Si am in gura un gust dulceag de fericire, asemanator cu opiumul. Credeti sau nu, dar unii oameni nu au nevoie de Yoga ca sa ajunga la Nirvana! Si va previn:  sansele sa auziti referinte anatomice destul de genitale  pe filme sunt maxime.\r\n\r\nDeci, ca sa incep cu inceputul:\r\n\r\n<strong>Ziua I</strong>\r\n\r\nCoprea zis NÃ¢rÅ£oagÄƒ zis PÃ¢rÅ£oagÄƒ, care e si noul membru al festivalului, vine sa ma ia vineri sa ma duca spre fericire, dar face un mic efort intelectoal si buseste areapa masinii finca nu o mai putut evita o masina stationara(!). Asa ca doua ore merem de-a lela prin Cluj sa reparam bara fatza, imbracati in palarie si cu barbi. Si cand plecam, lom si un student la ocazie, ca sa avem pe cine traumatiza cu muzica tiganeasca la maxim si chiote.\r\n\r\nPe drum ma suna astia si zice, printre sughitze: \"Baaaaa, pirandule, zice ei, am mers in piatza sa lom legume, sh s-o umplut de tigani in juru\' nostru, bÄƒÄƒÄƒ!!!! BÄƒÄƒÄƒÄƒ,  si ne-or intrebat daca punem scocuri, si daca tinighigerim bÄƒÄƒÄƒÄƒ!!! Si le-am zis ca daaa, bÄƒÄƒÄƒÄƒ!!!\"\r\n\r\nAm ajuns acasa, m-am schimbat: camesha inflorata, palaria neagra, vesta de la costumu\' meu bun, slapii bulgÄƒreÅŸti de zidar si ciorapi gauriti cu furie; cand furia nu o mai ajuns, am loat foarfeca si i-am spintecat. Si imi iesea gegetele de la picioare foarte vesele prin slapi. A, si mi-am dat cu crema de ghete pe barba si pe fatza. Oricum, am fost mai putin gay decat Mitroa si Nelu, care s-or dat cu crema autobronzanta!!!\r\n\r\nUite acilea cum ne-am reunit cu tiganiazii. Era plin magazinu\' de palarii!!!\r\n\r\n[google -7257832418182644112]\r\n\r\nIn magazin, tot magazinu\' vuia de hohotele noastre de ras, ca radeam din orice. Si agentul de paza s-o facut badigardu\' nost! Ca merea prin magazin lipit-lipit de noi! Nu ne-o slabit din ochi! Si de vreo patru ori ne-am oprit toti si ne-am zgait fix in ochii lui, cat am putut de fioros! Si atuncea copilu\' zambea, ca era numa\' de vreo 19 ani, si firav, ma, da\' firav, de oioioi, si cica verifica preturile! Si mai tarziu o venit la noi si s-o scuzat si mi-o zis ca shafu\' lui ne roaga frumos daca suntem amabili si dragutzi sa nu mai filmam in magazin, ca ne roaga el frumos, ca e interzis.  Da\' nu o zis un cuvintzel ca de ce ii hartuim pe ceilalti cumparatori, ca noi hartuiam tot ce puteam!\r\n\r\nAm golit raftu\' de coniac ieftin!\r\n\r\nDupa cum ziceam mai devreme, am loat si camera aia cumparata de la ialomitzean. Si am incercat sa o vand la vreo 6 persoane din juru\' magazinului. Da\' nu prea mi-o iesit. Bag sama ca nu era o vinere cu cumparat camere.\r\n\r\n[google -613422120259238524]\r\n\r\nUrmatoarea oprire - la cea mai infectioasa bodega crajmatica de langa cimitirul din capitala culturala: La Nelu sh Klein. Asa-i zice. Uiteti-va si voi ce fel de local:\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/05/dsc02140.JPG\" title=\"www.groparu.ro Romanian blog blog romanesc gipsy gitan tigan rrom Tiganiada\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/05/dsc02140.JPG\" alt=\"www.groparu.ro Romanian blog blog romanesc gipsy gitan tigan rrom Tiganiada\" height=\"301\" width=\"398\" /></a>\r\n\r\nAm incercat si aici sa vand camera lu tanti ospataritza care se chelnerea, lu\' trei sapatori de santuri si inca doi clienti ai birtului, dar tot fara succes. Asa ca m-am resemnat si am bagat o berula BÃ¢lea (cea mai ieftina de pe piaÅ£Äƒ) ÅŸi am stins-o cu o Saniutza orighinala. Si Carlanu\' ne-o prezentat Actul Constitutiv al Enclavei Valea Caselor, care va aparea aici pe sait imediat ce-mi da sh mie pedefeu\'.\r\n\r\n[google -3651626843079539447]\r\n\r\nUrmatoarea oprire -  cartierul Valea Aurie. Numa\' de sanchi. Numa\' ca sa punem muzica la maxim si sa oripilam romanii boratzi. Am urlat pe Ternipe ca o magaritza in calduri, de mi s-o si facut sarma ghimpata in gatlej. La finalul filmului veti vedea ce boxa are Stef. Oioioi!\r\n\r\n[google -3697283963467022514]\r\n\r\nAm facut si o pauza de scormonit in gunoaie.\r\n\r\n[google -4169220364368113443]\r\n\r\nNu mi-am refuzat placerea de a face poza cu alt cautator de gunoaie:\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/05/dsc02148.JPG\" title=\"dsc02148.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/05/dsc02148.JPG\" alt=\"dsc02148.JPG\" height=\"285\" width=\"377\" /></a>\r\n\r\nAm plecat apoi catre vale. Si am ajuns la vale! Dar cu pauzele de riguare.\r\n\r\n[google -6204753256713559025]\r\n\r\nSi nu am mers oricum pe vale: ci chiar pe capote.\r\n\r\n[google -6268082647615157600]\r\n\r\nSi am ajuns acolo, si am pus corturile - care le-or avut, ca io nu mai stiu in ce amanet l-am lasat. Si am continuat sa bem. Si am pus si steagu\' - sus pe colina. Ca am avut steag. Si or vint tri pujtani din Rashinari cu drujba, si ne-or taiat lemne. Si i-am cinstit cu bere. Si nu mai stiu ce am vorbit cu ei, da stiu ca am ras mult. Si inca ceva: porcul de anu\' astaa fost EXTRAORDINAR. In afara numa de faptu\' ca am calcat de vreo 4 ori in ceaunu\' cu baitz (condimente de dat pe porc cu ulei de motor si vin si bere si tat felu\'), de m-am umplut cu foi de dafin pe piciorul meu uleios!\r\n\r\nZiua I era gata.','Euro-Tiganiada 2007 - ziua I',0,'','publish','open','open','','euro-tiganiada-2007','','','2007-05-28 12:19:42','2007-05-28 10:19:42','',0,'http://www.groparu.ro/?p=442',0,'post','',9),(443,2,'2007-05-28 11:40:55','2007-05-28 09:40:55','www.groparu.ro Romanian blog blog romanesc gipsy gitan tigan rrom Tiganiada','www.groparu.ro Romanian blog blog romanesc gipsy gitan tigan rrom Tiganiada',0,'','inherit','open','open','','wwwgroparuro-romanian-blog-blog-romanesc-gipsy-gitan-tigan-rrom-tiganiada','','','2007-05-28 11:40:55','2007-05-28 09:40:55','',442,'http://www.groparu.ro/wp-content/uploads/2007/05/dsc02140.JPG',0,'post','image/jpeg',0),(444,2,'2007-05-28 11:49:00','2007-05-28 09:49:00','','dsc02148.JPG',0,'','inherit','open','open','','dsc02148jpg','','','2007-05-28 11:49:00','2007-05-28 09:49:00','',442,'http://www.groparu.ro/wp-content/uploads/2007/05/dsc02148.JPG',0,'post','image/jpeg',0),(445,2,'2007-05-29 00:48:26','2007-05-28 22:48:26','Rasinari e o comuna rurala nascuta din darul muntilor, unde s-au nascut oameni ca Emil Cioran si fratele sau, Octavian Goga, <a href=\"http://www.romanianvoice.com/poezii/poezii/dascalita.php\" target=\"_blank\">Dascalitza</a> din poezia homo-nima, precum si acest bland domn simpatic pe nume Achim Petru:\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/05/ganistra.JPG\" title=\"www.groparu.ro Romanian blog blog romanesc tiganie tiganiada rrom gitan tigan\"></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/05/achim-petru.JPG\" title=\"Achim Petru, Rasinari\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/05/achim-petru.JPG\" alt=\"Achim Petru, Rasinari\" style=\"width: 366px; height: 296px\" height=\"296\" width=\"366\" /></a>\r\n\r\nNoi inca nu ne-am nascut in Rasinari, ci am renascut acolo, de fiecare data. Cu fiecare Tiganiada.\r\n\r\nAnul asta vreau sa zic ca am fost dusi pe noi culmi de succes si fericire. La asta a contribuit si porcul, care se vedea ca a fost hranit cu dragoste si devotiune si apnegatie, si ne-a rasplatit cu o carnitza EXTRAORDINARA. Anu\' asta ne gandisem sa lom ceva miel sau caprina sa o chinuim la protzap, da\' ne-am dat seama ca:\r\n\r\n1. Sansele sa ne imbatam sunt exagerat de mari;\r\n2. Daca ne imbatam, suntem predispusi la delir;\r\n3. Daca suntem predispusi la delir, poate aiuram si vedem mujahedini;\r\n4. Mujahedinii pot veni sa ne manance mielu\'. Pe cand asa ei nu mananca porc, si degeaba mai vin, ca de omorat nu ne pot omori, ca deja suntem morti de beti, si beutura ei nu bea, si porcu\' lor nu li se pare sexy, ca-s cu Allah -- rezulta zero talibani! Invatza de-aci cum sa te bati cu talibanii, W. Bush!!!\r\n\r\nBun. Porcul - ma repet, da\' daca nu bagati la cap!!! - a fost extraordinar.\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/05/dsc02176.JPG\" title=\"Porc la protap\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/05/dsc02176.thumbnail.JPG\" alt=\"Porc la protap\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/05/dsc02181.JPG\" title=\"Porc la protap\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/05/dsc02181.thumbnail.JPG\" alt=\"Porc la protap\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/05/dsc02185.JPG\" title=\"Porc la protap\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/05/dsc02185.thumbnail.JPG\" alt=\"Porc la protap\" /></a>\r\n\r\nE drept ca dumicatele, bine usturoiate, or cam pleoscait intr-un stomac in care susura vesel un Nil de bere - gÃ¢l-gÃ¢l! aÅŸa fÄƒcea - dezinfectat cu coniac ieftin, sa nu faca crocodili. Da\' nu conteaza asta. Conteaza ca anu\' asta nu am mai cazut ca un balig in valea rÃ¢ului (asezata suspect de aproape de vatra focului, si degeaba am rugat-o sa curga mai incolo, ca nu vru!) - nici inainte, nici dupa ce gitanii or inceput sa se pishe in ea. E meritul meu. Faptul ca am invatzat din gafele anului trecut e semn de maturitate - unic, de alfel.\r\n\r\nAsaaaaaa. A doua zi ne-am trezit (ma-sa mare, deja simt ca am uitat cel putin 6 chestii meseriashe care s-or mai petrecut in noaptea aia!) - clar! - cu cafea. Originala, marca Timisoreana. Si la doza. Buuuuna cafea!\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/05/carlanu.JPG\" title=\"Romanian blog blog romanesc www.groparu.ro tigani gitan rrom tiganiada\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/05/carlanu.thumbnail.JPG\" alt=\"Romanian blog blog romanesc www.groparu.ro tigani gitan rrom tiganiada\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/05/crang.JPG\" title=\"Romanian blog blog romanesc www.groparu.ro tigani gitan rrom tiganiada\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/05/crang.thumbnail.JPG\" alt=\"Romanian blog blog romanesc www.groparu.ro tigani gitan rrom tiganiada\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/05/degeaba.JPG\" title=\"www.groparu.ro Romanian blog blog romanesc tiganie tiganiada rrom gitan tigan\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/05/degeaba.thumbnail.JPG\" alt=\"www.groparu.ro Romanian blog blog romanesc tiganie tiganiada rrom gitan tigan\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/05/duda.JPG\" title=\"www.groparu.ro Romanian blog blog romanesc tiganie tiganiada rrom gitan tigan\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/05/duda.thumbnail.JPG\" alt=\"www.groparu.ro Romanian blog blog romanesc tiganie tiganiada rrom gitan tigan\" /></a>\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/05/ganistra.JPG\" title=\"www.groparu.ro Romanian blog blog romanesc tiganie tiganiada rrom gitan tigan\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/05/ganistra.thumbnail.JPG\" alt=\"www.groparu.ro Romanian blog blog romanesc tiganie tiganiada rrom gitan tigan\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/05/glezna.JPG\" title=\"www.groparu.ro Romanian blog blog romanesc tiganie tiganiada rrom gitan tigan\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/05/glezna.thumbnail.JPG\" alt=\"www.groparu.ro Romanian blog blog romanesc tiganie tiganiada rrom gitan tigan\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/05/ielvis.JPG\" title=\"www.groparu.ro Romanian blog blog romanesc tiganie tiganiada rrom gitan tigan\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/05/ielvis.thumbnail.JPG\" alt=\"www.groparu.ro Romanian blog blog romanesc tiganie tiganiada rrom gitan tigan\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/05/nartzoaga.JPG\" title=\"www.groparu.ro Romanian blog blog romanesc tiganie tiganiada rrom gitan tigan\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/05/nartzoaga.thumbnail.JPG\" alt=\"www.groparu.ro Romanian blog blog romanesc tiganie tiganiada rrom gitan tigan\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/05/rramon.JPG\" title=\"www.groparu.ro Romanian blog blog romanesc tiganie tiganiada rrom gitan tigan\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/05/rramon.thumbnail.JPG\" alt=\"www.groparu.ro Romanian blog blog romanesc tiganie tiganiada rrom gitan tigan\" /></a>\r\n\r\nAm taiat si tri sorlice din porcu\' care poposise peste noapte pe capota lu\' masina lu DeGeaba, si care avea deja gust de Passat. Si altceva nu cred ca am mai mancat in ziua aia, numa am gÃ¢lgÃ¢it ca prostu\' la doze de berule sh la coniace. A, ba da. Am mai mancat o jumate de ridiche dospita. Si finca imi pÄƒsa de ficat, am mai hapait si o juma\' de felie unsa cu pateu vegetal, sa nu cada mancarea greu la stomac. Si m-am uitat admirativ la COPACUL PE CARE-L TAIASE DUDÄ‚ NOAPTEA TRECUTÄ‚, cÄƒ nu Ã®nÅ£elegeam cum dreq Ã®l tÃ¢rÃ¢se singur peste ditamai rÃ¢u\'!!!!\r\n\r\nDupa aia, ne-am chinuit vreo juma de ora sa urcam pe dÃ¢mbu\' ala de 40 cm inaltime, sa facem poze.\r\n\r\n[youtube MwbCgT3BpE4]\r\n\r\nDupa aia am vrut sa il batem pe GleznÄƒ, cÄƒ ne fuma chiÅŸtoacele pe care noi le aruncam in mlajtinÄƒ, cÄƒ la un moment dat avea vreo patru pe dejte simultan.\r\n\r\nDupa aia, o trebuit sa jucÄƒm rugby - ca asa-i traditia.\r\n\r\n[youtube 0qZW6WZ6s08]\r\n\r\nCu sticla de vin. Desculti. La bustu\' gol. Si orice regula era permisa. Nu va puteti imagina ce traume au survenit in urma impactului! Oricum, echipa groparului a castigat detasat - si cred ca si cealalta, ca nu mai stie nimeni bine.\r\n\r\nDupa ce terenul a devenit impracticabil finca nu mai stiu care descoperise si brevetase o metoda sa faca pipi din fuga, ne-am retras pe margine, si ne-am loat slipii. Slipii aia invizibili. Finca mergeam sa facem baie. Da, in aceeasi bulboana de 1 metru patrat ca anu\' trecut. Da, apa era rece. Infiorator de rece. Da, am stat cred ca mai mult de o ora in apa. Si nu, nu va pot arata filme, finca asta e un sait decent. Da\' o poza-doo tot va pun.\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/05/wwwgroparuro-in-piscina.JPG\" title=\"www.groparu.ro - in piscina\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/05/wwwgroparuro-in-piscina.thumbnail.JPG\" alt=\"www.groparu.ro - in piscina\" /></a>\r\n\r\nAsaaaaaa. Soarele, ca o gura de cuptor, zambea catre noi cu toata gura, iar numai arareori o scama de nor ne ascundea goliciunea de privirile sale uimite. In dreapta, sau in stanga (depinde cum te tÃ¢rai in 4 labe... hai sa zic 4 membre), apele cristaline si pline de molecule de hidrogen si oxigen ale pÃ¢rÃ¢ului Ã®ncercau, fara succes, sa acopere trilurile Fanfarei din ChetriÅŸ, care izvorau vesele din toate masinile simultan, dar decalate, intru deliciul atÃ¢tor urechi de admiratori ai versului tradiÅ£ional Å£igÄƒnesc.\r\n\r\nNu mai stie nimeni cand a inceput batalia cu ketchup si mustar: mi se pare de la o simpla intrebare: \"Ketchup, sau mustar?\" Cert este cÄƒ sÄƒ ÅŸtiti si voi ca ÅŸi ketchupu\' ala dulce pt. copii pisca ca dreq cand ajunge la mucoasele alea sensibile, alea cu pÄƒr, alea de cand le gadili se umfla nush ce cartilagiu, ca de fiecare data ma mir. Si mai e cert ca toti eram improscati ca dalmatienii!!! Si atunci s-a petrecut. Cand ma spalam mai abitir in rÃ¢u, ca deja ma simteam ca o pizza la cÃ¢t eram de ornat, <em>cineva (</em>astia zice ca singur am cÄƒst, da io nu-i creeed!) mi-o dat cu un sete branci miselesc, pe la spate; si cred ca era o zona cu gravitatie marita, finca am loat apa aia de 3 centimetri adancime in piept in stil fluture, inotand voiniceste, si cred ca am incercat sa imi mai si fac loc in piscina, ca am lovit sec cu urechiusha mea un soi de stanca, ca era prea mare sa fie bolovan. Norocu\' meu - si aici multumesc Dumnezeului betivilor! - ca la Groparu capu\' nu e un organ vital, si chiar atata de tare m-am inveselit de la lovitura, ca vreo 14 minute m-am invartit in cerc in curu\' gol in apa aia in patru labe in pietrele alea ascutite, ca mi s-or si facut poze si or zis astia ca imi schimba numele la anu\', imi vor zice Smeagol, ca asa aratam!\r\n\r\nDar Tiganiada continua, si la un moment dat or venit mujahedinii: var-mio (care mi-e ca o sora) si amicu\' lui, nu mai stiu cum il cheama, nici macar nu erau incoerenti, nici macar nu mai stiu ce am vorbit cu ei, nici macar nu mai stiu cand or plecat, si astialaltii nici macar nu i-or vazut, si nici macar nu mai conteaza. In fine.\r\n\r\nAsaaa... ce s-o mai intamplat, oare? Chiar nimic nu s-o mai intamplat...? Hmmm... ciudat...\r\n\r\nStiu numa ca a treia zi... duminica, parca era... da-da-da... am plecat acasa... si de atuncea numa visez ca is intr-un somn bicisnic, care se va termina dimineatza, si ma trezesc vineri in Sibiu, sa merem la tiganiada cu astia... cu tiganii...\r\n\r\nPS: Breaking news, lu\' Rramon i-o pus genunchiu-n ghips dupa Tiganiada, hihihi!','Euro-Tiganiada, partea a II-a',0,'','publish','open','open','','euro-tiganiada-partea-a-ii-a','','','2007-05-29 11:05:54','2007-05-29 09:05:54','',0,'http://www.groparu.ro/?p=445',0,'post','',9),(446,2,'2007-05-29 00:43:33','2007-05-28 22:43:33','','Achim Petru, Rasinari',0,'','inherit','open','open','','achim-petru-rasinari','','','2007-05-29 00:43:33','2007-05-28 22:43:33','',-1180385883,'http://www.groparu.ro/wp-content/uploads/2007/05/achim-petru.JPG',0,'post','image/jpeg',0),(447,2,'2007-05-29 01:10:10','2007-05-28 23:10:10','www.groparu.ro - in piscina','www.groparu.ro - in piscina',0,'','inherit','open','open','','wwwgroparuro-in-piscina','','','2007-05-29 01:10:10','2007-05-28 23:10:10','',445,'http://www.groparu.ro/wp-content/uploads/2007/05/wwwgroparuro-in-piscina.JPG',0,'post','image/jpeg',0),(448,2,'2007-05-29 01:13:45','2007-05-28 23:13:45','Romanian blog blog romanesc www.groparu.ro tigani gitan rrom tiganiada','Romanian blog blog romanesc www.groparu.ro tigani gitan rrom tiganiada',0,'','inherit','open','open','','romanian-blog-blog-romanesc-wwwgroparuro-tigani-gitan-rrom-tiganiada','','','2007-05-29 01:13:45','2007-05-28 23:13:45','',445,'http://www.groparu.ro/wp-content/uploads/2007/05/carlanu.JPG',0,'post','image/jpeg',0),(449,2,'2007-05-29 01:15:01','2007-05-28 23:15:01','Romanian blog blog romanesc www.groparu.ro tigani gitan rrom tiganiada','Romanian blog blog romanesc www.groparu.ro tigani gitan rrom tiganiada',0,'','inherit','open','open','','romanian-blog-blog-romanesc-wwwgroparuro-tigani-gitan-rrom-tiganiada-2','','','2007-05-29 01:15:01','2007-05-28 23:15:01','',445,'http://www.groparu.ro/wp-content/uploads/2007/05/crang.JPG',0,'post','image/jpeg',0),(450,2,'2007-05-29 01:16:43','2007-05-28 23:16:43','www.groparu.ro Romanian blog blog romanesc tiganie tiganiada rrom gitan tigan','www.groparu.ro Romanian blog blog romanesc tiganie tiganiada rrom gitan tigan',0,'','inherit','open','open','','wwwgroparuro-romanian-blog-blog-romanesc-tiganie-tiganiada-rrom-gitan-tigan','','','2007-05-29 01:16:43','2007-05-28 23:16:43','',445,'http://www.groparu.ro/wp-content/uploads/2007/05/degeaba.JPG',0,'post','image/jpeg',0),(451,2,'2007-05-29 01:18:20','2007-05-28 23:18:20','www.groparu.ro Romanian blog blog romanesc tiganie tiganiada rrom gitan tigan','www.groparu.ro Romanian blog blog romanesc tiganie tiganiada rrom gitan tigan',0,'','inherit','open','open','','wwwgroparuro-romanian-blog-blog-romanesc-tiganie-tiganiada-rrom-gitan-tigan-2','','','2007-05-29 01:18:20','2007-05-28 23:18:20','',445,'http://www.groparu.ro/wp-content/uploads/2007/05/duda.JPG',0,'post','image/jpeg',0),(452,2,'2007-05-29 01:19:31','2007-05-28 23:19:31','www.groparu.ro Romanian blog blog romanesc tiganie tiganiada rrom gitan tigan','www.groparu.ro Romanian blog blog romanesc tiganie tiganiada rrom gitan tigan',0,'','inherit','open','open','','wwwgroparuro-romanian-blog-blog-romanesc-tiganie-tiganiada-rrom-gitan-tigan-3','','','2007-05-29 01:19:31','2007-05-28 23:19:31','',445,'http://www.groparu.ro/wp-content/uploads/2007/05/ganistra.JPG',0,'post','image/jpeg',0),(453,2,'2007-05-29 01:21:20','2007-05-28 23:21:20','www.groparu.ro Romanian blog blog romanesc tiganie tiganiada rrom gitan tigan','www.groparu.ro Romanian blog blog romanesc tiganie tiganiada rrom gitan tigan',0,'','inherit','open','open','','wwwgroparuro-romanian-blog-blog-romanesc-tiganie-tiganiada-rrom-gitan-tigan-4','','','2007-05-29 01:21:20','2007-05-28 23:21:20','',445,'http://www.groparu.ro/wp-content/uploads/2007/05/glezna.JPG',0,'post','image/jpeg',0),(454,2,'2007-05-29 01:22:25','2007-05-28 23:22:25','www.groparu.ro Romanian blog blog romanesc tiganie tiganiada rrom gitan tigan','www.groparu.ro Romanian blog blog romanesc tiganie tiganiada rrom gitan tigan',0,'','inherit','open','open','','wwwgroparuro-romanian-blog-blog-romanesc-tiganie-tiganiada-rrom-gitan-tigan-5','','','2007-05-29 01:22:25','2007-05-28 23:22:25','',445,'http://www.groparu.ro/wp-content/uploads/2007/05/ielvis.JPG',0,'post','image/jpeg',0),(455,2,'2007-05-29 01:23:23','2007-05-28 23:23:23','www.groparu.ro Romanian blog blog romanesc tiganie tiganiada rrom gitan tigan','www.groparu.ro Romanian blog blog romanesc tiganie tiganiada rrom gitan tigan',0,'','inherit','open','open','','wwwgroparuro-romanian-blog-blog-romanesc-tiganie-tiganiada-rrom-gitan-tigan-6','','','2007-05-29 01:23:23','2007-05-28 23:23:23','',445,'http://www.groparu.ro/wp-content/uploads/2007/05/nartzoaga.JPG',0,'post','image/jpeg',0),(456,2,'2007-05-29 01:24:17','2007-05-28 23:24:17','www.groparu.ro Romanian blog blog romanesc tiganie tiganiada rrom gitan tigan','www.groparu.ro Romanian blog blog romanesc tiganie tiganiada rrom gitan tigan',0,'','inherit','open','open','','wwwgroparuro-romanian-blog-blog-romanesc-tiganie-tiganiada-rrom-gitan-tigan-7','','','2007-05-29 01:24:17','2007-05-28 23:24:17','',445,'http://www.groparu.ro/wp-content/uploads/2007/05/rramon.JPG',0,'post','image/jpeg',0),(457,2,'2007-05-29 01:25:47','2007-05-28 23:25:47','','Porc la protap',0,'','inherit','open','open','','porc-la-protap','','','2007-05-29 01:25:47','2007-05-28 23:25:47','',445,'http://www.groparu.ro/wp-content/uploads/2007/05/dsc02176.JPG',0,'post','image/jpeg',0),(458,2,'2007-05-29 01:27:07','2007-05-28 23:27:07','','Porc la protap',0,'','inherit','open','open','','porc-la-protap-2','','','2007-05-29 01:27:07','2007-05-28 23:27:07','',445,'http://www.groparu.ro/wp-content/uploads/2007/05/dsc02181.JPG',0,'post','image/jpeg',0),(459,2,'2007-05-29 01:28:26','2007-05-28 23:28:26','Porc la protap','Porc la protap',0,'','inherit','open','open','','porc-la-protap-3','','','2007-05-29 01:28:26','2007-05-28 23:28:26','',445,'http://www.groparu.ro/wp-content/uploads/2007/05/dsc02185.JPG',0,'post','image/jpeg',0),(460,1,'2007-05-31 19:12:56','2007-05-31 17:12:56','Da, deci. Asadar.\r\n\r\nDespre Sibiu se poate scrie multe. De exemplu, in Sibiu e mai multi olteni decat in Valcea, tine-i, Doamne! Finca tata meu din acte e oltean. Se zice ca pe olteni ii boteaza cu: \"In numele Tatalui sh-al Fiului, ia drumu\' Sibiului!\" Tata o loat drumu\' Sibiului, sh pac! io sh sor-mea, sor-mea curata si parfumata, io betiv, puturos, nu prea dajtept, da\' cu diplome kklau, amandoi crescuti si emigrati d-acolo.\r\n\r\nIn alta ordine de idei, stiu pe cineva a carei mama o vint dintr-un sat vecin, sh s-o maritat cu ta-su; femeile din sat nici in ziua de azi nu o kiama la shezatorile lor, finca Ã®i <em>viniturÄƒ</em>.\r\n\r\nCeea ce merita insa intr-adevar scris despre Sibiu este numa\' atata: Marginimea Sibiului. Stiti voi cand or pornit ungurashii verzui sa cotropeasca voios Transilvania Ardealului, prin anu\' 900 AD? Mnoa, or vint, s-or imbatat bine cu palinca prin Satu Mare, s-or f**** bine prin Bistrita (pfuaaai, ce mamici faine are orashu\' ala! respect...), or facut baie la Felix ca sa scape de bolile lumeshti luate de prin Bistrita, n-or reusit, or incercat si in Alba pe la Geoagiu, unde s-or deparazitat, si or ajuns in Sibiu. Mnoa. Amu is doo teorii ca de ce nu prea avem unguri prin Sibiu:\r\n\r\n1. S-or batut cu vajnicii sibieni zi de vara pana-n seara, nu o vint nici un corb cu apa in plisc, sibienii i-or tot dus la razboi de gherila, pana cotropitorii or zis \"Da io-mi sh bag p*** in iel Sibiu, baga-mi-as trombonu\' in savarina lu\' ma-sa! Hai sa chemam sashii sa colonizeze, ca io m-am saturat sa tat iau bote de cioban la oaie!\" Asa ca or mers pe la lacu\' Constantz, or loat cei mai derbedei sashi de prin crajme si i-or stramutat la granitza imperiului (mi se pare ca erau si in plina migratie slava peste Carpati, sh ungurilor le trebuia un tampon cu aripioare intre Imperiul Magyar si barbarii de olteni fierbinti) - si uite asa sibienii s-or trezit cu hotii aia de sashi acolo, care le-or furat tot: disciplina muncii, seriozitatea cuvantului dat, patentul de la motoarele BMW si prototipul de Messerschmidt 109, planurile pentru U-Boot-uri si schitele pentru Airbus 380. Sau 360. In fine.\r\n\r\n2. Or ajuns ungurii pe la Sibiu, dupa betia aia de la Satu Mare, saunele de la TÄƒjnad sh grasunele din Bistrita, ii durea capu\', le era rÄƒu, da\' rÄƒu-rÄƒu-rÄƒu, se simteau violati, si or vÄƒst sibienii. S-or uitat luuuung la ei, dupa aia s-or uitat la ei insisi, apai iara lung la sibieni, si or zis: \"Da ba Korci, da tie-ti traba, ca ungur, sibienii ÄƒÅŸtia?\" La care Piszta, scarbit, o zis: \"Ba Ionci, nu ba, face-mi-as limonada din cÃ¢t de acri is astia! Uita-te la ei! Hai mai bine sÄƒ aducem neshte sashi betivi acilea, ca la aia le e indiferent!\" Si asa Sibiul a scapat de unguri, da\' o dat de sashi, care le-or furat tot: disciplina muncii, seriozitatea cuvantului dat, patentul la motoarele BMW si prototipul de Messerschmidt 109, planurile pentru U-Boot-uri si schitele pentru Airbus 380. Sau 360.\r\n\r\nCa sa va dati un pic seama despre ce e vorba, si de ce nu le-o trebuit la unguroaice sibieni: in frumosul sat-orash Salistea Sibiului, unu\' s-o gandit sa isi faca benzinarie. Amu vreo 10 ani. Sa ia toate ARO-urile alora de are oi multe benzina de la el. Laudabil, veti zice voi. Najpa, o zis alt crescator de oi. Si a inceput sa isi faca si el benzinarie, da\' vizavi dÄƒ iel. Primu\' o zis: \"I beg your pardon??? Pai ala din Tilisca ma concurÄƒ iel pÄƒ mine?\" Sh zaaaang!!! Sh-o mai trantit o benzinarie, da pe cealalta parte a drumului, atza in fatza lu\' ala, lu\' competitoru\'. Amu al doilea - ghiciti ce o facut??? Exact. Si-o trantit sh el inca o benzinarie, da\' vizavi de primu.\r\n\r\nAstfel, cine ajunge pe la Salistea Sibiului, poate admira 4 benzinarii pe 500 de metri de pustietate, doo de o parte a drumului, alte doo pe cealalta parte, si pe fiecare parte e cate un EUROIL si cate un ARAL. Si aici e cel mai eftin combustibil din partea asta a lumii crestine si curvare sh betivane. Io am mers cu ocazie cu tirishti care veneau cu 60 la ora de la Cluj ca sa le ajunga gazu\' pana la Saliste, sa alimenteze de-acolo, ca la 900 de litre cat ia un tirist, se cunoajte, taica!','Razboiul celor doua Gaoze',0,'','publish','open','open','','razboiul-celor-doua-gaoze','','','2007-06-01 21:58:02','2007-06-01 19:58:02','',0,'http://www.groparu.ro/?p=460',0,'post','',6),(461,2,'2007-06-01 10:57:33','2007-06-01 08:57:33','Cica un pustiulica <a href=\"http://ralph18.hi5.com/\" target=\"_blank\"></a>facea flotari peste profa lui de romana. Si la un moment nefericit de proasta inspiratie cauzat de inima sa gaurita, s-a gandit ca piesa aia a lu R. Kelly (I believe I can fly) e pe bune. Asa ca o zburat de la un etaj la care aveai nevoie de lift ca sa cobori in jos; si baietu\', nefiind Luceafar (duh!!!) s-o facut clatita pe pavaj. Care sigur avea gropi. Nesapate de Groparu.\r\n\r\nMnoa. Asta suna ca genu\' feminin de moarte la care as visa si eu. Finca io, intr-o buna zi, o sa vreau sa mor din cauza unei profe de romana. Da. Sa ma indragostesc de ea, sa ii scriu poezele <a href=\"http://www.groparu.ro/?p=74\" target=\"_blank\">d-alea d-ale mele</a>, stil Emil Brumaru, da\' - firesc - oleaca mai najpa, sh sa o scot la kefane, sh toti sa se minuneze ca ce moaca de tocilara are. Si sa zica toti ca io am innebunit!!! Sh pe mine sa ma doara-n pics sh sa ma iubesc cu ea printre manuale, teze si extemporale, si sa-mi recite Macedonski in timp ce-mi face pedichiura. Si sa gateasca pentru prima data gombotzi, sh sa ii iese najpa, sh io sa o iert, in imensa mea marinimie, si sa comandam o pizza de la Pizza Cezar, numa ca sa ne distram si sa o refuzam, finca o sa fim prea ocupati sa ne fasolim. Si o sa ne plimbam prin parc, sh o sa tragem vanturi pe bancile pe care se etaleaza alte cupluri, si daca comenteaza ii iau sh gajica lu Äƒla, sh mÄƒ sexez cu amandouÄƒ toata noaptea, sh profa mea o sa fie un pic geloasÄƒ, si o sa-i promit cÄƒ de acum inainte nu o mai facem decat cu prekinele ei, profe de mate, un pic isoscele pentru gustul meu, da\' taaare doritoare de rigla. Åži de la prea mult amor, inima mea, sireaca, Ã®ÅŸi cam va bÄƒga putulica in putulica mea, si s-ar putea sa cam dau coltzu\', tot in zbor, da spre ceruri, finca ma voi orgasma cu nesimtire.\r\n\r\nIo o sa am 94 de ani si ea va fi profa de romÃ¢nÄƒ a lu\' stranepotu-mio.','Groparu se va sinucide din solidaritate',0,'','publish','open','open','','groparu-se-va-sinucide-in-solidaritate-pentru-bogdan-costache','','\nhttp://www.groparu.ro/?p=74','2007-06-03 21:13:44','2007-06-03 19:13:44','',0,'http://www.groparu.ro/?p=461',0,'post','',38),(463,2,'2007-06-04 18:46:57','2007-06-04 16:46:57','Il stiti pe Mungiu, meseriashu\' care o loat in palmele sale o palma de aur la Cannes.Â  Si pe care toata presa acuma-l tine ca-n palma. Mnoa.\r\n\r\nDeci Mungiu, meseriashu\' care o loat o palma de aur la Cannes, o vint prin Cluj la <a href=\"http://www.tiff.ro/\" target=\"_blank\">TIFF</a>. Si dupa TIFF, s-o dus la o beuta, ca omu\'. Sh la beuta, cine da peste el? Unu\'. Pe care-l stiu. Care o vrut si el sa ii dea o palma, da\' nu de aur. O palma simpla. Si i-o intins palma, sa dea noroc cu el si sa-l felicite. Mungiu, pe care il manca palma, i-a si strans-o.\r\n\r\nCe nu stia insa Mungiu: datatorul de noroc are o ciuperca mica, mica-mica, nehalucinogena, crescuta pe palma aia cu care da noroc cu regizori care castiga palme de aur. El zice ca nu e oleaginoasa sau contagioasa. Io oricum nush ce sa cred, ca ciuperca ramane ciuperca!','Palma luata de Mungiu',0,'','publish','open','open','','palma-luata-de-mungiu','','','2007-06-04 18:46:57','2007-06-04 16:46:57','',0,'http://www.groparu.ro/?p=463',0,'post','',2),(462,2,'2007-06-04 12:46:19','2007-06-04 10:46:19','<a href=\"http://oedip.blogspot.com/\" target=\"_blank\">Oedip</a> (puii mei, ca nu vreti sa-ntelegeti! nu e ala cu ma-sa, mÄƒ, din mitolojie!!) o preluat, o mestecat sh o dat mai departe un tag: \"<span style=\"font-style: italic; font-weight: bold\">Ce v-ar plÄƒcea sÄƒ vi se scrie epitaf cÃ¢nd vÄƒ strÄƒmutaÅ£i pe plaiurile vÃ¢nÄƒtorii eterne?</span>\" (stiam ca sunt <em>vesnicele plaiuri ale vanatorii</em>, da\' bag samÄƒ ca e numa\' rephrase)\r\n\r\nCel mai tare epitaf cica era sa scrie pe crucea lu Daniel Scavinschi, asa cum zicea Negruzzi, oare...? Parc-asa suna:\r\n\r\n\"<em>Sunt Daniel Scavinschi, cel mititel de statura\r\nPe care insasi natura l-a creat in miniatura\r\nSi caruia i-au cazut mustetile, si e chiar caricatura!</em>\"\r\n\r\nHahaaaaa! Deci, io-s gropar, da? Normal, ca d-aia am tot timpu\' dreptate, ca tot timpu\' dati din cap ca da cand io zic ceva. Deci.\r\n\r\nIn primu rand ca cand-a fi sa mor, io astept cu nerabdare orgasmu\' ala de final. Ca cica asa moare cate unii, cu dintii stranshi si urland, ca nush ce endorfine se scapa in pantaloni la tine-n vine, de iti fac <em>marea trecere</em> mai usoara, si cica is aceleasi endorfine care  isi dau drumu\' ca nesimtitele cand spermatozoizii (campioni - la unii!) ies din cartilaju\' din dotare, si incep sa alerge ca apucatii, chiuind.\r\n\r\nP-orma, cu o secunda inainte, as vrea sa revad filmu\' vietii mele, da\' cu toate betivaniile sh preacurvishteniile facute, sÄƒ mÄƒ rÃ¢d. Åži daca se poate, sÄƒ dau <em>rewind</em> si sa fac screenshoate mai ales cand ma f**eam ca nesimtitu\' in multele momente care mi-or punctat aceasta bicisnica si sublima viatza.  Si eventual sa pot face si live blogging, ca - jur! - veti avea ce ceti, oioioi...\r\n\r\nP-ormÄƒ - as vrea sa ii vaz pe gropari cum isi face treaba, si o sa isc o melodie pe sunetul bulgÄƒrilor de Å£ÄƒrÃ¢nÄƒ care bate ritmu\' pe capacu\' copÃ¢rÅŸeului. O sÄƒ fie un remake a lu\' \"Another one bites the dust - heh heh!\"\r\n\r\nAsaaa. Sh-apÄƒ - vine momentu\' suprem. Cica pluteshti asa o vreme prin negreatza, sh vezi o lumina, sh tre sa meri spre ea, ca te atrage ca pe o scama un aspirator. Sh aici lucrurile se complica in sensu\' prost.\r\n\r\nCa cica meri, asa, catre lumina, sh iti apare in fatza la ghiseu un functionar ceresc barbos, batraior, cu okelari pe nas sh fonfÄƒnit, care vrea sa vada tat ce ai facut, si are in fatza un catastif. Io pun pariu cÄƒ o sa i se faca un pkik rushine cand o sa vada unele scene, si io n-o sa prea am ce sa-i zic; si Ã®mi voi auzi:\r\n\r\n- Acuzarea prezinta dovezi irefutabile. Deci tu nu te-ai dat in lÄƒturi de la niica: fornicare, betie, clevetit, tras chiulu\', inghesuit studente prin Ratucuri. Ba, in unele momente, chiar te credeai un mic Dumnezau, mai ales cand picurai plastic arzand peste furnicutze; asta e cu deosebire najpa. Si ai si scris in bloage despre Dumnezau, in care cam vorbeai cu el de la egal la egal; ceea ce iara e deosebit de najpa: o fi el tac-tu\', da\' nij kiar asha!!! Ca sa nu mai punem la socoteala ca singurele donatii facute de tine erau cand dadeai bere la prekinii tai betzivani, si credeai ca faci fapte bune.\r\n\r\n-  Inaltzata excelentza, o sa-l intrerupa Groparu cu juma\' de voce, io... mnoa, asta e, am cam facut ghi tatie, mai ales pacatoshenii. Si inca cu o sete care si pe mine m-a surprins. Si ceea ce e cel mai najpa ie caaa... phuii mei, da\' nij nu prea regret io ce-am facut, ca noa... nu regret! Cum puii mei sa regret? Hai ca betiile le regret, da\' numa alea dupa care m-am simtit cu adevarat oribil, de am umblat o saptamana intreaga chiaun de cap, cu un gust metalic in gurÄƒ, de la desfacut berile cu dintii; da\' in rest - cum sa regret io tocma\' fornicarea? Ha? Aud? Tu - dumneavoastra - ce ai fi facut in locu\' meu, din moment ce fornicarea era singura metoda de a lipi dreq un zambet pe fÄƒtzÄƒu\' meu? Ce ai fi facut tu Ã®n locu\' meu, cÃ¢nd Ã®s atÃ¢tea femei neiubite cum trÄƒbÄƒ pe lumea asta? Ha? Deci Ã®n loc sÄƒ Ã®mi daÅ£i o moÅŸie ultracentralÄƒ Ã®n esplanada raiului, cu vedere la muntii raiului populati cu nimfe care face baie dezbracate Ã®n tot felu\' de paraie reci care le sumetzeshte sfarcele, voi Ã®mi bagati de vina si Ã®mi daÅ£i <em>ban</em>?\r\n\r\nIo sunt sigur ca pledoaria mea nu o sa ii impresioneze prea tare pe cuvioshii gardieni ai Portii Raiului, da\' io o sa incerc, oricum. Sh daca nu mere, o sa incerc cu o spaga micutza, sa deskiza portile numa pana ma poci io strecura inauntru; si daca nici cu spaga nu o sa se poata, o sa ma rog ca totu\' sa fie la camera ascunsa, si ei numa\' sa se prefaca ca nu ma primesc, da\' de fapt sa ma welcome-uiasca ca sa le fac si acolo, la ei in rai, Tiganiada.\r\n\r\nCat despre epitaf, ca parca de-acilea pornise tat, o sa fie cam asa:\r\n\r\n\"Aici zace **** ******** ******* (asta e numele meu), omul care nu a trait niciodata 2 zile la fel. La moartea sa, prietenii sai in borhot l-au pus, si palinca l-au facut; si cu mare bucurie l-au baut, si mare sarbatoare au facut!\"\r\n\r\nPS: Dau mai departe <em>gutu-va-n</em> tagu\' asta lu\': <a href=\"http://iepurasulatomic.weblog.ro/\" target=\"_blank\">Iepurashu\'</a>, <a href=\"http://rottencabbage.haipa.ro/\" target=\"_blank\">VarzÄƒ</a>, sh <a href=\"http://www.doingtheartwork.com/\" target=\"_blank\">Muishu</a>.','Epitaf de Gropar',0,'','publish','open','open','','epitaf-de-gropar','','','2007-06-06 11:42:05','2007-06-06 09:42:05','',0,'http://www.groparu.ro/?p=462',0,'post','',6),(465,2,'2007-06-05 17:30:17','2007-06-05 15:30:17','Deci, la Maramu\' e nunta cat 4, fara \'mormantare!\r\n\r\nSh cuplu o fo kewl: o olteanca fierbinte din Filiashi cu un june prim din Baia Mare. Cele doua antiteze au avut un <em>cultural shock, </em>dar viatza si setea de amor a invins, si s-au hotarat ca e cazu\' sa se chinuie o viatza intreaga, pentru ca apoi sa se si impace si sa se reproduca.\r\n\r\nMnoa: am plecat cu vreo 14 ore mai repede din Cluj decat planificasem, ca am sh ratat o noapte sanatoasa de beuta ca sa-mi fac incalzirea pentru nunta. Asta e. Noroc ca ficatzii mei e suficientzi de antrenati cat sa nu cedeze usor la olimpiade de horinca ad-hoc.\r\n\r\nApropos, ca sa va dati un pic seama de ce fel de popor avem, ca atata mi-i de drag de el, ca l-as hiroshimiza: ajungem la sala, sh toata lumea s-o napustit la whiskane, Teachershi sh Geci. Am refuzat cu dispretz o chelneritza trecuta de prima tineretza si ucigator de politicoasa care dorea sa-i puna groparului coloratura d-aia in pahar, sh m-am dedat la horinca d-aia dullllce, da\' dulllce, atata de dulllce ca mi-o dat pe nas de placere, de mi s-or si cauterizat mucoasele nazale, de tot in juru meu mirosea dupa aia parfumat a coditza de pruna. Chiar si soacrele lu\' mirii!\r\n\r\nN-asa. S-o furat mireasa, da\' nu de mine, sh norocu\' mirilor cÄƒ nu de mine, ca Äƒia de-or furat-o or cerut o <em>lada de bere si o sticla de gec, </em>sh le-or sh primit instant. Da\' goale. <em>Beginners</em>, o pufnit Groparu dispretuitor.\r\n\r\nSi baimarenii is enervant de politicoshi in doua ipostaze: cand is kelneri, sh cand nu-s. Zic asta finca nu o existat doleantza nesatisfacuta instant de armata de Garsoane si Garsoni care nu mai pridideau sa aduca papa bun sh lichide in sticle cu etichete pretentioase. Si cand un nene s-o cam ofticat si s-o rastit la un chelner in legatura cu ceva cafea neadusa, ca s-o fi gandit rÄƒstitoru\' ca e prin litoralu\' romanesc si trebe sa isi apere interesele in fatza chelnerilor si sa loveasca preventiv, ficioru\' de Garson atÃ¢Ã¢Ã¢Ã¢ta o fost de stapan pe situatie si i-o explicat lu\' Äƒla ca unui debil mintal cum sta treaba cu cafeaua, ca io in secunda aia mi-am dorit sa fiu chelner de Baia Mare, sa fiu la fel de stapan pe mine cÃ¢nd urla shafu\' la mine (urlÄƒ des, mai ales cÄƒ io ii si reusesc sa Ã®i dau motive zdravene!!!) sh sa il intreb cu un calm ucigator \"Doua pliculetze de zahar ajunge?\" Da\' sa nu imi taie din salar\' dup-aia.\r\n\r\nAtata.\r\n\r\nPS: Cand meretz la nunta in Maramu\', sh sunteti masculi, sh nu purtati blugi sau trening, ci costum, sh nu avetz putzulica prea lunga, avetz de grija cand meretz la buda la pipi la barbati: recomand costume de culoare inchisa, ca pe celelalte se vad stropii.','In weekend am fo\' la nunta in Maramu\'',0,'','publish','open','open','','in-weekend-am-fo-la-nunta-in-maramu','','','2007-06-05 17:50:50','2007-06-05 15:50:50','',0,'http://www.groparu.ro/?p=465',0,'post','',12),(466,2,'2007-06-06 12:59:03','2007-06-06 10:59:03','1. Astepti sa se elibereze.\r\n2. Astepti sa se elibereze.\r\n3. BaÅ£i Ã®n uÅŸÄƒ insistent, aÅŸtepÅ£i sÄƒ se elibereze.\r\n4. CÃ¢nd se elibereazÄƒ, tragi adÃ®nc aer Ã®n piept, ÅŸi intri. ÃŽnuntru pute a caca amestecat cu spray anti-caca.\r\n5. Te deschiloÅ£ezi Ã®n vitezÄƒ. Åžtergi rapid cu hÃ¢rtie igienicÄƒ stropii gÄƒlbui de pipi de pe colac (dacÄƒ apuci). Sufli flocuÅ£ii de pe plastic.\r\n6. Te aÅŸezi. Colacul, Ã®n loc sÄƒ fie rece, e cald de la bucile ocupantului anterior. Oftezi. Astepti.\r\n7. ÃŽncepi sa nu Ã®Å£i mai poÅ£i Å£ine respiraÅ£ia, ÅŸi tragi aer pe gurÄƒ, ca sa nu simÅ£i mirosul. TuÅŸeÅŸti, te ineci.\r\n8. Te gandeshti la Putin sh rachetele lui, la gemenele alea sinucigase, la variante de mat din 3 mutari; verifici mesajele si creditu\' din telefon, dai de mesajele insipide de Pasti si te eliberezi instant.\r\n9. Intre timp incep sa te usture ochii, reuÅŸeÅŸti sÄƒ iei un kilometru de hÃ¢rtie igienicÄƒ nefolositÄƒ cu care te ÅŸtergi Ã®n vitezÄƒ. Tragi apa, mai bagi un rÃ¢nd de aer Ã®n plÄƒmÃ¢ni prin gurÄƒ, lucrezi cu buzduganu ca sa cureÅ£i maro-ul de pe porÅ£elan, ieÅŸi Ã®n vitezÄƒ.\r\n10. Auzi vocea lu\' antipaticu\' firmei. Renuntzi sa te mai speli si mergi sa dai noroc cu el. Ii strangi mana indelung, si cu cealalta il bati usurel pe umar, colegial.\r\n11. Revii sa te speli, dar buda e ocupata. Astepti sa se elibereze.\r\n12. Astepti sa se elibereze.\r\n13. Astepti sa se elibereze.\r\n14. Renunti.','Cum se merge la buda',0,'','publish','open','open','','cum-se-merge-la-buda','','','2007-06-06 12:59:38','2007-06-06 10:59:38','',0,'http://www.groparu.ro/?p=466',0,'post','',12),(468,1,'2007-06-07 12:20:22','2007-06-07 10:20:22','1.1. Toti elevii are fantezii sexoale profe (cand Groparu era elev, visa la un animal cu doo spinari cu profa de fizica, da\' ea nu o vrut, nici cu fortza macar).\r\n1.2. Cand un elev si-o indeplinit fantezia cu profa de romana, s-o cam <a href=\"http://www.evz.ro/article.php?artid=306592\" target=\"_blank\">sinucis</a>.\r\n\r\n2.1. Cand un elev ia un 4 la mate, isi face funia cravata si se cam <a href=\"http://www.evz.ro/article.php?artid=295965\" target=\"_blank\">sinucide</a>.\r\n2.2. Cand un elev e olimpic, se <a href=\"http://www.hotnews.ro/articol_8811-Un-elev-olimpic-s-a-sinucis-din-dragoste.htm\" target=\"_blank\">sinucide</a>.\r\n\r\n3.1. Un student din Hajdeu se <a href=\"http://arhiva.monitorulcj.ro/2004/2004.01.06/local2.html\" target=\"_blank\">arunca</a> de la etaju\' 9 din cauza ca facea Dreptu\' amu-s 2-3 ani.\r\n3.2. <a href=\"http://www.protv.ro/stiri/social/doua-gemene-din-cluj-s-au-sinucis-intr-un-parc-din-centrul-orasului.html\" target=\"_blank\">Doua foste studente</a> la Literi si-or pus cravata fatala dupa ce or termenat facultatea.\r\n\r\n4.2. Cand un elev nu mai suporta scoala, se cam <a href=\"http://www.hotnews.ro/articol_74908-Psihologii-avertizeaza-ca-stresul-ii-poate-duce-pe-unii-adolescenti-la-gesturi-disperate.htm\" target=\"_blank\">sinucide</a>.\r\n4.3. Cand o tigancusha nu e lasata la scoala, se cam <a href=\"http://www.cotidianul.ro/index.php?id=11345&amp;art=30069&amp;cHash=4eba4bf384\" target=\"_blank\">sinucide </a>destul de definitv.\r\n\r\nq.e.d.','Dovezi ca tinerimea de azi e confuza',0,'','publish','open','open','','dovezi-ca-tinerimea-de-azi-e-confuza','','','2007-06-07 12:20:22','2007-06-07 10:20:22','',0,'http://www.groparu.ro/?p=468',0,'post','',5),(469,1,'2007-06-07 17:07:14','2007-06-07 15:07:14','- Sa infigi un furculitz cu putere intr-un carnatz sfaraind, sa il ridici de pe gratar cu evlavie si sa il lasi sa picure, preacuvios, pe felia de paine.\r\n- Sa se uite in troleu o gajica bunoaca la tine zambind (oare din cauza ca ai un muc verzui si aproape uscat agatzat semetz de o nara?) si sa intorci privirea, flegmatic.\r\n- Sa fii invitat cu glas mieros de directoarea ta  de la scoala unde predai (ea fiind profa de romana si te urashte) sa <em>analizati impreuna poezia aia*</em> \"A venit toamna, acopera-mi inima cu ceva\", ca ei versurile astea nu ii spun nimic ei, ca ea nu o facut Stanescu la scoala.\r\n- Sa iti sara un fost elev in fatza sh sa te salute bucuros.\r\n- Sa ti se dubleze salariu\' fara sa meriti.\r\n- Sa ii inveti pe altii cum sa-si gestioneze banii, indrumandu-i spre investitii sortite esecului (tzapÄƒÄƒÄƒÄƒÄƒÄƒ!)\r\n- Sa iti cumperi un kil de fistic, sh sa te apuci de dezghiocat acasa, ca sa nu imparti cu nimeni.\r\n- Sa te joci cu bormashina cand vecinele studentele are sesiune.\r\n- Sa descoperi in troleu la o gajica bunoaca un muc verzui si aproape uscat, agatzat semetz de o nara, sa-i zambesti si ea sa intoarca capu\', flegmatica.\r\n- Sa ti se tripleze salariu\' fara sa meriti.\r\n- Sa te intinzi pe pat si sa te uiti fix la tzantzaru\' omorat asta-vara.\r\n- Sa ii auzi pe vecini cum se fute, sa iti suni prietenii si sa lipesti telefonu\' de perete, sa auza sh ei.\r\n- Sa ceteshti interviuri cu Tamango.\r\n- Sa rÃ¢gÃ¢i sonor si sa simti gustul pranzului cum Ã®Å£i revine in guritza.\r\n\r\nDAR NICI UNA DIN PLACERILE DE MAI SUS NU SE COMPARA CU PLACEREA SCARPINATULUI.\r\n\r\n_______________\r\n* nu va ganditz la prostii pls','Placeri preavinovate',0,'','publish','open','open','','placeri-preavinovate','','','2007-06-07 17:07:14','2007-06-07 15:07:14','',0,'http://www.groparu.ro/?p=469',0,'post','',4),(470,1,'2007-06-19 00:03:06','2007-06-18 22:03:06','O noua teorie aparuta dupa ce s-au lins cu furie ciuperci halucinogene face furouri pe forumu\' ziarului <a href=\"http://www.cotidianul.ro/index.php?id=11653&amp;art=30762&amp;nr=1&amp;cHash=fdd4bad3fe#opinii\" target=\"_blank\">Cotidianu\'</a>: zice un nene cum ca noi ne tragem din cumani, deci nici macar deloc din Traian si Decebal, primul cel mai violator de Dacie (pe atunci nu era Logan) din istoria celui mai pederast neam latin, celalalt cel mai sinucigas rege din istoria celui mai caciulit-cu-motz popor trac (desi, nota bene! nu era elev care-si picase bacu\').\r\n\r\nNenea istoricu\', ca si Groparu, o fost de toate la vremea lui, inclusiv ambasador in Africa (kiar ambasador inca nu am fost, deshi mi-as fi placut sa rezolv afaceri cu hash in numele natiei mele cu ambasadoare shefe de trib cu tzatze mari). Si el zice ca o aflat destule dovezi cum ca de fapt romanii or fo natia cea mai preacurvara din istoria Romaniei, ca la betie n-or iertat ici o migratoare, dimpotriva, i-o cam dat sh ei s-o bea, si-or activat marketingu\'  sexoal sh ashe le-or calarit, mah, ca daca puneai o bucata de pastrama intre ei iesea sunca de Praga, presata, gata sarata cu miros dulceag de femeie!!! Deja salivez.\r\n\r\nMnoa, fornicarea asta nediscriminatorie (stiam eu ca suntem cel mai tolerant popor din tzara mea, mai ales daca la sex suntem lasati sa stam deasupra) a dus la aparitia noastra. Da\' inainte ca ai nostri sa se dedea la carne de migratoare, cicÄƒ cumanii aia care or fost nucleul Ã®nsuÅŸi al revigorÄƒrii proto-romÃ¢nilor or fo, cicÄƒ, africani, mah!!! Deci de aici pot trage decÃ¢t concluzii care ne avantajeazÄƒ:\r\n\r\n1) daca suntem si africani, Ã®nseamnÄƒ ca masculii nostri auÂ  p*** mare;\r\n\r\n2) nu prea suntem noi chiar asa de neamuri cu pederashtii aia orgiastici de la Roma, ceea ce e bine;\r\n\r\n3) nu prea suntem noi nici chiar asa de barbari pe cat erau dacii, ceea ce e iara bine;\r\n\r\n4) desi nu prea suntem neamuri cu romanii, am fo\' suficienti de treji la cerebica incat sa le invatzam limba, finca stiam ca asta ne va baga in UE dupa vreo 2000 de ani;\r\n\r\n5) sa nu va prind ca nu suntetz de acord, ca imi fac bracinar de bombe sh ma arunc in aer cu Iliescu cu tot; ca cica ca daca esti african egiptian d-ala musulman te asteapta una bucata lot de 50 de virgine numa pe tine (io atatea virgine nu am vazut nici cand eram la cresha!)\r\n\r\n6) nu, ma, nu suntem un popor de homosexuali, finca avem mame sh tati, nu mamic sh tatic!!!!','De ce nu suntem un popor de homosexuali',0,'','publish','open','open','','de-ce-nu-suntem-un-popor-de-homosexuali','','','2007-06-19 00:03:06','2007-06-18 22:03:06','',0,'http://www.groparu.ro/?p=470',0,'post','',4),(471,2,'2007-06-08 10:52:58','2007-06-08 08:52:58','Oricat ar parea de ciudat, Groparu are si el prekini, parinti, o sora pe care-l iubeshte, sh sh fosti colegi de liceu.\r\n\r\nMnoa, unu dintre ei e si unu\' Calin. Calin, si atata. Desi am o groaza de vorbit despre Calin, alceva nu mai zic, ca e om insurat, si am jurat ca nu spun, ca afla nevasta-sa, care e destul de. Deci.\r\n\r\nGroparu in liceu o avut o gashca faina, ca eram 4 masculi la 27 (parca) de fete, ca io asa ma orientez in viatza, sa fie  numa\' femei pe langa mine, cum ar fi: o mama, o sora, si 2 vecine studente. Mnoa. Si in liceu, Calin, deÅŸi era plin de coÅŸuri, o reusit sa isi faca rost de prima gajica normala dintre noi patru, pe nume Ana. Mnoa, sh s-o tat iubit cu asta vreo 2 anishori, da\' turbat, nu gluma! pana cand  o vint despartirea, si or ramas numa cu amintireaÂ (eram odata la fata-n shura si jucam carti pe pedepse,  era noaptea pe la 4, ÅŸi am auzit usa bufnindu-se, si taica-su o dat navala spre gradina prin shura unde noi ne cartofoream, sh s-o pishat indelung in gradina, si in timp ce se pisha l-am auzit cum se pÃ¢rÅ£Ã®ia sonor, ÅŸi atÃ¢ta de nasol o fost ca nu am putut rÃ¢de cumsecade, oioioi!!! ca dacÄƒ auzea ne dÄƒdea afarÄƒ)\r\n\r\nMnoa, Dupa vreo... 6 ani, ma suna Calin.\r\n\r\n- Ba pulÄƒ, zice asta, Ã®s diztrus.\r\n- Ce-i ma? ZÃ¢c. Iar ai bÄƒgat bani in pokere? Ti s-o futut delcou\' la Dacie? Ce ai?\r\n- CÄƒ taci mÄƒ, zice. O murit Ana.\r\n- Cum pula mea sÄƒ moarÄƒ Ana? zic. Ej nebun? Du-te bea o cafea si trezeste-te, zÃ¢c.\r\n- Nu ma prostule, zice, ca e chiar rece, ce pula mea! Åži cred cÄƒ ÅŸi Å£apÄƒnÄƒ!!!\r\n\r\nÅži Ã®mi zice bou\' ce o pÄƒÅ£it fata, ca cand aud mi se ÅŸi face pielea gÄƒinii ÅŸi cotcodÄƒceÅŸte veselÄƒ cÄƒtre grÄƒdinÄƒ, unde face pipi ÅŸi se ÅŸi pÃ¢rÅ£Ã¢ie. DupÄƒ divorÅ£u\' de el, fata... ÅŸi-o loat un <em>altu\'. </em>Cu care s-o ÅŸi mÄƒritat. Åži nu i-o ajuns, ÅŸi o ÅŸi trÃ¢ntit cu el un copil, sau o fatÄƒ. Ceva de genu. Si tot nu i-o ajuns! Ca o mai ramas o data gravidutzÄƒ. Åži aici lucrurile deja incep sÄƒ ia turnurÄƒ de toatÄƒ groaza. ÃŽn luna a 5-a o aflat ca are leucemie, din care se cam moare. Åži o cam ÅŸi murit, tocma\' cand era gravidutza prin luna a 8-a. Bebele nu o putut fi salvat. Åži toate astea le-o aflat Calinu\' meu de la un consatean al Anei (ce nume simplu).\r\n\r\nClar ca am tzÃ¢jnit Ã®n Sibiu in weekendu ala sÄƒ mÄƒ imbÄƒt cu el, sa-i treacÄƒ, sa ne amintim copilariile noastre strict heterosexuale. Si stiu ca atata de tare m-am imbatat, ca am plecat din crajma cu taxiu pe furish, si filmam tot cu noua mea camera, si soferu se criza, si am ajuns acasa, am mers la non-stop, m-am filmat cand am cumparat un kil de lapte, si apai cum am mers acasa, si cum am adormit. In fine.\r\n\r\nMnoa. UNDE AM GAFAT IO. Dupa vreo trei zile, intra asta online, sh ii zic:\r\n\r\n- Da\' ce faci ma tranta.\r\n- Najpa, zice el.\r\n- Te mai gandeshti la ea? zic.\r\n- Pai da, clar (ofteaza).\r\n- Hai sa iti dau neshte muzica, sa ti-o inveselesti (Calin e mort dupa muzica).\r\n\r\nSi caut pe calc ultimele 4 melodii cu Margineanu, si i le dau sa curga pe tzava. <strong>Si imi dau seama tocmai cand terminase de descarcat prima piesa ca printre ele sa afla si melodia Jana</strong> (<em>Jana era croitoreasa/Jean frizeru\' o iubea/Si a murit tuberculoasa/Jean frizeru\' o jelea). </em>Si urlu la el pe mes:\r\n\r\n- Baaaaa pulaaaaa!!!! Auzi, ai descarcat cumva melodia Jana?\r\n- Da, zice asta.\r\n- Ba, zic (tremuram). Faci ceva pt mine?\r\n- Orice, zice el (mintzea).\r\n- Sterge-o, te implor ca pe Maica Sfanta.\r\n- Di ce? intriaba.\r\n- ...\r\n- ?\r\n- Nu cre\' ca-tz face bine, zic io, fluturandu-mi stomacu in burta de emotie sa nu fut meciu\'.\r\n- DE CE??? ma intreaba (asa ma inerveaza, niciodata nu ma asculta nimeni, veci pururi nu o sa fiu manajer!!!)\r\n- CA E CU MUARTE, MA PULA!!! STERGE-O ACUM!!!\r\n- Nu, zice el, deja o ascult de 5 minute. E OK.\r\n\r\nPS: Partea cea mai faina e caaa... dupa vreo 3 luni, am aflat ca nu murise Ana, ci murise o verisoara de-a ei pe nume tot Ana, si nu era tanara, era batrana, ceea ce e OK, si nu era gravida, ca niciodata nu se maritase, ca era fata batrana care e OK sa moara. Deci m-am scos. Ca alfel nu va ziceam la toti de chestia asta.','Cum am comis-o BIG TIME, ca sa zic asa',0,'','publish','open','open','','cum-am-comis-o-big-time-ca-sa-zic-asa','','','2007-06-08 10:52:58','2007-06-08 08:52:58','',0,'http://www.groparu.ro/?p=471',0,'post','',8),(472,2,'2007-06-08 16:18:02','2007-06-08 14:18:02','- gogele (ziÅŸi si mniolÅ£Äƒi, ziÅŸi ÅŸi zambuci) = cÃ¢nd mergi la budÄƒ, ÅŸi te ÅŸtergi, ÅŸi rÄƒmÃ¢n neÅŸte buburuze rebele de caca cu hÃ¢rtie igienicÄƒ prinse bine pe firele de pÄƒr din vecinÄƒtatea  gÄƒurii curului. Ies numa cu foarfeca.\r\n\r\n- birgubici = cÃ¢nd mergi la munte, bei apÄƒ de izvor din PET transparent; ÅŸi dupÄƒ ce mÄƒnÃ¢nci, dar Ã®ncÄƒ mai mesteci, duci sticla la gurÄƒ ÅŸi bei; birgubicii Ã®s animalele alea vesele care ies din gura plinÄƒ de mÃ¢ncare ÅŸi Ã®ncep sÄƒ Ã®noate vesele prin apa din PET, ÅŸi la ceilalÅ£i le e scÃ¢rbÄƒ sÄƒ mai beie dupÄƒ tine.\r\n\r\nMai era un cuvÃ¢nt, da nu-mi vine amu in cap.','Limba romana este patria mea',0,'','publish','open','open','','limba-romana-este-patria-mea','','','2007-06-08 16:18:02','2007-06-08 14:18:02','',0,'http://www.groparu.ro/?p=472',0,'post','',12),(473,2,'2007-06-11 03:00:04','2007-06-11 01:00:04','Deci nush altii cum sunt, da\' io tocma\' ce-am aflat cum face ei banii. Ei = unii.\r\n\r\nSa va zic?\r\n\r\nHmmm.\r\n\r\nOK.\r\n\r\nVa zic.\r\n\r\nDa\' va trebe palinca.\r\n\r\nVeche.\r\n\r\nO palinca veche de regula e si o palinca buna.\r\n\r\nO palinca veche si buna, pt. Groparu, e ca un felinar pentru o molie d-aia de nuapte.\r\n\r\nIrezistibila.\r\n\r\nDeci va trebe palinca veche, sh sa chemati Groparu sa beie la voi.\r\n\r\nGroparu nu are fizic cum rezista unei asemenea invitatii.\r\n\r\nAr fi impotriva firii.\r\n\r\nMnoa.\r\n\r\nSh cand Groparu bea la voi palinca veche si irezistibila, de regula apare asa ca prin farmec Cluj o ceatza din aer care se i cam pune pe crieri si ochi. Groparului. Pe care-l stiu destul de bine, da\' care inca ma uimeshte la betie. Pe langa faptu\' ca lu\' Groparu i se pare in secunda aia ca e irezistibil de frumos (ca d-aia tot ciupeshte kelneritze de fundulica ca sa le impresioneze, ca odata s-o sh batut cu un badigard pe chestia asta!!! pffuaai, ce blog va iesi cu patzania asta), tot atunci i se pare ca e irezistibil de intelijent. Groparu e arareori suficient de inteligent incat sa nu puie botu\' la tot felu\' de; da\' cand e si oleaca parfumat cu zama ghe pruna (yyeeeeee---haaaaaaaaa!!!) vreau sa zic ca redefineshte normele Parkinson, sindromului Down si idiocratiei congenitale. Finca pune pariuri cu <a href=\"http://www.andreicrivat.ro/\" target=\"_blank\">Andrei Crivatz</a> cum ca nu mai stiu pe ce motiv, da\' numa pe vinuri scumpe. Si a pierde pariuri e o arta despre care pot spune, fara falsa modestie, ca o stapanesc pana la rescriere; eu sfidez insasi arta de a pierde pariuri; sunt chiar un semizeu al pariurilor pierdute (medicu\' de najteri o pus pariu cu mine cand aveam 4 luni ca nu prind 16 ani in deplinatatea facultatilor mintale, si o cam castigat); imi fac chiar o cariera din acest sport, care de alfel nici macar nu s-a reinventat cu adevarat pana sa ma nasc eu.\r\n\r\nMnoa. Si revenind la cum se face banii, pui pariu cu Groparu, da\' numa cand e parfumat bine, pe chestia cum ca Basescu NU o vorbit in duma de sat a Rusiei atunci cand le-o zis muscalilor ca or stat 30 de ani in Romunica si nu le-o zis nime\' niica; inainte de asta, vorbesti cu Basescu sa NU vorbeasca in duma de stat niciodata, da\' sa il zapaceasca pe Groparu suficient de mult incat acesta din urma sa creaza ca de fapt kiar o vorbit in duma de stat; Groparu pierde pariu\' sh e obligat sa cumpere nush ce phuii mei de vin vechi la pretz promotional de numa 150 EUR (cu sau fara TVA? exact!) - dar (asa cred io) de la firma presedintelui. Crivatz apai face jumi-juma cu presedintele, si asfel economia prospera.\r\n\r\nIo amu imi dau seama ca singura sansa sa ma scot e sa fur nevasta Crivatzului cand se insuara amandoo (ba, Crivatze, apropos, nu iti schimbi TU numele dupa casatorie? e numa o idee) si sa cer ca rascumparare - ati ghicit! - aceeasi sticla de vin inapoi, ca sa cer bani e sub demnitatea mea. Si am scos parleala! Dar planu\' asta nu prea are cum reusi, ca deja l-am pus pe blog. Mnoa. Atat.\r\n\r\nPS: N-am scris nimic weekendu\' asta, ca nu am putut ajunge la calc din cauza hainelor murdare de la mine din garsoniera, care blocau accesu\'. Si mi-o fo\' frica sa le rascolesc, ca te miri ce fortze mortale as fi trezit!','Deci cum se face banii',0,'','publish','open','open','','deci-cum-se-face-banii','','','2007-06-11 03:01:14','2007-06-11 01:01:14','',0,'http://www.groparu.ro/?p=473',0,'post','',5),(474,2,'2007-06-11 15:32:03','2007-06-11 13:32:03','Mnoa, bere bauta cu un ficior scotiano-olandezo-spaniolo nu mai stiu cum, ficior fain.\r\n\r\nDiscutie.\r\n\r\nClar - despre politica.\r\n\r\nSi vine vorba ca lumea nu mai mere la vot, nici la alegerile locale, nici la alegerile nationale. Si el se oripileaza cand ii zic io: ceea ce ma nerveaza e ca lumea nu mere nici macar la votu\' la alegerile locale! Si el ma intreaba: da\' care-s cele mai importante, in opinia ta, alea locale, sau alea nationale? Alea locale, zic io, clar!\r\n\r\nDa\' di ce? intreaba el.\r\n\r\nPai sa-ti zic, zic io. Hai sa-ti zic. Finca la mine-n patrie, oricat de tare se kinuie politicienii, economia duduie, investitorii vine. Singurele probleme pe care le am amu, zilele astea, is legate de: transportul in comun, ca nu is destule studente la inghesuiala asta; prafu\' de pe strazi, care intra si-n kiloti; traficul, care mere ca o tzestoasa ne-Ninja; cozile la administratia locala si impozitele care trebe platite.\r\n\r\nMnoa.\r\n\r\nMa doare la basca cine e in spatele carmei patriei mele, ca e marinar beat, Citroen-ist patrician, vacaroi sau f***-escu. Ce conteaza e ca premarele si prefectele sa fie suficienti de <strong>curvi politici</strong> incat sa dea binishor din coditza pe langa impotentatii din Bucale, sa fie <strong>suficient de blanzi incat sa suga</strong> (de la 2 oi) si sa aduca banuti in orash indiferent ce coluare politica doarme in parlament si in guvern, si suficient de gospodari incat sa duca la bun sfarsit planurile de dezvoltare in beneficiul comunitatii.\r\n\r\nAtat! Finca asa se face politica in Romania.\r\n\r\n(= strain oripilat)','Cum am oripilat un strainez',0,'','publish','open','open','','cum-am-oripilat-un-strainez','','','2007-06-11 15:37:54','2007-06-11 13:37:54','',0,'http://www.groparu.ro/?p=474',0,'post','',7),(475,2,'2007-06-12 21:01:39','2007-06-12 19:01:39','Deci.\r\n\r\nHai sa va zic ce se poate Ã®ntÃ¢mpla la conferinÅ£Äƒ.\r\n\r\nIn primu rand, nu conteazÄƒ ce ai mÃ¢ncat cu 2 zile Ã®nainte, sau cat de bine ai mestecat ce ai mancat; nu conteazÄƒ  ce lenjerie de corp ai, cÃ¢te zile ai purtat-o, cat de aproape de sfÃ¢ntul tÄƒu fund s-a lipit kilotu\', cÄƒ e cald sau frig afarÄƒ, ÅŸi nici nimic altceva: cand esti acolo, pe scena, de traduci ce zice te miri ce pseudo-vorbitor de engleza, te mÃ¢ncÄƒ curu\', asta e leje. RÄƒu. Da\' rÄƒu-rÄƒu-rÄƒu! Si nu te poti scarpina, ca esti langa un nene care baga vreo 140.000.000 euroi in orashu\' tau, si daca te scarpini in cur te dÄƒ in judecata, ca incepe presa sa rÃ¢dÄƒ si sÄƒ scrie prÄƒpÄƒstii despre voi doi prin ziare, cum cÄƒ pe traducÄƒtor Ã®l cam doare-n cur de ce zici tu acolo, ÅŸi Ã®i fuÅ£i investiÅ£ia.\r\n\r\nÃŽn al doilea rÃ¢nd, Äƒia de-i traduci ÅŸi stau pe scenÄƒ se flatuleazÄƒ la greu. De emoÅ£ie. Åži tu n-ai Ã®ncotro decÃ¢t sÄƒ respiri. Ca sa scapi, vorbeÅŸti Ã®ntr-o parte a sÄƒlii ÅŸi tragi aer Ã®n piept din altÄƒ parte, mai cu ozon, da\' de respirat (ca orice forma de viatza pe baza de carbon) tre\' sÄƒ respiri, ca n-ai ce face. Si nesimtitu\' care vorbeste langa tine intr-o engleza aproximativa nici mÄƒcar nu clipeÅŸte un \"Sorry, mÄƒ p***!\"\r\n\r\nP-orma - toti oamenii la costum is plini de matreatza pe umeri, si se si vede pe costumele de culoare inchisa, asa ca un zahar se vede, da\' nu e o idee buna sa il scuturi in cafea. Serios. Ca te mai miri ce gust ii mai da.\r\n\r\nSi sa nu uit: aia de n-au matreatza, sau la care nu se vede ca au matreatza is aia cu costume deschise la culoare, pe care ii rog sa ceteasca ce am scris mai devreme cu nunta la Baia Mare, ca se vede picurii de pipi pe pantalonii de culoare deschisa! Puii mei, ma oameni buni, da e chiar asa de greu sa intelegeti? Scuturati-vi-o in palma, sh apai dati noroc cu cel mai antipatic om din firma, decat sa ma impestritati bunatate de pantaloni de la reduceri de la Steilmann, dupa ce-ati beut cerneala, de se vede picurii albastri pe culoarea oului de ratza!\r\n\r\nSi ca sa va zic si voo ce am invatzat tura asta de la o ziarista: daca sunteti serviti mititei fara tacamuri, si vreti musai sa mancati mititeii cu mustar, loati linguritza de la muÅŸtarierÄƒ, Ã®ntindeÅ£i mujtaru peste pkitÄƒ, puneÅ£ peste pkita mititelu\', sh gata! :D Ca io m-as fi boit tat cu mujtar, ca mi-as fi bagat dejtele inauntru si apai in gura, de s-ar fi oripilat toti investitorii aia, asa cum numa Groparu stie a-i oripila!\r\n\r\nUpdate: Uitai sa va zic ca din cauza vremii schimbatoare, Groparu o fost sfatuit sa vie la confe\' cu ceva anti-ploaie; cum umbrela nu folosesc, ca umbrelele atrag ochi de italience, m-am dus cu geaca mea impermeabila CARE INCA MAI PUTZEA A PORCU\' FACUT LA PROTZAP DE TIGANIADA!','Deci Groparu o mÄƒrs la conferinÅ£Äƒ',0,'','publish','open','open','','deci-groparu-o-mars-la-conferinta','','','2007-06-12 23:01:24','2007-06-12 21:01:24','',0,'http://www.groparu.ro/?p=475',0,'post','',0),(476,2,'2007-06-13 11:03:15','2007-06-13 09:03:15','Tag cu care m-o infectat <a href=\"http://oedip.blogspot.com/\" target=\"_blank\">Oedip</a> - da\' nu ala cu ma-sa:\r\n\r\n<strong>1. Ce carte nu ai imprumuta?</strong>\r\nO carte de joc cu femei cu tzatze mari.\r\n<strong> 2. Ce carte nu ai recomanda?\r\n</strong>Mizerabilii - pt unii e prea personala.\r\n<strong>3. Ce carte nu ai cumpara?</strong>\r\n<a href=\"http://en.wikipedia.org/wiki/Coffee_Table_Book_(Seinfeld)\" target=\"_blank\">A coffee table book about coffee tables.</a>\r\n<strong> 4. Ce carte nu ai citi niciodata?</strong>\r\n<a href=\"http://www.amazon.com/Professional-Search-Engine-Optimization-PHP/dp/0470100923/ref=sr_1_14/002-1022451-1424026?ie=UTF8&amp;s=books&amp;qid=1181684768&amp;sr=8-14\"><span class=\"srTitle\"></span></a>Professional Search Engine Optimization with PHP: A Developer\'s Guide to SEO.\r\n<strong> 5. Ce carte nu ai scrie niciodata?</strong>\r\nUna despre agatzat gajici - voi lua secretu\' cu mine in gruapa.\r\n<strong> 6. Care-ar fi prima carte pe care ai da-o, intru citire, copiilor tai?</strong>\r\nBibila povestita copiilor; daca se fac popi, m-am scos, ajung in rai.\r\n<strong> 7. Care a fost cartea copilariei tale?</strong>\r\nSeria Jules Verne, visam numa naufragii pe insule pustii; ulterior insulele s-au populat cu triburi de femei; ulterior am cunoscut femei si am revenit la insule pustii.\r\n<strong> 8. Cartea pe care ai facut-o cadou ultima data, ai citit-o?</strong>\r\nEra una despre sex; ce sa citesc, sa ma nervez numa cat de prost e scrisa?\r\n<strong> 9. Ce carte ti-a marcat felul de a fi?</strong>\r\nSatra :D.\r\n<strong> 10. Ce carte pe care ai citit-o ai lua cu tine pe o insula pustie?</strong>\r\nCand i-am zis lu profu\' de francieza ca as loa Shakespeare - Opere Complete, o zis ca epatez; asa ca as loa cartea \"Cum sa imbogatesti uraniul si sa construiesti rachete balistice  iraniene intr-o insula pustie din arhipelagul Baleare\", editia revizuita si adaugita (dupa aia m-as alia cu Coreea de Nord si i-as santaja deopotriva pe americani si rusi, si pe Sarkozy l-as pune sa se imbete zilnic, hihi!)\r\n<strong>11. Ce carte pe care n-ai citit-o, ai risca sa o iei cu tine pe o insula pustie?</strong>\r\nIn primu\' rand ca acilea o virgula e pusa aiurea. Pas.\r\n<strong> 12.Cum se numeste cartea pe care ai citit-o de cele mai multe ori? De cate ori?</strong>\r\nSeria Sven Hassel (scenele cand mergeau soldatii la bordel), si Legendele Olimpului (scenele cand Zeus prostea pamantence sa se <u><em><strong>CENZURAT</strong></em></u> cu el. Ba Zeus, cat m-ai mai putut tu imita, ba!!!)\r\n<strong> 13. Numeste o carte plictisitoare. De ce?</strong>\r\nOrice carte din facultate scrisa de Thomas Hardy (ba, proasta mai era Tess aia!)\r\n<strong> 14. Numeste-ne o carte pe care ai inceput-o, dar nu ai terminat-o.</strong>\r\nKamasutra. Ma plagiau.\r\n<strong> 15. Povesteste-ne cum cumperi o carte.</strong>\r\nScot banii,... aaa.... stai ca stiam... deci scot banii.... ii numar, vad ca nu-s suficienti, bag cartea in san... bag banii inapoi... ies din librarie... dau banii la biserica sa ma ierte Dumnezeu ca am furat.\r\n<strong> 16. La ce renunti ca sa cumperi o carte?</strong>\r\nCand eram in Danemarca, mi-am loat 2 carti care m-or costat 120 marci amandoo. A doua zi am sunat-o pe sor-mea si i-am plans la telefon ca daca nu trimite bani imi tai venele in cada. Deci - de la o pereche de vene arteriale in sus, catre cot.\r\n<strong> 17. La ce nu renunti ca sa cumperi o carte?</strong>\r\nLa asta chiar nu stiu ce sa raspund.\r\n<strong> 18. Cartile carei edituri iti plac cel mai mult?</strong>\r\nDeci daca editurile vrea sa stie ce ceteshte Groparu, sa ma intrebe direct, ca le <strong><em>vÃ¢nd</em></strong> informatia asta. In mare, cam ce scoate Cotidianu\' pe piata.\r\n<strong>19. Cat timp a trecut de cand nu ti-ai mai cumparat o carte? Cum se numeste acea ultima carte cumparata?</strong>\r\nO saptamana; e cartea de la Cotidianu\', dar nu o voi ceti probabil pana la pensie, asa ca nu stiu cum o kiama, finca nu prea fac io planuri pentru asa perioade lungi de timp, mai ales ca cand ies io la pensie sansele sa ne bucuram de o iarna nucleara atomica efectuata de sera sunt destul de crescute.\r\n<strong>21. Cati tarani au participat la rascoala din o mie noua sute sapte?</strong>\r\nBullshit.\r\n<strong> 22. Care este scriitorul roman preferat?</strong>\r\nCioran, ca da bine sa citezi din el: <em>A-ti iubi aproapele e de neconceput: cui ii cere unui virus sa iubeasca alt virus?</em>\r\n<strong> 23.Care este scriitorul strain preferat?</strong>\r\nKazantzakis. Clar.\r\n<strong> 24. Ecranizarea carei carti ai dori sa o vezi?</strong>\r\nZorba, over and over again.\r\n<strong>25. Numeste o carte a carei ecranizare ti-a placut mai mult decat romanul in sine.</strong>\r\nNu-mi amintesc, oare The Merchant of Venice...? care e teatru, de fapt.\r\n<strong> 26. Numeste o carte buna cu o ecranizare proasta.</strong>\r\nPas.\r\n<strong> 27. Numeste un blogger pe care-l citesti cu placere.</strong>\r\n<a href=\"http://rottencabbage.haipa.ro\" target=\"_blank\">Varza stricata</a>. Ii la mine-n blogroll. Stiu de ce e. <a href=\"http://www.jeg.ro\" target=\"_blank\">JEG</a>. Nu-i la mine-n blogroll. Nush de ce nu e! Si mai e unu, Marius, da\' ala-i pe 360,Â  nu vrea sa <em>go global</em>.\r\n<strong>28. Numeste un blogger pe care ai vrea sa-l cunosti.</strong>\r\nBloggeritza se poate? In sensu\' biblic, se poate?<strong>\r\n29. Ce cantaret/trupa ti-ar placea sa concerteze in Romania?</strong>\r\nAmu ca vin Alice Cooper, Stones si Accept, numa Doro as mai vrea.\r\n<strong> 30. Numeste intrebarea care-ti place cel mai mult.\r\n</strong><em>Dragul meu, cum se face ca de fiecare data e atata de fantastic?</em>\r\n\r\nDau mai departe Tagu\' lu <a href=\"http://baghy.wordpress.com/\" target=\"_blank\">Baghy</a> si lu\' para<a href=\"http://lityx.blogspot.com/\" target=\"_blank\">Litics</a>, si lu <a href=\"http://www.512kbps.com/\" target=\"_blank\">Katmay</a>.','Carte frumoasa, cinste cui te-a plagieat',0,'','publish','open','open','','carte-frumoasa-cinste-cui-te-a-plagieat','','','2007-06-13 11:03:15','2007-06-13 09:03:15','',0,'http://www.groparu.ro/?p=476',0,'post','',4),(477,2,'2007-06-13 11:50:53','2007-06-13 09:50:53','BA, TU VREI SA MA FAC OEDIPUL FAMILIEI TALE???','O injuratura intelectoala, psihanalitica si anacoluta',0,'','publish','open','open','','o-injuratura-intelectoala-psihanalitica-si-anacoluta','','','2007-06-13 11:50:53','2007-06-13 09:50:53','',0,'http://www.groparu.ro/?p=477',0,'post','',6),(478,2,'2007-06-14 00:42:17','2007-06-13 22:42:17','<a href=\"http://www.groparu.ro/wp-content/uploads/2007/06/komodo10.jpg\" title=\"http://www.heptune.com/komodo.html\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/06/komodo10.jpg\" alt=\"http://www.heptune.com/komodo.html\" /></a>\r\n\r\nStiti si voi dragonii de komodo, ca doara d-aia avetz Discovery, ca se da la pachet cu canalu\' alalant, de adulti, cu porneturi; si cand va uitati la porneturi, tot asa salivati si voi, ca dragonu\' ala, si cu la fel de multe bacterii prin scuipat. In fine.\r\n\r\nCica prin anii \'80, tot ce s-o mai descoperit dintr-un turist german care filma reptilele astea simpatice or fo camera foto, o pingea... si cam atata.\r\n\r\nIo sunt sigur ca saraca reptila o capatat o indigestie severa de la carnea aia de neamtz - despre care se stie ca e teribil de indigesta - si mi-e sincer mila de ea, mai ales ca nu avea cum sa serveasca si un colebil sau un coniacutz, sau macar un Danone Activia.','Despre dragonii de Komodo',0,'','publish','open','open','','despre-dragonii-de-komodo','','','2007-06-14 00:54:56','2007-06-13 22:54:56','',0,'http://www.groparu.ro/?p=478',0,'post','',1),(479,2,'2007-06-14 00:54:38','2007-06-13 22:54:38','http://www.heptune.com/komodo.html','http://www.heptune.com/komodo.html',0,'','inherit','open','open','','httpwwwheptunecomkomodohtml','','','2007-06-14 00:54:38','2007-06-13 22:54:38','',478,'http://www.groparu.ro/wp-content/uploads/2007/06/komodo10.jpg',0,'post','image/jpeg',0),(480,1,'2007-06-14 19:44:36','2007-06-14 17:44:36','1. Munceau zi lumina la pashune, in firme de programare, de audit sau in banci, dupa care mergeau in crajme sh se imbetau, ajungeau acasa seara obositi,  sex - din pix =&gt; asa au murit dinozaurii.\r\n\r\n2. Dinozauritzele s-au emancipat, si au incetat sa se epileze, sa poarte sutiene si sa se culce cu shafu\' =&gt; sex din pix =&gt; asa au murit dinozaurii.\r\n\r\n3. Au descoperit autoturismele si au inceput sa conduca pe muzica lui Pepe =&gt; asa au murit dinozaurii.\r\n\r\n4. S-au facut toti absolventi de Litere si au incercat sa scoata radical din 4 =&gt; asa au murit dinozaurii.\r\n\r\n5. Au descoperit transportul in comun inainte sa descopere sapunul =&gt; asa au murit dinozaurii.\r\n\r\n6. Au papat fasole mexicana, s-au flatulat la greu =&gt; efect de sera =&gt; asa au murit dinozaurii.\r\n\r\n7. Au venit peste ei o shleahta de dinozauri mineri sa instaureze democratia =&gt; asa au murit dinozaurii.\r\n\r\n8. Or venit o alta shleahta de dinozauri afaceristi care le-or bagat cianura intr-o Rosia Montana d-aia dinozaureasca de-a lor =&gt; asa au murit dinozaurii.\r\n\r\n9. Or inceput sa manance la Cantina Primariei din Cluj =&gt; asa au murit dinozaurii.\r\n\r\n10. A aparut un meteorit care i-o dat un cap in gura Terrei, si dinozaurii erau Meteo<strong>R</strong>sensibili. Asa au murit dinozaurii.','De ce au murit dinozaurii - 10 teorii',0,'','publish','open','open','','de-ce-au-murit-dinozaurii-10-teorii','','','2007-06-14 19:44:36','2007-06-14 17:44:36','',0,'http://www.groparu.ro/?p=480',0,'post','',8),(481,1,'2007-06-15 13:20:40','2007-06-15 11:20:40','Ii un club in Cluj are canta muzikie laiv in kimnitza sa. De fapt, clubu\' e kiar el cam in pivnitza.\r\n\r\nMnoa, am ajuns acolo dupa ce am mancat salata mea de seara, ca verile numa salatzi bag, si nu puteam fave diarie de la rosii cu smantana si castra\' decat daca strokeam bine cu berule. Apropos, mi-am beut banii cu care trebuia sa merg la Sibiu weekendu\' asta :D\r\n\r\nMnoa, m-am intalnit acolo cu vo doi programeci si Spaic, despre care as scrie foarte multe, da\' se supara ca vorbesc de viatza lui privata, care e o catastrofa (sau nu). Vorba ceea: toata viatza mi-am dorit sa ma f** cu o femeie matura, da\' numa pe la 40 de ani mi s-o implinit visu\', cand o implinit nevasta-mea varsta corespunzatoare!\r\n\r\nMnoa, ideia e ca am vast o sumedenie de artisti pe care nu-i stiam, ca io ascult decat manele de la Twisted Sister si Halloween. Da\' l-am vast laiv pe Gyuri Pascu Ionel, care singura diferentza dintre el si mine este ca amandoi suntem uratzi ca dreq, da\' el e simpatic, pe cand io cam nu, ca asha mi-or zis toate, ca d-aia s-or f**** cu mine, ca or crezut ca is simpatic, da\' era numa marketing si ele era prea bete ca sa-si dea seama.\r\n\r\nNoi stateam in spatele la o tipesa in maieutz, care avea un neg uriash pe spate, si langa neg avea si un cosh d-ala albicios.\r\n\r\nLa un moment dat m-am urcat pe scena si eu, cÄƒ ce? Aia sa cÃ¢nte fain si io nu? Si am cÃ¢ntat, da\' deloc fain. Pentru chestia asta io si acuma dau vina pe maica-mea, ca nu mi-o bagat in trupu-mi de adolescent suedez niscai gene de Columbean sau macar de Ileana Sararoiu. Si pe scena i-am mintit ca scriu mai bine decat cant, si i-am indrumat catre www.groparu.ro. Azi traficu\' mi s-o dublat: au intrat 4 persoane pe sait.\r\n\r\nAsaaa... oare ce s-o mai petrecut in seara aia...? Hmmm... A dreq cum sugruma ea berea amintirile!\r\n\r\nA, da mi-am amintit ceva: daca cautati pe youtub \"varu  on fire\" il gasitz pe unu\' cu care am beut asar\'.','Deci Groparu o fost la seara de cantecaci',0,'','publish','open','open','','deci-groparu-o-fost-la-seara-de-cantecaci','','','2007-06-15 13:37:27','2007-06-15 11:37:27','',0,'http://www.groparu.ro/?p=481',0,'post','',5),(482,1,'2007-06-15 13:39:07','2007-06-15 11:39:07','Deci finca tot am inceput sa ma bat pe burta cu <a href=\"http://oedip.blogspot.com/\" target=\"_blank\">Oedip</a> (nu ala cu ma-sa), vreau sa se stie ca Oedip nu e motherfucker, e \'notherfucker. Punct.','Totul despre Oedip si despre sex',0,'','publish','open','open','','totul-despre-oedip-si-despre-sex','','','2007-06-15 13:39:07','2007-06-15 11:39:07','',0,'http://www.groparu.ro/?p=482',0,'post','',3),(483,1,'2007-06-15 14:42:41','2007-06-15 12:42:41','Groparu: (oftÃ¢nd) BÄƒ, ce fain o fost la Å¢iganiadÄƒ!\r\nNÃ¢rÅ£oagÄƒ: De unde ÅŸtii?\r\n\r\n(asta e o insinuare murdarÄƒ cum cÄƒ io aÅŸ fi fost in transÄƒ coniacalÄƒ pe parcursul desfÄƒÅŸurÄƒrii evenimentelor)\r\n\r\nGroparu: Mi-am citit blogu\', d-aia stiu.','DiscuÅ£ie cu NÃ¢rÅ£oagÄƒ',0,'','publish','open','open','','discutie-cu-nartoaga','','','2007-06-15 14:42:41','2007-06-15 12:42:41','',0,'http://www.groparu.ro/?p=483',0,'post','',3),(484,1,'2007-06-18 01:34:24','2007-06-17 23:34:24','Alt copkil cumsecade (aluzie suptila la <a href=\"http://rottencabbage.haipa.ro/\" target=\"_blank\">varza</a>) pleaca din tzara; el nu stie ca presedinte nu mai e Iliescu de vreo 3 ani.\r\n\r\nDeci ba Lapu\', fii antena la mine-aci, ca io am tot umblat prin lume, si am vazut pana si Bucurestiu\':\r\n\r\n1. Aia is tot oameni, ma, ca sh noi, ma. Serios, pe bune. Sh lor le place femeile cu tzatze mari, fetele de 15 ani cu pielea neviolata de celulita sh sh ei viseaza la sex in trei, daca se poate a treia sa fie kinezoaica. Sau macar sashie.\r\n\r\n2. Vezi ca aia conduc pe stanga. Pe cealalta stanga decat dreapta noastra.\r\n\r\n3. Vezi ca aia, ca orice alt popor de pe lumea asta, le cam beau. Sa nu primesti de la careva daru\' betiei. Ajunge un gropar pe lumea asta.\r\n\r\n4. Vezi ca acolo, spre deosebire de Romunica, nu prea e cool sa ii dai in gura la nevasta-ta cand vii acas\' bat, cantand  \"shade calul lui Gheorghitza, priponit de-o garofitza\", sh ea da din gura ca mai bine se marita cu electricianu\'.\r\n\r\n5. Acolo nu poti loa tzapa ca iti vand aia miel de Pasti care inainte de a deveni miel latra, statea in lantz sh il kema Rocky sau Nero.\r\n\r\n6. Australia nu e o tzara in care sa faci misto de regina Angliei si sa zici despre ea ca daca poarta pantaloni nu iti dai seama daca e barbat sau femeie.\r\n\r\n7. Daca te opreste Garcea de la canguri sh ai beut la volan, mai bine iei buchetelu\' de dolarei, il mesteci bine sh in inghiti (fara sare) decat sa freci bancnotele una de alta, sÄƒ Ã®i zÃ¢mbeÅŸti  sh sa zici ca la o curvÄƒ \"OfisÄƒr, cudÃ¢nt ui cat sam sort Äƒf Äƒ dil?\" Da, stiu, tzara  aia mai are pÃ¢nÄƒ sÄƒ ajungÄƒ la nivelu ala de civilizaÅ£ie Ã®n care cu o jpagÄƒ te vindeci de boale, Ã®l Ã®nscrii p-Äƒla micu la orice ÅŸcoalÄƒ vrei ÅŸi o ÅŸtergi Ã®n Siria dupÄƒ ce ai incercat sÄƒ rÄƒpeÅŸti 3 ziariÅŸti ÅŸi sÄƒ-i vinzi Ã®napoi patriei mumÄƒ.\r\n\r\n8. In locu tau, nu as prea face scuba diving acolo unde o cam dat coltzu Steve Irwin. Stii?\r\n\r\n9. Sa stii ca nu e adevarat ca daca Australia e de cealalta parte a planetei, australienii umbla cu capu in jos.\r\n\r\n10. Vezi ca aia cica s-ar putea ca Australia sa ramaie fara apa in viitorul indepartat; ca sa le salvezi rezervele, bea bere! Un sfat dat cu caldura.\r\n\r\n11. Aia, saracii, n-au rechini decat in ocean, nu-n taximetre.\r\n\r\n12. Cand cobori la aeroport, sa nu intrebi vameshu daca aia e Anglia, desi le seamana steagurile.\r\n\r\n13. Desi si moneda lor nationala se cheama tot dolar, sa nu ii intrebi de ce nu e fatza lu Washington pe nici o bancnota.\r\n\r\nAceasta postare nu are nici o legatura cu persoane ireale.','Vrea sa pleaca in Australia',0,'','publish','open','open','','vrea-sa-pleaca-in-australia','','','2007-06-18 01:42:16','2007-06-17 23:42:16','',0,'http://www.groparu.ro/?p=484',0,'post','',2),(485,1,'2007-06-19 11:36:51','2007-06-19 09:36:51','Deci.\r\n\r\n1. Ieri, luni dimineatza, cand meream sh io la munca beat de soare si parlit ingrozitor, ma inghesui in al doilea autobuz care venea, ca primu\' troleu era ca o conserva de ton, d-aia de iti da botulism, de inghesuit ce era.\r\n\r\nSi in autobuz, clar, plin de lume. Si in fatza mea, o tanti oleaca mai tiganoasa, la vreo 40 de ani, statea in picioare in bratele lu barba-su, la fel de tiganos. Noa, ma uit la ei, ei se uita la mine, zice capu\' meu in mintea mea cum dreq stau oamenii astia  imbratisati, cu pieile lor transpirate lipite intim intr-un autobuz care inhiba  orice  pornire sexuala! Ce iubireeee, mai tata... si la varsta lor...\r\n\r\nSi uimirea mea surprinsa o durat pana doamna s-o cam prabusit. Lesinata. Ba, da\' lesinata-lesinata! S-o intins precum o baligutza pe podeaua autobuzului, fara macar sa cracneasca. Palmi, scos afara la aer, inerta, mai tata, ca un hering afumat!!!\r\n\r\n2. Azi-dimineatza, scot beletu\' (nu mai am bani de abonament de ceva vreme) si il dezvirginez. Si la urmatoarea statie, urca ratucii, controlorii. Si ca de obicei, pana sa se des... de...conspire, asa, le intind, cu zambetul meu tamp, beletul sa-l verifice. Ala mai manelist dintre ei se uita la moaca mea, i se pare ca ma cunoaste, si zice \"Nu, nu inca\". Si io stau cu beletu intins pana imi oboseste mana. Si apai el ma intreaba:\r\n\r\n- Ce faci?\r\n\r\nCe pola era sa-i zic?\r\n\r\n- Bine, zic, ma duc la munca.\r\n\r\nSe lasa o tacere stanjenitoare pe care o asasinez plin de tact.\r\n\r\n- Tu?\r\n- La munca, zice el. La munca.\r\n- Najpa, zic eu, sh pana sa invadeze iar tacerea bunatate de conversatie, continuu:\r\n- Nu vi-i greu? Pe caldura asta?\r\n- E! zice el. Astept concediu.\r\n- Super, zic euÂ  (chiar era super).\r\n- Da, zice el. Am 2 LUNI DE CONCEDIU IN FIECARE AN.\r\n\r\nDeci in secunda urmatoare gandurile mi-au fost sugrumate de o reverie obraznica. Mai, taticule, 2 luni de conceeediu??? Ba, da\' 2 luni???? 2 luni. Hmmm. 2 luni. Iertare, nu ma mai prea pot gandi la al\'ceva. 2 luni. 2 LUNI, MAH!!!! 2 LUNI DE CONCEDIU ANUAL.\r\n\r\nNij nu stiu ce concluzie sa trag, asa ca incerc sa ma abtin, si reusesc.','Ratuc lovejte din nou, dublu impact',0,'','publish','open','open','','ratuc-lovejte-din-nou-dublu-impact','','','2007-06-19 11:36:51','2007-06-19 09:36:51','',0,'http://www.groparu.ro/?p=485',0,'post','',14),(486,1,'2007-06-19 22:00:40','2007-06-19 20:00:40','Deci, ca orice om cu veleitatzi geniale, am sh io o slabiciune, un par pe care mi-l taie Dalila mea ca sa-l deie la dujmani. Ahile avusa calcaiu\'; <a href=\"http://old.jeg.stuffo.info/main.php\" target=\"_blank\">Jeg</a> - onoratul testicul; eu - desi am trecut de varsta la care ma pisham in ghivecele din clasa - darul de a ma injura la CounterStrike cu tot felu\' de pustani de varsta mea, da\' la jumate sh chiar la o treime.\r\n\r\nEi bine si, intr-una din zile, unul dintre onor copkiii care se counterstrikeaza impotriva Groparului o zis ceva rau de maica-mea, care de fapt i-o doamna, sh anume ca ar cam vrea sa ii arate ei cat de barbat este. Sa va reproduc dialogul:\r\n\r\n- Sa-mi bag p*** in ma-ta, Gropare!\r\n- Sughi-bughi, i-am zis io, pe maica-mea sh pe maica-ta le fute taica-meu!!!','Ce am invatzat bun din CounterStrike',0,'','publish','open','open','','ce-am-invatzat-bun-din-counterstrike','','','2007-06-19 22:18:54','2007-06-19 20:18:54','',0,'http://www.groparu.ro/?p=486',0,'post','',7),(487,1,'2007-06-20 11:02:52','2007-06-20 09:02:52','Sanda nu e fosta mea vecina putin grasutza cu care dansam blues-uri la 16 ani la chefuri cate 4 ore, sh in camera era intuneric, si se uita frati-su la mine cu lasere in ochi; nu, sanda e singularul incaltarilor legionarilor romani, si eu, care ma cred roman (din cauza ca visez mereu la orgii de palat), port sandale vara, uneori fara ciorapi.\r\n\r\nMnoa, sandala atrage atrag pietricele; pietricelele astea se furiseaza ca un sherpe intre picior si sanda, si nu mai poti sa mergi decat  schiopatand. Si atunci femeile nu se mai uita la tine pe strada cu admiratie, ci cu mila - si, dupa cum stim unii dintre noi, femeile nu fac niciodata amor cu barbatii din mila, ca io am incercat sa speculez si calea asta, da\', ca si altele, nu o prea mers (odata i-am oferit la o tanti noaptea pe Calea Turzii 200 EUR, si o zis ca prefera un sofer de TIR nespalat, pentru 30 lei).\r\n\r\nMnoa, si mergand io ieri spre casa, nush cum se face ca agatz o pietricica in sandala, de la lucrarile care se efectueaza pe Eroilor. Si schiopatez io asa o vreme (uitasem de faza cu gajicile, sexu\' si mila, si ma asteptam sa vina trei femei la mine sa-mi zica \"Saraaacuuu, uite-l cum schiopata! Du-ne la tine acasa, iti vom gati, te vom spala si te vom iubi\", lucru ce nu s-a materializat, da\' am pastrat ideea); si de la un moment dat nu mai suport, si incep sa zvacnesc din picior cu furie, sa iasa pietriceaua. Si zvacnesc ca un mustang potcovit prima data, si, mai tata, zboara pietricica aia mah dintre picior si sandala cu o viteza si velocitate furioasa, si zboara drept catre decolteu\' generos a lu\' o gajica care venea pe drum din sens opus! Si a dreq pietricica, mah, o loveste pe domnisoara in piept, mah, si se strecoara (la fel as fi ales si eu) ATZA-N DECOLTEU\' EI MAH!!!\r\n\r\nDe fapt, nu o lovit-o, si nici nu o cazut in decolteu, da ar fi fost fain ca ceva care mi-ar fi apartinut mie pe drept sa ajunga acolo.','Pietricica din Sanda',0,'','publish','open','open','','pietricica-din-sanda','','','2007-06-20 11:02:52','2007-06-20 09:02:52','',0,'http://www.groparu.ro/?p=487',0,'post','',3),(488,1,'2007-06-20 15:09:57','2007-06-20 13:09:57','Cine il stie, il stie, cine nu-l stie, nu-l stie! Da\' are ce kerde.\r\n\r\nGreuceanu e membru de baza al Tiganiadei. Am cautat o poza in care sa nu aibe paharel in mana, da\' n-am gasit. Asta e.\r\n\r\nAsta e fiica-sa, care e o scumpete:\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/06/micutza-lu-flaviu-cu-tiganca.JPG\" title=\"www.groparu.ro blog romanesc romanian blog tiganiada greuceanu tigani rrom\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/06/micutza-lu-flaviu-cu-tiganca.JPG\" alt=\"www.groparu.ro blog romanesc romanian blog tiganiada greuceanu tigani rrom\" height=\"332\" width=\"437\" /></a>\r\n\r\nSi asta e injuratura cu care-l potolesc io pe el:\r\n\r\nNU MA MAI INERVA, CA MA INSOR CU FIICA-TA DACA NU!!!','Cum se potoleste un Greucean',0,'','publish','open','open','','cum-se-potoleste-un-greucean','','','2007-06-20 15:19:19','2007-06-20 13:19:19','',0,'http://www.groparu.ro/?p=488',0,'post','',5),(489,1,'2007-06-20 15:06:28','2007-06-20 13:06:28','www.groparu.ro blog romanesc romanian blog tiganiada greuceanu tigani rrom','www.groparu.ro blog romanesc romanian blog tiganiada greuceanu tigani rrom',0,'','inherit','open','open','','wwwgroparuro-blog-romanesc-romanian-blog-tiganiada-greuceanu-tigani-rrom','','','2007-06-20 15:06:28','2007-06-20 13:06:28','',-1182343699,'http://www.groparu.ro/wp-content/uploads/2007/06/wwwgroparuro-blog-romanesc-romanian-blog-tiganiada-greuceanu-tigani-rrom.jpg',0,'post','image/jpeg',0),(490,1,'2007-06-20 15:08:26','2007-06-20 13:08:26','www.groparu.ro blog romanesc romanian blog tiganiada greuceanu tigani rrom','www.groparu.ro blog romanesc romanian blog tiganiada greuceanu tigani rrom',0,'','inherit','open','open','','wwwgroparuro-blog-romanesc-romanian-blog-tiganiada-greuceanu-tigani-rrom-2','','','2007-06-20 15:08:26','2007-06-20 13:08:26','',-1182343699,'http://www.groparu.ro/wp-content/uploads/2007/06/micutza-lu-flaviu-cu-tiganca.JPG',0,'post','image/jpeg',0),(494,1,'2007-06-21 11:10:05','2007-06-21 09:10:05','Finca io deja ar cam fi trebuit de vreo 9 (!) luni sa imi schimb onor buletinu\', m-am hotarat sa cedez ispitelor: da, il voi schimba.\r\n\r\nDar nu vreau ca lucrurile sa fie intr-atata de simple. Vreau sa merg la pozat dupa o noapte de beut la greu. Si a doua zi sa imi astup focu\' din vintre band o juma de kil de American Cola, cea mai contra-indicata beutura de beut dupa ce ai beut. Si sa ma si duc usor nebarbierit. Si sa si fac o moaca d-aia de alcolist iremediabil, muncitor disponibilizat care bea prin parcuri pana dimineatza, sh apai imbraca pufoaica si mere, cu pleoapele abea ridicate, si cade prin tramvai la prima frana.\r\n\r\nAstfel, pentru a putea arata ca in buletin si pentru a nu avea probleme cu Politia (\"ne pare rau, al cui e buletinu\'? ca nu semanati deloc!!! va rog sa ne urmati la sectie\"), va trebui sa beau non-stop.\r\n\r\nCeea ce inseamna ca raiul poate fi atins si aici, pe Pamant.','M-am hotarat sa-mi schimb buletinul',0,'','publish','open','open','','m-am-hotarat-sa-mi-schimb-buletinul','','','2007-06-21 11:10:05','2007-06-21 09:10:05','',0,'http://www.groparu.ro/?p=494',0,'post','',2),(491,1,'2007-06-20 15:13:20','2007-06-20 13:13:20','www.groparu.ro blog romanesc romanian blog tiganiada greuceanu tigani rrom','www.groparu.ro blog romanesc romanian blog tiganiada greuceanu tigani rrom',0,'','inherit','open','open','','wwwgroparuro-blog-romanesc-romanian-blog-tiganiada-greuceanu-tigani-rrom-2','','','2007-06-20 15:13:20','2007-06-20 13:13:20','',488,'http://www.groparu.ro/wp-content/uploads/2007/06/wwwgroparuro-blog-romanesc-romanian-blog-tiganiada-greuceanu-tigani-rrom.jpg',0,'post','image/jpeg',0),(492,1,'2007-06-20 15:14:58','2007-06-20 13:14:58','www.groparu.ro blog romanesc romanian blog tiganiada greuceanu tigani rrom','www.groparu.ro blog romanesc romanian blog tiganiada greuceanu tigani rrom',0,'','inherit','open','open','','wwwgroparuro-blog-romanesc-romanian-blog-tiganiada-greuceanu-tigani-rrom-3','','','2007-06-20 15:14:58','2007-06-20 13:14:58','',488,'http://www.groparu.ro/wp-content/uploads/2007/06/wwwgroparuro-blog-romanesc-romanian-blog-tiganiada-greuceanu-tigani-rrom.jpg',0,'post','image/jpeg',0),(493,1,'2007-06-20 15:17:46','2007-06-20 13:17:46','www.groparu.ro blog romanesc romanian blog tiganiada greuceanu tigani rrom','www.groparu.ro blog romanesc romanian blog tiganiada greuceanu tigani rrom',0,'','inherit','open','open','','wwwgroparuro-blog-romanesc-romanian-blog-tiganiada-greuceanu-tigani-rrom-4','','','2007-06-20 15:17:46','2007-06-20 13:17:46','',488,'http://www.groparu.ro/wp-content/uploads/2007/06/wwwgroparuro-blog-romanesc-romanian-blog-tiganiada-greuceanu-tigani-rrom.jpg',0,'post','image/jpeg',0),(496,2,'2007-06-21 14:11:26','2007-06-21 12:11:26','<p class=\"entry\">- nu am lipit plintele la parchet\r\n- colacuâ€™ de la buda e mereu sus\r\n- nu suntem in stare sa spalam o furculitza\r\n- nu am vopsit usa de la balcon\r\n- nu dam cu aspiratoruâ€™\r\n- nu am pus perdelutzele in balcon\r\n- nu am dezghetat frigideruâ€™\r\n- nu am spalat in viatza vietzii noastre cada\r\n- nu am sters oglinda din buda\r\n- nu am spalat buda cu Domestos\r\n- nu am spalat geamurile de la camera\r\n- nu le cumparam flori destul de des\r\n- nu aruncam branza aia din frigider odata\r\n- nu spalam lenjeria de pat\r\n- intram incaltat in casa si nu maturam dupa aia\r\n- nu facem ordine in kimnitza\r\n- nu spalam in fatza usii de la intrare, pe coridor\r\n- nu spalam preshuâ€™ de la intrare\r\n\r\nLa toate astea, dragi masculi, va invit sa raspundeti:\r\n\r\nDragele noastre, DAR VOI CREDETZ CA <strong>NAPOLEON</strong> ISI FACEA EL SINGUR CIZMELE CU CREMA???','Ce li se reproseaza masculilor',0,'','publish','open','open','','ce-li-se-reproseaza-masculilor','','','2007-06-21 14:11:26','2007-06-21 12:11:26','',0,'http://www.groparu.ro/?p=496',0,'post','',13),(497,1,'2007-06-22 11:04:56','2007-06-22 09:04:56','Deci maine, Groparu mere la o nunta exxxotica, dintre o fosta colega de facultate si un japonez.\r\n\r\nSi finca io la nunti nu ma prea plictisesc, maine am de gand sa fac ceva ce nu s-o prea mai prea facut pe plaiuri mioritice: in loc sa fur mireasa, voi fura japonezu\'. Asa. Si voi si face 1.000 de poze la toti japonejii care fac poze.\r\n\r\nSi pun pariu ca pana maine imi mai vin tot felu\' de idei despre cum sa ma rÃ¢d la nunta.','Maine fur japonezu\'',0,'','publish','open','open','','maine-fur-japonezu','','','2007-06-22 11:04:56','2007-06-22 09:04:56','',0,'http://www.groparu.ro/?p=497',0,'post','',7),(498,1,'2007-06-22 15:39:52','2007-06-22 13:39:52','S-a demonstrat stiintific: abonatii Orange traieste mai mult finca la ei timpul se expandeaza. De exemplu, luna iunie are mai multe zile decat are orice alta luna de iunie pentru alti abonati, cum ar fi de exemplu abonatii Vodafon.\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/06/orange.GIF\" title=\"orange.GIF\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/06/orange.thumbnail.GIF\" alt=\"orange.GIF\" /></a>\r\n\r\nVia <a href=\"http://blog.pacurar.net/\" target=\"_blank\">Shafu\'</a>.\r\n\r\nPS: Oare ash putea sa imi platesc factura pe luna asta in 32 decembrie? Oare cand vine moartea sa ma ia, nu o trimiteti sa vina pe 30 februarie? As putea oare sa ma imbat, sh sa-mi fie rau pe 0 (zero) aprilie?','Abonatii Orange traieste mai mult',0,'','publish','open','open','','abonatii-orange-traieste-mai-mult','','','2007-06-22 15:43:28','2007-06-22 13:43:28','',0,'http://www.groparu.ro/?p=498',0,'post','',2),(499,1,'2007-06-22 15:38:48','2007-06-22 13:38:48','','orange.GIF',0,'','inherit','open','open','','orangegif','','','2007-06-22 15:38:48','2007-06-22 13:38:48','',-1182519370,'http://www.groparu.ro/wp-content/uploads/2007/06/orange.GIF',0,'post','image/gif',0),(500,2,'2007-06-22 15:49:17','2007-06-22 13:49:17','Ma duc la tigare, sh ma intalnesc cu contabila. Si zice: vaaai, domnu\' Groparu, nici nu se vede ca ati chefuit aseara! (aseara am avut kef cu firma, sh m-am cam makit).\r\n\r\nFeresc cearcanele, baigui ceva din spatele ochilor mei tulburi cum ca am antrenament, si ca fac asta frecvent, si ca e OK amu ca am apucat sa dorm 2 ore az-noapte, ca de regula ma sui la birou direct din birt.\r\n\r\nDupa care ma duc catranit la calc, sh dau mass in toata firma: DRAGI COLEGI, INCETATI SA MAI IMPRASTIATI ADEVARURI DESPRE MINE PRIN TOATA FIRMA!!!','Despre cat se vorbeste in firma despre mine',0,'','publish','open','open','','despre-cat-se-vorbeste-in-firma-despre-mine','','','2007-06-22 15:49:17','2007-06-22 13:49:17','',0,'http://www.groparu.ro/?p=500',0,'post','',1),(505,1,'2007-06-29 14:45:39','2007-06-29 12:45:39','Io plec in concediu finca am avut o saptamana in care am tradus texte care suna cam asa:\r\n\r\n<em><span style=\"font-size: 11pt\">Corp octogonal articulat de trei brÃ¢uri formate din ÅŸiruri de motive trilobate ÅŸi crinuri decupate, </span><span style=\"font-size: 11pt\">iar pe corpul cÄƒnii apar trei herme</span><span style=\"font-size: 11pt\">. Corpul se sprijinÄƒ pe picioare de leu dispuse pe sfere. </span><span style=\"font-size: 11pt\">Talpa este decoratÄƒ cu motive traforate de crinuri alternate cu cvadrilobi. </span><span style=\"font-size: 11pt\">Partea superioarÄƒ prezintÄƒ un cap de putti Ã®naripat, </span><span style=\"font-size: 11pt\">avÃ¢nd toarta decoratÄƒ cu volute ÅŸi un ÅŸir de astragal.</span></em>\r\n\r\nDesi nu se prea compara cu <a href=\"http://www.groparu.ro/?p=97\" target=\"_blank\">asta</a>, traducerea asta nu fu singulara; finca am mai avut si\r\n\r\n<em><span style=\"font-size: 11pt; font-family: Arial\" lang=\"IT\">La ora actualÄƒ nu existÄƒ biomarkeri serici, tisulari sau din sucul pancreatic<span> </span>specifici, predictivi ÅŸi prognostici, pentru cancerul de pancreas. De aceea, detectarea cantitativÄƒ proteomicÄƒ din Å£esuturile pancreatice a intrat Ã®n sfera de interes a cercetÄƒtorilor, mai ales </span><span style=\"font-size: 11pt; font-family: Arial\" lang=\"IT\">materialul citologic obÅ£inut din puncÅ£ia fin aspirativÄƒ pancreaticÄƒ preoperatorie. </span><span style=\"font-size: 11pt; font-family: Arial\" lang=\"IT\">SuprafaÅ£a urmeazÄƒ un tratament care sÄƒ faciliteze ionizarea proteicÄƒ, este supusÄƒ energiei unui laser care separÄƒ <span>Â </span>proteinele, identificate apoi prin spectrometrie de masÄƒ<span>Â  </span>Ã®n timp de zbor, rezultÃ¢nd proteinograma. Investigarea pacienÅ£ilor ÅŸi recoltarea de mostre tisulare seÂ  va face prin ecoendoscopie - tehnicÄƒ imagisticÄƒ convenÅ£ionalÄƒ consideratÄƒ cu cea mai mare acurateÅ£e la ora actualÄƒ ÅŸi care este de 4 ani folositÄƒ Ã®n arsenalul diagnostic din Romania.</span></em><span style=\"font-size: 11pt; font-family: Arial\" lang=\"IT\">  </span>\r\n\r\nAti inteles acuma de ce?\r\n\r\nPa. Ne vedem in maximum 2 saptamani, asta numa in cazu in care nu gasasc ceva niet prin Coztineshti, pe unde umblu sa-mi caut tineretea pierduta, si ma ia pofta sa scriu cu o mana si sa beau berule cu cealalta. Sa fiti iupitzi!','De ce plec in concediu',0,'','publish','open','open','','de-ce-plec-in-concediu','','\nhttp://www.groparu.ro/?p=97','2007-06-29 14:45:39','2007-06-29 12:45:39','',0,'http://www.groparu.ro/?p=505',0,'post','',12),(502,2,'2007-06-25 13:56:43','2007-06-25 11:56:43','Finca un intelect cu IQ din trei cifre (ale carui prime cifre is 00 - zero-zero) trebuie oprit cu orice pretz din ascensiunea lui de catre forte malefice unguresti, rusesti si nemtesti care vor raul patriei mele, Groparu o reusit sa se raceasca ca tantalau sambata noaptea, asa ca saitu\' asta va cam intra in gruapa o vreme, pana reusesc sa stau iara pe scaun la calc fara sa cad in cap.','Groparu s-o cam racit',0,'','publish','open','open','','groparu-s-o-cam-racit','','','2007-06-25 13:56:43','2007-06-25 11:56:43','',0,'http://www.groparu.ro/?p=502',0,'post','',13),(503,2,'2007-06-27 02:10:44','2007-06-27 00:10:44','Multumesc celor 8 mesaje coplesitor de incurajatoare de la postul precedent (eu stiu ca de fapt e una si aceeasi persoana care si-a asumat 8 identitati diferite, finca io nu am 8 vizitatori pe sait nici daca intru eu de 8 ori in aceeasi sapamana), si la ora asta nu am decat asta de zis, dupa 2 zile de stat cu batistele la nas, finca curge mucii, si asteptat in caldura sufocanta ca un shtreang, ca stau la etaju\' IV,  deasupra caruia nu face gajici plaja topless, ca daca facea ma vindecam mai repede, ca poate daca faceau, ma rugam de ele sa imi deie neshte anticorpi din aia de mama de la sanii lor, ca chiar daca nu are inca bebe fetele, bebele o sa vina, si anticorpii poate e in sanii lor deja inainte de a naste, si eram fericit incercand sa-mi inghesui sfarce de domnisoara printre buze in scop terapeutic, in loc sa bag nush ce medicamente cu futocinilon in coada, de m-o costat o groaza de bani, ca mai bine faceam o cura de maltz sh hamei distilat in apa pura, ca daca ma imbatam tot cu gura la sfarcuri ajungeam, da\' oricum nu-i stress, ca peste 3 zile plec in concediu la mare, la romani, ca trebe sa fiu furat de banii mei castigati numa io stiu cum, si acolo macar partea buna e ca e plin de studente care isi dezvaluie chestiile alea care li se balangane cand alearga pe plaje, stiti voi, chestiile alea ca pana si homosexualilor le place de ele si si le implanteaza cand isi descopera noa lor vocatie; si mie atata imi plac chestiile alea inspicate cu sfarcuri (ca frumoase felinare ale unui far de noapte) ca mai ca eram sa-l rog pe doftor, care e mascul, sa-mi dea voie sa ii pipai sora medicala la piept, da\' m-am abtinut la timp, finca daca i se scoala la tanti sa imi faca o clizma ca sa ma vindece de <strong>tzÃ¢tzobsesie</strong>? Doamne, daca ti-as cere de ziua mea o pereche de sÃ¢ni sÄƒ mÄƒ aÅŸtepte zilnic seara acasÄƒ, ce-a fi?\r\n\r\nDeci io numa atata am de zis: Baaa, neagra poa\' sa mai fie apa asta dupa ce ma spal io pe fatza cu ea!','Transmisie laiv din (d)raceala',0,'','publish','open','open','','transmisie-laiv-din-draceala','','','2007-06-27 02:20:14','2007-06-27 00:20:14','',0,'http://www.groparu.ro/?p=503',0,'post','',19),(504,1,'2007-06-28 15:36:02','2007-06-28 13:36:02','Finca is gropar nemernic, orice s-ar zice, nu am reusit sa descarc nici o poza de la nunta cu ficiorul din tzara soarelui rasare, desi preumblandu-ma pe langa parcul de langa restaurant in timp ce gajica-mea imi (in)jura iubire vejnica, am dat de un soricel mort, mic, sexy si neingropat, la care i-am si facut poza; arÄƒta ceva mai bine ca mine, o sa apara imediat, poate chiar azi pe blog.\r\n\r\nMnoa, io m-am kinuit sa ma gandesc cum sa le stric la oameni nunta multiculturala Manashtur-Osaka; si pe langa ca mi-am loat un ciorap de un fel si unu de alt fel, da\' nu s-o prins nimeni, cea mai buna ideie pe care o am avut-o o fost sa ii zic lu giapaniz guy \"there is a tradition in Romania, that before the first dance, <strong>the groom must bite hard on the bride\'s ass, until she screams! it is said to be good omen for the future children</strong>!!!!!\" Da\' chinezu\' - sau japonezu\', in fine - zice \"I... don\'t... understand... Engrish!\"\r\nPisda mane-sa de treaba, m-am suparat io; plus ca in afara de el, nimeni - da nimeni! nici macar o jumate de giapaniz - nu mai era cu ochii mijiti, ca venise singur, dupa cum mi-a spus chiar el:\r\n\r\n<strong>Groparu</strong>: Konichiwa, Shin san, anatano cici to haha wo dondesuka?\r\n<strong>Shin</strong>: Oooh, they wel too ord to com hir.\r\n<strong>Groparu</strong>: So desuka!\r\n\r\n(Traducere liberala dupa japoneza facuta de mine in facultate - asa-i ca is un tip ordinar? sau extraordinar? -: salut, ba kim ir sen, unde-i mami shi tati tau din Coreea? la care zice confucius in engleza: is prea batrani sa mai vie pana acilea. Ca fac o paranteza, nenea are vreo 40 de ani, sh arata de 22; io am mult mai putin, si arat ca taticul lui Irinel Columbeanu. Si i-am raspuns cu o chestie care inseamna nu mai stiu ce, da\' cica asa se inkeie o discutie pre limba lor)\r\n\r\nMnoa; am ajuns acolo in <em>cursa</em> de Gilau, cursa d-aia, cum zice neamtzu, <em>das Original</em>, adeca autobuz mai batran ca mine un pic, deci putea fi cu succes bunicul lui Irinel; sh am stat in spatele unei tanti cu coc si cu sclipici in par. Si ajunsi acolo, tot din experientzele mele multiculturale, dar nesexuale, mi-am amintit ca cand eram in Danemarca, am mers cu Iki Wakabayashi la consulatu\' Japoniei, ca era ziua Japoniei si dadeau biscuiti gratis, sa vedem un film; si cand am vazut ca imparatul da si bere gratis de ziua tarii lui care-o borbandat Pearl Harbor, ne-am napustit la sticloantze, am desfacut doapele cu dintii, si am dat cioc:\r\n\r\n- Noroc, zice Groparu, insetat ca-ntotdeauna, si dornic ca-ntotdeauna sa termine odata cu ciocnitu\', sa poa\' sa beie;\r\n- Nazdarovie, zice rusu, nu mai putin ahtiat sa bage aer in sticla.\r\n- Cin cin, zice italieanu\', plescaindu-si saliva de anticipatie, de ne-o si improscat un pic.\r\n- Nooooo!!! Zice Iki, care era cam japonez, si am si crezut ca se apoplexeaza. You mustn\'t say that!!!!!\r\n\r\nGhiciti ce am intrebat?\r\n\r\n- Why???\r\n- Because... sta un pic Iki... Cin means a veeery baaad thing  in... giapaniz!\r\n\r\nGhiciti ce am intrebat?\r\n\r\n- What???\r\n- Err... it means... what men have.. and women don\'t!\r\n\r\nGhiciti ce am intrebat, ca un porc sovin, sexist si xenofob care stie ca rolu\' femeii e la oale, cratitzi, bucatarii si supt barbat?\r\n\r\n- What,... BRAINS???\r\n\r\nHaha, veti rade voi de complezantza, ideea e ca am aflat si io ca se zice <strong>Campai</strong> atunci cand dai noroc cu giapaniz, nu <strong>Cin Cin</strong>, ca cin cin inseamna putza putza. Asa ca am instruit toti nuntashii sa NU CARE CUMVA SA ZICA <strong>CIN CIN</strong> (putza putza) cand dau noroc cu mirele, CA E FOARTE MARE BAI!!! Sa zica dreq Campai, si gata discutia!\r\nDar sa vedeti numa ce s-a intamplat. Prevedeti? Da, asta s-a intamplat.\r\n\r\nVine mirele, mireasa, se asaza la masa, noi ridicam toti paharele cu sampanie, masa noastra era chiar in fatza mirilor, moment solemn, muzici, soacre mici plÃ¢ngÃ¢nde, si cand zice mirii \"Noroc!\" catre nuntasi, cine rage ca un rinocer, fericit de restu\' de japoneza pe care il mai stia din facultate??? Groparuuuuu!!! Si ce rage Groparu\', cand rage??? Nuuu,  deci Groparu nu o mai stiut ce sa raspunda la Noroc!, cin cin (putza putza) sau campai, si o lansat un <strong>Cin Cin</strong> (<strong>Putza Putza</strong>) cu toata fortza lui vocalica, palatala si dentala, bilabiala si ploziva, de mirele s-o albastrit la fatza!!!\r\n\r\nSi degeaba am zis dupa aia de o mie de ori <strong>Campai Campai Campai  </strong><strong>Campai Campai Campai!!!!!</strong>, ca mirele tot incruntat s-o uitat la mine toata seara!!! Desi mireasa o rÃ¢s de s-o pisat pe ea, la fel si toata masa la care stateam si care erau fostii mei discipoli de japoneza pe care tocmai ii pierdusem, si degeaba o incercat sa ii explice mireasa lu\' puiu de samurai ca io-s tantalau, si ca m-am gandit Campai, da o iesit Cin Cin (putza putza) din motive complet inexplicabile (cum dreq poti explica OZN-urile?), ca giapaniz guy (care cicÄƒ fÄƒcuse ÅŸi ceva karate - asta fÄƒrÄƒ vreajÄƒ) cred cÄƒ se gÃ¢ndea cum sÄƒ mÄƒ facÄƒ <a href=\"http://www.reteteculinare.ro/forum/discutii/surimi-1735/\" target=\"_blank\">surimi</a>, ca aÅŸa poftÄƒ sÄƒ ripostez prin fugÄƒ nu am avut niciodatÄƒ pÃ¢n-atunce!\r\n\r\nPS: Si pe bune ca venise mirele fara nimeni de-al lui, ca m-am uitat la el in valiza, si nu era nici un chinez!!!','Deci ce-am gafat la nunta de japonez',0,'','publish','open','open','','deci-ce-am-gafat-la-nunta-de-japonez','','','2007-06-28 15:41:51','2007-06-28 13:41:51','',0,'http://www.groparu.ro/?p=504',0,'post','',13),(506,2,'2007-07-15 21:01:43','2007-07-15 19:01:43','Deci in primu rand ca is negru ca Cabral, sh deja astept ca si alte dimensiuni sa ajunga ca de negru, desi mi s-o zis ca dupa 20 de ani putulica nu mai creste decat periodic, cand se iriga nush ce caverne cu chestia aia rosie in care se gaseste multa bere.','Deci, din concediu, foarte scurt, virgula',0,'','publish','open','open','','deci-din-concediu-foarte-scurt-virgula','','','2007-07-15 21:07:36','2007-07-15 19:07:36','',0,'http://www.groparu.ro/?p=506',0,'post','',3),(507,2,'2007-07-16 00:07:02','2007-07-15 22:07:02','Aseaaaaa. Am revenit in splendidul meu bloc muncitoresc de pe colinele mamelonate ale Manajturului, unde e intersectia aia periculoasa in care intra toti soferii cu viteza, si dupa ce or evitat la musteatza accidentu\' se uita urat unu la altu\'. Studentele de vizavi s-or cam carat, deci nu mai fac bird-watching seara cand se schimba. Asta e.\r\n\r\nAm plecat in conced cu trinu\', de era sa-l si pierd, da\' l-am prins si am fumat in el ca nesimtitu, chiar langa semnu\' de fumatu interzis. Da, sunt un mic rebel in pragul pensiei. Sh pe tren ne-am imprietenit cu un constantzean cumsecade (salut, Marius!) care ne-o explicat ca un ghid tot ce vedeam: aici e Dunarea, aiciÂ  un deal, iar acesta - bine-nteles - un copac.\r\n\r\nCostinestiu\' nu mai e ce era cand eram io ficior studentzash sh unde mergeai pe plaja calcai pe tzitzi. Romanii incep sa o duca mai bine supt regimul Taricica, sh am vazut mai multe shunculitze expuse pe plaja decat in Metro, la raionul de fleici. Deci studentele frumoase amu trebe sa le cam cauti cu foaaarte mare atentie. Oricum, nu pot sa nu imi dezamagesc prietenii mei voyeurishti, asa ca o sa va afisez cele mai frumoase fetitze de pe plaja, pozate special pentru ochii vostri flamanzi.\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/07/1.JPG\" title=\"1.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/07/1.thumbnail.JPG\" alt=\"1.JPG\" /></a> <a href=\"http://www.groparu.ro/wp-content/uploads/2007/07/2.JPG\" title=\"2.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/07/2.thumbnail.JPG\" alt=\"2.JPG\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/07/3.JPG\" title=\"3.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/07/3.thumbnail.JPG\" alt=\"3.JPG\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/07/4.JPG\" title=\"4.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/07/4.thumbnail.JPG\" alt=\"4.JPG\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/07/5.JPG\" title=\"5.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/07/5.thumbnail.JPG\" alt=\"5.JPG\" /></a>\r\n\r\nM-am si tuns cam chel, la o frizerie intitulata cu un nume similar numelui meu de scena.\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/07/dsc00361.JPG\" title=\"dsc00361.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/07/dsc00361.JPG\" alt=\"dsc00361.JPG\" height=\"343\" width=\"456\" /></a>\r\n\r\nAm vazut sh Constantza - aici avetz o poza cu je sh o cetatzeanca foarte obosita.\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/07/7.JPG\" title=\"7.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/07/7.JPG\" alt=\"7.JPG\" height=\"353\" width=\"462\" /></a>\r\n\r\nAm vizitat Muzeul de Istorie sh cand am ajuns la sectiunea despre razboaiele mondiale, m-am indreptat catre cele doua nemtoaice care vizitau muzeu\' cu noi sh m-am oferit sa le explic mai mult despre cum a pornit Germania razboaiele, dar m-au refuzat politicos. Dupa aia am mers in portu\' Tomis sh am mancat fructe de mare si intre-picioare-de-broasca, delicioase. Poate numai carnitza de femeie e mai gustoasa. Sh cand am mers in Mamaia, am beut bere in telegondola, desi scria clar ca nu ie voie, da Groparului nu ii place interdictiile la bere.\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/07/dsc00276.JPG\" title=\"dsc00276.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/07/dsc00276.JPG\" alt=\"dsc00276.JPG\" height=\"388\" width=\"514\" /></a>\r\n\r\nIn Costinesti este si o terasa, La francezu\'. Am mers la ei si i-am intrebat: Voulez vous coucher avec moi? Notres poules dans votre cour? Si am plecat.\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/07/dsc00423.JPG\" title=\"dsc00423.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/07/dsc00423.JPG\" alt=\"dsc00423.JPG\" height=\"386\" width=\"514\" /></a>\r\n\r\nNacazu\' o fost ca s-o racit apa marii, si era sa-i scot ochii pe plaja unei dame cu sfarcurile mele intarite. Asa ca am tzajnit de-acolo sh am plecat in Delta. Dar despre Delta - in episodul urmator.','Concediu de Gropar',0,'','publish','open','open','','concediu-de-gropar','','','2007-07-16 00:07:02','2007-07-15 22:07:02','',0,'http://www.groparu.ro/?p=507',0,'post','',6),(508,2,'2007-07-15 23:38:02','2007-07-15 21:38:02','','1.JPG',0,'','inherit','open','open','','1jpg','','','2007-07-15 23:38:02','2007-07-15 21:38:02','',-1184526570,'http://www.groparu.ro/wp-content/uploads/2007/07/1.JPG',0,'post','image/jpeg',0),(509,2,'2007-07-15 23:38:22','2007-07-15 21:38:22','','2.JPG',0,'','inherit','open','open','','2jpg','','','2007-07-15 23:38:22','2007-07-15 21:38:22','',-1184526570,'http://www.groparu.ro/wp-content/uploads/2007/07/2.JPG',0,'post','image/jpeg',0),(510,2,'2007-07-15 23:38:34','2007-07-15 21:38:34','','3.JPG',0,'','inherit','open','open','','3jpg','','','2007-07-15 23:38:34','2007-07-15 21:38:34','',-1184526570,'http://www.groparu.ro/wp-content/uploads/2007/07/3.JPG',0,'post','image/jpeg',0),(511,2,'2007-07-15 23:40:45','2007-07-15 21:40:45','','4.JPG',0,'','inherit','open','open','','4jpg','','','2007-07-15 23:40:45','2007-07-15 21:40:45','',-1184526570,'http://www.groparu.ro/wp-content/uploads/2007/07/4.JPG',0,'post','image/jpeg',0),(512,2,'2007-07-15 23:40:57','2007-07-15 21:40:57','','5.JPG',0,'','inherit','open','open','','5jpg','','','2007-07-15 23:40:57','2007-07-15 21:40:57','',-1184526570,'http://www.groparu.ro/wp-content/uploads/2007/07/5.JPG',0,'post','image/jpeg',0),(513,2,'2007-07-15 23:58:27','2007-07-15 21:58:27','','dsc00361.JPG',0,'','inherit','open','open','','dsc00361jpg','','','2007-07-15 23:58:27','2007-07-15 21:58:27','',-1184526570,'http://www.groparu.ro/wp-content/uploads/2007/07/dsc00361.JPG',0,'post','image/jpeg',0),(514,2,'2007-07-16 00:00:37','2007-07-15 22:00:37','','7.JPG',0,'','inherit','open','open','','7jpg','','','2007-07-16 00:00:37','2007-07-15 22:00:37','',-1184526570,'http://www.groparu.ro/wp-content/uploads/2007/07/7.JPG',0,'post','image/jpeg',0),(515,2,'2007-07-16 00:03:46','2007-07-15 22:03:46','','dsc00276.JPG',0,'','inherit','open','open','','dsc00276jpg','','','2007-07-16 00:03:46','2007-07-15 22:03:46','',-1184526570,'http://www.groparu.ro/wp-content/uploads/2007/07/dsc00276.JPG',0,'post','image/jpeg',0),(516,2,'2007-07-16 00:05:13','2007-07-15 22:05:13','','dsc00423.JPG',0,'','inherit','open','open','','dsc00423jpg','','','2007-07-16 00:05:13','2007-07-15 22:05:13','',-1184526570,'http://www.groparu.ro/wp-content/uploads/2007/07/dsc00423.JPG',0,'post','image/jpeg',0),(517,1,'2007-07-16 16:09:45','2007-07-16 14:09:45','Ce nu am apucat sa scriu despre mare:\r\n\r\n- am intalnit sh romani fericiti care canta mai najpa decat mine;\r\n\r\n[google -2071717330122837961]\r\n\r\n- era sa-mi fac cruce in moscheea din Constanta, noroc ca m-am potolit; am cerut sa vad daca nenea de la intrare are dinamita la centura, sh la plecare am zis \"Doamne-ajuta!\" si i-am facut cu ochiu\';\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/07/dsc00212.JPG\" title=\"dsc00212.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/07/dsc00212.JPG\" alt=\"dsc00212.JPG\" height=\"359\" width=\"477\" /></a>\r\n- am servit ghiaurul din mine cu carne de oaie la restaurantu\' turcesc, nenea care servea era destul de turc si l-am pus sa repete in turca meniu\' pana am simtit ca vrea sa imi zica \"anadÃ¢ anamu\", care, dupa umilele mele cunostintze de turca inseamna o pomenire licentzioasa a mamei mele, care de fapt e o doamna;\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/07/11.JPG\" title=\"11.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/07/11.JPG\" alt=\"11.JPG\" height=\"355\" width=\"470\" /></a>\r\n- am papat pastruga, care sigur crescuse in hazna la Metro, un peste cel putin gretzos daca nu mai locuiesti in camin;\r\n- ne-am dat cu autobuzu\' ala hotz si decopertat din Constantza, sh am facut poze la toti marinalii de pe drum (ca erau imbracati in berete ca domnu\' Goe) sh le-am strigat \"Sa traiti, domnilor presedinte!!!\"\r\n- ne-am dat cu vaporetto prin portu\' Tomis si in exterior, pana in ziua de azi voi regreta ca nu am urcat la bordu\' vasului cu macar doo doze de berula la bordu\' meu; sh pe vapor m-am imprietenit cu cel mai retard baietzel din Constantza, care arÄƒta de 27 de ani, dar de fapt avea abia 12, nu i-am facut poza ca sa nu turbeze. Ex de dialog cu el:\r\n<strong>El</strong>: \"Cum e in Danemarca?\"\r\n<strong>Eu</strong>: \"Fain\"\r\n<strong>El</strong>: \"OK...\"\r\ntot el: \"Cred ca Constantza e cel mai frumos orash din Romania!\"\r\n<strong>Eu</strong>: \"Si eu cred... si cred ca si Sibiul si Clujul sunt cele mai frumoase orase din Romania!\"\r\n<strong>El</strong>: \"Da...\"\r\ntot el: \"Ce muzica ascultati?\"\r\n<strong>Eu</strong>: \"Muzica buna\"\r\n<strong>El</strong>: \"OK...\"\r\n<strong>Eu</strong>: \"Ablatiunile canguresti ale nefelatziei pot mena fie la pseudo-cinegeticism intempestiv, fie la pelagism atavic celenterat!\"\r\n<strong>El</strong>: \"Da...\"\r\n\r\n- am incercat sa scot camera foto din plasa cu mana cu care tineam tigarea, am reusit sa ma ard la buricel sh sa lepad pe pavaj camera mea proaspat reparata la care deja nu i se mai inchidea obiectivul; camera a scos un clinchet metalic (placut, daca e camera altcuiva) si si-a inchis obiectivul. Am fost foarte happy. Camera mea se reparase singura... the Russian style.\r\n\r\nIar in urmatoarea postare, chiar voi vorbi despre aventurile deltaice.','Karaoke la mare',0,'','publish','open','open','','karaoke-la-mare','','','2007-07-16 16:12:28','2007-07-16 14:12:28','',0,'http://www.groparu.ro/?p=517',0,'post','',0),(518,1,'2007-07-16 15:50:20','2007-07-16 13:50:20','','dsc00212.JPG',0,'','inherit','open','open','','dsc00212jpg','','','2007-07-16 15:50:20','2007-07-16 13:50:20','',-1184590532,'http://www.groparu.ro/wp-content/uploads/2007/07/dsc00212.JPG',0,'post','image/jpeg',0),(525,2,'2007-07-16 23:06:44','2007-07-16 21:06:44','Fix tranta, ca m-am dat cu Denim, sh tot o trebuit sa cer, sh am primit numa\' dupa ce am facut dush, deci nici o schimbare. Dar nu despre asta vreau sa vorghesc.\r\n\r\nDeci: Haha! Una din gogoritzele trecutului de mijloc de prim deceniu al mileniului nostru. Unui <a href=\"http://www.petitiononline.com/iancu/\" target=\"_blank\">nene</a> i s-o cashunat pe statuia funaresca care il reprezinta pe Avram Iancu din centrul (romanesc al) Clujului, si zice ca trebe sa inlocuim statuia.\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/07/avramiancu1.jpg\" title=\"avramiancu1.jpg\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/07/avramiancu1.jpg\" alt=\"avramiancu1.jpg\" height=\"475\" width=\"365\" /></a>\r\n\r\nWHAT THE F***????\r\n\r\nIn primul rand, aflati si voi ca Romania nu o avut un trecut imperial. Deci nu are cum sa aiba statui d-alea din bronz d-ala verde, coclit, faine statui imperiale stilizate bestial, cu riga Frantz si Iosif si Pizmarck, statui de care geme Austria, Germania, Danemarca sh cam orice alta tzara din Europa asta pe care ne-am anexat-o. Nu are, deci nu avem ce statui cat de cat meseriashe sa ne facem. Pana si in Craiova, statuia lu Mihai Viteazu\' (coios Mishu asta, la vremea lui!) mi se parea enervant de mica sh de slabanoaga. Asta e, suntem un neam de nestatuabili.\r\n\r\nIn al doilea rand, cand am mers sa vad cetatea de la CÃ¢lnic (o fortareatza saseasca apsolut dementiala, intre Sibiu si Sebes), am dat peste un ghid (amazing, nu?). Si cand discut cu el despre bruma de istorie pe care o mai stiu de pe cand eram si eu ghid nu pot sa nu opserv ca comunistii or incercat prin anii \'80 sa ranforseze zidul exterior cu un parete de - da! - beton ordinar. Sh il iau io,  ca vizitator, de guler pe ghid: Ba, da de ce puii mei nu eliminati voi PORCARIA aia de cement d-acilea? Sh ghidul, genial, zice: Mai taticule, deci peste cetatea asta din sec. 14 or cam trecut tot felu de perioade, care si-or lasat amprenta peste ea. Si comunismu e o perioada care s-o cam prelins peste ea, si si-a lasat amprenta. Chiaro? Si noi nu putem sterge istoria.\r\n\r\nIn aceeasi ordine de idei: Clujul a trecut peste o gruaza de perioade. Inclusiv perioada funaresc-cripto-comunista. De ce sa nu lasam chestia aia acolo unde e, ca reprezentatie a perioadei funaresti? Plus ca n-as prea vrea ca porumbeii din orashul meu sa faca caca pe un simbol national bine reprezentat, oricum statuia asta actuala nu e nij macar un simbol comunal.\r\n\r\nSi dac-ar fi sa o inlocuim, cu ce o vom inlocui? Cu ce alt simbol clujesc? Cu\r\n\r\n1. Statuia Nokia. Un telefon mobil urias cu vibrator.\r\n2. Statuia Caritas. Putini stiu ca statuia asta a fost erectata (si) cu fonduri donate de castigatorii caritashi.\r\n3. Statuia Ursus. Nu, ca este o fabrica falimentara de tractoare Ursus (asa le zice, un fel de Roman Brasov) in Polonia.\r\n4. Statuia lui Boc. Neeee, ca nu se vede daca e pusa pe soclu fara lupa.\r\n5. Statuia lui Funar. Asta numai daca langa ea se ridica statuia Consulatului Maghiar din Cluj.\r\n6. Statuia cu raul Somesul Mic.\r\n7. Statuia cu Manajturul (pt non-clujeni: frumosul cartier muncitoresc in care fiintesc, un brand in sine insusi). Nu trebe decat o bucata murdara de beton, si voila!\r\n8. Statuia lui <strong>Groparu</strong>. Greuceanu, care este un om caruia ii cam lipseste un dog, vroia ca la apsolvire sa ne facem mulaje de ghips, si sa ii kemam pe decani si prorectori la dezvelirea busturilor noastre, sa ne distram la un pahar de votca bauta in fatza propriilor noastre sanctuare. Da\' porcu o terminat cu un an mai repede decat mine, sh s-o tirat in Spania; sh nu am apucat sa ne punem planu\' in aplicare. Sh alte facultati decat mintale nu avem cum sa mai apsolvim.\r\n9. Statuia lui Hagi (oricum zicea intr-o vreme ca ar trebui sa ridicam statui fotbalistilor), dar din moment ce nu joaca pt CFR - slabe sanse.\r\n10. Statuia lui Dan Diaconescu.\r\n11. O STATUIE CU O FEMEIE CU SANII CU ADEVARAT MARI.\r\n\r\nPS: Data viitoare chiar scriu despre Delta.','Avram Iancu Rebranded',0,'','publish','open','open','','avram-iancu-rebrabded','','','2007-07-17 09:21:55','2007-07-17 07:21:55','',0,'http://www.groparu.ro/?p=525',0,'post','',9),(524,1,'2007-07-16 16:05:55','2007-07-16 14:05:55','','11.JPG',0,'','inherit','open','open','','11jpg','','','2007-07-16 16:05:55','2007-07-16 14:05:55','',-1184590532,'http://www.groparu.ro/wp-content/uploads/2007/07/11.JPG',0,'post','image/jpeg',0),(526,2,'2007-07-18 16:11:54','2007-07-18 14:11:54','Se zice ca pentru a avea o viatza sanatoasa nu conteaza asa de mult ce mananci, cat conteaza ceea ce arde corpul; asa ca pe vapor in drum spre Delta am ars un pachet tigari si vreo 8-9 beri fara nici un fel de remuscare, pentru ca daca omu\' nu bea suficient in concediu, cand dreq sa bea? va zic tot eu: cand nu ai concediu!\r\n\r\n<strong>Ziua Una.</strong>\r\nDeci: spre Delta (spre Tulcea, se pronuntza ca Turcia) se pleaca dinspre Constanta, cu microbuz plin cu pui de gaina sh bobocei de ratza, sh tanti lelitze din sud, extrem de piparate la limba; sh daca esti Gropar milos sh multi-poliglot la limbi (dintre care nici macar romana io nu o vorbeshte corec), infiezi pe drum un cuplu de nemtzoici picate din cer sh inca unu\' de frantzuji pensionari. Care nu se prea omoara cu vorbit de limbi straine, sh nici macar de romana, care nu e limba straina! Sh dinspre Turciea spre Crisan, pe antebratul Sulina, se mere cu vaporetto.\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/07/21.JPG\" title=\"21.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/07/21.JPG\" alt=\"21.JPG\" /></a>\r\n\r\nSh vreau sa va zic urmatoarea faza: geniul constructorilor navali romani se manifesta plenar pe nava Mehedinti, finca daca stai in cur sh te uiti la canale, vezi exact prin slotul ala liber dintre copastie sh balustrada, da\' numa daca ai bere in mana; io-te, in imagine, avetz un Gropar ganditor, care bea una din cele 9 (!) beri consumate apsolut fata moderatie in drum spre. Sh la ce se gandea Groparu cand se gandeam stand asa? Se gandea, in infinita lui intelepciune Dalai Lamica, la necazurile lumii, la bolile, problemele si provocarile inceputului de mileniu, sh la <strong>CUM MA DOARE PE MINE FIX CU 3 METRI IN SPATE DE ELE</strong>. Asta e.\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/07/dsc00243.JPG\" title=\"dsc00243.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/07/dsc00243.JPG\" alt=\"dsc00243.JPG\" height=\"380\" width=\"495\" /></a>\r\n\r\nFinca suntem romani cumsecade, pe nemtoaicele infiate le cazam la hotelul de 4 stele din satul Crisan, unde mergeam noi (pretz cazare: 30 lei camera pe noapte, da nu era hotel, era numa pansiune, da nij macar pensiune nu era, ca era la cineva acasa; de fapt nici la cineva acasa nu era, ca era acasa la maica-sa). Sh vorbim cu gazda, tanti Luci, sigur o stiti, toata lumea o stie pe d-na Luci din Delta; sh vorbind cu ea, ea ne da un nr de telefon aÂ  lu\' alt Luci, de data asta nene sau domn, nu mai stiu, care erea ghid, cica. And a damn good one.\r\n\r\nCulmea zilei. DECI CEVA MAI BUN EU SINCER NU CRED CA EXISTA. Desi pe lume s-au inventat gorgonzole, carne de vanaturi, pitulici in sos de gulii si rocheforturi, dar va decretez amu, oficial: ceva mai bun decat telemeaua de sibiu originala si CIORBA DE PESTE papata in Delta, nu exista. Tanti Luci ne-a asteptat cu o zama din inotatoare, mÄƒi copii, pentru care din pacate limba romana este muuuhuhult prea zgarcita, deci este indescriptibil de buna*.\r\n\r\n<strong>Ziua Doo</strong>\r\nSh a doua zi plecam dis de dimineatza spre padurea Letea intr-o barcutza cu motorash - noi, doi romanci, doi frantzuji, doi nemtzoici si el, carmaciul. Pe canale. Am cautat Kanal D, sh nu l-am gasit. Asta e. In schimb am vazut alte canale, cel putin la fel de bestieale. Sh ghidu\' - care era un fel de barefoot bushman - o prins un sherpe, sh ne-am pozat cu el; sh ne-o cioplit o palarie din frunza de balta; sh ne-o orbit cu explicatii, pe care sa va vad io incercand sa le traducetz simultan in engleza sh franceza despre pasari gen\r\n\r\n- stÃ¢rc de baltÄƒ, stÃ¢rc cenuÅŸiu, stÃ¢rc de noapte, stÃ¢rc galben;\r\n- chirichiÅ£Äƒ;\r\n- chirÄƒ de baltÄƒ;\r\n- dumbrÄƒviÅ£Äƒ;\r\n- Å£igÄƒnuÅŸi;\r\n- avoazete;\r\n- ciocÃ®ntorÅŸi;\r\n- pescÄƒruÅŸul pescar;\r\n- pelican ÅŸ barzÄƒ ÅŸ cormoran ÅŸ raÅ£Äƒ ÅŸ gÃ¢scÄƒ ÅŸ bobocei sÄƒlbateci ÅŸ egrete (care e chiar decente, Ã®s Ã®n manualele de clasa a 7-a);\r\n- sitari;\r\n- furtunar;\r\n- cufundari;\r\n- silvii;\r\n- muscari, ÅŸ gata - plus jdemii de pejti, unii mai sturioni decÃ¢t alÅ£ii.\r\n\r\nAtÃ¢ta am vorbit la limbi strÄƒine cÄƒ ÅŸi in ziua de azi ma dor mainile. Da\' am vast padurea Letea. Sh cea mai tare faza din grindu\' letea - trecem pe langa un nene batranel el, asa, da\' destul de pescar de-al locului; si zice: <strong>Papiroshka, Papiroshka!</strong> Finca io stiu si foarte putina rusa, mai ales ca cand zicea imi facea semn cu mainile ca vrea tigari, scot Kenturile mele, sh il servesc; Spasiba, zice moshu, Pajaluska, zic io, sh ma fuljereaza: am votca la mine! Da\' o votca bei cu mine? Il intreb. Da, da, zice nenea, cu o sclipire matÄƒ de solz de stiuca in ochi, ca o pÄƒrere; sh scoate Groparu votca loata anume pentru Delta, sh bÄƒi tata, cand o pune nenea la guritza sticloantza aia de Scandic, jur ca vreo 180 de mililitri din ea s-au dus bolborosind la vale, in gatleju\' mariei sale, lipoveanu\', de parca nu ar fi fost in sticla nici macar niciodata! In fatza unei asemenea dovezi de maiestrie, m-am resemnat, am pupat sh eu sticla care mirosea usurel a peste si a usturoi, sh am plecat ca orice ardelean de bun simtz, care stie ca performantele sale sub-notabile se vor rasfrange asupra intregii sale regiuni de provenientza.\r\n\r\nPadurea Letea ni s-o parut boring, poate n-am vast noi ce trebia; da\' am vine inapoi pe neshte canale, mai tata, canale d-alea ca-n Vietnam, salbatece, oioioi! Si am facut bird-watching la pasarici, ghe mai mare dragu\'! Va pun sh poze, va pun, mintenash.\r\n\r\nSi cand plecam de-acolo, ne oprim in neshte locuri perfect anonime; sh scoate Luci, care deja era cel mai bun prekin de-al meu, plase de peste; sh scoate niscai stiuca sh somn, pe care l-am si cumparat de la el, vreo 6 kile de peste cu 24 de lei. Scump, scump, dincolo era mai ieftin!\r\n\r\n<strong>Ziua trei</strong>\r\n\r\nAm vazut Lacul Iacob, Lacul Cuibul Lebedei, sj inca nush ce ghioluri, pline-ochi de pasaret; am vazut vultur codalb, care daca se naraveaza creca cam poa sa radice Gropari la cer ca pe Niels Holgersson. Sh am mancat sh papura (!) - care e un aliment super :D\r\n\r\nSi cred ca mai fac update la ce am scris acilea, ca sigur am uitat o groaza de chestii, plus pozele, pe care amu nu le pot pune sus tatie.\r\n\r\n_______________\r\n* Ciorba de peste se remarca printr-o usoara senzatie de mÃ¢l, inundata aproape instantaneu de puternice, dar discrete intepaturi de otet ieftin, da\' bun. Legumele sunt mai putine ca pestii din chiuveta, dar au rol strepezitor si profund racoritor la mestecare. Ciorba se serveste scaldata de soare, asta daca e fierbinte, sh ea se serveste fierbinte; sh cand cari pe high speed linguri de zama la gura, uiti de paine, si transpiri ca intr-o mica sauna plina de chinezoaice micutze si care rÃ¢d dintr-o piele curata. Pestele din zama se serveste intr-un bol aburind alaturat, si cu mana libera scormonesti printre pestii (care nu se uita la tine din simplul motiv ca is decapitati) caldurosi de acolo, despre care se zice ca daca ii prinzi ca sa-i faci ciorba de peste, <strong>nici macar nu se zbat</strong> <strong>in unditza</strong>. Paturile succesive de produse ihtiologice pelagice au rolul deloc secundar de a-ti induce o pofta sa scufunzi TOATA FATZA in zama, sh sa o sorbi cu nasul, gura, urechile, ochii, sprancenele, sa picure pe piept picuri de zama sh tu sa nu te lasi, sa iti contorsionezi capul si sa iti lingi picurii de ciorba de pe buric, si efectiv iti dai seama ca orice incercare de a lauda zama in afara de grohaieli porcine sh scrofuloase e sortita esecului. Nimic nu putea perfectiona avalansa de simturi drogate de ciorba decat - bineinteles - inca o portie de peste, da\' prajit, asezat alaturea, sh pentru care constati, frustrat, ca nu mai ai inca o mana, finca alelalte doo is ocupate; sh iti vine sa te descalti sh sa te servesti cu picioarele, ca un fachir, ca un cimpanezu pluridextru, sau picioro-dextru. Si cand descurajat de prima portie care curge pe duoden la vale ca caca prin vidanja de 200 CP Yamaha, iti umpli din nou farfuria cu ciorba din bol tinand polonicul intre dinti, iti dai seama ca piciorul lui Dumnezeu e acolo, mai, acolo, intre bratele tale, si il tii cu putere, si Dumnezeu nu are ce sa mai faca, finca e silit sa te desfete, finca tu esti Voievodul Polonicului!!! Si repeti figura cu umplutul farfuriei inca o data, inca o data, desi bolul are 400 mililitri, pana cand iti dai seama ca ai mancat in 15 minute UN KIL JUMATE DE ZAMA DE PESTE, basca vreo 3 bucati de somotei prajit plus 3 stiuci fierte in ciorba, si atunci, ca calare pe o mingiuca plina cu apa grea, iti dai seama ca nu te mai poti ridica de pe scau, pentru ca picioarele nu ti-au fost proiectate sa sustina atata greutate, si daca faci efort, digeri mai repede ciorba, sh tu vrei cu orice chip sa o tii inauntrul tau!!!! Si iti vine sa te rostogolesti la pamant, sa bufnesti surd de podea, si sa spui cu o voce stinsa \"Doamne, daca vrei sa ma omori, fa-o acuma, ca jur ca nu-mi mai pasa de ce se intampla cu mine acum!\"\r\n\r\nCa o reclama la Heineken: cum innobilezi apa verde, din smarcuri de Dunare? O FACI ZAMA DE PESTE! Ia uite-o:\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/07/dsc00668.JPG\" title=\"dsc00668.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/07/dsc00668.JPG\" alt=\"dsc00668.JPG\" height=\"359\" width=\"477\" /></a>','Deci, Delta, intr-o postare luuuunga',0,'','publish','open','open','','deci-delta-intr-o-postare-luuuunga','','','2007-07-18 16:11:54','2007-07-18 14:11:54','',0,'http://www.groparu.ro/?p=526',0,'post','',11),(527,2,'2007-07-16 23:23:06','2007-07-16 21:23:06','','avramiancu1.jpg',0,'','inherit','open','open','','avramiancu1jpg','','','2007-07-16 23:23:06','2007-07-16 21:23:06','',525,'http://www.groparu.ro/wp-content/uploads/2007/07/avramiancu1.jpg',0,'post','image/jpeg',0),(528,1,'2007-07-17 22:15:25','2007-07-17 20:15:25','<a href=\"http://stoica.hotnews.ro/drumul-de-la-firma-romaneasca-de-stat-la-multinationala.html\" target=\"_blank\">Aici</a> scrie ca Taricica doreste ca companii bastinoase, marci romanesti de traditie, de alfel, sa se extinda peste granitele patriei mele si sa cumpere cu furie firme straine, ca sa ne incordam noi mujkii la lume si sa aratam ca suntem mai mult decat ceea ce vom fi!\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/07/12.JPG\" title=\"12.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/07/12.JPG\" alt=\"12.JPG\" /></a>\r\n\r\nDeci CEC ar putea, bag sama, sa cumpere FMI. Mi se pare fair ca noi sa gestionam finantele mondiale, numa sa nu se razgandeasca si aia de la vanzare, asa cum s-or razgandit ai nostri cu CEC-ul.\r\n\r\nCFR Marfa cica ar putea cumpara operatorul maghiar. Marfa! zic io.\r\n\r\nRegia Autonoma a Huilei Petrosani ar putea cumpara niscai mine de diamante din zone de conflict; asta in cazu\' in care vor sa porneasca inspre Bucale in mineriade, de data asta cu Kalashnikoave. In cazu asta imi pare bine ca nu mai sunt student.\r\n\r\nCentrala de la Cernavoda ar putea cumpara Cernobilu\'. Asta am decretat dupa ce am vazut pozele <a href=\"http://freeenergynews.com/NOT/ChernobylTour/index.html\" target=\"_blank\">astea</a>.\r\n\r\nGuvernul ar putea sa cumpere un alt guvern dintr-o tzara mai bananiera ca a noastra; sh sa ne trimita la fertilizat indigene (preferabil mulatrese) cu material genetic gropar de calitate.\r\n\r\nSi in final, Groparu s-ar decreta destul de fericit daca i s-ar permita sa cumpere GOOGLE.','Romani, va ordon, treceti Prunul',0,'','publish','open','open','','romani-va-ordon-treceti-prunul','','\nhttp://stoica.hotnews.ro/drumul-de-la-firma-romaneasca-de-stat-la-multinationala.html','2007-07-17 22:15:25','2007-07-17 20:15:25','',0,'http://www.groparu.ro/?p=528',0,'post','',4),(529,1,'2007-07-17 14:22:15','2007-07-17 12:22:15','','12.JPG',0,'','inherit','open','open','','12jpg','','','2007-07-17 14:22:15','2007-07-17 12:22:15','',528,'http://www.groparu.ro/wp-content/uploads/2007/07/12.JPG',0,'post','image/jpeg',0),(530,1,'2007-07-19 13:49:46','2007-07-19 11:49:46','\r\n<p style=\"font-weight: bold\">Capitolul I</p>\r\nBUZZ!!!\r\n<span style=\"font-weight: bold\">Marian:</span> ma\r\nBUZZ!!!\r\n<span style=\"font-weight: bold\">Marian:</span> ma... tu te stergi la fund cu mana dreapta sau cu mana stanga?\r\nBUZZ!!!\r\n<strong>Groparu</strong><span style=\"font-weight: bold\">:</span> stanga\r\nBUZZ!!!\r\n<strong>Groparu</strong><span style=\"font-weight: bold\">:</span> de ce?\r\nBUZZ!!!\r\n<span style=\"font-weight: bold\">Marian:</span> ashe\r\nBUZZ!!!\r\n<span style=\"font-weight: bold\">Marian:</span> da tu nu te stergi cu hartie mah?\r\nBUZZ!!!\r\n<span style=\"font-weight: bold\">Marian:</span> ha??\r\nBUZZ!!!\r\n<span style=\"font-weight: bold\">Marian:</span> bou\r\nBUZZ!!!\r\n<span style=\"font-weight: bold\">Marian:</span> castrat\r\nBUZZ!!!\r\nBUZZ!!!\r\n<span style=\"font-weight: bold\">Groparu:</span> pai sh hartia cu ce-o tii, dobi, cu dintii???\r\n\r\nPS: Contrar a ceea ce credetz, nu e Marean Van Chelie.\r\n\r\n<span style=\"font-weight: bold\">Capitolul II</span>\r\n\r\n<span style=\"font-weight: bold\">voda mihai:</span> vitaaaaaaaaaaaa\r\n<span style=\"font-weight: bold\">Groparu:</span> capraaaaaa!!!!!!!!!!!!\r\n<span style=\"font-weight: bold\">voda mihai:</span> ai fo la concediu ma oaie\r\n<span style=\"font-weight: bold\">Groparu:</span> am fo mah belitule\r\n<span style=\"font-weight: bold\">voda mihai:</span> ai prins ceva\r\n<span style=\"font-weight: bold\">voda mihai:</span> sau doar pula\r\n<span style=\"font-weight: bold\">Groparu:</span> n-am mers la pescuit\r\n<span style=\"font-weight: bold\">Groparu:</span> am mers la beut sh papat sh uitat la pasarici\r\n<span style=\"font-weight: bold\">voda mihai:</span> aha\r\n<span style=\"font-weight: bold\">voda mihai:</span> betivule\r\n<span style=\"font-weight: bold\">Groparu:</span> bizon unguresc!!!\r\n<span style=\"font-weight: bold\">voda mihai:</span> vaca australopiteca\r\n<span style=\"font-weight: bold\">Groparu:</span> sarpe inghinal!\r\n<span style=\"font-weight: bold\">voda mihai: </span>penis flasc\r\n<span style=\"font-weight: bold\">Groparu:</span> fleica de babiun\r\n<span style=\"font-weight: bold\">voda mihai:</span> penticostalule\r\n<span style=\"font-weight: bold\">Groparu:</span> budistule radioactiv, pescar diareic, bulgare de caca rostogolit de scarabei!\r\n<span style=\"font-weight: bold\">voda mihai:</span> ye ye\r\n\r\nPS: Mihaita este disponibil la sex4uromania@yahoo.com','Dupe YM adonate',0,'','publish','open','open','','dupe-ym-adonate','','','2007-07-19 13:50:41','2007-07-19 11:50:41','',0,'http://www.groparu.ro/?p=530',0,'post','',3),(531,2,'2007-07-18 16:05:56','2007-07-18 14:05:56','','dsc00243.JPG',0,'','inherit','open','open','','dsc00243jpg','','','2007-07-18 16:05:56','2007-07-18 14:05:56','',526,'http://www.groparu.ro/wp-content/uploads/2007/07/dsc00243.JPG',0,'post','image/jpeg',0),(532,2,'2007-07-18 16:07:26','2007-07-18 14:07:26','','21.JPG',0,'','inherit','open','open','','21jpg','','','2007-07-18 16:07:26','2007-07-18 14:07:26','',526,'http://www.groparu.ro/wp-content/uploads/2007/07/21.JPG',0,'post','image/jpeg',0),(533,2,'2007-07-18 16:09:01','2007-07-18 14:09:01','','dsc00668.JPG',0,'','inherit','open','open','','dsc00668jpg','','','2007-07-18 16:09:01','2007-07-18 14:09:01','',526,'http://www.groparu.ro/wp-content/uploads/2007/07/dsc00668.JPG',0,'post','image/jpeg',0),(534,2,'2007-07-19 14:07:08','2007-07-19 12:07:08','- fac dragoste cu lumina stinsa;\r\n- fac dushuri reci-reci cand nu pot face dragoste;\r\n- nu-mi spal niciodata lenjeria, ca sa nu poluez apele;\r\n- respir parfumuri de femeie de pe piele incinsa, ca sa nu respir oxigenul pretios;\r\n- cand fac pipi dupa bere, incerc sa fac la radacina copacilor;\r\n- nu trag apa dupa mine la WC; apa e o resursa prea pretioasa;\r\n- nu ma barbieresc ca sa nu consum apa, care e o resursa prea pretioasa;\r\n- nu cumpar rosii primavara, ca is produsul efectului de sera;\r\n- nu combat mucegaiul producator de oxigen din baie;\r\n- sterg cu manelistii peretii uzi din discoteci, ca sa nu fie obligati sa faca dush;\r\n- cumpar bere cu continut cat mai mic de apa si cat mai mare de alcool;\r\n- folosesc aerul neconditionat;\r\n- nu ma uit la TV decat rar, si atunci la filme porno;\r\n- incurajez din priviri domnisoarele cu decoltee, finca mai multe decoltee inseamna economie de material;\r\n- nu sustin zborurile spatiale, din moment ce avem atatea Venusuri de explorat aici, pe Pamant;\r\n- incerc sa plantez arbori, ca e foarte fain sa pupi gajicile prin paduri (hehe!);\r\n- circul cu troleul, ca uneori e plin de studente.\r\n\r\nSh bag sama ca or mai fi.','Cum salvez eu planeta',0,'','publish','open','open','','cum-salvez-eu-planeta','','','2007-07-19 14:07:08','2007-07-19 12:07:08','',0,'http://www.groparu.ro/?p=534',0,'post','',6),(535,1,'2007-07-20 18:14:02','2007-07-20 16:14:02','Dumineca - nunta lu tibby. Pfuaaay, ce va ieshi! furam tat.\r\n\r\nDeocamdata bau (bere! clar) cu Tetea Dan, intr-o vizita extraordinara in Cluj pÃ¢nÄƒ sÃ¢mbÄƒtÄƒ, singurul om care a scos o chestie jeniala in fatza shafului sau: ii era fuame, sh vrea sa se care sÄƒ mÃ¢ncÄƒ. Sh sÄƒfu urlÄƒ: Da unie p***ula me pleci? Ca avem trieaba sh deadline sh cine mai stie ce! Sh i se mai sh umfla o vena la tÃ¢mplÄƒ. Sh el zice, cu o moaca flegmaticÄƒ (asta numai cel de-l shtiu cunosc moacele acre pe care le scoate Danila): Eeeeeeeuuuuu...  sh restul de 5 miliarde! Ce insamna asta, zice shafu, dintr-o data curios. Pai, zice Danila, contez EEEEUUUUUU, sh restu de 5 miliarde mai putin! Mie amu mi-i foame. Ma duc sa bag in cotetz, sh revin. Pula mi-i de iei.','Deci, weekendu\' aiesta',0,'','publish','open','open','','deci-weekendu-aiesta','','','2007-07-20 18:14:02','2007-07-20 16:14:02','',0,'http://www.groparu.ro/?p=535',0,'post','',0),(536,1,'2007-07-21 11:57:58','2007-07-21 09:57:58','Deci, postare pe bune.\r\n\r\nIo am un prekin, Silvan pe numele  sau mic. Nu ma intrebati ce fel de nume e asta, ca va zic io: nume de baiat!\r\n\r\nFaza mai ie ca beiatu aiesta canta enervant de fain la chitara. Si cand zic enervant, zic Demential. Cand zic Demential, zic Absolut (nu votca, mah!). Mnoa. Sh care o castigat anu\' trecut toate (!) editiile locale ale festivalului de muzica folk <strong>Om Bun</strong> la care o participat (asta inseamna vreo 5-6 premii prin toata tzara). Stiti voi cum e, fani in picioare aplaudand, ovatii, urale, baclavale. Finca omu\' le merita. Kiar stiu. Si nu ca mi-i prekin. Nu am dreptu\' sa va pui aci vreo melodie de-a lui, da cand canta face cu chitara aia cam ce o facut Iliescu trei mandate: cam ceea ce vrea.\r\n\r\nAnu asta urmeaza sa isi scoata albumu, sh io i-am tradus tecstele in engleza. Sh am facut-o finca merita canguru\' asta al meu de prekin, ca prea fain canta.\r\n\r\nMnoa. Sh domnu\' Silvan e la festivalu\' de muzikie de la Sf. Gheorghe, in Delta. Sh PULETZII DE ARBITRI (se scrie cu un singur \"i\", dar puteti sa va amuzati punandu-va prekinii sa scrie <em>zurbagiii aceia de arbitri</em>) i-or dat nota 1 (mah! 1!!!!). Sh d-asta am pornit o campanie pro-Silvan.\r\n\r\nAsa ca va rog sa intrati pe http://88.158.0.5//netvoting.php?cx=details&amp;id=9#aaa81 si acolo dati nota 10 lui Silvan, cel mai tare cantaretz de la festivalul de la Sf Gheorghe, da\' care fu furat de organizatori, c-asa-i in tenis!\r\n\r\nPS: Am sa va pun, cu acordul domniei sale, sh neshte piese ca sa vedetz de cine zic ;)','Campanie anti Fuck You',0,'','publish','open','open','','campanie-anti-fuck-you','','','2007-07-21 11:57:58','2007-07-21 09:57:58','',0,'http://www.groparu.ro/?p=536',0,'post','',11),(537,1,'2007-07-23 16:05:18','2007-07-23 14:05:18','Cu cine s-a maritat Tiberiu? Cu o gajica, normal! Unde va credetz aici, in Amsterdam sau Gayland?\r\n\r\nNunta d-aia bengoasa, da\' ne-fitzoasa: la intrare, nu iei shnapanie (vin spumant angelli cu aroma de piersica, 8 lei in Metro), ci tequila: sh-asha e cald ca la mexicani.\r\n\r\nInuntru, bar de cocktailuri, facut de Misha meseriashu\'. Am cerut un Screaming Orgasm sau un Sex on the Beach, sh-o zis ca sa plec de-acolo, ca kiama Politia Sexoala sh ma aresteaza pt hartuire de persoane de acelasi sex, sh ca sa fac bine sa-mi scot gandurile gay din cap, sh i-am zis ca io n-am ganduri gay decat cu femei, sh ca ce am cerut io e beuturile, nu orgasmu\'! Sh mi-o facut tot felu\' ce cocktaile d-alea de inotau in ghieatza, sh care racoreau burta de Gropar care o beut vreo 2 sticle de ape minerale de sete, sh abia daca o mers la buda o singura data toata nunta la un pishu scurt, la cat era de cald! Ca bag sama ca lichidele le eliminam prin pere, sau pori, cum le zice.\r\n\r\nInainte de ceremonie, ma duc la socru mic. Emotii? intreb. Da, zice el. E OK, zic io, Tibby e baiat bun, sh nu o bate prea tare pe Mariana, c-atz vazut doara ca vÃ¢nÄƒtÄƒile de la mÄƒna ei Ã®s mici. Sh-apa\' m-am carat.\r\n\r\nMai incolo, Tibby sh consoatza or zis \"Da!\" in fatza lacului, ca uitai sa va zic ca eram in plina natura, in frumoasa asezare Gilau, la o crÃ¢jma cu ÅŸtaif - peisaj salbatec de munte, cu pÄƒduri, tÄƒu de munte, piscuri, inclusiv vreo doua tractoare care or perturbat slujba dom\' parintelui, ca otzÃ¢rÄƒ am ras, asa, ca-n biserica, mai cu pofta cand stii ca e interzis. Ui aci cum inconjurau ca apucatii masa aia pe care erau piscoatele sh mierea:<a href=\"http://www.groparu.ro/wp-content/uploads/2007/07/dsc00141.JPG\" title=\"dsc00141.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/07/dsc00141.JPG\" alt=\"dsc00141.JPG\" /></a>\r\n\r\nPapa cu pastrav, icre negre (mai rosiatice), daca va intereseaza nu va mai zic.\r\n\r\nDa, am furat mireasa, sh am mers cu ea in locul cel mai select din toata asezarea: birtul comunal. Unde am beut o votca mica. Sh ne-am intors sh le-am dat un bon fictiv de 1000 lei de consumatie, sh i-am zis nasului olandez sa plateasca, ca asta e mai sgarcit, sh tre\' sa simpta ca o vint la nunta in Romunica. Da\' am renuntat sa mai cerem rambursu\' cand am vazut ca i s-o umflat o vena la tampla care zvacnea violent. Asa ca l-am pus sa faca pe amorezu\' gay sh sa incerce sa il agatze pe Ovidiu, care e destul de mascul, sh o mimat destul de bine! Bag sama de bucurie ca nu mai trebuia sa plateasca nimic. Sau oare finca avea experienta la agatat masculi...? In fine.\r\n\r\nP-orma, pedeapsa ca masculii ambelor perechi de nash sa danseze la sentiment pe o manea cantata apsolut superb de mine laiv la microfon, ceva cu despartire, curva dracului, iti rup curu\' cand te prind sh tie sh lu ma-ta aia proasta cu care semeni tu, etc. Pocaitii (ca am avut sh d-ashtia la nunta) or cam bolovanit ochii, da\' n-or zis nimic! Sper sa se fi rugat pentru sufletul meu pacatos in sinea lor, ca sincer am mare nevoie.\r\n\r\nP-orma, cand negociam noi mai abitir si vroiam sa ii punem pe nanashi sa imite pasaricile din padurea Letea la microfon, altcineva ne-o furat mireasa! Sa fure de la mine, ma, la mine-n tzara! O furat-o patronu\' lu Tibby, care e american (asta venise la nunta IN SANDALE SPORT!!!)\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/07/dsc00004.JPG\" title=\"dsc00004.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/07/dsc00004.JPG\" alt=\"dsc00004.JPG\" /></a>\r\n\r\nSh no - l-ash fi pedepsit io, da\' mi-i ca avioanele americane is deja la Constanta, sh de-acolo pan-aci un F16 ajunge in 30 minute fix, ca astea nu is aparate care se opresc sa are ogoarele patriei mele, ca Migurile 21. Asha ca l-am lasat in plata Domnului, mai ales ca nashu\' ala roman-roman ii ficior cumsecade, sh n-am vrut sa il vatÄƒm in vreun fel, Doamne fereshte!\r\n\r\nLa final: Nicu Bendea (Comedica) o cam dezbatut teorii complementare de urinoterapie, facut sala sa se cam pishe pe ea de ras. Asta e. Mishu o cantat la chitara (sh asta cand canta, apai canta! ca unii atata or oftat cand asta canta, ghe Doamnie feri!)  sh am avut sh un foc de tabara, dar daca mergeam sa il pozez pierdeam locu\' privilegiat de langa lada de bere, asa ca am zis ca ma lipsesc.\r\n\r\nPS: In buna traditie romaneasca, ii intreb pe ceilalti nuntasi: voi cat ati pus la nunta? Si pe Tibby: cat ai scos de la nunta?','Nunta Tiberiului',0,'','publish','open','open','','nunta-tiberiului','','','2007-07-23 16:26:07','2007-07-23 14:26:07','',0,'http://www.groparu.ro/?p=537',0,'post','',4),(538,1,'2007-07-23 16:03:31','2007-07-23 14:03:31','','dsc00141.JPG',0,'','inherit','open','open','','dsc00141jpg','','','2007-07-23 16:03:31','2007-07-23 14:03:31','',-1185194746,'http://www.groparu.ro/wp-content/uploads/2007/07/dsc00141.JPG',0,'post','image/jpeg',0),(539,1,'2007-07-23 16:05:07','2007-07-23 14:05:07','','dsc00004.JPG',0,'','inherit','open','open','','dsc00004jpg','','','2007-07-23 16:05:07','2007-07-23 14:05:07','',-1185194746,'http://www.groparu.ro/wp-content/uploads/2007/07/dsc00004.JPG',0,'post','image/jpeg',0),(540,1,'2007-07-23 17:06:47','2007-07-23 15:06:47','- V-a dat cineva voie sa faceti poze in restaurant? intreaba doamna aparuta ca din senin langa mine.\r\n\r\nImi inghit saliva cu greu.\r\n\r\n- Doamna scumpa, zic eu cu o prezentza de spirit daneza, ma iertati, dar in viatza mea nu am vazut trei greseli gramaticale, ortoepice, organoleptice sh de punctuatie intr-o singura fraza publicitara!\r\n- Da? Ce anume e gresit?\r\n\r\nIi zic.\r\n\r\n- Si de ce faceti poza sh numelui firmei?\r\n- Voi avea grija sa nu apara sh numele firmei, zic io.\r\n\r\nPromisiune indeplinita, desi era facuta unei femei. Voi v-atz prins care erau greshalele?\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/07/dsc00077-1.JPG\" title=\"dsc00077-1.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/07/dsc00077-1.thumbnail.JPG\" alt=\"dsc00077-1.JPG\" /></a>','Intamplare cu patzanie II',0,'','publish','open','open','','intamplare-cu-patzanie-ii','','','2007-07-23 17:06:47','2007-07-23 15:06:47','',0,'http://www.groparu.ro/?p=540',0,'post','',19),(541,1,'2007-07-23 17:06:08','2007-07-23 15:06:08','','dsc00077-1.JPG',0,'','inherit','open','open','','dsc00077-1jpg','','','2007-07-23 17:06:08','2007-07-23 15:06:08','',-1185202539,'http://www.groparu.ro/wp-content/uploads/2007/07/dsc00077-1.JPG',0,'post','image/jpeg',0),(542,2,'2007-07-24 21:55:26','2007-07-24 19:55:26','<a href=\"http://www.groparu.ro/wp-content/uploads/2007/07/dsc07286.JPG\" title=\"dsc07286.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/07/dsc07286.JPG\" alt=\"dsc07286.JPG\" /></a>\r\n\r\nAsta vine de la nashu\' meu, care e un balzacian otzara mai mare ca nevasta-sa, care mie mi-e nasha, sh care amandoi n-or facut copii, ca asha s-or hotarat ei, sau ea, cÄƒ intr-un cuplu femeia conduce, nu barbatu\', ca d-aia barbatii mai pun mana pe cate-un retevei sh le altoieshte pe unele femei sh cred ca asa preiau controlu\'! (bullshit)\r\n\r\nDeci il prind io pe nashu\' aptziguit, sh tocma cand mama me (care de fapt e-o doamna) zicea: ioaaaaai, mai copii, da\' cata bere ati loat! (erau numa vreo 90 de beri la vreo 3 guri insetate, intr-o sambata, la tzara). Sh ma traje deoparte, sh zice:\r\n\r\n- Las-o tu pe mamÄƒ-ta-n pace, si zi mersi ca amu se poate! Ca tu stii cum era cand eram noi? <em>Pe vremea noastra?</em>\r\n\r\nMie mi-or placut mereu povestile alea din vremea pestelui de pe televizor sh telejurnalului cu stiri despre tovarashu\'.\r\n\r\n- E, zice nashu, fii antena: meream la padure - de unde corturi de stat peste weekend cu fetele! de unde! - patru-cinci baieti sh tat atatea fete (ca pa vremea noastra nu iereau homosexuali) cu o sticla de vin. Toti. Si era misto.\r\n\r\nNormal ca era misto.\r\n\r\n- P-orma, zice, ne-am loat biciclete. Deja eram mai cu tuleiele prin barba. Plecam cu doua sticle de vin, una pt noi, si una pentru fete, pe care o beam tot noi. Asa. Stii?\r\n\r\nStiam, ca inteleg perfect limba romana.\r\n\r\n-Dupa aia, \'ce nashu, plecam fiecare cuplu cu sticla lui de vin; sh am inceput sa ne insuram pe ici pe colo, sh sa stam peste noapte pe la foace de tabara.\r\n\r\nNaspa, oameni insurati, toti laolalta, pipaindu-si nevestele pe supt paturi. Asa era pe vremea aia!\r\n\r\n- P-orma, zice nashu\', am inceput sa ne lom Daaaaciiiiii :D tac-tu - Skoda 120 L, ca asa o fost el mereu, mai capos (da, tata e mai capos, sh sh io is capos!) sh-o vrut alta masina. Sh amu - aveam ditamai portbagaju! Sh-am inceput sa caram vinu\' cu damijenile. De 3 litre, de 5,... bidonashe... ce era pe vremea aia!\r\n\r\nAsa era pe vremea aia.\r\n\r\n- Sh-apa\' - \'ce nashu\' - gata, ca s-or dezlantuit baierile, mai hinule. Loam damijana de 5 litre, plus bere, cat ducea portbagaju; sh mereu-mereu ramaneam fara combustibil pe sambata seara, sh dumineca meream in sat sa lom bere de la crajma satului - cu pile, cu ciubucuri, cu rugaminti in genunchi, cu tat ce puteam sh noi!\r\n\r\nDa\' se descurcau, oamenii! Ca nashu-meu, balzacian cum e el, nu poate negocia ceva din care sa iasa in pierdere. Ca e iute la gura, sibian d-ala care pica mereu in 5 picioare, o fo\' sh shaf de sindicat pe vremea aia.\r\n\r\n- S-apa - zice - mai chiraiau ele muierile, ca <em>al meu iara n-o nimerit cortu asara decat la a patra incercare</em>, sau <em>iar o confundat nevestele, </em>da\' cine le baga in seama?\r\n\r\nNimeni.\r\n\r\n- Si-ntru-un final, zice nashu, o vint revolutia, sh din p*** ficat! ca deja eream batrani. Asha ca zic io, asa, impotriva lu mama-ta, care de fapt e-o doamna: cu vremile astea nu te mai intalneshti!\r\n\r\nNici io nu cred ca ma mai intalnesc, eventual pe vesnicele plaiuri ale vanatorii, la care, din cauza ca nu sunt populate cu nimfe cu sanii dezgoliti, nu prea ma grabesc sa ajung.\r\n\r\nSanatate!','Despre cum se bea inainte',0,'','publish','open','open','','despre-cum-se-bea-inainte','','','2007-07-24 21:59:22','2007-07-24 19:59:22','',0,'http://www.groparu.ro/?p=542',0,'post','',3),(543,2,'2007-07-24 21:58:12','2007-07-24 19:58:12','','dsc07286.JPG',0,'','inherit','open','open','','dsc07286jpg','','','2007-07-24 21:58:12','2007-07-24 19:58:12','',542,'http://www.groparu.ro/wp-content/uploads/2007/07/dsc07286.JPG',0,'post','image/jpeg',0),(544,2,'2007-07-25 11:32:53','2007-07-25 09:32:53','Â <a href=\"http://www.groparu.ro/wp-content/uploads/2007/07/rotation-of-dsc00448.JPG\" title=\"rotation-of-dsc00448.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/07/rotation-of-dsc00448.JPG\" alt=\"rotation-of-dsc00448.JPG\" /></a>\r\n\r\nAmu nu vreau sa ma gandesc cat mijto as face eu de turisti daca as fi deltaic, ghid cu barca, sh ar veni la mine neshte ardeleni tantalai, cum am fo\' noi, d-aia care pune botu\' la orice. Da\' faza asta merita zisa.\r\n\r\n\'ce Luci, ghidu\', asta de incolaceshte sherpi pe manutza:\r\n\r\n- Vin pescarii, prin septembrie. Ii cazez la mine. Dimineatza zic: Ba Luci, noi merem sa pescuim, lom barca, ne vedem desara, fa-ne o zama de peshte, OK?\r\n- OK, zice Luci, meretz.\r\n\r\nDupa 14 ore, suna telefonu\' lu\' Luci.\r\n\r\n- Luuuuciiii, zice o voce plangareatza de pescar, vii sa ne iei d-aci???\r\n- Da\' unde suntetz, zice Luci.\r\n- Nu stim!\r\n- Cum nu stiti?\r\n- Nu stim, ne-am ratacit... toate canalele arata la fel, puii mei!\r\n- Of, zice Luci, bine mah, vin sa va iau...\r\n\r\nSh pleaca sa ii ia. Sh ajunge (cum dreq???) langa ei, sh le zice la telefon:\r\n\r\n- Ba, fii atent la mine-aci! Apucati-va sh strigati, sa-mi dau seama unde suntetz.\r\n\r\nAstia se apuca sa strige, cu lacrimi amarui:\r\n\r\n- LUUUCIIIIIII... :(( LUUUUUUCIIIIIIIIIIIIIIIIIIIIIIII :(((((\r\n\r\nAsta mere tiptil langa ei, sh le apare-n spate, ca un mic Rambo, sh le racneshte in ureke, de astora le scapa inima in kilotz:\r\n\r\n- BAAAAAAAA!!! Haidetz sa merem ca se raceshte zama de peste.','Faza din Delta',0,'','publish','open','open','','faza-din-delta','','','2007-07-25 11:32:53','2007-07-25 09:32:53','',0,'http://www.groparu.ro/?p=544',0,'post','',21),(545,2,'2007-07-25 11:32:18','2007-07-25 09:32:18','','rotation-of-dsc00448.JPG',0,'','inherit','open','open','','rotation-of-dsc00448jpg','','','2007-07-25 11:32:18','2007-07-25 09:32:18','',-1185353970,'http://www.groparu.ro/wp-content/uploads/2007/07/rotation-of-dsc00448.JPG',0,'post','image/jpeg',0),(546,1,'2007-07-27 12:14:32','2007-07-27 10:14:32','Va rog frumos sa comentati orice avetz chef la aceasta postare, care de fapt nu e o postare, ca e numa o fraza, cam lunga, e drept, dar tot fraza ramane, dar care totusi nu vorbeste despre nimic!','Postare pentru comentat',0,'','publish','open','open','','postare-pentru-comentat','','','2007-07-27 12:14:32','2007-07-27 10:14:32','',0,'http://www.groparu.ro/?p=546',0,'post','',21),(547,2,'2007-07-27 18:02:00','2007-07-27 16:02:00','Adica nu la munte, ci la Belish. Sh daca nu poci face baie in lac, in bere tat oi face!\r\n\r\nNe revedem dumineca seara. Sper cu un cap problematic cat Yugoslavia!','Groparu pleaca la munte',0,'','publish','open','open','','groparu-pleaca-la-munte','','','2007-07-27 18:02:00','2007-07-27 16:02:00','',0,'http://www.groparu.ro/?p=547',0,'post','',3),(548,2,'2007-07-29 23:20:14','2007-07-29 21:20:14','Booon. Dupa cum ziceam, is proaspat intors de la un weekend DEMENTIAL pe malu\' unui lac de munte, sh a unei balti cu bere. A, si cu vin. A, ca sa nu mai zic de coniace. Sh tigari.\r\n\r\nIn primu\' rand, ca sa ajung acolo o trebuit sa ii sparg okelarii lu gajica-mea, ca alfel nu intelegea anumite chestii, cum ar fi ca intr-un concubinaj masculu\' trebe lasat macar cu iluzia ca el conduce relatia, ca stim sh noi ca n-avem nici o sansa, ca tot cum vrea ele facem. Lasand gluma la o parte, i-am spart ochelarii, sh am ras nervos, finca era perechea de  rezerva, ca prima i-o sparsesem (tot eu, tot din greseala) in Delta. Najpa moment.\r\n\r\nMnoa, am ajuns acolo vinerea pe la 10 seara, ca era ziua lu <a href=\"www.doingtheartwork.com\" target=\"_blank\">www.doingtheartwork.com</a>, sh am plonjat derect in galgaieli de bere la foc sh cantece de chitara despre <em>scrum - da! - scrum de tigara, sa treaca totul sh sa dispara</em>, asa-s versurile.  Sh nij nu cred ca are rost sa va mai zic ca ne-o prins dimineatza sh soarele cu mana pe sticloantze; asa ca am facut un efort si ne-am carat pe noi sh pe unditza sh pe niscai bere, merinde pentru oamenii flamanzi, sh am scoborat vreo 20 metri pana la lac. Ca da, mah, era lac mah in care aproape puteai face pipi de pe prispa cabanei!\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/07/dsc00330.JPG\" title=\"dsc00330.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/07/dsc00330.JPG\" alt=\"dsc00330.JPG\" /></a>\r\n\r\nBooon. Clar ca nu am prins nimic, ca la un moment dat ne-am sh incalcit mulineta la cat eram de ansesteziati; asa ca m-am carat inapoi la cabana in patru labe, sh am incercat sa nu imi rup gÃ¢tzii uitandu-ma la veveritzele care alergau ca apucatele prin copaci, ca ma simteam ca Alba ca Zapada, atata numa ca io nu cantam muzica din Walt Disney, ci singurele sunete pe care le scoteam erau alea din cazaturi, sau cand faceam shushu. A, sh am mancat zmeura langa ceva chestie imbracata intr-o blana maro.\r\nAm ajuns, m-am bagat in pat, sh de disperare sau din nu mai stiu ce motiv, am reusit sa pic din pat, dar fara sa reusesc sa ma trezesc. Sh am dormit asa in continuare pe podea,\r\nsh am rezistat eroic tuturor incercarilor colocatarilor de a ma sui inapoi.\r\n\r\nA doua zi, clar ca am facut baie, am plecat cu barcutza pe lac, sh am scuipat in mijlocu\' apei ca sa fac rotocoale; sh m-am bucurat de liniste aproape la fel de mult ca de bere. Sh cand am revenit cu barca la mal, un nene tatic cu lacrimi in ochi m-o rugat frumos sa ma dau sh cu fetele lui, una bunaciune de 13 anishori, sh alta care promitea o groaza de la cei 7 anishori ai ei, da\' sa le dau io cu barca, ca el nu poate ca are mainile ocupate cu (atz ghicit) una bucata tigara sh una bucata bere. Sh am vorbit cu fetele cate-n luna sh-n soare cand ne faceam plimbarea noastra romantica pe lac; le-am spus inclusiv sa isi ierte parintii daca is obraznici cu ele.\r\n\r\nSh-apa am mers inapoi la desishul de zmeura, sh ne-am ghiftuit.\r\n\r\nBoooon.\r\n\r\nDupa o vreme, pescaru\' de serviciu a gashtii o mars la ce stia mai bine sa faca: sa pescuiasca. Sh am petrecut seara cu batzu\' in mana, in cea mai ucigatoare liniste, prinzand cleni dilÄƒi, pe care i-am sh facut in folie cu legume  seara, despre care retzeta voi vorbi maine mai pe larg, finca este una din hranele zeilor sh nu as vrea sa merg in groapa fara sa v-o zic.\r\n\r\nCert este ca seara aia am racnit la cantece pana pe la 5 dimineatza, sh a doua zi iara am facut baie ca nesimtitii, sh am jucat Mafia pana tarziu in noapte, sh numa\' amu am venit inapoi, sh is super obosit asa ca poate mai apdeituiesc scriitura maine. Punctum. A, sh am sh mancat la zmeura azi cel putin 5 kile pe cap de vita furajata. Ati baut vreodata zmeura din pahar cu Zaraza? E gros, mai copii!','Weekendu\' asta o cam Belish!',0,'','publish','open','open','','weekendu-asta-o-cam-belish','','','2007-07-29 23:20:14','2007-07-29 21:20:14','',0,'http://www.groparu.ro/?p=548',0,'post','',26),(549,2,'2007-07-29 23:18:06','2007-07-29 21:18:06','','dsc00330.JPG',0,'','inherit','open','open','','dsc00330jpg','','','2007-07-29 23:18:06','2007-07-29 21:18:06','',-1185740819,'http://www.groparu.ro/wp-content/uploads/2007/07/dsc00330.JPG',0,'post','image/jpeg',0),(550,1,'2007-07-30 16:30:44','2007-07-30 14:30:44','Mnoa, are Groparu asta un prekin, sau amic, sau dujman, sau whatever, care desi e baiat bun, e si destul de inginer. Sh faza asta s-o petrecut cu ceva vreme in urma, recte vo trei ani, da\' ce-s trei ani la scara universului?\r\n\r\nMnoa, mere asta sa isi faca baia anuala unde altundeva decat la bazinu\' olimpic. Ghe la Cluuuj.  Clar ca nu face dush inainte de a intra in bazin, finca se stie ca cei mai multi microbi, inclusiv bacteria aia vesela de face cancer la prostata sau parameciu\' ala care da generos HIV-ul se iau de la dush, nu din bazin. Sh mai e sh periculos sa faci dush cu masculii sh sa iti scape sapunu\' pe jos, sh prekinu\' meu nu are incredere in geluri de dush, finca alea se pot foarte usor transforma in lubrefiant anal. Oare le-o fi patit? Nush.\r\n\r\nSh deci, intra asta in bazin, sare o burta d-aia spectaculoasa, sh incepe sa deie din bratze ca un apucat. Sh pac, face aproape o juma de tura de bazin, se opreste sa se uite in jur, vede ca nici o gajica nu se uita la el, sh continua sa inoate catzaleshte, stiti voi, stilul ala de inot al sugarilor. Sh cum inoata el asha voiniceshte, printre fire lungi de par sh petice albe de piele de la ceilalti inotatori care si ei se feresc de dush inainte de a intra in bazin, zgarie foarte serios cu copitutza din dotare o alta persoana, are facea scufundari langa el. Asta, fiind baiat cu bun simtz peste medie, scoate un \"scuzati-ma, nu va suparati!\" - asa, ca un ardelean politicos sh dornic de a lega prietenii noi la piscina cu barbati imbracati numai in slip sh in casca de inot.\r\n\r\nFinca nenea scufundac nu zice nimic, asta continua sa inoate, da\' dupa inca trei pedalari prin apa, aude numa\' o tiuitura in ureche; tiuitura aia incepe sa se transforme intr-un fluierat de arbitru de la galeria echipei U Cluj, pana cand tipuritura moare, sh e urmata de un pleoscait viforos in ape. Sh se uita cu  o scarba cadavrofoba cum cineva sare in apa sh il ia pe nenea ala pe care-l zgariase el cu copitutza, sh incearca in van sa il scoata la suprafatza.\r\n\r\nDa. Zgariase cu copitutza un cadavru al unui om care fusese candva viu, dar care proaspat daduse coltzul din motive neelucidate chiar langa traseul pe care inota el catzaleshte.\r\n\r\nNu stiu daca in urma acestei traume s-a hotarat el sa devina inginer, finca sincer nu ma intereseaza.','Din seria \"nu conteaza, ca io numa ieri am aflat!\"',0,'','publish','open','open','','din-seria-nu-conteaza-ca-io-numa-ieri-am-aflat','','','2007-07-30 16:30:44','2007-07-30 14:30:44','',0,'http://www.groparu.ro/?p=550',0,'post','',18),(551,1,'2007-07-31 16:09:32','2007-07-31 14:09:32','Nu Petre Roman ala care umbla cu manelista, de o chemat minerii sh nij n-are niciun pkik de gÃ¢t. Nu, Petre Roman asta e un baiat kiar super sh - oare intamplator? - sh foarte inginer. Deci, poezeaua-manea de rigoare:\r\n\r\nSa mananci cartofi prajiti,\r\nSh semintze, sh berici,\r\nDrumu-n viatza drept sa-ti fie,\r\nSh ani sa traiesti o mie,\r\nSa nu-ti moara putzulica,\r\nSa-ti traiasca sh fetica,\r\nMandri plozi cu ea sa faci,\r\nFericire s-ai in saci,\r\nBani in cont sa ti se adune,\r\nSa-i dai pe tuica de prune,\r\nNu pe toti, numa\' pe unii\r\nCa tu nu bei ca nebunii!!!\r\nSa n-ai in viatza probleme,\r\nSa nu mori in veci de lene,\r\nSh sa nu mori niciodata,\r\nS-ai chilotzii fara pata\r\nLa Multi Ani, si frunte lata!\r\n\r\nDa, bah, La Multi Ani!','Noptile astea o fost ziua lui Petre Roman',0,'','publish','open','open','','zilele-astea-o-fost-ziua-lui-petre-roman','','','2007-07-31 16:09:54','2007-07-31 14:09:54','',0,'http://www.groparu.ro/?p=551',0,'post','',6),(552,2,'2007-07-31 19:59:49','2007-07-31 17:59:49','<strong>I. Pestele</strong>\r\n\r\nIn primu\' rand, trebe sa faci rost de peste, finca io is de parere ca nu poti sa faci peste in folie daca nu ai peste.\r\nPoa\' sa fie orice peste mititel daca l-ai prins tu la pluta; sh se stie ca pestele nu se prinde decat daca esti bine abtiguit. Daca prinzi peste si esti abtiguit, oricum nu mai conteaza cat de bun e pestele in folie.\r\n\r\nDaca nu, rogi colegu\' sa iti dea legitimatia de la Metro, dai o fuga acolo, sh iei pastrav. Nu e musay sa fie mare pestele; e bine sa fie mic, sa se patrunda mai bine, daca esti zgarcit cu legumele.\r\n\r\nBooon. Avem pestele: cum procedam?\r\n\r\nPestele - dupa cum bine se stie - are nevoie, ca si femeia, de tandrete. Asculta-l ce iti zice: vei afla chestii interesante. Daca nu ai chef, macar fa-te ca intelegi; va ajuta mult. Cand esti gata, eviscerezi ce trebe eviscerat; daca eviscerezi femeia, atunci o arunci intr-un lac mare, ca sigur nu se mai umfla gazele in ea sh nu mai iese la suprafatza, o manca racii, daca putrezeste nitel, sh tu ai toate sansele sa scapi de parnaie finca doara se stie, daca pola cadavru, atunci pola parnaie! Dar sa nu o bagi in frigider, ca e riscant! Daca eviscerezi pestii, ii asezi pe toti unu langa altu, te uiti la ochii lor de soacra, te bucuri ca tu ii papi pe ei, nu verishorii lor de prin oceane pe tine, sh oftezi ranjind, bucuros de viatza.\r\n\r\n<strong>II. Legumele</strong>\r\n\r\nAl doilea ingredient: legumele. Io prefer ceapa, usturoi, lamai (cu tot cu coaja), ciuperci (da\' sa nu fie ciuperca d-aia de picior, de se ia de la strand, de trebe unguent la ea), sh ardei. Bag sama ca daca bagi sh dovlecel, rosii sau orice alta pastaie e kiar ok; da\' sa nu uitati de frunze - marar cat mai mult, patrunjel care trozneste intre dinti si ramane intre ei, de se vad cand zambesti, chiar si nitica frunza de telina, daca e toamna sh ai gradina. Leusteanul, de asemenea, face casa buna cu pestele, de zici ca-s frate sh gajica-sa. Cand ai toate astea, le tai, asa, cu dragoste, sh le vorbesti ca la nevasta-ta aia de ai aruncat-o in lac, eviscerata. Amestecu\' se amesteca - tot cu dragoste multa, multa - intr-un bol de plastic rosu. Asa. Cand toate legumele se uita la tine, casapite, inspicate de verdeatza frunzelor sh nerabdatoare sa fie infoliate, scoti neshte ulei de masline (extra-virgine, de la <a href=\"http://www.andreicrivat.ro\" target=\"_blank\">Crivatz</a> citire, desi io tot mai cred ca in ziua de azi nu mai exista virgine) sh torni peste amestec atata numa cat dureaza, odata cu susurul suvoiului galben, sa soptesti \"Nascut din spermatozoizi campioni\". Musay sa zici descantecu\' asta, c-alfel amestecu\' se supara sh o sa aiba gustul care-l are pentru ailanti, care nu-s nascuti din spermatozoizi campioni!\r\n\r\n<strong>III. Beutura</strong>\r\n\r\nDaca ai pestele, musay sa ai sh beutura: <em>poisson sans boisson est poison</em>, zice franciezu\'. Daca e peste, e clar vin alb. Destupi sticla, ii injuri p-aia care fac vin din pastile (daca e vin de cumparat) sau UE care ne va lasa fara vin facut in casa (daca e vin de la socru\'); zici un Doamne-ajuta! sh tragi o dushca sanatoasa. Daca iti place vinu\', mai tragi una; si apoi torni un picutz de vinishor alb in amestecul de mai sus, sa se prelinga asa ciudat intre uleiul de masline. Sh apai amesteci totu\' inca o data. Sh pui condiment, sh iar mai amesteci.\r\n\r\n<strong>IV. Prepararea</strong>\r\n\r\nBooon. Iei o bucatica de unt, ungi folia pe partea pe care pui pestele. Iei pestisorii eviscerati ca nevasta de la punctul anterior, unu cate unu; ii mangai cu dragoste, ii sarezi sh condimentezi cu multa grija sh afectiune, ii umpli cu amestecul ala, presari si in stanga sh in dreapta lor cateva legume, sh ii inchizi pe fiecare in parte cu folia, in asa fel incat zama aia care va iesi din ei sa nu picure pe gratar cand se va infierbanta; ca e pacat de la Dumnezeu, care nu iarta asemenea pacate mortale, ca io stiu, ca asa mi-or zis vocile. Cand e gata, o sa fie fiecare pestiuc bine invelit in folie doldora de legume, ca un trup de femeie proaspat iubita care se inveleste transpirata in cearceaf, de i se vad formele sh sfarcele cum strapung tesatura transparenta, promisiune de sh mai multe voluptati ulterioare, daca te mai tine putulica.\r\n\r\n<strong>V. GRATAREALA</strong>\r\n\r\nPe gratarul incins, asezi foliile una cate una. Jarul, sper eu, a fost aprins cand te incalzeai sau racoreai cu palinca, sau, minim respect, cu coniac. Astepti; iti aprinzi tigarea de la jar, ca are gust mai bun asa, mai spui un banc, le mai spui prietenilor de blogu\' meu, mai intorci pestele, asa, si astepti. Daca jarul e sanatos, in 15-20 minute maximum pestele e gata pe ambele parti. Desfaci usurel folia, gusti legumele sa fie facute, sh strigi la toata gasca ca e gata papa.\r\n\r\nMusay sa uzi gatleju cu vin alb cand bagi chestia asta in fizic. Asculti pe toti cum se mormaie de placere, razi in sinea ta de astia cum manca pestele cu mana, le faci poze, sh te pregatesti sa primesti complimentele care este.\r\nSh daca totusi vrei sa te simti balonat dupa asa o papa ultra-usoara, recomand porcul. Dar cu  carnea de frate porc prajita pe gratar, e o cu totul sh cu totul alta poveste...','Deci, pestele in folie e o folie!',0,'','publish','open','open','','deci-pestele-in-folie-e-o-folie','','','2007-07-31 19:59:49','2007-07-31 17:59:49','',0,'http://www.groparu.ro/?p=552',0,'post','',7),(559,1,'2007-08-02 15:34:04','2007-08-02 13:34:04','Finca Justin Timberlake, Beyonce sh Britney nu vin sa concerteze in Romunica, asta e, ma multumesc sh cu Goran, care va ne va inalta mai sus decat poate marijuana cu metamfetamina - in Piata Mare din capitala cortorara a patriei mele sh a continentului pe care tocma\' ce l-am anexat.\r\n\r\nFaza najpa e ca merg cu 4 gajici in mashina (!) sh in total suntem numa vreo 9, din care 2 masculi (!!!). Partea asta najpa reprezinta in acelashi timp sh partea cea mai cool a expeditiei. Daca nu supravietuiesc, sa rÃ¢detz otzara de ridicolu\' situatiei, ca io unu o sa rad pana raman tzapan: groparii il vor ingropa pe groparu! Hihihi...','Ma duc la Goran Blegovici',0,'','publish','open','open','','ma-duc-la-goran-blegovici','','','2007-08-02 15:34:04','2007-08-02 13:34:04','',0,'http://www.groparu.ro/?p=559',0,'post','',11),(558,1,'2007-08-02 11:14:07','2007-08-02 09:14:07','Mail primit azi-dimineatza de la Ayesha Kadir, prekina mea musulmanca americanca super-cumsecade:\r\n\r\n<em>dearest family and friends,\r\n\r\nthanks for all of your calls and messages. i  just wanted to let everyone know that i am fine. i was not driving over the  bridge that collapsed today, although i had a bit of a shock, as i was supposed  to be crossing it at the time it collapsed. because of the construction, i chose  to go a different route at the last minute... it brings one\'s own mortality into  sharp view. thankfully i\'m quite well. i hope and pray that this finds all of  you well, too.\r\nlove\r\nayesha</em>\r\n\r\nConcluzia Groparnicului: profitati, mai copii, de viatza, ca vremea p*lii trece!!! Sh-intr-o buna zi, v-oi zice cum era sa kiara Groparu\' in drum spre Budapesta, sh ce ganduri l-au incercat ulterior, sh  ce pohta de viatza il tot kinuie d-atunci, ca de-atunci in viatza mea nu am mai intalnit o bere care sa nu sfarseasca la mine in vintre!','Cand esti la un fir de par de a juca ÅŸah cu Teoctist',0,'','publish','open','open','','cand-esti-la-un-fir-de-par-de-a-juca-sah-cu-teoctist','','','2007-08-02 11:14:07','2007-08-02 09:14:07','',0,'http://www.groparu.ro/?p=558',0,'post','',5),(556,1,'2007-08-01 17:41:32','2007-08-01 15:41:32','Da, ma, stateam la ocazie, eram anu I, februarie, tocmai parasisem un asternut cald de camin cu cineva in el, ca trebuia sa ajung la Sibiu, ca avea prekinu meu de la gradinitza Neatza juramantul militar, ca el nu o fost la fel de norocos ca mine sa intre la facultate dupa a treia (!) incercare, ca mine.  Era 8 dimineatza, sambata, pustie Calea Turzii, eram numai eu sh profesionistele (Puiule, te fac o clantza? Servus, Marocano, tu erai, nu se poate, inca nu s-or dat bursele!) Sh fluturam cartonu\' cu SIBIU bolduit cu picsu\', doar-doar sh-a face vrunu\' mila.\r\n\r\nSh, intr-un final, opreste un TIR verde, de Bucale, cu Sandu la volan. Salut, ba, io is Groparu, Groparu? Ce nume e asta? Nu e nume, mah, da\' suntem pe net, nu intelegi ca asta e fain pe net, ca te poci da anonim fara nume? Du-ma la Sibiu sh nu ma mai imbarliga. Ba, zice Sandu, te duc, da\' vezi ca io ma cam grabesc, ca azi se marita sor-mea in Bucuresti, sh io trebe sa ajung cu astea 30 de tone de oua din spate (pe vremea aia inca nu era restrictie de 22 de tone incarcatura pe tiruri) intacte, din Spania le aduc, da\' io ma grabesc, ce pana mea! Asa ca daca vrei sa mergi mai in sigurantza, nu te urca. Ej nebun, zic io, nu vezi ca de frig imi scot mucii tzurtzuri din nas, ca mi-am lasat manusile amanet intr-un bar! Du-ma, numa sa fie cald sh sa ajung intr-un final. Bineeeee, zice Sandu, da vezi ca tre\' sa stai cu genunchii la gura, ca am lazile astea de ulei, le duc la mama unui prekin, asta e! Sh n-am nici centura de sigurantza, pa, s-o dus. Sh se ghemuie Groparu in pozitia aia ombilicala; sh imi amintesc cum imi miroseau genunchii a podea de camin, de la ultimu\' chef in care n-am mai ajuns decat in 4-5 labe acasa.\r\n\r\nBooon. Ficioru\' urca Feleacu\' sforaind, TIRu\' gafaia, eleroanele troznea - sau nu, ca alea cica numa la avioane este - oricum, panta mare pt 33 de tone. Da\' trecem de culmea Feleacului, sh bai frate, bai, de nu-ncepe Sandu asta al meu, mah, neshte janseuri sh depashiri pe banda dubla continua, de mi-o stat inima-n loc, de am si crezut ca mor inaintea lu\' Teoctist!!! Imi ascundeam privirile infricoshate dupa genunchiuri mirositoare, ma tineam de ce apucam prin cabina, da\' TIRu\' era un Volvo d-ala cu botul bont, de vedeam cum zboara soseaua pe sub picioarele mele, alea cu care ma taram io de la chefuri, sh am zis: daca asta se isbeste de ceva, voi zbura pana pe statia spatiala MIR (pe vremea aia inca exista) sh o sh strapung de la velocitate!\r\n\r\nBun, gonim noi, depasim coloane de tiruri pe contrasens in curbe cu vizibilitate redusa, incepem sa ne imprietenim, calcam un cutzu mare, ciobanesc, langa Turda, unde e panta aia mare care urca, da\' sh coboara daca vii dinspre Cluj, sh TIRu\' nij macar nu s-o hurducat; ca la 36 de tone in spate, cum dreq sa simtz ceva? Sh - da\' de fapt nu de asta vroiam sa va istorisesc, ca nu asta e important, pulsul meu de gropar care imi batea in vena aia de se umfla cand cÃ¢nt sh copilaria mea de copkil abuzat de vecinu\' Luci de vizavi care se derula in fata okilor mei uimiti; ci istorioara pe care mi-o istorisit-o omul care avea drept de viatza sh de zburat prin geam asupra mea - Sandel, de!\r\n\r\nDeci: \'zce Sandel, care avea 2 metri sh 130 de kile: veneam odata din Portocalia cu nush ce incarcatura, nu ca astea 39 de tone de acum, sh vad o bunesa la ocazie. Curatzica, studenta, frageda sh crocanta. Statea sh vroia sa o duc acasica, da ea statea in Tg Mures, sh io meream prin Sibiu. Sh incepe sa se roage de mine haaaaaaaaai, ma, faaa maa Sandel maaa un occoooool, mah, prin Targu Mures! Io nu sh nu, ca io am traseu meu, da\' pan la urma ma-ndupleca, ca asa sunt io, inima slaba de mascul sh cedez cand o bunesa ma roaga ceva. Sh merem noi pe drum, mai o poveste, mai una-alta, sh zice Sandel: Tu fato, da-mi sh mie nr tau de telefon, poate om bea sh noi o cafea cand mai dau prin Cluj! Pai io n-am mobil, zice domnisoara, ca asa era pe vremile alea, nu toti aveau. Da\' daca vrei, zice ea shagalnic, iti pot da nr camerei mele de la camin, sh vii direct acolo, ca <em>io stau serile acasa, sh invatz. </em>Gata, zice Sandel, deci camin 4, camera 67, parca era, nu mai stiu exact. O lasa pe domnisoara in Tg Mures, sh el pleaca la Bucale. Da\' dupa 2 saptamani, are drum iara prin Cluj, sh zice: ia hai ma sa vedem ce iasa cu crocanta!  Asa ca trage pe marginea drumului, se spala cu apa distilata de curatzat parbrize, se sh barbiereshte, pune un kil de spray pe fizic, parcheaza TIRu\' undeva pe unde apuca, ia un tacsi, ia un tufish de flori, sh zang! Repede, in caminu\' 4. Shpaguieshte portaru\' cu o tigare, urca la etaju 3 unde era camera 67, sh numara: camera 63... camera 64... camera 65... camera 66, astea-s dusurile... sh camera 67: camera 67 era, dragi colegi intr-ale dezamagirilor, nici mai mult nici mai putin decat BUDA caminului. Tzapaaaaa...\r\n\r\nUnde te las? Ma intreaba Sandel, ca deja eram in Sibiu. Lasa-ma aici, la biserica asta, sa multumesc lui Dumnezeu din ceruri ca nu m-o loat la el, sh m-o mai lasat sa mai pacatuiesc. Da-l in pics de juramant, ca mai bine ma imbat io cu Neatza deseara. Drum bun!','Patzanie intamplata cu Sandu, soferu\' de TIR',0,'','publish','open','open','','patzanie-intamplata-cu-sandu-soferu-de-tir','','','2007-08-01 17:41:32','2007-08-01 15:41:32','',0,'http://www.groparu.ro/?p=556',0,'post','',16),(557,1,'2007-08-06 08:55:42','2007-08-06 06:55:42','Direct din Coreea de Sud (cred ca nu din aia de nord), de pe YM, din seria <em>Are sh ei falitii nostri</em>:\r\n\r\n<strong>Pris:</strong> seul, intr-o seara a zilelor trecute, treceam noi printr-un tunel care leaga 2 cladiri de vreo 7-8 etaje fiecare pline numai cu electronice\r\n<strong>Pris:</strong> si vedem homeless-ii (oare ziua unde stau? ca nici tipenie de ei) cum isi construiau paturile\r\n<strong>Pris:</strong> din cutii de carton pe care le legau cu scotch\r\n<strong>Pris:</strong> cum faceam noi cazemate\r\n<strong>Pris:</strong> si faceau ei dupa gust si interes tot felul de arhitecturi\r\n<strong>Pris:</strong> unul dintre ei se opreste destul de nervozat la un mom dat din cutezatoarea activitate\r\n<strong>Pris:</strong> ca... surprise... ii suna mobilul!\r\n<strong>Pris:</strong> am ramas paf, mai ales ca vreo 20m mai inainte vazusem si talpile altui cersetor care se pare ca era mai obosit ca se culcase mai devreme... curate curate, pariu ca mult mai curate ca ale mele care erau in sandale de vreo 2 ore\r\n<strong>Groparu:</strong> ce tareeee :))\r\n<strong>Groparu:</strong> ioai\r\n<strong>Groparu:</strong> pot pune asta pe blog?\r\n<strong>Pris:</strong> feel free\r\n<strong>Pris:</strong> imi pare rau ca n-am avut camera la mine sa fac niste poze\r\n<strong>Pris:</strong> cu tel nu ies prea bine','Din patria catzailor mancatzi cu betisoarele',0,'','publish','open','open','','din-patria-catzailor-mancatzi-cu-betisoarele','','','2007-08-06 08:55:42','2007-08-06 06:55:42','',0,'http://www.groparu.ro/?p=557',0,'post','',1),(560,1,'2007-08-03 14:57:55','2007-08-03 12:57:55','<strong>Me-secina, mesecinaaaaa, iuiu!</strong>\r\n\r\n[google -4979761562167752630&amp;hl]\r\n\r\nMai, copii, mai. Mai, copii. V-am fost ca o mama! Ca o mama v-am fost. Da\' mah, io ce am trait asara nebaut nu se compara decat cu cel putin vreo inca o chestie pe lumea asta, sh asta io creca e cica orgazmu\' ala metadonic de-l au copiii cand se nasc! C-asa se zice.\r\n\r\nDeci Goran ar fi singurul mascul de pe lumea asta cu care Groparu si-ar pune-o o data, bine-nteles, cu conditia ca el sa fie femeie. Asa sa stiti!\r\n\r\nZiceam ca am plecat io cu 4 gajici inspre incolo; total gresit. Am plecat 11 oameni, din care 3 (trei) masculi sh 11-3=8 gajici, sh am ajuns  acolo vreo 15. C-asa e in filme, cand pleci cu trei mashini. Cert e ca tot drumu numa\' asa faceam: <strong>Mesecinaaaa, mesecina, iuiu!!! IUIU!!! </strong>Ca am si crezut ca astia ma arunca din mashina cu violentza, sa dau cu capu\' de bordura gol. Capu\' gol.\r\n\r\nIn Sibiu, capitala cortorara PE BUNE, nu se prea gaseste loc de parcare; sh nu din cauza ca e plin de tiriste in parcari, ci finca (uimitor!) e plin de mashini in parcari! Da\' noi fiind copii cu intelect, am gasit un loc in fatza la morga, sh am tzajnit derect catre Piata Mare, bine-nteles, scandÃ¢nd: <strong>Mesecinaaa, mesecinaaaaa!!! IUIU!!!\r\n</strong>\r\n\r\nIn Piata Mare, purcoi-purcoi de lume, mah. Da\' purcoi, cat tatarii! Ca sibienii e sh ei cortorari. Sh le <em>gustas</em> Gropanii. Sh am inghiontit noi in stanga sh-n dreapta, am ajuns la vro 20 de metri de scena, unde deja se infatzosha mah, mÄƒre, Gropan!!!\r\n\r\nAm ajuns langa el, sh puteam sa-l ating; puteam sa-l iau in bratze sh sa fug cu el in lume, puteam sa ma uit deasupra lui, puteam sa-i fac orice. Cui? Cum cui? Cheliosului de langa mine:\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/08/chelie.jpg\" title=\"chelie.jpg\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/08/chelie.jpg\" alt=\"chelie.jpg\" /></a>\r\n\r\n...finca nu am fo la fel de norocos ca Alin PÄƒtru (sau cinci) care o stat la un scuipat distanta de nenea Gropan, de i-o vuit timpanurile 5 zile dupa concert, ca statea sh langa boxe! Ni ce poza o facut baietu\':\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/08/goran-alin-patru-cinci.jpg\" title=\"goran-alin-patru-cinci.jpg\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/08/goran-alin-patru-cinci.jpg\" alt=\"goran-alin-patru-cinci.jpg\" /></a>\r\n\r\nMnoa, bieata me inimioara deja batea cu maaare violentÄƒ, ca avusÄƒi mai mari emoÅ£ii ca la dezvirginare; Goran m-o vÄƒzut Ã®n mulÅ£ime, i-am facut semn in limba iugoslava sa nu arate lumii ca ne cunoaÅŸtem, sh el o-nÅ£Äƒles. Maaare domn, mare caracter! O vrut sÄƒ zicÄƒ ulterior cÄƒ el numa d-aia o vinit in Sighii, ca sÄƒ mÄƒ vazÄƒ pe mine cum Ã®l ascult, da\' cu acelasi semn iugoslav din mana i-am facut semn sa ii deie pace, ca nu-mi place cand face transfer de notorietate de pe saitu\' meu pe muzica lui. Asa.\r\n\r\n<strong>Mesecinaaa, mesecinaaaa!!! IUIU!</strong>\r\n\r\nIdeea e ca nenea asta din parinti traficanti de benzina peste Dunare le canta, mah, le canta asa de bine ca APROAPE  CA ESTE MAI BUN CA BEREA!!! Sh are sh dume-n fizic: zice bueeeeey (era sa zica Groparu\', da\' semnele mele iugoslave si-or atins targetu\' sh s-o potolit), noi cantam la nunti sh inmormantari; da\' sa nu ne kemati la mormantari, ca zice noi suntem foarte expensivi! ASA CA PLEASE DON\'T DIE!!! (asta mi-o placut, bag sama ca lu Teoctist i-o parut rau cand o auzit, ca daca stia...)\r\n\r\nBooon. Ca sa va facetz o idee, voi, cei 7 cetitori masculi ai saitului meu, despre cum se simte omu\' cu intelect modest (eu, adeca) la concert de mai multi bregovici, imaginati-va ca stati intinsi pe pat, legat fedeles, proaspat dupa un dush; sh in juru\' tau is vreo 20 de fecioare amestecate, brunete, negrese, blonde, maneliste d-alea bunoace, Barbie girls, asiatice, nordice, tat felu; sh tatie te pupa asa gingash, da\' gingash! cu limba sh buzele pe tot corpul tau dezvelit, lasat prada lor intre asternuturi de satin; sh in casti asculti muzica din Matrix la maximum, sh tu sa poti sa urli de fericire, sh eventual sa si pescuiesti in perioada asta, dar sa si bei bere; sh sa ai sh o tigare din care sa gusti alaturea, sau seminte daca nu fumezi. Cam asa e muzica lu Brego\'!\r\n\r\nOricum, what is best is yet to come, cum zice mexicanii. Dimineatza, ma suna prekinu\' meu de lucreaza la aeroport, zis CÄƒcÄƒlin: ba, zice, haidatz la o cafea (era 6 dimineatza) ca amu tre sa pleaca sh Goran cu avionu!\r\n\r\nCand am auzit, claro ca am tzajnit derect in cel mai mare aeroport din Sibiu, sh l-am pus pe CÄƒcÄƒlin sa ne ieie cafele. Sh cum stateam noi, asa, la coada la cafele, numa ce apare doo limuzine cu Capitala Cortorara scris pe ele! Sh dintr-una se scoboara, mare, insushi nenea, mah, nenea Gropan :D\r\n\r\nUn suvoi navalnic de emotie mi-a inundat pieptul meu barbatesc, sh am vrut sa il rog sa face o poza cu mine sh cu celelalte personalitati ale mele, da\' nenea Gropan arata cam distrus; sh dintr-un gest imediat in limba iugoslava mi-o facut semn sa ma potolesc. Asa ca am stat sh am asteptat; nenea Gropan s-o pus langa noi la coada, prekinu CÄƒcÄƒ  ne-o servit pe noi cu cafeauÄƒ, sh la urmÄƒ - pe nenea Gropan. Astea vÄƒ jur cÄƒ is 100% adevÄƒrate, cÄƒ io nu prea mint! Sh ne-am limitat la a-i face o pozÄƒ in aeroport, deÅŸi nu e voie sÄƒ faci poze la cel mai mare aeroport din Sibiu, sh asta e, v-o ÅŸi las spre opservaÅ£ie mai jos.\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/08/goran-aeroport.jpg\" title=\"goran-aeroport.jpg\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/08/goran-aeroport.jpg\" alt=\"goran-aeroport.jpg\" /></a>\r\n\r\nSh spre casa, vreau sa zic ca am dat de un blocaj de circulatie, fitz antena numa cat de mare:\r\n\r\n[google -8506882910965379230&amp;hl]\r\n\r\nSh gata, amu suntem in Cluj, Goranovori pana la muarte, sh abia astept sa merg desara in Autograf, unde e iara ceva conciert de muzikie tiganeasca!','Gropan Bregovici',0,'','publish','open','open','','gropan-bregovici','','','2007-08-03 15:06:02','2007-08-03 13:06:02','',0,'http://www.groparu.ro/?p=560',0,'post','',6),(561,1,'2007-08-03 14:33:32','2007-08-03 12:33:32','','chelie.jpg',0,'','inherit','open','open','','cheliejpg','','','2007-08-03 14:33:32','2007-08-03 12:33:32','',560,'http://www.groparu.ro/wp-content/uploads/2007/08/chelie.jpg',0,'post','image/jpeg',0),(562,1,'2007-08-03 14:39:04','2007-08-03 12:39:04','','goran-alin-patru-cinci.jpg',0,'','inherit','open','open','','goran-alin-patru-cincijpg','','','2007-08-03 14:39:04','2007-08-03 12:39:04','',560,'http://www.groparu.ro/wp-content/uploads/2007/08/goran-alin-patru-cinci.jpg',0,'post','image/jpeg',0),(563,1,'2007-08-03 14:59:11','2007-08-03 12:59:11','','goran-aeroport.jpg',0,'','inherit','open','open','','goran-aeroportjpg','','','2007-08-03 14:59:11','2007-08-03 12:59:11','',560,'http://www.groparu.ro/wp-content/uploads/2007/08/goran-aeroport.jpg',0,'post','image/jpeg',0),(564,1,'2007-08-03 15:56:46','2007-08-03 13:56:46','','mesaj.jpg',0,'','inherit','open','open','','mesajjpg','','','2007-08-03 15:56:46','2007-08-03 13:56:46','',565,'http://www.groparu.ro/wp-content/uploads/2007/08/mesaj.jpg',0,'post','image/jpeg',0),(565,1,'2007-08-03 15:58:39','2007-08-03 13:58:39','Via Danila, aka Tetean.\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/08/mesagiu.jpg\" title=\"mesagiu.jpg\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/08/mesagiu.thumbnail.jpg\" alt=\"mesagiu.jpg\" /></a>','Din seria: Administratorul, partea 2 1/2',0,'','publish','open','open','','din-seria-administratorul-partea-2-12','','','2007-08-03 15:58:39','2007-08-03 13:58:39','',0,'http://www.groparu.ro/?p=565',0,'post','',7),(566,1,'2007-08-03 15:58:30','2007-08-03 13:58:30','','mesagiu.jpg',0,'','inherit','open','open','','mesagiujpg','','','2007-08-03 15:58:30','2007-08-03 13:58:30','',-1186149346,'http://www.groparu.ro/wp-content/uploads/2007/08/mesagiu.jpg',0,'post','image/jpeg',0),(567,1,'2007-08-04 13:13:37','2007-08-04 11:13:37','Cel mai frumos lucru pe care il pot zice de ziua mamei Groparuluui aka Gropareasa este: mama draga, te iert ca ai dat kix cu mine!\r\n\r\nPlec la Sibiu sa ma-mbat cu maica-mea sh cu taica-meu, sh apai sa ma nervez cand ii aud cum isi amintesc ei de una-alta cand eram io mic, gen faza aia cand am mers la mare la un nene care statea pe cearshafu\' din dotare, m-am pus ciuciumiciu langa el sh am lasat un kaka mare cat un salam sasesc kiar langa domnia sa,  dupa care am continuat sa ma antrenez pentru viitor, adica pentru jocurile alea cu putulica in gaurile din femei.\r\n\r\nNe revedem, din pacate, mult prea devreme: luni.','Ziua mamei Groparului',0,'','publish','open','open','','ziua-mamei-groparului','','','2007-08-04 13:13:37','2007-08-04 11:13:37','',0,'http://www.groparu.ro/?p=567',0,'post','',7),(568,1,'2007-08-06 10:32:05','2007-08-06 08:32:05','\r\n<table border=\"0\" cellpadding=\"0\" cellspacing=\"0\" width=\"100%\">\r\n<tr>\r\n<td>\r\n<table border=\"0\" cellpadding=\"3\" cellspacing=\"1\" width=\"100%\">\r\n<tr>\r\n<td class=\"bluebold\" bgcolor=\"#f0f6f6\">Kincses KolozsvÃ¡r-kiÃ¡llÃ­tÃ¡s Nagyszebenben</td>\r\n</tr>\r\n</table>\r\n</td>\r\n</tr>\r\n<tr>\r\n<td>\r\n<table border=\"0\" cellpadding=\"3\" cellspacing=\"1\" width=\"100%\">\r\n<tr>\r\n<td align=\"center\" valign=\"middle\" width=\"86\"><img src=\"http://www.palyazatok.ro/images/img_news/datehu.gif\" height=\"18\" width=\"86\" /></td>\r\n<td class=\"red\" bgcolor=\"#e0eaeb\">2007-08-03</td>\r\n</tr>\r\n</table>\r\n</td>\r\n</tr>\r\n<tr>\r\n<td>\r\n<table border=\"0\" cellpadding=\"3\" cellspacing=\"1\" width=\"100%\">\r\n<tr>\r\n<td align=\"center\" valign=\"middle\" width=\"86\"><img src=\"http://www.palyazatok.ro/images/img_news/sourcehu.gif\" height=\"18\" width=\"86\" /></td>\r\n<td class=\"blue\" bgcolor=\"#e0eaeb\">www.szabadsag.ro</td>\r\n</tr>\r\n</table>\r\n</td>\r\n</tr>\r\n<tr>\r\n<td height=\"57\">\r\n<table border=\"0\" cellpadding=\"5\" cellspacing=\"0\" width=\"100%\">\r\n<tr>\r\n<td height=\"10\">&nbsp;</td>\r\n</tr>\r\n<tr>\r\n<td bgcolor=\"#d5e1e1\">\r\n<p align=\"left\"><font face=\"Arial\" size=\"2\">Ma nyÃ­lik meg az ErdÃ©lyi TÃ¶rtÃ©neti MÃºzeum KolozsvÃ¡r â€“ ErdÃ©ly Kincses vÃ¡rosa cÃ­mÅ± kiÃ¡llÃ­tÃ¡sa a nagyszebeni Bruckenthal MÃºzeumkomplexum TÃ¶rtÃ©neti MÃºzeumÃ¡ban. A kiÃ¡llÃ­tÃ¡s rÃ©sze a Nagyszeben â€“ EurÃ³pa KulturÃ¡lis FÅ‘vÃ¡rosa elnevezÃ©sÅ± programnak, Ã©s augusztus 26-ig lehet megtekinteni. A megnyitÃ³ alkalmÃ¡bÃ³l bemutatjÃ¡k a KolozsvÃ¡r â€“ ErdÃ©ly kincses vÃ¡rosa / Cluj â€“ â€žthe Treasure City\" of Transylvania cÃ­mÅ±, Tudor SÄƒlÄƒgean Ã©s MihÃ¡ly Melinda Ã¡ltal Ã­rt Ã©s illusztrÃ¡lt Ãºtikalauzt is, amelyet Radu BÄƒzÄƒvan fordÃ­tott le angolra. KiÃ¡llÃ­tjÃ¡k az ErdÃ©lyi TÃ¶rtÃ©neti MÃºzeum gyÅ±jtemÃ©nyÃ©nek nÃ©hÃ¡ny legÃ©rtÃ©kesebb darabjÃ¡t, illusztrÃ¡lva a vÃ¡ros XVIâ€“XVII. szÃ¡zadi fejlÅ‘dÃ©sÃ©t. BemutatjÃ¡k az iparosok tevÃ©kenysÃ©gÃ©t Ã©s munkÃ¡it, tÃ¶bbek kÃ¶zÃ¶tt lÃ¡thatÃ³ lesz a kolozsvÃ¡ri aranymÅ±vesek pecsÃ©tje, DÃ¡vid Ferenc unitÃ¡rius pÃ¼spÃ¶k kannÃ¡ja, valamint Bocskai IstvÃ¡n erdÃ©lyi fejedelem aranyozott ezÃ¼stkannÃ¡ja is.</font></p>\r\n</td>\r\n</tr>\r\n</table>\r\n</td>\r\n</tr>\r\n</table>\r\nde la: http://www.palyazatok.ro/hirek/civil-vilag/kincses-kolozsvar-kiallitas-\r\nnagyszebenben-12369.html','Deci io numa atata va zic: Kincses KolozsvÃ¡r-kiÃ¡llÃ­tÃ¡s Nagyszebenben',0,'','publish','open','open','','deci-io-numa-atata-va-zic-kincses-kolozsvar-kiallitas-nagyszebenben','','','2007-08-06 10:35:42','2007-08-06 08:35:42','',0,'http://www.groparu.ro/?p=568',0,'post','',13),(569,1,'2007-08-06 23:10:00','2007-08-06 21:10:00','Deci nu intru in detalii referitoare la ocazia pe care am luat-o la Sibiu la ziua lu\' mama lu\' Groparu\', ca am mers pentru prima data in vieatza mea cu mashina de basarabean, cu numar basarabean, cu basarabean la volan sh grai basarabean pe limba! Sh era atata de basarabean, ca vorbea cu mine mai mult in rusashte decat in orice alta limba de pe fatza Pamantului! (oare chiar se scrie cu P mare?)\r\n\r\nFaza e ca am ajuns, m-am berarit cu mama sh cu tata, sh am facut poze la malamutu\' vecinilor, un exemplar care daca ar fi om ar fi Robert Redford sh ar fi in stare sa f*** un camin intreg de mediciniste:\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/08/dsc00482.JPG\" title=\"dsc00482.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/08/dsc00482.JPG\" alt=\"dsc00482.JPG\" /></a>\r\n\r\nSi ne-am distrat cu puiu\' lui facut cu o maidaneza, ui ce poze faina i-am facut cand tinea ÅŸnuru\' de la camera in dinti, acelasi cablu pe care sh mie imi place sa-l tin intre fildeshi:\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/08/dsc00500.JPG\" title=\"dsc00500.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/08/dsc00500.JPG\" alt=\"dsc00500.JPG\" /></a>\r\n\r\nCand s-o gatat chefu, am purces din nou pe drumul de costishe care duce fix atza drept in Cluj. Si cum stateam io asa la ocazie, fluturand cartonul cu \"CLUJ\" la biciclisti, troleibuze sh masini de Politie, vine de se asaza langa mine un ficior, rontzaind un Twix din care imi sh ofera, da il refuz cu delicateÅ£Äƒ.\r\n\r\n\"Da\' la Cluj meri?\"\r\n\"Da, la Cluj mÄƒrg\"\r\n\"Sh io!\"\r\n\r\nSh scoate un cartonash pe care abia puteai ceti \"CJ\", in comparatie cu scrisul meu de pe carton, listat la imprimanta laser cu font de 78 Arial bold, de se vede sh din satelitzi, dovada de corp locuit de homo sapiens. \"Ma\", zic io, \"hai ca te infiez cu cartonu\' meu mai hyper vizibil, ca am mai facut din estea, sh merem amandoi catre Cluj!\" Gata, zice Nelu, pe care am aflat ulterior ca il kiama Mihai.\r\n\r\nBooon. Sh oprim noi un autobuz! plin cu ce credeam io ca is ceva nuntasi sau pocaiti, sau amandoua, da\' am aflat ca erau de fapt nush ce formatie de Jale sh Dor Transilvan din Giurtelecul Hododului, sau ceva de genu\'. Sh tot drumu\' or tinut-o cu bance rasuflate de <em>old timeri</em>, despre tiganul care incerca sa devina membru de partid sh secretarul general al RSR.\r\n\r\nEra timpul sa aflu mai multe despre ficiorul pe care l-am infiat pe autobuz; mnoa, ficioru\' asta venise la Sibiu ca avea un tournament la un joc, un fel de \"Nu te supara, frate!\", de ii zice <a href=\"http://www.warhammeronline.com/english/home/index.php\" target=\"_blank\">Warhammer</a>, si care e foarte realist, finca se joaca cu pioni, zaruri, orci sh elfi, humani sh tat felu de lasere sau sabii, probabil si de robotei micuti, care cu manutza lor... Sh spre marea mea <strike>satisfactie</strike>, am aflat tot ce trebuia despre toate aceste aspecte ale jocului, fiecare personaj, cu cat are strength, leadership, defense, attack, magic skills, magic power, ce vraji, arme sau artefacte suporta, range-ul la care trag, armura, weaknesses, speed, etc, etc, etc, fiecare unitate cum se poate upgrada, adeca tot ce trebuia sa aflu eu intr-o seara in care nu vroiam decat sa dorm si sa ascult  muzikia din autocar, ca uitai sa va zic ca Giurtelecii Hododului aveau muzica de cea mai populara calitate:\r\n\r\n<object height=\"350\" width=\"425\"><ibed type=\"application/x-shockwave-flash\" height=\"350\" width=\"425\"> [youtube v/vvG4NDJPUzw]</ibed></object>\r\n\r\nIntr-un final, am ajuns intr-o parcare, unde am hranit un cutzu sau doi cu gratarele pe care nu le-am putut dovedi la ziua lu mama, sh am avut sh placerea de a hrani sh beiatu\' care juca \"Nu te supara, frate\" cu carnaciorii, mititeii sh pulpitza de pui pe care nu le-or papat cainii. Sh uite asa aflu eu, mai frate, ca beiatu\' ashiela ii fix fratele lu\' Dl. Trilulilu, adeca <a href=\"http://www.trilulilu.ro\" target=\"_blank\">www.trilulilu.ro</a>, adeca exact saitu\' unde postul de radio <a href=\"http://www.radiotransilvania.eu\" target=\"_blank\">cu care mai colaborez io</a> isi gazduieste podcasturile! Deci am reusit sa hranesc o jumate de trilulilu intr-o parcare in care eram numa noi doi, giurtelecii, doi caini vagabonzi sh (presupun sh sper din toata inimioara) o mÃ¢nÄƒ de fetite care isi castiga banii, ca sh politaii de trafic, prin soselele, trotuarele si parcarile patriei.\r\n\r\nCert e ca autocarul o bagat un ocol de vreo 80 de kilometri finca o trebuit sa margÄƒ sa ii ejecteze pe giurteleci, sh in loc sa ajung la 11 in Cluj am ajuns la 1 jumate noaptea, timp berechet ca sa aflu diferentza dintre Dark Elves sh High Elves, Chaos Troops sh Empire Army, importanÅ£a sa poti lua in calcul temperamentul pionilor care ii reprezinta pe orci sh pe goblini mai ales cand te bati cu ÅŸamanii, ca sa nu mai vorbim de semnificatia runelor cand joci cu dwarfii! Din pacate, nenea soferu ne-o chemat in fata la el cand o scapat de giurteleci si ne-o plictisit cu subiecte mai <em>phantasy</em>, gen ce Å£Äƒri o mai vÄƒzut el ÅŸi ce pÄƒÅ£anii i s-or mai Ã®ntÃ¢mplat prin Spania, cum e viaÅ£a de ÅŸofer ÅŸ o groazÄƒ de alte chestii, din pÄƒcate mai plictisitoare decÃ¢t armatele de pioni pe care le poÅ£i chiar ÅŸi colora cu carioca!!!!\r\n\r\nLa final, cand sa plec, ii zic: BÄƒ Mihai, zic, vezi cÄƒ te bag pe blog. De ce? Zice el, mai ales ca nu prea ÅŸtia ce e aia blog. FINCA MERIÅ¢I!!!!! Da\' ba, zice, stai ca nu am apucat sa iti explic de strategia Dogs of Wars-ilor, sa poti face comparatie intre ce e mai bine sa folosesti, rasa Greenskinsilor  sau rasa Knight of the Blazing Sun-ului! Gropareeeee!!!! De ce si unde fugi maaaaaa?!?!?!','Cum am hranit jumate din trilulilu',0,'','publish','open','open','','cum-am-hranit-jumate-din-trilulilu','','','2007-08-06 23:10:00','2007-08-06 21:10:00','',0,'http://www.groparu.ro/?p=569',0,'post','',5),(570,1,'2007-08-06 23:09:21','2007-08-06 21:09:21','','dsc00482.JPG',0,'','inherit','open','open','','dsc00482jpg','','','2007-08-06 23:09:21','2007-08-06 21:09:21','',-1186429347,'http://www.groparu.ro/wp-content/uploads/2007/08/dsc00482.JPG',0,'post','image/jpeg',0),(571,1,'2007-08-06 23:09:43','2007-08-06 21:09:43','','dsc00500.JPG',0,'','inherit','open','open','','dsc00500jpg','','','2007-08-06 23:09:43','2007-08-06 21:09:43','',-1186429347,'http://www.groparu.ro/wp-content/uploads/2007/08/dsc00500.JPG',0,'post','image/jpeg',0),(572,1,'2007-08-07 11:01:26','2007-08-07 09:01:26','','fwd-cv.htm',0,'','inherit','open','open','','fwd-cvhtm','','','2007-08-07 11:01:26','2007-08-07 09:01:26','',-1186476855,'http://www.groparu.ro/wp-content/uploads/2007/08/fwd-cv.htm',0,'post','text/html',0),(573,1,'2007-08-07 14:19:42','2007-08-07 12:19:42','','fwd_cv-1.jpg',0,'','inherit','open','open','','fwd_cv-1jpg','','','2007-08-07 14:19:42','2007-08-07 12:19:42','',578,'http://www.groparu.ro/wp-content/uploads/2007/08/fwd_cv-1.jpg',0,'post','image/jpeg',0),(574,1,'2007-08-07 14:20:08','2007-08-07 12:20:08','','fwd_cv-2.jpg',0,'','inherit','open','open','','fwd_cv-2jpg','','','2007-08-07 14:20:08','2007-08-07 12:20:08','',578,'http://www.groparu.ro/wp-content/uploads/2007/08/fwd_cv-2.jpg',0,'post','image/jpeg',0),(575,1,'2007-08-07 14:20:23','2007-08-07 12:20:23','','fwd_cv-3.jpg',0,'','inherit','open','open','','fwd_cv-3jpg','','','2007-08-07 14:20:23','2007-08-07 12:20:23','',578,'http://www.groparu.ro/wp-content/uploads/2007/08/fwd_cv-3.jpg',0,'post','image/jpeg',0),(576,1,'2007-08-07 14:20:37','2007-08-07 12:20:37','','fwd_cv-4.jpg',0,'','inherit','open','open','','fwd_cv-4jpg','','','2007-08-07 14:20:37','2007-08-07 12:20:37','',578,'http://www.groparu.ro/wp-content/uploads/2007/08/fwd_cv-4.jpg',0,'post','image/jpeg',0),(577,1,'2007-08-07 14:20:48','2007-08-07 12:20:48','','fwd_cv-5.jpg',0,'','inherit','open','open','','fwd_cv-5jpg','','','2007-08-07 14:20:48','2007-08-07 12:20:48','',578,'http://www.groparu.ro/wp-content/uploads/2007/08/fwd_cv-5.jpg',0,'post','image/jpeg',0),(578,1,'2007-08-07 14:21:05','2007-08-07 12:21:05','<a href=\"http://www.groparu.ro/wp-content/uploads/2007/08/fwd_cv-1.jpg\" title=\"fwd_cv-1.jpg\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/08/fwd_cv-1.thumbnail.jpg\" alt=\"fwd_cv-1.jpg\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/08/fwd_cv-2.jpg\" title=\"fwd_cv-2.jpg\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/08/fwd_cv-2.thumbnail.jpg\" alt=\"fwd_cv-2.jpg\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/08/fwd_cv-3.jpg\" title=\"fwd_cv-3.jpg\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/08/fwd_cv-3.thumbnail.jpg\" alt=\"fwd_cv-3.jpg\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/08/fwd_cv-4.jpg\" title=\"fwd_cv-4.jpg\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/08/fwd_cv-4.thumbnail.jpg\" alt=\"fwd_cv-4.jpg\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/08/fwd_cv-5.jpg\" title=\"fwd_cv-5.jpg\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/08/fwd_cv-5.thumbnail.jpg\" alt=\"fwd_cv-5.jpg\" /></a>\r\n\r\nUn CV apsolut demential ÅŸi 100% real, v-Äƒ recomand s-Äƒ ave-Å£i suficentÄƒ rÄƒpdare s-Äƒ Ã®l ceti-Å£i pe indelete!','Sivi via Danila, aka Teteanu\'',0,'','publish','open','open','','sivi-via-danila-aka-teteanu','','','2007-08-07 21:38:56','2007-08-07 19:38:56','',0,'http://www.groparu.ro/?p=578',0,'post','',12),(579,1,'2007-08-07 15:06:36','2007-08-07 13:06:36','<a href=\"http://www.groparu.ro/wp-content/uploads/2007/08/62355poza_interior.jpg\" title=\"62355poza_interior.jpg\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/08/62355poza_interior.jpg\" alt=\"62355poza_interior.jpg\" /></a>\r\n\r\nCÄƒ ani ai numa\' douÄƒzeciÅŸidoi,\r\nAsta o stie un Ã®ntreg popor;\r\nCa un cÃ¢rmaci tu ne ghidezi pe noi\r\nDestoinic ÅŸÄƒf, puternic luptÄƒtor!\r\n\r\nPrivirea ta de vultur firma o vegheazÄƒ\r\nGreÅŸeala n-are nici o ÅŸansÄƒ sa ne futÄƒ;\r\nCÃ¢nd spre noi culmi de glorie echipa-nainteazÄƒ\r\nNe umpli inimile cu o bucurie mutÄƒ!\r\n\r\nCÃ¢nd oastea noastrÄƒ la concediu trage\r\nTu darnic ÅŸi-ntelegator ne-acoperi;\r\nCand lipsa de finanÅ£e in portofele rage\r\nTu cardul tau de credit Å£i-l descoperi!\r\n\r\nNe mai forÅ£ezi sa-Å£i cumpÄƒrÄƒm un bon de masÄƒ\r\nDar cÃ¢nd mai Ã®ntÃ¢rziem nu comentezi;\r\nFereasca Dumnezeu sa ne trezim cu-alt ÅŸef Ã®n casÄƒ\r\nCa numa tu, mai Kissu, tu contezi!\r\n\r\nCÄƒci tu ne umpli conturi, inboxuri, sh inimi\r\nCu taskuri, ÅŸi rÄƒspunderi, bigubaxuri!\r\nSi indiferent cat par ai tu pe piept,\r\nCA SHAFU\' NIMENI NU-I AÅžA DÄ‚JTEPT!!!','Az\' e ziua lu Shafu\': urmeazÄƒ os-analele',0,'','publish','open','open','','az-e-ziua-lu-shafu-urmeaza-osanalele','','','2007-08-07 15:13:56','2007-08-07 13:13:56','',0,'http://www.groparu.ro/?p=579',0,'post','',10),(580,1,'2007-08-07 15:13:40','2007-08-07 13:13:40','','62355poza_interior.jpg',0,'','inherit','open','open','','62355poza_interiorjpg','','','2007-08-07 15:13:40','2007-08-07 13:13:40','',579,'http://www.groparu.ro/wp-content/uploads/2007/08/62355poza_interior.jpg',0,'post','image/jpeg',0),(581,1,'2007-08-08 00:00:07','2007-08-07 22:00:07','Sa isi faca Google reclama prin Ad-Sense chiar pe pagina lor www.google.com, sh sa isi mai si dea centi pe pay-per-click!\r\n\r\nPS: Si sa mai si transfere banii pe pay-per-click din acelashi cont in acelashi cont!','Culmea Ad-Sense-ului',0,'','publish','open','open','','culmea-ad-sense-ului','','','2007-08-08 00:00:07','2007-08-07 22:00:07','',0,'http://www.groparu.ro/?p=581',0,'post','',2),(582,1,'2007-08-08 13:50:33','2007-08-08 11:50:33','<a href=\"http://deceblog.net/2007/08/ultimul-post-pe-blog/#comment-13936\" target=\"_blank\">Deceblog</a> o pornit o initiativa demna da toata lauda: ce ar spune floarea blogosferei daca ne-am afla in pragul sfarsitului lumii. Sh l-o impersonat sh pe Groparu (pentru cei care nu il cunoasteti, il gasiti pe www.groparu.ro) punandu-se in pielea lui sh incercand sa ghiceasca ce as zice eu daca ar veni meteoritul, s-ar topi calota glaciara sau ar da o epidemie de SIDA in noi din cauza ca nu prea ne place sa facem amor cu prezervative. Sh daca dati click pe primul cuvant din postarea asta, aflati si ce ar zice alti blogheri in cazu\' ca ar trebui sa dam cu totii coltzu\'.\r\n\r\nPS: Cica ultimele mele cuvinte vor fi legate de zama de peshte. A gresit? N-a gresit!\r\n\r\n<strong>Update</strong>: ca sa dam <a href=\"http://www.denisuca.ro/blog/\" target=\"_blank\">Denisei</a> ce-i al Denisei, ca daca nu o sa vreie sh ce e al Cezarului, sau poate sh al Groparului, sa recunoastem  ca de fapt Deceblog a preluat din zbor o initiativa deveano-<a href=\"http://www.denisuca.ro/blog/\" target=\"_blank\">denisoiana</a>. Iaca! Corectura ;)','Dece? Blog!',0,'','publish','open','open','','dece-blog','','\nhttp://deceblog.net/2007/08/ultimul-post-pe-blog/#comment-13936','2007-08-08 17:28:59','2007-08-08 15:28:59','',0,'http://www.groparu.ro/?p=582',0,'post','',9),(583,1,'2007-08-08 16:37:21','2007-08-08 14:37:21','Adunate din statusurile mele de yahoo:\r\n<p class=\"MsoNormal\">- Oare se poate spune despre o reclama la pui ca e o porcarie?</p>\r\n\r\n<p class=\"MsoNormal\"><span lang=\"RO\">- Cand o fata iti spune ca o faci sa roseasca, probabil ca se refera la faptul ca o iriti ca un elastic de la kiloti.\r\n</span>\r\n<p class=\"MsoNormal\"><span lang=\"RO\">- Arpagica Popescu</span></p>\r\n<p class=\"MsoNormal\"><span lang=\"RO\">- Tranzitia s-a incheiat. La shlitz<o:p></o:p></span></p>\r\n<p class=\"MsoNormal\"><span lang=\"RO\">- Oamenii se tem de mine cand sunt antipersonal<o:p></o:p></span></p>\r\n<p class=\"MsoNormal\"><span lang=\"RO\">- Ordonati urmatoarele ocupatii dupa marimea IQ-ului: politist, gardian public, bodyguard de discoteca<o:p></o:p></span></p>\r\n<p class=\"MsoNormal\"><span lang=\"RO\">- Facultatea de Monkey Business<o:p></o:p></span></p>\r\n<p class=\"MsoNormal\"><span lang=\"RO\">- Cum se scoate Romania din rahat? cu vidanja, mon cher! cu vidanja. <o:p></o:p></span></p>\r\n<p class=\"MsoNormal\"><span lang=\"RO\">- Cum se scoate Romania din rahat? Se aduc scarabeii sa manance rahatul din jurul Romaniei.<o:p></o:p></span></p>\r\n<p class=\"MsoNormal\"><span lang=\"RO\">- Daca omoriti un mester de apartamente, Dumnezeu va iarta 7 pacate!<o:p></o:p></span></p>\r\n<p class=\"MsoNormal\"><span lang=\"RO\">- Plecat sa platesc taxa de prima inmatriculare la masina de spalat<o:p></o:p></span></p>\r\n<p class=\"MsoNormal\"><span lang=\"RO\">- Schimb pilule pentru celulita contra tratament pentru liposuctiune<o:p></o:p></span></p>\r\n<p class=\"MsoNormal\"><span lang=\"RO\">- Si bogatii plang. De fericire<o:p></o:p></span></p>\r\n<p class=\"MsoNormal\"><span lang=\"RO\">- Dupa ce ca lumea era sucita asa cum era, mai vine si Katrina asta, ca s-o faca si mai sucita!<o:p></o:p></span></p>\r\n<p class=\"MsoNormal\"><span lang=\"RO\">- Foarfeca. Scoate cele mai frecvente 99 de plete<o:p></o:p></span></p>\r\n<p class=\"MsoNormal\"><span lang=\"RO\">- Azi s-a nascut copilul lui Irinel si Monica. Cine spunea ca mama prostilor e mereu gravida s-a inselat!</span></p>\r\n<p class=\"MsoNormal\"><span lang=\"RO\">- The only capital in the world whose name features fuck and dick: Bangkok<o:p></o:p></span></p>\r\n<p class=\"MsoNormal\"><span lang=\"RO\">- Christmas Eve. Where is Christmas Adam ?<o:p></o:p></span></p>\r\n<p class=\"MsoNormal\"><span lang=\"RO\">- Culmea crestinismului: sa te rogi al D-zeu sa-i ierte sh pe extraterestri<o:p></o:p></span></p>\r\n<p class=\"MsoNormal\"><span lang=\"RO\">- Nu sunt dezaxat; de vina e axa pamantului, care e stramba.<o:p></o:p></span></p>\r\n<p class=\"MsoNormal\"><span lang=\"RO\">- Unii oameni sunt intregi la cap, dar numai la calota craniana.<o:p></o:p></span></p>\r\n- <span lang=\"RO\">M-o intepat o viespe in mana stagna. Si? Ce-ai facut? Am continuat sa beau cu dreapta!</span>\r\n<p class=\"MsoNormal\">&nbsp;</p>','Statuse de yahoo, din preputzul gandirii',0,'','publish','open','open','','statuse-de-yahoo-din-preputzul-gandirii','','','2007-08-08 17:25:22','2007-08-08 15:25:22','',0,'http://www.groparu.ro/?p=583',0,'post','',21),(584,1,'2007-08-09 11:48:46','2007-08-09 09:48:46','','dsc00146-3.JPG',0,'','inherit','open','open','','dsc00146-3jpg','','','2007-08-09 11:48:46','2007-08-09 09:48:46','',585,'http://www.groparu.ro/wp-content/uploads/2007/08/dsc00146-3.JPG',0,'post','image/jpeg',0),(585,1,'2007-08-09 11:53:19','2007-08-09 09:53:19','Da, gropareala asta face victime. Si da, tot mai multa lume imi spune ce-i spuneau lu\' Mowgli maimutzele, ca \"I wanna walk like you, talk like you!\"\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/08/groparii.jpg\" title=\"groparii.jpg\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/08/groparii.thumbnail.jpg\" alt=\"groparii.jpg\" /></a>','Din seria: \"I wanna walk like you, talk like you!\"',0,'','publish','open','open','','din-seria-i-wanna-walk-like-you-talk-like-you','','','2007-08-09 11:53:19','2007-08-09 09:53:19','',0,'http://www.groparu.ro/?p=585',0,'post','',4),(586,1,'2007-08-09 11:52:05','2007-08-09 09:52:05','','groparii.jpg',0,'','inherit','open','open','','gropariijpg','','','2007-08-09 11:52:05','2007-08-09 09:52:05','',-1186652889,'http://www.groparu.ro/wp-content/uploads/2007/08/groparii.jpg',0,'post','image/jpeg',0),(587,1,'2007-08-09 16:34:43','2007-08-09 14:34:43','...sau, cum se zice, pentru <em>cea lume</em>. <a href=\"http://www.publicitatepelumeacealalta.ro/\" target=\"_blank\">Aici</a>. Via <a href=\"http://idei-locale.blogspot.com/\" target=\"_blank\">Legionaru</a>, care sh el le loa de la saitu\' normal, care si el s-o reflectat in saitu\' lu <a href=\"http://www.varabiescu.ro/new-media/2007/08/art7273784695-New-Media-Cautam-distribuitori/\" target=\"_blank\">Vrabie</a>.\r\n\r\nDeci un bine infipt in media, sau medium, psihopat sau psiho-transcendento-comunicativ, sau puii mei... medium, da\' nu ca in mass-media, are contacte, da\' nu sexuale, cu lumea, da\' nu lumea asta, ci lumea cealalta. Mai mult, el vinde spatiu publicitar pentru lumea de dincolo\r\n\r\nBoooon.\r\n\r\nMai nene, hai sa facem afaceri impreuna! DaÅ£ nu d-estea de publicitate, ca nij pe mine nij pe tine nu te cheama Brunet, Leo Brunet.\r\n\r\n1. IÅ£i dau un pumn de nÄƒsip de Mangalia daca imi spui numerele conturilor tuturor evreilor ucisi de Hitlerica, conturile alea din care nu s-o mai recuperat nimic, finca elvetienii aia cu pielea alba si care fac dragoste cu sosete in picioare le-or facut pierdute;\r\n\r\n2. IÅ£i dau doua oua fierte moi daca imi spui care e de fapt Insula Tortuga, aia in care piratu\' shela, Morgan, sh-o ingropat pradaciunile; io-s gropar, sh dezgrop ditamai averea, sh vreau sa torn sh io o continuare la Piratii din Caraibe, varianta porno, bine-ntales;\r\n\r\n3. ÃŽÅ£i dau o pompÄƒ de bicicleta cu doua mufe universale baÅŸca o lanterna de buzunar stricata daca ma duci la Teotihuacantenocitlan sh imi areÅ£i cu deshtiu\' care e Eldorado; vorbeste cu spiritu\' lu Viracochas Äƒia, cÄƒ Äƒia Ã®Å£i zic tÄƒt;\r\n\r\n4. ÃŽÅ£i dau fac share la colecÅ£ia mea de linkuri porno dacÄƒ Ã®mi confirmi cÄƒ Maria Tereza o murit supt caluÅ£, de la penetrare; nu o sa fac bani dupa chestia asta, da\' vreau sa stiu daca e vreo sansa sa moara vreuna supt mine;\r\n\r\n5. Iti dau un Koson original chinezesc de plastic de pe vremea lu Burebista daca imi areti unde si-o ingropat Decebal comoara, aia mai mare decat alea 100 tone de aur duse de TrÄƒienel din Dacia, de or scapat imperiul de la dezastru;\r\n\r\n6. ÃŽÅ£i dau o piramidÄƒ din aia sub care Ã®Å£i dureazÄƒ mai mult lamele de bÄƒrbierit dacÄƒ vorbeÅŸti cu Ramses ÅŸi Tutmes ÅŸi Ã®Å£i zic ÄƒÅŸtia cum dreq s-or fÄƒcut piramidele;\r\n\r\n7. ÃŽÅ£i dau un foc de la bricheta daca imi explici ce e cu flacarile alea care tot apar pe dealuri, de umbla astia pe la Orastie ca apucatii cu detectoare de metale pe dÃ¢mburi;\r\n\r\n8. ÃŽÅ£i dau un tricou ud cu sÃ¢ni cu tot dacÄƒ vorbeÅŸti cu Mata Hari sÄƒ Ã®Å£i spunÄƒ unde ÅŸi-o ascuns ea pozele alea secrete, ÅŸi care is si destul de porno;\r\n\r\n9. Iti darui blogul meu (parola e Å¢Ã¢Å£e-cur-fetiÅ£e) dacÄƒ vorbesti cu Asklepios si iti da radacina aia de fir de iarba care te facea nemuricios, de l-o enervat pe Hades ca nu-i mai venea cÄƒrniÅ£Äƒ de om prin Tartar;\r\n\r\n10. Iti dau doua pereci de ciorapi desperecheati daca imi spui SIGUR daca atunci cand tin pÃ¢rtzurile mele cu metan in stomac mi se face efect de sera in stomac! Asta nu prea are legatura cu capacitatile tale para-, da\' m-ar interesa sa stiu.\r\n\r\nFacem dealu\'???','Publicitate pentru lumea de dincolo',0,'','publish','open','open','','publicitate-pentru-lumea-de-dincolo','','','2007-08-09 16:34:44','2007-08-09 14:34:44','',0,'http://www.groparu.ro/?p=587',0,'post','',6),(588,1,'2007-08-10 18:18:31','2007-08-10 16:18:31','Pacat ca e locuita.\r\n\r\nDeci azi ajung rupt in gura, ca tocmai ce baui az-noapte cu <a href=\"http://oedip.blogspot.com/\" target=\"_blank\">Oedip</a> (nu, nu e ala cu ma-sa) sh cu <a href=\"http://www.doingtheartwork.com/\" target=\"_blank\">Mishu</a>, sh dormisem vreo 5 ore, sau ceva de genu\'. Sj ajung la scarbiciu, unde primesc de lucru cacalau. Sh in pauza de masa fug pe bitza sa vorbsc la banca, ca mai trebe bani; stau 20 minute, nu imi vine randu\', ma sucaresc si o sterg sa iau papa de la kineji; langa Maimutza Plangacioasa am stat 12 minute pana cand o tanti incerca sa o convinga pe alta tanti (la telefon) ce sa comande. Cand imi vine randu, cineva de la masa cere ultima portie de spaghete de orez, care lu\' Groparu place; urmau inca 8 minute de frecat tziparu\', asa ca m-am carat. Pe Memo\' era plin de lume, ashijderea in Mihai Viteazu\'; da acilea m-am pus la coada, ca era ultima optiune. Sh vine un mojnegel, sh intreaba:\r\n\r\n- Ce se da acilea?\r\n- Papa de kineji, zic io.\r\n- Si cum e? Cu ce e?\r\n- Pai, zic io vizibil deranjat, cu carne de maimuta, catel sh carne de pisica (tanti din fatza deja se caca pe ea, ca nu putea rade zgomotos).\r\n- E scumpa?\r\n- 8 lei, zic io.\r\n\r\nSe cara.\r\n\r\nVine randu, iau patru portii, o intreb pe tanti: tu copila, nu se varsa? Vai, zice ea, niciodata, nu are cum, uitati-va numa\' cum stau sh fiecare o inchid ermetic!\r\n\r\nMi s-o varsat. In rucsac. Mi-am patat husa de la camera foto, tricou\' de skimb dinauntru, rucsacu\', pompa, faru\' de la bitza, sh inca cateva chestii.\r\n\r\nLa serviciu, clar ca am nimerit portia aia din care se varsase zama, si am papat orez cu sare.\r\n\r\nAmu tre\' sa plec la munte, sh io bag la serviciu ca chinezu\'. E 7 sh 20 seara, sh la 8 se pleaca. Nu am nici cea mai timida urma de bagaj, si stau la 30 minute de pedalat de casa. ]\r\n\r\nTotusi, se putea si mai rau. Se putea sa ploua, zise Groparu fara sa vada ce nori amenintatori se strang in fatza geamului termopan!','Ce zi frumoasa!',0,'','publish','open','open','','ce-zi-frumoasa','','','2007-08-10 18:18:31','2007-08-10 16:18:31','',0,'http://www.groparu.ro/?p=588',0,'post','',9),(589,1,'2007-08-13 00:04:34','2007-08-12 22:04:34','Ni ce cabana faina are Vlad Tepesh:\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/08/dsc00722.JPG\" title=\"dsc00722.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/08/dsc00722.thumbnail.JPG\" alt=\"dsc00722.JPG\" /></a>\r\n\r\nN-am putut pescui, nu din cauza ca eram prea beti, da\' mai ales din cauza ca o plouat la greu, sh apa avea asa, o coloare cacanie, diuretica chiar.Â  Numa Vladivistok o pescuit neshte cleni dilÄƒi, pe care i-am sh executat cu legume, stropiti din belsug cu un vin de o calitate foarte neindoielnica. Da\' nu asta e cea mai tare faza de weekendu\' asta.\r\n\r\nAm cumparat o galetusa cu 4 kile de zmeura la un pret care bate la cur orice alta afacere: 20 lei, cu tot cu recipient. Se-aude, Vantule, Tiriacule sh Becalilule? Sunteti pepsi, buey! Sh dupa aia l-am blastemat pe mocanul tuciuriu care mi-o vandut-o, ca am avut nevoie de 4 ore ca sa sortam spurcaciunile din zmeura de zmeura aia care mere la gem de dulceatza, cu care am sa ma dreg io diminetile de sambata, cu mult lapte sh omleta. Da\' nu asta e cea mai tare faza de weekendu\' asta.\r\n\r\nNe-am innamolit ca neshte porcine in drumu spre malu lacului, sh cativa dintre noi erau chiar sa cam puna frana cu barbia; uitati-va numa\' sh voi ce porcaiala se  stransese pe pantoafe!\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/08/dsc00654.JPG\" title=\"dsc00654.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/08/dsc00654.thumbnail.JPG\" alt=\"dsc00654.JPG\" /></a>\r\n\r\nClar ca atunci cand o eviscerat clenii, Vladeasa o aruncat pe toate fetele bashicile alea din peste care is umplute cu aer, sh astea fugeau prin ploaie mieunand de excitement. Da\' nu asta e cea mai tare faza de weekendu\' asta.\r\n\r\nAm jucat Mafia, sh in tura in care io am fo\' mafiot am castigat, i-am terminat pe cetateni pana la ultimu\'. Da\' nici asta nu e cea mai tare faza de weekendu\' asta.\r\n\r\nCea mai tare faza ne-o zis-o un nene care lucreaza la Ratuc.\r\n\r\nZice ca era un sofer proaspat angajat care lucra pe 43; sh cum cobora el asa dealu\' dintre Zorilor sh Manastur, urla in microfon: BAAAAAA, TOATA LUMEA PE PODEA, CA NU MAI AVEM FRANE!!!\r\n\r\nClar ca cetatenii s-or aruncat ca supt bombardament. Io, de exemplu, daca eram acolo, m-as fi aruncat pe fiecare studenta din autobuz, pe rand.\r\n\r\nSh ajung astia la poalele dealului, dupa ce o facut nenea soferu\' neshte janseuri mai ceva ca un Schumi; sh pune o frana d-aia brusca, sh racneshte: BAAA, PROSTI MAI SUNTETI! Sh o sterge rapid din autobuz, ca lumea deja alerga sa isi rupa mana in dantura lui.\r\n\r\nAceea a fost ultima lui zi de lucru ca sofer pentru Ratuc.','Deci, cea mai tare faza de weekendu\' asta',0,'','publish','open','open','','deci-cea-mai-tare-faza-de-weekendu-asta','','','2007-08-13 00:04:34','2007-08-12 22:04:34','',0,'http://www.groparu.ro/?p=589',0,'post','',16),(590,1,'2007-08-13 00:00:33','2007-08-12 22:00:33','','dsc00654.JPG',0,'','inherit','open','open','','dsc00654jpg','','','2007-08-13 00:00:33','2007-08-12 22:00:33','',-1186954307,'http://www.groparu.ro/wp-content/uploads/2007/08/dsc00654.JPG',0,'post','image/jpeg',0),(591,1,'2007-08-13 00:03:58','2007-08-12 22:03:58','','dsc00722.JPG',0,'','inherit','open','open','','dsc00722jpg','','','2007-08-13 00:03:58','2007-08-12 22:03:58','',-1186954307,'http://www.groparu.ro/wp-content/uploads/2007/08/dsc00722.JPG',0,'post','image/jpeg',0),(592,2,'2007-08-13 14:11:20','2007-08-13 12:11:20','1. Ziceam <a href=\"http://www.groparu.ro/?p=536\" target=\"_blank\">acilea</a> de Silvan, albanez de felu mariei sale, care ma cam enerveaza finca daca s-ar enerva, ar canta la chitara aia sh cu omuletzul din gat, cu urechea, cu sfarcele sh cu firele de par din juru buricului; dotat cu un ego cat evreu\' ala, iceberg, de o scufundat Titanicu\', a reusit fie sa ia locu\' I cam pe oriunde a mers, fie sa fie dat afara din concurs finca un nene (da, ma, era inginer! aia nu insamna ca toata rasa lor e gresita) o zis ca \"Silvan canta versuri obscene, cu <em>o curva ordinara</em>!\" Nenea respectiv este shaful Casei de Cultura din Ieshi, si eu personal il respect pentru ca rareori mai vezi asemenea mostre de intelectualism feroce.  Silvanismele de la Folk You le puteti vedea dand click <a href=\"mms://library.radio3net.ro/library2/folkyou3/silvan%20stancel.wmv\" target=\"_blank\">aici</a>.\r\n\r\n2. <a href=\"http://www.doingtheartwork.com\" target=\"_blank\">Mishonca</a>, aka Davie. Io cu asta sunt pe flash, sh e foarte greu sa fii pe flash cu cineva cand canta. Stiti cum iti dai seama ca cineva e meseriash la chitara? Ca nu incearca sa iti deie peste nas cu piesele lui, pe care numa el le stie; in plus, te mai si intreaba \"No, ba, ce mai cantam?\" Ca sa va faceti u pic idee de cat de Mish e meseriashu, ia vighetz <a href=\"http://www.doingtheartwork.com/wp-content/uploads/2007/05/Mishu_-_Scrum.mp3\" target=\"_blank\">acilea</a> piesa \"Scrum\", pe care o respect, finca de fapt i-o doamna. Sh sunt super mare fan piesa asta, sh Mishu o canta super.\r\n\r\nSh Groparu, ca de obicei, se crede super meseriash si finca are asemenea oameni in lista la YM.\r\n\r\nFinca ma uit in ochii lor, ma admir cum ma oglindesc si imi dau seama si eu, de fapt, cat pot fi de meseriash.','Cantecacii care place Groparului',0,'','publish','open','open','','cantecacii-care-place-groparului','','\nhttp://www.groparu.ro/?p=536','2007-08-13 17:02:16','2007-08-13 15:02:16','',0,'http://www.groparu.ro/?p=592',0,'post','',2),(593,1,'2007-08-13 21:29:09','2007-08-13 19:29:09','Amu s-ar putea sa fiu cuman, da\' sh asta inca e in dezbatere.\r\n\r\nDi ce zic io ca nu is roman? Finca mie nu imi mai place sa fur. Nush ce pana me s-o dereglat la mine in cap, da\' io incerc sa nu mai fur. Nimic.\r\n\r\nCand eram bursier in Danemarca, eram cam paduchios de sarantoc. Asa de paduchios ca am plecat de acolo pornit sa nu mai fiu in viatza mea nevoit sa imi mananc de supt unghie din cauza saraciei. Sh asa de bine mi-am respectat promisiunea, ca la intoarcere am lucrat 2 ani lungi de zile ca prof. Sh am avut sansa sa redefinesc hotarele saraciei. Foame sh alte shele.\r\n\r\nSi in Danemarca, mergeam io intr-o zi cu bitza mea (primita cadou) sh hopa! Vaz pe jos un portofel. D-ala eftin. Pun frana, ma uit in jur sa nu traga careva de vreun snur sh sa ma vad pe www.redtube.com, la sectia \"Fomisti\". Dar nu vad nici un snur, descalec sh ma uit inauntru. Inauntru - 50 de coroane (adeca vreo 8 euro), fara nici un act sau altceva. Io stau, ma scarkin in cap, ma fac ca ma gandesc, ma uit la mine-n portofel unde urla saracia. Ma iau sh ma duc la casa cea mai apropiata, sh sun la usa sa le predau portofelu\', asa incat cine l-a pierdut sa vina la ei, sa si-l recupereze, nu la mine la camin, la un student pÃ¢rlit. Acasa - nimeni. Booon! Zic io. Deci azi mancam, ca avem 50 de coroane, asta e, Dumnezeu vrea sa ii pastrez, ca daca nu vroia sa ii pastrez ar fi fost cineva acasa! Sh dusu-s-a Groparu, sh s-o imbuibat, ca de obicei, cu cartofi cu macaroane, ca deja mi-era acru sufletu\' de atata papa najpa.\r\n\r\nDupa 2 saptamani, am pierdut portofelul meu, cu 120 de coroane, sh ala care l-o gasit nu o venit sa mi-l aduca, ba o si incercat sa imi sparga contul de card, noroc ca o picat in capcana PIN-urilor false puse expre\' prin portofel, sh ATM-ul i l-o retinut, ca l-am recuperat de la banca.\r\n\r\nAzi, merg la bancomat sa scot lei. In fatza mea, un gagiu bine imbracat discuta la telefon. Isi scoate banii sh extrasu\' de cont, sh se cara fara sa-si ia cardu\'. Io vad asta, si tocmai atunci apare in stanga mea dracu\' ala mic, roshu, sh zice: \"Gropare, da iama in contu\' lui! Goleste-l, da-l dreq de luzÄƒr!\" Nu apuc sa ma dezmeticesc, ca apare sh ingerashu, care-mi zice: \"Gropare, kiar asa! Goleste-i contu\'!\" Noroc ca nu ascult niciodata de vocea providentei, sh am dat cancel la nush ce tranzactie ramasese neefectuata, sh tuleo! Dau fuga catre ala, il bat pe umar cu violentza, sh ii zic: \"Da\' ce faci, ma!\" sh ii intind cardu\'. Am plecat pana sa apuce sa-mi multumeasca.\r\n\r\nAmu de ce scriu asta: finca la mine in cont mi s-or virat amu vreo 3 saptamani vreo 2000 lei (!) fara sa-i merit. Da, lei noi. Sh ma gandesc, oare sa ma fac ca nu stiu, sau sa merg la banca sh sa le zic sa ii returneze?','Am ajuns la concluzia ca nu sunt roman',0,'','publish','open','open','','am-ajuns-la-concluzia-ca-nu-sunt-roman','','','2007-08-13 21:29:09','2007-08-13 19:29:09','',0,'http://www.groparu.ro/?p=593',0,'post','',19),(594,2,'2007-08-14 16:49:32','2007-08-14 14:49:32','Da.\r\n\r\nMuncesc mai mult decat muncesc toti pensionarii din Romania.\r\n\r\nMuncesc mai mult decat toti copiii sub 4 ani din patriea mea.\r\n\r\nMuncesc mai mult decat trei manageri la un loc care numa forwardeaza e-mailuri.\r\n\r\nMuncesc mai mult decat Vacaroiu!!!!\r\n\r\nMuncesc mai mult decat un fir de praf suspendat pe cerul Clujului, atat de curat, atat de fin.\r\n\r\nMuncesc mai mult decat o chitara care sta cuminte in husa ei.\r\n\r\nMuncesc mai mult decat tasta Num Lock.\r\n\r\nMuncesc mai mult decat bitza mea de la Maros, which suckz, BTW.\r\n\r\nMuncesc mai mult decat bocancii mei de munte, pe care nu i-am mai incaltzat de doi ani.\r\n\r\nMuncesc mai mult decat o starleta porno care numa\' sta intinsa pe pat sh geme in vocale.\r\n\r\nMuncesc mai mult decat doua degete de chinez.\r\n\r\nMuncesc mai mult decat o carte de programare, din aia groasa, pe care iti asezi monitorul sa stea mai sus.\r\n\r\nMuncesc mai mult decat un con de brad care se lasa rontzait de un veveritz.\r\n\r\nIntr-o buna zi voi munci mai mult chiar decat mine!','Am ajuns la concluzia ca muncesc prea mult',0,'','publish','open','open','','am-ajuns-la-concluzia-ca-muncesc-prea-mult','','','2007-08-14 16:49:32','2007-08-14 14:49:32','',0,'http://www.groparu.ro/?p=594',0,'post','',9),(595,1,'2007-08-15 00:13:54','2007-08-14 22:13:54','Da, mah, super tare.\r\n\r\nMerem azi la pizcina.\r\n\r\n11 m x 5 m. Deci - mnica.\r\n\r\nIn piscina eram deja 4 oameni, toti gropari, plus o tanti cu un prunc care foarte se bucura sa se arunce drept in bot in apa, de nu puteai inota (cu un singur <em>n</em>!) nici macar catzaleshte. Clar ca viitorii tatzi din noi nu i-or zis nimic; daca pruncu\' ar fi avut sh o beruca in manutza sh un trabuc in coltzu\' gurii, ar fi fost deja primit in clubul exclusivist \"Groparii Veseli\", care-i atata de exclusivist ca nu are nici macar un membru, finca inca nu mi-am aprobat cererea, ca inca nu mi-am votat consiliul de administratie care, bine-nteles, e format din mine insumi, sh atat.\r\n\r\nBoooon.\r\n\r\nSh stand noi asa, de-a lela, sh inghitind apa din aia cu clor, numa ce vad ca apare, mÄƒre, nu unu\', nu doi, ci tri! Tri chinezoi, sau coreeni. Care toti vin sh se baga in apa.\r\n\r\nAm incercat - sincer - sh nu am reusit. Am incercat din nou, sh iear am ratat. Asa ca a treia oara nici macar nu am mai incercat. M-am dus la ei direct, sh i-am intrebat:\r\n\r\n- Voi ati venit in aceeasi valiza?\r\n- ?\r\n- Toti trei?\r\n- ?!\r\n- Ba, zic io.\r\n- ?!?\r\n- Zice-ti-mi un proverb chinezesc!\r\n- !?!?\r\n- Da, mah, un proverb.\r\n- ?!?!?!\r\n- Auzi, zic io. Vezi ca in jacuzzi or ramas neshte resturi de piele de la round-eyes-ii astilanti de dinainte, plus un sapun. Facem un Chickety China, the <a href=\"http://www.goofball.com/phone/INC20001004065810\" target=\"_blank\">Chinese Chicken</a>?\r\n- !!??!!??\r\n- Ba, mai zic io. Cine zici ca is mai tare, Ninja sau Shaolin?\r\n- !!!!!!\r\n- Bineeeee! mai zic. <a href=\"http://www.youtube.com/watch?v=FuE621j50Z0\" target=\"_blank\">Who is the president of China</a>?\r\n- ????\r\n- Auzi, mai zic io, tibetanii is ca secuii nostri? Sh e adevarat ca Dalai Lama daca vrea va trajnejte cu foc din Buda? Si e adevarat ca aveti fetitze pe care le cheama Ling, acolo la voi la chineji? Sh daca e adevarat, imi faci sh mie cunostinta cu una pe care o cheama Ling? Sh e adevarat ca voi avetz voie sa avetz numa zero sau un copil - tu care copil ai fost, ala unu, sau ala zero? Sh daca voi ati inventat hartia, de ce nu ati inventat sh hartia de buda? Si asa-i ca nu-i nici o diferentza intre voi sh japoneji? Asa-i ca in medicina voastra se folosesc coaie de urs, sh cand  nu aveti folositi coaeh de urs de plush? Si asa-i ca aveti copii nascuti in anu\' porculu? Si asa-i ca recuperati tzepele alea de le folosim noi la frigarui, si faceti acupunctura cu reumatici? SI ASA-I, IN PUII MEI, CA NICI VOI NU VA DEOSEBITI INTRE VOI???','Trei chineji',0,'','publish','open','open','','trei-chineji','','','2007-08-15 00:13:54','2007-08-14 22:13:54','',0,'http://www.groparu.ro/?p=595',0,'post','',10),(596,2,'2007-08-15 21:16:02','2007-08-15 19:16:02','V-am mai zis ca am fost sh io odata un studinte amarat sh vai de curu\' meu? Diferentza dintre vremile de atunci sh ziua de azi e numa\' ca nu mai is student.\r\n\r\nEram in anu I, mÃ¢ndru ca stau in caminu\' 16, desi mama (care de fapt e-o doamna) o plans cu lacrimi amare, ca cum sa-si lase ea odoru\' in asa cloacÄƒ? Mai ales ca asta insemna ca nu mai avea cum sa ma f*** la melodie, ca pe vremea aia nu erau celulare, sh cine avea celular era pui de Isarescu.\r\n\r\nBoooon.\r\n\r\nSh ma prinde pe mine o vineri seara fara un ban in buzunar, fara nici un fel de papa, paine, lapte, conserve, niic! Nada de nada. Buzunarele plangeau, ca mai era in ele fix numa suficienti bani cat sa plec sambata acasa, unde era cald, bine, papa moca sh un pahar de vin cu Groparoiu, tata lu Gropu\'. Da\' io dormisem de amiaza, si m-am trezit cu o foame din aia speciala, de camin; cine stie cum e nu poate sa nu isi aminteasca gustu\' ala de tzava de dush coclita pe care-l ai in gura,  precum sh musuroiul de albine atomice africane care iti zumzaia in burta, de iti era sh jena de colege la seminaru\' de la 6 la 8 seara, ca grohaia stomahu\' de nu mai putea seminaristu sa isi tina sh el, bietu\', orele!\r\n\r\nMnoa. Deci papa ioc, bani ioc, foame - mare.\r\n\r\nMnoa. Sh sta Groparu\' incolacit de pat cum stau serpii boa cand le e foamea mai mare, si se gandeshte: ce e de facut? Sh isi ia inima-n dinti, si coboara Piezisha catre liceu\' Postei, sau cum \'mniezau ii zice, ala de ii pe Motilor. Acolo, astia aveau cantina, da\' io nu aveam abonament, ca asa era pe atunci, nu se putea plati in regim de restaurant, adeca cum e azi in camine, nu ca <em>pe vremea mea</em>.\r\n\r\nSh intru in cantina - era vineri seara, pustiu peste tot, o seara d-aia de noiembrie, najpa-najpa! Sh ploua afara, sh mie foamea imi bubuia in timpane, ui asa facea: zdroiiiiing!!! zdroooinnnngg!!! Sh desi imi venea sa ma catzar peste tanti aia bucatareasa si sa ii pup picioarele sh sa i le spal cu parul meu, numa\' sa-mi deie sh mie un coltz de pita, eram calm. Calm-calm, sh analizam instinctiv o stratagema despre care stiam ca nu are nici o sansa de izbanda; da\' asa cum tigru\' infometat sta zile in sir la izvor, ca stie ca pe-acolo vin caprioarele sa isi stinga setea (ca asa am auzit, ca caprioarele nu beau bere!), asa stateam si eu, si cu o masca cat se poate de amabila ma indrept catre tanti aia de serviciu.\r\n\r\n- Sar\'na, zic eu, zambind Humphrey Bogart-ian.\r\n- Buna seara, zice tanti, deja suspicioasa.\r\n- Ce mancare aveti? o intreb.\r\n- Paste fainoase cu varza, zice tanti, cu juma de gura. <em>Ce dreq vrea asta?\r\n</em>- Preferatele mele, zic io, gandindu-ma ca trebe sa ii arat la stomac poze cu friptura ca sa bag in gura asa o naclaiala. Puneti-mi o portie, va rog, zic io, scotand portofelu\' gol-golutz, ca urla saracia in el, si prefacandu-ma ca caut printre bancnote.\r\n- Aveti bon la cantina? Zice tanti, fara sa miste un muschi. Stia ea ca de la lichelele astea de studenti care nici macar n-au accent clujean te poti astepta la ce e mai rau.\r\n- Nu, zic eu, da\' nu-i problema, ca platesc.\r\n- Nu se poate plati, zice tanti, cu aceasi masca de gheatza.\r\n\r\nFoamea mea deja se preschimbase in 4 kile de cobalt scufundat in acid cianhidric; daca as fi avut in fatza mea un iaz cat Rosia Montana plin cu zama de orice fel (preferabil de burta), l-as fi secat cat numeri pana la 4 in japoneza, cu tot cu timpul care iti trebe sa cauti pe net cum se numara pana la 4 in japoneza.\r\n\r\n- Cum nu se poate plati? zic eu, cuprins de \"mirare\". Dar am bani, aici, numai putin,...\r\n- Se plateste la caserie, zice tanti.\r\n- Bun! zic eu. Perfect! Unde e caseria?\r\n- E inchisa acuma! (era 8 fara 10 seara de vineri...)\r\n- No, zic io, ce pacat, sh atata-mi era de foame...\r\n- ...\r\n- Mnoa, dati-i pace, zic eu, lasati ca vin luni, si-mi fac abonament! Buna seara, zic.\r\n- Buna seara, zice sh tanti.\r\n- Weekend placut, mai zic eu, neclintindu-ma.\r\n- Multumesc la fel, zice tanti.\r\n- Sanatate, mai zic eu. Si ma fac ca plec, fac un pas dureros, in timp ce foamea mea deja ma strangea de gat sh ma sufoca pe la branhii, mai fac un pas calvaric, si ma intorc la tanti, care nici macar nu se miscase, finca se astepta la manevra asta.\r\n- Tanti, zic eu.\r\n- Da! zice ea, si cred ca stia cuvant cu cuvant fraza de 7 cuvinte pe care urma sa o zic, cu un calm cadaveric.\r\n- <strong><em>Nu aveti cumva o portie in plus</em></strong>? zic eu. Amu-i amu, zic io, sa o vad io ca zice nu! Cantina era goala, eram numa\' noi doi.\r\n- Ba da, zice ea, sh zambeshte, io zambesc sh incerc sa nu pufnesc in rÃ¢s, imi pune o piramida de taitei cu varza intr-o farfuie d-aia veeeche, sh mi-o inmaneaza.\r\n- Multumesc frumos, zic eu, ma duc la cea mai din colÅ£ masÄƒ ÅŸi incep sa infulec, sh inghit ca un lup hamseit, si mananc, si imi cufund fatza in movila aia de taiteiÂ  cu varza, si cand gura mi-e plina prizez cu nasu\', sh ma bucur de deliciile acelei mancari de armata cum nu m-am bucurat in viatza mea de tzukini sh de surimi sh de queue de boeuf si de sauce de biere sh de dreq stie ce am mai papat io in viatza asta!\r\n\r\nSh am tot zis ca merg odata cu o sticla de cola sh neshte alune la tanti aia, da\' inca nu am avut coraju\'; da\' oricum donatia asta e prioritara in planul meu pe termen mediu.','Patzanie intamplata in studentie',0,'','publish','open','open','','patzanie-intamplata-in-studentie','','','2007-08-15 21:16:02','2007-08-15 19:16:02','',0,'http://www.groparu.ro/?p=596',0,'post','',14),(597,2,'2007-08-16 16:41:51','2007-08-16 14:41:51','Am ramas fara cuvinte cand am cetit <a href=\"http://milecarpenisan.wordpress.com/2007/08/16/de-ce-citesc-un-gropar/#comment-145\" target=\"_blank\">asta</a>, mai ales ca pe net lumea mai degraba se injura decat se flateaza, finca se flateaza numa cand e femeie, sh io nu-s femeie!','Oda Groparului!',0,'','publish','open','open','','oda-groparului','','\nhttp://milecarpenisan.wordpress.com/2007/08/16/de-ce-citesc-un-gropar/#comment-145','2007-08-16 16:41:51','2007-08-16 14:41:51','',0,'http://www.groparu.ro/?p=597',0,'post','',9),(598,1,'2007-08-17 16:01:04','2007-08-17 14:01:04','Finca e foarte greu sa nu fiu genial atunci cand sunt mahmur, azi m-au izbit drept unde-i e moale voinicului urmatoarele idei:\r\n\r\n- femeile, care are Parkinson la cap, le e OK, ca desi li se clatina capu\', nu se misca inauntru nimic;\r\n- e bine sa ai doo colege de birou care is nulitati, finca minus cu minus da plus;\r\n- daca tot se face marsuri pentru minoritati sexuale, io zic ca sa se faca sh pentru femeile frumoase si destepte, care si ele e in minoritate.\r\n\r\nAcestea fiind zise, io ma cam car in concediu de tri zile, finca vine sorella, care ui ce copkii frumoshi naste din insasi burtica ei (tine-o, Doamne!), dupa ce selecteaza cu foarte mare atentie spermatozoizii campioni:\r\n\r\n[youtube v/I9s-snK_-Zk]\r\n\r\nAsa ca daca vi-i dor de mine, aflatz ca io iz bizzy jucand \"Nu te supara, frate!\"','Idei misogine de azi',0,'','publish','open','open','','idei-misogine-de-azi','','','2007-08-17 16:01:04','2007-08-17 14:01:04','',0,'http://www.groparu.ro/?p=598',0,'post','',8),(599,1,'2007-08-22 01:15:13','2007-08-21 23:15:13','V-am tras-o finca am vint mai rapidie decat anticipasesem, sau cum se zice in <em>mai mult ca perfectul</em> gramatical, care este timpul meu preferat, finca sh io ma considerez mai mult ca perfect, numa ca nu in sus, adeca deasupra <em>perfect</em>ului, ci ca si cum <em>perfect</em>ul ar fi un punct pe planeta asta, sh io depasind <em>perfect</em>ul inconjur planeta, sh ajung exact in punctul de unde am plecat, adeca supt perfect, da\' e OK, finca asta imi lasa un nou ideal neatins in viatza, sh daca ai multe ideale de atins cica traiesti mai mult.\r\n\r\nCe vreau io sa zic: am petrecut 4 zile dementiale cu nepoteii mei, care is cei mai adevarati pui de neamtz sh de om de pe lumea asta, finca is jmekeri:\r\n\r\n- nu se bat intre ei decat numa atunci cand noi nu ne uitam la ei, sh cand ii vedem ca se bat, Äƒla care e ultimu\' plesnit peste fatza de celalalt urla sh zbiara, sh celalalt ÅŸi le Ã®ncaseazÄƒ;\r\n- finca nepotu\' mai mare vroia sa se uite cu mine la DVD-ul cu Pokemoni in germana, sh i-o zis lu maica-sa, care e sor-mea, sh care de fapt e-o doamna sh ea, ca \"Mami, daca nu ma lasi sa ma uit la Pokemoni cu Groparu imi frangi inima!!!\" (ia sa vaz io parinte care sa poata rezista la asa ceva...)\r\n- vorbesc o romano-germana mortala;\r\n- nepot-meu de 6 ani o jucat de 2 ori in viatza lui sah, sh deja stie fiecare piesa ce face, cum se misca si ce e aia rocada, sh daca nu eram atent mi-o cam tragea in freza, ceea ce s-o si intamplat, de fapt;\r\n- is singurele persoane de pe lumea asta care ma fac sa pierd la \"Nu te supara, frate!\", fara ca io sa ma oftic sh sa-l palesc pe nesimtit in moalele capatanii.\r\n\r\nMi-i somn.\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/08/untitled.JPG\" title=\"untitled.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/08/untitled.JPG\" alt=\"untitled.JPG\" /></a>\r\n\r\nIo-te-i acilea cu fetitza Greuceanului, care intr-o buna zi va gati, spala si iubi pe cel putin unul dintre ei.','V-am tras o tzapa!',0,'','publish','open','open','','v-am-tras-o-tzapa','','','2007-08-22 01:15:13','2007-08-21 23:15:13','',0,'http://www.groparu.ro/?p=599',0,'post','',9),(600,1,'2007-08-22 01:13:34','2007-08-21 23:13:34','','untitled.JPG',0,'','inherit','open','open','','untitledjpg-2','','','2007-08-22 01:13:34','2007-08-21 23:13:34','',-1187735166,'http://www.groparu.ro/wp-content/uploads/2007/08/untitled.JPG',0,'post','image/jpeg',0),(601,1,'2007-08-22 16:00:16','2007-08-22 14:00:16','<strong>1.</strong> Finca pe vremea lu\' Ceau\', incalzirea intr-un apartament era intre 80 sh 100 lei. Amu ii vreo cateva milioane bune.\r\n\r\n<strong>2.</strong> Finca am concurat la un post de PR Manager la ei amu-s hÄƒhÄƒÄƒÄƒ, ceva ani buni. Sh am trecut printr-o procedura stufoasa de recrutare, cu copii legalizate pe bani grei (da! muie sh notarilor), cu candidatura depusa numa intre orele 14 sh 15 la ultimul etaj, cu felatii la greu, cu dosar refacut finca nu ne place dosar plic alb, ci trebe culoarea cartonului, bashini d-astea, plicuri timbrate autoadresate, flatulatzii.\r\n\r\nSh examenul o durat 7 ore mari sh late, sh io aveam febra 39 cu nu stiu cat, ca eram super racit, sh una din probe o fost sa descriem un print care sa faca reclama la termoficare. Sh ideea mea o fost ca print-ul sa contina un calorifer sh un puishor de gaina, mancatz-ash, ca toata lumea se udÄƒ cÃ¢nd vede puiÅŸor de gÄƒinÄƒ, deÅŸi nu au nici o problemÄƒ Ã®n a-l ronÅ£Äƒi la KFC cand se face baiat mare, ca dupa aia te si inervezi ca cum puii mei de romancele arata cat butoaiele alea de bulgaroaice!!!\r\n\r\nSh ma gandisem sh la un slogan cel putin demential, de is sigur ca Leo insusi mÄƒre Brunett s-ar fi emotionat sh ar fi facut cerere de rebransare, atata era de sugestiv, dar care ca si celelalte idei DaVinciene din istoria omenirii s-a uitat. Sh am avut sh proba de limba engleza, io fiind singuru\' d-acolo care termenase Literi. Sh dupa proba asta or mai trecut vreo trei saptamani, sh oamenii ma kiama la interviu, ca ramasasem din 16 oameni numa 6, sh mi-am zis: Gropare, amu vei avea caldura intregului orash la limbutza ta, mah! La a ta! Sh tu stii ce chestii frumoase poti face cu limba, mah!\r\n\r\nSh la interviu ramasasem 4 meseriashi sh doua gaini, noi astia patru socializam, mai fumam o tigare, mai un banc cu unguri, numa alelalte doo pkisde nu se integrau, sh mi-am zis ni, mah, astea doo, ce PR menejeritze de toata lela, mah, nu-s in stare sa afle unde-i nordu\', da\' ele or ajuns mari finaliste, ui mai ales la curca cu coc, aia cu decolteu\' ala indoielnic care isi tot aranjeaza sutienu\', gogoasha dreq! Sh dau interviu\', sh aflu dupa alte trei saptamani (o trebuit sa sun io, ca ei desi or promis ca ma suna, o putza! Ia tzapa, Gropare) aflu ca luase al\'cineva, ceea ce era OK, finca niciodata nu m-am considerat cel mai bun la nimic, nici macar la somn, ca sh in somn am vise penale cu insule cu lesbience, in loc sa visez la Nirvana. Care vise mie mi se par super OK, de alfel.\r\n\r\nDa\' dupa 3 luni ma duc la nush ce job fair, sh cine recruta, mancatz-ash! Termoficareaaaa! Ha, zic io, si ma duc la fosta doamna care ma recrutase, sh asta da din coltz in coltz, ca vai, domnu\' Groparu (ma tinuse minte, finca asa-s io, <em>ma tine minte femeileeee</em>), io zic ca nu ca domnu\' Groparu, mi-atz promis ca ma sunatz sa imi spunetz ca am picat interviu\', de ce nu m-atz sunat? Vai, ca ma scuzatz, zice ea, deja nu mai era chitra aia najpa termoficata, era una care nu prea stia cum sa ma ieie, sh zic io \"Da cine-o loat postu\'?\" \"A, zice ea, o domnisoara foarte calificata sh buna in ceea ce face, o kiama <em>nu-mai-stiu-cum</em>, nu e aici ca e pana afara! \"Bine, zic io, bafta, ma duc sa le dau muie la Zapp, care sh ei fac recrutari, sh merg sa ma rad de Zappii aia care is mai prosti ca mine, da\' castiga dolarei la greu, ca lucreaza pe telefonie mobila, ca io inca is profesor sh pana sa se inventeze bloagele, peste 7 ani, nu am cum sa stralucesc de pseudo-genialitate decat la o bere!\" Da nu ma rabd, sh dau o tura inapoi sa o vaz sh io pe PR menejeritza aia care loase postu\', ca credeam ca era una din aia 4 care tot povesteam la interviu, sh cand colo! Era gogoasha, mah, gogoasha, aia decoltata indoielnicÄƒ, macar daca era unu sau una din aia 4, da\' nu, termoficatii or loat-o pe curca aia, mah, sh-apa sa nu te ovtici??? Muriti!!!\r\n\r\n3. Pentru ca la cativa ani de la chestia asta, trec prin centru, sh ce reclama la termoficare imi zambeste dintr-un outdoor? Un puisor de ratza (!?!?!) langa un calorifeeeer!\r\n\r\n4. Finca azi dimineatza cand sa fac dushul de riguare, descopar ca, pentru a patra oara anu\' asta, NU AM APA CALDA.  Sh asta fara sa puna nici un anuntz - sh-apa sa nu-i baji in kisda mamii lor???','Deci de ce fuck you, too, termoficare',0,'','publish','open','open','','deci-de-ce-fuck-you-too-termoficare','','','2007-08-22 16:00:48','2007-08-22 14:00:48','',0,'http://www.groparu.ro/?p=601',0,'post','',9),(602,1,'2007-08-22 17:03:18','2007-08-22 15:03:18','Io nu pre pun chestii de la altii la mine pe blog (daca vreatz haioshenii, meretz pe resursedefun, daca va trebe pornache, redtube.com e always available, sh daca vreatz tecste penale scrise de o minte virgina, de calugaritz, va recomand groparu.ro), da\' chestia asta merita cetita, mai ales ca e la prima manutza, primita de la prekinu\' meu Luci, care e in State, sh e cam coios, asha, el de felu lui:\r\n\r\n<em>\"Ia uite ce i s-a intamplat la un prieten de-aici! si-a cumparat Noul Celular ipod ala de l-a facut apple, la care ii zice IPHONE, si totu\' frumos si bine, planul lunar care l-a facut cu AT&amp;T (o companie telefonica mare de aici din state) a fost ok pentru USA. Dar cand baiatul a inceput sa calatoreasca in Europa (Franta), a folosit telefonul numai pentru e-mail. Cand s-a intors inapoi si a venit plata lunara, surpriza! pe bill zicea ca are de plata $4190 (dolari, da!). Asta sa inebuneasca, a sunat compania, crezand ca e o greseala, dar reprezentantul AT&amp;T i-a explicat ca in afara Statelor Unite, ei incaseaza $5/mb. No acum trebe de stiut ca telefonul asta bengos foloseste Internetul si singur, chiar daca tu nu-l folosesti, ca iti \"update\" automatic toate functiunile care se bazeaza pe conexiune de internet, cum ar fi vremea, stock market s.a. Suparat asta, a chemat stirile, interviuri, chestii, si a apelat la noi sa-i facem o comerciala pentru youtube, ca vrea sa-i dea in gat pe ticalosii astia </em>corporate<em>. Ei bine, noi ce am zis, hai sa imitam cat mai bine spotu\' publicitar original (iar acela fiind foarte simplu am reusit in 20 min sa il filmam la noi in studio, iar in alte 10 min l-am montat cu muzica si vocea facuta de Buster colegul meu, cu vocea lui de radio). Si iata ce a iesit!\r\n</em><a href=\"http://www.youtube.com/watch?v=qTkP-4CvoOE\" target=\"_blank\">http://www.youtube.com/watch?v=qTkP-4CvoOE</a><em>\r\nCa sa vedeti originalul, sa aveti ca si comparatie, mergeti aici:</em> http://www.apple.com/iphone/ads/ad9/\r\n<em>Dupa ce am avut comerciala, Äƒsta a pus-o pe youtube, a trimis-o la CEO de la AT&amp;T, si chiar a prins unele din e-mailurile lui Steve Jobs. Astazi dimineata a primit un e-mail de la CEO AT&amp;T care zicea ca cineva de la companie o sa-l sune, ceea ce s-a si intamplat, si i-au redus bill-ul la $700.\r\nSi inca ceva: spre surpriza lui, la o zi dupa ce a trimis e-mail-urile, contul lui de e-mail de la Mac nu a mai functionat astazi pentru o zi intreaga. (Najpa, nu?) No pa asta-i poveste pe lung la ce i s-a intamplat lui Piere cu bengosul lui telefon IPHONE, pe care si eu l-am cumparat bininteles, ca pana la urma trebe sa tinem pasul cu tehnologia!\r\n</em>\r\n<em>Inca o data, puteti viziona versiunea noastra a spotului publicitar aici:</em>\r\nhttp://www.youtube.com/watch?v=qTkP-4CvoOE\r\n\r\n<em>No ni la ei!\r\nCiau bai flacai, si numa de bine!</em>\r\n\r\n<em>Luci </em>','iPhone? Neverphone!',0,'','publish','open','open','','i-phone-neverphone','','','2007-08-22 17:05:48','2007-08-22 15:05:48','',0,'http://www.groparu.ro/?p=602',0,'post','',1),(603,1,'2007-08-23 08:58:21','2007-08-23 06:58:21','Booon, aia am inteles-o cum ca Zaraza nu te mai respecta daca cauti lantisoare de aur prin parizere. Dar\' daca caut carne prin parizer, ma mai respecta? Oare ce am mai multe sanse sa gasesc prin parizere, carne adevarata, sau aur?','Deci, pastila despre respect',0,'','publish','open','open','','deci-pastila-despre-respect','','','2007-08-23 08:58:21','2007-08-23 06:58:21','',0,'http://www.groparu.ro/?p=603',0,'post','',9),(604,1,'2007-08-23 11:43:33','2007-08-23 09:43:33','Â <a href=\"http://www.groparu.ro/wp-content/uploads/2007/08/vladimir.jpg\" title=\"vladimir.jpg\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/08/vladimir.jpg\" alt=\"vladimir.jpg\" /></a>\r\n\r\nDa, mai copii, deci dupa ce am stabilit o Basescu o relatie sincera, de prietenie si reclama in sistem barter (dÄƒ click <a href=\"http://www.groparu.ro/?p=402\" target=\"_blank\">aci</a> daca ej mai nou pe sait), m-am hotarat sa tintesc mai sus. Da, mult mai sus.\r\n\r\nGerhard Schroeder ma cam enerveaza, ca s-o dat cu Gazpromu\'. Bushulica nu cred ca stie engleza la fel de bine ca mine ca sa comunicam, sh nici nu are suficienti bani ca sa ii dau io meditatii la limba lu Shakespeare, plus ca de 7 ani e ocupat cu <em>nukular bombs</em>. Baroso ii numa un birocrat european, sh sh portughez pe deasupra, sh Sarkozy m-o rugat sa il las un pic sa termine primu mandat sh-apai iesim la bere.\r\n\r\nAsa ca m-am hotarat sa ma imprietenesc cu Putin. Da, mah, cu Vladimir Putin, pe care l-am acatzat de pe net, de pe o adresa de social networking, aia de-i zice Yahoo! 360. Nu i-am facut invitatie de join, ca nu ma intere\' sa ii creasca traficu\' de pe pajina lui daca il adaug la prekini, finca probabil isi pune Ad Sense ca alti bloggeri. Oricum, e bine de stiut ca e acolo nenea Putin. Sh daca am kef il invit odata la o partida de box, la un meci de Counter Strike sau chiar la <a href=\"http://www.groparu.ro/?cat=4\" target=\"_blank\">Tiganiada</a>, desi cica nu mai primim noi membri.\r\n\r\nPS: A, era sa uit: <a href=\"http://blog.360.yahoo.com/blog-zUc8ya0nfqoQ56EDRze55IaNirrlWhg-?cq=1&amp;p=1#comments\" target=\"_blank\">acilea</a> e saitu\' lui de pe yahoo 360, va rog FRUMOS daca ii lasati comentarii sa o faceti cu mult bun simptz, asa cum v-o invatzat mama sh taticul vostru, bunul vecin de vizavi, ca sa nu ne trimeata dreq ceva tezaure de boambe atomice!!! Ca asta-i nebun.','Eu sh prietenul meu Vladimir Putin',0,'','publish','open','open','','eu-sh-prietenul-meu-vladimir-putin','','\nhttp://www.groparu.ro/?p=402','2007-08-23 11:43:33','2007-08-23 09:43:33','',0,'http://www.groparu.ro/?p=604',0,'post','',4),(605,1,'2007-08-23 11:40:34','2007-08-23 09:40:34','','vladimir.jpg',0,'','inherit','open','open','','vladimirjpg','','','2007-08-23 11:40:34','2007-08-23 09:40:34','',-1187861071,'http://www.groparu.ro/wp-content/uploads/2007/08/vladimir.jpg',0,'post','image/jpeg',0),(606,1,'2007-08-23 14:09:59','2007-08-23 12:09:59','Azi vorbeam cu Tibby, pe care il puteti auzi zilnic intre 7 sh 12 la ekipa de distractie intr-un show demential pe <a href=\"http://transilvania.hertza.ro:8512/listen.pls\" target=\"_blank\">Radio Transilvania</a>, deci vorbeam cu Tibby despre neshte subiecte asa de importante, ca or devenit predicate!!!','Deci, despre',0,'','publish','open','open','','deci-despre','','','2007-08-23 14:11:36','2007-08-23 12:11:36','',0,'http://www.groparu.ro/?p=606',0,'post','',2),(607,1,'2007-08-23 14:49:02','2007-08-23 12:49:02','(cine imi spune care e prenumele si care numele din <a href=\"http://milecarpenisan.wordpress.com/2007/08/22/vine-23-august-un-moment-bun-pentru-defilari-si-pentru-un-eseu-semnat-de-mile/#comments\" target=\"_blank\">Mile Carpenishan</a>, e ori meseriash, ori sarb)\r\n\r\nDeci:\r\n\r\nAstazi e ziua ta, zi frumoasa ca si tine,\r\nS-ai o viatza far\' bashine,\r\nSa apari mereu pe sticlÄƒ,\r\nSa vorbesti si de-a mea biclÄƒ,\r\nSa transmiti sh despre viatza, dragoste si pace,\r\nSefii-ti sa nu fie dobitoace!\r\nSanatate s-ai cu caru\'\r\nSi in mana plin\' paharu\',\r\nSi sa mai ceteshti Groparu\'!\r\nSa fii fruncea din Banat\r\nSi frumos ca un pÄƒcat,\r\nSi daca ti-or zice altii\r\nAberatii, aberatii\r\nTu nu te lua dupa ei:\r\nTrimite-i la Doctorul Andrei!\r\n\r\nE, mah, La Multi Ani;)','Azi e ziua lui Mile (Grazie) Carpenisan',0,'','publish','open','open','','azi-e-ziua-lui-mile-grazie-carpenisan','','\nhttp://milecarpenisan.wordpress.com/2007/08/22/vine-23-august-un-moment-bun-pentru-defilari-si-pentru-un-eseu-semnat-de-mile/#comments','2007-08-23 14:56:24','2007-08-23 12:56:24','',0,'http://www.groparu.ro/?p=607',0,'post','',7),(608,1,'2007-08-23 20:57:09','2007-08-23 18:57:09','Urmeaza un mesaj cat se poate de suburban, vulgar sh licentios, si rog domnisoarele, pocaitii sh minorii sa isi astupe urechile:\r\n\r\nBAGA-MI-AS PULA IN EA TERMOFICARE, DIN CAUZA CAREIA O TREBUIT SA FAC DUSH CU APA RECE SH AZI, SH DIN CAUZA CAREIA PUTZULICA MEA S-O MICSORAT LA DIMENSIUNI PE CARE NU LE-AS FI BANUIT POSIBILE, FINCA E MULT MAI MICA CHIAR DECAT MI-O FACUT-O OVULUL MAMICII MELE (care de fapt e-o doamna) IN COLABORARE CU SPERMATOZOIZII CAMPIONI!!!\r\n\r\nMUIEEEE AAARRRRGGGGHHHHHH','Deci despre Termoficare, AGAIN',0,'','publish','open','open','','deci-despre-termoficare-again','','','2007-08-23 20:57:09','2007-08-23 18:57:09','',0,'http://www.groparu.ro/?p=608',0,'post','',17),(609,1,'2007-08-24 12:03:02','2007-08-24 10:03:02','E ceva Sony Ericsson K 4 miliarde i de la giava, la rugamintile fioroase ale <a href=\"http://blog.pacurar.net\" target=\"_blank\">shafului</a> sh la somatiile <a href=\"http://www.andreicrivat.ro\" target=\"_blank\">Crivatzului</a>, care vorbeste cu mine la telefon de fiecare data cand face ceva apsolut demential, gen pishu pe colac fara sa se stropeasca, cand papa telemeaua de oaie (de fapt e de oi, da\' inca nu-i spuneti), cand isi cumpara bicicleta de gay sau cand isi skimba tricou\'.\r\n\r\nIdeea care este: telefonu e amu la formatat, e inkis, asa ca cei care nu aveau de gand sa ma sune azi ii rog sa ma sune acum, finca nu le pot raspunde.','Mi-am loat telefon nou',0,'','publish','open','open','','mi-am-loat-telefon-nou','','','2007-08-24 12:03:02','2007-08-24 10:03:02','',0,'http://www.groparu.ro/?p=609',0,'post','',8),(610,1,'2007-08-24 15:17:26','2007-08-24 13:17:26','<a href=\"http://www.groparu.ro/wp-content/uploads/2007/08/gropy_chair.jpg\" title=\"gropy_chair.jpg\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/08/gropy_chair.jpg\" alt=\"gropy_chair.jpg\" /></a>\r\n\r\nVia Danila, care e mai multe chestii, sh care o pus-o <a href=\"http://www.imagic.ro/groparu/Gropy_chair.jpg\" target=\"_blank\">acilea</a>.\r\n\r\nIo i-am zis ca spatiu pentru coaeh e prea mic pentru mine.','Scaun de Gropar',0,'','publish','open','open','','scaun-de-gropar','','','2007-08-24 15:54:58','2007-08-24 13:54:58','',0,'http://www.groparu.ro/?p=610',0,'post','',11),(611,1,'2007-08-24 15:47:57','2007-08-24 13:47:57','','gropy_chair.jpg',0,'','inherit','open','open','','gropy_chairjpg','','','2007-08-24 15:47:57','2007-08-24 13:47:57','',610,'http://www.groparu.ro/wp-content/uploads/2007/08/gropy_chair.jpg',0,'post','image/jpeg',0),(612,1,'2007-08-26 00:53:38','2007-08-25 22:53:38','Am ramas in urma cu raspunsul la comentarii, am ramas in urma cu ce am facut de joi seara pana azi, sh kiar am kestii de zis, pen\' ca joi seara am mÄƒrs in Autograf si iar\' m-am facut de ras cand am pus mana pe chitarÄƒ, vineri am fo la bowling si am reusit sa obtin un scor de fatÄƒ, sÃ¢mbÄƒtÄƒ am foat la nunta lu\' LuminiÅ£a UNDE S-OR INTAMPLAT O GROAZA, sh dumineca, adeca azi, ma car la Sibiu, unde ma mai dau o tura in barci cu nepoteii lu\' unchiu\', ultima tura de anu asta, si nu revin decat marti dimineatza in <em>cel mai frumos oras din Romania </em>(yeah, right...)\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/08/dsc00046.JPG\" title=\"dsc00046.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/08/dsc00046.JPG\" alt=\"dsc00046.JPG\" /></a>\r\n\r\nCe pot sa zic este cÄƒ: m-am hotarat sa mai trag o abstinenta ca pe vremea postului. Mi-i efectiv acru sufletu\' de betii sh kefuri, asa ca o vreme <strong>nu am sa mai fumez sh nu am sa mai beau NIMIC</strong>, sper sa ma tina macar o saptamana, si e musai sa ma tina. Ca io iz asa, cam masochist. Numa\' de la cele trupesti, fie-mi iertata aplecarea nepamanteana catre preacurvie,  nu am sa ma abtin, decat cand mi-or coase p***!','Deci in primul rand',0,'','publish','open','open','','deci-in-primul-rand','','','2007-08-26 00:56:25','2007-08-25 22:56:25','',0,'http://www.groparu.ro/?p=612',0,'post','',7),(613,1,'2007-08-26 02:06:10','2007-08-26 00:06:10','Da, nu ma pot abtine, sh tot va zic:\r\n\r\nDeci joi - betie, club, muzica live, toate ingredientele; a doua zi, vineri, ma trezesc - natural - cu urekile vÃ¢jÃ¢ind,  plec la firma, pe dupa pauza de masa vine doo colege cu cei doi prunci proaspat ejectati sa se laude cu ei, sh clar - mai mere o bere, kiar doo; seara - bauling, dupa cum ziceam,  nu am iertat nici o berula care nu fierbea in pahar, ci numa se acoperea pe capatzana de o spuma rece.Sambata - exact. Doua mahmureli se zbateau vesele la mine intre urechi, in spatele fruntii sh in fatza cefii, pitite bine sub calota craniana. Ma simteam de parca aveam un pitic ascuns in cap sh care dadea in peretii capatanii cu un ciocan:  BOOOOIIIINNGGG!!!! BOBOBOBOOOIIINNNNGGGGG!!!!!! Auuu... doare.\r\nParanteza: a inceput un sezon care va ramane in analele autobiografiei mele ca fiind sezonul celor 5 nunti, fara nici o inmormantare, cÄƒ sÄƒ nu prind pe nimeni ca moare, ca-l omor! Deci ideea e ca am de mers la 5 nunti pana pe 23 septembrie, sh prima tocmai a debutat.\r\n\r\nMnoa. Sambata, deci, dupa doo betii, aveam de mers la nunta. Io, de regula, la nunti ma bucur ca beutura e in sistem de bufet suedez. Dar din moment ce tÄƒt golisem sticloantze sh joi, sh vineri, sÃ¢mbÄƒtÄƒ dimineatza nu prea m-o imboldit o veselie matinalÄƒ afarÄƒ din pat; dimpotriva, am simtit nevoia sa imi fac somnul de frumusetze pana hapt la ora 1, sau, cum i se mai zice, <em>treisprezece.</em> Cand mi-am dat seama ca degeaba am dormit atata, ca tÄƒt ma dureau toate, bine-nteles ca nu am devenit foarte fericit; dar cu vaiete sh gemete m-am tarat pana supt dush, pe care l-am si facut, mi-am amintit apoi ca mi-am promis ca nu ma mai ating de beutura si tigari o saptamana, sh apoi am taiat-o spre Cora sa imi iau costumu\' de la curatat.\r\n\r\nClar ca intr-un final am intarziat mai mult de o ora la nunta.\r\n\r\nDar - si aici povestioara devine interesanta - noi am crezut ca norii Äƒia negri-negri care se strang pe cer is de fapt numa\' neste aburi de parfum de domnisoare, o simplÄƒ ceaÅ£Äƒ de august; cÃ¢nd colo, mÄƒi frate, cand mi ti se porneste ditamai ploaia, cu grindinÄƒ, Å£urÅ£uri ÅŸi zÄƒpadÄƒ din cer, cu aoleo, ca am si crezut ca ne smulge cu tot cu taxiu ÅŸi ne tÃ¢rÄƒÅŸte pÃ¢nÄƒ prin Republica Centrafricana, sau cum p^@# se scrie!!!\r\n\r\nÅži aici intervine geniul plenar al Groparelui, care dacÄƒ n-ar fi el (geniul), acest blog ar musti de creatiile youtubizate ale altora: Ba, zic  io, haide sa coboram sa cautam restaurantu\', ca e prin zona! Nu poate fi departe. Si coboram din taxi pe ploaia aia torentiala imbracati frumosi de nunta, cu o juma de umbrela de domnisoara la purtator, intr-o zona in care SE REPARA TROTUARUL, deci apa din balti avea vreo 10 centimetri adancime, sh era si ciocolatie. A, si nu puteam merge pe trotuar, ca era mocirla, asa ca mergeam pe carosabil, si toate masinile ne stropeau cu apa din balti, balti din alea ciocolatii, dupa cum ziceam, culoarea cafelei cu lapte negru!\r\n\r\nIntr-un final glorios, dar ud, ajungem sh la restaurant. Unde venisera cam toti, sala arhiplina, lumea tocmai papase aperitivu\' (va zisei ca am intarziat o ora), sh discutau oamenii la mese, se imprieteneau sh asteptau ca mirii sa deschida dantzul. Sh numa ce aparem noi doi, smiorcaitzi, in haine ca buretii, ca cand calcam pe jos numa asa se auzea: flatsch!!! flatsch!!! Sh clar ca intram in sala, sh nimeni nu mai discuta nimic!!! Toti se holbÄƒ cum de am io costumu\' in 2 culori (partea curata sh uscata versus partea uda sh mizerabila), se holbÄƒ la freza Groparitzei (care freza???),  la florile pe care nu le mai luasem sau le pierdusem, io in acelasi timp cocÃ¢rjat de dureri mahmureice, la picaturile de apa care se prelingeau furioase pe urechi, la baltoacele care ramaneau pe unde calcam. Sh noi ranjeam foaaarte nervos!\r\n\r\nSh ne-am dus la miri, i-am felicitat pe miri sh pe nashi sh am avut grija sa ii udam sh stropim sh pe ei in procesul asta, dupa care ne tÃ¢rÃ¢im catre masa noastra. Care nu mai avea locuri disponibile, ca le loasera altii. Toata sala era cu ochii pe noi! Stam acolo, complet depasiti de evenimente, pana cand cineva cheama un chelner, care se uita la noi, ridica din umeri, sh dispare. Sala se holba, sh shushoteshte in jur, prind franturi cu \"Sa plece acasa!\" Ne uitam in jur - singurele locuri disponibile din sala erau la alta masa, masa pazyanilor, asa am dedus io, ca erau foarte rurali oamenii sheia din cea masÄƒ, femei cu batic sh fuste, sh aveau sh de vreo 8 ori varsta mea, care de fapt e destul de venerabilÄƒ, deci am fi avut o sumedenie de subiecte interesante de discutat cu ei, despre cum l-au sedus ele in tinerete pe Ramses sh Tutmes.\r\n\r\nDupa ce mai aluneca privirile salii peste trupurile noastre ude pretz de inca cateva minute, cineva preia initiativa, se impinge masa aia a tinerilor, o trag, o fut de-amiaza, ni se face loc, ni se aduc doua scaune (nota bene, chelnerii reaparusera sh <em>coordonau</em> toata operatiunea fara a se <em>implica</em> deloc!), sh ma prabusesc la locul meu, simtindu-ma ud, transpirat de la emotia vie care ma incerca, gafaind de rau ce-mi era sh dorindu-mi sa mor, numa sa nu se mai uite toata lumea la mine asa!!!\r\n\r\nToata nunta am baut numa\' Pepsi sh apa minerala. Nici nu am mirosit alcoolu\'. Tigari ashijderea, deloc.\r\n\r\nDa, sh la masa nu aveam trei tipuri de furculite sh trei de cutite, ci trei furculite sh cutite de acelasi tip, aceeasi dimensiune, aceeasi serie. Asa ca, ca de obicei cand merem la nunti,  le-am furat! Si acum am acasa cel putin vesela necesara pentru inca doi oaspeti, daca vin la masa.\r\n\r\nCERT E CA LA NUNTA NE-AM DICKSTRAT SUPER, SH O FOST SUPER K-LUMEA, SH VA DORESC O VIATZA USCATA, FAR\' DE PATA, familia! Se aude? CASA DE PIATRA!\r\n\r\nPS: Ca uitai sa va spui ca pe mireasa o cheama de azi intr-un fel care seamana cu Marcy Darcy.','Tot nu ma pot abtine...',0,'','publish','open','open','','tot-nu-ma-pot-abtine','','','2007-08-26 07:01:09','2007-08-26 05:01:09','',0,'http://www.groparu.ro/?p=613',0,'post','',6),(614,1,'2007-08-26 00:56:00','2007-08-25 22:56:00','','dsc00046.JPG',0,'','inherit','open','open','','dsc00046jpg','','','2007-08-26 00:56:00','2007-08-25 22:56:00','',612,'http://www.groparu.ro/wp-content/uploads/2007/08/dsc00046.JPG',0,'post','image/jpeg',0),(615,1,'2007-08-28 14:17:56','2007-08-28 12:17:56','Ce pot sa zic decat ca telefonu\' meu e atata de destept, ca azi dimineatza m-o pus <strong>el</strong> pe mine sa sun, ca sa il trezesc! Sh cand m-or furat extraterejtrii peste weekend, m-or examinat pe mine sh telefonul, or bombanit intre ei, sh stii ce or decretat ei intre ei in egztraterestra aia a lor? \"Ce cauta asta mic sh destept cu asta mare sh prost?!?!?\"\r\n\r\nMnoa!','Despre telefonul meu',0,'','publish','open','open','','despre-telefonul-meu','','','2007-08-28 14:17:56','2007-08-28 12:17:56','',0,'http://www.groparu.ro/?p=615',0,'post','',5),(616,1,'2007-08-28 16:23:28','2007-08-28 14:23:28','EU - GropareleÂ  -\r\n\r\nNu. Suna ca dreq in romaneste, asa ca am s-o zic in engleza:\r\n\r\nI don\'t have a drinking problem! I have a drinking <strong>solution</strong>!\r\n\r\nUite o poza cu familia mea:\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/08/p4221300.JPG\" title=\"p4221300.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/08/p4221300.thumbnail.JPG\" alt=\"p4221300.JPG\" /></a>\r\n\r\nPS: V-atz prins, nu e familia mea, e familia maica-sii.','Si ca sa termin discutia,',0,'','publish','open','open','','si-ca-sa-termin-discutia','','','2007-08-28 16:23:28','2007-08-28 14:23:28','',0,'http://www.groparu.ro/?p=616',0,'post','',4),(617,1,'2007-08-28 16:22:58','2007-08-28 14:22:58','','p4221300.JPG',0,'','inherit','open','open','','p4221300jpg','','','2007-08-28 16:22:58','2007-08-28 14:22:58','',616,'http://www.groparu.ro/wp-content/uploads/2007/08/p4221300.JPG',0,'post','image/jpeg',0),(618,1,'2007-08-28 22:58:31','2007-08-28 20:58:31','1. Daca ai fost traumatizat in copilarie de un vecin pe nume Luci, te poti razbuna pe fiecare copil pe care-l cheama la fel.\r\n\r\n2. Multi copii au mame tinere sh frumoase care asculta cu sfintenie tot ce le spui tu.\r\n\r\n3. Nu in fiecare zi intalnesti la strand o fosta eleva devenita peste noapte o bunaciune de 19 anisori!\r\n\r\n4. Nu in fiecare zi o asemenea bunaciune vine sa te pupe in piscina.\r\n\r\n5. Nu in fiecare zi ai sansa sa refuzi o asemenea bunaciune.\r\n\r\n6. Poti sa exclami \"Nu stiu ce se va alege de generatia voastra!\", si chiar sa ii convingi si pe ei de ce spui.\r\n\r\n7. Poti sa confisti pentru o perioada un celular mai meserias ca al tau de la un elev care se da jmeker cu el si sa iti suni de pe el pretenii profesori care culeg struguri in Spania.\r\n\r\n8. Poti sa vorbesti cate o ora pe zi unui auditoriu care <em>nu are voie</em> sa sufle.\r\n\r\n9. NU ORICAND IN VIATA TA AI SANSA SA FUTI CREIERELE TINERE ALE UNEI INTREGI GENERATII! Now ain\'t that fun, or what???\r\n\r\n<strong>Update</strong>: Deci la punctul 1, in loc de \"Luci\", se va ceti \"Pompiliu\", ca am primit reclamatii de la Asociatia Lucienilor Caldarari din Calea Lactee.','9 motive sa fii prof',0,'','publish','open','open','','9-motive-sa-fii-prof','','','2007-08-29 10:12:27','2007-08-29 08:12:27','',0,'http://www.groparu.ro/?p=618',0,'post','',15),(619,1,'2007-08-29 16:26:18','2007-08-29 14:26:18','I: Cum innobilezi apa pura de izvor?\r\n\r\nR: O transformi in bere.\r\n\r\nI: Cum innobilezi o bere pura?\r\n\r\nR: O transformi in pishu.','Intrebarea zilei',0,'','publish','open','open','','intrebarea-zilei','','','2007-08-29 16:27:21','2007-08-29 14:27:21','',0,'http://www.groparu.ro/?p=619',0,'post','',3),(620,1,'2007-08-29 19:38:56','2007-08-29 17:38:56','Azi, stateam sh eu pe un fund de-al meu sh ma zgÃ¢mÃ¢iam Ã®n nas sh - munceam. Cu cealalta mÃ¢nuÅ£Äƒ munceam, ca ailaltÄƒ decat cealaltÄƒ era ocupatÄƒ cu foratu\'. Adeca calculatoream sh gropÄƒream.\r\n\r\nDeodata primesc un mail.\r\n\r\nDe la Radu Bazavan!\r\n\r\nCu un atasament baban, 3 mega sh ceva, pe care scria \"poze Ardeal\".\r\n\r\nAia dintre voi care nu ma stiti in cealalta lume virtuala, aia de carne sh oase, aflati ca trebe sa stiti doo kestii referitoare la mine: 1) daca nu ma stiti, nu aveti nimic de pierdut; 2) numele meu in viata virtoala ii - ati ghicit - Radu Bazavan.\r\n\r\nDeci eu primisesem un mail de la mine, fara ca eu sa mi-l fi trimis vreodata!\r\n\r\nAm incremenit o vreme cu degetu\' meu preferat in nas; am clipit sh am incercat, cu unghia de la degetul mic (aia pe care o folosesc eu drept sÄƒrÄƒtiÅ£Äƒ) sÄƒ imi Ã®nlÄƒtur ceara aia galbenÄƒ intarita din jurul ochilor, care de fapt e aceeasi materie pe care o scot din urechi dupa ce fac baie sh ma sterg cu chilotii in pavilioane, catre trompa lui <em>Eustache</em> sau <em>Eustachio</em>, <em>both versions are correct</em>, depinde cu cine ai facut Botanica la scoala.\r\n\r\nViziunea aceea de mail ramasese acolo, in inboxul meu.\r\n\r\nAmu... ce era sa fac?\r\n\r\nDescarc atasamentu\', sa vad io ce atasament ii ala de trei mega, si asteptandu-ma sa fie vreo bomba atomica de virus care sa inchida firma, sa schimbe presedintii chinezi sh sa schimbe gradul de inclinare al axei Pamantului, ca atunci cand or murit dinozaurii!\r\n\r\nAtasamentu\' - un .zip cuminte - nu avea altceva decat neshte poze, da\' nu cu femei goale sau cu mine scobindu-ma in nas, ci cu ceva vulcani noroiosi sh castelul Huniazilor - stiti voi, familia aia romaneasca ce o ajuns cea mai tare dinastie de regi maghiari.\r\n\r\nMah! Sh stau io, sh incerc sa ma gandesc cum de chestia asta e posibila, ca io cam tin minte ce am facut, mai ales ca din cate stiu m-o ferit D-zeu pana amu de trei chestii: boli transmise sexual sh Alzheimer. Sh in timp ce mintea mea era asa-ntr-o erectie prelungita, ce fac io! Pun mana pe telefon sh sun la numarul ala care era scris in mail, la semnatura.\r\n\r\nSuna.\r\n\r\nRaspund eu, de la celalalt capat al firului.\r\n\r\n- Alo, zic io.\r\n- Da, zic tot io. Dl. Bazavan? Ma intreb eu.\r\n- Da, imi raspund eu.\r\n- Buna ziua, zic eu.\r\n- Buna ziua, imi raspund.\r\n- Sunt Bazavan, zic eu, Radu... Bazavan.\r\n- ?!?!?!?! fac io.\r\n- Da, zic, mi-am trimis amu-s 3 minute un e-mail!!! Sh era de pe o adresa de firma la care eu nu lucrez!\r\n- ?!?!?!?! fac io.\r\n- Bai nene, zic io, uite ce e: ma cheama Radu Bazavan sh nu am telefonul asta pe care te-am sunat acuma. Intelegi? No, e simplu doara!\r\n- Nu pot sa cred! exclam eu, mirat pana peste poate.\r\n- Ba da, e adevarat. Unde locuiti? ma intreb.\r\n- In Bucuresti, raspund eu.\r\n- Cluj, zic io, viitorul <em>Villa Groparica</em> <em>Rex</em>.\r\n- Hehe, fac io, dandu-mi seama cat is de amuzant.\r\n- Si! zic io. Ce-s parintii?\r\n- Olteni, zic eu, da\' nush din ce parte.\r\n- Olteni, ha! zic io. D-aia care stie sa faca zama de gaina, nu se joaca! Mno mah, fii antena, ca sh tata meu e oltean, mai mancatz-ash, mai vere, de la Dragasani, mÄƒi, de la Dragasani, unde e vinu ala dulce, mah, sh vinu-i dulce!\r\n- Ba, zic io, fii antena ce propun io: hai, cand avem copii,Â  le dam acelasi nume!\r\n- ?!?!?! fac io, uimit de ce-am putut propune!\r\n- Da, bah, fii antena, indiferent daca e baiat sau fata! Daca asta nu ar fi cool, io nush ce e cool atunci! zic eu, dintr-o data entuziasmat.\r\n- Mo, zic io, nestiind cum sa ma iau, nush ce sa zic, finca...\r\n- Ba, zic, asta nu se negociaza, finca daca ma enervezi o sa ajung celebru sh o sa te intrebe toata lumea \"Dvs sunteti Radu Bazavan?\", si tu vei raspunde o viatza intreaga cu \"Nu, io sunt celalalt!\" - devin io dintr-o data amenintator.\r\n- Ba, zic io, hai sa ne imprietenim sh sa ne cunoastem mai bine!\r\n- Ba, zic io, numa atata asteptam de la viatza!Si apoi... <em>we shall rule ze world!!!</em>\r\n\r\nDupa ceÂ  ne-am loat la revedere, am continuat sa il zgÃ¢mÃ¢i pe Radu BÄƒzÄƒvan in nas, stÃ¢nd sh eu pe un fund de-al meu sh - muncind.','Cum l-am cunoscut eu cu adevarat pe Radu Bazavan',0,'','publish','open','open','','cum-l-am-cunoscut-eu-cu-adevarat-pe-radu-bazavan','','','2007-08-29 19:38:56','2007-08-29 17:38:56','',0,'http://www.groparu.ro/?p=620',0,'post','',12),(621,1,'2007-08-30 14:54:18','2007-08-30 12:54:18','Tunait canta Mishu in Autograf ieara, sh mi-o zis sa ii fac reclama, si ui ni, ca asta ii fac!\r\n\r\nPe la 10-11, Memorandumului 23, parca, cel mai treaz personaj de acolo voi fi - ati ghicit - eu, finca inca <strong>nu </strong>m-am re-apucat de beut, fumat sh alte shele. Desi mi-a venit de cateva ori sa imi trec un glontz printre urechi, sa imi fac venele evantai, sa ma tai in bucatele sh sa ma fierb, sa ma arunc de pe sediul BRD din Marasti, sa ma sugrum cu o punga sh sa imi zic zic \"I\'m sorry, Groparu, it\'s nothing personal; it\'s just business!\", sh dupa ce m-am omorat sa imi fac semnul crucii, sa ma ingrop undeva in cimitir unde sunt inmormantate virginele, sau intr-o padure din aia cu fenomene paranormale, la miez de noapte, la lumina farurilor masinii, sh dupa ce ma ingroapa, asasinul meu (care de fapt tot eu sunt) sa fie cuprins de o frica subita finca aude tot felu de gemete (da\' nu erotice) din padure, sh cand sa fuga cu mashina sa nu ii porneasca, sh cand sa fuga pe jos sa se impiedice de manutza mea ieshita subit, intr-un fel cum nu-mi explic, din mormantul proaspat sapat, sa il trantesc pe jos, sa ma catzar pe el, sh sa ii strig la ureche, cu privirea fixa:\r\n\r\nCREDEAI C-AM MURIT, NEICA????','Tunait canta Mishu',0,'','publish','open','open','','tunait-canta-mishu','','','2007-08-30 14:54:18','2007-08-30 12:54:18','',0,'http://www.groparu.ro/?p=621',0,'post','',2),(622,1,'2007-08-30 15:29:24','2007-08-30 13:29:24','In mod exceptional, incep postarea de azi cu un citat din memorie sau din Academia Catzavencu:\r\n\r\n\"Despre statul african Swaziland se prea poate ca nici macar locuitorii lui sa nu fi auzit\"\r\n\r\n(rÃ¢sete)\r\n\r\nEi bine, amu veti fi auzit mai multi. Finca in revista ziarului pastorit de <a href=\"http://www.ciutacu.ro/\" target=\"_blank\">Ciutacu</a>, ma refer la <a href=\"http://www.jurnalul.ro/articole/101013/swaziland-printesa-sikhanyiso-conduce-dansul-virginelor\" target=\"_blank\">Draga Jurnalule</a>, am cetit o stire care m-a incremenit ca atunci cand, in troleu, eleva tzatzoasa de a 12-a care mere la pregatire pentru bac isi freaca decolteu\' de spinarea goala a maieului tau, sau cand pe picior ti se catzara o tarantela, sau un tarantino, sau un tartarin din tartarino, nu mai stiu cum ii spune la paianjenu\' ala femeie.\r\n\r\nEi bine, da. In Swaziland se practica Ceremonia Virginelor, in care 40.000 de fecioare (!?!)Â  defileaza in sanii dezveliti prin fatza unui porcovan de rege pe care-l urasc cu toata puterea fiintei mele de ardelean european!\r\n\r\nDeci asta intrece pana sh legendele despre anii turbati cand in Cisnadie, oras eminamente covoristic, populatia de femei intrecea populatia de barbati cu 8:1. Mai copii! Se zice ca atatea tesatorese lucrau acolo, ca daca mereai chiar si cu masina de la pompe funebre sh claxonai, ieseau la geamurile caminului cel putin vreo 16 priviri curioase! Sh nu trebia decat sa zici \"hai la o cafea!\", ca tot se gaseau vreo trei cel putin care sa accepte!!! Asta chiar daca erai la fel de urat ca je!\r\n\r\nE mai mult chiar sh decat orgiile acelea romane, in care nu se prea tinea seama de ce fel de orificiu folosesti pentru a-ti satisface pohtele murdare; sau chiar sh perioada aia a reproducerii serpilor, atunci cand se fac toti ghem sh nu se stie care pe care, sh se iubesc asa zile in shir!!! Pfuaaaaay...\r\n\r\nE chiar mai meseriash decat liceul sh facultatea mea (incredibil, sunt apsolvent de amandoo!), cand am fost 4 baieti sh 27 fete, respectiv 5 masculi sh vreo 60 de coleje!\r\n\r\nDepaseste cu mult vizitele la Apaca ale lui nea Nelu sh Pietrie Roman (Pepe, jur ca nu de tine e vorba!), cand muncitoarele ieseau la pupat lidÄƒri, agitand pancarte cu \"Nu vrem bani, nu vrem valutÄƒ, Vrem ca Roman sa ne futÄƒ!\"\r\n\r\nEste chiar mai meseriash decat Love Parade. Este mai tare decat sa mergi in Obsession la deschidere, sh sa te cocoshezi de la atata holbat prin decoltee.\r\n\r\nEste mai tare ca orice alta chestiede pe lumea asta!!!\r\n\r\nSh ca sa fie sh mai multa sare pe rana, mai aflatz una: regele din Swaziland are 13 (!) neveste, mah. 13!\r\n\r\nSTIE CAREVA CAND SE FAC ANGAJARI PE POST DE REGE IN SWAZILAND??? ALO! NU STITI CEVA FIRMA DE RECRUTARI REGALE? DAU COMISION GRAS, IN VIRGINE!!!','Omul pe care il urasc cel mai mult sh mai mult pe lumea asta',0,'','publish','open','open','','omul-pe-care-il-urasc-cel-mai-mult-sh-mai-mult-pe-lumea-asta','','','2007-08-30 15:29:24','2007-08-30 13:29:24','',0,'http://www.groparu.ro/?p=622',0,'post','',10),(623,1,'2007-08-31 10:57:06','2007-08-31 08:57:06','<p class=\"MsoNormal\"><span lang=\"FR\"><strong>greuceanu_original</strong>: GropaÂ !\r\n<strong>Groparu</strong>: unie imbli mah!!!\r\n<strong>greuceanu_original</strong>: unie unmblu?!\r\n<strong>Groparu</strong>: e!\r\n<strong>Groparu</strong>: ma gandeam la tine asar\'\r\n<strong>Groparu</strong>: sh tu - pula!\r\n<strong>Groparu</strong>: nu te-ai gandit la minie\r\n<strong>greuceanu_original</strong>: da!\r\n<strong>greuceanu_original</strong>: io pula!\r\n<strong>greuceanu_original</strong>: vi sa ne-mbatam?!\r\n<strong>greuceanu_original</strong>: la motij?!</span>\r\n<em><span lang=\"FR\">NN: Moti</span></em><em><span lang=\"RO\">ÅŸ</span></em><em><span lang=\"FR\"> = sat s</span></em><em><span lang=\"RO\">Äƒsesc pe Valea Viilor, unde noi chefuim fix Ã®n casa fostului popÄƒ!</span></em>\r\n<span lang=\"IT\"><strong>Groparu</strong>: am nunta maine\r\n<strong>Groparu</strong>: sh dumineca e ziua GropariÅ£ei\r\n<strong>greuceanu_original</strong>: kief!\r\n<strong>greuceanu_original</strong>: mo\r\n<strong>greuceanu_original</strong>: am veste tare!\r\n<strong>Groparu</strong>: z\r\n<strong>Groparu</strong>: ej tatic?\r\n<strong>greuceanu_original</strong>: ieap!\r\n<strong>Groparu</strong>: deci tu ej tata lu medeea?\r\n<em>NN: Medeea = GreucenicuÅ£a</em></span><em><span lang=\"RO\">, fiica lu Greuceanu sh a Greuceanei</span></em>\r\n<span lang=\"PT-BR\"><strong>Groparu</strong>: ma\r\n<strong>Groparu</strong>: ba pula\r\n<strong>Groparu</strong>: nu-tz bate joc de o inimÄƒ curatÄƒ!\r\n<strong>Groparu</strong>: esti???\r\n<strong>greuceanu_original</strong>: iz!\r\n<strong>Groparu</strong>: piiiizdaaaaaaa maaatiiiiiiiiiiiiiiiiii!!!!!!!!!!!!!!!\r\n<strong>Groparu</strong>: da\' cati faci, mah pula???\r\n<strong>Groparu</strong>: DOAMNE BINECUVANTEAZA PUTULICA TA! pardon my French<strong>\r\ngreuceanu_original</strong>: da mo! sh mai sus de toate io am fo\' la pejti in perioada aia! ala da barbat!\r\n<strong>greuceanu_original</strong>: avem!\r\n<strong>greuceanu_original</strong>: ce pola.... deja e evident\r\n<strong>Groparu</strong>: hai ghe pulicica me, mah\r\n<strong>Groparu</strong>: m-ai terminat!!!!\r\n<strong>Groparu</strong>: mah\r\n<strong>Groparu</strong>: ce sa iti zic?\r\n<strong>Groparu</strong>: FELICITARI!!!\r\n<strong>greuceanu_original</strong>: ieap!\r\n<strong>greuceanu_original</strong>: thx!\r\n<strong>Groparu</strong>: sh meri sa sarbatpresti cu un kefan la motij?\r\n<strong>greuceanu_original</strong>: tz clar\r\n<strong>greuceanu_original</strong>: tÄƒtÄƒ vieaÅ£a un kevan!\r\n<strong>greuceanu_original</strong>: tz-am zis sa ne-nsuram amandoi.... n-ai vrut!\r\n<strong>Groparu</strong>: nu erea legal, tu ej nebun?\r\n<strong>greuceanu_original</strong>: ei mo! popika al meu... pt o suma bunaaa...... </span><span lang=\"IT\">o facea....</span>\r\n<em><span lang=\"IT\">NN: popika = prekin greucenesc din facultate care g</span></em><em><span lang=\"RO\">Äƒ</span></em><em><span lang=\"IT\">sise un buletin ÅŸi o falimentat Holywood Music and Film luand casete pe buletinu ala, pe care le vindea in T</span></em><em><span lang=\"RO\">Ã¢</span></em><em><span lang=\"IT\">rg.</span></em>\r\n<span lang=\"IT\"><strong>Groparu</strong>: mah pula\r\n<strong>Groparu</strong>: deci m-ai pisat in pantalon\r\n<strong>Groparu</strong>: cu asta\r\n<strong>Groparu</strong>: cu taticia!\r\n<strong>Groparu</strong>: sa stii\r\n<strong>Groparu</strong>: esti meseriash<strong>\r\nGroparu</strong>: zaraza sh groparu respecta greuceanu!!!!</span>\r\n<strong>Groparu</strong>: 4 ever\r\n<strong>greuceanu_original</strong>: mo\r\n<strong>greuceanu_original</strong>: that\'s God\'s will\r\n<strong>Groparu</strong>: and Greuceanuâ€™s dickâ€™s!\r\n<strong>Groparu</strong>: tzuca-l mama\r\n<span lang=\"FR\"><strong>greuceanu_original</strong>: \"mi-o scapat un pic!\"\r\n<strong>Groparu</strong>: \"sh era fix jetu cu campionu\'!!!\"\r\n<strong>greuceanu_original</strong>: ieah mo......\r\n<strong>greuceanu_original</strong>: \"asta sh-o scot, jur!\"\r\n<strong>Groparu</strong>: mah pula\r\n<strong>Groparu</strong>: esti adevarat\r\n<strong>Groparu</strong>: sh felicita-l sh pe: Nelu, Cipi, Huby\r\n<strong>Groparu</strong>: pe mine nu\r\n<strong>Groparu</strong>: io am facut-o din prietenie\r\n<strong>greuceanu_original</strong>: ce-ai facut mo din pretenie?\r\n<strong>Groparu</strong>: pai copilu tau!!! dobi<strong>\r\nGroparu</strong>: vezi ca poate sh lu var-mio trebe sa-i dai telefon\r\n<strong>Groparu</strong>: sa stie\r\n<strong>Groparu</strong>: ca o reusit proiectuâ€™\r\n<strong>Groparu</strong>: (is bancuri naspa astea?)\r\n<strong>Greuceanu_original</strong>: is bancuri?!\r\n<strong>Groparu</strong>: futa-te pula aia care scoase asa Medee faina mah!\r\n<strong>greuceanu_original</strong>:<span>Â  </span>ma bucur mo ca\'tz place!\r\n<strong>greuceanu_original</strong>: asta trebe sa fie baiat\r\n<strong>greuceanu_original</strong>: la cat am beut sh-am pipat.... numa baiat poate fi!\r\n<strong>Groparu</strong>: http://adriangeorgescu.ro/2007/08/30/razboiul-masinilor/#more-277\r\n<strong>greuceanu_original</strong>: l-am citit de la varf de sajeata\r\n<strong>Groparu</strong>: okapa\r\n<strong>Groparu</strong>: de la mine are linku porcovanu!\r\n</span><em><span lang=\"FR\">NNÂ : nu era adevarat, da ma dadeam <strong>grande</strong></span></em><span lang=\"FR\">.\r\n<strong>Groparu</strong>: (sau nu)\r\n<strong>Groparu</strong>: mo, sh daca e tot fata? n-ar fi asta super tare, frate?</span>\r\n\r\n<p class=\"MsoNormal\"><span lang=\"FR\"><strong>Greuceanu_original</strong>: mo.... </span><span lang=\"IT\">imi zice medeea...:\"ai vb cu Doamne doamne sa-mi aduka un bb?!\"\r\n\"da, da\' tu ce vrei?fetita sau baietel\"?\r\n\"baietel\"\r\nsi daca nu mai are?\r\nsi fetita e buna, da\' sa fie mov!<o:p></o:p></span>\r\n\r\n<p class=\"MsoNormal\"><span lang=\"IT\"><strong>Groparu</strong>: DUUU-TEE MAHHHH!!!\r\n<strong>Groparu</strong>: =)) =)) =))\r\n<strong>Groparu</strong>: CEEE TAAAREEEE!!!!!\r\n<strong>Groparu</strong>: Medeea ruleaza\r\n<strong>Groparu</strong>: s-ar putea totusi sa nu ma mai insor cu ea\r\n<strong>greuceanu_original</strong>: te caci pe tine!\r\n<strong>Groparu</strong>: sa n-o nenorocesc, sireaca\r\n<strong>Groparu</strong>: da\' daca faci amu tot o fetitza...\r\n<strong>Groparu</strong>: ce zici?\r\n<strong>Groparu</strong>: pe asta i-o faci lu groparu?\r\n<strong>Groparu</strong>: ai ma\r\n<strong>greuceanu_original</strong>: stranje bani, ca daca-i asha cu ce ai tu acuma....in 4 luni te falimenteaza sh te lasa!\r\n<strong>Groparu</strong>: :))\r\n<strong>Groparu</strong>: nu-i stress, ca iau de la tine imprumut\r\n<strong>greuceanu_original</strong>: o iei pe mama imprumut\r\n<strong>Groparu</strong>: HMMM\r\n<strong>Groparu</strong>: nu ca sh aia keltuie\r\n</span><strong>Groparu</strong>: GREUCEAANUUU!!!!!!!!\r\n<strong>Groparu</strong>: U HAVE DONE IT!!!!\r\n<span lang=\"PT-BR\"><strong>Groparu</strong>: AGAIN!!!\r\n<strong>Groparu</strong>: (ooops!)\r\n<strong>greuceanu_original</strong>: ce mo!\r\n<strong>greuceanu_original</strong>: ce tat vrei?!\r\n<strong>Groparu</strong>: mah, incep sa ma invatz cu ideea\r\n<strong>Groparu</strong>: ca nu mai ej al meu\r\n<strong>greuceanu_original</strong>: da mo amu tu ejti al meu\r\n<strong>greuceanu_original</strong>: dar dupe ce crejte copiii, iara-s al tau</span>\r\n<strong>Groparu</strong>: :))<o:p></o:p>','Despre',0,'','publish','open','open','','despre','','','2007-08-31 10:57:06','2007-08-31 08:57:06','',0,'http://www.groparu.ro/?p=623',0,'post','',8),(624,1,'2007-08-31 15:59:47','2007-08-31 13:59:47','Da, se marita verisoara mea scumpa, pe care nu am mai vazut-o dee... ÄƒÄƒÄƒ... de... bon, am vazut-o la nunta lu var-mio, amu 2 ani, si inainte de asta nu am mai vazut-o literalmente de un secol! Ca in mileniu asta ioc.\r\n\r\nO sa fie o nunta cu multa muzica populara, neveste batute, certuri sh alte shele, dihonii intre neamuri, manele, sibieni jmekeri capitali cortorari europeni! Sh cel mai important - o sa ma apuc iar de fumat sh de beut, finca maine expira paoza. Sau poate nu ma apuc. Sau mai vedem.\r\n\r\nCert e ca voi sta cu var-mio la masa, var-mio care cel mai scump personaj din universul\r\nasta care se tot extinde de la Big Gang Bang incoace, asa, si vom barfi sh vom rÃ¢de de neamurile noastre, care is atata de najpa, ca io cu el aproape ca suntem cele mai putin nereusite exemplare!\r\n\r\nSi stiti din ce cauza? Pen\' ca, din tot neamu, mama (care de fapt e-o doamna)Â  sh ma-sa  OR FOST SINGURELE CARE NU SI-OR LOAT CONSORT SIBIAN, desi ele e sibience! Sh cica din amestecaturi de astea de gene ies maidanezi frumosi, curati, sanatosi sh uscati, de le sh da IQ-ul afara din cap, ca mie imi tot da, sh de fiecare daca cand imi da il curatz din urechi, sh e asa, galbin!\r\n\r\nDeci: La Multi Ani, Ramonica!','Nunta din weekendu\' asta',0,'','publish','open','open','','nunta-din-weekendu-asta','','','2007-08-31 15:59:47','2007-08-31 13:59:47','',0,'http://www.groparu.ro/?p=624',0,'post','',9),(625,1,'2007-09-03 11:13:18','2007-09-03 09:13:18','Nu nunta verii, ca de fapt e nunta verisoarei.\r\n\r\nDeci sa stiti ca toti ominii care iau Gropar la ocazie sunt cei mai:\r\n\r\n- destepti\r\n- becali\r\n- sireti\r\n- soferi.\r\n\r\nDeci io cand discut cu tot felu de soferi ma simt asa cum ma simt io de regula cand ma cearta sefu\' si incearca sa ma impuste prin birou: umil sh prostanac. Da\' ce mi-o zis dambovitzanu\' care m-o loat la ocazie vineri merita scris:\r\n\r\n\"Bueeey, fii atent la mine-aci! Ca asa o stiu de la tataia meu, care tataia e vecinu\' sh, posibil, insusi tata meu.\r\n\r\nCand iti iai nevasta, ii dai pace vreo luna, doo. P-orma vii acasa aptziguit, sh ii cauti in cuarne! Asha. Ea - fiind femeie - nu va putea rezista, sh va comenta la greu. In secunda aia ii administrezi o mamaie de bataie d-aiaÂ  sora cu muartea.Â  P-orma - normal - adormi.  Daca te scoli dimineatza sh nevasta s-o carat la ma-sa, atunci faci o cruce mare, sh zici DOAMNEEEE!!!! Multumescu-ti tie ca am scapat de lelea asta! Sh daca nevasta nu ti-o fugit de-acasa, ii ceri frumos iertare, sh cate zile mai ai tu pe planeta nu o mai atingi nici cu-o floare, veninoasa sau nu!\"\r\n\r\nLa nunta, am mers la mire sh i-am zis asta. Nu o ras.\r\n\r\nP-orma am mers la mireasa, si i-am zis \"tu verisoara! arata-mi neamurile lui, ca sa ne radem de ei, ca aia is najpa si noi suntem mai meseriashi ca ei!\" Nici ea n-o ras.\r\n\r\nP-orma or vint toate neamurile mele, sa ma pijte de obraji, sa zica ca ce mare m-am facut, ca cand mai merg sa le vizitez, ca au mare nevoie de bani, sh ca cand ma insor odata? Muie, le-am zis.\r\n\r\nA, da\' n-o venit un unchi la nunta, ca ii suparat pe tot neamu\', sh nici o matusha, care ii cam decibelÄƒ era, asa, de felu\' ei. Si bine-nteles - nu or vint nici neamurile care deja or cam dat coltzu\', finca si-or dat seama ca decat sa mai stea in asa familie, mai bine moartea!\r\n\r\nGata. Maine am sa va zic ce am patit cu studentele care stau sub mine, sh le place!','Nunta verii',0,'','publish','open','open','','nunta-verii','','','2007-09-03 11:13:18','2007-09-03 09:13:18','',0,'http://www.groparu.ro/?p=625',0,'post','',5),(626,1,'2007-09-03 21:21:24','2007-09-03 19:21:24','Postare inspirata de Mumuland, care comenteaza la mine pe blog la postarea anterioara, sa-i fie de bine, sa fie primit sh sa mai pofteste:\r\n\r\nCica in Danemarca exista o asociatiune a femelelor halterofile, karateka, imblanzitoare de rinoceri, asasine de taipani sh wrestleritze cu meduze veninoase.\r\n\r\nDeci daca onor subecta Margrethe Rasmuessen o ia in dinti de la subectul S<span style=\"font-size: 12pt\">Ã˜</span>ren Mikkelsen, onor Margrethe Rasmuessen suna la asociatie. Femelele halterofile sh karateka se infiinteaza la casa Margrethei, se mascheaza sh intra frumos inauntru, unde il prind pe dl. S<span style=\"font-size: 12pt\">Ã˜</span>ren Mikkelsen in mijlocul a tot felu\' de ocupatii masculine rusinoase, gen reparat motoreta, navigat pe Internet in kimnitza pe saituri porno gen groparu.ro sau pur si simplu dopÃ¢ndu-se cu o berula, in timp ce echipa locala FC Odense se arde (fara blat) cu echipa rivala Arsenal Aarhus. Tantile intra inauntru de-a valma, lock on target sh fara prevenire incep sa-i care nefericitului prost-inspirat tot felu de coate, genunchi, bote de baseball sh cordoane de la sutien (care de regula is lanturi de priponit taurii din Pamplona). Pentru ca sunt tanti d-astea anti-globalizare sh pentru drepturile minoritatilor, nu fac deloc rabat, discount sau discriminare la numarul de lovituri aplicate sau la intensitatea lor. Si nici nu pleaca de acolo pana cand dl. Mikkelsen nu musca covorul cu gingiile sh isi studiaza uimit dantura risipita pe podea de la acelasi nivel - ca niste mici zaruri de os.\r\n\r\nIn alta ordine de idei: sorella mia (care de fapt e fata unei doamne) avea o colega care o cam loa in mandibula de la onor sotul domniei sale, genul de alcoolic care vedea o amenintare in orice nu seamana a sticla sau pahar plin cu chestii de la 40 grade in sus - mai ales daca acel ceva e o gura mare de femeiushca ce gaseste o voluptate diabolica sa ii arunce in fatza epitete gen \"betiv ordinar\", urari de bine gen \"voma-ti-ai diareile pe lueta!\" sau chiar comparatii gen \"iar esti bat ca un porc!\" Sh nenea, fiind sh el darnic din fire, nu precupetea nici un efort in a-i astupa mashinaria de comentat; si desi se stie ca pumnul nu incape intr-o gura, el se kinuia sa isi infunde monturile la tanti intre molari.\r\n\r\nAsta pana intr-o zi.\r\n\r\nCa cand o vint nenea acasa rrupt de bat (bat de incerca sa descuie broasca de la usa cu nasul sh cu limba de la pantof), tanti l-a tarat in patuc cum a putut ea mai bine (ca avea antrenament), a loat o curea d-aia sdravana, l-a legat de toate membrele alea cele mai lungi de patuc.\r\n\r\nSi a inceput distractia.\r\n\r\nNici pana in ziua de azi nu se stie cu ce instrumente de tortura i-a probat rezistenta pielii sale de betiv; nici cate ore i-au trebuit ca sa isi duca la indeplinire marsava ei activitate impotriva unui om lipsit de aparare; cert e ca stiu patru chineji veniti special in delegatie de la Shenzen ca sa ia notite de la tanti, ca or zis ca tortura aia kinezeasca cu cusca de sobolani flamanzi legati de curu\' detinutului, si care sobolani rontaie din anusul nefericitului, pe viu, in sus pe intestinu gros, ii practic la fel de inofensiva ca o curÄƒ de apa minerale la Olanesti in comparatie cu mintea diabolica de femeie pornita pe <em>vendetta</em>.\r\n\r\nAsa.\r\n\r\nSi dupa bataitza asta, tanti o bagat tot ea divortz, pe motiv de violentza in familie.\r\n\r\nViatza e nedreapta.','Apropos de violenta in familie',0,'','publish','open','open','','apropos-de-violenta-in-familie','','','2007-09-03 21:26:13','2007-09-03 19:26:13','',0,'http://www.groparu.ro/?p=626',0,'post','',8),(627,1,'2007-09-04 13:37:24','2007-09-04 11:37:24','Ce pateste un sconcs care isi face o operatie ca sa devina viezure?\r\n\r\nSe de-sconcs-pireaza.','O intrebare pe an',0,'','publish','open','open','','o-intrebare-pe-an','','','2007-09-04 13:37:24','2007-09-04 11:37:24','',0,'http://www.groparu.ro/?p=627',0,'post','',2),(628,1,'2007-09-06 19:40:03','2007-09-06 17:40:03','Decat sa iti tai o pereche de vene de-a lungul, nu mai bine tai o maioneza?','O alta intrebare pe an',0,'','publish','open','open','','o-alta-intrebare-pe-an','','','2007-09-06 19:40:03','2007-09-06 17:40:03','',0,'http://www.groparu.ro/?p=628',0,'post','',5),(629,1,'2007-09-04 18:12:51','2007-09-04 16:12:51','Pe ProTV, un dobitoc de cetatean roman d-al nostru,  fuge de salariile de 1500 lei din constructii, salarii disponibile in Romania, sh isi da foc in Spania pentru ca nu o gasit loc de munca sh pe castellonezi ii cam doare la pedala. Clar, espanioli oripilati, nevasta-sa urland, nepot minor traumatizat pe viatza.\r\n\r\nPe Antena, o dobitoaca de mamica isi ascunde pruncu\' intr-o punga sh il lasa sa moara.\r\n\r\nSh atunci ma intreb io, asa: nu era mai simplu daca dobitoaca de mamica il nastea si-l omora pe dobitocu\' de cetanean roman de-al nostru, ca sa nu-si mai dea foc ca prostu\'?','Pentru ca tocmai m-am uitat la stiri',0,'','publish','open','open','','pentru-ca-tocmai-m-am-uitat-la-stiri','','','2007-09-04 18:15:31','2007-09-04 16:15:31','',0,'http://www.groparu.ro/?p=629',0,'post','',13),(630,1,'2007-09-05 10:58:12','2007-09-05 08:58:12','Deci, io am doo studente supt mine tot timpul, sh ele e OK cu asta, ca is surori.\r\n\r\nAdeca locuiesc supt mine.\r\n\r\nSh cu una din ele am facut o gafa cum numai EU (da, numai eu) pot face.\r\n\r\n(pregatiti batistele)\r\n\r\nMa-sa uneia dintre ele are un pic de cancer. O vint la Cluj sa se trateze, sh sta la ele acasa. Una dintre studente e plecata in State sa castige bani pentru familia ei. Sh cum io am Internet acasa, sorura ramasa vine cu ma-sa sa vorbeasca cu sor-sa pe net, ca ele nu au net acasa. Sh vine cu maica-sa, ca sa o asigure pe sorella plecata la amerloci ca totul e OK.\r\n\r\nMa-sa - o femeie de treaba, de alfel - o inceput sa imi zica cum or tratat-o, ce i-or dat, sh io in timpu\' asta io o tot incurajam, ca is asa, fire mai optimista, sh cand vad oameni ca se vaita nu prea ii las in pace, ca pana nu ii vad ca rÃ¢d nu ma potolesc.\r\n\r\nDupa vreo doo zile, ma intalnesc cu sorura ramasa pe scari, ca urcam amandoi. Sh ne apuca sa discutam - normal! - despre vreme.\r\n\r\n- Se raceste, zice ea!\r\n- Da! zic io. Super, asa ma bucur...\r\n- Ba nu, zice ea, ca era mai bine cand era mai caldutz.\r\n- Ba da, zic io, io is nascut iarna, zic io (is Scorpion d-ala najpa sh irezistibil).\r\n- Si ce legatura are asta? zice ea.\r\n- Mie-mi place cand e frig afara, frig d-ala, CANCER sa fie!\r\n\r\nMnoa. M-am scos rapid cu alte faze d-ale mele, da cand am ajuns acasa, prima mea reactie o fost sa ma impusc. Dar nush daca sa ma impusc io sau sa va las pe voi sa ma impujcati, gura sparta de spurcata ce is!','Ma impuscati voi, sau ma impusc io?',0,'','publish','open','open','','ma-impuscati-voi-sau-ma-impusc-io','','','2007-09-05 10:58:12','2007-09-05 08:58:12','',0,'http://www.groparu.ro/?p=630',0,'post','',21),(631,1,'2007-09-06 13:28:16','2007-09-06 11:28:16','Ieri dimineata, cum fac eu de regula, eu fac dush, ca asa fac eu de regula dimineata. Spre deosebire de <em>ceilalti</em>, eu FAC dush dimineata. De regula.\r\nSi finca era o zi ca oricare alta, ce mi-am zis io? Hai, ba, sa facem ceva deosebit, sa spalam sh picioarele astea de apostol la care cade domnisoarele cand ma vede pe strada, pedaland furios si ascultand muzikie la telefonu meu cu <em>empetrei</em> (care, dupa cum se stie, e mai destept ca mine), ca atunci cand mai vine Marii Magdalene si mi le spala cu pletele lor, sa miroasa a mosc! Sau macar a bou moscat.\r\n\r\nSi insfac intr-o manutza sapunul meu cu glicerina, PH neutral si extract de Aloe Veronica, sapunesc cu voioshie scoartzele calcaielor mele, sh ma ridic in doua picioare.\r\n\r\nAlunec.\r\n\r\nSi incep sa rad ca prostu\', in cadere. Bou ej, Gropare! Imi zic.\r\n\r\nCaderea mea sublima fu intrerupta de o bufnitura, si o pereche de perdele se trase peste ochii mei care erau caprui intr-o vreme. Am dat cu instalatia de gandire in marginea cÄƒzii asa de tare, ca am crezut ca ies timpanele din cap ca gloanÅ£ele.\r\n\r\nMa adun cu greu de pe jos, nestiind pe care sfinti sa ii injur de prima data, asa ca injur de Sfantul Sapun, Fericita Apa Calda sh Cuviosul Calcai Alunecacios, proaspÄƒt hirotonisiÅ£i Ã®n subect de afurisenie.\r\n\r\nTermin dushu, ma duc cu capu vÃ¢jÃ¢ind in camera, unde termin toaleta, ma imbrac, iau Å£oacla sh fuga-fuguÅ£a catre serviciu. Incerc sa vad mai bine drumul printre celulele sh bastonasele care dansau Cha-cha-cha in faÅ£a privirii mele sticloase.\r\n\r\nDupa vreo 5 ore de vÃ¢jÃ¢ialÄƒ, ca nu il mai auzeam pe Vali Sterian Ã®n cÄƒÅŸti, ma iau ÅŸi ma duc la spital. Io, acolo, la spital, ÅŸtiam cÄƒ is tot felu de tinerele care te pune sa te dezbraci cu ele! Dar nu a fost cazul meu.\r\n\r\nMi se pune de urgenÅ£Äƒ o zgardÄƒ din aia sa-mi Å£inÄƒ ceafa ÅŸi cervicalitatea mea dreaptÄƒ, ÅŸi mÄƒ reped sa Ã®mi fac pozÄƒ sÄƒ o pun pe blog. Nenea doftoru\' sau tanti doftora (avea un sex incert) imi zice ca daca vreau imi baga si o sonda pe gat in jos, ca sa arat mai rupt din realitate. Ii zic ca atata vreme cat e o sonda BUCALA sunt de acord.\r\n\r\nO/Il intreb daca sa ne dezbracam impreuna pentru examinare, si sunt refuzat si amenintat cu sonda, da\' nu de aia petroliera si nici BUCALA, si ma potolesc uimitor de repede.\r\n\r\nMa trimete la raze XXX, sa vaza daca o mai ramas ceva intreg in gulashu\' ala al meu din cap, sau o prins mucegai si a expirat. Nici la raze XXX nu sunt lasat sa ma dezbrac.\r\n\r\nRevin la urgente, si sunt lasat sa astept pe un scaun d-ala de paralitic paraplegic cu roate. Ma mai intreaba doo cadre medicale feminine daca m-o vazut vrun doftor, si le zic ca daca sunt de acord sa ne dezbracam impreuna, atunci nu, nu m-o vazut nimeni! A doua ma ameninta ca imi baga, da\' nu o sonda, ci un stetoscop. Si ea ma potoleste.\r\n\r\nIntr-un final vin analizele: da, ba, n-ai nici pe dreq, meri acas\' odata, ia medicamentele astea de 16 milioane, si daca ti-e rau dupa eel, nu e vina noastra! Elibereaza gazonu\', ca vin neshte victime feminine de accident de circulatie. Pot sa ma dezbrac cu ele, intreb in timp ce doi brancardieri cat un SMURD ma insfaca si ma arunca pe pavaj, asa cum ma arunca pe mine de regula chelnerii cand vor sa inchida sandramaua si io mai vreu s amai stau si sa mai beau.\r\n\r\nSi stiti ce mi-i cel mai ciuda? Ca nici macar nu am cazut din cauza ca eram bat sau mahmur.\r\n\r\nPS: Per total is OK, o disparut una din vocile din capu\' meu, da\' a aparut alta. Oricum, cand o auzit ca am dat cu capu\' de cadÄƒ, Pavarotti o murit!!!!','Groparu e cam batut in cap',0,'','publish','open','open','','groparu-e-cam-batut-in-cap','','','2007-09-06 13:46:10','2007-09-06 11:46:10','',0,'http://www.groparu.ro/?p=631',0,'post','',20),(632,1,'2007-09-06 21:58:59','2007-09-06 19:58:59','Pe saitu\' <a href=\"http://www.ciutacu.ro/articol-352.html\" target=\"_blank\">Ciutacelui</a> am cetit o panica a jos-numitei Mana referitor la ce situatii ridicole i-ar putea prinde pe Ciutaci cu pantalonii pe vene la nunta jos-numitului <a href=\"http://www.andreicrivat.ro\" target=\"_blank\">Crivat, Andrei Crivat</a>,  avand in vedere ca in patria mea cu munti si vÄƒi datinile difera de la sud la nord ca si cÃ¢nd.\r\n\r\nPentru non-connoisseuri: Ciutacii vor fi nasi la nunta micului <a href=\"http://www.andreicrivat.ro\">Uragan de Braila</a>.\r\n\r\nIo stiu ca de exemplu, in Germania, in landu\' lu\' sor-mea (inca nu e al ei, ca inca nu l-am cotropit de tot), cand un june ajunge la frumoasa varsta de 30 de anisori si nu s-o prostit suficient incat sa aleaga sa se trezeasca langa aceeasi femeie PENTRU TOT RESTUL VIETII SALE, in fata primariei se varsa o bascula sau roaba sau galeata plina cu nasip, sh el trebe sa o mature <strong>toata</strong>. C-asa-i traditia.\r\n\r\nCica in Maramu\', cand te prinde cam aceeaisi varsta tot umbland dupa fuste de femei (laudabila ocupatie!), moroshenii fac o papusha din paie, ii leaga tzatze de bostan (daca nemaritata e femeie, ii atarna o putzulica de cocean de cucuruz), atarna papushoiu\' de stalpu de telegraf si il/o kiama la poarta ca sa vaza isprava! Sh respectivul/a se ovtica. C-asa-i in tenis.\r\n\r\nTot in Germania, exista o traditie nobila de a face farse mirelui in ziua nuntii: gen batut in scanduri usa si geamurile, gen suit masina nuptiala pe butuci fara roti, si cand mirele vrea sa plece in voiaju\' de nunta numa\' nu se mai misca autovehiculu\', gen legat masina cu lant de poarta si ala tot nu poa\' sa plece, si d-astea eftine, de nemti care se distreaza imbatandu-se ca porcii si leganandu-se pe bancile de la Oktoberfest care - by the way - are loc in septemvrie. Faina tzara! Pacat ca porneste razboaie sh borbandeaza sarbi.\r\n\r\nBooon. Dar in Ardeal, cum a fi? Va zic io.\r\n\r\nNu se pun bani in keptu\' mirelui, cum face oltenii, asa, de fudulie (var-miu Treienush o pierdut trei bancnote de 100 lei prinse in keptul sau de oltean verde <em>pe vremea lu\'</em>, si toti nuntasii or inceput sa caute banetu\'!). De asemenea, mirele nu isi cumpara trening nou, finca isi ia costum. Asta stiu sigur. Se prind neshte floricele langa hertz, daca e cazu\', daca nu, iara bine.\r\n\r\nDa\' sa va asteptati la coarda aia intinsa la iesirea din orice casa prin care veti intra, ca sa faca bariera. Sh vreo bÄƒbÄƒtie sau ceva prunci isi vor cere drepturile - o spaga mica, de vreo 10-20 lei. Vor cere mai mult, da voi fiti zgarciti, ca, asa cum zicea <a href=\"http://andreanum.wordpress.com/?s=ardelean\" target=\"_blank\">andreanum</a>, aici e patria zgarceniei, la care i se zice altcumva, parca, cand esti zgarcit cica esti <em>gospodar</em>.\r\n\r\nS-ar putea fura pantofu\' miresei (asta in cazu in care is ceva prunci la nunta, invatati de parintii lor sa faca un ban cinstit), si se da MAXIM un milion.Vedeti ca daca sunteti Mitici, ardelenii astia hicleni or sa incerce sa va faca de bani (apropos, dati-mi sh mie 4000 euroci imprumut pana maine!!!)\r\n\r\nCand se fura mireasa, mai Ciutace, fii antena. Nu te cÄƒcÄƒi pe tine, ca asa am patit la nunta lu Tibby, care o avut ceva naÅŸ din Olanda (fost ardelean d-al nostru), care mah, ATATA FU DE ZGARCIT, CA NE FU LEHAMITE!!! Intra in gioc, sh matale, sh daca nu faci show, mai bine nu. Tre\' sa faci show, musay de musay! Fa-te oÅ£Ã¢rÄƒ de Seinfeld, fa mijto de tine, de mire (asta chiar meritÄƒ!), nu uita ca ardelenii voteazÄƒ BÄƒsescu indiferent de, dar musay sÄƒ fie show, nush, cautÄƒ pe youtube clipuri cu Pablo Francisco, Southpark sh Beavis and Butt-Head (daca vrei, pot face ca Beavis! Huh-huhhuh) daca vreai inspiratie.\r\n\r\nA, si inca ceva: nu are rost sa iti spun ca NIMIC DIN TRADITIILE CARE EXISTA NU SE MAI APLICA DACÄ‚ LA NUNTA VIN, MÄ‚RE, <a href=\"http://idei-locale.blogspot.com/\" target=\"_blank\">LEGIONARU\'</a>, <a href=\"http://www.jeg.ro\" target=\"_blank\">COMMY CHICKEN aka puiuÅ£u de comunist</a> ÅŸi, mai modest, aÅŸa, Groparele. Deci asteapta-te la ce e mai sublim de <em>evil</em>. Io numa atata zic.','Despre obicee de Ã®nmor... ÄƒÄƒÄƒ, nuntÄƒ',0,'','publish','open','open','','despre-obicee-de-inmor-aaa-nunta','','','2007-09-06 21:58:59','2007-09-06 19:58:59','',0,'http://www.groparu.ro/?p=632',0,'post','',11),(633,1,'2007-09-10 15:15:23','2007-09-10 13:15:23','Deeeeeci:\r\n\r\nCa sa nu mai ramaie repetent si anu\' asta, d-ra T. (care la orele la care scriu de fapt e-o doamna) i-a promis ca il aduce pe dl. <a href=\"http://www.andreicrivat.ro\" target=\"_blank\">Crivat</a> in fata altarului.\r\n\r\nDl. Crivat a acceptat foarte fericit, deoarece stia din surse sigure ca indiferent cate magazine de bijuterii ar mai fi cautat, asa bijuterie de fata nu mai gasea, parol.\r\n\r\nBoooooon!\r\n\r\n\"Am inceput ca doua adieri separate; ulterior, ne-am hotarat sa mergem impreuna pe aripile aceluiasi vant\" - asta era textul pe care l-am fÄƒtat special pentru nunta lor.\r\n\r\nInvitati de oroare:\r\n\r\n- famelia <a href=\"http://www.ciutacu.ro\" target=\"_blank\">Ciutacu</a> - nuni - primul contact cu ei a fost intrebarea \"auzi, cat se pune la voi la nunta in prov... aaa, Ardeal?\", intrebare pusa in timp ce se rontaiau amandoi de supt unghii;\r\n- ilustrul <a href=\"http://www.jeg.ro\" target=\"_blank\">JEG</a>, din motive geometrice disparut din blogosfera, parerea mea e ca vrea sa reapara ca Zamolxis si sa vaza cate femei il insotesc cand va disparea din nou in pestera;\r\n- spectaculosul cuplu <a href=\"http://www.alexis-design.info/\" target=\"_blank\">alexis-design</a> cu <a href=\"http://idei-locale.blogspot.com/\" target=\"_blank\">ideile sale locale</a>, despre margelele carora voi scrie un pic mai jos (sub birou, adica)\r\n- <a href=\"http://www.blogoree.ro/blog/\" target=\"_blank\">Bobby Voicu</a>, fara Pamela;\r\n- Adreian, da\' nu Nastase, ci ala de la <a href=\"http://adrian.filozofie.ro\" target=\"_blank\">Filosofie punct ro</a>, de fapt ar fi trebuit sa fie filosofiesunt.eu.\r\n- Groparu\'. Si personalitatile multiple din dotare.\r\n\r\nCand Groparele i-a atras atentia miresei ca mirele nu are cum bea sampanie din pantofii ei cu gaurele, d-ra T. s-a suparat si si-a uitat buletinul acasa, finca probabil uitase ca trebuie sa se marite cu dl. Crivat, ca sa nu ramaie repetent sh anul acesta.\r\n\r\nCineva (EU) a trebuit sa se fugutzeasca dupa el, si era sa-mi rup de patru ori gÃ¢tzii, plus sa pic peste o gaÅŸcÄƒ de raÅ£e bine mersi, finca uitai sa va zic cÄƒ la Cluj, mai nou, ceremoniile de Ã®nmor... ÄƒÄƒÄƒ, nuntÄƒ se petrece in aer liber, Ã®n parc, lÃ¢ngÄƒ bÄƒltoaca aia de-i zice Chios. De ce era sÄƒ-ÅŸi rupÄƒ Groparu gÃ¢Å£ii, vÄƒ veÅ£i Ã®ntreba? Pentru ca ploua, dar d-ra T., asemeni Anei lui Manole, nu s-a dat batutÄƒ, ci dimpotrivÄƒ, a ignorat ploaia, a incÄƒlecat pe CrivÄƒÅ£ ÅŸi cÃ¢nd a rÄƒcnit odatÄƒ \"DA!!!!\" la intrebarea fatidica, pun pariu ca pÃ¢nÄƒ ÅŸi condorii din Anzi s-au ridicat, sparieÅ£i, in aer.\r\n\r\nLa nunta - clar, toata lumea se smiorcÄƒia in sosete de la ploaie.\r\n\r\nPrima amintire de la nunta propriu zisÄƒ: alexis design si-a rupt o pÄƒreche de margele foarte ieftine, pe care, daca-mi amintesc, le-a lipit intr-un final cu scuipat; a doua amintire: idei locale a papat tot pestele, asa cum sade bine olteanului; a treia amintire: finca stia ca o sa scriu urat de ei, alexis design a incercat sa imi faca ceva cu o lumanare, dar finca in locul acela scria \"exit only\", nu a reusit decat sa ma pÄƒteze pe costumul meu de mers la biserica cu cearÄƒ de lumÃ¢nare.\r\n\r\nPapa (nu asta Bonifaciu) o fost demential, vreau sa zic. Atata numa ca chelnerii or fo atata de amabili ca mi-o dat greaÅ£a. Pe bune.\r\n\r\nLa un momentdat ne-am apucat, io si vecinu de la masa, sa ne uitam fix, cu privire de Hannibal Lecter, la sefu\' de sala; omu o venit si ne-o intrebat de vreo patru ori daca dorim ceva, i-am raspuns, de gheatza, ca nu, pana cand o cedat psihic si s-o tirat din sala.\r\n\r\nS-o furat mireasa. Sh mi-o placut chestia ca rapitorii or cerut numa\' ceva beutura, sh ca nÄƒnaÅŸu ala mai <a href=\"http://www.ciutacu.ro\" target=\"_blank\">ciudac</a> sa Ã®l umple pe mire de friÅŸcÄƒ, adecÄƒ sÄƒ Ã®l facÄƒ ovrei cu friÅŸcÄƒ, cu bucle, plete ÅŸi - sper io - cu puterile paranormale de a produce bani inclusiv din vÃ¢nzare de ingheÅ£atÄƒ ÅŸi evantaie la Poli Norzi.\r\n\r\nCiutacu o fost prea ocupat ca sa discute cu Groparu, ÅŸi in unicul moment cand am fi putut sa complotam cum sa il detronam pe Base\' si sa il punem pe Hagi in locu\' lui, serviciile secrete ne-au zadarnicit intreprinderea, ca il faceam pe Basescu faimos ca Kennedy! (Oh my God! You killed Ken-nedy!!! You bastards!!!)\r\n\r\nEra p-acolo unu in camasa rosie care tot dansa, atata m-o enervat ca am vrut sa il prind in baie sh sa il caftesc, da\' am aflat dupa aia ca e baiat bun, are si sait, si mai ales cand mi-o tras o privire de alcoolic din oglinda m-am muiat tot.\r\n\r\nNu pot sa pun poze cu mirii finca dupa aia apar pe sentimente.ro la sectiunea \"cuplu caut cuplu\", si io prefer sa ii las sa se iubeasca intre ei, c-asa o randuit Dumnezeu lumea, ca femeia sa se uneasca cu barbatul si sa fie amandoi un singur trup, si sa-l asculte, sa nu-l supere, sa-i spele, sa-i gateasca si sa-l iubeasca si sa-l descalte si sa-l urce in pat cand el vine in 4 labe acasa.\r\n\r\nNu stiu ce or facut mirii in noaptea aia, da\' din moment ce nu mi-or dat bip insamna ca s-or descurcat.\r\n\r\nSh, ba Andrei, ai mei parinti (inclusiv maica-mea, care de fapt e-o doamna!) m-or pus sa jur ca va urez si din partea lor Casa de Piatra, si io uite, n-am uitat, c-asa o zis mama, sa nu uiti, Darie, asa mi-o zis cand mi-or pus altii botnitza ca sa nu mai beu!','Uraganul de Braila, deci - nunta',0,'','publish','open','open','','uraganul-de-braila-deci-nunta','','','2007-09-14 18:19:15','2007-09-14 16:19:15','',0,'http://www.groparu.ro/?p=633',0,'post','',8),(634,1,'2007-09-12 10:03:17','2007-09-12 08:03:17','De fapt, nu prea mere cu preafericit, ca oamenii sh femeile, de regula, nu se pot preafericiza decat cu bere, pescuit, colectionat timbre sau jucat counter (daca esti din prima categorie) sau gatit, spalat, curatat (daca esti din a doua). Ori patriarhii nush daca are voie sa se uite la TV cand e meci sh sa rontaie seminte, ca tre\' sa fie ocupati mereu cu rugaciuni plictisitoare.\r\n\r\nDin cate am inteles, patriarhu\' nu se alege ca un papa, cu semne divine - io cred ca se aleg dupa marimea barbii si marimea dosarului de la Secu. Deci marimea conteaza.\r\n\r\nUite aici propunerile Groparului la patriarhat:\r\n\r\n- Fuego - orice popa tre\' sa stie sa cante, dar nu stiu ce sanse are finca e din Turda; daca devine patriarh, Irina Loghin ii poate deveni PR manager\r\n- Axinte de la Vacanta Mare - in linii mari, e cam la fel de antipatic ca orice popa\r\n- Gica Hagi - oricum tre sa ii ridicam statuie fostului patriarh, sh sh lui Gica; asa o sa avem doua statui la pretz de una\r\n- Nikita - asta numai daca se skimba legea si o sÄƒ putem avea popiÅ£e, patriarhiÅ£e ÅŸi patriarhioaie\r\n- Iulian, imparatul rromilor de pretutindeni - ar putea declara Tiganiada sarbatoare nationala\r\n- Chuck Norris - cel mai tare ambasador al lui Dumnezeu dupe lumea asta, si, din cate scrie pe <a href=\"http://www.chucknorrisfacts.com\" target=\"_blank\">http://www.chucknorrisfacts.com</a>, singuru din univers capabil sa il \"convinga\" pe Dumnezeu sa ne plateasca taxa de protectie.\r\n\r\nIs io, mah Mumuland. Cum care eu? Asta: ;)','Propunerile Groparului la preafericire',0,'','publish','open','open','','propunerile-groparului-la-preafericire','','','2007-09-12 10:03:17','2007-09-12 08:03:17','',0,'http://www.groparu.ro/?p=634',0,'post','',6),(637,1,'2007-09-13 18:37:47','2007-09-13 16:37:47','- Pentru ca au maini mici, catifelate, uneori reci, care au nevoie de caldura palmei tale\r\n- Pentru le poti mangaia si cu dosul mainii, cu sprancenele, obrajii si nasul\r\n- Pentru ca dupa ce le mangai, iti ramane mirosul lor pe dosul mainii, sprancene, obraji si nas\r\n- Pentru ca atunci cand le saruti, respiri usor aerul din narile lor, aerul pe care il respira si ele, si aerul are miros placut\r\n- Pentru ca le e frig tot timpul, si cand le e cald nu transpira dizgratios\r\n- Pentru ca le miroase frumos buricul, care e ca un sambure de pepene!\r\n- Pentru ca sfarcurile le sunt colorate intr-o nuanta foarte gustoasa\r\n- Pentru ca dupa ce le saruti, cand sughiti iti revine in gat <em>gustul</em> lor\r\n- Pentru ca iti ofera fruntea sa le-o pupi\r\n- Pentru ca pielea de sub sÃ¢n e cea mai fina suprafata a unei forme de viata pe baza de carbon (suupeeeer fiiinaaaa)\r\n- Pentru ca mananci Orbit cu menta si apai sufli in pumn si mirosi, sa iti aminteshti respiratia Ei cand te pupa dupa ce s-a spalat pe dinti\r\n- Pentru ca le sta bine cu parul ud\r\n- Pentru ca sunt sexy cand incearca sa fie vulgare\r\n- Pentru ca gem usurel in bratele tale cand le guÅŸti pe gÃ¢t\r\n- Pentru ca isi fac o datorie de onoare in a face curatenie in pestera\r\n- Pentru ca se cuibaresc frumos in bratele tale\r\n- Pentru ca se trezesc dimineata inaintea ta\r\n- Pentru ca scancesc ca un catelus cand nu se simt bine\r\n- Pentru ca nu se scurma in nas\r\n- Pentru ca arata DEMENTIAL DE SEXY cand sunt gravide\r\n- Pentru ca si cand injura, o fac fara vulgaritate\r\n- Pentru ca atunci cand plang esti in stare sa faci orice pentru ele\r\n- Pentru ca umbla super sexos pe tocuri\r\n- Pentru ca isi tin mainile in poala cand stau pe scaun\r\n- Pentru ca canta foarte haios la karaoke\r\n- Pentru ca nu prea iau amenzi de la Garcea\r\n- Pentru ca atunci cand le strangi in brate, iti dai seama ca is <em>numa\' otzara\r\n</em>- Pentru ca atunci cand le mangai cu buzele pe spate, niste perisori foarte fini iti zgarie gingas buzele\r\n- Pentru ca nu te lasa sa le platesti nimic\r\n- Pentru ca sunt in stare sa piarda ore in sir pe zi mangaindu-se cu creme\r\n- Pentru ca uneori iti fac sanvisuri dimineata, cu continut metodic aranjat\r\n- Pentru ca si dupa o noapte intreaga de iubit, tot arata numa\' bune de pus pe coperta de revista\r\n- Pentru ca am putea sta ore in sir numai uitandu-ne la ele cum fac dush, fara ca ele sa stie\r\n- Pentru ca uneori primul sarut ti-l dau cu dintii stransi, parca de frica\r\n- Pentru ca au un ritual in a-si aranja parul cand pun capul pe perna\r\n- Pentru ca nu am vazut in viata mea o femeie bÃ¢lbÃ¢itÄƒ\r\n- Pentru ca simt ca mai am o multime de scris despre ele, si de aceea sectiunea asta <em>va urma</em>\r\n\r\nPS: Stiu ca nu l-am ofticat pe Cartarescu, da\' e OK, mai e vreme.','De ce iubim femeile (eat this, Cartarescu!)',0,'','publish','open','open','','de-ce-iubim-femeile-eat-this-cartarescu','','','2007-09-13 18:55:28','2007-09-13 16:55:28','',0,'http://www.groparu.ro/?p=637',0,'post','',42),(635,1,'2007-09-11 17:22:48','2007-09-11 15:22:48','Deci sa ma scuteasca astia cu iaurtu ala care avea dioxina, fina asa ceva nu era posibil: CE VINDE DANONE NU E IAURT!\r\n\r\nDar nu despre asta vreau sa va vorbesc, finca vreau sa va vorbesc despre nunta sor-mii.\r\n\r\nSor-mea - asa cum shade bine unei viitoare ambasadoare a viitoarei enclave romanesti care se va intinde in tot UE-ul - s-o maritat, da\' asta fu amu vreo 10 ani, parca. Ca ea isi alese un neamtz care numa neamtz nu ii, ca ii numa dupe acte, sh e la fel de habauc ca restu\' natiei mele de arieni est-europeni, finca e un fel de haiduc de prin anii \'80.\r\n\r\nMnoa. Nunta avu loc intr-un fel de local meseriash pe vremea aia din Sighii, Transilvania ii zicea, care amu e un fel de darapanatura, finca romanu\' e foarte multe chestii, numa\' bun manager nu ie. Uitati-va la tara mea si dati-mi dreptate.\r\n\r\n(moment in care mi se da dreptate)\r\n\r\nMnoa, sh finca TAT NEAMU\' GROPARESC urma sa vie sa vazÄƒ p-ala suficient de iresponsabil incat sa iÅŸi ieie o pacoste ca sor-mea pe cap, sor-mea zice; bueeeey, io nu-mi ieu fotograf, finca io iz jmekera; asa ca ieu din Jermanica 6 (sase) filme (filme) Kodak, le insurubam pe rand in camera aia jmekera Olympus Made in China, ca se stie ca chinejii fac chestii de calitate, sh tu, fratello (fratello fiind io) ai sa-mi traji neshte poze de toata frumusetea! D-alea care am sa le fac tapet in dormitor, sa ma uit la mine ce frumoasa si ce mireasa is sh sa-mi placa.\r\n\r\nSh amu ma apuc io sa fac poze la toata lumea posibila si imposibila de la nunta, toate rubedeniile oltenesti, toti unchii din Ardeal care nu stau bine cu dantura, insistand asupra unor detalii nesemnificative cum ar fi negii de pe nasuri, parul din negi, parul din nas, coÅŸurile verisoarelor mele mai pubere, decolteele deprimate ale vecinelor mele de 80 de anishori, carii, dinti de aur, pistruii de pe umeri, cosurile alea purulente de pe spate, gingiile sangerande, oamenii care se scobeau cu scobitoarea intre fildeÅŸi, unghiile cornoase ne-ojate care ieseau curioase dintre sandale verzi... aaa, stai un pic, ca era martie, nu se inventasera inca sandalele verzi. Deci toate amanuntele Picassoiene, Baudelairiene si Balzaciene de care nunta abunda! Ca toti avem neamuri najpa, incepand cu fiica presedintelui. Nu zic care presedinte de care partid conservator.\r\n\r\nAsaaaa. Totul a fost super OK si eu ma amuzam asa, in perfectiunea mea Adonisiaca sau Afrodisiaca, nu mai stiu, pana cand am consumat trei filme din 6. Si am scos al treilea film facut, l-am pus langa celelalte 2 facute, si am plecat nush ce sa fac.\r\n\r\nSi cand am revenit, ma uit la cele doua seturi de cate trei filme (3 facute, trei nefacute), sh nu imi mai dau seama care sunt facute si care nu.\r\n\r\nAsa ca am loat din gramada gresita trei filme (care erau deja facute, da\' io nu stiam), si am continuat sa fac poze cu furie, pana cand am terminat din nou filmele.\r\n\r\nPeste doua zile, cand o fost cu filmele la developat, sor-mea o vrut sa ma sinucida in chinuri groaznice, dupa care sa ma taie in bucatele si sa fiarba bucatelele.\r\n\r\nPentru cei care nu stiau: sor-mea, de fapt, e-o doamna.','Io, sor-mea, pozele sh ardelenii',0,'','publish','open','open','','io-sor-mea-pozele-sh-ardelenii','','','2007-09-11 17:22:48','2007-09-11 15:22:48','',0,'http://www.groparu.ro/?p=635',0,'post','',2),(636,1,'2007-09-11 19:38:15','2007-09-11 17:38:15','Base\': <font size=\"-1\">in sfarsit, vad si eu un <strong>armean bun.</strong></font>\r\n\r\nGroparu: Noi asteptam sa vedem un presedinte <strong>bun </strong>de la Ceausescu incoace, deci nu-i stress.\r\n\r\nVarujica, nu te ataca, da-i pace.','Base loveste din nou',0,'','publish','open','open','','base-loveste-din-nou','','','2007-09-11 21:07:47','2007-09-11 19:07:47','',0,'http://www.groparu.ro/?p=636',0,'post','',3),(638,1,'2007-09-12 14:14:03','2007-09-12 12:14:03','In seara asta, Groparu este invitat de oroare la emisiunea Alinei, de la Radio Cluj, combinatie facuta de <a href=\"http://www.doingtheartwork.com\" target=\"_blank\">Mihaita</a>. La ora zece. Seara. Nu v-am zis ca seara?','In seara asta - Groparu, pe unde?',0,'','publish','open','open','','in-seara-asta-groparu-pe-unde','','','2007-09-12 14:14:03','2007-09-12 12:14:03','',0,'http://www.groparu.ro/?p=638',0,'post','',21),(639,1,'2007-09-13 15:29:10','2007-09-13 13:29:10','Nu va asteptati la nimic spectaculos, finca amu ma ascult sh imi dau seama cat am putut fi de najpa, mai rau ca Nikita pe AcasaTV mah!!! Ceea ce e record personal.\r\n\r\nPrima bucata: <a href=\"http://www.trilulilu.ro/Groparu/91b42d0ea6bcf9\" target=\"_blank\">aci</a>.\r\n\r\nA doa bucata: nu aici, ci <a href=\"http://www.trilulilu.ro/Groparu/b01a1220b2d1b0\" target=\"_blank\">acolo</a>.','Groparu fusÄƒ la radio',0,'','publish','open','open','','groparu-fusa-la-radio','','','2007-09-13 16:27:33','2007-09-13 14:27:33','',0,'http://www.groparu.ro/?p=639',0,'post','',16),(640,1,'2007-09-15 02:54:09','2007-09-15 00:54:09','Groparu ma va lua sh ma va duce pe mine, adica tot pe el, la un <em>tim bildin</em>. Adeca intr-un loc unde e bere, papa sh somnic pe banii alcuiva, langa lac de munte unde se poate pescui cleni dilÄƒi si pastravi jmekeri, unde vom face pain-ball sh tiroliana, gratare sh chitari la foace de tabara pe banii alcuiva, adeca ai unei cooperative la constructia careia pun si io umaru\', si care de fapt e o meseriasha. Luni dimineata, cand va ploua si va fi frig, inghesuiala in troleu sh va mirosi usurel a navtalina finca is 8 grade sh lumea sh-o scos din dulape paltoanele alea tinute pentru lunile cu R, sa va ganditi la mine, care voi dormi in bratele celor 6 colege lezbience de la firma, calare pe naveta de Ursus sau Holsten sau votca Perfect sau Tequila sau vin rosu sau alb, intr-un hotel montan super bine incalzit, facand bancuri cu gratarele ca sa le conving sa se faca mai rumene, fragede si gustuoase. Nush de voi, da\' mie tat timpu imi ies numa\' bunie.\r\nNe recitim... errr... marti.','Paoza',0,'','publish','open','open','','paoza','','','2007-09-15 02:54:09','2007-09-15 00:54:09','',0,'http://www.groparu.ro/?p=640',0,'post','',12),(641,1,'2007-09-18 15:24:40','2007-09-18 13:24:40','Postarea asta sper sa nu fie prea mare, numa\' voluminoasa.\r\n\r\nDeci: loat aproximativ 40 de ingineri la adÄƒpat, paintbolizat, hranit (cu carne de animal), incÃ¢ntat, etc.\r\n\r\nComandat soare pentru injineri, soare conformat. Rezultat - weekend luminat.\r\n\r\nAjuns la Belish sambata amiaza, regardat lac, incercat imbetat, esuat: aveam trebi de-organizat.  La receptie receptionera am certat ca alt grup era sosit la imbetat, celalalt grup foc de tabara organizat, noi de nimic beneficiat. La final cu celalalt grup ne-am imprietenit, femeile lor nu le-am iubit, numa le-am cantat sh aburit pana cand toti s-or pilit sh or plecat la adormit.\r\n\r\nA doua zi ochii erau umflati, de la beuturÄƒ ingraÅŸaÅ£i.  Am plecat pe lac ca sÄƒ vÃ¢slim, am venit de pe lac sÄƒ ne hranim. Papa bun am killÄƒrit, ne-am oprit cÃ¢nd paintballul a venit. La paintball am tras ÅŸi tras ÅŸi tras, pÃ¢nÄƒ nici o bilÄƒ n-a rÄƒmas. Am plecat la tirolianÄƒ ÅŸi ne-am dat pe coardÄƒ lunga zi de toamnÄƒ sÄƒ ne-ajungÄƒ.\r\n\r\nSeara iar grÄƒtar nebun, am papat ÅŸi am cÃ¢ntat, veselie mare am iscat.\r\n\r\nIarÄƒ luni, cÃ¢nd voi munceaÅ£i, noi cu sucuri ne tratam, mahmureala s-o-ngropÄƒm, firma sÄƒ ne-o apÄƒrÄƒm!\r\n\r\nVreau inapoi la BeliÅŸ. Uite de ce:\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/09/picture-007.jpg\" title=\"picture-007.jpg\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/09/picture-007.jpg\" alt=\"picture-007.jpg\" height=\"529\" width=\"399\" /></a>','Gata cu paoza',0,'','publish','open','open','','gata-cu-paoza','','','2007-09-18 15:25:43','2007-09-18 13:25:43','',0,'http://www.groparu.ro/?p=641',0,'post','',9),(642,1,'2007-09-18 15:24:20','2007-09-18 13:24:20','','picture-007.jpg',0,'','inherit','open','open','','picture-007jpg','','','2007-09-18 15:24:20','2007-09-18 13:24:20','',-1190119164,'http://www.groparu.ro/wp-content/uploads/2007/09/picture-007.jpg',0,'post','image/jpeg',0),(643,1,'2007-09-18 16:36:36','2007-09-18 14:36:36','Hai s-o spunem p-a dreaptÄƒ: o iubire perfecta trebuie sincronizatÄƒ cu o lipsÄƒ acutÄƒ de intelect, cÄƒci oamenii deÅŸtepÅ£i nu prea pot fi fericiÅ£i (bine-nÅ£Äƒles, io mai am o ÅŸansÄƒ, fincÄƒ de cÃ¢nd m-am pÄƒlit la capaÅ£Ã¢nÄƒ crecÄƒ trei hemisfere cerebrale Ã®s Ã®n ÅŸomaj tehnic de la guvern).\r\n\r\nMai sunt locuri pe lumea aceasta care ÅŸi-au pÄƒstrat prospeÅ£imea de odinioarÄƒ: MÄƒrginimea Sibiului, iaurturile Napolact (NOT!) ÅŸi - bine-nÅ£Äƒles - BeliÅŸu\'.\r\n\r\nIn acest din urma caz, as indrazni sa spun ca nu exista pe lumea asta o forta suficient de mare ca sa poata schimba greaua mostenire comunista din acel locas - de alfel - binecuvantat.\r\n\r\nComunistii or preferat sa faca tot complexul pe vreo 4 corpuri de cladire, fiecare aflat la o altitudine mult mai mare decat celalalt: jos de tot e restaurantu\', mai sus ii Receptia, si mai sus is vilele, si si mai sus de vile is terenurile de penis.... aaa, tenis. Binenteles ca locul de grÄƒtarealÄƒ e si el la alt nivel decÃ¢t astelante patru.\r\n\r\nDacÄƒ esti cazat la vila aia de 2 stele, la care am stat noi pentru o nimica toatÄƒ de vreo 40 EUR/noapte/camera (ati cetit 2 stele? adica asa: ** ? ati cetit bine), atunci trebuie sa iti iei genunchiere si cotiere: la venirea de acolo, toti programecii aveau rani la coate sh genunchi de la urcat in patru labe treptele alea - din motive foarte temeinice, care au de-a face cu zeul ala grec care era sef peste bacante. La coborÃ¢t era mai uÅŸor, cÄƒ numa\' te rostogoleau colegii pana langa navetele de bere.\r\n\r\nP-orma - daca incerci sa gasesti un numar de telefon de la hotel pe Internet, poti mai bine spera sa gasesti o bratara dacica in ciorapeii pe care ii lasi pentru Mos NicolÄƒieÅŸ. Si dupa ce il gasesti, afli ca telefonul ala nu mai e valabil. Din 1992.\r\n\r\nHotelul sta foarte prost cu semnalul GSM, iar cand le spui de Zapp, oamenii cred ca esti turist francez care vorbeste in dialect; iar Internetul e sublim, dar (continuati voi fraza).\r\n\r\nTot personalul hotelului are o faÅ£Äƒ impersonalÄƒ, si aceeasi uniforma ca acum 37 de ani. Farfuriile si vesela au fost casate de la hotelul Belvedere din Cluj si aduse acilea. Decoratiunile interioare refac peisajul gospodariei de partid; si daca ai intelect de Gropar, nu ai cum sa nu musti furculita de tantalau ce esti (io mi-am ciobit incisivii fara sa vreau, dar asta o pun tot pe seama socului anafilactic pricinuit de privelistea conservata perfect din anii \'86, priveliste care m-a facut brusc sa ma simt ca atunci cand eram baietel rau, nu ma uitam la desenele cu Mihaela si il bateam pe varu-mio Vali).\r\n\r\nConstructiile nu puteau fi totusi lipsite de - ati ghicit - termopane termopane.\r\n\r\nLa restaurant nu se serveste papa afara, pe terasa: si cand ti se comunica asta, chelnerul are grija sa se uite la tine cu o privire de popa ortodox care fixeaza un punker. Nici o forta din lume nu ii poate convinge pe chelneri sa mai faca 4 metri pana pe terasa cu supa in manutza, asa ca, desi afara e o zi frumoasa cu 28 grade sh lacul iti schinteie ca o dantura cu totul si cu totul de aur, trebuie sa stai sa asculti Julio Iglesias si Fuego (manca-mi-ar Turda) si sa te uiti pe peretii imbracati cu lemn si catifea.\r\n\r\nLa restaurant, dacÄƒ stai la hotel, Ã®Å£i dÄƒ reducere 20%. Hmmm, zic io, ce tare! Åži la cat se ridicÄƒ un prÃ¢nz complet, fÄƒrÄƒ reducere? La numai 50 lei, zice tanti. Voi stiti vreun loc pe lumea asta unde sa nu papi pe saturate cu 15 euroi? Ca in centrul Bratislavei am papat zamÄƒ de burtÄƒ la 2 euro, iar acilea o zamÄƒ cu pitÄƒ ÅŸi smÃ¢ntÃ¢nÄƒ ÅŸi ardei ajunge la 3 euro ÅŸi ceva.\r\n\r\nNota bene: reducerea de 20% se aplica numai in weekend. Si stiti de ce? Cum DumniezÄƒu sa ÅŸtiÅ£i dacÄƒ nu aÅ£i cetit mai jos? Uite, vÄƒ zic io acuma: finca in timpul sÄƒptÄƒmÃ¢nii <em>tarifele scad la restaurant, pÃ¢nÄƒ devin rezonabile. Numa cÃ¢nd prind un grup de turiÅŸti tÄƒntÄƒlai ca noi preÅ£urile se umflÄƒ</em>. Mai poftiÅ£i, ni s-a zis la plecare.\r\n\r\nBalmos aveti? Da, zice. Ma satur cu o portie? intreb. Atunci va recomand sa mancati si supa, zice d-ra aia.\r\n\r\nD-ra aia de serveÅŸte e prevazuta din fabricatie cu un lant de aur la gÃ¢Å£i - asa de gros cÄƒ ai putea priponi o balenÄƒ cu el. In capÄƒtul lanÅ£ului zace o cruce de aur care cred ca odatÄƒ ÅŸi odatÄƒ a stat pe vreo besericÄƒ, aÅŸa e de mare. Mie imi placeau filmele alea cu mafioÅ£i care te omorau ÅŸi apÄƒi Ã®Å£i pupau crucea de la gÃ¢Å£i, cuprinÅŸi de evlavie. Am zis: tanti asta procedeazÄƒ la fel, te furÄƒ pe faÅ£Äƒ ÅŸi apoi pupÄƒ crucea.\r\n\r\nComandÄƒm o zamÄƒ de burtÄƒ cu un balmoÅŸ cu ciumperci (chinezÄƒÅŸti, clar! de la conservÄƒ), ÅŸi - daca se poate - scuipatul separat, sa nu ni-l amestece in mÃ¢ncare. Si cÃ¢nd sÄƒ pun oÅ£et in ciorbÄƒ (din motive de dezgreÅ£oÅŸare) OBSERV, MÄ‚RE, UN INTREG CARTIER DE MUSCULIÅ¢E DE OÅ¢ET NAUFRAGIATE IN OÅ¢ETIERÄ‚!!!!!\r\n\r\nCa sa nu inchei totul intr-o nota proasta, va zic numa atata: papa este dementiala. Deci respect. Totusi, am refuzat sa fac un tur al bucatariei de frica sa nu ma imi sara la gÃ¢Å£i paianjenii de care fugisera musculitele din otet.\r\n\r\nCa sa inchei intr-o nota sh mai optimista: toate pozele cu toti programecii consista dintr-o serie uriasa de cearcane de la beutura. Semn ca acolo te distrezi indiferent de.\r\n\r\n<strong>Update</strong>: Uitai sa va zic ca tocma\' cand am ajuns acolo, ca s-o si pornit prohibitia la pastrav! Deci pa si pusi pescuit. Fuck well, dear fish! I\'ll be eating your offspring in a couple of yearz.','Cazare la Belis',0,'','publish','open','open','','cazare-la-belis','','','2007-09-18 23:28:11','2007-09-18 21:28:11','',0,'http://www.groparu.ro/?p=643',0,'post','',11),(644,1,'2007-09-19 14:26:07','2007-09-19 12:26:07','Eu, deci Groparele, am ajuns la o concluzie usor oarecum foarte destul de aproape alarmanta:\r\n\r\nSingura chestie sanatoasa din capul meu sunt - ati ghicit!- ochii.','Am ajuns la concluzia',0,'','publish','open','open','','am-ajuns-la-concluzia','','','2007-09-19 14:26:07','2007-09-19 12:26:07','',0,'http://www.groparu.ro/?p=644',0,'post','',6),(645,1,'2007-09-19 21:33:10','2007-09-19 19:33:10','Io, dupa parerea mea, Aradu\' de acum 8-10 ani era cel mai frumos oras din Romania, da, da. Bine-nteles, dupa Copsa Mica, in mod SIGUR cel mai frumos, si Turda, aflatÄƒ pe un onorabil loc 2. Sa ne traiascÄƒ, sa creascÄƒ si sa mai apara magazine de hard discount in ele, care sÄƒ constate uimite catÄƒ bere la PET poate cumpÄƒra populaÅ£ia lor de votanÅ£i cu Becali.\r\n\r\nSor-mea, care de fapt e o doamna, merea odata cu mashina spre Jernamica, cu cumnatu-meu in mashina. Sh de la Sighie, ea mere tÄƒÄƒÄƒÄƒÄƒt aÅŸe Ã®nainte spre Arad, unde (pentru connoisseuri) o ia pe centurÄƒ ca sÄƒ treacÄƒ mai repede de ultima frontierÄƒ care o separa de Ungaria sau, ca sa dau un sinonim perfect, lumea civilizatÄƒ.\r\n\r\nÅži cum mereau ei aÅŸa prin centuri arÄƒdene, mai tatÄƒ, dau aÅŸtia de niÅŸte bloace comuniste, mai, da\' infioratoare, deci tot jegu\' de pe lumea asta se afla hapt acolo, geamuri sparte, garaje in care ominii tineau porci, gunoaie invartindu-se vesele in bataia vantului ca la nunta, ziduri innegrite (asta sigur e cu doi de \"n\"), copii rapciugosi - ce mai, ca in Kinshasa! Sh sor-mea zice catre consort \"Maaaai, tu stii ca io am o prietena din Arad in Jermania? Vaaai... stii ce am sa fac? Opreste sa fac o poza, sa ii arat si ei ce oras urat are!\" (ghini, ei, ca sibianca, ii era foarte usor sa vorbeasca, slava ceriului, ca noi, ca sibieni, deja de pe atunci stiam ca vom fi cortorari capitali ioropeni).\r\n\r\nSh opreste cumnatu\' masina, sor-mea scoboara face o poza, doo, trei, si pleaca mai departe. Dupa doo zile developeaza filmu\', scoate pozele si o cheama pÄƒ aradeanca la ea acasÄƒ, la o cafea. Si cand barfeau ele mai cu spor, sor-mea isi aminteste de pozele proaspat scoase, si ii zice:\r\n\r\n- Tu copilÄƒ, zice, draga mea prietenÄƒ din frumosul oraÅŸ Arad, da-mi voie sa iti arat ce blocuri mai urate ca Cyrano de Bergerac am pozat in frumosul tau oras! Si daca tu, o bÄƒÅŸtinaÅŸÄƒ, nu te oripilezi, sa-mi zici mie Mihaela Radulescu!\r\n\r\nSi scoate pozele, si i le tranteste pe masÄƒ la prekinÄƒ. Åži prekina, ce sa facÄƒ? Le ia ÅŸi se uitÄƒ la poze.\r\n\r\nÅži dintr-o datÄƒ, mÄƒi copii, i se lumineazÄƒ faÅ£a, si strigÄƒ:\r\n\r\n- Unde ai facut pozele astea? Zi repede!! Stii de ce? Finca uite, asta e chiar blocul meu!!! Da! Asta e blocul meu! Pot pastra poza? Eu? Da? Te rog!!!\r\n\r\nAici aveti un footage (I love this word!) cu Copsa, asa cum era ea in 2005. Daca va ganditi ca s-a schimbat ceva de atunci, nu va mai ganditi!\r\n\r\n[youtube 8pBxfdSPh1U]','Cel mai frumos oras din Romania',0,'','publish','open','open','','cel-mai-frumos-oras-din-romania','','','2007-09-19 21:35:12','2007-09-19 19:35:12','',0,'http://www.groparu.ro/?p=645',0,'post','',13),(646,1,'2007-10-08 18:41:25','2007-10-08 16:41:25','Draga banca,\r\n\r\nTu banca proasta si naparca cu limba bifurcata!\r\n\r\nMie imi trebuiau neshte bani. Corect? Da.\r\n\r\nCand eram paduche, mi-ai zambit condescendent si m-ai refuzat cand ti-am prezentat planul meu imbatabil de afaceri: <a href=\"http://www.groparu.ro/?p=330\" target=\"_blank\">un bordel numa\' de mamelit</a>.\r\n\r\nDupe aia, mi-or trebuit banutei ca sa imi ieu un cotetz in frumosul cartier muncitoresc in care adÄƒstez acuma.\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/10/dsc01025.JPG\" title=\"dsc01025.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/10/dsc01025.thumbnail.JPG\" alt=\"dsc01025.JPG\" /></a>\r\n\r\nSi la care o trebuit sa platesc: comision de acordare (cum adeca? adeca voi ma rugati sa va ieu banii si apai tÄƒt voi mÄƒ amendaÅ£i cÄƒ de ce mi-i daÅ£i?), comision de analizÄƒ dosar (cum adecÄƒ? adecÄƒ voi ma rugati sa va ieu banii ÅŸi tÄƒt voi ma taxaÅ£i cÄƒ <em>ia sÄƒ vedem dacÄƒ Äƒsta meritÄƒ banii noÅŸtri!?</em>),<em> </em>comision de administrare cont (cum vine asta? contu\' asta trebe periat, plimbat, rujat, epilat, epilat anal, tinut in bratze seara, dus la munte si in Antalia, dus la gheise si hranit numa\' cu frunze de eucalipt proaspete? Wtffff...), plus alte comisioane pentru toate porcariile inimaginabile. Aaaa, plus ca daca castig la Loto, ma incaltati cu un comision de rambursare anticipata care imi reteaza orice chef sa mai pun un ban deoparte, sperand numa\' atata, ca undeva prin 2069 o sa scap de rate si o sa imi scot curu\' la ghiseele voastre, semn de etern dispretz.\r\n\r\nP-orma m-ati obligat sa imi inchei asigurare de viatza, fiinca - citez din intelepciunea voastra infinita - acest afis va exista si maine, dar tu?\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/10/aviva.JPG\" title=\"aviva.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/10/aviva.thumbnail.JPG\" alt=\"aviva.JPG\" /></a>\r\n\r\nAsa ca si acolo o trebuit sa platesc taxa analiza dosar, pule maturi, declaratii pe propria mea raspundere, plus ca asigurarea de viatza acopera toate felurile de moarte, mai putin: moartea pricinuita de cancer pricinuit de tigari, beuturi si fomei; moartea intr-un accident in care io-s de vina daca am condus; moartea pe parapanta, cordelina, sporturi extreme; provocata de sotul ei care e gelos, moartea provocata de boli venerice (wtffff:O?!?!?!), cazuri de boli mentale imprevizibile (aici tre\' sa recunosti ca tz-am tras tzapa, fraiero!!! ca te-am tzapit cu toti expertii aia olandeji ai tai), sinucidere cauzata de boli mentale, pierderea temporara a judecatii, incaierari cu motociclisti sau manelisti etc, etc, etc. A, si in afara de moartea buna, la tine in pat.\r\n\r\nP-orma mi-atz trantit pe capatzana un <em>evaluator imobiliar</em>, un nene cu limba bifurcata care o vint cu un aparat digital mai strabun ca al meu, o tras doo poze cu fosta propitareasa (buna femeie, BTW!), o fumat ca nesimtitu\' in camera, o tras un partz in viitorul meu apartament (care de fapt e garsoniera), s-o mai scarpinat un pkik la boashe si s-o carat, lasandu-ma mai sireac cu 100 si ceva de euroi dupa 10 minute de respirat aeru\'.\r\n\r\nP-orma - ca si cum n-ar fi fost de ajuns - m-ati indrumat cu draga inima la un notar <em>special</em>, cu atribute <em>speciale</em>, cu care lucrati voi (bankeri imputiti!!!) - si care avea si un tarif foarte <em>special</em>, numai si numai pentru clientii vostri (aici tre sa recunosti ca v-am tras-o, finca am mers la notaru\' MEU, care mi-0 facut numai MIE o reducere de vreo 2 milioane, finca am mers cu pile la el! a, i-o facut reducere si la doamna care imi vindea apartamentu si isi cumpara altu\' cu banii mei, da\' ea nu o avut pile, ca o primit reducerea numa\' finca arata bine). Bine-nteles ca pentru a primi semnatura notarului MEU, ala care imi facea mie reducerea aia penala, o trebuit sa se cace pe el ca sa-i dati voi, banca curului meu, voie, ca <em>nu e notar agreat</em> (care nici macar nu sunteti banca, finca suntetz FRANCIZA!!! finca banca voastra nu investeste in Romania in sedii si personal, ea numa inkiriaza franciza la tat felu\' de firme care se dau drept banca lu\' Costica Olandezu\').\r\n\r\nSi cand ma invatzasem deja cu toata tarasenia asta, mi-ati si trantit un e-mail care mi-o umflat vena aia de la tzmpla mai tare decat i se umfla lu\' tata cand trebia sa-mi semneze carnetu\' de note: cica sunt convocat la cea mai apropiata sucursala ca sa imi incheie pensia privata obligatorie.\r\n\r\nDati-mi voie sa va transmit un mesaj pe care, desi e scris, sa vi-l imaginati ca si cum ar fi racnit de Tarzan:\r\n\r\n<strong>MUUUUUIEEEEEEEE!!!!!!!!!!</strong> (bag pixu\' ca nu is fonturi mai mari in versiunea asta de wordpress)\r\n\r\nPS: A, si va mai doresc ce-o patit si Nadina din partea lu\' Petre din Rascoala, eroina aia a lu Marchizu\' de Sade, nu mai stiu cum o kema, si - bine-nteles - patru rangi mineresti in dantura, asa, ca in mineriadele din anii \'90. Pentur cei care nu stie: e vorba, bine-nteles, de banca fuck<strong>ING</strong>.\r\n\r\n<strong>Update</strong>: uitai sa va zic ca la aceeasi banca, cand platesti rata, trebuie sa completezi si cel mai cretin formular de varsamant posibil (am patru rate la 4 banci diferite, si numa la portocaliii astia trebe formular!) care are sectiune speciala de completat - sursa banilor. Nu are rost sa va mai zic ca la sectiunea asta completez cu \"BUZUNARUL MEU\". Si tanti de la ghiseu rade de fiecare data.','Draga Banca!',0,'','publish','open','open','','draga-banca','','\nhttp://www.groparu.ro/?p=330','2007-10-08 19:20:50','2007-10-08 17:20:50','',0,'http://www.groparu.ro/?p=646',0,'post','',20),(647,1,'2007-09-21 09:46:08','2007-09-21 07:46:08','Da. Si stiti de ce?\r\n\r\nFinca au un comision de acordare a imprumutului de nevoi personale de 6%.\r\n\r\nStiti cat e suma asta din 9000 euroi? Plus comision de incasare?\r\n\r\nAproape 600 euroi .\r\n\r\nDeci: FUCK YOU, ALPHA BANK!\r\n\r\nSi nu comentati ca de ce nu am cetit cu atentie contractul, ca daca ceteam azi nu mai aveam ce scrie. Deci - ne potolim.','Fuck you too, Alpha bank!',0,'','publish','open','open','','fuck-you-too-alpha-bank','','','2007-09-21 09:46:08','2007-09-21 07:46:08','',0,'http://www.groparu.ro/?p=647',0,'post','',9),(648,1,'2007-09-21 14:13:22','2007-09-21 12:13:22','Dap. In primu rand finca vineri ma intalnescu in Sibiu cu <a href=\"http://www.southbeachundercover.com/sbu2.html\" target=\"_blank\">Luciano</a>, prekinu\' mieu din copkilarie care amu isi urmeaza cariera domniei sale de film director prin Miami (ca sa vighetz filmu\' va trebe <a href=\"http://www.apple.com/quicktime/download/\" target=\"_blank\">QuickTime</a>); asa; si cu Delia sh cu Nelutzu, pe care io i-am cuplat, deci is un fel de godfather spiritual pentru ei, sh ce uneshte Groparu Dumnezeu nu prea desparte. Si care amu isi duc rodul iupirii lor prin cea Italie, ca toti romanii, de alfel.\r\n\r\nSambata am nunta in Fagarash.\r\n\r\nDuminica am nunta in Cluj.\r\n\r\nDeci ne recitim luni.','Urmeaza un weekend alb',0,'','publish','open','open','','urmeaza-un-weekend-alb','','','2007-09-21 14:13:22','2007-09-21 12:13:22','',0,'http://www.groparu.ro/?p=648',0,'post','',9),(649,1,'2007-09-21 15:21:18','2007-09-21 13:21:18','<a href=\"http://www.hotnews.ro/articol_84546-Salvati-planeta-Top-opt-sfaturi-sa-faci-sex-ecologic.htm\" target=\"_blank\">Aici</a>.\r\n\r\n<strong>1. Stingeti luminile!</strong>\r\nNu uitati in prealabil sa va asigurati ca partenera nu are, nu a avut si nu va avea NICIODATA putzulica lui/ei personalÄƒ. Pentru ca daca are, partida de sex nu va ieÅŸi exact aÅŸa cum planuiaÅ£i la inceput.\r\n\r\n<strong>2.</strong><strong>Reduceti consumul de apa!\r\n</strong>Adeca <em>faceÅ£i dus impreuna</em>. Daca partenera are, a avut sau va avea VREODATA putzulica lui/ei personalÄƒ, grijÄƒ mare la sÄƒpun!\r\n\r\n<strong>3. </strong><strong>Folositi ingrasaminte naturale!</strong>\r\n<em>22% dintre oamenii din toata lumea au facut sex in gradina, iar gradina trebuie fertilizata cu ingrasaminte naturale, ca sa fiti ecologisti</em>. Daca sunteti scatlover, nu aveti decat motive de bucurie.\r\n<!-- BBmedia one2many Position: hotnews.ro(13) / content(5) / patrat(1) / rectangle 300x250(7) --> <!-- HowTo: Place this code into the html page there the ad should appear. -->\r\n\r\n<span class=\"arial12negru\"><font class=\"arial12negru\"><strong>4.</strong></font></span><span class=\"arial12negru\"><font class=\"arial12negru\"><strong> Jucariile erotice pot fi toxice!</strong></font></span><span class=\"arial12negru\"><font class=\"arial12negru\"><strong> </strong>\r\nIo, dupa ce l-am cetit pe <a href=\"http://oedip.blogspot.com/2007/09/orange-nare-acoperiren-pizd.html\" target=\"_blank\">Oedip</a>, am zis cÄƒ marchizu\' de Sade e un bebelush in maieu, Torquemada e un fel de Mahatma Gandhi, sh Doftor Mengele un fel de mitropolitu\' Daniel.   </font></span>\r\n\r\n<span class=\"arial12negru\"><font class=\"arial12negru\"><strong>5. </strong><strong>Ce e scump e si bun!</strong>\r\nNu zau! Cica <em>jucarioarele alea care se infig si care is scumpe is si ecologice</em>. Io va zic cea mai ecologica jucarioara erotica: fomeia, mah. Si e drept ca nu e ieftina, finca coasta muuuhuhuult mai mult decat o oaie. Pastorii stie de ce. </font></span>\r\n\r\n<span class=\"arial12negru\"><font class=\"arial12negru\"><strong>6. Aruncati prezervativele la gunoi!</strong>\r\n<em>Prezervativele din latex</em>, spre deosebire de cele din matz de capra, <em>au o mica problema: nu sunt biodegradabile. Nu le aruncati la toaleta pentru ca infunda tevile</em>. Daca tipesa e maritata, e de preferat sa aveti mare-mare grija unde le puneti, finca daca vine inshelatu\', s-ar putea sa fiti nevoiti sa le inghititi. Io numa atata zic.</font></span>\r\n\r\n<font class=\"arial12negru\"><strong>7. Faceti miscare!</strong>\r\n<em> Exercitiul fizic este la randul lui un afrodisiac si ceva ce multi dintre noi ar trebui sa practice mai des</em>. Va recomand aerobic cu o gashca de liceence, inot cu trupa de anul I de la medicina, rugby cu majoretele de la CFR Ecomax, lupte greco-romane cu crainicele de sport de la ProTV, urmate - bine-nteles - de o sauna cu fetele de la paginile 5. </font>\r\n\r\n<span class=\"arial12negru\"><font class=\"arial12negru\"> <strong>8. Alegeti afrodisiace naturale!</strong>\r\n<em>Incercati una dintre plantele cu efect afrodisiac - telina, morcovul, ardeiul iute rosu, sparanghelul, ginsengul, piperul negru si avocado</em>. Daca ele dau gresh, mereti in cea mai apropiata crajma studenteasca, bagati bere la greu si stingeti cu coniac, si veti fi uimit langa cine va veti trezi a doua zi in pat.</font></span>\r\n\r\nBonus de la Groparu, care de fapt iz io: creca <a href=\"http://www.groparu.ro/?p=534\" target=\"_blank\">am mai scris</a> despre asta!','Cica secs ecologic. Citez: hÄƒÄƒÄƒ, hÄƒÄƒÄƒ, hÄƒÄƒÄƒ!',0,'','publish','open','open','','cica-secs-ecologic-citez-haaa-haaa-haaa','','\nhttp://www.groparu.ro/?p=534','2007-09-21 16:04:43','2007-09-21 14:04:43','',0,'http://www.groparu.ro/?p=649',0,'post','',19),(650,1,'2007-09-24 20:56:33','2007-09-24 18:56:33','Deci mai oameni, femei, copii, animale, becali:\r\n\r\nIo, daca mai vaz anu\' asta vreo rochie de mireasa, torturi cu artificii, voaluri sau de mai auz  marsul ala funebru de maritis, in Romania statu\' sprijina casatoria, io o sa ma simt ca aia care is victime de criminali in serie, care is kinuiti zile in sir pe aceeasi melodie, scapa de criminal, si tat mai aud intre urechi muzica aia nubÅ£iala!!!\r\n\r\nFaza e ca am avut doo nunti meseriashe tat weekendu\', si asta zice tat. Nuntile cu numarul 7 si 8 (!!!) anul asta.\r\n\r\nAsta dupa ce m-am intalnit cu Luciano sh Nelu vineri seara, cu care am beut pana la o ora rezonabila, am cumparat lumea toata, am vandut-o la loc, am pus tarile la cale etc.\r\n\r\nSambata o trebuit sa vie cineva sa ne duca de la Sibiu pana la Fagaras, pe acel drum de 74 km prevazut cu (nu glumesc) 19 semafuare. Am comandat la Dumnezeu vreme faina, si cand treceam de-a lungul muntilor pe care (in tineretele mele aventuroase) i-am batut de atatea si atatea ori, s-au itit neshte creste care ne-or facut cu ochiu\', si mi-or zis ca daca ma las de beuturi, chefuri, femei si tigari, o sa am ocazia sa ii bat din nou. Cand le-am explicat beneficiile (moarte rapida si nedureroasa pe la criza varstei de mijloc) n-au mai zis nimic, da\' nimic! Ca or intzales.\r\n\r\nCand am ajuns, aia cu care am venit, si care is patronii uneia din viitoarele foarte mari agentii de publicitate din Cluj, or incercat vreo juma de ora, la telefon, sa invetze cum se face un nod de cravata, ca nu vroiau sa li-l fac io, d-ala groparesc. Parol! Sh tat n-or reusit.\r\n\r\nO kestie care nu mi-o placut:cand am fo\' la Belish, asa bine or gatit aia, ca mi s-o umflat buza sh mi-o aparut o ditamai buboaie pe buza de sus. Noi am intrat tarziu acolo, la nunta; si toata nunta s-o uitat luuuung, lung la mine, din cauza buzei. Si si-or pastrat privirea pe buboaia mea pana cand am plecat de acolo.\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/09/buboi.JPG\" title=\"buboi.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/09/buboi.JPG\" alt=\"buboi.JPG\" /></a>\r\n\r\nBoooon. Mnoa, Phoenix, prekinu\' lu Sicretu\' (astea is numele de cod din camin) si-o loat, mai copkii, o dragutza de nievasta, mah, ghe la Maramu\', ghe strÄƒlucea tÄƒtÄƒ, mah!!! Sh le statea bine la amandoi, ghe numa, si cam era cazu\' sa se ieie, ca doara de 8 ani ii tat facea lui ei curte!\r\n\r\nNunta avu loc intr-un loc super demential, numit FÃ¢ntÃ¢niÅ£a CrÄƒiesei, care avea p-acolo numa baltoace d-alea, iaze de pescuit; si in baltoaca din fatza hotelului putrezea linistit un stÃ¢rv de arici pogonici.\r\n\r\nLa nunta - plin de tineret. Sh <em>viaipiuri</em>. Ovidiu Uscat (Ottonel) fu acolo, mah! A, si io. Care nuz inca un vedet decÃ¢t, aÅŸa cum spuneam, numa\' la mine Ã®n budÄƒ.\r\n\r\nUna din chestiile care mi-or placut: fiecare tip de sticloantza de beutura avea pe ea o eticheta personalizata. Gen:\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/09/dsc00805.JPG\" title=\"dsc00805.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/09/dsc00805.thumbnail.JPG\" alt=\"dsc00805.JPG\" /></a>\r\n\r\nUna din gajicile dela nunta s-o dat cu atata ruj, ca o pastrat o feliutza de varza de la salata vreo 20 minute lipita de buza inferioara, fara sa-si deie seama.\r\n\r\nToata cavalerele de onoare aveau aceeasi rochie. Adica acelasi tip de rochie. Si toate or plans la final, cand le-o aratat un colaj d-ala cu poze din tineretze, mah, or inceput toate sa planga ca miresele, de ti-era mai mare dragu\'!\r\n\r\nAm plecat seara d-acolo. Am ajuns la 4 dimineatza in Cluj. La 7 dimineatza ne-am trezit sa merem la a doa nunta pe weekendu\' asta de trecu amu.\r\n\r\nAcilea - am fo la nunta la un neam de clonatzi, finca toti semanau intre ei! Da\' totzi.\r\n\r\nFitz antena numa ce tablou avea mirele in casa la el:\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/09/dsc00101.JPG\" title=\"dsc00101.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/09/dsc00101.thumbnail.JPG\" alt=\"dsc00101.JPG\" /></a>\r\n\r\nAsaaaaa. Åži aici naÅŸii\', socrii, mirii, toti - da\' toti - nuntaÅŸii s-or holbat toatÄƒ nunta la buzoaia mea umflata. Io, de regula, cand mergeam la evenimente, imi aparea un cosh special pe fatza, care nu putea fi anihilat, si care disparea a doua zi. Io il numeam \"coshu\' de evenimente speciale\", ca l-am avut inclusiv la banchetu\' de absolvire din fuckultÄƒ. Finca am cam trecut de varsta aia acneica, amu m-am procopsit cu ditamai buboaia pe buza! Si cu buboaia aia am pupat tot ce-o miscat la nunta, ba cand l-o vazut era sa si uite popa replicile sale la beserica, ca era sa zica \"buboiu dantzuieshte\" in loc de Isaia, da\' s-o stapanit la vreme. Ofiteru\' starii civile o avut chiar o grimasa de caprar cand mi-o vazut umflatura de la guritza, si de la ÅŸoc o vorbit numa\' cu accent unguresc, probabil din cauza ca chiar era ungur. Da\' nevermind.\r\n\r\nLa nunta de langa noi, am aflat ca conlocuitoru\' de nash o dat o cinste de toata cinstea: 100.000 coco. Dap. Euro d-Äƒia. Vero.\r\n\r\nSi o poza de final:\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/09/dsc00099.JPG\" title=\"dsc00099.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/09/dsc00099.thumbnail.JPG\" alt=\"dsc00099.JPG\" /></a>\r\n\r\nCu asta am terminat, ca deja gata!\r\n\r\n<strong>Update</strong>: Voi ati vazut vreodata vreun fotograf de nunti care sa nu se imbrace in blugi in cea mai frumoasa si selecta zi din viata ta? Puneti un costum pe voi, porcovanilor!','ULTIMELE NUNÅ¢ÃŽ PE ANU\' ASTA!!!',0,'','publish','open','open','','ultimele-nunti-pe-anu-asta','','','2007-09-25 09:27:08','2007-09-25 07:27:08','',0,'http://www.groparu.ro/?p=650',0,'post','',13),(651,1,'2007-09-24 20:03:24','2007-09-24 18:03:24','','dsc00805.JPG',0,'','inherit','open','open','','dsc00805jpg','','','2007-09-24 20:03:24','2007-09-24 18:03:24','',650,'http://www.groparu.ro/wp-content/uploads/2007/09/dsc00805.JPG',0,'post','image/jpeg',0),(652,1,'2007-09-24 20:53:23','2007-09-24 18:53:23','','dsc00101.JPG',0,'','inherit','open','open','','dsc00101jpg','','','2007-09-24 20:53:23','2007-09-24 18:53:23','',650,'http://www.groparu.ro/wp-content/uploads/2007/09/dsc00101.JPG',0,'post','image/jpeg',0),(653,1,'2007-09-24 20:55:57','2007-09-24 18:55:57','','dsc00099.JPG',0,'','inherit','open','open','','dsc00099jpg','','','2007-09-24 20:55:57','2007-09-24 18:55:57','',650,'http://www.groparu.ro/wp-content/uploads/2007/09/dsc00099.JPG',0,'post','image/jpeg',0),(654,1,'2007-09-24 21:15:16','2007-09-24 19:15:16','','buboi.JPG',0,'','inherit','open','open','','buboijpg','','','2007-09-24 21:15:16','2007-09-24 19:15:16','',650,'http://www.groparu.ro/wp-content/uploads/2007/09/buboi.JPG',0,'post','image/jpeg',0),(655,1,'2007-09-25 14:39:11','2007-09-25 12:39:11','Deci Tibby face show de dimineatza pe <a href=\"http://transilvania.hertza.ro:8512/listen.pls\" target=\"_blank\">Radio Transilvania</a>, si Tibby ii om din ala care mai are inca vreo 3 joburi pe langa toate astea, sh e si insurat cu Marieana sh tat felu\'. Sh nu are vreme de niica, sh noi tot facem mijto de el ca nu mai are vreme nij sa se **** (cuvantul de supt stelutze incepe cu f).\r\n\r\nCum facem noi mijto?\r\n\r\nZicem ca Tibby, cand se suie pe nevasta-sa, o infige o data; apai o scoate, si zice: \"Poftim, draga mea! La toate celelalte miscari te simti la fel!\"','Cum face Tibby dragoste',0,'','publish','open','open','','cum-face-tibby-dragoste','','','2007-09-25 14:39:11','2007-09-25 12:39:11','',0,'http://www.groparu.ro/?p=655',0,'post','',8),(656,1,'2007-09-25 14:49:08','2007-09-25 12:49:08','Ati auzit de AZP?\r\n\r\nAZP este, pentru cei care au fost mai dastepti ca mine sh or <em>eludat</em>, ca sa zic asa, armata, este denumirea generica pentru un soi de chiloti de armata. Chiloteii astia seamana cu boxerii, deci au manecutze, si din cauza asta putulica nu prea stie ea, sireaca, de ce parte a axei corpului sa steie; sh se tot plimba de nebuna de pe stanga pe dreapta si inapoi (in afara de cazurile cand sta, ca la unii mai fericiti dintre noi, numa\' in sus).\r\n\r\nSi denumirea de AZP vine exact de la faptul caÂ  putulica se bezmeticeste in chilotii astia:\r\n\r\nAZP = Aparat de Zapacit Pula.','Acronime-acronime, termopane-termopane',0,'','publish','open','open','','acronime-acronime-termopane-termopane','','','2007-09-25 14:49:08','2007-09-25 12:49:08','',0,'http://www.groparu.ro/?p=656',0,'post','',17),(657,1,'2007-09-26 00:08:51','2007-09-25 22:08:51','Deci da, mai copkii, da. Trebe animalele salvate. Asa cum v-am invatzat, iata lista cu <em>de ce</em>-uri:\r\n\r\n1. Pisicutzele femeilor sh cocoseii barbatilor trebe protejati, asta fara putintza de tÄƒgadÄƒ; asijderea serpii din pantaloni, veveritzele de supt fuste, aricii pogonicii de la fetele care nu se mai obosesc sa isi tundÄƒ cretzu\' (si tot arata bine!)\r\n2. Daca se promulga legea, mai multi romani verzi vor ajunge dupa gratii pentru torturat de animale, vor fi violati si vor deveni homosexuali; dupa cum am mai zis, asta va lÄƒsa mai multe femei de iubit pentru noi, heterosexualii;\r\n3. Daca n-or sa-si mai bata animalele, romanii se vor dezvatza si sa-si mai bata nevestele, asa ca atunci cand pui manutza pe orice parte a corpului nevestei aproapelui tau ea nu va ofta de durere de la vanatai;\r\n4. Scapam de aparitii fantomatice gen Brigitte Bardot, care te fac sa nu iti mai placa de nici o fomee, ever!\r\n5. Scapam de mafia japoneza Yakuza care vine in tzara ca sa razbune moartea conationalului muscat si omorat de cutzu ala din Bucuresti, amu ceva vreme; daca ei nu mai vin acilea, avem mai multe sanse sa ramana romancele in patrie, stiut fiind ca majoritatea romancelor pica cu cracii in sus daca in fatza le apare un strain, chiar daca respectivul strain e un italian mai batran ca bunu-mio, chel sh burtos, la volanul unui Fiat Tempra din \'81, care asculta la maxim Toto Cotugno sh poarta ochelari de soare.\r\n6. Ne salvam viatza daca ne reincarnam (la asta pun pariu ca nu v-atz gandit!); io, de exemplu, vreau sa ma reincarnez in motanu\' lu Bill Gates, sh sa nu ma castreze niciodata, ca daca nu prind bugs sh i le bag in Vista; sau, a doua alternativa, m-as reincarna in mobilier de bordel din camera asiaticelor.\r\n7. Daca se face Politia Animalelor, se va face si Ministerul lor de Educatie, Parlamentul Animalelor, Presedintia, Clubul lor de Fotbal \"Steaua\", discotecile si primariile lor, alegeri libere si economia de piatya; pun pariu cu voi ca daca se fac astea, ne vom muta la ele-n regat sh vom trai mai bine ca in Romania - deci o sansa-n plus pentru tine, privitorule de proteveu si votator de Becali!\r\n8. Animalele nu asculta manele la telefon. Deci - respect.\r\n9. Ne asiguram ca animalele alea din care se fac blanuri pentru cretine de fotomodele mor de moarte frumoasa, la pensie, nu jupuite de vii de kineji, asa cum am vazut intr-un film care m-o facut sa renunt sa ma mai insor cu Kate Moss, finca face parte din tagma designerilor de moda homosexuali, anorexicelor care-si ascund formele ÅŸnur (fÄƒrÄƒ Å£Ã¢Å£e fÄƒrÄƒ cur) in spatele blÄƒnurilor ÅŸi tagma femeilor care picÄƒ Ã®n cur pentru fotbaliÅŸti.\r\n10. Mai era parca un motiv... ÄƒÄƒÄƒ... stai sa mi-l amintesc... A! Da. Evitam cruzimea gratuita fatza de animale,desi asta nu mi se pare un motiv chiar asa de important, da\' l-am pus acilea ca sa nu ziceti ca Groparu\', dupa ce ca n-are crieri, n-are nici inima!\r\n\r\nDeci <a href=\"http://www.protv.ro/filme/azi-la-stirile-pro-tv-stop-torturarii-animalelor-semneaza-petitia.html?id_file=30854#30854\" target=\"_blank\">votatz</a>, in puii mei!','Petitia protevista pentru salvat animalele',0,'','publish','open','open','','petitia-protevista-pentru-salvat-animalele','','','2007-09-26 00:08:51','2007-09-25 22:08:51','',0,'http://www.groparu.ro/?p=657',0,'post','',26),(658,1,'2007-09-27 12:15:23','2007-09-27 10:15:23','Eram in Danemarca. Si urmam un curs despre Shakespeare tinut de aproape cea mai tare profesoara ever, o daneza care era sh faina, sh desteapta, si de 30 de ani, cand e femeia mai femeie, si si scolita prin <em>cheimbrigiuri</em>, si care ne preda noo, aia - danejii dÄƒjteptii si io - claro, prostu\' Europei de Est. Clar ca mi-o picat cu tronc din prima clipitÄƒ!\r\n\r\nTanti asta stia Shakespeare cum stiu io sa recit din Pavel Stratan, my personal all time hero (totusi, nu chiar cat stie Dunareanu despre Shakespeare, un prof super meseriash de la Cluj). Si gasea, manca-tz-ash, kestii prin versele lu Will, ca il facea pe Cretziu, prof de la faculta asta din Romania, sa isi retraga ce zisese el odata, la un curs: \"Despre Shakespeare nu s-a scris nimic remarcabil in ultimii...\"\r\n\r\n(acilea facea o paoza de toti ne auzeam pÃ¢rÅ£urile de emotie)\r\n\r\n\"100 de ani!\"\r\n\r\nMnoa, si deci. Eram la curs, si asta ne arata intrigile triunghiurilor amoroase din Two Merchants of Venice, interpretari freudiene ale Romeo sh Julietei, abordare post-coloniala la nush ce sonet, sh deodata - BUUUUUUM!!!! Nu Boom TV, nu-nu-nu. Se spargeau in figuri neshte mesteri si niste faiantza in camera de langa, si faceau aia o galagie cu mÄƒru\'... ÄƒÄƒÄƒ, cu pica-mÄƒru, ca tanti vorbea ca in filmele cu Charlie Chaplin! Adeca nu se auzea nemica, finca Chaplin o facut numa filme mute (in afara de Dictatoru\', parca).\r\n\r\nSi in tot vacarmu\' ala, tanti isi sufleca poalele si pleaca sa le zica frumos la mejteri sa termine, in pula mea, cu galagia, ca nu isi poate tine cursu\'. Si vine inapoi toatÄƒ rÃ¢zÃ¢ndÄƒ, asa cum numa femeile intelectoale stiu radea, de ui ase imi perpelea inimioara mea de studinte sarantoc indragostit fara sperantza de doamna profesoara parfumata!\r\n\r\nZice:\r\n\r\n- M-am dus la sefu de ekipa, care fuma, si dadea cu biciu peste muncaÅŸi, care erau toti negri sau arÄƒboci. Åži i-am zis: Bueeey, termenati cu galagia, ca am curs cu anu 3!\r\n- Nu se poate, d-ra, zice nenea team leaderu\', la sictir, ca ii platesc cu 20 euro pe ora pe astia, si trebe sa terminam repede.\r\n- Hey! Zice profa, si in secunda aia o devenit amenintatoare si geniala, cred ca mai exersase atitudinea asta cu prekinii ei intimi, imbracata in lenjerie de cauciuc sh cu zbici in manutza: HEY, ASSHOLE, zice ea, I\'M EXPENSIVE, TOO!!!!\r\n\r\nOra aceea nu am mai auzit nici macar un oftat din camera de langa.','Blue Collar vs White Collar',0,'','publish','open','open','','blue-collar-vs-white-collar','','','2007-09-27 12:15:23','2007-09-27 10:15:23','',0,'http://www.groparu.ro/?p=658',0,'post','',10),(659,1,'2007-09-26 18:26:50','2007-09-26 16:26:50','Pentru cei care nu stie: click <a href=\"http://www.groparu.ro/?p=405\" target=\"_blank\">acilea</a> ca sa aflati despre cheful nostru in care ne imbracam in tigani sh ne doare la pedala de tot.\r\n\r\nAnul asta, dupa cum ziceam, am avut stema, steag, fanion, Act Constitutiv si logo. Iata logo-ul:\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/09/blazon_v1_final.jpg\" title=\"blazon_v1_final.jpg\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/09/blazon_v1_final.jpg\" alt=\"blazon_v1_final.jpg\" height=\"427\" width=\"288\" /></a>\r\n\r\nSi ca sa fie totul ofitzial, iata sh Actul Constitutiv, la redactarea caruia au dat coltzul multi ficati sh multe beri stinse  cu coniac, la intalnirile celulei de criza. Deci - cetitz, ca io m-am kishat deja in pantaloane! GraÅ£ie, CÃ¢rlanu\';)\r\n<p class=\"text14\" style=\"text-align: center\" align=\"center\"><strong><span style=\"font-size: 20pt\" lang=\"RO\">Act constitutiv</span></strong><strong><span style=\"font-size: 8pt\" lang=\"RO\"><o:p></o:p></span></strong></p>\r\n<p class=\"text14\" style=\"text-align: center\" align=\"center\"><strong><span style=\"font-size: 20pt\" lang=\"RO\">al<o:p></o:p></span></strong></p>\r\n<p class=\"text14\" style=\"text-align: center\" align=\"center\"><strong><span style=\"font-size: 20pt\" lang=\"RO\">Stemei enclavei Valea Caselor</span><span lang=\"RO\"><o:p></o:p></span></strong></p>\r\n<p class=\"text14\" style=\"text-align: center\" align=\"center\"><strong><span style=\"font-size: 14pt; font-weight: normal\" lang=\"RO\">din 15.05.2007</span><span lang=\"RO\"><o:p></o:p></span></strong></p>\r\n        Stema Enclavei Valea Caselor reprezinta un semn de recunoastere, conventional, distinctiv, caracteristic si simbolic, functionÃ¢nd implicit ca marca sigilara a autoritatii administrativ-teritoriale.Stema va fi redata pe frontispiciul sediului , pe indicatoarele care marcheaza intrarea Ã®n enclava, va fi folosita la toate actiunile festive si de protocol si cu toate prilejurile care impun prezentarea stemei enclavei. Fiind Ã®n cauza o stema se impun conventiile heraldice.\r\nCa semn heraldic al unui spatiu avÃ¢nd traditie heraldica autentica si un trecut istoric prestigios, stema se cere a indica aceasta ascendenta si demnitatea ei.\r\nCa fapt social, alcatuirea heraldica proiectata Ã®nainte de a fi legal conferita prin autoritatea statului se cere a se dovedi apta de a satisface exigentele cetatenilor pe care urmeaza a-i reprezenta urmÃ¢nd a fi demonstrata dispozitia lor de a-si apropria stema si de a si-o Ã®nsusi. RespectÃ¢nd conventia heraldica si functiunile semnului, acesta se cere a fi unic, simplu si clar, elocvent pentru cÃ¢teva idei generale si fundamentale acceptate de catre locuitorii enclavei ca semnificative pentru identitatea lor.\r\n\r\nDESCRIEREA SI SEMNIFICATIILE elementelor Ã®nsumate ale stemei Enclavei Valea Caselor\r\n\r\nDescrierea stemei:\r\nStema Enclavei Valea Caselor, ca si compozitie heraldica, este reprezentata printr-un scut clasic cu baza rotunda despicat format din: Partea dreapta sus, pe smalt galben cu strugure dacic si butoi de stejar cercuit. Partea dreapta jos, pe smalt albastru cu cort clasic. Partea stanga sus, pe smalt albastru cu ceaun de Polovragi si foc de lemne. Partea stanga jos, pe smalt galben cu palarie tiganeasca si roata de caruta cu coviltir.\r\n\r\nSemnificatiile elementelor Ã®nsumate:\r\nStema Enclavei este o stema civica a entitatii teritorial-administrative. Ea cuprinde semne de patronaj istoric, fiind totusi o asumptiune. Din punct de vedere stilistic este o stema gotica.\r\n\r\n- Partea DEXTRA SUPERIOR - smalt galben cu strugure dacic si butoi de stejar cercuit. Semnul indica culoarea berii ca bautura traditionala a enclavei combinata cu vinul obtinut din strugurii zemosi proveniti din comertul cu teritoriile invecinate. Semnul este intrat Ã®n conventia heraldica europeana, din epoca timpurie pÃ¢na astazi, ca semn heraldic vlah si semn Ã®n stema dinastica a domnilor Valahiei Mari.\r\n- Partea DEXTRA INFERIOR - smalt albastru cu cort clasic. Semnul indica locuinta traditionala a locuitorilor enclavei asa cum este ea cunoscuta inca din vremea marilor migratii, ca si locuinta comoda si usor de deplasat destinata unor oameni vesnic in miscare.\r\n\r\n- Partea SINISTRA SUPERIOR - smalt albastru cu ceaun de Polovragi si foc de lemne. Semnul reprezinta metoda principala de preparare a hranei, alaturi de protap, element din care se zareste numai partea centrala, loc in care de obicei este agatat ceaunul.\r\n- Partea SINISTRA INFERIOR â€“ smalt galben cu palarie tiganeasca si roata de caruta cu coviltir. Semul indica obiectul vestimentar traditional folosit de locuitorii enclavei pentru partea superioara a corpului, mai precis cap si mijlocul de deplasare folosit de acestia, asa cum sunt ele descrise in scrierile carturarilor din vechime.\r\n\r\nNota: Stema Enclavei Valea Caselor a fost aprobata prin HotarÃ¢rea nr. 1 / 2007 a Celulei de Criza ca organism decizional si executiv al enclavei.\r\n\r\nData: 15.05.2007\r\n\r\nCelula de Criza:\r\n\r\nCÃ‚RLANU\r\n\r\nDeGeaba\r\n\r\nTÃ‚MP\r\n\r\nCRÃ‚NG\r\n\r\nIELVIS\r\n\r\nDUDÄ‚\r\n\r\nADI\r\n\r\nECO aka Neghinitza\r\n\r\nNÃ‚RÅ¢OAGÄ‚ aka PÃ‚RÅ¢OAGÄ‚ (NÃ‚RÅ¢OAGÄ‚ numa\' o pus dejtiu, ca el nu stie sa scrie, el e inginer)\r\n\r\nPS: Na, prekini d-ajtia am io!','Tiganiada - Memento',0,'','publish','open','open','','tiganiada-memento','','\nhttp://www.groparu.ro/?p=405','2007-09-26 22:10:41','2007-09-26 20:10:41','',0,'http://www.groparu.ro/?p=659',0,'post','',10),(660,1,'2007-09-26 12:21:09','2007-09-26 10:21:09','','blazon_v1_final.jpg',0,'','inherit','open','open','','blazon_v1_finaljpg','','','2007-09-26 12:21:09','2007-09-26 10:21:09','',-1190800997,'http://www.groparu.ro/wp-content/uploads/2007/09/blazon_v1_final.jpg',0,'post','image/jpeg',0),(661,1,'2007-09-26 14:54:10','2007-09-26 12:54:10','Un <a href=\"http://verbiaj.blogspot.com/2007/09/o-nsemnare-care-m-ngreoat.html\" target=\"_blank\">beiat</a> ma judeca:\r\n\r\n\"DupÄƒ ce dobitocii din BuzÄƒu au cÄƒlcat Ã®n picioare o pisicÄƒ in scara blocului, iatÄƒ cÄƒ mai apare unul, care Ã®i mai dÄƒ cÃ¢teva suturi din tastaturÄƒ. Post-mortem, Ã®n scara blogului. CÄƒ aÅŸa vrea el, sÄƒ facÄƒ miÅŸto. Groparu\' Ã®i mai sapÄƒ o datÄƒ groapa pisicii, Ã®ntr-un pamflet care-Å£i face scÃ¢rbÄƒ.\"\r\n\r\nMai mult cetiti voi pe saitu\' sau, care este si care se anti-gropariceste.\r\n\r\nDa, mai copii. Daca nu v-atz prins pana amu, io nu prea is <a href=\"http://www.urbandictionary.com/define.php?term=tree+hugger\" target=\"_blank\"><em>tree-hugger</em></a>, ca am verificat; io-z un criminal, da\' sa stiti ca io nu dau cu picioru\' la pisicutze, finca pisicutzele place la Groparu (hehe!). Da\' numa\' atata va mai dzic: daca vreti sa fiti seriosi, fitzi; io nu is serios decat cand ma kiama shafu\' sh imi scoate pe nas greshelile (care e multe) si cand imi platesc ratele, care e si ele multe. In rest scriu aberatiuni care-Å£i face scÃ¢rbÄƒ exact asa cum le dicteaza vocile din mansarda, ce pana me, si cred ca le voi scrie indiferent de ce zice unu\'-altu\', ca e singuru\' mod de a le face sa tacÄƒ.\r\n\r\nSi sper ca ceilalti cetitori au inteles (duh!!!) cÄƒ io, intr-o aberatiune, pastrez artileria grea la final (d-aia am bagat la finalu\' aberatiei fraza cea mai sugjestiva, pe care prekinu\' meu virtoal cel mai bun o incrimineshte). Si sa mai intzaleaga ca unele chestii de p-acilea is \"wannabe jokes\", despre care io is primu\' care recunoaste ca nu prea ies decÃ¢t deloc. Si stiti de ce nu ies?\r\n\r\n(pauza pur meditativa)\r\n\r\n<a href=\"http://www.groparu.ro/?p=147\" target=\"_blank\">Finca nu pot bea bere kiar zilnic</a>!!!','Ce s-o inteles din petitia pentru animale',0,'','publish','open','open','','ce-s-o-inteles-din-petitia-pentru-animale','','\nhttp://www.groparu.ro/?p=147','2007-09-26 18:15:39','2007-09-26 16:15:39','',0,'http://www.groparu.ro/?p=661',0,'post','',13);
INSERT INTO `wp_posts` VALUES (662,1,'2007-10-01 18:50:16','2007-10-01 16:50:16','Io - deci persoana dintre urechile mele, dintre putulica si poponetzul meu sexy sh impenetrabil, de supt calota mea craniana, omul ale carui bratze ma scarpina in fundulica si imi place, fiintza din spatele ochilor mei, <em>homo anti-sapiens</em>ul pe care il carÄƒ picioarele si mainile mele cand vin de la beute si urc in 4 labutze scara mea de bloc frumos de Manajtur - sunt chiar eu. Sh-am fost lepjuit.\r\n\r\nCe as face eu din administratia pudica locala.\r\n\r\n1. Io, Groparu, deci persoana dintre urechile mele, as pune limita de centimetri de zambet d-asta: :( - adeca colturile gurii care coboara mai mult de 2 milimetri in jos sa fie penalizate cu: incalecat magar pe de-a-ndoaselea, tavalit in catran si fulgi, sau tintuire la stalpu\' infamiei in penitenciarul de la Gherla - bine-nteles, fara pic de zdreantza pe nevolnicul sau trup de femeie.\r\n\r\n2. Io, Groparu, deci persoana dintre putulica mea sh popoul meu impenetrabil, as dori ca fiecare depasire de limita de decibeli cauzata de o rastire a vreunei ghibolitze din spatele ghiseului catre onor <em>tax payer</em> sa fie amendata cu introdus una bucata ghibolitza intr-un clopot de arama, sh jbenguit clopot 4 minute non-stop.\r\n\r\n3. Io, Groparu, deci persoana de supt calota mea craniana, ar dori ca ghiseele sa nu mai fie la inaltimea de 40 centimetri, ca sa te oblige pe tine, mascul falnic, cand vorbesti cu ghibolitza, sa te apleci de spate, cocosandu-te si umilindu-te, mai ales ca daca te intorci invers si le arati curu in loc sa te apleci cu fatza catre ele astea cheama jandarmu\' public. Care are IQ mai minus chiar ca tine si ii place sa bruscheze intelectoalii.\r\n\r\n4. Io, Groparu, omu\' ale carui bratze ma scarpina in fundulica sh imi place (nu mai folosesc hartie igienica din clasa a 9-a) si-ar dori ca in administratia pudica locala sa nu mai puta in halu asta: io nu am intrat veci intr-un birou administrat public in care sa nu duhneasca a dusumele umede sh a haine ude de pipi de cutzu lasate in pivnitza.\r\n\r\n5. Io, Groparu, fiintza din spatele ochilor mei foarte apropiati de nas, as dori ca toate afisele din administratia publica locala sa fie in continuare redactate de cei mai sub-intelectoali membriii, c-a s-a avem ce poze s-a punem pe blog.\r\n\r\n6. Deci eu, Groparu, anti-homo-sapiensul, imi doresc ca rampele pentru persoanele cu dizabilitati, (sau, cum li se mai spune, handicapati) sa nu fie facute numa la intrare! ci si la iesire.  Si fara sonerie de asistentza asezata la 2 metri inaltime, ca daca se puteau ridica la inaltimea aia nu le mai trebia asistentza! Buoilor.\r\n\r\n7. Deci eu, omu\' caruia ii place sa urce in 4 labe scarile pana la mine la etaju 4/4 (odata am gasit 10 bani pe scari, si a doua zi mi-am pierdut husa de la camera cu 4 acumulatori inauntru!), asa, si-ar dori ca sa le creasca, in puii mei, salariile la oamenii astia, ca sa fie mai motivati in ceia ce fac, sa atraga tinere (hehe!), sa li se faca caldura cand e frig sh rece cand e cald afara, sa ia pauze de masa pe rand, nu tot motherfucking birou\' deodata, sa se internetizeze, sa poti discuta cu ei ca si cu un account manager (unu care sa stie totul despre contul tau si sa iti dea un amarat de e-mail cand trebuie facut ceva), sa poti vira si administra platile si contul pe Internet, sa faca dush regulat, sa poarte decolteu daca nu sunt masculi, SI SA INTRODUCA DREQ SISTEMU\' ALA CU BONURI DE PROGRAMARE LA GHISEU!!! A, si sa posteze pe Internet loacele unde se construiesc blocuri noi, sa stim unde sa cautam si sa scapam, noi ejtia, tinerii dornici de rate la banci hulpave, de hienele alea numite agentii imobiliare.\r\n\r\n<a href=\"http://www.arhiblog.com/tag-catastif-si-administratia-locala\" target=\"_blank\"><em>Arhi </em></a><em>a dat la </em><a href=\"http://visurat.ro/\" target=\"_blank\"><em>Visurat</em></a><em>, </em><a href=\"http://piticu.ro/\" target=\"_blank\"><em>Piticu</em></a><em>, </em><a href=\"http://fulgerica.com/\" target=\"_blank\"><em>Bullets</em></a><em>, </em><a href=\"http://cristiroman.ro/\" target=\"_blank\"><em>Cristi Roman,</em></a><em> </em><a href=\"http://tolo.ro/\" target=\"_blank\"><em>Tolo </em></a><em>si <a href=\"http://www.andreicrivat.ro\" target=\"_blank\">Andrei</a>. Crivat, la rÃ¢ndul d-mniei sale, o dat la: </em><a href=\"http://idei-locale.blogspot.com/index.html\" target=\"_blank\"><em>RÄƒzvan Antonescu</em></a><em>, </em><a href=\"http://www.groparu.ro//\" target=\"_blank\"><em>Groparu</em></a><em>, </em><a href=\"http://www.sergiubiris.ro/\" target=\"_blank\"><em>Sergiu BiriÈ™</em></a><em>, </em><a href=\"http://www.cassini.ro/\" target=\"_blank\"><em>Radu BeligÄƒr</em></a><em>, </em><a href=\"http://cpaun.blogspot.com/\" target=\"_blank\"><em>Ciprian PÄƒun</em></a><em>, </em><a href=\"http://nastase.wordpress.com/\" target=\"_blank\"><em>Adrian NÄƒstase</em></a><em> È™i </em><a href=\"http://www.fenomental.com/\" target=\"_blank\"><em>Alexandru Bejan</em></a><em>. </em>Io- persoana din fatza acestui blog la ora la care scriu - ii lepjuiesc pe <a href=\"http://www.whitewolf.1gb.at/\" target=\"_blank\">Lupulainu\' Balan</a>, bine-ntzales - pe <a href=\"http://www.doingtheartwork.com\" target=\"_blank\">Mishonca</a>, <a href=\"http://rottencabbage.haipa.ro\" target=\"_blank\">Varza Putreda</a>, <a href=\"http://www.avionaru.ro\">Avionatu</a>, <a href=\"http://fluture.blogs.com\" target=\"_blank\">Flutelele</a>, <a href=\"http://milecarpenisan.wordpress.com\" target=\"_blank\">Millllle</a>, <a href=\"http://aberatiuni.blogspot.com/\" target=\"_blank\">Aberatiunei</a>, si <a href=\"http://giconet.blogspot.com/\" target=\"_blank\">Ghitza Ghitzalau</a>. Preluati textul asta de final cu toate hyperlinkurile, sh dati mai departe leapja la 7 nefericiti + 1! C-asa vrea <a href=\"http://www.andreicrivat.ro\" target=\"_blank\">Crivatzu</a>. <a href=\"http://aniakhaki.blogspot.com/\" target=\"_blank\">Ania Khaki</a>, sa nu crezi c-ai scapat! Ca sh pe tine te, ca sa zic asa, insarcinez.<em>\r\n</em>','AdministraÅ£ia pudicÄƒ localÄƒ si un Gropar global',0,'','publish','open','open','','administratia-pudica-locala-si-un-gropar-global','','\nhttp://www.arhiblog.com/tag-catastif-si-administratia-locala','2007-10-01 18:52:30','2007-10-01 16:52:30','',0,'http://www.groparu.ro/?p=662',0,'post','',10),(663,1,'2007-09-27 14:37:16','2007-09-27 12:37:16','Urc sus (n-am cum urca jos, ca m-am interesat) cu cutia de paste cu carne productie proprie (nu made in China) si cu CaÅ£avencu supt braÅ£ul meu vÃ¢njos. IncÄƒlzesc pastele la cuptioru\' cooperativei, insfac o furculitza de material plastic sh ma apuc de citit sh de carat la gura. Gura - asta stie cel mai bine - preia cu limba si buzele pastele albe cu carne sh cabanos sh le mesteca <em>like there\'s no tomorrow</em>.\r\n\r\nLanga mine, un coleg vadit deranjat ca nu-i dau atentie, ma intreaba fumand:\r\n\r\n- Tu tot timpul citesti ziarul cand mananci?\r\n- Depinde de anturaj, zic eu. Depinde de anturaj.\r\n\r\nNu s-o suparat, ca o rÃ¢s.','Eu, deci la masa',0,'','publish','open','open','','eu-deci-la-masa','','','2007-09-27 14:37:16','2007-09-27 12:37:16','',0,'http://www.groparu.ro/?p=663',0,'post','',6),(664,1,'2007-09-27 15:44:58','2007-09-27 13:44:58','Cand am migrat de pe Yahoo 360 pe .ro, am dat copy-paste la toate aberatiunile mele reale sau ireale de acolo. Daca am pus-o si pe asta si va supun aceleiasi lecturi antrenanto-captivanto-spumoaso-savuroaso din nou, imi cer scuze, mi-i lene sa caut. Daca nu atz mai cetit-o, cetiti-o acum! Finca este vorba despre nimeni altul decat\r\n\r\n<strong>Florinel</strong>\r\n\r\n\"Despre Florinel ce sa-ti spun/Ce cuvinte sa adun/Ca-n adevarul lor sa creeeeeezi...\"\r\n\r\nNu pot sa dau prea multe detalii despre el, ca unii il mai si stie p-asta.\r\n\r\nFlorinel (zis Benone) e un haiduc. In sensul rau al cuvintului. Bea, fumeaza, fute, inseala, minte, fura, ia bani imprumutzi si nu-i mai da, injura de sfinti, se da la prietenele prietenilor pe fatza - deci cam ca mine. Desi la o scara mai redusa.\r\n\r\nEram in caminu\' 14 Hasdeu, si ma trezesc odata cu un telefon de la el. Ci fa mah, ui bine, tu, cum mai esti, is in Cluj. IN CLUJ? Pai musai sa ne vedem. Ce faci acilea? Ui, am vint cu socru-mio sa-l opereze. Da\' ci-are? Nada grav, cieva polipi or something, dreq stie ce organ o mai fi sh-asta, ca cica e in plus si traba scos. Hai sa ne vedem. Gata, zice, vezi ca is intr-o Dacie alba parcata ezac in fata intrarii spitalului, pe Clinicilor (sau clinciurilor).\r\n\r\nMa duc, ma scobor, vb cu el, etc. Plec acasa la camin.\r\n\r\nMa suna dupa doua saptamani: ba, zice, am pizdit-o, zice. Rau. Rau-rau!! Da\' rau-rau-rau!!! Zice. Si numa\' tu ma poti ajuta, zice. Dic: Ba pula, io bani imprumutzi nu-ti mai dau! Da\' taci ma fraiere, zice el, ca nu d-aia te sun. Inregistreaza ce-am patit, zice el. Inregistrez, zic io. Ce pula mea era sa zic altceva?\r\n\r\nFlorinel venise cu socru-so sa-l opereze de polipi (oare am mai zis asta?). El, socru-so, si cumnatu-so. Operatie de rutina, nu de ruina. Fiind in Romania, daca nu ma insel, tzara in care trebe sa dai shpaga si ca sa te ingropi, batrinocu\' sh-o pregatit o mica atentie, \"ceva\", acolo, sa fie, pt dom\' doftor. Sa nu-i tremure mana prea tare la operatie, ca era cam stafidit omu\' in halat alb, mai avea o beshina si se curatza. Si - din pensia amarului sau - prepara omu 2 milioane de lei, ii baga-n pizda masii in plik, si le zice la astia: Ba, fitz atentz la mine-aci! Io n-o sa pot vorbi dupa operatie, ca ma opereaza la polipi, dreq stie ce organ o mai fi sh-asta, ca cica e in plus si traba scos. Dupa operatie o sa vie dom\' profesor (n.n. - vraciu\') sh io o sa fiu mahmur. Asha ca ii datz voi pliku\', sa hie omu multumit, sa ma trimeata acasa tot azi! Ne-am intzales? Da\' ii dai tu malaiu\', zice cata Florin, ca daca ii las lu cumnatu-to asta ii be. Vai, tata socrule, cum, n-ai incredere in noi, zice Florinel, cu ochi sclipitori. Du-te matale de-ti scoate polipii, ca banii sunt in sigurantza.\r\n\r\nZis si facut, omu paseste catre incaperea de unde urma sa iasa mai sarac de polipi decat intrase, operatia reuseste, numa ca bolnavu\' nu mai poate vorbi deloc o vreme - numa cu mainile; si astia stau ce stau sa se faca ora 5, cand dom\' profesor o promis ca vine si verifica starea agregatului, sa-l trimita acasa la el. Si astia stau sa se faca ora cinci. Si se face ora 6, 7, 8, 9. Si profu\' - canci.\r\n\r\nSi-atunci, ce le trece lor razant prin idei? Un gand! Ba, zice Florinel catre cumnatu-so, ce pula mea. Asta isi bate joc de noi. Sa ma f. Hai sa nu-i mai dam 2 milioane! Ii dam numa un mileon, si unu il impartim cumnatzeshte intre noi, sa avem si noi banuti de o tigara, de-o maslina. Da-l in ma-sa, ca oricum are bani, si tac-tu nu poate vorbi cu el dupa operatie! Asa. Tine, si da. Boooon. Ba, da\' oare ce are asta in dulapele astea? (astia il asteptau pe doc in cabinet la el). Uau! ce carti de medicina groase, cu desene si coperti legate,Â  si - pun pariu - scumpe. Uau. Ba. Hai sa il futem, ca si el ne fute, ne face sa dormim in masina o noapte. Hai ia tu cate poti duce, si iau si eu, si le ducem la masina, ca s-a bucura niscai anticar de ele, sarmanu\'! Si mai facem si bani de-o votculitza mica (ati opservat ca tot timpul cand se face o manarie, se face pentru \"o cafea, un coniac, o bere\"?)\r\n\r\nBooooon. Sh baietii cara vreo doua plase pline cu carti in masina, si se pregatesc confortabil sa doarma in Dacie, nu inainte de a-i spune Florinel lu cumnatu-so cum i-o mai tras-o lu soru-sa, in ce pozitii, de cate ori si in ce gauri, si cat de greu se pot fute ei cand comnatu\' doarme langa ei si sforaie, ca ii pufneste rasu si ii moare pula. Boooon.\r\n\r\nDimineatza, se scoala baietii mei dis-de, se indreapta cu fatza carpita de somn catre salonu\' unde era cazat nenea cu polipii in alta camera, si au placuta surpriza de a-l vedea pe tata socru in picioare, vorbind pe soptite cu doftoru\', ca mai mult nu putea, decat <em>sotto voce</em>. Cand ii vede, se bucura, ce era sa faca mosu\'! Nu mai avea polipi, da ii avea p-aia. Cred ca tot mai bine ar fi fost cu polipi, da\' fara aia. Si mere catre ei, si le zice perplecshilor: Ba, zice, ia da-ncoa plicu\'! si mai repeta de vreo trei ori, ca astia nu credeau ca-si aud urekilor. Impietrit de frica, Florinel al meu isi indreapta mana spre buzunaru de la piept, scoate plicu\', si mosu il insfaca ca un uliu. Il flutura triumfator pe la nasu doftorului, si ii gajaie din gat: dom doftor, zice, uitati aici, o mica atentie, bla-bla. Nu, nu trebuie zice doftorul, cu ochi sclipitori. Ba, nu, dom\' doftor, zice mosu, e o nimica toata, <strong>2 milioane e bine</strong>? Cred ca Florinel arata ca un pastel de Picasso. Da, da, e bine, zice doftoru, preluand mica avere si depunand-o cu grija printre celelalte plicuri ale halatului sau.\r\n\r\nNu are rost sa va spun ca, dupa intrevedere, Florinel si cumnatu-su or batut recordul mondial de viteza la coborit treptzile spitalului cu moshneag fara polipi. Si cred ca nu a fost Dacie mai rapida la iesit din Cluj ca Dacia lor, acum mai usoara cu o familie de polipi.\r\nDa ba pula, zice Florinel in continuare, moshu s-o dilit! Zice. Vrea sa vina la Cluj sa il vada doftoru\', sa ii dea nush ce analize o facut el la iesirea din spital, si alea i le trebe la medicu\' de famelie! Si ba, zice, abia il pot tine-n frau! Ba, zice, te rog ca pe profet: zice, ba, te implor meri tu acolo si ia analizele pulii, ca, zice, de vine asta si vorbeste cu doftoru, m-am fript in fericire! Zi-le dreq ca esti varu-mio, sau nepotu-so, sau ce vrei tu, zi-le ca esti lieutenant-commander Worf, din partea mea, numa PUNE DREQ MANA PE ANALIZELE ALEA, CA DACA NU MA BELESHTE ASTA! Ba, zic. Daca nu e vorba de bani, te ajut cu draga inima, zic.\r\n\r\nSi uite asa mere Groparu\' nostru la spital, ca proaspat nepot a lu\' Zgabeatza Iftode. Si il intreb pe Stelea... aaa... pe portar: ba shefu\', zic. De unde pot ridica analizele la polipi? La camera trei, zice el. Booon, zic eu. Sanatate. Si ma indrept catre camera trei. Si bubui in usha. Nu se aude nimic, si dau buzna inauntru.\r\n\r\nAmu, astia care or dat bacu\' din Rascoala lu Liviu Rebreanu, isi amintesc cu sigurantza scena in care Petre da buzna si ii trage un viol lu\' Nadina, care era imbracata in pielea si parul ei, si nimic mai mult. Noa. In camera trei in care tocma am dat buzna, camera care - am aflat atunci, ad-hoc - era si vestiar, se rasfatza o dragutza de sora medicala in tzitzele goale, care se skimba, presupun. Faine tzitze! Faine. Stil pere, usor ridicati in sus, usor inegali, cu o alunita pe cel stang, cu pielea gainii ca era usor racoare in cabinet, si butonasele erau ridicate in sus, de puteai atarna camasi la uscat in ele. Si fara urme de plaja de sutien. Si clar ca am mormait ceva scuze cu o voce care nu era a mea, de parca io nu mai aveam polipi. Si dupa o secunda luuuunga de playboyit, fac 180 grade si ies.\r\n\r\nSi ma gandesc: Tiii, Florinele, bata-te! Furi, inseli, si amu fut si eu meciu\', ca mi-o ramas ochii lipiti in bustiera lu tipesa aia! Pula analize, imi zic. Infunzi pushcaria. Si stau un minut afara, cu ochii sticlosi. Si vine o d-ra si da sa intre in camara trei. D-ra scumpa, zic io, un pic neobisnuit sa vad si sore medicale imbracate, zic, am de ridicat analizele lu Zgabeatza Iftode, va rog a binevoi sa. Da, sigur, zice ea, haideti inauntru. Multumesc, zic, ricaind de pe fundul oalei bruma de bun simtz pe care am mai avut-o, prefer sa astept afara.\r\n\r\nTanti a revenit, cu un zambet pe care se kinuia fara folos sa il ascunda de pe fatza si cu un set de analize in mana stanga. Florinele, ii zic, ai luat-o-n mana, prietene. Asta te costa o gramada de fiole de bere. Te-am scapat, ma pula.','Nu pot sa cred ca nu am pus-o si pe asta!',0,'','publish','open','open','','nu-pot-sa-cred-ca-nu-am-pus-o-si-pe-asta','','','2007-09-27 15:44:58','2007-09-27 13:44:58','',0,'http://www.groparu.ro/?p=664',0,'post','',9),(665,1,'2007-09-28 11:15:39','2007-09-28 09:15:39','Ierarhia intr-o firma mare/multinationala : sefi - sefuti - fututi - rasfututi - pulimea.\r\n\r\nIo, la cooperativa, is rasfututu\' de pulime.\r\n\r\nScuze pentru limbaj.','Ierarhia dintr-o firma',0,'','publish','open','open','','ierarhis-dintr-o-firma','','','2007-09-28 12:09:27','2007-09-28 10:09:27','',0,'http://www.groparu.ro/?p=665',0,'post','',16),(666,1,'2007-09-28 16:01:22','2007-09-28 14:01:22','GÃ¢ndu 1: succesul unei casatorii perfecte e sa ai o nunta super najpa - ca sa te faca sa exclami: I ain\'t never ever gonna do this shit again!\r\n\r\nGÃ¢ndu 2: nimeni nu ar trebui sa isi doreasca sa aiba o putulica super mare, finca vei depune mult mai mult efort ca sa o trezesti!\r\n\r\nGÃ¢ndu 3: E super Ok ca lumea sa te puna pe un soclu, sa depuna coroane de flori la picioarele tale sh sa planga din cauza de cat de meseriash esti tu; da\' trebe sa ai mare grija la porumbei, ca astia se pot caca lejer pe tine.','Ganduri de (aproape) weekend',0,'','publish','open','open','','ganduri-de-aproape-weekend','','','2007-09-28 16:21:50','2007-09-28 14:21:50','',0,'http://www.groparu.ro/?p=666',0,'post','',12),(667,1,'2007-09-30 14:06:00','2007-09-30 12:06:00','...nu ma pot opri sa ma intreb: oare Consantinescu o lesinat la inscaunarea patriarhului de ciuda ca nu o fost el numit patriarh?\r\n\r\nHmmmm...','Finca ieri am fost la pezcuit...',0,'','publish','open','open','','finca-ieri-am-fost-la-pezcuit','','','2007-09-30 14:06:00','2007-09-30 12:06:00','',0,'http://www.groparu.ro/?p=667',0,'post','',8),(668,1,'2007-10-02 10:57:39','2007-10-02 08:57:39','Adi, voievodul spiritualitatii noastre,\r\nCu idei diafane ca pasari maiastre,\r\nPraslea cel voinic al intregului neam,\r\nOmul cu p*** cat un salam,\r\nCu falnica gandire profunda,\r\nCu spirit viu, minte latrÃ¢ndÄƒ,\r\nUn creier urias venind catre noi,\r\nOmul cu oÅ£el in ambii coi,\r\nCel mai potent intelectual\r\nDaca eram in \'50, era trimis la Canal,\r\nPe care-l plagiaza Plesu, Liiceanu, Eliade\r\nSi nume grele de filozofi din apuse Elade,\r\nOmul care se bate cu Einstein pe burtÄƒ,\r\nOmul care pentru mine e telemea de Sibiu, cascaval si urda,\r\nOmul pentru care premiul Nobel nu e de ajuns,\r\nOmul care mitropolit trebuia uns,\r\nOmul care il va prinde pe Bin Laden,\r\nE omul care ne va duce inapoi in Eden\r\nReparand un rau facut de Eva\r\nVietii noastre redandu-i seva!\r\nAcest om astÄƒzi serbeazÄƒ\r\nViaÅ£a lui ce de mult dureazÄƒ;\r\nAcestui om eu ii doresc\r\nLa Multi Ani, si izbavirea neamului romÃ¢nesc!\r\n\r\nE, mah, La Multi-Multi-Multi Ani!','Azi - azi, e ziua lui, Adi Sicretu\'',0,'','publish','open','open','','azi-azi-e-ziua-lui-adi-sicretu','','','2007-10-02 10:57:39','2007-10-02 08:57:39','',0,'http://www.groparu.ro/?p=668',0,'post','',4),(669,1,'2007-10-02 11:24:40','2007-10-02 09:24:40','Deci, io cand am cetit http://www.cotidianul.ro/index.php?id=14459&amp;art=36517&amp;cHash=88af0106d4\r\n\r\nam zis: e clar, o mierlit-o <a href=\"http://oedip.blogspot.com/\" target=\"_blank\">Oedip</a>! Pana cand am aflat ca, de fapt, o mierlise un Oedip, da\', din fericire pentru noi, nu ala cu ma-sa, care e OK sh bea bere nemtzeasca prin berarii unde nu mai ai voie sa fumezi, deci sigur fumeaza la corturile de la Oktoberfest-uri.\r\n\r\nDeci: Oedipus is dead, long live Oedipus!','Am rasuflat usurat',0,'','publish','open','open','','am-rasuflat-usurat','','','2007-10-02 11:24:40','2007-10-02 09:24:40','',0,'http://www.groparu.ro/?p=669',0,'post','',3),(670,1,'2007-10-02 14:37:46','2007-10-02 12:37:46','Azi - zi de rate. Deci din fix tranta buna dispozitie pe capu\' meu, ca in asemenea zile imi vine sa ma imbrac in dinamita sh sa ii detonez pe toti bankerii aia cumsecade cu fetze de poker imbracate la costum, care de fapt n-au nici o vina, finca dobanzile <em>vin de la Bucuresti si nu se pot negocia.</em>\r\n\r\nSi ma duc sa schimb un purcoi de lei pe o mana de euroi, ca sa platesc la bancheri, sa aibe sh ei saracii cu ce-si plati conceiile in Antalia. Sh merg la schimbu\' meu valutar preferat, ala dintre Diesel sh libraria Oedip... aaaa, Orfeu. Si iau bancnotele de euro, sh ma car la banca.\r\n\r\nLa banca - GRRRRRRRR!!!! Descopar o bancnota rupta. Rupta rau.\r\n\r\nZic: sa vezi ce muie va loa amu cineva, ori io (cel mai sigur!), ori tanti aia de la ghiseu, ca fac un tarabontz, ghe numa! Sh imi pun fatza mea de Orc pe mine, sh ma reped inapoi.\r\n\r\nIntru, si zic:\r\n\r\n- Domnisoara!\r\n- ?\r\n- Domnisoara, mi-ati dat o bancnota rupta!\r\n\r\nSi ii intind nota terfelita.\r\n\r\n- Oioioi, zice domnisoara, razand de mine.\r\n\r\nIn secunda urmatoare imi schimonosesc trasaturile ca sa dea cat mai rau pe sticla, ma pregatesc sa scot pompa de la bicicleta sa o amenintz cu ea ca o umflu ca pe o broasca sh ii dau drumu\' pe Somesu\' Mic, sa ii stropshesc ranjetu\' de sticla blindata, sa ii bag tabela cu cursu\' valutar in cur (sau sa gresesc cativa centimetri si sa ma asigur ca nu va darui deloc urmasi patriei mele cu munti sh vai), sa chem Protectia Consumatorului ca sa rÃ¢da si aia de mine cum radeam noi de colegu nostru gras din clasa a II-a, sa imi infasor parul ei pe bratul meu drept, sa ii scot limba sh sa i-o bag in fundulica, sa ii beau ochii, sa ii infig aratatoru\' meu in urechea ei sh sa ii las sa ii curga materia cenusie prin trompa lui Eustache...\r\n\r\nN-am apucat. Domnisoara ia bancnota, imi da alta perfecta in schimb sh imi zambeste.\r\n\r\nAsa ca mi-am pus pe fatza chipul meu de elf sh m-am carat. Nu inainte sa ii suier un \"Multumesc frumoooos!\" respectuos.','Ce n-am patit azi',0,'','publish','open','open','','ce-n-am-patit-azi','','','2007-10-02 14:37:46','2007-10-02 12:37:46','',0,'http://www.groparu.ro/?p=670',0,'post','',8),(671,1,'2007-10-03 16:19:27','2007-10-03 14:19:27','Finca deja stau in Cluj de 10 ani de zile, bashca cateva (mai multe) iubiri consumate sau neconsumate inca, basca hectolitri de bere bauti in cele mai dubioase birturi, si ca sa nu mai raman repetent sh anu asta, mai ales ca detin ceva metri patrati in frumosul cartier muncitoresc Manastur al Clujului, m-am hotarat sa imi skimb buletinu\' pe Cluj. Sa ma fac, din capitalist (cultural european sibian bulan) in provincial (clujean).\r\n\r\nAseaaaa.\r\n\r\nLa Politie ti se cer tot felu de acte, care mai de care mai scoase din povestea lui Ionica cel Prost sau Povestea P*lii: adeverintza ca nu ai catel, ca catzelu\' nu are purici, locul de munca al fostului proprietar, analizele lui medicale la zi si adeverintza cu tratamentu\' sÄƒu anti-sifilis, copie dupa cartea lui de munca, poza care sa ateste ca are toti lindenii in cap etc.\r\n\r\nLa Politie, programul de preluare a actelor dureaza 4 ore.\r\n\r\nCand merge Groparu de 3 ori in 3 zile sa depuna actele, Politia Romana are grija ca in fatza ghiseelor sa fie cea mai mare coada posibila.\r\n\r\nCand Groparu isi ia inima lui neinfricata de leu greu in dinti si se pune la o coada intr-o dimineatza (daca ma gandesc mai bine, era chiar azi-dimineatza), coada deja atinsese cote paroxistice. Lumea - disciplinata cum erau animalele care se urcau in Arca lui taica Noe.\r\n\r\nLa Politie se strigÄƒ cu glas de politruc neshte nume de piloÅŸi. PiloÅŸii, burdushiti de plase din care se intrezaresc pachete de cafea Jacobs sh etichete de Johnnie Plimbaretzu\', se cocoseaza, umili, in fatza afiselor cu \"Denuntza spaga! Suna la 0800800800, numar apelabil NUMAI din reteaua Romtelecom\" si depun ploconu\' la picioarele unor persoane de supt chipie, dupa care dispar impreuna sa-si faca te miri ce acte sh documente.\r\n\r\nLa coada ai toata ocazia sa te imprietenesti cu pensionari care dau apartamente in chirie; ii recunosti usor - figuri acre supt palarii sau batice, cu negi parosi pe fatza, in general genul de oameni care desi te-au asigurat un an intreg ca chiria e batuta in cuie, iti cresc chiria tocmai in septembrie, cand vin studentii (\"O scazut euro! o crescut euro!!!\").\r\n\r\nCa un facut, dupa o ora de stat la coada (te-ai trezit si la 7 ca sa ajungi acolo la 8), coada se dizolva. In spatele tau mai numeri numa\' 2 persoane - o batranica care pute a pipi acrit sh o tinerica slabutza si speriata din spatele unor ochelari grosi, care strange la piept o mapa de acte, ca Electra urna cu cenusha fratelui ei Oreste (sigur nu de personajele astea e vorba, da\' va datz voi seama de cine vorbesc).\r\n\r\nTanti de la ghiseu - sa mor io, am crezut ca imi inghit proteza! - foarte amabila. Dar atata numa\' ca vorbind din spatele geamului termopan care o desparte de VULG nu se intelege nimic; si atunci te cocosezi ca in fatza unui patriarh Daniel (fost securist) ca sa o auzi mai bine.\r\n\r\nCand mergi sa faci poza, o intrebi pe madama: arat prezentabil cat de cat? (eram curios daca mi se dezumflasera cearcanele de la beutura). Daaa, zice tanti, la varsta dumneavoastra nu aveti cum sa nu aratati decat bine! Mai, sa fie, zic io, s-o rasturnat butoiu\' cu amabilitate tocma\' aci, in politia clujeana? Si dumneavoastra aratati foarte bine pentru varsta dumneavoastra, zic eu, dornic sa ii intorc complimentu\', vreti sa ma dezbrac aici?\r\n\r\nAsa si-a depus Groparu dosarul pentru schimbarea buletinului, intr-o zi apsolut identica cu celelalte zile de Octombrie, atata numa\' ca - in ziua de azi - mi-am schimbat buletinu\'. Dar cred ca asta v-am mai zis-o. De fapt, v-am mai scris-o.','Va fi totul bine intr-o zi! Dar nu va dura decat o singura zi',0,'','publish','open','open','','va-fi-totul-bine-intr-o-zi-dar-nu-va-dura-decat-o-singura-zi','','','2007-10-03 16:20:53','2007-10-03 14:20:53','',0,'http://www.groparu.ro/?p=671',0,'post','',19),(672,1,'2007-10-04 15:01:36','2007-10-04 13:01:36','Dap.\r\n\r\nDupa evenimentul in care am lovit cu putere cada de baie de capu\' meu tzestos, azi am mai facut una. Destul de groasa.\r\n\r\nDeci: pedalam si eu voios catre serviciu, dis-de-dimineatza, fericit ca viatza este, totusi, mai buna ca in Republica Moldova. Aveam sa ma caiesc amarnic cateva secunde mai tarziu. Mai ales ca mancasem mujdei la micu-dejun.\r\n\r\nPedaland, trec pe verde, si ajung la o coloana de masini stationara. Fac un tur cu ochii imprejur sa vaz unde pot sa-mi infig bitzicÄƒlu\', sa nu stau dupÄƒ prostii aia care si-or cumparat masini - si vad ca n-am unde. Mai pedalez de 5 ori, ma Ã®ncadrez in spatele unei Octavii, si cand vÄƒd ca masina stationa, nu mergea, dau sa pun frana.\r\n\r\nLa o roata numai.\r\n\r\nFrana nu prinde, finca aveam vitezÄƒ.\r\n\r\nIn derapaj, izbesc cu putere biÅ£a cu ghidonu\' ei, de fapt, de porbagaju\' Octaviei.\r\n\r\nBUUUUUM!!!!! O facut ca la Nagasaki.\r\n\r\nNenea pune avariile, iese afara:\r\n\r\n- Ce pula mea nu te uiti???\r\n- Ce pula mea sa fac daca nu mi-o prins frana??? zic io, mirosind puternic a usturoi.\r\n\r\nSi ma bufneste rasu\'. Totusi, ma pusesem in garda, sa nu ii vina la ala kef sa isi rupa pumnii in dintii mei, la care chiar tin, finca mi-s dragi.\r\n\r\n- Esti OK? Ai patit ceva? ma intreaba.\r\n- Is OK, tu esti OK?  Nu te doare nimic, nu? intreb, obraznic, mirosind puternic a usturoi. Nici macar nu mustaceste.\r\n- De ce nu ai grija cum mergi?\r\n- E primu\' incident pe care-l am cu bitza, in puii mei! Pana amu nici macar un claxon nu am primit. Ai CASCO? zic io, mirosind puternic a usturoi.\r\n- Nu, zice el, am decÃ¢t deloc.\r\n- Ce coincidentza! zic io. Nici eu nu am pe bitza, zic io, mirosind puternic a usturoi.\r\n- Hai sa vedem ce s-o stricat, zice el.\r\n\r\nSi ne uitam.\r\n\r\nUn fleac.\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/10/dsc00129.JPG\" title=\"dsc00129.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/10/dsc00129.thumbnail.JPG\" alt=\"dsc00129.JPG\" /></a>\r\n\r\n(Cand am facut poza la accident, omu\' o vrut sa intre si el in poza, cu un zambet pe fatza, ca de vanator langa ursul ucis; l-am potolit rapid).\r\n\r\n- Da-mi, zice, telefonu\' tau. Si buletinu\'.\r\n- Haha, ma ia pe mine un ras nervos, din pula! Da-mi tu numaru\' sa iti dau bip, da\' buletinu\' n-am de unde sa ti-l dau, e la Politie, l-am dat sa imi fac adresa pe Cluj, zic io, mirosind puternic a usturoi.\r\n- Ai un act, ceva? zice el.\r\n- Am, zic io, mirosind puternic a usturoi, am un <strong>bon de masa</strong> scris! si scot bonu\' de masa, si asta isi noteaza, constiincios, numele si prenumele (Groparu Nemernic, adica), firma la care lucrez, ii explic cum sa ajunga la sediu, daca va fi nevoie, si dam noroc. Ramane sa ma sune la 11:30.\r\n\r\nMa suna: hai sa ne vedem la Politie! Ma duc inarmat cu prekinu meu <a href=\"http://www.andreicrivat.ro\" target=\"_blank\">Crivatz, Andrei Crivatz</a>. Politaiu\' se uita la mine luuuung: zice \"Tu ai accidentat mortal o Skoda Octavia? Cu un bitziclu?\" \"Da!\", zbier io, spashit. Langa noi mai era lume, care o belit ochii, si unii or inceput chiar sa zambeasca, desi aveau capu\' bandajat.\r\n\r\n- Te doare ceva? Te-ai accidentat rau? zice Garcea.\r\n- Nu, mah, zic, stai flexat. Pe sofer nu-l intrebati? zic io, mirosind puternic a usturoi.\r\n\r\nNush cum, da\' nimeni nu gusta bancu\' asta.\r\n\r\n- Meretz la celalalt sediu, sa va faca constatarea.\r\n\r\nLa celalalt sediu, iara: la declaratie, am lasat loc liber la sectiunea cu \"autoturism implicat in accident\", si scriu: Bicicleta proprietate personala. Nu uit sa mentionez, la descrierea accientului, ca soferul masinii nu a patit nimic, e navatamat.\r\n\r\nAsa.\r\n\r\nLa Politie te mai pune sa faci un desen in care sa desenezi harta accidentului. Am desenat o masina cu o biciclÄƒ mai mare ca masina infipta in ea, sh de pe bicicleta zambea, mare, insusi Groparu. M-am gandit daca sa imi fac si barba si palarie de tigan, da\' m-am oprit la timp.\r\nSoferu - un morosan super de treaba - ii zice la politziot ca n-are rost sa imi dea amenda, ca fac puncte aiurea, si raman si fara permis de conducere de bicicleta. Asa ca scap fara amenda. Mersi, mah!\r\n\r\nPlecam la Service autorizat sa isi refaca omu\' masina.\r\n\r\nDe aici, postarea asta incepe sa isi piarda hazu\'. Reparatia costa 13 milioane. Si dureaza o saptamana. Plus ca numa peste 2 saptamani au loc la servis sa ii iese la nenea masina. Plus ca daca ii tine masina in servis o saptamana intreaga, as face bine sa ii si inkiriez o masina de la un rent-a-car. Si costa atata finca trebe scos porbagaju\', bara de protectie, futute de-amiaza, lingusite, masate, reconditionate, revopsite, dracu-lacu.\r\n\r\nCercetarile continua.\r\n\r\nPodcastul, transmis laiv pe <a href=\"http://www.radiotransilvania.eu\" target=\"_blank\">Radio Transilvania</a>, este <a href=\"http://www.trilulilu.ro/Groparu/9dfb0fddc346fd\" target=\"_blank\">acilea</a>. Icnorati balbaielile mele.\r\n\r\nPS: Asta e nume pentru mine si Doamne-Doamne, deci nu cititi: Draga Doamne-Doamne, ieri m-o sunat mama sa imi zica ca le trebe alea 4000 lei pe care mi i-o imprumutat in primavara, ca isi izoleaza blocu\'; am un card de credit de 6000 lei gol-golutz; am si vreo 40.000 euroi datorii la banci, cu rate mai mari ca un salariu mediu pe economie, in care intra si creditu\' loat ca sa-mi iau masina, masina pe care nu am loat-o finca nu am carnet inca, carnet pe care nu l-am loat inca finca nu am inceput scoala de soferi, scoala de soferi pe care nu am cum s-o fac, finca inca nu am buletin! plus ca am amu pe cap si cheltuielile legate de accidentu\' asta. Asa ca Doamne, daca vroiai sa faci pe cineva castigator la Loterie, fa-ma pe mine, acum! Da\' sa nu trebuiasca sa imi cumpar bilet, ca io nu cred in chestii din estea. Si Doamne multzam pentru soferu\' masinii, ca daca eram in locu lui l-as fi omorat pe Groparu de cat de bou poate sa fie. Oare am intrat in anu mortii lui Iorgovan?','Groparu a facut accident de bicicleta. Soferul a scapat nevatamat',0,'','publish','open','open','','groparu-a-facut-accident-de-bicicleta-soferul-a-scapat-nevatamat','','','2007-10-04 15:34:56','2007-10-04 13:34:56','',0,'http://www.groparu.ro/?p=672',0,'post','',27),(673,1,'2007-10-04 14:27:07','2007-10-04 12:27:07','','dsc00129.JPG',0,'','inherit','open','open','','dsc00129jpg','','','2007-10-04 14:27:07','2007-10-04 12:27:07','',-1191499765,'http://www.groparu.ro/wp-content/uploads/2007/10/dsc00129.JPG',0,'post','image/jpeg',0),(674,1,'2007-10-04 15:02:08','2007-10-04 13:02:08','','dsc00129.JPG',0,'','inherit','open','open','','dsc00129jpg-2','','','2007-10-04 15:02:08','2007-10-04 13:02:08','',672,'http://www.groparu.ro/wp-content/uploads/2007/10/dsc00129.JPG',0,'post','image/jpeg',0),(675,1,'2007-10-05 13:49:27','2007-10-05 11:49:27','Deci: se pare ca cea mai veche urma de Homo Sapiens s-o descoperit intr-o pestera din Romania, tzara mea cu munti sh vai. Este vorba de o mandibula, botezata IonicÄƒ.\r\n\r\n<strong>Concluzia 1</strong>: Stramosii nostri mai mult mancau sh beau decat gandeau (daca gandeau mai mult, se descoperea o calota craniana!).\r\n\r\nDeci: cum zicea PÃ¢rtzoagÄƒ, toate boboarele desenau la greu pe pesteri rupestre vanatori complicate, violuri de caprioare si bizoni, tot felu\'. Noi: sculptam hora de la Frumusica. Si Ganditorul (io-i zic Constipatul) de la Hamangia, cu tot cu fomeia lui grasa sh sexy.\r\n\r\n<strong>Concluzia 2</strong>: Stramosii nostri mai degraba dantuiau sh beau decat sa munceasca, vÃ¢neze sau violeze cÄƒprioare.\r\n\r\n<strong>Concluzia 3</strong>: Io cred ca Ganditorul (io-i zic Constipatul) de la Hamangia o fost la chef cu fomeile de la Frumusica, sh sculptorul l-o imortalizat Ã®n dimineaÅ£a de dupe, cÃ¢nd era mahmur.\r\n\r\nDeci: toata lumea stie fragmentul ala din cartea de istorie despre neamul tracilor, care e cel mai numeros din lume dupa cel al inzilor, pule maturi, cei mai viteji si mai drepti dintre traci fiind getii (cum zicea Iliescu: ZÄƒ dacs come from zÄƒ tracs!) etc. Ce NU scria in cartea de istoria era continuarea (citez din memoria mea de alcoolic: <em>la ei, trÃ¢ndÄƒveala e la mare preÅ£; iar cei care fac munca cÃ¢mpului sunt constant subiect de bajocurÄƒ. Ling vin la greu, si ca sa nu munceasca isi vÃ¢nd copiii ca sclavi.</em>\r\n\r\n<strong>Concluzia 4: </strong>Io cred ca fragmentu\' de mai sus se refera la familia mea.\r\n\r\nDeci: se zice ca cel mai vechi mesaj scris din istori omenirii sunt neshte tablitze descoperite la Tartaria, in judetul albanezilor. Au 7000 de ani vechime, sau 9000, sau ceva de genu\'. Nimeni pana acuma nu o reusit sa descifreze ce inseamna - probabil pentru ca sunt pline de greseli de ortografie sh nu contin suficient porn.\r\n\r\n<strong>Concluza 5</strong>: Suntem sh redusi dpdv intelectoal, si insuficient de predispusi la imperechere (a se citi impotenti).\r\n\r\nDeci: nij nu mai scriu nimic. Da\' m-am gandit la o leapsa.','Cateva consideratiuni despre istoria neamului romÃ¢nesc',0,'','publish','open','open','','cateva-consideratiuni-despre-istoria-neamului-romanesc','','','2007-10-05 13:49:27','2007-10-05 11:49:27','',0,'http://www.groparu.ro/?p=675',0,'post','',19),(676,1,'2007-10-07 15:18:25','2007-10-07 13:18:25','Facuta de mine. Insusi.\r\n\r\nStiu ca ati citit in tinerete Winnetou, Old Shatterhand sh Old Surehand, stiu ca v-ati jucat cu indieni si ati cetit viata lui Haiawatta zis si Hiawatta.\r\n\r\nStiu ca v-ati intrebat de ce cand sar americanii cu parasuta striga \"Geronimoooo!\", si ca cine-o fost Sitting Bull si cine i-o tras-o generalului Custer, la ora aceea cel mai tanar general din istoria Americii; si stiu ca stiti ca Apashii is mai tari decat Comanchii, desi amandoo triburile or dat nume de elicoptere americane de atac, care is destul de bengoase, mai bengoase chiar decat blogu\' meu, desi un mojnegel irakian o doborat unu cu o flinta din 1960 si drept recompensa o primit de la Saddam 24.000 parai, cu care si-o cumparat o noua nevasta, mai tanara (lol).\r\n\r\nDeci leapsa mea este: cum ati dori sa va cheme daca ati fi fost indian?\r\n\r\nNumele pe care-l aleg eu este - bine-nteles - Two-Lesbian-Dogs-Fucking, ca in bancu\' ala prost.\r\n\r\nLeapsa merge mai departe in ordinea blogrollului meu la <a href=\"http://www.andreicrivat.ro\" target=\"_blank\">Crivatz</a>, bine-nteles, <a href=\"http://nenea.wordpress.com\" target=\"_blank\">Cozmos</a>, bine-nteles, la <a href=\"http://www.512kbps.com\" target=\"_blank\">minte pe banda larga</a>, <a href=\"http://oedip.blogspot.com\" target=\"_blank\">Oedip</a>, da\' nu ala cu ma-sa, <a href=\"http://rottencabbage.haipa.ro\" target=\"_blank\">Varzaru</a>, si <a href=\"http://www.visurat.ro\" target=\"_blank\">Vis</a>, urat vis. Hai sa va vad cat de creativi suntetz, manca-v-ar mamica fiicei lu\' Pamela Anderson!\r\n\r\n<strong>UPDATE</strong>: Inspirat de cetitorii care au comentat primii, va lepshuiesc sh pe voi, astilantii care cetesc: bagatz numele voastre de indieni la commenturi sau pe bloagele voastre, ca sa stiu din ce trib facetz parte!!!!','Deci: leapsha',0,'','publish','open','open','','deci-leapsha','','','2007-10-07 17:48:53','2007-10-07 15:48:53','',0,'http://www.groparu.ro/?p=676',0,'post','',22),(677,1,'2007-10-08 14:18:12','2007-10-08 12:18:12','Si Gropar cu 21 de pule.\r\n\r\nIa uitat-va si voi ce am primit azi-dimineatza de la colegu\' care e proaspat revenit dintr-o delegatie unde a fost trimis de cooperativa, in exact tzara aia de-i zice Botswana.\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/10/dsc00150.JPG\" title=\"dsc00150.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/10/dsc00150.thumbnail.JPG\" alt=\"dsc00150.JPG\" /></a>\r\n\r\nAmu nush cat de coios oi fi io, da\' de pulos sa nu mai zica nimeni ca nu-z!!! S-aude???\r\n\r\n<strong>Update</strong>: Le-am pipait si mirosit, is reale, si ceea ce e si mai important - desi au aceeasi sursa - nu au nimic in comun cu cele <a href=\"http://www.doingtheartwork.com/?p=196#comments\" target=\"_blank\">21 de pule ale lui Mihaitza</a>.','Ciobanas cu 300 de oi',0,'','publish','open','open','','ciobanas-cu-300-de-oi','','\nhttp://www.doingtheartwork.com/?p=196#comments','2007-10-08 14:57:20','2007-10-08 12:57:20','',0,'http://www.groparu.ro/?p=677',0,'post','',10),(678,1,'2007-10-08 14:17:30','2007-10-08 12:17:30','','dsc00146.JPG',0,'','inherit','open','open','','dsc00146jpg','','','2007-10-08 14:17:30','2007-10-08 12:17:30','',-1191845559,'http://www.groparu.ro/wp-content/uploads/2007/10/dsc00146.JPG',0,'post','image/jpeg',0),(679,1,'2007-10-08 14:17:42','2007-10-08 12:17:42','','dsc00147.JPG',0,'','inherit','open','open','','dsc00147jpg','','','2007-10-08 14:17:42','2007-10-08 12:17:42','',-1191845559,'http://www.groparu.ro/wp-content/uploads/2007/10/dsc00147.JPG',0,'post','image/jpeg',0),(680,1,'2007-10-08 14:23:04','2007-10-08 12:23:04','','dsc00150.JPG',0,'','inherit','open','open','','dsc00150jpg','','','2007-10-08 14:23:04','2007-10-08 12:23:04','',677,'http://www.groparu.ro/wp-content/uploads/2007/10/dsc00150.JPG',0,'post','image/jpeg',0),(681,1,'2007-10-08 18:35:43','2007-10-08 16:35:43','','dsc01025.JPG',0,'','inherit','open','open','','dsc01025jpg','','','2007-10-08 18:35:43','2007-10-08 16:35:43','',646,'http://www.groparu.ro/wp-content/uploads/2007/10/dsc01025.JPG',0,'post','image/jpeg',0),(682,1,'2007-10-08 18:36:54','2007-10-08 16:36:54','','aviva.JPG',0,'','inherit','open','open','','avivajpg','','','2007-10-08 18:36:54','2007-10-08 16:36:54','',646,'http://www.groparu.ro/wp-content/uploads/2007/10/aviva.JPG',0,'post','image/jpeg',0),(683,1,'2007-10-09 09:41:00','2007-10-09 07:41:00','- Ba Gropare, io ma tot gandesc ce ai fi fost tu intr-un trib din Neolitic! zice unu\'.\r\n\r\nPana sa apuc sa le zic \"tatal copiilor vostri!\", se baga alt dajtept:\r\n\r\n- Masa de pranz...?\r\n\r\nMnoa...','Discutie la tigare',0,'','publish','open','open','','discutie-la-tigare','','','2007-10-09 09:45:50','2007-10-09 07:45:50','',0,'http://www.groparu.ro/?p=683',0,'post','',5),(684,1,'2007-10-09 11:38:12','2007-10-09 09:38:12','','dsc00153.JPG',0,'','inherit','open','open','','dsc00153jpg','','','2007-10-09 11:38:12','2007-10-09 09:38:12','',685,'http://www.groparu.ro/wp-content/uploads/2007/10/dsc00153.JPG',0,'post','image/jpeg',0),(685,1,'2007-10-09 11:41:03','2007-10-09 09:41:03','Asa arata indicatorul de evacuare in caz de incendiu INAINTE:\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/10/dsc00153.JPG\" title=\"dsc00153.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/10/dsc00153.JPG\" alt=\"dsc00153.JPG\" height=\"287\" width=\"382\" /></a>\r\n\r\nAsa arata indicatorul de evacuare in caz de incendiu DUPA:\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/10/dsc00152.JPG\" title=\"dsc00152.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/10/dsc00152.JPG\" alt=\"dsc00152.JPG\" height=\"505\" width=\"383\" /></a>\r\n\r\nDe mult vroiam sa fac asta!!!\r\n\r\nPS: poze facute, bine-nteles, cu telefonul meu, care e mai destept ca mine.','Ce am facut azi la coperativa',0,'','publish','open','open','','ce-am-facut-azi-la-coperativa','','','2007-10-09 11:41:03','2007-10-09 09:41:03','',0,'http://www.groparu.ro/?p=685',0,'post','',9),(686,1,'2007-10-09 11:39:03','2007-10-09 09:39:03','','dsc00153.JPG',0,'','inherit','open','open','','dsc00153jpg-2','','','2007-10-09 11:39:03','2007-10-09 09:39:03','',-1191922586,'http://www.groparu.ro/wp-content/uploads/2007/10/dsc00153.JPG',0,'post','image/jpeg',0),(687,1,'2007-10-09 11:39:54','2007-10-09 09:39:54','','dsc00152.JPG',0,'','inherit','open','open','','dsc00152jpg','','','2007-10-09 11:39:54','2007-10-09 09:39:54','',-1191922586,'http://www.groparu.ro/wp-content/uploads/2007/10/dsc00152.JPG',0,'post','image/jpeg',0),(688,1,'2007-10-10 21:30:33','2007-10-10 19:30:33','Da, cand eram student noi invatzam mai mult, nu aveam Internet, deci n-aveam de unde fura si plagia, asa ca trebia sa gandim, fetele erau mai aratoase (inca nu daduse boala-n ele cu fast fooduri care se depun pe soalde) dar nu se combinau cu mine chiar asa usor, finca eram tantalau si la prima intalnire ori flegmam pe strada, ori ma scarpinam in cur si cu aceleasi deÅŸte ma zgamaiam in nas si ea ma vedea, ori se combina cu mine crezÃ¢nd ca is cioban bogat de Sibiu si cand afla ca n-am oi, numa salam de Sibiu la discretie, ma parasea dezamagita combinandu-se cu prietenii mei,  puÅŸca ÅŸi cureaua latÄƒ, eeeei! Ce ficior eram odatÄƒ...\r\n\r\nAÅŸaaaa. Åži stÄƒteam io odatÄƒ la singuru\' loc din facultÄƒ unde aveam Internet moca, ÅŸi scriam un e-mail nu mai stiu io cui, cÄƒ era-n englezÄƒ. Åži cÃ¢nd scriam io, aÅŸa, vreau sa scriu un cuvÃ¢nt ÅŸi nu mai ÅŸtiu cum se spune in englezÄƒ la cuvantu ala. Era ceva cuvÃ¢nt greu, cred ca ceva ce nu se inventase inca in limba engleza, care e patria lor.\r\n\r\nAsa.\r\n\r\nSi finca nu gaseam cuvantu\' si ma ofticam, ies val-vartej de la biblioteca si ma preumblu prin facultate, in interiorul corpului meu sexy cum e el de obicei, cautandu-mi cuvantul si prefacandu-ma preocupat si incercand sa gasesc o victima pe care s-o intreb cum se zice in engleza la cuvantu\' ala, sa imi zica ca nu stie si apai sa ii zic ca-i proasta si ca nu stiu ce cauta la facultate, si ca ar trebui sa se duca la oi sau sa o indrum cÄƒtre salamu\' meu de Sibiu.\r\n\r\nSi cum haladuiam io asa prin fuckultate, dau de prekinu meu bun Popica. Popica era cel mai pitoresc personaj din fuckulta finca era femeie de serviciu, portar, telefonista, curatzator, amenajator de gard viu, gunoier, curier, instalator, curatator de bude, si mie-mi era drag finca cand ma vedea ma chema la el in gÃ¢rlici unde ma servea cu spirt Mona (!!!)  diluat cu concentrat de zmeura, d-ala de cumparat. Ati baut vreodata? Daca pishi licoarea, gauresti  gardu\', parol.\r\n\r\nSi il vad pe Popica, si ii zic: Buna ziuaaaa, dom\' Popicaaaa!!! Ce faci ba, ii mai zic, finca il loam la pertu, desi putea sa-mi fie bunic. Ba, Gropare, zice, vrei? Gusti? (lichior de concentrat de spirt, adica). Nu, ba, zic, azi nu.\r\n\r\nSi ma uit in stanga - si-l vad pe un asistent de la Engleza, ficior tinerel cu care ma stiam din vedere, si il salutam (cu Buna Ziua, normal). Deci domÅ£ asistent care le preda la colegii mei, si io - zero barat, student rupt in coate. Da\' cum eram io asa preocupat, il intreb direct:\r\n\r\n- Salut, ba, zic io, zi repede, asa-i ca la cuvantu\' ala i se zice asa in engleza? si-i zic.\r\n- Da, zice el un pic nedumerit de neobrazare, asa se zice...\r\n- Bine, ba, zic io, mersi. Pa! Si ii intorc spatele, sa plec inapoi sa-mi termin e-mailu\'.\r\n- La revedere, dom\' Popica, sanatate! ii mai zic io la prekinu meu care era si  femeie de serviciu, si portar, si telefonista, si curatzator de cosuri de gunoi, si amenajator de gard viu, gunoier, curier, si instalator. Si curatator de bude.\r\n\r\nAstfel s-a incheiat faza in care i-am spus \"dvs.\" lu\' Popica si \"bÄƒ\" unui asistent de la facultÄƒ. Care, spre norocul meu, s-o suparat decÃ¢t deloc.','Cand eram student',0,'','publish','open','open','','cand-eram-student','','','2007-10-10 22:26:02','2007-10-10 20:26:02','',0,'http://www.groparu.ro/?p=688',0,'post','',5),(689,1,'2007-10-09 21:26:31','2007-10-09 19:26:31','- Daca ai avut o zi teribil de proasta, cu mirosuri in autobuz;\r\n- Daca seful tau tocmai te-a transformat intr-un vibrator pe care tot tie ti l-o infipt supt coada;\r\n- Daca afli ca prekina ta umbla cu cel mai bun prekin al tau;\r\n- Daca afli ca prekina ta s-o mozolit cu un arab, si toti prekinii stiau, da\' nu ti-or zis nimic;\r\n- Daca vezi ca blogul tau primeste numai comentarii nasoale sau nici un comentariu deloc;\r\n- Daca ai intarziat la un interviu important si ai aflat ca nu mai primesti jobul;\r\n- Daca castigi cat un profesor;\r\n- Daca esti racit si tre\' sa dai o avere pe medicamente, avere pe care n-o ai;\r\n- Daca te simti mai intellectually-challenged ca Mitica Dragomir, Becali sau un crampon;\r\n- Daca ai hemoroizi;\r\n\r\nETC,\r\n\r\n1. Cauti o haita de maidanezi; nu ai cum sa nu gasesti.\r\n2. Din haita, selectezi o catea.\r\n3. Catelei ii pui lesa.\r\n4. Legi catelusa de un pom.\r\n5. Te uiti la catelusa si intrebi:\r\n\r\n- WHO\'S THE BITCH <strong>NOW</strong>????\r\n\r\n6. Dezlegi lesa. Te simti mai bine. Nu tu esti.\r\n\r\nOK, asta nu e cea mai buna postare a mea. De acord. Da\' am incercat si io. Azi am mancat slana cu ceapa, semn ca se apropie iarna.','Idee de cum sa te simti mai bine',0,'','publish','open','open','','idee-de-cum-sa-te-simti-mai-bine','','','2007-10-09 21:26:31','2007-10-09 19:26:31','',0,'http://www.groparu.ro/?p=689',0,'post','',18),(690,1,'2007-10-10 10:49:29','2007-10-10 08:49:29','Care este cea mai mare companie americana?\r\n\r\nIndicii: are cea mai mare cifra de afaceri; cel mai mare numar de angajati; cel mai mare numar de sedii; are afaceri cu petrol - rafinarii, tancuri petroliere, benzinarii, puturi de extractie, zacaminte de Å£iÅ£ei etc, dar se mai ocupa si cu altele; este asa de puternica, ca e nevoie de armata americana sa o apere; compania detine mii de kilometri patrati  de pamant si sute de mii de cladiri.\r\n\r\nEi? Ce ziceti? Chevron, Exxon, Coca-Cola, Microsoft...? General Motors, Boeing,  Bell, Halliburton, Bechtel, Ford, Wal-Mart...? Lockheed Martin? Google? Apple?\r\n\r\nNu, mah. Nici gand.\r\n\r\nCea mai mare companie americana este deocamdata statul Irak.','Cea mai mare companie americana ',0,'','publish','open','open','','cea-mai-mare-companie-americana','','','2007-10-10 10:49:29','2007-10-10 08:49:29','',0,'http://www.groparu.ro/?p=690',0,'post','',6),(691,1,'2007-10-10 13:41:05','2007-10-10 11:41:05','Britney, aceasta Mitica Dragomir a show-bizului american, a ramas fara copiii ei, finca ea le cam bea sh se drogheaza. Da\' asta se stie deja.\r\n\r\nTot Britney a ratat prima sa intalnire cu copiii ei.\r\n\r\nLe recomand copiilor lui Britney sa ii cumpere la mamicutza neshte votca, si atunci mami va veni sa-i vada, negresit. Finca mama ii iubeste.','In premiera despre Britney Spears',0,'','publish','open','open','','in-premiera-despre-britney-spears','','','2007-10-10 13:41:05','2007-10-10 11:41:05','',0,'http://www.groparu.ro/?p=691',0,'post','',7),(692,1,'2007-10-10 13:40:29','2007-10-10 11:40:29','Bacanie = magazin din judetul Bacau.','Alt gand de miercuri',0,'','publish','open','open','','alt-gand-de-miercuri','','','2007-10-10 13:40:29','2007-10-10 11:40:29','',0,'http://www.groparu.ro/?p=692',0,'post','',4),(693,1,'2007-10-12 13:08:03','2007-10-12 11:08:03','Da-da-da, stiti voi, Polus Mall, cel mai mare centru comercial pe un singur nivel din toata Romania.\r\n\r\nHostese demenÅ£ial de faine.\r\n\r\nLa deschidere: Florin Piersic Cicoflenderu\', Ioan T. Morar (asa ca daca nu va aparea veci pururi ceva scris in Catavencu de rau despre mall, sa stiti de ce!), Boc, Ovidiu Uscat, premarele Florestiului, baÅŸca o gaÅŸcÄƒ de investitori care impreuna castiga pe luna cat castig io in 9 ani de zile, cu zile polare.\r\n\r\nHostese demenÅ£ial de faine!!!\r\n\r\nOameni care lucreaza de se caca pe ei, la greu, deci care alearga ca un stol de MIG-uri sa puie covoare de iarba, tufisuri, sa curete, etc. Cine o zis ca romanii nu sunt harnici bine o zis, finca toti care lucrau acolo erau sloveni, slovaci, unguri o gramada, rromi. A, si romani erau, si de fapt si ei bagau la greu, deci imi cer scuze pentru ce am scris mai sus.\r\n\r\nHostese absolut demenÅ£ial de faine.\r\n\r\nRau artificial inauntru, dar fara pesti. Am zis ca atunci cand mai venim de la pescuiala facem o miscare anarhica: intram in mall si aruncam trei plase de carasei din aia care nu mor never-ever in rÃ¢uleÅ£ (cine e pescar ÅŸtie ce zic! CaraÅŸii is in stare sa traiasca si in apa aia grea de la CernobÃ¢l!)\r\n\r\nHostese de-de-de-demenÅ£ial de faine (deja ma balbai numa cand ma gandesc).\r\n\r\nFantani arteziene. Cand le vezi, instant te trece sa meri la budescu, da\' toaletele is in celalalt capat, si tre sa mergi vreo 8 minute pana la una (cel putin numa\' acolo am vazut io sa fie, da\' io-s mai tantalau).\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/10/dsc00158.JPG\" title=\"dsc00158.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/10/dsc00158.JPG\" alt=\"dsc00158.JPG\" height=\"297\" width=\"395\" /></a>\r\n\r\nHostese demenÅ£ial de faine.\r\n\r\nPalmieri in centru\' comercial. Mai mici ca aia de la Mamaia. Singura problema e ca amu\' trebe sa aduca si caini care sa ii piÅŸe.\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/10/dsc00160.JPG\" title=\"dsc00160.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/10/dsc00160.JPG\" alt=\"dsc00160.JPG\" height=\"301\" width=\"397\" /></a>\r\n\r\nHostese demenÅ£ial de faine.\r\n\r\nAm vazut ca un magazin chemase un popa sa le binecuvinteze afacerile, si toate vanzatoarele alea cu curu mare si pantaloni stransi si decoltati stateau serioase, si io radeam de ele, dar nici nu s-or miscat.\r\n\r\nHostese demenÅ£ial de faine, ca nici nu ai curaj sÄƒ te uiÅ£i la ele, ÅŸi Ã®Å£i tremurÄƒ mÃ¢na dacÄƒ vrei sa le faci pozÄƒ. AÅŸa cÄƒ nu veÅ£i gÄƒsi pe blogul meu poze cu ele, perversilor!\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/10/dsc00161.JPG\" title=\"dsc00161.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/10/dsc00161.JPG\" alt=\"dsc00161.JPG\" height=\"535\" width=\"407\" /></a>\r\n\r\nPapa bun la final, chiar bun, si beutura. PromoÅ£ii ÅŸi tÄƒte ÅŸele. Organizare faina, si muncitÄƒ, s-o vÄƒzut asta. Numa interpretul ala de o tradus ce or zis gasca aia de investitori s-o cam balbait oÅ£Ã¢rÄƒ, ca se vedea cÄƒ e piÅŸat in pantaloni de emoÅ£ie. A, si acustica era proasta in spatele boxelor, si strainii astia vorbeau incet si cu accent maghiaro-olandezo-nu-se-stie.\r\n\r\nInterpretul ala am fost chiar eu.\r\n\r\nV-am zis oare despre hostese?','Deci deschiderea Polus',0,'','publish','open','open','','deci-deschiderea-polus','','','2007-10-12 13:41:57','2007-10-12 11:41:57','',0,'http://www.groparu.ro/?p=693',0,'post','',19),(694,1,'2007-10-12 13:37:25','2007-10-12 11:37:25','','dsc00158.JPG',0,'','inherit','open','open','','dsc00158jpg','','','2007-10-12 13:37:25','2007-10-12 11:37:25','',693,'http://www.groparu.ro/wp-content/uploads/2007/10/dsc00158.JPG',0,'post','image/jpeg',0),(695,1,'2007-10-12 13:38:52','2007-10-12 11:38:52','','dsc00160.JPG',0,'','inherit','open','open','','dsc00160jpg','','','2007-10-12 13:38:52','2007-10-12 11:38:52','',693,'http://www.groparu.ro/wp-content/uploads/2007/10/dsc00160.JPG',0,'post','image/jpeg',0),(696,1,'2007-10-12 13:39:31','2007-10-12 11:39:31','','dsc00161.JPG',0,'','inherit','open','open','','dsc00161jpg','','','2007-10-12 13:39:31','2007-10-12 11:39:31','',693,'http://www.groparu.ro/wp-content/uploads/2007/10/dsc00161.JPG',0,'post','image/jpeg',0),(697,1,'2007-10-12 16:44:31','2007-10-12 14:44:31','Deci: weekendu\' asta o sa ling la greu, impreuna cu <a href=\"http://www.andreicrivat.ro\" target=\"_blank\">Crivatz</a> si <a href=\"http://www.ciutacu.ro\" target=\"_blank\">Ciutacu</a>, si bine-nteles, cu <a href=\"http://www.jeg.ro\" target=\"_blank\">JEG</a>. Bere o sa ling. La Tilisca. Cine nu stie unde e, bine face! Finca e atza-n Marginimea Sibiului, acolo unde n-o intrat picior de ungur, sas, navalitor sau migrator. Numa\' de tigan. Ca aia intra oriunde.\r\n\r\nNe recitim luni.\r\n\r\nPS: Dumineca e Sf. Paraschiva, adica mama. Care de fapt...','Lingaii',0,'','publish','open','open','','lingaii','','','2007-10-12 16:45:19','2007-10-12 14:45:19','',0,'http://www.groparu.ro/?p=697',0,'post','',9),(698,1,'2007-10-15 14:28:38','2007-10-15 12:28:38','Tilisca este o localitate binecuvantata din muntii Concubinului... ÄƒÄƒÄƒ, Cibinului.\r\n\r\nIn Tilisca, oamenii (desi ei sunt sibieni) poarta cloape. Cloapele stau pe o parte a capului in asa fel incat sa oftice gravitatia, care moare de ciuda. Inexplicabilul fenomen se datoreaza unei malformatii congenitale care apare numai in momentul in care se pune clopul pe cap, malformatie care impinge clopul in sus; in acest rastimp, vicleana gravitatie, de ciuda ca clopul o sfideaza, pleaca in baie si incearca sa isi taie venele - de-a lungul. Dupa ce clopul este luat de pe cap, malformatia se retrage inapoi in cap, iar gravitatia devine buimaca si ii pica ÅŸiÅŸu\' din mÃ¢na ei de gravitaÅ£ie.\r\n\r\nCa sa va dati si voi un pic seama cat e de tantalau Groparu: s-o dus la bancomat ca sa-si scoata 400 lei, bani de weekend. Cand bancomatul i-a inapoiat cardul, Groparu si l-a bagat in buzunar si a plecat fara sa mai ridice si banii. La ora actuala umbla disperat pe la Banca Transilvania sa ii convinga pe aia ca bancomatul e de vina. Daca va reusi sau nu veÅ£i afla in emisiunile urmatoare, sau in cele viitoare, nu-s sigur.\r\n\r\nSpre Tilisca, ocazia care mi-a fost ursita sa o iau era un nene care o lucrat ani de zile pe TIR pe vremea lu CeaÅŸcÄƒ: sa il fi auzit numa\' ce istorii avea in el prin Tikrit ÅŸi Fallujah, prin Libia ÅŸi Siria, cÄƒ instant l-ati fi rugat sa isi faca blog! O sa apara si pe trilulilu, ca l-am inregistrat cu telefonul meu, care e mai destept ca - bine-ntzales - mine.\r\n\r\nLa Tilisca - floarea blogosferei, dupa cum am mai zis scriind: <a href=\"http://www.ciutacu.ro\" target=\"_blank\">ciutacimea</a>, <a href=\"http://www.andreicrivat.ro\" target=\"_blank\">crivatzimea</a>, <a href=\"http://www.jeg.ro\" target=\"_blank\">jegoshimea</a> sh groparimea, la aceasta din urma nu-i mai pun hyperlink. Åži toÅ£i am fost lingÄƒi de bere, dupÄƒ cum probabil ati ÅŸi observat din postarea anterioarÄƒ. Åži toÅ£i ne-am reÃ®nnoit jurÄƒmintele de blogrollie, mai puÅ£in JeguÅ£u, care nu are blogroll, fincÄƒ lui i se pare ca el este cel mai. Nu cÄƒ n-ar fi!\r\n\r\nNota bene: noi, ciobanii din Tilisca, nu ii suportam pe ciobanii din Rod, Jina, Poiana, si in nici un caz pe cei din GaleÅŸ; apoi, cand am ajuns in Orlat, unde onor maica-mea (care de fapt e-o doamna) serba pe Sfanta Patroana Parascheva, ne-am dat seama ca noi, ciobanii orlatzeni, nu ii suportam pe ciobanii aia din Sibiel, Fantanele, Cristian si - bine-nteles - Poplaca. Deci toata Marginimea Sibiului e numa\' un scandal si-o dihonie, matze fripte si rÃ¢ci.\r\n\r\nStiti care a fost motto-ul zilei de sambata? In primul rand c-au fost 2:\r\n\r\nMotto 1: \"What a piece of work is the bladder! How noble in reason! how infinite in faculties! in form and moving, how express and admirable! in action how like an angel! in apprehension, how like a god! the beauty of the world! the paragon of animals!\" - ca sa pricepeti si mai bine, ma extaziam de puterile si flexibilitatile vezicai, la fel cum Hamlet se extazia de puterile divine ale omului. Mie mi s-o parut o chestie destul de reusita, dar nu o ras nimeni, si pun pariu ca nici dintre cetitorii mei nu o ras nimeni.\r\n\r\nMotto 2: \"Dati-mi colesterol, voi, oilor!\" - strigat de batalie la momentul mesei: cel mai demential <strong>sloi de oaie</strong> si gratar de oaie. Divin.\r\n\r\nMotto 3 (bonus): \"De ce trebuie ca tu sa bei cel mai mult dintre toti, tot timpul?\" Raspuns: \"Prefer sa fiu geniu betiv decat geniu gay!\" Am gresit? N-AM gresit!\r\n\r\nAsaaaaa. Tiliscanii, inainte de a fi fost tiliscani, or fost daci, dupa cum zicea si Iliescu: \"ZÄƒ dacs come from zÄƒ tracs!\" Cetatea dacica de la Tilisca e practic sublima, mai ales ca s-or pÄƒstrat din ea cel puÅ£in 4 cÄƒrÄƒmizi ÅŸi un bolovan.\r\n\r\nAsaaaaa. La plecare am trecut prin satul GaleÅŸ, la DÄƒdÃ¢rlat IlieÅŸ (istoria nu a consemnat care e numele ÅŸi care prenumele), meÅŸterul care face cloape de sibieni, cu tot cu malformaÅ£ie. I-am arestat cÃ¢te un clop de persoanÄƒ.\r\n\r\nAcuma am senzaÅ£ia cÄƒ am uitat sa scriu despre o sumedenie de lucruri, cum ar fi ca crÃ¢jma din satul - pardon, oraÅŸul - SaliÅŸte se cheamÄƒ \"Saloon\". Dar amintirile au sa-mi revie, deocamdatÄƒ lÄƒsati-mÄƒ sÄƒ Ã®mi cultiv Ã®n liniÅŸte durerea de cap.\r\n\r\n<strong>Update</strong>: <a href=\"http://vladutul.ciutacu.ro/\" target=\"_blank\">Ciutacelul</a> - cel mai tanar blogger roman - vede cu ochii lui intreaga excursie. Ia vedetz! Plus ca sh <a href=\"http://www.ciutacu.ro/articol-438.html\" target=\"_blank\">Ciutacu</a> si <a href=\"http://www.andreicrivat.ro/2007/10/16/vesnicia-s-a-nascut-la-tilisca/\" target=\"_blank\">Crivatz</a> facura aceeasi chestie, oglinditoare de altfel.','In Tilisca, unde se deschide berea cu brisca',0,'','publish','open','open','','in-tilisca-unde-se-deschide-berea-cu-brisca','','\nhttp://www.andreicrivat.ro/2007/10/16/vesnicia-s-a-nascut-la-tilisca/','2007-10-16 16:04:34','2007-10-16 14:04:34','',0,'http://www.groparu.ro/?p=698',0,'post','',14),(699,1,'2007-10-16 09:39:04','2007-10-16 07:39:04','Asar\' o venit Huby la Cluj, care e destul de oltean simpatic sh cumsecade; si Huby aka CÃ¢rlanu\', care e de fapt destul de Tiganiad de membru fondator al celulei de criza, are ca sarcina, ca angajat al nush carei agentii guvernamentale de agricultura, sa NUMERE OILE CIOBANILOR CARE SE TRANSHUMEAZA.\r\n\r\nAtata numa ca Huby nu reuseste niciodata sa numere toate oile.\r\n\r\nStiti de ce?\r\n\r\nFinca daca incepe sa numare oile il ia somnu\'.','Cum se apara ciobanii',0,'','publish','open','open','','cum-se-apara-ciobanii','','','2007-10-16 09:51:51','2007-10-16 07:51:51','',0,'http://www.groparu.ro/?p=699',0,'post','',10),(700,1,'2007-10-16 15:43:09','2007-10-16 13:43:09','Se tot zice cum ca romanashii nostri le beau mult, ca e betivi, ca dupa ce beau mult isi bubuie nevestele si apai le iubesc, si din copiii astia facuti la betie se aleg membrii urmatoarelor legislaturi.\r\n\r\nE!\r\n\r\nUltima data cand am baut cu un rus, am aflat de la el o istorioara hiper interesanta.\r\n\r\nFinca tocmai incepusem sa ne dam jmekeri cu cat bem noi, romanii, ce buna e palinca de Zalau si horinca de Maramu\', rachia de Bistrita de 58 de focuri (= de grade), rachia aia de Sibiu care este, ca am baut uzo si absint, sh tat felu de coniace.\r\n\r\nSi el ne zice, cu un accent preponderent rusesc:\r\n\r\n- But did you ever drink double refined alcohol, 98 degrees?\r\n- What?!?!?!\r\n- Yes, zice el, I did.\r\n- OMG!!!!\r\n- My father taught me how to drink it, mai zice rusu\'. You pour some double refined alcohol on a spoon; and then you throw it down your throat.\r\n- Cool, zicem noi in mintile noastre usor invidioase.\r\n- It burns your throat, continua nenea, but afterwards (si aci fatza i se transfigura de placere!) you can drink TWO BIG CUPS of double refined alcohol, and you\'re OK!!!!\r\n\r\nRus veritabil, din Sankt Petersburg. Il si chema Ivan. Deci nu poti fi mai rus decat atata.','Despre cat de mult beau romanii',0,'','publish','open','open','','despre-cat-de-mult-beau-romanii','','','2007-10-16 15:43:09','2007-10-16 13:43:09','',0,'http://www.groparu.ro/?p=700',0,'post','',18),(701,1,'2007-10-17 11:36:42','2007-10-17 09:36:42','Deci aceasta postare nu reprezinta un linsaj mediatic, deoarece DTR nu mai poate fi linsat: cariera lui politica s-o incheiat, din neumila mea parere, la ceasul la care guvernarea CDR o dat coltzu\' (bueeeey, io v-am votat, porcilor!)\r\n\r\nDaca justitia il gaseste nevinovat, mi-e teama ca va stÃ¢rni un trend periculos: toti parintii isi vor numi copiii lor dupa patternul de asociere-de-nume-de-vechi-dusmani, cum e cazul cu Decebal-Traian, ca fiind un nume mare aducator de noroc in cazul unei anchete DNA. Astfel, am putea asista la urmatoarele combinatii:\r\n\r\n- Cezar Vergingetorix RemeÅŸ;\r\n- Sula Jugurtha RemeÅŸ;\r\n- Hernando-Cortes Montezuma RemeÅŸ;\r\n- Menumorut-Regele-Bela RemeÅŸ;\r\n- Napoleon Ducele-de-Wellington RemeÅŸ;\r\n- Baiazid Mircea-cel-Batran RemeÅŸ;\r\n- Athos-Porthos-Aramis-d\'Artagnan Mazarin RemeÅŸ;\r\n- Hitler Stalin RemeÅŸ;\r\n- Montgomery Rommel RemeÅŸ;\r\n- Hrusciov Kennedy RemeÅŸ;\r\n- Logan Mahindra RemeÅŸ;\r\n- Basescu Tariceanu RemeÅŸ;\r\n- Saddam W. TufiÅŸ RemeÅŸ;\r\n\r\n- SPERMATOZOID-CAMPION SPERMATOZOID-NECAMPION REMEÅž;\r\n\r\ns.a.m.d.\r\n\r\nBrrrrrrr!!!!!','Despre Decebal Traian Remes (DTR)',0,'','publish','open','open','','despre-decebal-traian-remes-dtr','','','2007-10-17 13:42:41','2007-10-17 11:42:41','',0,'http://www.groparu.ro/?p=701',0,'post','',7),(702,1,'2007-10-18 14:47:26','2007-10-18 12:47:26','Deci stirea zice ca oficialii UE s-or loat cu urmarit pasarile, si si-or dat seama ca Romania nu le-o pregatit infrastructura de cazare peste iarna, cuibare incalzite decomandate, de 4 sh 5 stele, sh alea-alea.\r\n\r\nMai, copii, mai! Noi amu suntem in UE sh trebe <a href=\"http://www.hotnews.ro/articol_87096-Romania-risca-sanctiuni-de-la-UE-pentru-ca-nu-protejeaza-speciile-salbatice-Bucurestiul-anunta-ca-va-remedia-situatia.htm\" target=\"_blank\">sa avem grija de pasarile noastre</a>. Sper sa nu va crizati din nou, ca io clar ca ma gandeam la ars pasarici cu cocoselu\', in timp ce birocratii bruxelezi se gandesc numa la cum sa le fie mai bine pasaricilor, sa stea ele comode, asa, incalzite prin cuiburi si sa fie sanatoase, curate si uscate, sh sa le f*** altii. Haida-de! Io numa acuma imi dau seama in ce confederatie de imbecili ne-am bagat, auzi la ei, UE, aia, care se gandesc la ele, si noi, care ne gandim sa ne fie bine la cocosel sh la stomacel mai intai, si numa\' dupe aia la pasarica!\r\n\r\nA doua la mana: io zic sa nu facem nimic pentru pasaretul lor pana nu terminam cu pasaretul local, ca io - cel putin - mai am cel putin vreo 4 milioane de pasaret romanesc de cea mai buna calitate pe care trebuie sa-l protejez de frig. Cu corpul meu, bine-nteles. Si finca is pro-ecologie, pentru pasaricile astea m-as face plapuma si cearshaf, sac de dormit, cerga de plaja, salcie la mal, sutien, tangÄƒ, loÅ£iune anti-soare  - orice, numai sa ne fie pasaricile fericite!\r\n\r\nA treia la mana - redevenind serios (sau nu) - si revenind la pasaricile alea cu aripioare, nu cu pÄƒruÅ£ ÅŸi frezÄƒ interesantÄƒ, io sunt ferm convins ca romanasii nostri le-or pregatit o sumedenie de locuri pentru iernat de cea mai buna calitate: in aspic, in sos de legume, in sos de vin/alb/tomat, cu cartofi sau broccoli, pe varzÄƒ, mÃ¢nz, mistreÅ£, cu bere dupa si/sau cu palinca inainte, ca antreu sau Ã®n budincÄƒ,  in torturi sau - de ce nu - ca desert, ca io am auzit ca or fost cazuri in care nush ce paysan s-o dedat la pasarica pasaricii! (da, <a href=\"http://everything2.com/index.pl?node_id=571333\" target=\"_blank\">sexul cu pasari existÄƒ</a>)\r\n\r\nUpdate: am uitat sa pun punct, asa ca pun acilea, ni: \".\"','Despre pasari',0,'','publish','open','open','','despre-pasari','','','2007-10-18 15:52:17','2007-10-18 13:52:17','',0,'http://www.groparu.ro/?p=702',0,'post','',12),(703,1,'2007-10-18 16:30:14','2007-10-18 14:30:14','Bahmuteanca a nascut.\r\n\r\nSi Monica Columbeanu a nascut.\r\n\r\nSa vie la mine sa-si ceara scuze si Einstein, si Murphy, sau cine-o mai zis ce o zis, si anume ca mama prostilor e mereu gravida.\r\n\r\nAcum sa vie!','Sa-si ceara scuze!',0,'','publish','open','open','','sa-si-ceara-scuze','','','2007-10-18 16:30:15','2007-10-18 14:30:15','',0,'http://www.groparu.ro/?p=703',0,'post','',3),(704,1,'2007-10-19 16:36:01','2007-10-19 14:36:01','Io nu prea ma stiu la saitele astea de RSS, finca io nu lucrez la firma de IT (sau da?). Asa ca am mers pe unul din cei mai recenti referreri de-ai mei, si i-am hackuit saitu\'. Voala:\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/10/groparu1.JPG\" title=\"groparu1.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/10/groparu1.thumbnail.JPG\" alt=\"groparu1.JPG\" /></a>\r\n\r\nPS: Daca nu va prindetz, cautati cuvantul groparu de cate ori apare!','Primul sait hackuit de mine!',0,'','publish','open','open','','primul-sait-hackuit-de-mine','','','2007-10-19 16:37:47','2007-10-19 14:37:47','',0,'http://www.groparu.ro/?p=704',0,'post','',9),(705,1,'2007-10-18 16:45:05','2007-10-18 14:45:05','','groparu.JPG',0,'','inherit','open','open','','groparujpg','','','2007-10-18 16:45:05','2007-10-18 14:45:05','',-1192718538,'http://www.groparu.ro/wp-content/uploads/2007/10/groparu.JPG',0,'post','image/jpeg',0),(706,1,'2007-10-18 22:04:51','2007-10-18 20:04:51','Deci Sarkozy divorteaza de nevasta-sa.\r\n\r\nPun pariu ca si nevasta-sa de el. Cine se baga?','Sarkozy divorteaza!',0,'','publish','open','open','','sarkozy-divorteaza','','','2007-10-18 22:10:19','2007-10-18 20:10:19','',0,'http://www.groparu.ro/?p=706',0,'post','',8),(707,1,'2007-10-19 00:48:41','2007-10-18 22:48:41','Intr-unul din posturile mele anterioare, intitulat <a href=\"http://www.groparu.ro/?p=698\" target=\"_blank\">Tilisca, unde se deschide berea cu brisca</a>, am ales acest titlu deoarece faceam o referire delicata (ca un funigel de delicata) la un banc clasic, de Marginimea Sibiului:\r\n\r\n<strong>Un ardelean coboara repede pÃ¢n\' sa plece trinu\' (trin care mergea, bine-nteles, de la Sibiu la Orlat) si mere la chioscurile alea din gara din Sibiu, de pe peron.</strong>\r\n\r\n<strong>- Dom\'ÅŸorÄƒ, zice al meu, dÄƒ-mi o cutie de bere!</strong>\r\n\r\n<strong>Dom\'ÅŸora - Ã®i dÄƒ. El scoate brijca din jep, o Ã®nfige Ã®n cutie, o desface ca pe o conservÄƒ, ÅŸi o soarbe dintr-un gÃ¢t (sibienii Ã®z oameni nÄƒpraznici!)</strong>\r\n\r\n<strong>- Dom\'ÅŸorÄƒ, zice al meu, mai dÄƒ-mi o cutie de bere!</strong>\r\n\r\n<strong>Dom\'ÅŸora - Ã®i mai dÄƒ. El scoate iar brijca din jep, o Ã®nfige Ã®n cutie, o desface ca pe o conservÄƒ, ÅŸi ÅŸi pe asta o soarbe dintr-un gÃ¢t! FincÄƒ sibienii Ã®z oameni nÄƒpraznici.</strong>\r\n\r\n<strong>- DomniÅŸorÄƒ, zice al meu, mai dÄƒ-mi o cutie de bere!</strong>\r\n\r\n<strong>DomniÅŸora  Ã®i zice: </strong>\r\n\r\n<strong>- Da\' mÄƒ  bade, ui acolo Ã®i un inel, ridicÄƒ inelul si trage-l spre tine, nu te mai chinui cu brijca!</strong>\r\n\r\n<strong>La care badele Ã®i rÄƒspunde:</strong>\r\n\r\n<strong>- ApÄƒi, no, domniÅŸorÄƒ dragÄƒ, inelul ii pentru aia de n-au briÅŸcÄƒ!</strong>\r\n\r\nAcest banc l-am adÄƒugat ca sÄƒ fac de-nÅ£eles la bobor. Oare scriu eu prea ermetic? Nu, nu rÄƒspundeÅ£i, fincÄƒ mi-i fricÄƒ de ce aÅ£i putea scrie. Da\' asta ii numa ase, ca sa stiti si voi ca atunci cand Groparu scrie ceva, le mai si gandeste - atata numa\' ca uneori nu ajung gandurile sa fie si puse pe blog, finca is prea multe si isi dau in gura la iesire, cand e inghesuiala.','Deci, pentru ca m-am facut ne-nteles',0,'','publish','open','open','','deci-pentru-ca-m-am-facut-ne-nteles','','\nhttp://www.groparu.ro/?p=698','2007-10-19 00:48:41','2007-10-18 22:48:41','',0,'http://www.groparu.ro/?p=707',0,'post','',6),(708,1,'2007-10-19 09:47:22','2007-10-19 07:47:22','DeÅŸi acest titlu v-ar face pe mulÅ£i sÄƒ credeÅ£i cÄƒ e vorba despre mine, daÅ£i-mi voie sÄƒ vÄƒ luminesc: e vorba de altÄƒ muscÄƒ beÅ£ivÄƒ.\r\n\r\nAceastÄƒ muscÄƒ beÅ£ivÄƒ, despre care e vorba in aceastÄƒ postare, trona, ca o nesimÅ£itÄƒ, la mine Ã®n baie, pe oglindÄƒ. La mine in baie, care e renovatÄƒ de la zero (m-o costat cam un milion de lei vechi renovarea, deci o micÄƒ avere!) se aflÄƒ, pe lÃ¢ngÄƒ un tron de porÅ£Äƒlan, ÅŸi o oglindÄƒ (Ã®n care mÄƒ Ã®ncordez io adesea) cu o luminÄƒ; fincÄƒ Ã®n orice baie trebe luminÄƒ, ca sÄƒ poÅ£i face pipi negreÅŸit pe colacul de pe budÄƒ. Deasupra luminii se aflÄƒ o gurÄƒ de aerisire cu ventilator electric, care elibereazÄƒ baia de mirosurile care Ã®nconjoarÄƒ tronul de porÅ£Äƒlan, ÅŸi de aburii mei cÃ¢nd fac duÅŸ, aburi care ma Ã®mpresoarÄƒ ca degetele unei zeiÅ£e lacome de corpul meu sexobolant.\r\n\r\nEu m-am gÃ¢ndit sÄƒ alung musca beÅ£ivÄƒ (care era aÅŸezatÄƒ chiar lÃ¢ngÄƒ lumina  de pe oglindÄƒ) Ã®nspre ventilatorul electric, care mergea; dar musca dreq era fascinatÄƒ de luminÄƒ, ÅŸi degeaba am hÃ¢ÅŸÃ¢it-o eu cu mÃ¢na, ca nu o vrut sÄƒ zboare cÄƒtre ventilator, care  mergea, cÄƒ vroia la luminÄƒ.\r\n\r\nAÅŸa cÄƒ am Ã®ndrumat-o cu drag cÄƒtre luminÄƒ, dar nu lumina mea din baie, ci cÄƒtre lumina de la capatul unui tunel, tunel in care a intrat Ã®n momentul Ã®n care am strivit-o, cu drag, de oglindÄƒ.','Musca beÅ£ivÄƒ',0,'','publish','open','open','','musca-betiva','','','2007-10-19 09:47:22','2007-10-19 07:47:22','',0,'http://www.groparu.ro/?p=708',0,'post','',5),(709,1,'2007-10-19 14:41:34','2007-10-19 12:41:34','Stateam cu NÃ¢rÅ£oagÄƒ zis PÃ¢rÅ£oagÄƒ la o pipÄƒ, pe balcoane. Zice:\r\n\r\n- Tu te uiÅ£i la sitcom-uri?\r\n- Numa dacÄƒ-s porno, zic io.\r\n- PÄƒcat. Am vÄƒst asarÄƒ unu\' de am rÃ¢s de am cutremurat patu\'!\r\n- Ce, bÄƒ, zic, Å£i-ai bagat mÃ¢na-n pantaloni ÅŸi te-o buÅŸit rÃ¢su\'?','Deci - iara la tigare',0,'','publish','open','open','','deci-iara-la-tigare','','','2007-10-19 14:41:34','2007-10-19 12:41:34','',0,'http://www.groparu.ro/?p=709',0,'post','',4),(710,1,'2007-10-19 16:37:15','2007-10-19 14:37:15','','groparu1.JPG',0,'','inherit','open','open','','groparu1jpg','','','2007-10-19 16:37:15','2007-10-19 14:37:15','',704,'http://www.groparu.ro/wp-content/uploads/2007/10/groparu1.JPG',0,'post','image/jpeg',0),(711,1,'2007-10-22 23:30:29','2007-10-22 21:30:29','<a href=\"http://www.mediafax.ro/blog/general/despre-globurile-oculare-ale-fotbalistului-traian-basescu/\" target=\"_blank\">Aici</a> scrie cum ca ochii lui Basescu e miopi, si ca cum de e miop, ca o primit o minge de nush ce in capatzana, si i s-o dereglat telemetru\'.\r\n\r\nCa Base\' e un pic sacÃ¢z ÅŸi ÅŸaÅŸliu la ochi, ca ochiul stÃ¢ng se uitÄƒ dupÄƒ ochiul drept, asta ÅŸtie o Å£ara Ã®ntreagÄƒ. Dar eu am auzit alta varianta PE BUNE, cum cÄƒ de ce e domnu\' presedinte Base\' asa cum e, strÃ¢mb la vedere, adeca.\r\n\r\n<strong>Deci ce a patit privirea lui Basescu?</strong>\r\n\r\nDeci: eram in anu 3 de facultÄƒ. In facultÄƒ, eram best friends cu adminu\' de reÅ£ea, un om absolut demenÅ£ial de fain, cum numa-n Cluj am vazut asemenea oameni, om cu care nu am cum sÄƒ semÄƒn vreodata fincÄƒ ioz cioban din Sibiu.\r\n\r\nÅži Ã®ntr-o zi, adminu\' de retea ma scoate la o berula cu un prieten. Prieten despre care aveam sa aflu, mai incolo, ca era marinal, sau capetenie de marineri, lup de mare, shaf de haita. Cum ioz fascinat de povesti gen toate panzele sus (sau toate panzele jos, mai ales cele care stau pe trup de dama), claro ca am fost orgasmat de ideea de a ma duce cu iei, desi urla foamea in mine de la nemancare si mai urla si lipsa in portofel, si era numa 11 dimineatza, si pe vremea aia inca nu imi incepeam ziua cu o dusca sanatoasa de bere stinsa cu votca.\r\n\r\nSi merem la bere, si ne apucam de povestit despre vapuare, despre cum is rusii pe mare, ca is in stare sa-si demonteze piesa de la propriul motor daca te vad ca ai avarie, etc, etc, cum era treaba cu contrabanda pe vremea regretatului, bordelele de prin porturi, bricul nava-scoala Mircea, care e diferenta dintre tambuchi si cambuza, femeie si meduza,  ca ambele-s lipicioase, asa, babord si bieleta de directie, carnetu\' de sofer de petrolier, d-astea. Nenea marineru\' (care intamplator era si derector la regia aia autonoma sergiu nicolaescu a apei din Cluj, Rajac, da\' vroia sa renunte la directorat, ca primise o oferta pe care n-o putea refuza nu de la naÅŸu\' lu Puzo, ci de la o firma norvegiana de pescuit) ii lÄƒsa ciubuc la tanti chelnerita cate 2000 lei vechi la fiecare halba, si bea bere cu o bordura de sare presarata pe marginea halbei.\r\n\r\nSi la un moment dat, cand io deplangeam soarta marinei noastre, care din vreo 180 de vapoare mai avea vreo 16 finca o vandut-o Basescu (pe vremea aia, ministru al transportului), nenea numa\' ce trage ganditor in tigare, si zice:\r\n\r\n- Io am fost coleg cu Basescu.\r\n- Serios? Zic io. Super tare. Si cum e Basescu?\r\n- E OK, zice, numa\' ca i-am facut una.\r\n- Adica? zic io.\r\n- Pai, zice, cand eram in Academia aia navala, faceam tzambale.\r\n\r\nPentru ne-incorporabili: cand un melitar doarme in patu ala de camin ostasesc si il rastorni in somn (ca se rastoarna foarte usor), aia se kiama tzambal.\r\n\r\n- Si, zice, odata o degenerat, ca i-am facut lu\' asta (recte, Basescu) un tzambal, si o inceput sa chiÅ£Äƒie. Asa ca l-am vindecat cu o patura pusa peste el, si vreo juma de duzina de bocanci trantiti peste patura, vreo 5 minute. A doua zi avea ochiul stramb. Dar nu ne-o pÃ¢rÃ¢t la comandament, ca o buleam. Bun baiat, zice el, lupu\' de mare.\r\n\r\nNi ce privire are dom\' presedintele, loata derect de la iel dupe sait:\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/10/basescu.JPG\" title=\"basescu.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/10/basescu.JPG\" alt=\"basescu.JPG\" /></a>\r\n\r\nAmu nush cat e adevar si cat minciuna, io am auzit astea amu-s ceva ani, da\' am zis ca amu mi s-o confirmat senzatia ca Ã®mpÄƒrat la orbi e Äƒl\' de vede doar c-un ochi!','Despe privirea lui Basescu - a true story',0,'','publish','open','open','','despe-privirea-lui-basescu','','\nhttp://www.mediafax.ro/blog/general/despre-globurile-oculare-ale-fotbalistului-traian-basescu/','2007-10-23 00:26:32','2007-10-22 22:26:32','',0,'http://www.groparu.ro/?p=711',0,'post','',14),(712,1,'2007-10-20 08:13:41','2007-10-20 06:13:41','Era odata o fata blonda care nu-si dorea altceva de la viatza decat sa cunoasca un baiat tanar, care sa aiba un BMW si care sa-i suceasca mintile, sa o miste asa cum nici un mascul nu a mai reusit vreodata.\r\n\r\nIntr-o buna zi, un BMW a luat-o pe capota, a aruncat-o intr-un tufis, si s-a facut nevazut. Fata a ramas teafara, dar perplexa - la fel de perplex cum ramanem fiecare dintre noi cand ne vedem visele implinindu-se supt ochii nostri nedumeriti si umezi.\r\n\r\n<strong>Update:</strong>\r\n\r\nEra odata o fata care isi dorea un ficior cu casa (sau macar apartament) in centrul Clujului. Intr-o buna zi, l-a descoperit: era chiar ficiorul de deasupra, ea insasi locuind in centrul Clujului. Dar in alta zi, un cutremur a venit: apartamentul baiatului s-a prabusit peste apartamentul fetei, iar fortelor de descarcerare le-au trebuit 2 zile ca sa o scoata de supt daramaturi, teafara, dar puternic deshidratata.\r\n\r\nEra odata o fata care isi dorea sa aiba un prieten cu multi, multi-multi bani. Intr-o buna zi, l-a intalnit: dar baiatul avea asa de multi-multi-multi bani, incat si-a cumparat un bilet de avion numai dus in Noua Zeelanda, si nu s-a mai reintors, deoarece s-a prins ca in Romania nu mai are rost sa ramai.\r\n\r\nEra odata o fata care isi dorea sa aiba un prieten muschiulos, asa, puternic si facut, cu abdomen bine striat, pÄƒtrÄƒÅ£elos, alea-alea. Dar la prima lor intalnire, baiatului i s-a facut atata drag de ea, incat a strans-o in brate cu putere si, datorita inclestarii, fata a si scapat fara sa vrea un pÃ¢rÅ£ umed si foarte puturos, deoarece cu o noapte inainte bause excesiv cu niste prietene 2 sticle de tequila originala, facuta in Baia Mare. A fost ultima ei intalnire cu acel baiat musculos, puternic si body-buildat.\r\n\r\nA fost odata o fata care isi dorea sa aiba un prieten care sa stie sa gateasca, si ea sa nu fie nevoita sa isi piarda timpul in bucatarie, imbacsindu-si hainele si parul cu miros de prajeala; intr-o buna zi, ea a intalnit un astfel de baiat, dar la primul chef, acesta s-a pierdut asa de tare in schimbat retete cu o alta fata care era innebunita dupa gatit, incat au plecat amandoi de la chef, si nu l-a mai vazut NICIODATA.\r\n\r\nA fost odata o fata care isi dorea foarte mult sa intalneasca un baiat sensibil, tandru, care sa cante la chitara si la harpa si care sa-i recite ore in sir, fara sa se repete, din Pablo Neruda, Charles d\'Orleans, Daniel Scavinschi sau chiar Seamus Heaney; intr-o buna zi l-a intalnit, dar spre surprinderea ei, a aflat ca acel baiat era putintel gay. Gay pasiv.\r\n\r\nA fost odata o fata care isi dorea foarte mult sa aiba parte de un baiat curatel, ordonat si pedant, care sa aspire, sa stearga praful, sa nu si lase chilotii si ciorapii pe scaun si care sa si bata covoarele cel putin o data pe semestru; dar in clipa in care si-a gasit un astfel de prieten, acesta i-a si dat papucii, deoarece o astfel de fata nu poate fi decat un jeg de fata, si el nu suporta jegul.\r\n\r\nMai trebuie sa ma mai gandesc la varianta cu pwla mare, dar nu gasesc apsolut nici un cusur unei asemenea variante.\r\n\r\n<em>The End</em>','Poveste trista, da\' funny',0,'','publish','open','open','','poveste-trista-da-funny','','','2007-10-21 12:04:46','2007-10-21 10:04:46','',0,'http://www.groparu.ro/?p=712',0,'post','',19),(713,1,'2007-10-22 11:05:08','2007-10-22 09:05:08','<a href=\"http://nenea.wordpress.com/2007/10/21/leapsa-de-la-nentu-cosmos/\" target=\"_blank\">Cozmos</a> (sau univers, aceste cuvinte ne doare!) m-o lepsuit, ca-mi vine sa ma-ngrop de rusinica. Cica prima carte pe care-am cetit-o in viata mea... pfuaaaay!\r\n\r\nIo numa atata mai tiu minte ca o fost o carte de joc cu femei guale, nu mai stiu ce editura. Sau Bunicul si Bunica de Delavrancea...? Pot numa atata sa zic ca io, in copkilarie, cartea pe care am cetit-o cu cel mai mare drag a fost Legendele Olimpului, partea aia cu Zeus si cu nesfarsitele sale iubite. Si partea aia cu Dionisos, care le baga, mÄƒre, la vinoase, de parca a doua zi urma sa fie luni dimineatza la birou. Si cartea asta o ceteam si rasciteam cand veneam acasa de la scoala la 12 la amiaz, si imi faceam pita prajita data cu usturoi si cu untura d-aia buna, de porc de care nu papa islamijtii, si beam lapte de casa pe care ni-l aducea o taranca din Bungard, de langa Sibiu, taranca cu care AM AVUT CELE MAI INDELUNGATE SI PERSISTENTE SI PERENE SI OBSEDANTE FANTEZII SEXUALE DIN TOATE COPILARIA MEA (in afara, bine-nteles, de mama unui vecin, alte vreo 8 colege de clasa, surorile tuturor tovarasilor din bloc si ale colegilor de clasa, fetele din blocul de vizavi, Elke care mi-a spart capul pe la 9 ani, liceencele care cand veneau acasa treceau pe sub balconul meu si io le udam cu apa ca sa ma distrez, prietenele si colegele sor-mii - toate, prietenele prietenilor din gasca lu\' sor-mea, si nu mai continuu, ca lista lu Schindler e mic copkil!!!!)\r\n\r\nLiapsa i-o dau lu cui vrea sa o primeasca, ca e contagioasa, dar o dau indeosebi celui mai proaspat fan groparesc, pre numele lui <a href=\"http://nandos.wordpress.com/\" target=\"_blank\">Nandos</a> - ca si strutzu\', numa\' ca cu -os la final.','Prima carte cetita',0,'','publish','open','open','','prima-carte-cetita','','\nhttp://nenea.wordpress.com/2007/10/21/leapsa-de-la-nentu-cosmos/','2007-10-22 11:05:08','2007-10-22 09:05:08','',0,'http://www.groparu.ro/?p=713',0,'post','',9),(714,1,'2007-10-22 16:35:36','2007-10-22 14:35:36','','basescu.JPG',0,'','inherit','open','open','','basescujpg','','','2007-10-22 16:35:36','2007-10-22 14:35:36','',711,'http://www.groparu.ro/wp-content/uploads/2007/10/basescu.JPG',0,'post','image/jpeg',0),(715,1,'2007-10-23 15:08:21','2007-10-23 13:08:21','E oficial, finca numa\' amu am aflat si io:\r\n\r\nSpermatozoizii cu cromozom Y (aia care stie biologie ca mine sa afle ca astia is viitori masculi, adica iese bloggeri din ei) cica nu traiesc decat 2 zile.\r\n\r\nSpermatozoizii cu cromozom X (aia care stie biologie ca mine sa afle ca astia is viitoare domnisoare, adica ies bloggeritze din ei) cica traiesc pana-n cinci zile.\r\n\r\nAsta din cauza ca astia din urma mai traiesc pana isi termina povestile.\r\n\r\nBrisca si cureaua lata, io-te ce spermatozoid eram odata:\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/10/sperm-egg.jpg\" title=\"http://en.wikipedia.org/wiki/Spermatozoon\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/10/sperm-egg.jpg\" alt=\"http://en.wikipedia.org/wiki/Spermatozoon\" /></a>','Despre spermatozoizi campioni',0,'','publish','open','open','','despre-spermatozoizi-campioni','','','2007-10-23 15:26:18','2007-10-23 13:26:18','',0,'http://www.groparu.ro/?p=715',0,'post','',12),(716,1,'2007-10-23 09:35:51','2007-10-23 07:35:51','http://en.wikipedia.org/wiki/Spermatozoon','http://en.wikipedia.org/wiki/Spermatozoon',0,'','inherit','open','open','','httpenwikipediaorgwikispermatozoon','','','2007-10-23 09:35:51','2007-10-23 07:35:51','',-1193124345,'http://www.groparu.ro/wp-content/uploads/2007/10/sperm-egg.jpg',0,'post','image/jpeg',0),(717,1,'2007-10-24 10:57:16','2007-10-24 08:57:16','Finca neshte rebeli kurzi ii tot hartuiesc, Turcia e hotarata sa atace nordul Irakului.\r\n\r\nAvand in vedere acest precedent, Marele Stat Major al Gropariei Mari a hotarat:\r\n\r\n\"Finca neshte studente ma tot hartuiesc ne-ncetat prin autobuze, birtoteci, sau pe stradÄƒ, agresÃ¢ndu-ma vizual cu decoltee, craci, fuste mini, tricouri mulate, blugi cu talie joasa, burice, pirsinguri, glezne dezvelite, sfarcuri intarite prin tricouri si maiouashe, gambe epilate si bronzate, deÅŸte de la picioare numa\' bune de bagat in tigaie ca delicati carnaciori de bere, antebrate acoperite cu piele fina care te mangaie \"din greseala\" pe antebratul tau in autobuz, priviri sexy din spatele ochelarilor, par care miroase a rai, mÃ¢nuÅ£e mici cu care se proptesc in tine cand autobuzul pune frana brusca, urechiuse mici de manguste, funduri bombate si rotunde, uneori abia intrezarite din spatele unor fuste lungi, curbe trupeÅŸti demne de imortalizat Ã®n statui greceÅŸti, ce mai! Un Ã®ntreg univers.\r\n\r\nÅži ca sa termin fraza, fincÄƒ aceste trupuri feminine locuite de spirite feminine mÄƒ hÄƒrÅ£uie ne-ncetat, io, Groparu, aÅŸ Ã®ntreprinde o expediÅ£ie de pedepsire la ele acasÄƒ, adicÄƒ voi Ã®ncepe cu cÄƒminul 6, cÄƒ acolo-s literate de-ale mele, aÅŸ continua cu cÄƒminul 5, apoi cÄƒminele medicinei, cÄƒminele de la ISE, 4 crÃ¢jme studenÅ£eÅŸti din urbe, Ã®nca 6 cluburi, apoi aÅŸ extinde operaÅ£iunea la nivel naÅ£ional!\r\n\r\nCINE E CU MINE? ÃŽNAINTEEEEEE, LA KURDU\' LOR, COPIII MEI!!!!\"','Turcia ataca Irakul!',0,'','publish','open','open','','turcia-ataca-irakul','','','2007-10-24 11:44:13','2007-10-24 09:44:13','',0,'http://www.groparu.ro/?p=717',0,'post','',31),(718,1,'2007-10-24 18:10:29','2007-10-24 16:10:29','<a href=\"http://www.groparu.ro/wp-content/uploads/2007/10/20070831013740flpaofidenrphq2xhxyf5k450.jpg\" title=\"http://www.istanbul.com/Content.aspx?CatId=3899&amp;Type=detail\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/10/20070831013740flpaofidenrphq2xhxyf5k450.jpg\" alt=\"http://www.istanbul.com/Content.aspx?CatId=3899&amp;Type=detail\" /></a>\r\n\r\nDeci, din cate stiu, ca am verificat, sultanul cel mare al Turciei rezida in Istanbul. Sh acolo avea harem, si acolo primea tributuri si tot acolo le rÄƒpea el nevestelor si sclavelor sale fecioria (ceea ce mie mi se pare destul de cool).\r\n\r\nDaca el nu rezida in Istanbul, nu avea cum sa-l primeasca pe Alexandru Ioan Cuza la el la birou, Ã®n Istanbul. Si legenda zice ca atunci cand o venit Cuza la el ca sÄƒ-l convingÄƒ sÄƒ accepte unirea Moldovei cu Å¢ara RomÃ¢neascÄƒ, Ã®n loc sa <em>linga praful din faÅ£a tronului</em>, cum pÄƒÅ£eau ÄƒilanÅ£i  vasali, Cuza nost\' s-o dus, coios ÅŸi nervos, ÅŸi numa s-o uitat la sultan cu o privire de soacrÄƒ. Sultanu\' (zice-se) ar fi zis \"Aferim!\", nu \"Siktir!\", ÅŸi iata - valahii cu moldovenii s-au unit, asa cum scrie in Biblie, si au devenit un singur trup.\r\n\r\nUlterior, in frumosul oras cu trasura de unire in care locuiesc eu, cineva s-a gandit sa ii inalte o statuie lui Cuza.\r\n\r\nPe soclul statuii mi-am sprijinit eu azi piciorul cÃ¢nd m-am legat la sireturi.\r\n\r\nDaca nu ar fi fost orasul Istanbul, Cuza nu ar mai fi avut, probabil, statuie, iar eu as fi ramas, putoare cum sunt, cu siretul nedesfacut, as fi calcat pe el si mi-as fi rupt gÃ¢Å£ii din dotare.\r\n\r\nÅži toate acestea se Ã®ntÃ¢mplÄƒ Ã®n RomÃ¢nia, o Å£arÄƒ europeanÄƒ.','De ce oraÅŸul Istanbul mi-a salvat viatza',0,'','publish','open','open','','de-ce-orasul-istanbul-mi-a-salvat-viatza','','','2007-10-24 18:16:08','2007-10-24 16:16:08','',0,'http://www.groparu.ro/?p=718',0,'post','',5),(719,1,'2007-10-24 18:10:15','2007-10-24 16:10:15','http://www.istanbul.com/Content.aspx?CatId=3899&Type=detail','http://www.istanbul.com/Content.aspx?CatId=3899&Type=detail',0,'','inherit','open','open','','httpwwwistanbulcomcontentaspxcatid3899typedetail','','','2007-10-24 18:10:15','2007-10-24 16:10:15','',-1193241288,'http://www.groparu.ro/wp-content/uploads/2007/10/20070831013740flpaofidenrphq2xhxyf5k450.jpg',0,'post','image/jpeg',0),(720,1,'2007-10-25 15:00:47','2007-10-25 13:00:47','Deci sÃ¢mbÄƒta trecutÄƒ, cÄƒ aÅŸe mÄƒ luai cu treaba cÄƒ uitai sa va zic.\r\n\r\nDeci oraÅŸul Turda, pe lÃ¢ngÄƒ cÄƒ e unul dintre cele mai frumoase oraÅŸe din RomÃ¢nia, locul 2 dupÄƒ CopÅŸa MicÄƒ, are de toate: chei, salinÄƒ, bÄƒi sÄƒrate, castru roman, blocuri, peisaje industriale ÅŸi rromales o liotÄƒ, din-Äƒia grei.\r\n\r\nLanga Turda se afla alte orase mai mici, dar de importanta regionala, cum ar fi Clujul. De asemenea, apa cristalina care trece prin urbe se cheama ArieÅŸ, atÃ¢ta numa ca nu o poÅ£i vedea, finca are coloarea cafelei.\r\n\r\nTot lÃ¢ngÄƒ Turda se aflÄƒ Cheile Turzii; Yala Turzii inca nu s-o inventat, deci nu poti inca descuia nimic cu cheile astea.\r\n\r\nO vizita la Turda incepe cu Salina. O vizita la Salina Turda incepe cu achitarea sumei modice de 8 lei, aproape trei euro (spre comparatie, cand am fost in Doiciland la nush ce castel coios din Bavaria, am achitat o marca sh 10 pfenigi la intrare).\r\n\r\nSalina e sublima, dar sa nu mergeti sambetele: e plin de autocare de prunci care tzipaaa, buey, tzipa ca descreieratii! Ia ui numa:\r\n\r\n[youtube v/FIadabo4KC0]\r\n\r\nLa intrare, se afla <em>PuÅ£ul</em> <em>celor 9 Å£ipete</em>, aÅŸa Ã®l cheamÄƒ, unde e bine sa iti arunci nevasta, ca ui numa cum se aude:\r\n\r\n[youtube v/PxXB8CnXRI8]\r\n\r\nIn salina e aer sarat, si e rece, si bate vantoasele, alte vantoase decat alea de la fasole. Cand bate, vantoasele ui ce forma face:\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/10/turda-salina.JPG\" title=\"Salina Turda\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/10/turda-salina.JPG\" alt=\"Salina Turda\" /></a>\r\n\r\nTot in salina, se afla niste faleze la vreo 30 de metri inaltime, si tu stai acolo suspendat si te uiti in jos, si scuipi in capu\' alora de jos.\r\n\r\nSalina e plina de oameni care is mai tuberculosi ca in poeziile lu\' Bacovia, si care cand tusesc flegmeaza pe jos tot felul de spute; sarea asta cu sputa o iau in manutza pruncii care vin cu clasa in excursie, si o duc la mama si la tata acasa, amintire din salina.\r\n\r\nIn continuare, periplul nostru a ajuns la o suita de poze, despre care va invit sa le savurati, daca nu ati calcat vreodata pe sarea cu sputa de la Salina Turda:\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/10/altar.JPG\" title=\"Salina Turda\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/10/altar.thumbnail.JPG\" alt=\"Salina Turda\" /></a> <a href=\"http://www.groparu.ro/wp-content/uploads/2007/10/altar2.JPG\" title=\"Salina Turda\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/10/altar2.thumbnail.JPG\" alt=\"Salina Turda\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/10/intrare-salina.JPG\" title=\"Salina Turda\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/10/intrare-salina.thumbnail.JPG\" alt=\"Salina Turda\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/10/perete-salina.JPG\" title=\"Salina Turda\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/10/perete-salina.thumbnail.JPG\" alt=\"Salina Turda\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/10/perete-salina-2.JPG\" title=\"Salina Turda\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/10/perete-salina-2.thumbnail.JPG\" alt=\"Salina Turda\" /></a>\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/10/perete-salina-3.JPG\" title=\"Salina Turda\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/10/perete-salina-3.thumbnail.JPG\" alt=\"Salina Turda\" /></a> <a href=\"http://www.groparu.ro/wp-content/uploads/2007/10/sala-mare.JPG\" title=\"Salina Turda\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/10/sala-mare.thumbnail.JPG\" alt=\"Salina Turda\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/10/trepte.JPG\" title=\"Salina Turda\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/10/trepte.thumbnail.JPG\" alt=\"Salina Turda\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2007/10/turturi.JPG\" title=\"Salina Turda\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/10/turturi.thumbnail.JPG\" alt=\"Salina Turda\" /></a>\r\n\r\nLa un moment dat, in ultima sala, ajungi la doo mese bÄƒÅŸite de ping-pong, ÅŸi lÃ¢ngÄƒ ele se aflÄƒ un bloc de sare ÅŸlefuitÄƒ, de zici cÄƒ-i sticlÄƒ.\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/10/bloc-gheatya-1.JPG\" title=\"Salina Turda\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/10/bloc-gheatya-1.JPG\" alt=\"Salina Turda\" /></a>\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/10/bloc-gheatya-2.JPG\" title=\"Salina Turda\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/10/bloc-gheatya-2.JPG\" alt=\"Salina Turda\" /></a>\r\n\r\nBlocul asta de sare trebe lins de oricine vrea sa-si faca poza cu el; dupa ce l-am lins si am facut poze cu limba scoasa lipitÄƒ de el, am Ã®ndemnat vreo 4 olandeji sÄƒ facÄƒ poze la fel, si mai ales i-am pus sa-ÅŸi lipeascÄƒ limba de blocu\' de sare exact acolo unde fuseserÄƒ limba noastra. Suvenir din Romania. Dupa aia i-am intrebat daca nu vor sa schimbe euro, si s-or tirat.\r\n\r\nAm iesit dupa aia. Iar despre periplul la castrul roman de la Turda - in emisiunea viitoare.\r\n\r\nPS: Si la iesire din salina, ui ce aveau astia la magazinu de suvenire!\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/10/la-taty-ni-greu.JPG\" title=\"Salina Turda\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/10/la-taty-ni-greu.JPG\" alt=\"Salina Turda\" /></a>','Salina Turda',0,'','publish','open','open','','salina-turda','','','2007-10-25 15:00:47','2007-10-25 13:00:47','',0,'http://www.groparu.ro/?p=720',0,'post','',12),(721,1,'2007-10-25 14:45:04','2007-10-25 12:45:04','Salina Turda','Salina Turda',0,'','inherit','open','open','','salina-turda','','','2007-10-25 14:45:04','2007-10-25 12:45:04','',-1193313262,'http://www.groparu.ro/wp-content/uploads/2007/10/turda-salina.JPG',0,'post','image/jpeg',0),(722,1,'2007-10-25 14:45:32','2007-10-25 12:45:32','Salina Turda','Salina Turda',0,'','inherit','open','open','','salina-turda-2','','','2007-10-25 14:45:32','2007-10-25 12:45:32','',-1193313262,'http://www.groparu.ro/wp-content/uploads/2007/10/bloc-gheatya-1.JPG',0,'post','image/jpeg',0),(723,1,'2007-10-25 14:45:53','2007-10-25 12:45:53','','bloc-gheatya-2.JPG',0,'','inherit','open','open','','bloc-gheatya-2jpg','','','2007-10-25 14:45:53','2007-10-25 12:45:53','',-1193313262,'http://www.groparu.ro/wp-content/uploads/2007/10/bloc-gheatya-2.JPG',0,'post','image/jpeg',0),(724,1,'2007-10-25 14:45:58','2007-10-25 12:45:58','Salina Turda','Salina Turda',0,'','inherit','open','open','','salina-turda-3','','','2007-10-25 14:45:58','2007-10-25 12:45:58','',-1193313262,'http://www.groparu.ro/wp-content/uploads/2007/10/bloc-gheatya-2.JPG',0,'post','image/jpeg',0),(725,1,'2007-10-25 14:46:34','2007-10-25 12:46:34','Salina Turda','Salina Turda',0,'','inherit','open','open','','salina-turda-4','','','2007-10-25 14:46:34','2007-10-25 12:46:34','',-1193313262,'http://www.groparu.ro/wp-content/uploads/2007/10/altar.JPG',0,'post','image/jpeg',0),(726,1,'2007-10-25 14:46:46','2007-10-25 12:46:46','Salina Turda','Salina Turda',0,'','inherit','open','open','','salina-turda-5','','','2007-10-25 14:46:46','2007-10-25 12:46:46','',-1193313262,'http://www.groparu.ro/wp-content/uploads/2007/10/altar2.JPG',0,'post','image/jpeg',0),(727,1,'2007-10-25 14:47:03','2007-10-25 12:47:03','Salina Turda','Salina Turda',0,'','inherit','open','open','','salina-turda-6','','','2007-10-25 14:47:03','2007-10-25 12:47:03','',-1193313262,'http://www.groparu.ro/wp-content/uploads/2007/10/intrare-salina.JPG',0,'post','image/jpeg',0),(728,1,'2007-10-25 14:47:18','2007-10-25 12:47:18','Salina Turda','Salina Turda',0,'','inherit','open','open','','salina-turda-7','','','2007-10-25 14:47:18','2007-10-25 12:47:18','',-1193313262,'http://www.groparu.ro/wp-content/uploads/2007/10/perete-salina.JPG',0,'post','image/jpeg',0),(729,1,'2007-10-25 14:47:39','2007-10-25 12:47:39','Salina Turda','Salina Turda',0,'','inherit','open','open','','salina-turda-8','','','2007-10-25 14:47:39','2007-10-25 12:47:39','',-1193313262,'http://www.groparu.ro/wp-content/uploads/2007/10/perete-salina-2.JPG',0,'post','image/jpeg',0),(730,1,'2007-10-25 14:47:55','2007-10-25 12:47:55','Salina Turda','Salina Turda',0,'','inherit','open','open','','salina-turda-9','','','2007-10-25 14:47:55','2007-10-25 12:47:55','',-1193313262,'http://www.groparu.ro/wp-content/uploads/2007/10/perete-salina-3.JPG',0,'post','image/jpeg',0),(731,1,'2007-10-25 14:48:10','2007-10-25 12:48:10','Salina Turda','Salina Turda',0,'','inherit','open','open','','salina-turda-10','','','2007-10-25 14:48:10','2007-10-25 12:48:10','',-1193313262,'http://www.groparu.ro/wp-content/uploads/2007/10/sala-mare.JPG',0,'post','image/jpeg',0),(732,1,'2007-10-25 14:48:24','2007-10-25 12:48:24','Salina Turda','Salina Turda',0,'','inherit','open','open','','salina-turda-11','','','2007-10-25 14:48:24','2007-10-25 12:48:24','',-1193313262,'http://www.groparu.ro/wp-content/uploads/2007/10/trepte.JPG',0,'post','image/jpeg',0),(733,1,'2007-10-25 14:48:37','2007-10-25 12:48:37','Salina Turda','Salina Turda',0,'','inherit','open','open','','salina-turda-12','','','2007-10-25 14:48:37','2007-10-25 12:48:37','',-1193313262,'http://www.groparu.ro/wp-content/uploads/2007/10/turturi.JPG',0,'post','image/jpeg',0),(734,1,'2007-10-25 14:49:23','2007-10-25 12:49:23','Salina Turda','Salina Turda',0,'','inherit','open','open','','salina-turda-13','','','2007-10-25 14:49:23','2007-10-25 12:49:23','',-1193313262,'http://www.groparu.ro/wp-content/uploads/2007/10/la-taty-ni-greu.JPG',0,'post','image/jpeg',0),(735,1,'2007-10-25 16:00:24','2007-10-25 14:00:24','Stiti cum? Finca am facut pishu acolo unde or facut, inaintea mea, sute de legionari din legiunea nu shtiu cat Gemina, parcata la Turda-Potaissa. Io-te-ma-s:\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/10/pishu.JPG\" title=\"Castrul roman Turda\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/10/pishu.JPG\" alt=\"Castrul roman Turda\" /></a>\r\n\r\nAm ajuns la castru dupa ce am intrebat fiecare picior de turdean iesit in cale, si care picior nu o fost in stare sa ma lamureasca unde e castrul si cum ajungem la el. Singura indicatie pretioasa a fost (citez din memorie) \"luati-o de la biserica in stanga, apoi pe cestalant drum, si-apai iara pe cestalant!\"\r\n\r\nN-am ajuns bine, ca am ajus in ceastalanta parte.','Cum mi-am dat seama ca sunt pui de daco-roman',0,'','publish','open','open','','cum-mi-am-dat-seama-ca-sunt-pui-de-daco-roman','','','2007-10-25 16:00:24','2007-10-25 14:00:24','',0,'http://www.groparu.ro/?p=735',0,'post','',15),(736,1,'2007-10-25 15:59:33','2007-10-25 13:59:33','Castrul roman Turda','Castrul roman Turda',0,'','inherit','open','open','','castrul-roman-turda','','','2007-10-25 15:59:33','2007-10-25 13:59:33','',-1193319438,'http://www.groparu.ro/wp-content/uploads/2007/10/pishu.JPG',0,'post','image/jpeg',0),(739,1,'2007-10-28 17:41:02','2007-10-28 15:41:02','','dsc00187.JPG',0,'','inherit','open','open','','dsc00187jpg','','','2007-10-28 17:41:02','2007-10-28 15:41:02','',737,'http://www.groparu.ro/wp-content/uploads/2007/10/dsc00187.JPG',0,'post','image/jpeg',0),(740,1,'2007-10-29 16:31:17','2007-10-29 14:31:17','Unii dintre voi mai stiti ca acum vreo 3 saptamani am vrut sa scot bani din bancomat, dar am fost suficient de tÄƒntÄƒ\' ca sÄƒ bag cardu\' inapoi in portofel, chitanta in buzunar si sa plec fara sa mai iau banii din bancomat. 400 RON, un fleac.\r\n\r\nAm facut cerere la Banca Transilvania ca sa anuleze tranzactia, si deja procesul dureaza de 3 saptamani incoace, cu vizite tot la 3-4 zilela banca, si Äƒia ma tÄƒt amÃ¢nÄƒ.\r\n\r\nAzi, cand am ajuns, olecutza exasperat de cat de mult se intinde procesul, zice tanti de la ghiseu:\r\n\r\n- Numa otzara, domnu\' Groparu, ca mai am aicea cereri de anulare de tranzactii, trebuie sa va gasesc in teancu\' asta mare.\r\n- Ha! zic io, deci mai sunt tantalai ca mine care uita sa scoata banii din bancomat?\r\n- Da, zice domnisoara.\r\n\r\nCu alte cuvinte, tocmai am fost facut tÄƒntÄƒlau, pe banii mei.\r\n\r\nNu m-am suparat.','Banca Transilvania',0,'','publish','open','open','','banca-transilvania','','','2007-10-29 16:31:17','2007-10-29 14:31:17','',0,'http://www.groparu.ro/?p=740',0,'post','',7),(741,1,'2007-10-30 01:45:14','2007-10-29 23:45:14','','dsc00176.JPG',0,'','inherit','open','open','','dsc00176jpg','','','2007-10-30 01:45:14','2007-10-29 23:45:14','',742,'http://www.groparu.ro/wp-content/uploads/2007/10/dsc00176.JPG',0,'post','image/jpeg',0),(742,1,'2007-10-30 01:50:59','2007-10-29 23:50:59','No comment.\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/10/dsc00176.JPG\" title=\"dsc00176.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/10/dsc00176.JPG\" alt=\"dsc00176.JPG\" height=\"280\" width=\"373\" /></a>\r\n\r\nPS: si daca imi spunetz ca nu vi-i greu, insamna ori ca a) avetz cÄƒpÄƒlÄƒu\' plin cu heliu, ori ca b) n-atz fo\' niciodata in Amsterdam.','La tatzi ni-i greu',0,'','publish','open','open','','la-tatzi-ni-i-greu','','','2007-10-30 02:01:07','2007-10-30 00:01:07','',0,'http://www.groparu.ro/?p=742',0,'post','',5),(743,1,'2007-10-30 01:50:24','2007-10-29 23:50:24','','dsc00176.JPG',0,'','inherit','open','open','','dsc00176jpg-2','','','2007-10-30 01:50:24','2007-10-29 23:50:24','',-1193701486,'http://www.groparu.ro/wp-content/uploads/2007/10/dsc00176.JPG',0,'post','image/jpeg',0),(744,1,'2007-10-30 01:52:34','2007-10-29 23:52:34','','dsc00186.JPG',0,'','inherit','open','open','','dsc00186jpg','','','2007-10-30 01:52:34','2007-10-29 23:52:34','',0,'http://www.groparu.ro/wp-content/uploads/2007/10/dsc00186.JPG',0,'post','image/jpeg',0),(750,1,'2007-10-31 22:28:39','2007-10-31 20:28:39','Deci tocmai ce vazui o reclama la Arctic Gaesti, la frigide(re), si asta le e sloganu, ca Arctic e inspirat din viatza mea, si atata m-o amuzat ca si acuma rÃ¢z.\r\n\r\nIo localitatea Gaesti o stiu finca odata m-o loat la ocazie cel mai sofer curvar din Gaesti, care lucra pentru fabrica de frigide(re) si transporta frigide(re). Cel mai curvar din gaesti? Din Balcani!!!! Prima intrebare pe care mi-o pune: Cum ii cu gajicile in Cluj? Io nu i-am zis, finca gentlemen si Groparu never tell. Asa ca s-o apucat el sa-mi zica povestile lui.\r\n\r\nCica asta o futut orice traseista pe langa care o trecut cu masina: urata, schioapa, stirba, grasa, gravida, batrana, transpirata, sashie, ochelarista, slabanoaga, fara tzatze, cu mustatza, de- sau neepilata, minora, cu cur mare sau mic, bunicutza sau scolaritza, cu copiii de manutza, cheala in cap, spalata sau nu (mai ales nu), cu vrabiutza rasa sau infoiata ca un par de african, cu piercing sau tatuaje, tat! Tat ce o umblat in doo picioare si o fost disponibila pentru suma minima de pe piata, cu reducere, pentru soferii care au buget redus si zboara la clasa \"economic\". Mi-o povestit si cum o fost in Turcia cu bijnitzereala, si inainte de asta s-o futut cu curva satului, si aia i-o dat latzei; si cum se statea cate 2 zile la vama dinspre Turcia, si el era paros, si pÄƒduchiuÅ£ii s-or inmultit ca iepurii pe la el prin pilozitate, si el o dat la tot autocaru\', si dupa aia o ajuns acasa si s-o barbierit pe tot corpu, de s-o facut ca o prunca! Si alta data un prekin de-al lui din Gaesti o loat sifilis de la altÄƒ curva a satului, si o fugit din spital si le-o vizitat pe toate nevestele satenilor, si o imprastiat bolejnitza prin mediul rural. Si cand Politia l-o prins sa dea cu subsemnatu\' cÄƒ cu cine o avut rapoarte sexuale, asta o umplut vreo 4 pajini! Si cand politaiu\' s-o crizat, asta o zis \"Da\' ce! Numa de mine sa rÃ¢dÄƒ satu\'?\"\r\n\r\nOricum, apoplexia era sa ma loveasca numa\' cand mi-o povestit el cum o loat si el sifilis de la una de pe drum, si o ajuns acasa, si i-o dat si la nevasta-sa, care era un pic gravida prin luna a sasea, sau ceva de genu\'. NOROCU\' LUI de la Dumnezau ca or mers degraba la spital si copkilu o iesit cumsecade, ca uitai sa va zic ca nenea avea si doi copkii si si nevasta, ca cica de regula astea vin la oferta. Si dupa aia o umblat 4 luni sa o calce cu masina pe curva aia care i-o dat sifilis, da\' n-o mai gasit-o niciodata, probabil a fugit in Polonia.\r\n\r\nSi nevasta-sa l-o iertat, si il iarta mereu, ca asa e cu nebunu\', ca el o zis ca daca ea nu il iarta, o cafteste bine. Si el i-o zis ei cÄƒ ce sÄƒ facÄƒ, ca daca i se scoala pula cand conduce nu mai poate invarti volanu\', ca ii blocheaza manevrele.\r\n\r\nMnoa, un astfel de om m-o loat pe mine la ocazie.\r\n\r\nSi acuma stau si io, gandindu-ma la sloganu de la Arctic: inspirat din viatza ta, cica. Asta ar fi o prapastie, sau macar un Nagasaki, o explozie de ebola sau o a doua guvernare PNTcd-ista, zic io. Daca frigid(eru\') e inspirat din viatza mea, atunci e betivan, preacurvar, injura, bea cat il tine buzunaru\', fumeaza cat un sultan, lasa orice ca sa fixeze cu felinarele un decolteu de orice fel, s-ar pisha in cancelarie, si multe altele despre care veti afla la timpu\' potrivit, ca doara d-aia am blog. Da\' ma intreb:\r\n\r\nDACA FRIGIDE(RE)LE ARCTIC SUNT INSPIRATE DIN VIATZA SOFERILOR LOR???','Cica inspirat din viatza mea',0,'','publish','open','open','','cica-inspirat-din-viatza-mea','','','2007-10-31 22:28:39','2007-10-31 20:28:39','',0,'http://www.groparu.ro/?p=750',0,'post','',3),(746,1,'2007-10-30 10:19:45','2007-10-30 08:19:45','Azi e marti, deci e folbal.\r\n\r\nFinca martea trecuta am reusit sa imi rup la folbal pantofii mei cu toc, aseara, cand imi faceam bagaju\' pentru azi, m-am apucat sa aleg o pereche de adidasi mai vechi, pe care  sa ii iau cu mine ca sa pot juca folbal azi.\r\n\r\nUnica unitate de masura a adidasilor care sunt alesi Ã®n aceastÄƒ posturÄƒ ingratÄƒ este gradul de Ã®mpuÅ£Ã¢cenie: cu cat sunt mai vechi, cu atÃ¢ta put mai rau, deci sansele sa fie purtati la OperÄƒ devin nule.\r\n\r\nMi-am dat seama in curÃ¢nd cÄƒ puteam loa la folbal orice pereche: toate puÅ£eau la fel.\r\n\r\nÅži mi se pare normal sÄƒ fie aÅŸa, din moment ce aceeaÅŸi toÅ£i adidaÅŸii au purtat aceeaÅŸi pereche de picioare!','Din seria: stiu ca imi pute gura, da\' macar nu miros a transpiratie!',0,'','publish','open','open','','din-seria-stiu-ca-imi-pute-gura-da-macar-nu-miros-a-transpiratie','','','2007-10-30 10:19:45','2007-10-30 08:19:45','',0,'http://www.groparu.ro/?p=746',0,'post','',12),(748,1,'2007-10-30 16:51:06','2007-10-30 14:51:06','<span lang=\"IT\">Ati auzit ca vor sa ne modifice statuia celui mai mare rege al Ungariei, romÃ¢nul Matei Corvin?<o:p></o:p></span>\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/10/dsc00186.JPG\" title=\"dsc00186.JPG\"><span style=\"text-decoration: none\"><!--[if gte vml 1]><v:shapetype  id=\"_x0000_t75\" coordsize=\"21600,21600\" o:spt=\"75\" o:preferrelative=\"t\"  path=\"m@4@5l@4@11@9@11@9@5xe\" filled=\"f\" stroked=\"f\">  <v:stroke joinstyle=\"miter\"/>  <v:formulas>   <v:f eqn=\"if lineDrawn pixelLineWidth 0\"/>   <v:f eqn=\"sum @0 1 0\"/>   <v:f eqn=\"sum 0 0 @1\"/>   <v:f eqn=\"prod @2 1 2\"/>   <v:f eqn=\"prod @3 21600 pixelWidth\"/>   <v:f eqn=\"prod @3 21600 pixelHeight\"/>   <v:f eqn=\"sum @0 0 1\"/>   <v:f eqn=\"prod @6 1 2\"/>   <v:f eqn=\"prod @7 21600 pixelWidth\"/>   <v:f eqn=\"sum @8 21600 0\"/>   <v:f eqn=\"prod @7 21600 pixelHeight\"/>   <v:f eqn=\"sum @10 21600 0\"/>  </v:formulas>  <v:path o:extrusionok=\"f\" gradientshapeok=\"t\" o:connecttype=\"rect\"/>  <o:lock v:ext=\"edit\" aspectratio=\"t\"/> </v:shapetype><v:shape id=\"_x0000_i1025\" type=\"#_x0000_t75\" alt=\"dsc00186.JPG\"  href=\"http://www.groparu.ro/wp-content/uploads/2007/10/dsc00186.JPG\" title=\"&quot;dsc00186.JPG&quot;\"  style=\'width:274.5pt;height:362.25pt\' o:button=\"t\">  <v:imagedata src=\"file:///C:\\DOCUME~1\\Jupan\\LOCALS~1\\Temp\\msohtml1\\01\\clip_image001.jpg\"   o:href=\"http://www.groparu.ro/wp-content/uploads/2007/10/dsc00186.JPG\"/> </v:shape><![endif]--><!--[if !vml]--><span><img src=\"http://www.groparu.ro/wp-content/uploads/2007/10/dsc00186.JPG\" alt=\"dsc00186.JPG\" v:shapes=\"_x0000_i1025\" border=\"0\" height=\"483\" width=\"366\" /></span><!--[endif]--></span></a><o:p></o:p>\r\n\r\nSub pretextul ca se renoveaza statuia lui Matthias, am surse foarte sigure care mi-au confirmat ca urmatoarele schimbari i se vor aduce statuii, schimbÃ¢nd-o. Voi ce credetz?:<o:p></o:p>\r\n<script language=\"javascript\" src=\"http://www.polldaddy.com/p/128950.js\"> </script> <noscript> <a href =\"http://www.polldaddy.com\" >Free Polls</a> - <a href =\"http://www.polldaddy.com/poll.asp?p=128950\" >Take Our Poll</a> </noscript>\r\n','Statuia lui Matthias',0,'','publish','open','open','','statuia-lui-matthias','','','2007-10-30 16:51:06','2007-10-30 14:51:06','',0,'http://www.groparu.ro/?p=748',0,'post','',14),(749,1,'2007-10-30 22:26:17','2007-10-30 20:26:17','DacÄƒ bÄƒnuiaÅ£i cumva cÄƒ sunt scrÃ¢ntit oleacÄƒ, Ã®mi pare rÄƒu, dar realitatea crudÄƒ mÄƒ sileÅŸte sÄƒ vÄƒ confirm: da, piciorul meu tocmai a facut un dublu triplu salt cu Å£ukahara, sucindu-se un pic (720 grade) Ã®n jurul propriei sale axe, Ã®ntr-o Ã®ncercare vanÄƒ (sau cadÄƒ) de a recupera balonul rotund de la un oponent. DacÄƒ balonul a supravieÅ£uit, glezna, mai deÅŸteaptÄƒ, a cedat.\r\n\r\nAvÃ¢nd Ã®n vedere cÄƒ am ÅŸi bÄƒgat un gol (uimitor, dar Ã®n poarta adversÄƒ!), consider cÄƒ un picior gropÄƒresc jertfit pe altarul unui sport pe care nu-l plac (sentimentul e reciproc), nu-l Ã®nÅ£eleg ÅŸi nu-l nimic este un fleac. DeÅŸi mau ciuruit de mi-au luat m-au\'.\r\nCine zicea cÄƒ e numai un joc minÅ£ea. Sau era politician. Ceea ce de fapt se refera la aceeaÅŸi chestie cu picioare scurte.\r\n\r\nDacÄƒ mÄƒ atacÄƒ tribul lesbienelor, aÅŸa cum sper mereu de-o vreme, va trebui sÄƒ aplic faza Karate Kid, secvenÅ£ele cÃ¢nd era ÅŸi el cu Å£urloaiele paradite. Oricum, doresc sÄƒ transmit ÅŸi pe aceastÄƒ cale cÄƒ voi ceda la primul val de atac, clar.\r\n\r\nIar morÅ£ii am sa-i transmit decÃ¢t un singur mesaj: \"CurvÄƒ proastÄƒ, iar ai dat greÅŸ! ÃŽn locu\' lu Dumnezau te-as concedia!\" (a nu se uita cÄƒ numai Ã®n ultimele 3 luni am rÄƒnit cada cu un cap bine Å£intit, am avut un accident de bicicleta, am pÄƒpat zmeurÄƒ lÃ¢ngÄƒ un nene Ã®mbrÄƒcat in blanÄƒ de urs, am avut o discuÅ£ie in contradictoriu cu <a href=\"http://www.andreicrivat.ro\" target=\"_blank\">CrivÄƒÅ£</a> ÅŸi am ÅŸi beut cot la cot cu <a href=\"http://www.ciutacu.ro/\" target=\"_blank\">Ciutacu</a>! ca sÄƒ nu mai menÅ£ionez cÄƒ circul zilnic cu RATUC, mai nou, ieri am pÄƒpat o felie de parizer unguresc, ÅŸi am ÅŸi Å£inut un bebeluÅŸ Ã®n braÅ£e - toate fiind chestii considerate, Ã®n cercurile de neofiÅ£i, drept foarte mortale)','PÃ¢nÄƒ la scrÃ¢ntealÄƒ, ÅŸi dincolo de ea!',0,'','publish','open','open','','pana-la-scranteala-si-dincolo-de-ea','','','2007-10-30 22:26:17','2007-10-30 20:26:17','',0,'http://www.groparu.ro/?p=749',0,'post','',6),(751,1,'2007-10-31 23:18:55','2007-10-31 21:18:55','Cand in atomic cataclism s-o sÄƒvÃ¢rÅŸi planeta\r\nTu sa rÄƒmÃ¢i cu pula ca racheta,\r\nCu coaiele din fier de ancorÄƒ,\r\nFemeia ta s-aiba contur de amforÄƒ!\r\nSi coniacul ce il bei la ceas de searÄƒ\r\nSa-Å£i schimbe gustul dacÄƒ ai gura amarÄƒ,\r\nFruntaÅŸ la Å¢iganiada sÄƒ rÄƒmÃ¢i,\r\nDuÅŸmanii sÄƒ Å£i-i spÃ¢nzuri de un cui,\r\nDeÅŸtept ca un LuceafÄƒr sÄƒ ajungi,\r\nSÄƒ nu cheleÅŸti, ci sÄƒ ai plete lungi,\r\nSÄƒ te iubeascÄƒ banii cum vor pruncii lapte,\r\nSÄƒ fii potent, copii sÄƒ faci vreo ÅŸapte,\r\nFicatu\' sa iti mearga ca si uns,\r\nLa Ã®ntrebÄƒri sÄƒ ai mereu rÄƒspuns,\r\nSÄƒ nu fii pesedist ca Agathon\r\nCÄƒci tu eÅŸti cel mai tare <em>maricon</em>,\r\nSÄƒ fii constant ÅŸi Ã®ncÄƒpÄƒÅ£Ã¢nat ca o pendulÄƒ,\r\nÅži cÃ¢nd il vezi pe var-tu, sÄƒ-i spui sÄƒ-mi sug-o pulÄƒ!\r\n\r\nLA MULÅ¢I ANI, BÄ‚Ä‚Ä‚Ä‚Ä‚Ä‚Ä‚Ä‚Ä‚!!!!!!!','Azi e ziua lu\' Nelu, viitoru\' meu hin, membru fondator de bazÄƒ Å¢iganiada',0,'','publish','open','open','','azi-e-ziua-lu-nelu-viitoru-meu-hin-membru-fondator-de-baza-tiganiada','','','2007-10-31 23:18:55','2007-10-31 21:18:55','',0,'http://www.groparu.ro/?p=751',0,'post','',6),(752,1,'2007-11-01 12:47:24','2007-11-01 10:47:24','Pentru toti cei care isi bat capurile cu o botÄƒ de oinÄƒ Ã®ncercÃ¢nd sÄƒ gÄƒseascÄƒ o sursÄƒ alternativÄƒ de energie:\r\n\r\nBueeey, de ce nu-mi explicati mie cum un blid de mancare produce atata metan ca poÅ£i umfla un Montgolfier intreg? Ha???','Sursa inepuizabila de energie',0,'','publish','open','open','','sursa-inepuizabila-de-energie','','','2007-11-01 12:47:24','2007-11-01 10:47:24','',0,'http://www.groparu.ro/?p=752',0,'post','',1),(753,1,'2007-11-01 21:53:49','2007-11-01 19:53:49','Deeeeeeci, odiseea bancara 2007 continua.\r\n\r\nMie, de ceva vreme, imi tot dispar lunar cate 42 lei din contul meu, greu incercat, de alfel. Si dispar catre realone.com, unde odata mi-am facut abonament acum vreo 40 de ani sa le iau playeru\' ala de care auzisem ca poate inregistra live streaming radiouri de pe net. Da\' - din cate mai tiu io minte - nu le-am dat nr de card; de asta poci fi aproape 99% sigur. Da\' de vreo 8 luni (!!!) imi tot vireaza banca mea dragutza suma de mai sus catre buzunarele lor de engleji imperialisti, si io aflu - cu stupuare! - numa amu, adica alaltaieri. Deci inmultit cu cateva luni, dÄƒ o suma frumusica, mai ales daca o primesti.\r\nAseaaaa. Si cand aflu de jmenereala, pun repede manutza pe telefon, sun la banca mea (al carei nume nu il voi divulga aici, finca la faza asta s-or descurcat profi copiii -  atÃ¢ta numa va zic ca am contu la o banca polonezo-fino-ugricÄƒ-malaeziancÄƒ - sau nu) si le zic: bueeeeeey, opriti dreq tranzactiile astea de care io n-am habar!!!! Nu se poate, zice ei, meretz la sediul din Cluj sh acolo facetz cerere, cÄƒ asa, prin telefon, am putea sta de vorba si cu bunica dvs. senila care sa opereze tranzactii in numele dvs.!\r\n\r\nMa duc la sediu din Cluj, discut cu cea mai bunesa dintre consigliere (astea is de regula si cele mai pe dinafara), ma duce la un coleg super amabil, ii las cererea, ramane sa ma sune de la BucureÅŸti, ca noi, fiind in provincie, tre sa isi deie capitala giru\', si or sa ma sune iei.\r\n\r\nCapitala ma suna fix amu in urma cu trei minute:\r\n\r\n- Dl. Groparu, zice, ma iertati ca va deranjez (io ma jucam counterstrike), stiti, tre\' sa incercati sa va dezabonati de la saitu ala, care e sait de escroci, ca daca nu va dezabonati, io n-am ce face, ca banca, decat sa le aprob cererile de plata!\r\n- Fuck this shit, zic io, chiar e nevoie sa il iau ostatic pe Varujan Vosganian ca sa refuzati platile?\r\n- Ma intelegeti, zice el, noi fiind banca egipÅ£iano-bangladeÅŸo-srilankianÄƒ nu putem sa operam asa negÄƒri de platÄƒ dupa cum li se scoala la gropari!\r\n\r\nSi se lanseaza nenea meu intr-o lista de sfaturi ca ce sa fac cand mai cumpar de pe Internet, ca sa cetesc, atunci cand bifez \"I agree to all the shit you\'re giving me\", toata poliloghia aia de disclaimer si acceptance of terms and conditions sh bla bla, alea pe care nu le ceteste nimeni, ca is scrise cu litere de 4 microni jumate.\r\n\r\n- De ce sa le cetesc? intreb io.\r\n- Finca astea pot ascunde capcÄƒni, zice el.\r\n- Aaaa, zic io, exact ca la contractele de la bancÄƒ, zic io. CÄƒ semnezi una, si apai apare o clauzÄƒ contractualÄƒ care te violeazÄƒ ca-n puÅŸcÄƒrie.\r\n- Haha, face el. Oricum, in locul dvs. mi-aÅŸ anula abonamentul la saitu ala (la saitu ala unde am \"abonament\" imi arata la billing history \"no transactions have been performed never ever, Amen!!!\") si apai as veni cu dovada ca sa putem anula si noi eventualele cereri de plata de la ei.\r\n- Bon, zic io, fincÄƒ n-am de gÃ¢nd sÄƒ sun in Anglia si aia sa ma transfere la call centeru\' ala al lor din Bangalore sa ii zic la un indian ce si cum, am sa imi anulez cardu\' de la banca si fac cerere pentru altu, si uite asa felez un intreg imperiu britanic!\r\n- Cea mai buna optiune, zice nenea.\r\n- Eu tot timpul fac cele mai bune optiuni, mai putin alea legate de viata mea, oftesc io.\r\n- Bun, mai zice nenea, pot sa va pun o intrebare personala?\r\n\r\nHaiti! zic. Am pus-o. Te miri pantru ce gajica ne-am batut odata noi doi, si aia o plecat pentru al treilea! (ca io numa gajici d-astea am avut - sau nu).\r\n\r\n- Ati avut probleme acum ceva vreme cu un bancomat de la Banca Transilvania?\r\n- Da, zic io, am uitat sa scot neste bani din bancomat si i-o scos altcine... Stai otzara! Da de unde stiti dvs. de problemele mele cu Banca  Transilvania??? Ca aia e alta banca!!!\r\n<em>- Pai</em>,<em> </em>zice el, <em>v-am citit blogu\', vi-l citesc de vreo luna si ceva, si asa am aflat</em>.\r\n\r\nDeci iata, deci, ce starlet am ajuns! Si nici macar n-o fost nevoie sa cant <em>Numanumaiei</em> sau sa-mi dezvelesc buricu meu care, de alfel, este buricul buricului pamantului!','Deci cum era Groparu sa se scape la el in pantaloni de vedet ce e el (noroc ca era buda aproape)',0,'','publish','open','open','','deci-cum-era-groparu-sa-se-cace-pe-el-de-vedet-ce-e-el-noroc-ca-era-buda-aproape','','','2007-11-01 21:55:12','2007-11-01 19:55:12','',0,'http://www.groparu.ro/?p=753',0,'post','',19),(754,1,'2007-11-02 02:08:36','2007-11-02 00:08:36','1. ÃŽ: Cum puteti fi zilnic geniali?\r\nR: CitÃ¢ndu-mÄƒ!\r\n\r\n2. SÃ¢ngele apÄƒ nu se face. Da\' coniac Ã®l putem face?\r\n\r\n3. DacÄƒ s-a fÄƒcut Piraeus Bank, de ce nu se face ÅŸi GrÄƒtaros Bank?','Ganduri de vineri noapte',0,'','publish','open','open','','ganduri-de-vineri-noapte','','','2007-11-02 02:08:36','2007-11-02 00:08:36','',0,'http://www.groparu.ro/?p=754',0,'post','',2),(755,1,'2007-11-02 16:23:54','2007-11-02 14:23:54','Deci cu scarba de rigoare, ca o fo nevoie de 5 beri dupe aia sa imi taie greatza, m-am uitat la film. Filmu\' e o facatura. Aia e clar. Din cauza cÄƒ:\r\n\r\n1. Daca aia e gaura cheii, insamna ca garsoniera mea e propitatea aia a lu\' Trump de valoreaza 144 milioane de para.\r\n\r\n2. Se stie ca femeile maritate nu mai fac sex oral, finca l-or prins pe prost de coaie, si Äƒsta nu mai are cum scapa. Asta se ÅŸtie. Sexu oral e numa o aiureala la care femeile consimt ca sa il convinga pe mascul ca ea le e suflet pereche, si dupa cununie, gata! se inchide robinetu\' si el e obligat sa plimbe copiii prin parc si sa mearga cu ea in vizita la socri.\r\n\r\n3. Tot procesu\' felational dintre Iri si Moni e obscurat de un pahar de apa asezat <strong>strategic</strong> ca sa ascunda madularu\' columbean. Daca in locul paharului se afla o cutie de Viagra sau Cialis, mai aveam dubii ca nu e regizare; chiar si daca paharul avea urme de vin rosu. Da\' asa, mai tata, la ce i-o facut Moni sex oral lu Iri, daca membru, la etatea avuta, statea flasc ca un spanzurat?\r\n\r\nIo cred ca tocmai luasera o masa copioasa si ea s-o curatat intre dinti cu paru\' lui pubian, finca papase vita, si aia ramane intre dinti.','Iri si Moni face sex oral',0,'','publish','open','open','','iri-si-moni-face-sex-oral','','','2007-11-02 16:40:01','2007-11-02 14:40:01','',0,'http://www.groparu.ro/?p=755',0,'post','',7),(756,1,'2007-11-03 02:54:43','2007-11-03 00:54:43','<a href=\"http://fluture.blogs.com/\" target=\"_blank\">Flutelelele</a> s-o hotarat dintr-o data sa faca ce si pe mine ma bantuie de ceva vreme incoace de cand calitatea postarilor mele se tat dilueaza pana devine alcool pur: sa renunte la blogareala. Deci mie mi se pare o neseriozitate finca dupa ce m-o castigat cu stilu\' sau de scris si l-am bagat in blogroll pe cheltuiala mea si cu interventii mari (o trebuit sa imi dau spaga ca sa ma conving) acuma sa isi bage (pardon de expresie) unghiile de la picioare in toata afacerea si sa se mai si cace in blidu nostru de cititori cu orizonturi de asteptare blogaresti si sa ne lase baltoaca ca la un concert organizat in Romania!!!\r\n\r\nDeci sper sa revina la aceleasi tigari pe care le fuma cand blogarea. Si sa se potoleasca.\r\n\r\nIn aceasta postare am uitat cu desavarsire sa pun virgule, asa ca le pun aci: ,,,,,,,,,,,,,.','Flutelelele',0,'','publish','open','open','','flutelelele','','','2007-11-03 02:54:43','2007-11-03 00:54:43','',0,'http://www.groparu.ro/?p=756',0,'post','',9),(757,1,'2007-11-03 12:28:01','2007-11-03 10:28:01','Valea Viilor este un satuc sÄƒsesc aproape parasit, aÅŸa cum ÅŸade bine oricÄƒrui sÄƒtuc sÄƒsesc, aÅŸezat lÃ¢ngÄƒ cel mai frumos oraÅŸ din RomÃ¢nia: CopÅŸa MicÄƒ.\r\n\r\nI se spune Valea Viilor din motive lesne de Ã®nÅ£eles: toatÄƒ lumea ÅŸtie cÄƒ saÅŸii sibieni, cÃ¢nd beau, nu beau bere. Ei, cÃ¢nd beau, beau vin ÅŸi palincÄƒ ÅŸi jinars. Åži se zice cÄƒ Ã®n Brateiu, care e tot prin preajmÄƒ, cÃ¢nd or ajuns comuniÅŸtii, or adus o secÄƒturÄƒ care sÄƒ le facÄƒ la peizani educaÅ£ie anti-alcool. Åži Äƒsta o Ã®nceput sÄƒ le zicÄƒ la saÅŸi cÄƒ hÃ¢r, cÃ® mÃ¢r, cÄƒ ce rÄƒu face alcoolu\' la casa, ficatu ÅŸi nevasta omului, ÅŸi aÅŸa si pe dincolo, pÃ¢nÄƒ cÃ¢nd la un moment dat un sas zice:\r\n\r\n- ApÄƒi domnule comunist, acilea Ã®n sat nimeni nu bea alcool, fincÄƒ toÅ£i avem pÄƒlinca ÅŸi vinu\' nostru!\r\n\r\nMnoa, Ã®n aceastÄƒ zonÄƒ mÄƒ deplasez eu weekendu asta, ÅŸi mÄƒ voi kefui FIX ÃŽN CASA FOSTULUI POPÄ‚ SAS! Casa de gospodar, unde poti intoarce TIRu\' in ograda, ÅŸi oricine poate face tat ce vrea fincÄƒ este loc berechet. Si unde sunt niste poze din 1940 pe pereti cu sasi si sasoaice, care se uita la tine cu niste ochi alb-negru ÅŸi ar vrea si ei sa fie acolo, cu noi, da\' noua nu prea ne pasa. Si voi ajunge acolo ÅŸontÃ¢c-ÅŸontÃ¢c, fincÄƒ Ã®s Ã®ncÄƒ ÅŸchiop de la folbal, ÅŸi voi sta la ocazie, ca de obicei, 3 ore. Dar ce sacrificii nu fac eu ca sa beau cu sibienii mei Å£iganiazi! Acest lucru, de fapt, s-a demonstrat clinic.','Deci, Valea Viilor',0,'','publish','open','open','','deci-valea-viilor','','','2007-11-03 12:28:01','2007-11-03 10:28:01','',0,'http://www.groparu.ro/?p=757',0,'post','',3),(758,1,'2007-11-05 05:24:42','2007-11-05 03:24:42','Am intrat pe un Hub de DC cu nick-ul - normal - Groparu.\r\n\r\nM-am certat cu unu UnderTaker care zicea ca sa-mi schimb nick-ul: i-am explicat ca undertaker si gravedigger is doua chestii diferite, si nu o inteles, deci am primit kick.\r\n\r\nAm uitat de micul scandal, da\' azi m-am conectat la hub iara, si primesc mesajul asta:\r\n\r\n\"You\'re banned from this hub by UnderTaker because: <strong>numai </strong>stai cu nickul asta mai ales aici ;)\"\r\n\r\nSe zice ca masura valorii unui om e data de dusmanii sai. Prin urmare, va trebui sa imi gÄƒsÄƒsc niscai dusmani mai de calibru\' meu, care sa stie macar sa vorbeste si sa scrie cum trebuie, sau cel putin sa poatÄƒ viola limba romana cu artÄƒ, asa cum fac eu!!! CÄƒ pentru asta trebe puÅ£Äƒ, nu glumÄƒ.\r\n\r\nPS: ...as I happens to knows :D','Din seria \"cat esti de inteligent...!\"',0,'','publish','open','open','','din-seria-cat-esti-de-inteligent','','','2007-11-05 05:32:10','2007-11-05 03:32:10','',0,'http://www.groparu.ro/?p=758',0,'post','',9),(759,1,'2007-11-05 16:55:59','2007-11-05 14:55:59','Deci aceasta postare se refera numai la cei cu rate carora, ca si mie, le tremura mainile de ciuda cand platesc imprumuturile la banci si nu le mai vine sa dea drumu la bani din mÃ¢nÄƒ cand tanti functionara vrea sÄƒ-i ia.\r\n\r\nDeci cea mai mare frustrare de-a mea e ca nu pot sa le urez bÄƒncilor o sincerÄƒ\r\n\r\nMUIE!\r\n\r\npentru cÄƒ oricum bÄƒncile, dupÄƒ cum se ÅŸtie, NE SUG. PÃ¢nÄƒ ne usucÄƒ. Åži ar fi redundant sÄƒ le urÄƒm cuvÃ¢ntul acesta din patru litere de mai sus, pentru ca ele oricum asta fac!\r\n\r\nScuze pentru limbajul suburban, trivial si licentios. Da\' ziua mea de rate e singura zi din lunÄƒ cÃ¢nd, nu ÅŸtiu de ce, nu am apsolut nici un chef de bance!','Pentru oameni cu rate',0,'','publish','open','open','','pentru-oameni-cu-rate','','','2007-11-05 16:55:59','2007-11-05 14:55:59','',0,'http://www.groparu.ro/?p=759',0,'post','',17),(760,1,'2007-11-06 17:34:06','2007-11-06 15:34:06','Ca sa va intre bine-n cap: cu sibienii mei, orice chef iese asa cum se cheama mai nou <a href=\"http://demaio.wordpress.com/2007/06/21/benq-ne-ofera-qisda/\" target=\"_blank\">firma Benq, adeca Qisda</a>.\r\n\r\nCand ii am in preajma, io tare ma bucur, desi ficatzii mei protesteaza de fiecare dat\'. Io ce sa le fac? Mie nu prea imi pasa, chiar daca a doua zi ficatii se aliaza cu capu\', si sunt atacat, ca Imperiul Roman, din trei parti de dureri migratoare (a treia durere este, bine-nteles, durerea la la 4 kilometri din fatza cotului).\r\n\r\nDeeci. Se pleaca cu ocazia din Cluj, io Ã®ncÄƒ ÅŸchiop de la folbal, se gaseste o masina cu un nene care incearca sa ma combine cu fiica-sa, io refuz politicos, fincÄƒ nu are rost sÄƒ o nenorocesc pe biata fatÄƒ; si care sofer vorbeste cu un alt ocazionist din TÃ¢rnaveni, amandoi mai Ã®n etate, despre ce ficiori erau ei odatÄƒ, si cÃ¢Å£i boxeri, caratiÅŸti ÅŸi mineri or nenorocit cÃ¢nd erau tinerei.\r\n\r\nPreluat din frumosul oraÅŸ CopÅŸa de cÄƒtre Greuceanu, care Ã®ÅŸi ducea muncaÅŸii acasÄƒ. Am vÄƒzut la castele sÄƒseÅŸti pe acolo prin satele alea gen Brateiu ÅŸi Biertan cÄƒ Valea Loarei s-o ascuns de frica sa nu fie violatÄƒ. Acolo E DE MERS!!!\r\n\r\nClaro ca la un moment dat ne-am oprit din cauza oilor. Care se uita la noi cu ochi straini ÅŸi goi.\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/11/dsc01128.JPG\" title=\"dsc01128.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/11/dsc01128.JPG\" alt=\"dsc01128.JPG\" height=\"296\" width=\"394\" /></a>\r\n\r\nCa sa va dati si voi un pic seama de ce si cum, iote ce ghiers filomelic pe capul nostru!\r\n\r\n[youtube e8_fEboEPWE]\r\n\r\nAr mai fi foarte multe de spus, din care spicuiesc: cÄƒ am ajuns sÄƒ dorm Ã®n acelaÅŸi pat cu GreucicÄƒ, ÅŸi Äƒsta, la fiecare ghiont, sforÄƒia Ã®n altÄƒ gamÄƒ. O scos din el 64 de game in 4 minute, cÄƒ io cred cÄƒ d-aia o murit Pavarotti, de ciudÄƒ! Åži alte chestii, nu va mai plicti. CÄƒ nij nu le mai Å£in minte.\r\n\r\nDar apogeul urmeazÄƒ numai dupÄƒ chef.\r\n\r\nMa duc astia cu masina in CopÅŸa MicÄƒ. Aveam tren la ora 1.\r\n\r\nÃŽmi iau bilet, mÄƒ pun sÄƒ aÅŸtept.\r\n\r\nAPARE UN TREN PE CARE SCRIA \"CLUJ\", DA\' CARE MERGEA CATRE SIBIU.\r\n\r\nImi zic io-n sinea mea:\r\n\r\n- Baaa, ce prooosti, da\' projti-projti is astia de la CFR! Pai Cluju\' e-n stanga?\r\n\r\nDati-mi voie sÄƒ vÄƒ luminesc: da, era Ã®n stÃ¢nga, fincÄƒ trinu\' fÄƒcea un mic ocol spre TeiuÅŸ.\r\n\r\nSun repede prekinii - BÄƒÄƒÄƒÄƒÄƒ, veniÅ£ sÄƒ mÄƒ loaÅ£ cÄƒ am kert trinu!!!\r\n\r\nAjung in Sibiu, unde stau la ocazie. Åži unde, deÅŸi Ã®ncÄƒ nu Ã®mi trecuse smogul din faÅ£a ochilor, ÅŸi eram nebÄƒrbierit de vreo jde zile ÅŸi plin de tinÄƒ - cÄƒ la un moment dat fÄƒcusem rodeo cu mine Ã®nsuÅŸi noaptea de dinainte - ÅŸi crecÄƒ ÅŸi miroseam zdravÄƒn a pÄƒlinca de la micu\' dejun, opreÅŸte o maÅŸinÄƒ.\r\n\r\nÃŽnuntru - doo hiper-bunoace.\r\n\r\nDeci ce scrie pe saitu asta al meu e 100% adevarat.\r\n\r\nINCREDIBIL, am zis, AVETI INCREDERE SA MA LOATI PAN LA CLUJ? Da, zice ele, hai ca facem o fapta buna!\r\n\r\nAveau incredere in mine, care, ma repet, mirosam a palinca si eram nebarbierit, si privirea mea era aceeasi pe care o am cand ma uit la orice fomee - adeca se tradeaza ca as face cu ea (nu cu privirea!) aceleasi chestii pe care le face Jenna Jameson.\r\n\r\nDar m-am comportat frumos. Mi-am rÃ¢cÃ¢it o ultima bruma de bun simptz de pe fundu buzunarelor.\r\n\r\nSi avÃ¢nd io, aÅŸa, o viaÅ£Äƒ ca soarele sfÃ¢nt de pe cer, ÅŸi plinÄƒ de imprevizibil pe care eu mi-l auto-creez, cum dreq sÄƒ renunÅ£ io la sait???','Deci, Valea Viilor de weekendu\' asta',0,'','publish','open','open','','deci-valea-viilor-de-weekendu-asta','','\nhttp://demaio.wordpress.com/2007/06/21/benq-ne-ofera-qisda/','2007-11-06 17:53:31','2007-11-06 15:53:31','',0,'http://www.groparu.ro/?p=760',0,'post','',16),(761,1,'2007-11-05 21:49:53','2007-11-05 19:49:53','Imi pare aproape sincer rau ca am o asemenea atitudine subversivÄƒ apropos de acest subiect ca o baÅŸicÄƒ spartÄƒ, puroindÄƒ.\r\n\r\nDar ca sa potolim orice urme de xenofobie intre popoare.\r\n\r\nCa sa inabusim serpele extremismului din faÅŸÄƒ, pana nu ii creste si coaie.\r\n\r\nCa sa eliminam din societatea noastra europeana orice sentiment de urÄƒ, intoleranÅ£Äƒ, idee preconceputÄƒ.\r\n\r\nPentru a restabili calmul ÅŸi Ã®nÅ£elegerea Ã®ntre o Å£arÄƒ ca o cizmÄƒ ÅŸi altÄƒ Å£arÄƒ ca un buchet de flori, cu tulpinele in Marea NeagrÄƒ.\r\n\r\nEu, Groparele.\r\n\r\nÃŽn deplinatatea facultÄƒÅ£ilor mele mintale, blogice, trupeÅŸti, bÄƒutureÅŸti ÅŸi de altÄƒ naturÄƒ (orice altÄƒ naturÄƒ, numai naturÄƒ moartÄƒ nu).\r\n\r\nDeclar.\r\n\r\nPe propria mea rÄƒspundere.\r\n\r\nCÄƒ pentru a Ã®ncerca cumva sÄƒ repar oalele sparte de romÃ¢ni.\r\n\r\nMai ales de Mailat Äƒsta, care e ÅŸi sibian.\r\n\r\nIo.\r\n\r\nAm hotÄƒrÃ¢t sÄƒ mÄƒ las violat de 4.000 italiance Ã®ntre 18 ÅŸi 30 de aniÅŸori, Ã®ntre 1,65 ÅŸi 1,85 m Ã®nÄƒlÅ£ime, cu dimensiuni Ã®ntre 90-60-90 ÅŸi 91-54-120, aproape indiferent de ce alte calitÄƒÅ£i mai au, pÃ¢nÄƒ cÃ¢nd opinia publicÄƒ italianÄƒ va trece la sentimente mai bune vizavi de naÅ£ia mea. Pot prelua cate 2-3 pe sÄƒptÄƒmÃ¢nÄƒ, de preferinÅ£Äƒ miercurea, sÃ¢mbÄƒta ÅŸi lunea dimineaÅ£a, mai ales dacÄƒ afarÄƒ plouÄƒ.\r\n\r\nDacÄƒ Å£ara mea are nevoie de mine, sunt gata sÄƒ mÄƒ sacrific.\r\n\r\nÃŽncheiat azi, 05.11.2007, cu acordul mai mult decÃ¢t deplin al cel puÅ£in uneia dintre pÄƒrÅ£i.','Deci despre italiani si romani',0,'','publish','open','open','','deci-despre-italiani-si-romani','','','2007-11-06 11:13:48','2007-11-06 09:13:48','',0,'http://www.groparu.ro/?p=761',0,'post','',22),(762,1,'2007-11-05 23:10:40','2007-11-05 21:10:40','','dsc01128.JPG',0,'','inherit','open','open','','dsc01128jpg','','','2007-11-05 23:10:40','2007-11-05 21:10:40','',760,'http://www.groparu.ro/wp-content/uploads/2007/11/dsc01128.JPG',0,'post','image/jpeg',0),(763,1,'2007-11-30 12:48:20','2007-11-30 10:48:20','Asupra urbei lor:\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/11/dsc01121.JPG\" title=\"dsc01121.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/11/dsc01121.JPG\" alt=\"dsc01121.JPG\" /></a>\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/11/dsc01119.JPG\" title=\"dsc01119.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/11/dsc01119.JPG\" alt=\"dsc01119.JPG\" height=\"367\" width=\"278\" /></a>\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/11/dsc01120.JPG\" title=\"dsc01120.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/11/dsc01120.JPG\" alt=\"dsc01120.JPG\" height=\"210\" width=\"280\" /></a>','Perspective mediesene',0,'','publish','open','open','','perspective-mediesene','','','2007-11-30 12:48:20','2007-11-30 10:48:20','',0,'http://www.groparu.ro/?p=763',0,'post','',4),(764,1,'2007-11-05 23:45:24','2007-11-05 21:45:24','','dsc01119.JPG',0,'','inherit','open','open','','dsc01119jpg','','','2007-11-05 23:45:24','2007-11-05 21:45:24','',-1194298539,'http://www.groparu.ro/wp-content/uploads/2007/11/dsc01119.JPG',0,'post','image/jpeg',0),(765,1,'2007-11-05 23:47:16','2007-11-05 21:47:16','','dsc01121.JPG',0,'','inherit','open','open','','dsc01121jpg','','','2007-11-05 23:47:16','2007-11-05 21:47:16','',-1194298539,'http://www.groparu.ro/wp-content/uploads/2007/11/dsc01121.JPG',0,'post','image/jpeg',0),(766,1,'2007-11-05 23:47:35','2007-11-05 21:47:35','','dsc01119.JPG',0,'','inherit','open','open','','dsc01119jpg-2','','','2007-11-05 23:47:35','2007-11-05 21:47:35','',-1194298539,'http://www.groparu.ro/wp-content/uploads/2007/11/dsc01119.JPG',0,'post','image/jpeg',0),(767,1,'2007-11-05 23:49:22','2007-11-05 21:49:22','','dsc01120.JPG',0,'','inherit','open','open','','dsc01120jpg','','','2007-11-05 23:49:22','2007-11-05 21:49:22','',-1194298539,'http://www.groparu.ro/wp-content/uploads/2007/11/dsc01120.JPG',0,'post','image/jpeg',0),(769,1,'2007-11-07 19:13:29','2007-11-07 17:13:29','Un naÅŸ (pentru nenapoceni, al lu\' NÃ¢rÅ£oagÄƒ zis PÃ¢rÅ£oagÄƒ).\r\n\r\nUn vis.\r\n\r\nO casa.\r\n\r\nMere omu\' sa isi caute teren sa isi face casÄƒ.\r\n\r\nAjunge in FÄƒget (pentru nenapoceni, asta e o padure de langa Cluj plina de prezervative, cÄƒ io cred cÄƒ nu e clujeancÄƒ sa nu fi facut amor in padurea aia cel putin cu unu - sau chiar cu mai multi deodatÄƒ!)\r\n\r\nIn FÄƒget - doi peizani bÄƒbuÅ£i.\r\n\r\nMoÅŸ ÅŸi bÄƒbuÅ£Äƒ.\r\n\r\nLe spun peizanii la astia doi nasi, in buna traditie romaneasca, cine ce parcele or loat, ce doftor si-o loat langa ce avocat parcela, ce casa vrea sa-si faca Äƒla, ce amanta mai are patronu ala care si-o loat in capu la deal, ce masina si-o schimbat senatoru de langa, vecinu alalalt de ce face puscarie (finca furase fonduri UE), toaaaate barfele!\r\n\r\n- Da\' ghe unie suntetz? intreaba babutza.\r\n- Ghin Cluuuuuj, zice ei.\r\n- Da\' chiar ghin Cluuuuuj?\r\n- E! zic astia (pentru nenapoceni, E! poate avea mai multe conotaÅ£ii nefireÅŸti, Ã®n cazul de faÅ£Äƒ Ã®nsemnÃ¢nd da).\r\n- Da, mai zic babuÅ£ii, da Ã®n Cluj v-aÅ£i nÄƒscut?\r\n- E! zic ei (pentru nenapoceni, E! poate avea mai multe conotaÅ£ii nefireÅŸti, Ã®n cazul de faÅ£Äƒ Ã®nsemnÃ¢nd nu)\r\n- Da\' ghe unie suntetz?\r\n- Poi, zice naÅŸu, ioz din MediaÅŸ, d-na mea e ghin Blaj.\r\n- BatÄƒ-vÄƒ norocu\', mÄƒi copkii, zice bÄƒbuÅ£ii, <strong><em>mÄƒ miram io cÄƒ de ce nu vÄƒ cunosc!!!!</em></strong>','ProaspÄƒt auzitÄƒ',0,'','publish','open','open','','proaspat-auzita','','','2007-11-07 19:13:29','2007-11-07 17:13:29','',0,'http://www.groparu.ro/?p=769',0,'post','',14),(768,1,'2007-11-05 23:51:51','2007-11-05 21:51:51','','dsc01123.JPG',0,'','inherit','open','open','','dsc01123jpg','','','2007-11-05 23:51:51','2007-11-05 21:51:51','',-1194298539,'http://www.groparu.ro/wp-content/uploads/2007/11/dsc01123.JPG',0,'post','image/jpeg',0),(770,1,'2007-11-08 12:36:20','2007-11-08 10:36:20','Am tat primit lepshe, da\' fiind asa de preocupat de mine insushi, cea mai importanta persoana din viatza mea, nu prea le-am dat curs, iertati-ma, fratilor!\r\n\r\nUltima iashte aia de la Oedip (da\' nu ala cu tac\'... aaa, ma-sa). Deci cica sa nominalizesc io erou\' meu de-o viatza, care de fapt pentru mine e hh... hhhh... heroin.\r\n\r\nDeci eroul meu munceste de la 15 ani, ca ziarist. La 16 ani o primit prima contraoferta din viatza lui de la un ziar concurent, si lucrand la ziarul concurent a reusit:\r\n\r\n- sa fie la un centimetru de la a fi dat in judecata de doftoritza liceului, care de alfel a si scos liceul lui de pe listele cabinetului ei in urma unui articol scris de el despre aceasta;\r\n- sa si-l scoale in cap pe directoru\' liceului, finca o scris de rau de el;\r\n- sa convinga directorii ovrei ai unor (mai multor) ditamai fabricile comuniste sa isi faca reclama la ziarul la care lucra, desi el avea numai 16 ani si piata publicitatii era, la acea data, cum era Polu Sud inainte de a ajunge la el Nansen (desi voi stiti, bine-nteles, ca Nansen nu a fost niciodata la Polul Sud!), adeca virgin.\r\n\r\nDesi o picat de doo ori la facultate, si-o sumetit muschii, o lucrat, si-o platit meditatiile integral, si dupa ce o intrat la faculta avea deja in anu\' I 2 joburi intr-un oras despre care nu stia decat nimic, intr-o perioada in care daca aveai un job erai meseriash. Si si-o si loat toate examenele din anu I, care erau criminale.\r\n\r\nAsa, si in anu\' 4 parintii nu i-or mai dat bani decat deloc.\r\n\r\nSi de prin 2001 are cel putin un job, la ora actuala are vreo 3. Chiar 4. Sau dreq mai stie. Si sa-i suga p*** cine spune ca romanii nu muncesc, asa zice erou\' meu, si tot erou meu spune ca ar mai fi o groaza de scris despre el, da\' cu alta ocazie.\r\n\r\nFuck me, am ajuns propriul meu erou!\r\n\r\nLeapsha goes to cine mai are chef sa o preieie, ca io deja am obosit sa ma tÄƒt lustruiesc atata.','Leapsha - eroul meu',0,'','publish','open','open','','leapsha-eroul-meu','','','2007-11-08 12:39:14','2007-11-08 10:39:14','',0,'http://www.groparu.ro/?p=770',0,'post','',7),(771,1,'2007-11-08 21:17:15','2007-11-08 19:17:15','Deci, azi e o zi mare pentru umanitate.\r\n\r\nAzi m-am inscris la liceul de ÅŸoferi.\r\n\r\nIo am Ã®nceput de douÄƒ ori facultatea de ÅŸoferi, ÅŸi de ambele dÄƒÅ£i am renunÅ£at.\r\n\r\nPrima datÄƒ o fost la Auto Compact. Am fost vreo 8 colegi din firmÄƒ, ÅŸi am reuÅŸit, Ã®n virtutea acestui fapt, sÄƒ obÅ£inem o reducere de aproape 10% de la cel mai zgarcit nene decan la masteratul de ÅŸoferi, dupÄƒ o negociere la sÃ¢nge fÄƒcutÄƒ de JE. Din cei opt, toÅ£i au terminat ÅŸcoala, numai eu ÅŸi Tibby nu, fincÄƒ odatÄƒ o urlat la noi vreo 2 ore la o sesiune de condus, ÅŸi am vrut sÄƒ-l killÄƒrim cu bestialitate ÅŸi sÄƒ-l aruncÄƒm Ã®n Lacul Morii, ca pe bancomat. De killÄƒrit nu l-am mai killÄƒrit, dar fincÄƒ i s-o terminat benzina Ã®n timpul ÅŸedinÅ£ei (!!!!!), ÅŸi el o plecat cu o ganistrÄƒ sÄƒ bage gazol, am plecat pur ÅŸi simplu din maÅŸinÄƒ, ÅŸi nu l-am mai revÄƒzut. Muie!\r\n\r\nA doua oarÄƒ cÃ¢nd am Ã®nceput doctoratul de ÅŸoferi o fost la Auto Tudor, la un nene muuuuult mai libidinos ca mine, ceea ce e record galactic, ca am fost odata cu o colega la el sa ma inscriu, si nij nu m-o bagat in sama, io vorbeam in gol, si el numa\' cu ea vorbea si ii picura saliva peste formulare. Åži care instructor ne-o bÄƒgat Ã®ntr-o maÅŸinÄƒ cu o gajicÄƒ care avea deja vreo 18 ore de condus. Åži ÅŸi pe Äƒsta am vrut sÄƒ-l batem, fincÄƒ am fÄƒcut greÅŸeala sÄƒ o Ã®ntrebam pe fatÄƒ \"Tu cÃ¢te ore de condus ai?\", la care se bagÄƒ chioru\' (ca avea probleme la un ochi care se incaleca peste rama de la okelari, nush cum dreq ajunsese el instructor!) sa ne faca varza: \"Fata asta stie mai mult decat veti sti voi vreodata!!!\" Am oftat cum oftez io de fiecare data cand urmeaza sa fut pe careva de care nu-mi place DELOC, si i-am spus ca ii facem plangere la patron, si ca atata vreme cat banii mei il obliga pe el sa stea drepti in fatza mea, sa faca bine sa nu stea pe loc repaos, ca il belesc si-i pun si sare, ca la lipitoare. S-o uitat la mine cu ochiu\' lui ala citav care ma privea cu o privire de Hitler, si asteptam, cu mana inclestata, sa-mi sparg monturile in strungareatza lui. Nu s-a intamplat, da\' nici nu am mai vrut sa am de-a face cu el, finca fix in perioada aia am primit un client super coios la traduceri, care m-o abuzat vreo 6 luni, timp in care n-am avut timp sa fac scoala de soferi, si iaca cum trecura vreo 4 ani de-atunci! Deci pula scoala de soferi.\r\n\r\nIar azi, la insistentele contului meu bancar din care platesc deja rata la mashina, m-am infiintat la o scoala de soferi si m-am inscris. Nu veti afla numele ei decat daca se comporta najpa cu mine, ceea ce de abia astept sa faca, finca am si eu, ca orice supraom, granitele mele romano-maghiare.\r\n\r\nSi acum, revenind la titlu, feriti-va copilele! Ca s-ar putea ca masina pe care o voi conduce eu sa nu calce!!!','Feriti-va copilele!',0,'','publish','open','open','','feriti-va-copilele','','','2007-11-08 21:17:15','2007-11-08 19:17:15','',0,'http://www.groparu.ro/?p=771',0,'post','',18),(772,1,'2007-11-09 15:43:24','2007-11-09 13:43:24','Mall de securist, aia se stie, da\' ui ce reclama ambulanta isi face!\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/11/iulius-mall.jpg\" title=\"iulius-mall.jpg\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/11/iulius-mall.jpg\" alt=\"iulius-mall.jpg\" height=\"449\" width=\"341\" /></a>\r\n\r\nNenea asta mere la fiecare culoare verde a semaforului de o parte si de alta a strazii, si le arata la soferi nu gesturi cu destele de la mainile alea mici ale lui, ci ditamai panotaju.','Iulius Mall',0,'','publish','open','open','','iulius-mall','','','2007-11-09 15:43:24','2007-11-09 13:43:24','',0,'http://www.groparu.ro/?p=772',0,'post','',7),(773,1,'2007-11-09 15:42:12','2007-11-09 13:42:12','','iulius-mall.jpg',0,'','inherit','open','open','','iulius-malljpg','','','2007-11-09 15:42:12','2007-11-09 13:42:12','',-1194615229,'http://www.groparu.ro/wp-content/uploads/2007/11/iulius-mall.jpg',0,'post','image/jpeg',0),(774,1,'2007-11-09 15:49:58','2007-11-09 13:49:58','','dsc00200.JPG',0,'','inherit','open','open','','dsc00200jpg','','','2007-11-09 15:49:58','2007-11-09 13:49:58','',777,'http://www.groparu.ro/wp-content/uploads/2007/11/dsc00200.JPG',0,'post','image/jpeg',0),(775,1,'2007-11-09 15:50:31','2007-11-09 13:50:31','','dsc00201.JPG',0,'','inherit','open','open','','dsc00201jpg','','','2007-11-09 15:50:31','2007-11-09 13:50:31','',777,'http://www.groparu.ro/wp-content/uploads/2007/11/dsc00201.JPG',0,'post','image/jpeg',0),(776,1,'2007-11-09 15:51:16','2007-11-09 13:51:16','','dsc00202.JPG',0,'','inherit','open','open','','dsc00202jpg','','','2007-11-09 15:51:16','2007-11-09 13:51:16','',777,'http://www.groparu.ro/wp-content/uploads/2007/11/dsc00202.JPG',0,'post','image/jpeg',0),(777,1,'2007-11-15 23:36:08','2007-11-15 21:36:08','La Cluj, fiecare masina oficiala are ierarhia ei. Nush daca si femeia de serviciu sau gardianu\' pudic are, ca nu i-am intrebat.\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/11/dsc00200.JPG\" title=\"dsc00200.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/11/dsc00200.JPG\" alt=\"dsc00200.JPG\" height=\"476\" width=\"359\" /></a>\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/11/dsc00201.JPG\" title=\"dsc00201.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/11/dsc00201.JPG\" alt=\"dsc00201.JPG\" height=\"478\" width=\"361\" /></a>\r\n\r\nA, si la anuntu asta am mers la ei si i-am intrebat daca vand pelerine!\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/11/dsc00202.JPG\" title=\"dsc00202.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/11/dsc00202.JPG\" alt=\"dsc00202.JPG\" height=\"476\" width=\"360\" /></a>\r\n\r\nAtat pentru azi.','De prin oras',0,'','publish','open','open','','de-prin-oras','','','2007-11-15 23:36:08','2007-11-15 21:36:08','',0,'http://www.groparu.ro/?p=777',0,'post','',5),(779,1,'2007-11-09 23:06:42','2007-11-09 21:06:42','Deci nu e vorba ca mireasa mÄƒ va vedea cÃ¢t Ã®s de frumos ÅŸi destept ÅŸi bogat ÅŸi tÃ¢nÄƒr (la toate puteti pune un NOT!!!!! in fatza, <a href=\"http://www.youtube.com/watch?v=7ePlSTycaL4\" target=\"_blank\">the Borat way</a>) si isi va da seama ca numai eu pot fi mascul alfa la ea in <a href=\"http://en.wikipedia.org/wiki/Vagina\" target=\"_blank\">pestera ei cu perdelutze</a> si ca viata ei fara mine nu are rost, la fel cum imi spun toti paduchii mei latzi. Aia-i clar.\r\n\r\nDeci nici de faptu\' ca m-am hotarat sa o fur pe mireasa si sa o fac regina peste castelu\' meu din frumosul cartier Manastur, unde bÃ¢rlogesc eu Ã®n nedeplinÄƒtatea facultÄƒÅ£ilor mele mentale, nu va constitui motiv suficent de stricare de nunta (nu la burta, ci la nunta).\r\n\r\nNu.\r\n\r\nIo voi fi maine, prin gratia divina, traducator la o nunta dintre o huedineanca si un nepalez. Dap. NuÅŸ dacÄƒ nenea ginere e ÅŸerpaÅŸ, da Ã®mi voi asigura o ascensiune pe Everest cu discount, aia-i clar.\r\n\r\nDa\' ideea ie cÄƒ dacÄƒ io nu apar mÃ¢ine ca traducÄƒtor autorizat, nunta <em>nu va avea loc. </em>\r\n\r\nDeci sunt un fel de DumnezÄƒu adjunct pentru nunta aia.\r\n\r\nSi dupe voi pleca la Sighie, la conciert Scorpions - fincÄƒ mÄƒ rog la ÅžÄƒfu sÄƒ Ã®i aducÄƒ de ani de zile.\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/11/scorpions.JPG\" title=\"scorpions.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/11/scorpions.JPG\" alt=\"scorpions.JPG\" /></a>\r\n\r\nAcest concert il datoresc moralmente iubirilor mele pe care le-am trait pe bluzurile formaÅ£iei, intr-o adolescenÅ£Äƒ cal. I, pt export. Åži slavÄƒ Domnului, ca multe mai furÄƒ! CÄƒ am iubit ÅŸi io cÃ¢t sÄƒ le trag Å£apÄƒ groasÄƒ Äƒlora de ziceau cÄƒ Ã®n viaÅ£Äƒ, <strong>dacÄƒ ai noroc</strong>, <em>ai parte de o singurÄƒ iubire adevÄƒratÄƒ</em>! (buoi! buoi...)\r\n\r\nDeci ne vom reciti dumineca sau luni, si puteti fi siguri ca orice vor doini scorpionii, io voi fi undeva in Nirvana, si voi face pishu de la bere suficient cat sa ostoiesc setea de uree a unei gÄƒÅŸti MISA serioase! A, si daca <a href=\"http://www.white-wolf.ro/\" target=\"_blank\">Whitewolf</a> agreeaza ideea, ma voi intalni cu iel prin birturi.','Deci maine, daca vreau, f** o nunta',0,'','publish','open','open','','deci-maine-daca-vreau-f-o-nunta','','','2007-11-09 23:25:27','2007-11-09 21:25:27','',0,'http://www.groparu.ro/?p=779',0,'post','',11),(780,1,'2007-11-09 23:03:34','2007-11-09 21:03:34','','scorpions.JPG',0,'','inherit','open','open','','scorpionsjpg','','','2007-11-09 23:03:34','2007-11-09 21:03:34','',-1194636099,'http://www.groparu.ro/wp-content/uploads/2007/11/scorpions.JPG',0,'post','image/jpeg',0),(783,1,'2007-11-12 16:48:24','2007-11-12 14:48:24','','fiero-di-essere-romeno.jpg',0,'','inherit','open','open','','fiero-di-essere-romenojpg','','','2007-11-12 16:48:24','2007-11-12 14:48:24','',784,'http://www.groparu.ro/wp-content/uploads/2007/11/fiero-di-essere-romeno.jpg',0,'post','image/jpeg',0),(782,1,'2007-11-12 12:12:57','2007-11-12 10:12:57','O vint si la noi la firma sa ne combine.\r\n\r\nM-am uitat la ei si le-am zis: \"Aceasta prezentare va exista si maine. Dar voi?\"','Pensii private Aviva',0,'','publish','open','open','','pensii-private-aviva','','','2007-11-12 12:12:57','2007-11-12 10:12:57','',0,'http://www.groparu.ro/?p=782',0,'post','',5),(784,1,'2007-11-12 20:38:05','2007-11-12 18:38:05','<a href=\"http://www.groparu.ro/wp-content/uploads/2007/11/fiero-di-essere-romeno.jpg\" title=\"fiero-di-essere-romeno.jpg\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/11/fiero-di-essere-romeno.jpg\" alt=\"fiero-di-essere-romeno.jpg\" /></a>\r\n\r\nLeapja primita de la <a href=\"http://www.imagine-romania.ro/internet/157/fiero-di-essere-romeno.html\" target=\"_blank\">*</a>. Io sono fiero di essere romeno finca:\r\n\r\n- noi violam straine, finca suntem un neam de potenti;\r\n- noi furam de la straini, finca avem nevoie de bani ca sa merem la femei, finca suntem un neam de potenti;\r\n- noi ducem romance cu noi in Italia si Spania ca sa le prostituam, sa le avem acolo, langa noi, finca suntem un neam de potenti;\r\n- la noi in tzara vanzarile de Viagra is minore in comparatie cu alea din alte tzari, finca suntem neam de potenti;\r\n- a, si ii avem pe Eliade, Cioran, Comaneci, Iliescu, Nastase, Basescu, Hrebe\', Geoana, Paunescu, Enescu, Badea CÃ¢rÅ£an, gimnaste care pozeazÄƒ dezbrÄƒcate, aveti gropari care scrie bloage, rÃ¢cÄƒ Ã®ntre bucureÅŸteni ÅŸi constÄƒnÅ£eni, Ã®ntre olteni ÅŸi ardeleni, Ã®ntre unguri ÅŸi romÃ¢ni ÅŸi Å£igani, nu aveÅ£i lege pentru protecÅ£ia animalelor, aveÅ£i romÃ¢ni care-ÅŸi bubuie proastele, aveÅ£i Mircea Badea, aveÅ£i furÄƒciuni, ÅŸpagÄƒ, chelneri penali, preÅ£uri europene la salarii vietnameze, licitaÅ£ii aranjate, aveÅ£i medici ÅŸpÄƒgari, copii cu cancer, formaÅ£ii de muzicÄƒ de 2 lei perechea care cÃ¢ntÄƒ playback, persoane cu dizabilitÄƒÅ£i care trÄƒiesc in condiÅ£ii mizere, aveÅ£i apartamente la preÅ£uri luxemburgheze ÅŸi pariziene, sunteÅ£i slugarnici cu strÄƒinii care vin Ã®n RomÃ¢nia sÄƒ vÄƒ fure de bani, daÅ£i ÅŸpagÄƒ la poliÅ£ai, megeÅ£i pe sens interzis, radeÅ£i pÄƒduri Ã®ntregi de pe faÅ£a pÄƒmÃ¢ntului, aveÅ£i hackeri ÅŸi phishermeni ÅŸi salmonella Ã®n gogoÅŸi, aveÅ£i un litoral de toatÄƒ jena ÅŸi niÅŸte munÅ£i Ã®n care lÄƒsaÅ£i PET-uri de Burger goale, aveÅ£i o DunÄƒre Ã®n care pescuiÅ£i cu dinamita, aveÅ£i un MaramureÅŸ Ã®n care te simÅ£i romÃ¢n, accidentaÅ£i copii ÅŸi nu recunoaÅŸteÅ£i, semnaÅ£i cu America angajamente ca soldaÅ£ii care omoarÄƒ cÃ¢ntÄƒreÅ£i sÄƒ fie extrÄƒdaÅ£i, nici mÄƒcar nu ÅŸtiÅ£i sÄƒ furaÅ£i cumsecade, locuiÅ£i Ã®n cartiere cÃ¢t furnicarele ÅŸi sunteÅ£i mÃ¢ndri, avem CoÅŸeriu, da\' vÄƒ Ã®nghesuiÅ£i Ã®n trolee ÅŸi ascultaÅ£i manele la telefon, daÅ£i din buci pentru un italian borÃ¢t, mai urÃ¢t ca mine ÅŸi mai bÄƒtrÃ¢n ca Å¢epelea, nu aveÅ£i decÃ¢t o vagÄƒ culturÄƒ ecologicÄƒ, lucraÅ£i prea mult pentru prea puÅ£in, vÄƒ Ã®njuraÅ£i Ã®ntre voi cu orice ocazie Ã®n loc sÄƒ vÄƒ zÃ¢mbiÅ£i, na, acuma aveÅ£i ÅŸi malluri Ã®n care sÄƒ vÄƒ boiÅ£i trupurile, cumpÄƒraÅ£i roÅŸii de la Cora ÅŸi mi le vindeÅ£i Ã®n piaÅ£Äƒ, NU ÅžTIÅ¢I SÄ‚ SCRIEÅ¢I, deÅŸi Ionesco o gÄƒsit limba francezÄƒ cÄƒrÄƒmidÄƒ ÅŸi o lasat-o marmurÄƒ, nu aveÅ£i autostrÄƒzi ÅŸi taximetriÅŸtii ÅŸtiu tot timpul mai bine ca tine ce trebuie fÄƒcut Ã®n Å£ara asta, aveÅ£i vameÅŸi hrÄƒpÄƒreÅ£i cu basarabenii - faÅ£Äƒ de care vÄƒ credeÅ£i mai coioÅŸi - ÅŸi pentru toate astea, eu, Groparu, sunt MÃ‚NDRU CÄ‚ SUNT ROMÃ‚N, PENTRU CÄ‚ ÅžTIU SIGUR CÄ‚, AÅžA CUM AM MAI ZIS, ÃŽNTR-UN CATACLISM ATOMIC NOI ÅžI GÃ‚NDACII DE BUCÄ‚TÄ‚RIE AM FI SINGURELE FORME DE VIAÅ¢Ä‚ CARE AR SUPRAVEÅ¢UI! Si pentru ca nu as schimba tara asta pentru nimic in lume, si desi am scris ce am scris, o iubesc si ma simt acasÄƒ aproape oriunde, ÅŸi apropos, Ã®n 13 noiembrie e ziua mea, ÅŸi puteÅ£i sÄƒ-mi uraÅ£i ceva frumos!','Fierro di essere Romeno',0,'','publish','open','open','','fierro-de-essere-romeno','','\nhttp://www.imagine-romania.ro/internet/157/fiero-di-essere-romeno.html','2007-11-12 21:25:41','2007-11-12 19:25:41','',0,'http://www.groparu.ro/?p=784',0,'post','',56),(785,1,'2007-11-14 09:58:42','2007-11-14 07:58:42','Dupa ce voi comprima inregistrarile facute la conciertu\' Scorpiilor, voi termina si postarea cu conciertu\'; pana atunci, vreu sa va zic ce gafai (nu ce gÃ¢fÃ¢i) dupe concert.\r\n\r\nNoi, cand merem la Sibiu la concierte, merem vreo 15-16, in 2-3-4-15 mashini, si ne dam de ceasu mortii incercand sa ne intalnim toÅ£i prin piatza aia mare, unde pe vremuri sibienii taiau capuri de vrajitoare si apoi le violau. Si voi nu puteti sti ce inseamna sa fii Gropar, unicul sibian din gajcÄƒ, si sa organizezi, cu mareata-ti si cutezatoarea-ti maretie cutezatoare, excursii cu injineri prin Sighie, injineri care apoi trebe plimbati, adÄƒpaÅ£i, schimbaÅ£i, etc.\r\n\r\nÅži noi cÃ¢nd merem in Sighie la concerte, ne oprim sa papam la Nomad, un restaurant de taximetristi cu preturi OK, si unde mancarea se trece repede, deci nu apuci sÄƒ papi zeamÄƒ din Mezozoic ÅŸi cartofi din Cuaternar.\r\n\r\nÅži la Nomad ii un ficior care lucreazÄƒ ca chelner, si care ii super demential de amabil, si oricÃ¢tÄƒ lume Ã®i acolo ÅŸi Ã®l Ã®nnebuneÅŸte de cap, el e foarte serios ÅŸi politicos, cÄƒ ÅŸi-i mai mare dragu\' de el, desi il banui ca uneori iti scuipa in supa, ca asa fac toti chelnerii.\r\n\r\nSi finca si la concertu cu Goran Blegovici o fost super cumsecade si o tinut deschis restaurantu\' non stop o ora in plus ca sa mance inginerii mei, de data asta nu m-am mai abtinut, si - desi simteam nevoia, ca Borat - nu l-am pupat, ci l-am tras deoparte, si i-am zis, finca io toata viatza mea am considerat ca e bine sa incurajezi oameni si femei cand fac un lucru bun:\r\n\r\n- Deci ba prekine, zic io, tre sa stii o chestie: tu esti prea meseriash pentru localul asta mah! Serios, deci jur ca tu esti prea meseriash pentru localu asta, ma, da\' serios! Uite-te si tu cum arata, si ce fain ne servesti tu, si cum ne aduci scaune, si cum nu te enervezi, desi toti trag de tine, si tu esti super calm, si uite-te si tu in jur in ce local lucrezi!\r\n- Da, zice el, mersi frumos. E localul meu.','Deci gafa la Sibiu',0,'','publish','open','open','','deci-gafa-la-sibiu','','','2007-11-14 09:58:42','2007-11-14 07:58:42','',0,'http://www.groparu.ro/?p=785',0,'post','',16),(786,1,'2007-11-15 01:16:05','2007-11-14 23:16:05','Buna seara, stimati terespectatori. Deci tin sa va anunt si pe aceasta cale ca io nu-s fan pizza de nici o culoare, finca nu-s sarmale, sloi de oaie, mamaliga in paturi, balmos sau bruschetele pe care le face <a href=\"http://www.andreicrivat.ro\" target=\"_blank\">Crivatz</a>. Da\' uneori mai manc sh pizzoaie, mai mult de fitze.\r\n\r\nAseaaaa. Si ma dusei sa pap pranzu\' la Pizzeria Gente, pe Horea.\r\n\r\nSi urcam sus la etaj, si dupa ce ma pun la masa am geniala idee de a trage scaunul mai spre masÄƒ, ca atunci cÃ¢nd fac pe jos, sa nu murdÄƒresc podeaua cÃ¢nd pot murdÄƒri bunÄƒtate de blugi!\r\n\r\nBig mistake.\r\n\r\nFundul scaunului era rupt, ÅŸi am ridicat numa fundu\', nu si scaunul.\r\n\r\nDeÅŸtiu\' meu, Ã®nvÄƒÅ£at de o Ã®ndelungatÄƒ experienÅ£Äƒ, cÃ¢nd o vÄƒzut locu\' liber, s-o strecurat instinctiv, aÅŸa cum l-am Ã®nvÄƒÅ£at eu, Ã®n despicÄƒturÄƒ.\r\n\r\nCand m-am asezat din nou pe scaun, in urmatoarea fractiune de secunda, destiu\' prostu\' cÃ¢inele nostru era felia aia de ÅŸuncÄƒ din sanviÅŸele copiilor bogaÅ£i, Ã®ntre fundu scaunului ÅŸi rama lui. CÃ¢nd kilele mele s-or aÅŸezat voioase peste scaun, deÅŸtiu meu Å£ipÄƒ de durere ÅŸi ne Ã®njurÄƒ de mamÄƒ, pe mine (desi a mea de fapt e-o doamnÄƒ) ÅŸi pe pizzar ÅŸi - bine-nÅ£eles - pe Ion Iliescu, taxa de prima Ã®nmatriculare, ÅŸoferii najpa din Cluj, copilÄƒria mea traumatizantÄƒ, sistemul sanitar si cel educaÅ£ional - ambele Ã®n agonie, serialu\' Dallas, stirile ProTV, stirile sportive ProTV, traficu\' din Cluj, inghesuiala de pe RATUC, placa mea video care ingheatza, frigu\' de afara, caldura de az-vara, alti politicieni, sapunul lichid colorat numit sampon cu balsam, posibilitatile reduse de pensionare la varsta mea, BANCILE, BANCILE, BANCILE si - bine-nteles - dobanzile lor. A, si o mai injurat si faptu\' ca nu eram in America, finca i-as fi dat in judecata si m-as fi umplut de verzi. Multi verzi.\r\n\r\nDa\' dupa ce am stat un pic si m-am gandit, cu mintea mea de pe urma, ce mi-am zis: din moment ce eu mai am madulare care intra instinctiv prin despicaturi, si daca destiu ar fi fost mai incet la actiune decat putza, NU AR FI FOST ASTA CEA MAI DUREROASA DECALOTARE DE PENIS DIN ISTORIE?\r\n\r\nNu le-am zis nimica de scaunu\' desfundulizat la Gentzi, ca sa o muÅŸte ÅŸi altu\', sa muarÄƒ ÅŸi capra lui. SA MUARÄ‚!!!','La Pizzeria Gente',0,'','publish','open','open','','la-pizzeria-gente','','','2007-11-15 01:16:05','2007-11-14 23:16:05','',0,'http://www.groparu.ro/?p=786',0,'post','',10),(787,1,'2007-11-14 22:08:15','2007-11-14 20:08:15','','dsc00108.JPG',0,'','inherit','open','open','','dsc00108jpg','','','2007-11-14 22:08:15','2007-11-14 20:08:15','',788,'http://www.groparu.ro/wp-content/uploads/2007/11/dsc00108.JPG',0,'post','image/jpeg',0),(788,1,'2007-11-14 22:11:58','2007-11-14 20:11:58','...de laaaaaaa <a href=\"http://alexandraghitalexis.blogspot.com/2007/11/mi-venit-o-idee.html\" target=\"_blank\">Alexandra Ghitza GhitzÄƒlÄƒu</a>.\r\n\r\nDespre ciasu\' Groparului.\r\n\r\nIata-l:\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/11/dsc00108.JPG\" title=\"dsc00108.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/11/dsc00108.JPG\" alt=\"dsc00108.JPG\" /></a>\r\n\r\nAsta e singuru\' ceas pe care-l mai am, finca pe celelalte le-am amanetat ca sa am bani de beutura. Opservati ca deocamdata indicÄƒ ora 6 si 9, din motive binecunoscute celor care se plictisesc pe acest blog. Pentru ceilalti: alaturati cele doua cifre, si dati pe gugal \"Kamasutra\".\r\n\r\nAnd zÄƒ leapja goes tooo... bine-nÅ£Äƒles, fetelor care mÄƒ ceteÅŸte ÅŸi scrie pe \"globurile\" lor personale, finca masculii care ma citeÅŸte bea ÅŸi ei ÅŸi, prin urmare, amaneteazÄƒ cease!','Leapsha primita de laaaaaa...',0,'','publish','open','open','','leapsha-primita-de-laaaaaa','','','2007-11-14 22:11:58','2007-11-14 20:11:58','',0,'http://www.groparu.ro/?p=788',0,'post','',16),(789,1,'2007-11-15 10:02:53','2007-11-15 08:02:53','<span class=\"arial12negru\"><font class=\"arial12negru\"><strong>1. Carabinieri, va ordon, pipaiti Gabitza!</strong>\r\n</font></span>\r\n\r\n<span class=\"arial12negru\"><font class=\"arial12negru\">Se stie deja ca actrita Laura Vasiliu, GÄƒbiÅ£a din \"4 luni, 3 saptamani si 2 zile\" a lu\' Cristian Mungiu, despre care <a href=\"http://www.groparu.ro/?p=463\" target=\"_blank\">am mai scris</a>, a fost prechezitionata de o gajcÄƒ de Garcea italieni, care or confundat-o cu o proxenetÄƒ. </font></span>\r\n<strong>Comentariul meu</strong>: pe GÄƒbiÅ£a aÅŸ vrea ÅŸi io sÄƒ o percheziÅ£ionez, ÅŸtiÅ£i, cu maaaaare  minuÅ£ie, deci nu Ã®nÅ£eleg de ce s-o inflamat presa.\r\n\r\n<strong>2. Papa s-o apucat de decoratiuni exterioare</strong>\r\nPapa i-o acordat lui Vadim nush ce decoraÅ£ie.\r\n<strong>Comentariul meu</strong>: deci e clar, pÃ¢nÄƒ ÅŸi papa are ce are cu ungurii.\r\n\r\n<strong>3. M-am saturat de italienii astia care ne fura locurile de munca si se marita cu femeile noastre!</strong>\r\n\r\nUn italian a fost prins <a href=\"http://www.bihon.ro/stiri/oradea-bihor/articol/italian-prins-in-timp-ce-fura-la-oradea/cn/news-20071115-08583123\" target=\"_blank\">furÃ¢nd dintr-un magazin ÃŽN ROMÃ‚NIA</a>. Prins de carabinierii orÄƒdeni, a declarat cÄƒ dacÄƒ conaÅ£ionalii noÅŸtri furÄƒ din magazinele din Italia, nu vede de ce nu ar fura ÅŸi el Ã®n RomÃ¢nia.\r\n<strong>Comentariul meu</strong>: bueeeey, ca sÄƒ fim chit, ia adu-ne matale vo juma\' de milion de italience sÄƒ se prostitueze la mine-n patrie! Åž-apÄƒi mai discutÄƒm.','Stirile zilei',0,'','publish','open','open','','stirile-zilei','','\nhttp://www.groparu.ro/?p=463','2007-11-15 10:27:01','2007-11-15 08:27:01','',0,'http://www.groparu.ro/?p=789',0,'post','',8),(790,1,'2007-11-16 10:42:02','2007-11-16 08:42:02','Faptul ca <a href=\"http://ioniliescu.wordpress.com\" target=\"_blank\">Bunicutza</a> are blog, si baga postari la greu, se stie deja.\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/11/08_1.jpg\" title=\"08_1.jpg\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/11/08_1.jpg\" alt=\"08_1.jpg\" /></a>\r\n\r\nCe se banuieste este ca Iliescu s-o gandit ca restul bloggerilor nu sunt bloggeri adevarati, ci numai intineaza cauza nobila a bologgeritului!!!\r\n\r\n[youtube kVeSld8QEiI]\r\n\r\nDa\' io ma mai gandesc: daca tot blogareste, nu ar fi cool daca <a href=\"http://ioniliescu.wordpress.com\" target=\"_blank\">Bunicutza</a> s-ar apuca sa bage filme de pe youtube pe blogul sau? Si poze de la petrecerile tovarasesti? <strong>Si AdSense</strong>? Si stiri preluate din Cancan despre Paris Hilton si Britney? Si stiri despre iPhone? Sau comentarii despre Steaua, poze cu Becali si tecstu\' ala cu fetitza aia de 8 ani scuipata pe strada pentru care tre\' sa facem embargou la produse italiene, deci sa nu mai papam supa de taitei, ca aduc a spaghete? Si poze cu el si Emil Constantinescu, cu autograf cu dedicatie? Si oare se bucura cand primeste spamuri cu Viagra, Cialis, Tramadol, Valium, Soma, Xanax?\r\n\r\nSi oare nu ar fi cool daca l-ar pune pe Vladimir Putin sa ii faca reclama la blog? Si, una si mai tare: dupa Groparu, <a href=\"http://www.zoso.ro\" target=\"_blank\">zoso</a>, <a href=\"http://www.andaa.ro\" target=\"_blank\">andaa</a> si <a href=\"http://www.andressa.ro\" target=\"_blank\">andressa</a> si <a href=\"http://www.innocente.ro\" target=\"_blank\">innocente</a> si <a href=\"http://www.visurat.ro\" target=\"_blank\">visurat</a> etc. punct ro (pe Crivatz sh Jeg ii respect prea tare ca sa ii includ in aceeasi enumÄƒraÅ£ie cu mine... well, de fapt numa pe <a href=\"http://www.andreicrivat.ro\" target=\"_blank\">Crivatz</a>!), nu ar fi super tare sa facem, noi, bloggerii, o cheta ca sa ii cumparam unu\' din domeniile\r\n\r\n- www.Bunicutza.ro\r\n- www.MaiAnimalule.ro\r\n- www.MaiDraga.ro\r\n- www.3mandate.ro\r\n- www.Mineriadul.ro\r\n- www.internationalasocialista.ro\r\n- www.coios.ro\r\n- www.APRRPDC.ro (Asociatia de Prietenie Romania-Republica Populara Democrata Coreeana)\r\n- www.ISawLeninHeIsAlive.ro\r\n- www.FuckPerestroika.ro\r\n- www.SinergiaFaptelor.ro\r\n- www.SeceraSiCiocanul.ro\r\n- www.TryToUnderstandMyEnglish.com\r\n- www.TryNotToLaughAtMyEnglish.com\r\n- www.antiburghezie.ro\r\n- www.iliescusipoporul.ro- s.a.,\r\n\r\n...pe care sa se blogareasca in voie???\r\n\r\n<strong>apdeit</strong>: asta vine oarecum in complectare la <a href=\"http://ioncreanga.wordpress.com/\" target=\"_blank\">NicÄƒ</a>. A lu Stefan a Petrii. NuÅŸ care-i mÄƒsa ÅŸi care-i ta-su!','Despre Ion Iliescu si blogul sau',0,'','publish','open','open','','despre-ion-iliescu-si-blogul-sau','','','2007-11-16 12:45:39','2007-11-16 10:45:39','',0,'http://www.groparu.ro/?p=790',0,'post','',16),(791,1,'2007-11-16 10:55:10','2007-11-16 08:55:10','','08_1.jpg',0,'','inherit','open','open','','08_1jpg','','','2007-11-16 10:55:10','2007-11-16 08:55:10','',790,'http://www.groparu.ro/wp-content/uploads/2007/11/08_1.jpg',0,'post','image/jpeg',0),(792,1,'2007-11-17 13:11:11','2007-11-17 11:11:11','Si ma duc la Sibiu sa ma imbat - in sfarsit - cu <a href=\"http://milecarpenisan.wordpress.com\" target=\"_blank\">Mile Carpenisan</a>, deci cine stie cand ne mai auzim.\r\n\r\nPS: finca Mile e sÃ¢rb, cine stie ce se poate Ã®ntÃ¢mpla!','Si ma duc',0,'','publish','open','open','','si-ma-duc','','','2007-11-17 13:11:11','2007-11-17 11:11:11','',0,'http://www.groparu.ro/?p=792',0,'post','',6),(793,1,'2007-11-19 10:16:21','2007-11-19 08:16:21','Maine, marti, 20.11.2007, ora 19:00, Nicu Bendea tine un spectacol de stand-up comedy, cu intrare libera, la Casa de Cultura a Studentelor, finca nu vrea sa isi cumpere o insula exotica pe banii vostri pe bilete, mai ales ca el nici nu trebuie sa plateasca pe nimeni pentru sex, deci ce sa faca cu banii vostri?\r\n\r\nSi daca sunteti cuminti, am sa va zic si ce-mi mai amintesc din weekendul asta care - iaca! - trecu.','Nicu Bendea loveste din nou, reincarcandu-se',0,'','publish','open','open','','nicu-bendea-loveste-din-nou-reincarcandu-se','','','2007-11-19 10:16:21','2007-11-19 08:16:21','',0,'http://www.groparu.ro/?p=793',0,'post','',4),(794,1,'2007-11-20 02:25:01','2007-11-20 00:25:01','Acuma, ca s-au incheiat zilele de nastere, ma uit in spatele meu, si vad ca am o groaza de lepshe la care tre\' sa raspund, nu am mai apucat sa scriu nimica de Scorpions, de concertul lui CoChilian la care am fost amu o saptamana jumate, de Ada Milea, la care nu am fost,  plus una-alta. Si acuma, cand ma uit, bovin, catre ecranul monitorului, simt o nicovala care imi tesheshte fruntea, iar intre cele doua urechi circula, voios, o locomotiva cu aburi. Si din cand in cand cate un ceferist vine si da cu ciocanu\' la roate. Cam la fiecare 18 secunde.\r\n\r\nAcuma as avea mai mult succes daca mi-as pune o ridiche neagra in loc de cap si as gandi cu ea, dar tot nu ma las si - iaca! raportez.\r\n\r\nDeci am tinut kef la baru\' lu Josh, bar care se va deschide in 2-3 saptamani, si ai carui chelneri au reusit sa se imbete mai mult chiar ca sarbatoritul. Si despre care mai sunt chestii de zis, da\' mi-i frica ca o sa-mi scuipe in beutura data viitoare, asa ca nu mai zic nimic.\r\n\r\nDeci baru\' lu\' Josh dÄƒ fix in Eroilor, care e un fel de practic centrul Clujului; si in balconu\' lui se mai fac gratare, si se scuipa in capu alora care trec pe dedesubt. E distractie mare!\r\n\r\nIo-te cata bere am avut:\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/11/dsc00032.JPG\" title=\"dsc00032.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/11/dsc00032.JPG\" alt=\"dsc00032.JPG\" height=\"325\" width=\"433\" /></a>\r\n\r\nOr fost unii care, finca in sediul barului se afla si Radio Transilvania, incercau sa intre in cabina de emisie si sa vorbeasca in direct. Nu au mai ajuns, si o trebuit sa il kemam pe <a href=\"http://www.electriccafe.org/Cinema/Leon/Nettoyeur.html\" target=\"_blank\">Le Nettoyeur</a>, ca umpluseram peretii de sangele lor, ca alfel nu fu chip sa-i potolim.\r\n\r\nIo, la kefu de anu asta, am avut urmatoarea costumatie: vreo doo sutiene push-up confiscate de la atmiratoare, o palarie colectia \"Kitsch\" de la Crivatz cu luminitze (nu Crivatz, ci palaria!), un tricou pe care scria\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/11/tricou.JPG\" title=\"tricou.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/11/tricou.JPG\" alt=\"tricou.JPG\" height=\"325\" width=\"330\" /></a>\r\n\r\nasa, si KILTUL meu original de la clanul Wallace, primit de la mama Anglie, aia care cuprinde si raionul Scotia. La Sibiu, la partea a doua a chefului, am mai avut si o palarie de la armata sÃ¢rbeascÄƒ pe care am primit-o de la Sasha acum vreo 5 ani, Sasha fiind prekinu\' meu din Cernauti, si care are o stea rosie in frunte. Palaria are steauÄƒ, nu el, desi, ca mine e ÅŸi el nostalgic fascist, imperialist, comunist si anarhist si colecist si unionist separatist terorist pacifist!\r\n\r\nAm avut totusi noroc ca nu s-o lasat cu bataie ca atunci cand am facut ziua de nastere in cantina Agronomiei, si despre care bataie veti afla mai incolo, cand raman iar in pana de idei de postari.\r\n\r\nMorosenii mi-or adus palinca <em>das orighinal, </em>de la mamica ei care de fapt e-o doamna. Cu motorina asta am imbatat jumate chefu\'.\r\n\r\n<a href=\"http://www.jeg.ro\" target=\"_blank\">JEG</a>, micul nebarbierit, mi-o adus cadou <strong>o lopata furata</strong>. Mai are pe ea urme de ciment. Mesagiul sau pentru groposfera:\r\n\r\n<em>\"Am furat aceasta lopata personal! Sper sa-ti ajute in promitatoarea cariera si nu uita: Sapa-ti singur groapa sa cada altii in ea! JEG\" </em>\r\n\r\nSi o stat la masa cu dl. si d-na <a href=\"http://www.andreicrivat.ro\" target=\"_blank\">andreicrivat.ro</a>, plus <a href=\"http://idei-locale.blogspot.com\" target=\"_blank\">idei-locale.blogspot.com</a> si <a href=\"http://www.alexis-design.info\" target=\"_blank\">alexis-design.info</a> si toata seara numa\' o scris ca un apucat in carnetel, ca lui asa i se pare ca tre sa fii cool, si degeaba o tot scris, ca tot nu s-o uitat nici o gajica la el! Claro ca pactizez cu el si zic ca \"pierderea e de partea lor\", desi cand zic asta imi creste nasu\' pinocheÅŸte.\r\n\r\nDeci desi ma uit la poze, imi dau seama ca is trucate, pentru ca io nu ii mai cunosc nici pe jumate din oamenii care or fost la ziua mea, la golit. Stiu numa ca la ultimu\' ramas acolo, si care adormise pe o canapea, i s-o scris pe frunte ceva gay cu o carioacÄƒ.\r\n\r\nA doua zi am plecat la Sibiu, fincÄƒ acolo urma sÄƒ beu cu sibienii mei ÅŸi cu <a href=\"http://milecarpenisan.wordpress.com\" target=\"_blank\">sÃ¢rbu</a>. SÃ¢rbu\' nu se bucurÄƒ deloc, din motive care mie imi scapÄƒ, dacÄƒ Ã®l saluÅ£i cu <em>Freedom for Kosovo!</em>\r\n\r\nDin nefericire, amintirile mele cu cheful de la Sibiu sunt mult mai vagi decat ar fi omeneste normal. Si motivul e finca am inceput, normal, cheful cu palinca aia de la Maramu\' rÄƒmasÄƒ din ziua precedentÄƒ. Ce mai reÅ£in io: sibienii mei cei coioÅŸi or venit toÅ£i cu pistoalele din pantaloni; numa\' Mile, manca-v-as, mah, amu va rog sa ma credeti ca si-o bagat manutza in paporniÅ£Äƒ ÅŸi o scos, mÄƒ, un pistol adevarat!!!!!\r\n\r\nDeci Mile umbla inarmat, mah, pe bune, are un <em>levorver</em> Colt. O avut numa\' suficenti crieri sa nu scoata arma sambata noaptea, cand toata gasca era pornita pe fapte mari!!! Ca io cred ca eram singuru\' care mai scÄƒpa de acolo, finca is ficior slabutz si sexy si far\' de burta, si daca stau intr-o dunga nu ma nimereste nimeni nici de la 20 centimetri, plus ca nici un glontz nu omoara bunatate de blogger! Aia-i clar.\r\n\r\nAsa. Si am mai discutat despre razboaiele prin care o fost el (nu razboaiele alea care se poartÄƒ printre cearÅŸafuri!), despre petrol, despre ovreii care conduce lumea ÅŸi - normal - cum sÄƒ facem sÄƒ-i detronÄƒm pe evrei, ÅŸi sÄƒ fim noi Äƒia care conduc lumea, mai ales cÄƒ, din punctu\' meu de vedere, cine conduce lumea, conduce si ditamai 3 miliarde de femei!!! PLUS TOATE FABRICILE DE BERE SI TOATE LACURILE UNDE SE POATE PESCUI DE PE LUMEA ASTA!!!','Stau pe scaun si incerc sa nu pic',0,'','publish','open','open','','stau-pe-scaun-si-incerc-sa-nu-pic','','','2007-11-20 09:05:21','2007-11-20 07:05:21','',0,'http://www.groparu.ro/?p=794',0,'post','',6),(795,1,'2007-11-20 01:57:56','2007-11-19 23:57:56','','dsc00032.JPG',0,'','inherit','open','open','','dsc00032jpg','','','2007-11-20 01:57:56','2007-11-19 23:57:56','',794,'http://www.groparu.ro/wp-content/uploads/2007/11/dsc00032.JPG',0,'post','image/jpeg',0),(796,1,'2007-11-20 02:14:41','2007-11-20 00:14:41','','tricou.JPG',0,'','inherit','open','open','','tricoujpg','','','2007-11-20 02:14:41','2007-11-20 00:14:41','',794,'http://www.groparu.ro/wp-content/uploads/2007/11/tricou.JPG',0,'post','image/jpeg',0),(797,1,'2007-11-20 16:44:14','2007-11-20 14:44:14','Banca, ca sÄƒ ÅŸtiÅ£i ÅŸi voi, eÅŸtia care nu aveÅ£i rate, este o caracatiÅ£Äƒ care Ã®ntr-o viaÅ£Äƒ anterioarÄƒ era baba aia de la parter, aia care te spunea lu mÄƒ-ta cÃ¢nd spÄƒrgeai un geam, cÃ¢nd te cÄƒuta dirigintele acasÄƒ ÅŸi nu gÄƒsea pe nimeni ÅŸi cÃ¢nd te vedea cÄƒ fentai fetele sÄƒ se urce Ã®n copaci, ca sÄƒ li te uiÅ£i supt chiloÅ£i. Asta e banca.\r\n\r\nBanca mea cea de-a treia sau a sasea, nu mai stiu, aia care mi-o loat 600 EUR comision de acordare la 9,000 EUR imprumutati, se tot cÄƒca pe ea sÄƒ le aduc o facturÄƒ la utilitÄƒÅ£i, ca sÄƒ <em>demonstrez cÄƒ io, Ã®ntr-adevÄƒr, locuiesc acolo in domiciliu, ÅŸi cÄƒ buletinul nu ie fals!</em>\r\n\r\nLa ora aia Ã®ncÄƒ nu aveam buletinu schimbat pe Cluj, deci trebia sÄƒ le duc facturÄƒ pe Sibiu. Si fincÄƒ ai mei, din motive de zgÃ¢rcenie, vara stau la Å£arÄƒ, iar eu, din motive de lene ÅŸi de nevoie de material de blog, nu aveam nici un interes sÄƒ le duc factura, clar cÄƒ i-am dus cu vorba pÃ¢nÄƒ mi-or dat banii, ÅŸi ca sÄƒ fie OK le-am dat o facturÄƒ de gaz care le-o furasem alor mei cu vreo 3 luni Ã®nainte fincÄƒ aveam de gÃ¢nd sÄƒ le-o achit eu (sa le fac surprizÄƒ fabuloasa sumÄƒ de 6 RON, cÃ¢t era factura!). Bancherii or acceptat factura (pai daca le vine vrun audit???) numai dupÄƒ ce le-am promis fierbinte, le-am jurat pe roÅŸu cÄƒ Ã®n octombrie le-o aduc, sÄƒ-mi moarÄƒ cÄƒÅ£aua mea personalÄƒ ÅŸi maidanezÄƒ din faÅ£a blocului, dacÄƒ vÄƒ mint! Luna octombrie o trecut, facturÄƒ nu le-am mai dus, cÄƒÅ£aua mea e bine mersi.\r\n\r\nÃŽn noiembrie, bancherii or recurs la scheme mafiote murdare: m-or sunat de 4 ori cu numÄƒr ascuns, nu le-am rÄƒspuns; mi-or trimes acasÄƒ plic cu invitaÅ£ie, m-am facut cÄƒ plooo; or continuat sa ma sune la firma, si apai sa imi ameninÅ£e contabilu firmei cÄƒ imi taie imprumutu daca nu le duc factura, ca daca le vine auditu\'?\r\n\r\nIntr-un final, ma duc acasa, fur de la ai mei alta factura neplatita pe nush ce luna, si azi, glorios, ajung la ghiÅŸeiÅ£a mea personalÄƒ de la bancÄƒ, care dacÄƒ era mai cumsecade primea mai devreme factura, da\' finca s-o crizat de fiecare data si nici macar nu mi-o zambit niciodata am considerat de cuviinta sa o trec prin asemenea suplicii.\r\n\r\nTanti - am simtit io - parca ar fi sarit la mine la beregati, ca o rotvailÄƒrÄƒ. Dar eu eram proaspÄƒt bÄƒrbierit, ÅŸi ÅŸi un pic clonÅ£os, ÅŸi stresat din alte motive care vor ajunge acilea pe blog. Åži eram Ã®ntr-una din zilele alea Ã®n care aveam papagal. Åži dupÄƒ ce butoneazÄƒ la greu la calculator, ia factura cu adÃ¢nc respect, ca pe o relicvÄƒ gepidÄƒ, ÅŸi se uitÄƒ. Åži am ÅŸi crezut cÄƒ izbucneÅŸte Ã®n lacrimi acide ÅŸi sÄƒrate ÅŸi cÄƒlduÅ£e cÃ¢nd Ã®ÅŸi dÄƒ seama cÄƒ nici factura aia nu era pe luna care trebuia! (chestie pe care io n-o ÅŸtiam, fincÄƒ nu mai ÅŸtiam pe ce lunÄƒ trebuie sÄƒ aduc facturÄƒ).\r\n\r\nÃŽntre doi, cel mai deÅŸtept cedeazÄƒ. Tanti o cedat, o acceptat factura, ÅŸi o zis \"No, asta e, dacÄƒ vine auditu\' am pus-o!\"\r\n\r\nSi eu, desi nu-mi face placere deloc sa ma rÃ¢d de oameni, am plecat Ã®n treaba mea, Ã®ncercÃ¢nd sÄƒ mÄƒ simt mai coios fincÄƒ i-am tras-o la una care era prototipu funcÅ£ionarei de la ghiÅŸeu, ÅŸi cÄƒ ce meseriaÅŸ Ã®s io cÄƒ mi-am bÄƒtut joc de o Ã®ntreagÄƒ birocraÅ£ie! Chiar daca i-am bulit ziua lu\' aia, care ÅŸi ea e un suflet.\r\n\r\nÅži senzaÅ£ia de general victorios care intra Ã®n Roma cÄƒlare pe calul sÄƒu, cu barbarul legat la spatele carului, m-o Å£inut pÃ¢nÄƒ mi-am dat seama cÄƒ mi-am uitat cÄƒciula Ã®n bancÄƒ. Care cÄƒciulÄƒ nu mai am curaj sÄƒ mÄƒ duc sÄƒ o recuperez.','Deci, tot la banca',0,'','publish','open','open','','deci-tot-la-banca','','','2007-11-20 16:45:20','2007-11-20 14:45:20','',0,'http://www.groparu.ro/?p=797',0,'post','',9),(798,1,'2007-11-21 16:48:42','2007-11-21 14:48:42','Deci zilele estea Groparu doarme in deplasare, finca nasii lui, neste personaje cu adevarat balzaciene, au treaba pe la spitale prin Cluj. Daca sunteti tineri si sanatosi, si parintii va traiesc, sa nu mai cetesc pe bloage postÄƒri cu \"Azi nu am kef de nimic, ÅŸi nu vreau sÄƒ vÄƒ vÄƒd pe nimeni, ÅŸi nu aveÅ£i decÃ¢t sÄƒ ma ***********************\", OK? Ca va sparg la dovlecel de deprimati, EMO kids si nu-mai-pot-zice-ca-am-zis-ca-nu-mai-scriu-cuvantu\'-fututzi.\r\n\r\nDar pana sa ma dispar la scoala de soferi si apoi la spitale, sa le ridic moralu sau sa le tin morala, nu mai stiu, tin numa sa va zic asta:\r\n\r\nSor-mea, cand s-o maritat, o primit cadou de nunta de la nashi un set de strachini - probabil ce primisera si ei de la altcineva de ziua lor, ca la mine in familie se poarta. Si sor-mea o zis: tu mama, io nu le ieu, ca mie nu-mi plac, is penale, vechi, din anii \'70, si prefer sa ii sparg in cap la barbatu-meu alt fel de oale! Deci tine-le tu. Mama zice: nu le tin io, ca le vede nashii, si se supara pe mine; las\' ca i le dau lu Groparu la Cluj, ca acolo-s in sigurantza!\r\n\r\nEi! Si aseara, cand vin nasii la mine acasa, ce oale si farfurii si strachini zaceau nespalate din luna aprilie la mine in chiuveta??? Si de ce or facut nasii mei ochii cat cepile? Si de ce m-or intrebat ca de unde am asemenea farfurii frumoase, si io le-am zis ca le-am cumparat din targul de vechituri?????\r\n\r\nPS: oare voi putrezi in iad, finca mint?','Deci zilele estea',0,'','publish','open','open','','deci-zilele-estea','','','2007-11-21 16:48:42','2007-11-21 14:48:42','',0,'http://www.groparu.ro/?p=798',0,'post','',8),(799,1,'2007-11-22 15:57:13','2007-11-22 13:57:13','La cativa ani de la asa-zisa revolutie, am ajuns si noi, doamnelor, domnilor si domnisoarelor, sa votam pentru europarlamentari.\r\n\r\nCine o avut curagiu sa se deie macar un pic pe saitu\' Parlamentului European si sa asculte live streaming cu sedintele lor stie deja ca noi nu avem asemenea neni si tanti care sa aiba suficient shtaif si clasa ca sa se dea in barci cu oricare dintre eia.\r\n\r\nDeci, draga mea tzara tzara care papÄƒ iaurt cu Biffidus Essensis(TM) ca sÄƒ poa\' sa se cace in voie, <strong>v-oi cu cine, votati</strong>? Ca io inca nu m-am dumirit, si vreu sa merg la vot. Luminati-ma si pa mine, oameni buni si femei!','Io cu ce neuroparlamentar votez?',0,'','publish','open','open','','io-cu-ce-neuroparlamentar-votez','','','2007-11-23 09:43:27','2007-11-23 07:43:27','',0,'http://www.groparu.ro/?p=799',0,'post','',10),(800,1,'2007-11-22 15:35:39','2007-11-22 13:35:39','Mail trimis in cooperativa, finca azi ne tinem ziua de nascare la firma vreo 6 scorpioni aprigi:\r\n<p class=\"MsoNormal\">Subject: Happy Birthday to us!</p>\r\n<p class=\"MsoNormal\"><font face=\"Arial\" size=\"2\"><span style=\"font-size: 10pt; font-family: Arial\">Dear  colleagues,<o:p></o:p></span></font></p>\r\n<p class=\"MsoNormal\"><font face=\"Arial\" size=\"2\"><span style=\"font-size: 10pt; font-family: Arial\"><o:p></o:p>Those of you who were kind enough to  give money for our birthdays are invited upstairs to join us for some  delicious goodies.</span></font></p>\r\n<p class=\"MsoNormal\"><font face=\"Arial\" size=\"2\"><span style=\"font-size: 10pt; font-family: Arial\">(Just  kidding)</span></font></p>\r\n<p class=\"MsoNormal\"><font face=\"Arial\" size=\"2\"><span style=\"font-size: 10pt; font-family: Arial\"></span></font><strong><font face=\"Arial\" size=\"2\"><span style=\"font-weight: bold; font-size: 10pt; font-family: Arial\">Everybody</span></font></strong><font face=\"Arial\" size=\"2\"><span style=\"font-size: 10pt; font-family: Arial\"> is invited  upstairs today, November 22, 2007, 16:30, or else!!!! This is not a drill!!! We  have a bunch of intruders (wine, beer, juice, cakes, pistachios, snacks, free  air and cost-effective mineral water) that need to be annihilated! The victory  must be ours! WE SHALL PREPAY!!!!</span></font></p>\r\n<p class=\"MsoNormal\">Semnat: Groparele.</p>\r\n<p class=\"MsoNormal\">Urmarea mailului, pe mes:</p>\r\n<strong>NÃ¢rÅ£oagÄƒ zis PÃ¢rÅ£oagÄƒ</strong>: parca-parca incep sa-mi aduc aminte de Groparu ala de il stiam io.\r\n<strong>Groparele</strong>: apai prefer sa fiu genial in fiecare noapte decat in fiecare zi!\r\n<strong>NÃ¢rÅ£oagÄƒ zis PÃ¢rÅ£oagÄƒ</strong>: da\' macar acolo iti mai iese?\r\n<strong>Groparele</strong>: nu, numa-mi intra!','Finca azi ne serbam noaptea de nastere',0,'','publish','open','open','','finca-azi-ne-serbam-noaptea-de-nastere','','','2007-11-22 15:35:39','2007-11-22 13:35:39','',0,'http://www.groparu.ro/?p=800',0,'post','',6),(801,1,'2007-11-22 18:58:53','2007-11-22 16:58:53','<a href=\"http://www.groparu.ro/wp-content/uploads/2007/11/protestrally-iamamuslim.jpg\" title=\"protestrally-iamamuslim.jpg\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/11/protestrally-iamamuslim.jpg\" alt=\"protestrally-iamamuslim.jpg\" height=\"417\" width=\"401\" /></a>\r\n\r\n<a href=\"http://www.kettlerdorothea.ro/2007/09/25/de-ce-urasc-tiganii.htm\" target=\"_blank\">Dorothy</a> scrie intr-o postare lunga de ce uraste ea, sau antipatizeaza cu natia <a href=\"http://warsongu.wordpress.com/\" target=\"_blank\">Warsongului</a>.\r\n\r\nLa ora actuala, e foarte sexy sa-i urasti pe conlocuitari, probabil vedeti si voi asta.\r\n\r\nDeci mai copii.\r\n\r\nIo - din pacate pt voi - is roman 100% (la Sibiu nu am prea avut casatorii mixte, asta sa stiti si voi!), mama e poplaceanca (Poplaca exista!) si tata e din Dragasani, de la vinu ala rosu la care Ã®i spune, Ã®n Sibiu, \"sculÄƒu\". Deci ca sa fim in clar cu chestia asta, da? Ca-s mai \"curat\" genetic ca multi dintre voi (ghilimele intentionate).\r\n\r\nCa sibian (deci io fiind capital cultural european) mutat la Cluj (capital transilvan), sunt obligat sÄƒ ii urasc pe mitici (care ne ia toÅ£i banii), pe olteni (ca e puturoÅŸi), pe moldoveni (cÄƒ nu e gospodari), pe basarabeni (cÄƒ e beÅ£ivi), si pe Å£igani, care - clar, zice-s-ar - ni-s toti inferiori.\r\n\r\nCa roman is obligat sa ii urasc pe porcii de italieni, care uite ce ne fac, pe mÄƒgarii de rusi care ne-or furat tezauru, pe nemtii care mi-or aruncat tzara in comunism (BTW, unu mi-o loat si sora, s-o maritat cu ea! ÅŸi mi-o ÅŸi futut-o, cÄƒ d-aia are sor-mea copiluÅ£i demenÅ£iali, care samÄƒnÄƒ cu ea si cu el!), pe americani, ca ne-or lasat in comunism, pe bulgari ca ne bat la folbal, pe ukraineni ca ne-or loat Bucovina, ca sa nu mai zic de unguri, faÅ£Äƒ de care avem o datorie naÅ£ionalÄƒ de a-i urÃ®.\r\n\r\nCa european is fortat sa ii urasc iara pe americani, ca tre\' sa-i contrabalansam ca putere, pe irakieni, iranieni, sirieni, ca-s TOÅ¢I teroristi, pe chinezi si indieni, finca ne vor fura suprematia economica, si lucrurile nu se termina aici.\r\n\r\nVom descoperi viatza pe alte planete, is sigur. Va mai trebui sa urÃ¢m: martieni, venusieni, mercurieni, jupiterieni. Si va trebui sa ii omoram pe Plutoieni si sa le lom femeile.\r\n\r\nDar daca vom gasi viata in alte sisteme solare? Atunci - claro - va trebui sÄƒ le ardem casele Äƒlora din Alpha Centauri si sa violam nevestele celor din Andromeda si K-Pax, si pe copiii alora din Solaris sa ni-i facem sclavi, ca toata lumea stie ca is naspa (ei).\r\n\r\nDar daca-n puii mei gÄƒsim viaÅ£Äƒ ÅŸi Ã®n alte galaxii? Nush ce sa mai zic, ca io deja am obosit, da\' sper ca ati prins ideia.\r\n\r\nDeci io numa atata va zic, ca io, decat sa ma mai cac pe mine sa scormonesc atata urÄƒ, mai bine o las dreq la budÄƒ, unde isi are locu, cÄƒ aÅŸa nu se mai poate, si trag si apa, ÅŸi prefer sÄƒ iubesc femele din orice rasÄƒ, naÅ£ie, coloare, orientare sexoalÄƒ, religie, Ã®nÄƒlÅ£ime samd, ÅŸi sÄƒ mÄƒ ÅŸi Ã®mbÄƒt cu toÅ£i masculii care Ã®s de aceeaÅŸi sorginte cu ele!\r\n\r\nSi bucurati-va ca sunteti liberi sa ganditi alfel decat mine. Si dupa ce va bucurati, mai explicati-mi de ce TOTI romanii, cand am fost la <a href=\"http://www.groparu.ro/?p=405\" target=\"_blank\">Tiganiada</a>, cand s-or gandit ca suntem tigani cu bani, erau in stare sa ne linga mochetele si ghiulurile de dragi ce le eram!!!!\r\n\r\nAr mai fi de zis, da\' tre sa ma car, sa-mi asigur un loc in istorie.','Deci, despre tigani',0,'','publish','open','open','','deci-despre-tigani','','http://www.kettlerdorothea.ro/2007/09/25/de-ce-urasc-tiganii.htm\nhttp://www.groparu.ro/?p=405','2007-11-22 19:08:13','2007-11-22 17:08:13','',0,'http://www.groparu.ro/?p=801',0,'post','',16),(802,1,'2007-11-22 18:54:41','2007-11-22 16:54:41','','protestrally-iamamuslim.jpg',0,'','inherit','open','open','','protestrally-iamamuslimjpg','','','2007-11-22 18:54:41','2007-11-22 16:54:41','',-1195749405,'http://www.groparu.ro/wp-content/uploads/2007/11/protestrally-iamamuslim.jpg',0,'post','image/jpeg',0),(803,1,'2007-11-23 11:32:32','2007-11-23 09:32:32','\r\n<p align=\"left\"><strong>I. </strong></p>\r\n<p align=\"left\">Tanti <a href=\"http://aberatiuni.blogspot.com/2007/11/leapsa-din-nou.html\" target=\"_blank\">AberaÅ£iunea</a>, zisÄƒ Lilith (ultimele doo litere se pronunÅ£Äƒ cu accentul ÅŸerpelui Äƒluia din Jungle Book - <em>Trusssssssst in meeeeeee</em>, deci Lilisssssss) m-o lepÅŸuit amu-s vreo 4 ani cu <strong><span style=\"font-weight: normal\"><span style=\"font-weight: bold\">Ce intrebari sau replici de pomina ati luat sau ati dat?</span></span></strong></p>\r\n<p align=\"left\">Hmmm. Voi credeÅ£i cÄƒ io Å£iu minte chiar tot ce scormonesc io zilnic? CÄƒ mÄƒ ÅŸi gÃ¢ndeam Ã®ntr-o vreme sÄƒ Ã®mi iau scrib, ca Ramses, care sÄƒ imortalizeze genialele mele propoziÅ£ii, ca sÄƒ plÃ¢nge cititorii dupÄƒ ce mor, cÄƒ cÃ¢tÄƒ vreme trÄƒiesc, veci nu voi depÄƒÅŸi 20 de vizite pe zi pe saitu aiesta!</p>\r\n<p align=\"left\">Dar sa revenim la replici de pominÄƒ. Cred ca despre asta am mai zis: eram in facultate ÅŸi stÄƒteam de vorbÄƒ cu Silvan, cÃ¢nd apare MirciulicÄƒ. Politicos, Ã®i Ã®ntreb:</p>\r\n\r\n<p align=\"left\">- VÄƒ cunoaÅŸteÅ£i?\r\n- Nu, zice ei!\r\n- Bine, zic io, n-aveÅ£i nici unu din voi ce pierde.\r\n<p align=\"left\"><strong>II. </strong></p>\r\n<p align=\"left\"><a href=\"http://nenea.wordpress.com/\" target=\"_blank\">Nenea cel mai cosmogonic</a> din blogosfera o scornit o <a href=\"http://nenea.wordpress.com/2007/11/15/leapsa-premiile-nenea-cosmos-2007/\" target=\"_blank\">leapsha</a> dintre bube, mucigaiuri si noroi.</p>\r\n\r\n<p align=\"left\"><strong>1) </strong><strong>Cel mai prost/stupid/mÃ®rlan/libidinos/retard om politic romÃ¢n.\r\nValeriu TabÄƒrÄƒ. </strong>Finca s-o pronuntat impotriva atribuirii fara licitatie catre Nokia a vo jdemii de hectare langa Cluj, ca sa-si poata sÄƒ-ÅŸi face ÅŸi finlanghezii ceia fabricÄƒ celularÄƒ de exploatat romÃ¢ni. Io zic cÄƒ faza cu Nokia e cea mai cu cap furÄƒciune post-decembristÄƒ, ÅŸi mai aÅŸteptÄƒm asemenea atribuiri fÄƒrÄƒ licitaÅ£ii de teren ÅŸi pentru persoane juridice gen MISA, cÄƒ are multe femei care umblÄƒ guale prin biserici, pentru colegu\' meu PÃ¢rÅ£oagÄƒ, care va naÅŸte curÃ¢nd ÅŸi nu i-ar strica un teren de casÄƒ, ÅŸi pentru oraÅŸul Amsterdam, pe care l-aÅŸ aduce la Cluj din motive lesne de Ã®nÅ£eles.\r\n<p align=\"left\">&nbsp;</p>\r\n\r\n<p align=\"left\"><strong>2) </strong><strong>Cel mai miÅŸto blogger romÃ¢n. </strong>\r\nAcilea io Ã®l votez cu dragÄƒ inimÄƒ pe <a href=\"http://rottencabbage.haipa.ro/\" target=\"_blank\">VarzÄƒÄƒÄƒÄƒ</a>, deÅŸi de ceva vreme s-o puturoÅŸit cu scrisu\', cÄƒ Ã®i e lene pÃ¢nÄƒ sÄƒ ÅŸi fure, ca orice romÃ¢n de treabÄƒ aflat prin strÄƒinÄƒtÄƒÅ£uri!\r\n\r\n<p align=\"left\"> <strong>3) </strong><strong>Cea mai naÅŸpa persoanÄƒ publicÄƒ promovatÄƒ Ã®n acest an de media romÃ¢neascÄƒ - se precizeazÄƒ media respectivÄƒ.</strong>\r\nElodia - OTV. SÄƒ mÄƒ ierte DumnezÄƒu cÄƒ mÄƒ leg de o tanti care nu mai este, da\' io zic cÄƒ sÄƒ lasam fomeile care nu e de gasit si sa ne concentram mai asiduu asupra femeilor care sunt disponibile!','LepÅŸe - tanti AberaÅ£iunea, nenea Coymos',0,'','publish','open','open','','lepse-tanti-aberatiunea-nenea-coymos','','\nhttp://nenea.wordpress.com/2007/11/15/leapsa-premiile-nenea-cosmos-2007/','2007-11-23 17:01:36','2007-11-23 15:01:36','',0,'http://www.groparu.ro/?p=803',0,'post','',5),(812,1,'2007-11-24 15:37:38','2007-11-24 13:37:38','Finca gugÄƒlii nu s-or gandit sa baje AdSense pe huburi de DC. D-aia.\r\n\r\nIo m-am gandit.\r\n\r\nGugÄƒle, trimite-mi un CV, poate te angajez.\r\n\r\nAtata am avut de zis!','De ce este Groparele mai bun ca jmekerii de la Google?',0,'','publish','open','open','','de-ce-este-groparele-mai-bun-ca-jmekerii-de-la-google','','','2007-11-24 15:37:38','2007-11-24 13:37:38','',0,'http://www.groparu.ro/?p=812',0,'post','',3),(804,1,'2007-11-23 12:18:04','2007-11-23 10:18:04','','rotation-of-dsc00211.JPG',0,'','inherit','open','open','','rotation-of-dsc00211jpg','','','2007-11-23 12:18:04','2007-11-23 10:18:04','',805,'http://www.groparu.ro/wp-content/uploads/2007/11/rotation-of-dsc00211.JPG',0,'post','image/jpeg',0),(805,1,'2007-11-23 12:19:25','2007-11-23 10:19:25','<a href=\"http://www.groparu.ro/wp-content/uploads/2007/11/rotation-of-dsc00211.JPG\" title=\"rotation-of-dsc00211.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/11/rotation-of-dsc00211.JPG\" alt=\"rotation-of-dsc00211.JPG\" height=\"450\" width=\"341\" /></a>\r\n\r\nApropos de neuroparlamentare, ceva coleji or facut tzinta de darts din Becal!','Deci fara no comment deloc nici un pic ',0,'','publish','open','open','','deci-fara-no-comment-deloc-nici-un-pic','','','2007-11-23 12:19:25','2007-11-23 10:19:25','',0,'http://www.groparu.ro/?p=805',0,'post','',6),(806,1,'2007-11-23 13:19:12','2007-11-23 11:19:12','','101413-apple-orchard-2-0.jpg',0,'','inherit','open','open','','101413-apple-orchard-2-0jpg','','','2007-11-23 13:19:12','2007-11-23 11:19:12','',807,'http://www.groparu.ro/wp-content/uploads/2007/11/101413-apple-orchard-2-0.jpg',0,'post','image/jpeg',0),(807,1,'2007-11-23 16:57:45','2007-11-23 14:57:45','Cine se prinde primu\' de mesajul subliminal din imaginea asta primeste de la Groparele o bere romaneasca de traditie germana facuta numai dintr-o mana de E-uri, maltz, hamei si apa! Anuntz pe bune.\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/11/101413-apple-orchard-2-0.jpg\" title=\"101413-apple-orchard-2-0.jpg\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/11/101413-apple-orchard-2-0.jpg\" alt=\"101413-apple-orchard-2-0.jpg\" /></a>','Vot pÄƒntru europarlamentare',0,'','publish','open','open','','vot-pantru-europarlamentare','','','2007-11-23 16:57:45','2007-11-23 14:57:45','',0,'http://www.groparu.ro/?p=807',0,'post','',44),(810,1,'2007-11-23 13:23:14','2007-11-23 11:23:14','','101413-apple-orchard-2-0.jpg',0,'','inherit','open','open','','101413-apple-orchard-2-0jpg-2','','','2007-11-23 13:23:14','2007-11-23 11:23:14','',807,'http://www.groparu.ro/wp-content/uploads/2007/11/101413-apple-orchard-2-0.jpg',0,'post','image/jpeg',0),(811,1,'2007-11-23 16:57:21','2007-11-23 14:57:21','Deci leapsa de la <a href=\"http://www.adrianpopa.ro/2007/11/23/o-leapsa-doua-lepse/\" target=\"_blank\">cel mai liberal clujean politician primarian</a>, tre sa declaram in blogu\' mare cu ce grupare politica vom vota.\r\n\r\nFinca la mine nu o venit nimeni sa-mi promita marirea pensiei mele de urmas de-al lui Decebal ÅŸi Traian ÅŸi Romulus Mailat, finca nu am primit nici macar un amarat de mic si un gat de bere de la nimeni, finca nu mi-o primis nimeni ca ii ingroapa pe toti parlamentzii si senatzii supt autostrazi, ca pe Hoffa, finca suntem condusi de Basescu si finca Nastase are blog, finca Iliescu e bine mersi, sarac (cu vo 7.000 EUR/luna), da\' cinstit, finca Taricica vrea sa-mi rupa gura finca vreu sa-mi iau un mashinutz second din strainatate, finca Videanu si Bocu\' ne schimba bordurile, pentru ca atunci cand sarim cu bicicleta din groapa de pe strada sa ne spargem tzestele de o bordura nou-noutza, deci finca Vadim vadimeshte, Funar funareshte, iar Ponta ponteshte, finca ungurii lor din Parlament is la fel de lichele ca romanii nostri din aceeasi institutie mentala, finca ne rupe in gura efectu de sera pe toti, si finca cumparam rosii turcesti, castraveti macedoneni, pere olandeze si vin din Chile mai ieftin ca orice alt vin romanesc, finca merele iordaniene is mai usor de gasit prin supermarkete decat alea de pe Valea HÃ¢rtibaciului, finca PetromV ne vinde inapoi resursele de petrol, care-s ale noastre, tot noua,  finca nu-mi plac colacii secuiesti si finca nu am prea vazut politicieni sapand o groapa pentru un copac, finca nici unu\' nu circula cu RATUCU\' masii, finca nici unu nu face reclama la sapun, finca nu am prea vazut politician modest, finca toate partidele ma scarbesc in aceeasi monumental de egala masura, deci cei care au avut rabdare sa ceteasca deja pana acilea vor afla ca s-ar putea sa votez cu Partida Romilor. Asta in proportie de 75%, pentru ca - repet - sunt inca nehotarat. Iar celor care nu au avut grija sa ceteasca pana acilea, tin sa le spun ca nu vor afla!\r\n\r\nNij nu stiu cui sa transmit aceasta leapsha, cine vrea sa o ieie, il rog sa o ieie, da cu prezervativ!','Alta leapjÄƒ',0,'','publish','open','open','','alta-leapja','','\nhttp://www.adrianpopa.ro/2007/11/23/o-leapsa-doua-lepse/','2007-11-23 16:57:21','2007-11-23 14:57:21','',0,'http://www.groparu.ro/?p=811',0,'post','',0),(813,1,'2007-11-26 10:41:35','2007-11-26 08:41:35','Io visez la un alt fel de Romanie, da\' e vis umed, va previn!\r\n\r\nVisez la o Romanie in care oamenii sa nu mai fie persecutati in functie de culoarea pielii, religie, rasa, apartenenta politica, orientare sexoala sau marimea putzulicii, conform algoritmului: putza mare - lucru bun, putza mica - multumim, va sunam noi.\r\n\r\nVisez la o Romanie in care, daca faci un pact cu Dumnezau, sa nu apara dracu\' in secunda urmatoare ÅŸi sÄƒ te tenteze si tu sÄƒ cedezi instant, bag cotoru-n mÄƒ-sa, dracu pulii!\r\n\r\nVisez la o Romanie care sa vrea EA independenta fatza de tzara secuilor.\r\n\r\nVisez la o Romanie debecalizatÄƒ.\r\n\r\nVisez la o RomÃ¢nie verde, fÄƒrÄƒ inghesuialÄƒ pe autobuze, plinÄƒ de lacuri ÅŸi pÄƒduri.\r\n\r\nVisez la o RomÃ¢nie cu sÃ¢nii mari ÅŸi tari.\r\n\r\nVisez la o RomÃ¢nie care sÄƒ anexeze Rusia, ÅŸi Rusia sÄƒ geamÄƒ, fericitÄƒ.\r\n\r\nVisez la o RomÃ¢nie in care sa nu fiu luat la <em>per tu</em> de o tanti cu pÄƒru mov, ajunsÄƒ la vÃ¢rsta senectuÅ£ii, cÃ¢nd merg la vot. Åži cÃ¢nd GropÄƒriÅ£ei i se atrage atenÅ£ia cÄƒ nu o complectat cum vroia tanti aia declaraÅ£ia aia de listÄƒ specialÄƒ de vot, sÄƒ nu i se zicÄƒ \"Dumnezeule, aÅŸa aveÅ£i un stil sÄƒ scrieÅ£i litera G, cÄƒ nici nu Ã®Å£i dai seama ca e G!!!!\" S-a Ã®ntÃ¢mplat Ã®n RomÃ¢nia, ieri.\r\n\r\nVisez la o RomÃ¢nie Ã®n care populaÅ£ia rromÄƒ sÄƒ fie integratÄƒ ÅŸi fericitÄƒ ÅŸi uscatÄƒ, ÅŸi d-aia am votat cu ei, dupa cum, de alfel, v-am ameninÅ£at deja.\r\n\r\nÅži mai visez la o RomÃ¢nie care sÄƒ meargÄƒ dreq la vot, mÄƒcar din bun simÅ£ faÅ£Äƒ de mine, fincÄƒ ÃŽI ÅžI Å¢ARA MEA, NEMERNICILOR!!!!\r\n\r\nVoi la ce RomÃ¢nie visaÅ£i?','I have a dream',0,'','publish','open','open','','i-have-a-dream','','','2007-11-26 12:11:53','2007-11-26 10:11:53','',0,'http://www.groparu.ro/?p=813',0,'post','',27),(814,1,'2007-11-26 16:24:17','2007-11-26 14:24:17','PÃ¢rÅ£oagÄƒ zis NÃ¢rÅ£oagÄƒ mere Ã®n Iordania, trimes de coperativa. ÃŽi zic:\r\n\r\n- Nelu, da\' nu fi bou! Salveaza o zi si fa cumva si treci de vezi <a href=\"http://foto.cere.ro/album-Calatorii-Petra-+orasul+pierdut+al+Iordaniei-329.html\" target=\"_blank\">Petra</a>, orasu ala meseriash si pierdut al Iordaniei, pierdut ca tine, cand erai mic, in scutece, de te-or gasit si infiat tiganii aia de parinti de-ai tai!\r\n- My retarded friend, incepe el sa ma contrazica, finca lui ii place sa ma contrazice, i se pare ca asta il pune pe el in valoare.\r\n- I am not your friend, i-o tai io, scurt, superior.','Pe balcon, la tigarÄƒ',0,'','publish','open','open','','pe-balcon-la-tigara','','','2007-11-26 16:24:17','2007-11-26 14:24:17','',0,'http://www.groparu.ro/?p=814',0,'post','',3),(815,1,'2007-11-27 08:59:44','2007-11-27 06:59:44','<a href=\"http://dexonline.ro/search.php?cuv=etologie\" target=\"_blank\">Etologia</a>, carevasazica, reprezinta stiinta care studiaza studiul comportamentului oamenilor si popoarelor, animalelor si voiculestilor.\r\n\r\nAsaaaaa.\r\n\r\nSi se zice, in chestia asta de-i zice etologie, cum ca fiecare animal, om sau natie are nevoie de un spatiu vital, personal, al lui propriu, in care sa se poata bÄƒÅŸi Ã®n voie fÄƒrÄƒ sÄƒ-i fie fricÄƒ cÄƒ Ã®l miroase vun ÅŸÄƒf, colegÄƒ sau viitoare gajicÄƒ. La urÅŸi, cicÄƒ, dacÄƒ te afli la mai puÅ£in de 40 m de el, s-ar putea sÄƒ se simtÄƒ agresat ÅŸi sÄƒ aibe chef sÄƒ te guÅŸte oÅ£Ã¢rÄƒ, sÄƒ le mai treacÄƒ greaÅ£a aia de la afine cu zmeurÄƒ - un cocktail, dupÄƒ cum se ÅŸtie, deopotrivÄƒ laxativ ÅŸi antidiuretic.\r\n\r\nMnoa.\r\n\r\nMÄƒ aflam Ã®n troleu, ÅŸi era suficientÄƒ inghesuialÄƒ Ã®ncÃ¢t sÄƒ scoale la viaÅ£Äƒ - nu, nu pe Gogu - toate pornirile mele agorafobe, care este. Si cand e inghesuialÄƒ, Groparele se pune acolo la mijlocu troleului, unde e burdufu, unde is doua bÄƒri, de te poÅ£i rÄƒzima de ele cu spatele, ÅŸi aÅŸa scapi de stresu ca in curu tau isi infige altu putulica, si se scuza ca e de la frÃ¢nÄƒ, ÅŸi Ã®Å£i face cu ochiu.\r\n\r\nDa\' tura asta, bara aia unde incapeau tri oameni era ocupatÄƒ de un zÃ¢dar. Care stÄƒtea, mÄƒ, Ã®n ciuda pulii, ca un belfÄƒr, sprijinit cu curu\' in siguranta, si cu mainile intinse de parcÄƒ era rÄƒstignit, ÅŸi ocupa toatÄƒ bara aia, mÄƒ! Åži restu troleului stÄƒtea in picioare ÅŸi ÅŸi-ar fi rÄƒzimat ÅŸi iei de bara ceia, da nu puteau de braÅ£ele gorilei.\r\n\r\nMÄƒ apropii de iel, ÅŸi simpt damfu\' lui de vin. Daca aprindeai un kribit, loa foc de la bÄƒÅŸini ÅŸi vapori de etilic.\r\n\r\nIo am momente cÃ¢nd nu stau la discuÅ£ii. AÅŸa cÄƒ scot ziaru Capital, cÄƒ Ã®l citeam asiduu pe troleu Ã®n vremile alea, ca eram dejtept, ÅŸi mÄƒ Ã®nfig lÃ¢ngÄƒ sÃ¢nu lui, ÅŸi mÄƒ fac cÄƒ ploo. Åži la vreo doo hopuri Ã®i mai ÅŸi lovesc mandibula cu umÄƒru meu, ÅŸi uit sÄƒ Ã®i zic scuze.\r\n\r\nÅži cÃ¢nd se mutÄƒ mai Ã®n lÄƒturi, io Ã®l urmez.\r\n\r\nÅži el se tot fereÅŸte.\r\n\r\nSi ma dau si mai inspre el, si ii rapesc aeru\' atata de pretios din jurul lui, si nici nu-mi pasa cand pufneste a dispret, ma fac ca ploua, finca tre sa verific teoria aia cu ursu.\r\n\r\nSi cand ajungem doo statii mai incolo, el renuntase si era exilat, saracu, intr-un coltz. Si se mai ÅŸi cocoÅŸase niÅ£el.\r\n\r\nEtologia, d-aia.\r\n\r\nCred ca citise manualu.\r\n\r\n(norocu\' meu!)(norocu\' lui!)','Deci, despre etologie aplicata',0,'','publish','open','open','','deci-despre-etologie-aplicata','','','2007-11-27 09:22:13','2007-11-27 07:22:13','',0,'http://www.groparu.ro/?p=815',0,'post','',20),(816,1,'2007-11-26 20:38:00','2007-11-26 18:38:00','Locul femeilor e la cratiÅ£Äƒ.\r\n\r\nFinca au nevoie sa aiba ceva la-ndemana cu care pentru ca sa deie dupÄƒ noi, sireacele.','Cugetare instantÄƒ',0,'','publish','open','open','','cugetare-instanta','','','2007-11-26 21:39:32','2007-11-26 19:39:32','',0,'http://www.groparu.ro/?p=816',0,'post','',9),(817,1,'2007-11-27 00:11:50','2007-11-26 22:11:50','<a href=\"http://nenea.wordpress.com/x2-cel-mai-misto-blogger/\" target=\"_blank\">Nen-tu Cozmos</a> s-o hotarat sa isi faca el singur roblogfest, ui ase, ni, ca ase poate muschii lui. Comentarii? Good.\r\n\r\nDeci nominalizati, pe langa greii blogosferei, apare din greseala si Groparele, din caoza ca creca cozmosu\' o manipulat voatele aducand ceva autocare de pensionari fomisti care or tot votat de mai multe ori, si iac-asa ajunsai si io printre top 10 omini care n-are alceva de facut decat sa scrie, sa scrie, sa scrie pe bloage Ã®n patria mea cu munti, vÄƒi ÅŸi sÃ¢ni tari la fecioare, din cÃ¢te mai Å£iu io minte, la etatea mea.\r\n\r\nDeci meretz si votati, da\' numa\' daca avetz blog, ca alfel nu se ia in calcul. Deja io mi-am votat-o pe <a href=\"http://andreanum.wordpress.com/\" target=\"_blank\">andreanum</a> ca favorita, fincÄƒ mi se pare suficent de intelectoal blogu iei colectiv ca sÄƒ-mi deie suficiente teme de gÃ¢ndire pe autobuz (vezi postarea viitoare), Ã®n ciuda mirosurilor. Nu sale, ci ale autobuzului! Oricum se ÅŸtie cÄƒ <a href=\"http://www.jeg.ro\" target=\"_blank\">Äƒsta micu</a> va cÃ¢ÅŸtiga tot, cÄƒ aÅŸa face el de fiecare datÄƒ, cÄƒ e un fel de JR al bloagelor, cÄƒ tot timpu ii iese pasenÅ£a, ÅŸi numa\' nu ÅŸtiu cum Mirmenu\' lui reuÅŸeÅŸte, cÄƒ-n afarÄƒ de talent, nu are niic! Da\' niic!!!','Deci, premii cosmice',0,'','publish','open','open','','deci-premii-cosmice','','\nhttp://nenea.wordpress.com/x2-cel-mai-misto-blogger/','2007-11-27 00:11:50','2007-11-26 22:11:50','',0,'http://www.groparu.ro/?p=817',0,'post','',9),(818,1,'2007-11-27 10:34:55','2007-11-27 08:34:55','Ati auzit ca Ozzy, in zilele lui bune, la concerte, arunca o galeata cu excremente peste spectatorii din sala?\r\n\r\nThis is where the shit hits the fan!!!!','Deci, Ozzy Osbourne',0,'','publish','open','open','','deci-ozzy-osbourne','','','2007-11-27 10:34:55','2007-11-27 08:34:55','',0,'http://www.groparu.ro/?p=818',0,'post','',10),(819,1,'2007-12-11 17:34:56','2007-12-11 15:34:56','Am primit, in sfarsit, filmu cu Tiganiada 2007 de la hinu\', master edited. Pana sa faca compilaju\' de aicea, hinu-meu (membru fondator Tiganiada, de alfel) s-o imbatat de vreo 16 ori, finca de fiecare data cand compila se apuca de nostalgii. Si de palinci.\r\n\r\nPe un om nu Ã®l face haina, Ã®l fac prekinii, si pe mine ma fac prekinii mei din Sibiu. De bani ma fac ei, cand ma fac.\r\n\r\nFilmu are 22 minute, e un pic lunguietz, si sper sa nu avetz rabdare sa il vedetz pana la capat, mai ales finca apar neshte momente cam de patratelu\' rosu p-acolo, cum ar fi cand jucam rugby cu sticla de tulburel, sau cand faceam baie in - sa ma iertati - anaconda goala.\r\n\r\nCare nu stiti despre ce e vorba la Tiganiada, mai bine nu aflati! Desi, daca dati un Search la mine pe sait cu \'Tiganiada\', aflati ce si cum. Nu si unde. Finca locatia e secreta, si daca va spun, va trebui sa va genocidez!\r\n\r\n[google -9008323501536470320&amp;hl=en]\r\n\r\nIar acum exclamez si eu, cu inima pustiita ca un bloc din CopÅŸa MicÄƒ: DOAMNEEE, BINE FU LA Å¢IGANIADÄ‚!','Deci Tiganiada 2007 - memento',0,'','publish','open','open','','deci-tiganiada-2007-memento','','','2007-12-11 18:31:38','2007-12-11 16:31:38','',0,'http://www.groparu.ro/?p=819',0,'post','',24),(820,1,'2007-11-27 22:39:04','2007-11-27 20:39:04','1. Cand te trece rapid si te instalezi in scaun, sa il simpti umed, cu picuri de pishu de la colegul anterior.\r\n2. Cand te trece rapid si te instalezi in scaun, sa il simpti umed SI FOARTE RECE.\r\n3. Cand faci pishu stand pe colac, putulica sa se indrepte in fatza, nu in jos, spre portzalan, si sa stropesti podeaua cu un susur primavaratic, da\' galbui.\r\n4. Cand incepe sa tot iasa domnu\' Maro, sa iti vina irezistibil pofta sa borasti in aceeasi secunda.\r\n5. Cand te scremi mai tare si fundu iti bolboroseste, sa auzi ca sefa incearca la usa baii unisex a firmei si iti aude oftaturile anale tocmai cand intreaba \"Ocupat?\"\r\n6. Cand pica caca, sa faca baldabac si sa sara trei stropi de apa fix in gauricea fundului, care este. Reci stropii.\r\n7. Cand dai sa te stergi, sa vezi ca nu mai ai hartie.\r\n8. Cand dai sa folosesti buzduganu ca sa cureti maroniul de pe portzalan, doi peri de plastic sa se arcuiasca si sa arunce maroniu in sus, preferabil nu pe fatza.\r\n9. Sa iesi din buda tinandu-ti mainile ca chirurgii, supt ochii uluiti ai sefei.\r\n10. Toate astea sa ti se intample intr-o singura zi.\r\n\r\nPS: Asa citeste un anuntz in buda firmei. Multumim lu\' <a href=\"http://www.doingtheartwork.com\" target=\"_blank\">Mishonca</a>, omul cu initiativa.\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/11/buda.JPG\" title=\"buda.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/11/buda.JPG\" alt=\"buda.JPG\" /></a>\r\n\r\nApropos, la mine-n firma buda nu e unisex.\r\n\r\nExperientza bonus: sa nu curga apa la buda in ziua aceea. Nici la chiuveta.','Deci 10 experientze najpa ce le poti patiii la buda firmei',0,'','publish','open','open','','deci-10-experientze-najpa-ce-le-poti-patiii-la-buda-firmei','','','2007-11-27 22:42:40','2007-11-27 20:42:40','',0,'http://www.groparu.ro/?p=820',0,'post','',18),(821,1,'2007-11-27 22:35:00','2007-11-27 20:35:00','','buda.JPG',0,'','inherit','open','open','','budajpg','','','2007-11-27 22:35:00','2007-11-27 20:35:00','',-1196195218,'http://www.groparu.ro/wp-content/uploads/2007/11/buda.JPG',0,'post','image/jpeg',0),(822,2,'2007-11-28 16:40:04','2007-11-28 14:40:04','Deci observe. Mersi, Cipala! Vino-ncoa sa te tzuc, mah.\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/11/groparu-picture-1.JPG\" title=\"groparu-picture-1.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/11/groparu-picture-1.JPG\" alt=\"groparu-picture-1.JPG\" /></a>\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/11/groparu-picture-2.JPG\" title=\"groparu-picture-2.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/11/groparu-picture-2.JPG\" alt=\"groparu-picture-2.JPG\" /></a>\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/11/groparu-picture-3.JPG\" title=\"groparu-picture-3.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/11/groparu-picture-3.JPG\" alt=\"groparu-picture-3.JPG\" /></a>\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/11/groparu-picture-4.JPG\" title=\"groparu-picture-4.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/11/groparu-picture-4.JPG\" alt=\"groparu-picture-4.JPG\" /></a>\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/11/groparu-picture-5.JPG\" title=\"groparu-picture-5.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/11/groparu-picture-5.JPG\" alt=\"groparu-picture-5.JPG\" /></a>\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/11/groparu-picture-6.JPG\" title=\"groparu-picture-6.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/11/groparu-picture-6.JPG\" alt=\"groparu-picture-6.JPG\" /></a>\r\n\r\nAnd, my personal favorite, cu barba de la Tiganiada:\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/11/groparu-picture-che.JPG\" title=\"groparu-picture-che.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/11/groparu-picture-che.JPG\" alt=\"groparu-picture-che.JPG\" /></a>','Groparu incepe guerrilla digitala',0,'','publish','open','open','','groparu-incepe-guerrilla-digitala','','','2007-11-28 16:40:04','2007-11-28 14:40:04','',0,'http://www.groparu.ro/?p=822',0,'post','',14),(823,2,'2007-11-28 16:37:53','2007-11-28 14:37:53','','groparu-picture-1.JPG',0,'','inherit','open','open','','groparu-picture-1jpg','','','2007-11-28 16:37:53','2007-11-28 14:37:53','',-1196260215,'http://www.groparu.ro/wp-content/uploads/2007/11/groparu-picture-1.JPG',0,'post','image/jpeg',0),(824,2,'2007-11-28 16:38:06','2007-11-28 14:38:06','','groparu-picture-2.JPG',0,'','inherit','open','open','','groparu-picture-2jpg','','','2007-11-28 16:38:06','2007-11-28 14:38:06','',-1196260215,'http://www.groparu.ro/wp-content/uploads/2007/11/groparu-picture-2.JPG',0,'post','image/jpeg',0),(825,2,'2007-11-28 16:38:18','2007-11-28 14:38:18','','groparu-picture-3.JPG',0,'','inherit','open','open','','groparu-picture-3jpg','','','2007-11-28 16:38:18','2007-11-28 14:38:18','',-1196260215,'http://www.groparu.ro/wp-content/uploads/2007/11/groparu-picture-3.JPG',0,'post','image/jpeg',0),(826,2,'2007-11-28 16:38:38','2007-11-28 14:38:38','','groparu-picture-4.JPG',0,'','inherit','open','open','','groparu-picture-4jpg','','','2007-11-28 16:38:38','2007-11-28 14:38:38','',-1196260215,'http://www.groparu.ro/wp-content/uploads/2007/11/groparu-picture-4.JPG',0,'post','image/jpeg',0),(827,2,'2007-11-28 16:38:51','2007-11-28 14:38:51','','groparu-picture-5.JPG',0,'','inherit','open','open','','groparu-picture-5jpg','','','2007-11-28 16:38:51','2007-11-28 14:38:51','',-1196260215,'http://www.groparu.ro/wp-content/uploads/2007/11/groparu-picture-5.JPG',0,'post','image/jpeg',0),(828,2,'2007-11-28 16:39:06','2007-11-28 14:39:06','','groparu-picture-6.JPG',0,'','inherit','open','open','','groparu-picture-6jpg','','','2007-11-28 16:39:06','2007-11-28 14:39:06','',-1196260215,'http://www.groparu.ro/wp-content/uploads/2007/11/groparu-picture-6.JPG',0,'post','image/jpeg',0),(829,2,'2007-11-28 16:39:34','2007-11-28 14:39:34','','groparu-picture-che.JPG',0,'','inherit','open','open','','groparu-picture-chejpg','','','2007-11-28 16:39:34','2007-11-28 14:39:34','',-1196260215,'http://www.groparu.ro/wp-content/uploads/2007/11/groparu-picture-che.JPG',0,'post','image/jpeg',0),(830,1,'2007-11-28 19:47:07','2007-11-28 17:47:07','Deci la gripa aviara se ard si pasarile Phoenix?','Gripa aviara',0,'','publish','open','open','','gripa-aviara','','','2007-11-28 19:47:07','2007-11-28 17:47:07','',0,'http://www.groparu.ro/?p=830',0,'post','',11),(831,1,'2007-11-29 16:13:44','2007-11-29 14:13:44','Lu <a href=\"http://kettlerdorothea.ro/2007/11/27/leapsa-cum-e-romania-ta.htm\" target=\"_blank\">Doro</a> i s-o facut mila cand o vazut ca la premiile lu\' <a href=\"http://nenea.wordpress.com/x2-cel-mai-misto-blogger/\" target=\"_blank\">Nenea Cozmos</a> pentru cel mai meseriash blogger (premiile constau intr-o scobitoare nefolositÄƒ, o fatza de masa si un vin Babanu) io Ã®z, ca de obicei, ultimu\'; asa ca mi-o aruncat din salt o leapsha despre patria mea, care de fapt e limba mea, si anume ca tre\' sa ii compun o poezea de o strofa.\r\n\r\nNu m-am putut aptinea sa nu conpun o-ntreaga oda:\r\n\r\n<strong>Å¢ara mea ce-asculÅ£i manele</strong>\r\n\r\nÅ¢ara mea ce-asculÅ£i manele\r\nÅ¢arÄƒ fÄƒrÄƒ de ÅŸosele\r\nUnde vameÅŸii-s toÅ£i hoÅ£i,\r\nPoliticienii netoÅ£i,\r\nÃŽÅ£i vinzi fetele frumoase,\r\nPe bÄƒtrÃ¢ni Ã®i scoÅ£i din case,\r\nÃŽÅ£i creÅŸti doctorii ÅŸpÄƒgari,\r\nPe Vangheli Å£i-i faci primari,\r\nPe Becali preÅŸedinte\r\nÅži-n poziÅ£ii cheie pui\r\nNumai oameni fÄƒrÄƒ minte!\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/11/dsc08785.jpg\" title=\"dsc08785.jpg\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/11/dsc08785.jpg\" alt=\"dsc08785.jpg\" height=\"403\" width=\"275\" /></a>\r\n\r\nÅ¢ara mea ce-asculÅ£i manele,\r\nÅ¢arÄƒ plinÄƒ de belele,\r\nCu ÅŸoferi claxonagii\r\nCerÅŸetori pomanagii\r\nBÄƒtÄƒi Ã®ntre galerii\r\nÅži cu boschetari copii,\r\nPoliÅ£ai burtoÅŸi ca crapul,\r\nOameni ce stau prost cu capul\r\nÅži din ce Ã®n ce mai graÅŸi\r\nOameni graÅŸi ÅŸi proÅŸti ca napul!\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/11/dsc08741.jpg\" title=\"dsc08741.jpg\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/11/dsc08741.jpg\" alt=\"dsc08741.jpg\" height=\"182\" width=\"268\" /></a>\r\n\r\nÅ¢ara mea ce-asculÅ£i manele\r\nÅ¢ara mea plinÄƒ de rele\r\nGropi in drumuri ÅŸi-n buget\r\nOameni slabi cÃ¢t un parchet\r\nManeliÅŸti la gÃ¢t cu lanÅ£\r\nÅži beÅ£ivi Ã®ntinÅŸi Ã®n ÅŸanÅ£\r\nÅ¢ara mea cu toate ÅŸele,\r\nÅ¢ara mea ce-asculÅ£i manele,\r\nÅ¢ara mea, tu n-ai ÅŸosele!\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/11/dsc01761.JPG\" title=\"dsc01761.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/11/dsc01761.JPG\" alt=\"dsc01761.JPG\" height=\"201\" width=\"264\" /></a>\r\n\r\n(amu am recitit-o, ÅŸi Ã®mi dau seama ca sunt supt zero la valuare artisticÄƒ)','Deci Romania miea',0,'','publish','open','open','','deci-romania-miea','','http://kettlerdorothea.ro/2007/11/27/leapsa-cum-e-romania-ta.htm\nhttp://nenea.wordpress.com/x2-cel-mai-misto-blogger/','2007-11-29 16:13:44','2007-11-29 14:13:44','',0,'http://www.groparu.ro/?p=831',0,'post','',20),(832,1,'2007-11-29 14:48:58','2007-11-29 12:48:58','3 la numar:\r\n\r\n1. <a href=\"www.doingtheartwork.com\" target=\"_blank\">Mishu</a> va concierta maine in Sighisoara, ceea ce e super, si va transmite conciertu live pe saitu din dotare, recte <a href=\"http://www.doingtheartwork.com\" target=\"_blank\">www.doingtheartwork.com</a>, IN PREMIERA IN BLOGOSFERA ROMANEASCA. Mishu e si designer, BTW. Apelati cu incredere!\r\n\r\n2. Silvan, care e cantecaci chitarian, scoase o noo pesa, iote acilea, trilulizata de mine Ã®nsuÅŸi, va fi urmatÄƒ de alte pese pe care amu mi le trimete, le veÅ£i asculta Ã®n primÄƒ audiÅ£ie internaÅ£ionalÄƒ!(sper sa mearga, daca nu mereti direct pe trilulilu si dati search \'Silvan\')\r\n\r\n<script src=\"http://www.trilulilu.ro/embed-audio/Groparu/d171cf17f9c825\" type=\"text/javascript\" language=\"javascript\"></script> <script type=\"text/javascript\" language=\"javascript\">show_d171cf17f9c825(448, 46);</script>3. MAINE SE DESCHIDE <a href=\"http://www.cgconsulting.ro/legeneral/\" target=\"_blank\"><strong>LE GENERAL</strong></a>, BARU\' CEL MAI PUÅ¢IN CAZON DIN CLUJ, PE EROILOR 18 la etaj, patron ii Joshica si Sergiu, fara de care acest proiect nu avea cum sa ia forma si contur si culoare si mahmurealÄƒ, si bine-nÅ£eles noroc cu Bianca, cÄƒ le-o fÄƒcut identitatea vizoalÄƒ, fÄƒrÄƒ de care nu-i vedeam, sau nu-i identificam! Despre Joshica numa atÃ¢ta Å£iu sa va exprim, ca cine se ia cu iel la beute tre sa fie ori rus, ori finlandez, ori nebun, mai ales cÄƒ odatÄƒ era sÄƒ ne omoare Ã®n drum spre Budapesta, cÃ¢nd meream la beute, cÄƒ era sÄƒ ne infigÄƒ Ã®ntr-un TIR, da o preferat mai degrabÄƒ sÄƒ Ã®nfige maÅŸina Ã®n ÅŸanÅ£. BÄƒgaÅ£i la cap, cÄƒ Ã®n <strong>Le General</strong> voi convoca o Ã®ntÃ¢lnire a bloggerilor Ã®n decemvrie! FincÄƒ patronii s-or sÄƒturat sÄƒ plÄƒteascÄƒ sume astronautice pe beuturi prin baruri, ÅŸi chiar promit o experienÅ£Äƒ nirvanianÄƒ cu bodega lor, care de fapt e super meseriaÅŸÄƒ. A, ÅŸi are ÅŸi oaieless. Deci bÄƒgaÅ£i la cap.\r\n\r\nSi deci iatÄƒ deci Ã®n ce lume de artiÅŸti ÅŸi dizainÄƒri ÅŸi crÃ¢jmari mÄƒ Ã®nvÃ¢rt io!','Deci evenimente publicitare',0,'','publish','open','open','','deci-evenimente-publicitare','','','2007-11-29 16:17:05','2007-11-29 14:17:05','',0,'http://www.groparu.ro/?p=832',0,'post','',17),(833,1,'2007-11-29 16:11:04','2007-11-29 14:11:04','','dsc08741.jpg',0,'','inherit','open','open','','dsc08741jpg','','','2007-11-29 16:11:04','2007-11-29 14:11:04','',831,'http://www.groparu.ro/wp-content/uploads/2007/11/dsc08741.jpg',0,'post','image/jpeg',0),(834,1,'2007-11-29 16:11:51','2007-11-29 14:11:51','','dsc08785.jpg',0,'','inherit','open','open','','dsc08785jpg','','','2007-11-29 16:11:51','2007-11-29 14:11:51','',831,'http://www.groparu.ro/wp-content/uploads/2007/11/dsc08785.jpg',0,'post','image/jpeg',0),(835,1,'2007-11-29 16:12:54','2007-11-29 14:12:54','','dsc01761.JPG',0,'','inherit','open','open','','dsc01761jpg','','','2007-11-29 16:12:54','2007-11-29 14:12:54','',831,'http://www.groparu.ro/wp-content/uploads/2007/11/dsc01761.JPG',0,'post','image/jpeg',0),(844,1,'2007-12-05 16:35:15','2007-12-05 14:35:15','<a href=\"http://www.alexis-design.info/violenta-in-presa-bruscare-a-la-petcu/\" target=\"_blank\">Alexis Design</a>, partenera de blog si cred ca de si mai mult a lu\' <a href=\"http://idei-locale.blogspot.com/2007/12/violenta-in-presa-petcu-ioan.html\" target=\"_blank\">Legionaru\'</a> (care de fapt nu e legionar, da\' e oltean) o fost bruschetatÄƒ de un nene care desi lucreaza in presa nu-i e coleg de breasla, finca se comporta ca un cocinar, pe cand ea e o domnucÄƒ draguÅ£Äƒ ÅŸi prea meseriaÅŸÄƒ.\r\n\r\nDeci la o Ã®ntÃ¢lnire Ã®n sediul PoliÅ£iei din STRADA, ca sa-l citez pe <a href=\"http://www.andreicrivat.ro/2007/12/05/violenta-de-salahor-in-presa/\" target=\"_blank\">andreicrivatzpunctro</a>, Albac, nea Petcu ÅŸi-o arogat un petic de teren de pe care sa pozeze ceva, deshi locul nu mirosea a urina-i proprie, cum se face Ã®n regnul animal, cÃ¢nd se arogÄƒ un crÃ¢mpei de pÄƒdure pe care tre sa urinezi ca sÄƒ areÅ£i cÄƒ-i al tÄƒu. Åži pentru a-l pÄƒstra, pentru a fi NUMAI EL, PETCU, STÄ‚PÃ‚NUL PETICULUI, ar fi fost Ã®n stare sÄƒ deie lovituri colegilor - care lovituri io le-aÅŸ numi <strong>lovituri de presÄƒ</strong>. Åži fincÄƒ nu o gÄƒst pe nimeni mai acÄƒtÄƒrii cu care sÄƒ facÄƒ wrestling, nea\' Petcu s-o loat tocmai de <a href=\"http://www.alexis-design.info\" target=\"_blank\">Alexis Design</a>, care, ca orice fatÄƒ de inÄƒlÅ£ime medie ce se respectÄƒ, e o damÄƒ de staturÄƒ medie. Ei, pe aceasta dÄƒmuÅ£Äƒ de staturÄƒ medie, nenea Petcu, care are ceva metri Ã®nspre sus, o bruschetat-o.\r\n\r\nAmu io ÅŸtiu cÄƒ o cam trecut timpurile elea cÃ¢nd dacÄƒ Ã®Å£i place de o fomee Ã®i dÄƒdeai una Ã®n cap; oamenii s-or prins de asta Ã®n momentul Ã®n care \"mÄƒ doare capul\" a devenit cea mai folositÄƒ scuzÄƒ pentru a eluda o partidÄƒ de secs. Dat fiind cÄƒ nenea Petcu nu o auzit de\r\nchestia asta, vrea careva dintre colegii sÄƒi de la FÄƒclia sÄƒ Ã®i comunice acest lucru?','Cum e sacu\' e ÅŸi Petcu',0,'','publish','open','open','','cum-e-sacu-e-si-petcu','','http://www.andreicrivat.ro/2007/12/05/violenta-de-salahor-in-presa/\nhttp://www.alexis-design.info/violenta-in-presa-bruscare-a-la-petcu/','2007-12-06 00:37:24','2007-12-05 22:37:24','',0,'http://www.groparu.ro/?p=844',0,'post','',9),(845,1,'2007-12-06 00:25:35','2007-12-05 22:25:35','Deci tuturor celor pe care ii kiama MoÅŸ le urez La MulÅ£i Ani!','Azi e Mos Niculae',0,'','publish','open','open','','azi-e-mos-niculae','','','2007-12-06 00:25:35','2007-12-05 22:25:35','',0,'http://www.groparu.ro/?p=845',0,'post','',3),(838,2,'2007-11-30 19:10:44','2007-11-30 17:10:44','Eroilor 18, in sara asta de la ora 8, punct!\r\n\r\nDaca auziti o ambulanta, trimite-ti-o incoa\', ca creca o sa fie nevoe.\r\n\r\nA, si sa aibe ekipament anti-scos-dezalcolizarea din om si femee.','Deci, Le General',0,'','publish','open','open','','deci-le-general','','','2007-11-30 19:10:44','2007-11-30 17:10:44','',0,'http://www.groparu.ro/?p=838',0,'post','',10),(839,1,'2007-12-03 02:11:00','2007-12-03 00:11:00','Sambata a fost o zi mare pentru mine, finca dap. O sosit momentu sa fac si io prima incercare serioasa sa renuntz la tigari. <a href=\"nenea.wordpress.com\" target=\"_blank\">Cozmose</a>, u are not alone no more!\r\n\r\nM-am plans la lume ca nu pot trenunta la fumat, finca tigarile is sursa de inspiratie in bloagele mele, ÅŸi toti mi-or declarat la unison, in cor pe voci ca la bisericÄƒ, cÄƒ e timpul sÄƒ fumez tigari cu mult mai bune.\r\n\r\nIo am  mai facut de 2 ori paoze din fumat in indelungata mea cariera de fumaci, una finca asa am vrut io (ficatzii amenintau cu greva!), de o saptamana, si a doua cand tineam Postu\' Pastelui, care cred ca bate de departe chinurile Golgothei, finca este un mod de chinuit mai rafinat ca decÃ¢t  <em>The Death of 1,000 Cuts</em>, manual chinezesc medieval de tortura, ca decÃ¢t sa ascult pe balcon la firma review-uri cu meciurile Stelei in etapa a II-a, io fiind complet anti-folbal inca din fabricatie, sau ca decÃ¢t sa spal vasele in care am facut asta-vara mamaliga, uitate pe balcon, vase care, de alfel, incepe sa miÅŸte!!!\r\n\r\nDeci decat sa ma las de fumat, azi, in a doua zi de fibrilatie si de sindrom premenstrual agravat, mai degraba as: (urmeaza lista, normal, ca in postarea aia cu buda firmei)\r\n\r\n1. - participa la concursul de lins cadavre\r\n2. - vota cu Nastase de la PSD la turul 2\r\n3. - rontai Nicorette ca pe Orbit ca atunci, la prima mea intalnire cu o fata, io proaspat iesit de supt imperiul varstei de 13 ani, plin de coÅŸuri, pe ea o kema Adriana si era deosebit de faina, atata numa ca era cam pocaita si avea cu totul alte ganduri despre prietenie, nu ca ale mele, care ganduri oarecum aduceau a pat mototolit si cearceaf aratat multimii; nij macar n-am pupat-o in sara aia, si am trait cu impresia ca ea nu o vrut sa guste Gropar finca am nasu\' mare, ceea ce mi-o traumatizat dezvoltarea mea ulterioara ca adult, finca io mi-am rugat toti prietenii care pana atunci ma alintau cu LÄƒptiuc sÄƒ-mi spunÄƒ Cyrano din acel moment incolo, fincacÄƒ LÄƒptiuc ar fi fost pupat Ã®n acea Ã®ntÃ¢lnire pÄƒcÄƒtoaso-pocÄƒitÄƒ, finca toate prietenele lu sor-mea, care e mai mare ca mine, ma tineau in bratze si ma tot pupau cand eram mic si Laptiuc si dragalash, si io ma cuibareamÂ  acolo, pe celulita lor;\r\n4. - iesi la un suc cu o feminista convinsa care nu si-o mai barbierit tzurloaiele din anii \'80 si nici nu poarta sutien, finca asta le dezonoreaza;\r\n5. - intarzia la sedintza cu parintii cand eram prof, si asta era cel mai najpa moment, ca intram in clasa tocmai cand ii vedeam pe cate unu-altu ca pleaca finca deja io intarziam de 20 minute (lol, imi ziceam, ce bou is!)\r\n6. - mere la clasa cu shlitzu desfacut, sa ma vada fostii elevi (asa mi s-o intamplat, si unu dintre ei mi-o si zis in gura mare, de o ras toata clasa; nu l-am iertat si era sa ramana corijent, noroc ca nu-s chiar asa de vendettist)\r\n7. - lasa o pensionara sa stea in locul meu in RATUC, desi ea tocmai declara in gura mare ca mai face doo ture cu troleu\' si apai mere acasa, desi acasa se plictiseste de muarte!\r\n8. - mere la Oncologie ca sa ii incurajez pe bolnavii de acolo ca o sa fie bine totul (creca asta ar fi cea mai dura chestie omeneasca, daca avetz sange prin ovare, baietzii mei, meretz numa p-acolo si va veti simti mult mai bine cand iesiti afara! mult mai bine chiar ca dupa o cacare la buda!!!)\r\n9. - prezenta cazul meu de femininopsesie Ã®n direct la Dr. Andrei\r\n10. - alege sÄƒ mÄƒ angajez iarÄƒ prof, cu toatÄƒ leafa aia mizerabilÄƒ ÅŸi copiii Äƒia obraznici.\r\n\r\nVÄƒ daÅ£i seama ce disperat Ã®s, noroc cÄƒ-s ÅŸi cÄƒpos. Al dreq de cÄƒpos. Åži Ã®ncÄƒ nu am de gÃ¢nd sÄƒ renunÅ£ la renunÅ£at. Åži nici sÄƒ iau Nicorette sau porcÄƒrii d-estea, fincÄƒ-s CÄ‚POS!!!\r\n\r\nMÄƒ duc sÄƒ ucid pe careva.','Groparu vrea sa se lase de fumat',0,'','publish','open','open','','groparu-vrea-sa-se-lase-de-fumat','','','2007-12-03 02:11:00','2007-12-03 00:11:00','',0,'http://www.groparu.ro/?p=839',0,'post','',8),(840,1,'2007-12-03 03:03:34','2007-12-03 01:03:34','...vÄƒ rog sÄƒ ignoraÅ£i postarea anterioarÄƒ, fincÄƒ chiar ar trebui sÄƒ merg la concursul de lins cadavre de bÄƒtrÃ¢nei!\r\n\r\nÅžtiÅ£i de ce?\r\n\r\nHehe.\r\n\r\nVÄƒ zic.\r\n\r\nFincÄƒ aÅŸ avea mai puÅ£inÄƒ greaÅ£Äƒ decÃ¢t am io acuma, pironitÄƒ furios de lueta mea.\r\n\r\nDe ce mi-i mie greaÅ£Äƒ?\r\n\r\nFincÄƒ tocmai auzii la stiri ca Miron Cosma fu eliberat. De la greatza Ã®mi vine sÄƒ pÄƒtez frumusete de covor primit de la sor-mea cu o borÃ¢turÄƒ de altÄƒ naturÄƒ decÃ¢t de sorginte alcoolicÄƒ, ceea ce io nu practic.\r\n\r\nIar procurorului, judecÄƒtorului sau oricÄƒrui magistrat din Å£ara asta tristÄƒ ÅŸi violatÄƒ, oricui a facilitat acest act de Ã®naltÄƒ trÄƒdare Ã®i urez sÄƒ primeascÄƒ aÅŸa, o mÃ¢ngÃ¢iere triple X hardcore pe coajÄƒ cu bastonu, <a href=\"http://www.youtube.com/v/ZY8rJ8bZQEE&amp;amp\" target=\"_blank\">Cozma style</a>.\r\n\r\nSau sÄƒ fie el Ã®nchis Ã®n locul minerului poet, dacÄƒ se poate, cu 28 de colegi de celulÄƒ poponauÅ£i ÅŸi foarte negri, cu chef de cÄƒrniÅ£Äƒ proaspÄƒtÄƒ, ÅŸi cu bile prin pulele domniilor lor pederaste. Åži sÄƒ se noteze cÄƒ Groparu tocmai a fÄƒcut o instigare la sodomie cu de-a sila. VÄƒ daÅ£i seama ce greaÅ£Äƒ mi-i dacÄƒ am ajuns sÄƒ instig la din estea?','Deci io nu fac politica, dar...',0,'','publish','open','open','','deci-io-nu-fac-politica-dar','','','2007-12-03 15:32:15','2007-12-03 13:32:15','',0,'http://www.groparu.ro/?p=840',0,'post','',5),(842,1,'2007-12-04 16:23:41','2007-12-04 14:23:41','Se zice ca oamenii is de trei tipuri: oameni buni, oameni rai si soferi. Dupa ce am incercat pe rand sa fiu si bun si rau, am ajuns la concluzia ca sunt o personalitate mult prea complexa si adamanta ca sa ma restrang la a fi doar inger sau demon, cand pot fi amandoo; de aia acum sunt Ã®n plin proces de devenire ÅŸi mai complex, prin devenirea de ÅŸofer.\r\n\r\nBon.\r\n\r\nAzi dimineatza ma duc la conducere, prima lectie de condus de la Tiganiada de anu asta, cand am bagat o tura cu masina lu TÃ¢mp aka Greuceanu, taman cÃ¢nd eram noi mai beÅ£i ÅŸi poiana noastra mai plinÄƒ de buÅŸteni. Sau de prekini buÅŸteni de beÅ£i.\r\n\r\nAÅŸa.\r\n\r\nÅži nenea instructoru zice:\r\n\r\n- CÃ¢te ore de condus aveÅ£i?\r\n- Nici una, zic io, pe stilu meu, cÄƒ dacÄƒ ziceam pe stilu Academiei aÅŸ fi zis \"niciuna\", Ã®mpreunÄƒ sau \"legat\", cum se zice.\r\n- Aha, zice el.\r\n- Da-da-da, zic io. Da dumneavoastra cÃ¢te ore de instructaj aÅ£i fÄƒcut pÃ¢n-acuma?\r\n- E a doua mea zi aicea, zice el.\r\n- A doua zi! zic io. Aha.\r\n- Da-da-da, zice el.\r\n- Bon! zic. HaideÅ£i Ã®nÄƒuntru. Prima chestie pe care trebuie sÄƒ o ÅŸtiÅ£i cÃ¢nd sunteÅ£i instructor: reglaÅ£i scaunul, oglinda, vÄƒ asiguraÅ£i sÄƒ fie frÃ¢na de mÃ®nÄƒ trasÄƒ. VÄƒ legaÅ£i cu centura de siguranÅ£Äƒ.\r\n\r\nDe ce dreq nu rÃ¢de nimeni cÃ¢nd fac io bancuri?\r\n\r\n- Uite aicea, zice instructoru. CÃ¢nd apeÅŸi pe pedale, apasÄƒ incetuc; cÄƒ nu mai suntem pe Dacie BerlinÄƒ!\r\n- Ai, najpa Ã®s maÅŸinile elea, zic io, cele mai najpa! Mai najpa ca elea nu existÄƒ. Najpa-najpa-najpa.\r\n- Åžtiu, zice el, ÅŸi io am din aia.\r\n- Nu-i stress, zic io, ÅŸi dau sÄƒ-l Ã®mpac. Ia ui o maÅŸinÄƒ de Auto Tudor! Dom instructor, pot sÄƒ mÄƒ Ã®nfig Ã®n maÅŸina concurenÅ£ei?\r\n- Nu, zice el, Ã®n nici un caz.\r\n- PÄƒcat, oftez io. Mai ales cÄƒ am Ã®nÅ£eles cÄƒ vina se Ã®mparte la jumate cu instructoru auto, dacÄƒ faci accident la ÅŸcoala de ÅŸoferi!\r\n- ÃŽncearcÄƒ sa nu mai apeÅŸi pe frÃ¢nÄƒ aÅŸa tare, zice el.\r\n- Da? zic io. Las ca de acum Ã®ncolo nu am sÄƒ mai apÄƒs deloc pe frÃ¢nÄƒ, ÅŸi am sÄƒ vÄƒd ce bine o sÄƒ vÄƒ parÄƒ!\r\n- LasÄƒ asta, zice el.\r\n- NU, zic eu, nu las. Åži Ã®n continuare, am fÄƒcut un top 10 chestii care NU trebe spuse la instructoru de la ÅŸcoala de ÅŸoferi:\r\n\r\n1. Ui doo gajici, mai zi-mi o data care-i claxonu! CÄƒ io aÅŸa am vÄƒst cÄƒ face bÄƒieÅ£ii, claxoneazÄƒ fetele ca nebunii.\r\n2. Hai sÄƒ-l fentÄƒm p-Äƒsta cu TIRu din spate, sÄƒ semnalizez stanga, ÅŸi de fapt sÄƒ fac dreapta! Ce zici?\r\n3. Hai sÄƒ probÄƒm dacÄƒ Dacia Logan chiar are 3 stele la EURONCAP!\r\n4.Â MÄƒ bag acuma prin groapa asta, cÄƒ vreau sÄƒ mÄƒ Ã®nveÅ£i ÅŸi cum se schimbÄƒ roata de rezervÄƒ.\r\n5. Hai sÄƒ o urmÄƒrim pe bruneta aia cu Matizu! Ce zici?\r\n6. Deci cÃ¢nd sunt claxonat la semafor aÅŸtept sÄƒ se facÄƒ galben, ÅŸi numa atuncea trec, nu?\r\n7. Ui, instructore, cum conduc io fÄƒrÄƒ mÃ¢ini ÅŸi cu ochii Ã®nchiÅŸi!\r\n8. MaÅŸina asta poate trece de-a dreptu prin giratoriu, fÄƒrÄƒ sÄƒ mai ocoleascÄƒ?\r\n9. Tre sÄƒ ne oprim sÄƒ beau o votcÄƒ, cÄƒ ui ce Ã®mi tremurÄƒ mÃ¢inile!\r\n10. Nu mai vorbiÅ£i Ã®n direcÅ£ia mea, vÄƒ pute Ã®nfiorÄƒtor gura!!!\r\n\r\n~ VA URMA ~','Deci top 10 chestii care nu se spune la scoala cu soferi - partea I',0,'','publish','open','open','','deci-top-10-chestii-care-nu-se-spune-la-scoala-cu-soferi-partea-i','','','2007-12-04 16:23:41','2007-12-04 14:23:41','',0,'http://www.groparu.ro/?p=842',0,'post','',19),(841,1,'2007-12-03 18:57:28','2007-12-03 16:57:28','Sunt in stare sa caftesc un miner.\r\n\r\nSunt in stare sa joc ruleta ruseascÄƒ cu Saddam.\r\n\r\nSunt in stare sa bag o tura de judo cu Putin, Vladimir Putin, si sa sterg tatami cu el, si apai sa-l chinuiesc si sa-l pun sa zica \"Tata, iarta-ma!\" si sa-i si confisc sanvisul si sa-l fac de ras in fatza colegilor pe care pun sa faca hora in juru lui si sa-i strige \"grasuuu, grasuuuuu!!\"\r\n\r\nSunt in stare sa votez cu Becali.\r\n\r\nSunt in stare sa ma arunc in mijlocul galeriei dinamoviste si sa strig \"Hai Rapiiiiiiiiid!\", desi eu sunt caine, finca is nascut din spermatozoizi campioni dinamovisti.\r\n\r\nIs in stare sa ma duc sa le cer iertare bancilor despre care am scris atata de rau, si apoi sa ma inchid in seiful ala mare-mare care se vede prin filme cu 17 functionare tinere, in prima lor luna de serviciu, si unele sa fie si usor virgine.\r\n\r\nIs in stare sa inot tot Canalul Manecii, desi is convins ca daca vreau pot umbla pe apa, atata is de Dumnezeu.\r\n\r\nIs in stare sa imi pun putulica sa faca wrestling cu un taipan si 2 cobre, numa\' ca sa ma distrez cum mor reptilele.\r\n\r\nIs in stare sa fac haltere cu elefanti turbati, si apoi sa-i pun la pamant si sa-i gadil, sa aud si io cum rÃ¢de un elefant!\r\n\r\nSunt in stare sa o chem pe Nikita la o cina romantica.\r\n\r\nIs in stare sa prind o balena albastra si sa o violez fara scrupule.\r\n\r\nIs in stare sa fac skandenberg cu toti raketii ucraineni care activeaza in partea asta a lumii.\r\n\r\nSunt chiar in stare sÄƒ rÄƒmÃ¢n Ã®n mijlocul oceanului cu o gospodinÄƒ Ã®n plin sindrom premenstrual, mi se piÅŸcÄƒ.\r\n\r\nSi toate astea din cauzÄƒ cÄƒ sunt Ã®n plin proces de lÄƒsare de fumat ÅŸi sunt ca un reactor cernobÃ¢lian supt presiune!','Stati departe de mine!',0,'','publish','open','open','','stati-departe-de-mine','','','2007-12-03 18:57:28','2007-12-03 16:57:28','',0,'http://www.groparu.ro/?p=841',0,'post','',24),(843,1,'2007-12-05 12:24:20','2007-12-05 10:24:20','1. Nu aveÅ£i nimica cu gayii, nu? (ÅŸi Ã®l iei de mÃ¢nÄƒ)\r\n2. BÄƒ, cÃ¢nd mai ai o elevÄƒ la condus, merem cu ea Ã®n FÄƒget sÄƒ o futem amÃ¢ndoi?\r\n3. MaÅŸina asta dacÄƒ se furÄƒ poate fi urmÄƒritÄƒ prin GPS?\r\n4. Fii atent acuma numa cum conduc io, fumez ÅŸi vorbesc la telefon fÄƒrÄƒ handsfree Ã®n acelaÅŸi timp!\r\n5. DacÄƒ calci o babÄƒ nu faci pÃ¢rnaie, aÅŸa-i?\r\n6. ÅžÄƒfu, mÄƒ mÃ¢ncÄƒ gaura curului, mÄƒ scarpini te rog, cÄƒ io-s ocupat cu condusu!\r\n7. ÃŽndreptÄƒ un pic oglinda, sÄƒ mÄƒ rujez, plm.\r\n8. Data viitoare, dacÄƒ e noapte, ai curaj sÄƒ te uiÅ£i cu mine cu bricheta dacÄƒ mai e benzinÄƒ Ã®n rezervor?\r\n9. Pfuaaay, Ã®l calc pe cÃ¢inele Äƒla, sÄƒ ÅŸtiu bine cÄƒ Ã®l urmÄƒresc pe trei trotuare!\r\n10. Shit, ÅŸÄƒfu, credeam cÄƒ mirosu de beÅŸinÄƒ se filtreazÄƒ prin scaun! Scuze.','Deci top 10 chestii care nu se spune la scoala de soferi - partea II',0,'','publish','open','open','','deci-top-10-chestii-care-nu-se-spune-la-scoala-de-soferi-partea-ii','','','2007-12-05 12:24:20','2007-12-05 10:24:20','',0,'http://www.groparu.ro/?p=843',0,'post','',10),(846,1,'2007-12-06 12:40:13','2007-12-06 10:40:13','Tine apasat ambreiaju, da\' pana-n fund! Si frana apas-o treptat, ca daca apesi dintr-o data dai cu capu de volan, ca ej prost, se vede pe tine! De ce nu te asiguri? Nu te mai uita acuma, ca pierzi prea mult timp si blochezi circulatia, iti trebuie ochelari? Vai de mama mea, ce sofer o sa iasa din tine, mai bine te apuci din nou de mers pe bicicleta! Ia privirea de la schimbatoru de viteze cand bagi in viteze! De ce nu te uiti dupa reper cand faci parcarea cu spatele? Cand ti-am zis io sa tragi de volan? Nu vezi ca tragi de volan in directia gresita??? Iar ai inecat motoru\', crezi ca firma are, asa, bani cacalau sa tot schimbe popma de benzina cand ai tu chef? Poarta-te frumos cu masina! Cand circuli, uita-te la 15-20 metri in fatza, la farurile alora din fatza, sa vezi daca nu pun frana! Io cu cine vorbesc? Io degeaba iti spun daca tu nu m-asculti! Ai grija la alternarea aia ambreiaj-acceleratie, daca ii dai drumu prea repede iar moare motoru! Incredibil cum la a doua lectie de condus tu inca nu simti masina! Cand mergi cu spatele, uita-te in oglinzi si in spate si pe geam si in fatza si lateral si la volan!!! <strong>SI NU MAI STA ASA STRESAT, RELAXEAZA-TE!!!!!</strong>\r\n\r\nAsa ca la plecare i-am lasat cadou pe volan, fara sa ma vada, un cacamitz din nas, cu dedicatie, care s-a si lipit instant si iremediabil de degetele lui umede, cand am schimbat locurile.','Deci scoala de soferi',0,'','publish','open','open','','deci-scoala-de-soferi','','','2007-12-06 12:40:13','2007-12-06 10:40:13','',0,'http://www.groparu.ro/?p=846',0,'post','',14),(847,1,'2007-12-06 16:05:06','2007-12-06 14:05:06','Azi am fost Moshu pentru colegii mei din firma, vreo 50 la numar, marea majoritate injineri, deci va dati seama prin ce trec zilnic. Uite aici sunt 4 dintre ei, intr-unul din chefurile noastre nebune, de la firma:\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/12/it-specialists-crazy-wild-party.jpg\" title=\"it-specialists-crazy-wild-party.jpg\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/12/it-specialists-crazy-wild-party.jpg\" alt=\"it-specialists-crazy-wild-party.jpg\" height=\"353\" width=\"470\" /></a>\r\n\r\nAm ajuns la firma, ca de obicei, orbitor de punctual, si deja aveam pe masa vreo 2 ciocolatzici ieftine, o napolitana expirata si neshte bombonele de la Pastile din 2006, cica cadou de la Mosh - adica de la cate vreun coleg mai milos care o vazut ca vin mereu imbracat ca un boschetar si s-o gandit ca la cate rate am mananc prin parcuri si pe strazi si dorm prin cimitire, ca groparii.\r\n\r\nCa sa ma recompensez, am mers cu Tzo la magazin si le-am cumparat tuturor vitelor furajate din cooperativa (cca. 50 capete luminate, da\' ingineresti) 2 saci de pufuleti cu care am venit prin centru\' Clujului, pufuleti pe care i-am distribuit cu mare veselie, si de care am facut mare haz.\r\n\r\nUite poza facuta in fatza la Sora:\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/12/dsc00221.jpg\" title=\"dsc00221.jpg\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/12/dsc00221.jpg\" alt=\"dsc00221.jpg\" height=\"338\" width=\"450\" /></a>','Azi am fost Moshu',0,'','publish','open','open','','azi-am-fost-moshu','','','2007-12-06 16:05:06','2007-12-06 14:05:06','',0,'http://www.groparu.ro/?p=847',0,'post','',24),(848,1,'2007-12-06 16:03:02','2007-12-06 14:03:02','','dsc00221.jpg',0,'','inherit','open','open','','dsc00221jpg','','','2007-12-06 16:03:02','2007-12-06 14:03:02','',-1196949381,'http://www.groparu.ro/wp-content/uploads/2007/12/dsc00221.jpg',0,'post','image/jpeg',0),(849,1,'2007-12-06 16:03:48','2007-12-06 14:03:48','','it-specialists-crazy-wild-party.jpg',0,'','inherit','open','open','','it-specialists-crazy-wild-partyjpg','','','2007-12-06 16:03:48','2007-12-06 14:03:48','',-1196949381,'http://www.groparu.ro/wp-content/uploads/2007/12/it-specialists-crazy-wild-party.jpg',0,'post','image/jpeg',0),(850,1,'2007-12-07 10:22:27','2007-12-07 08:22:27','Deci weekendu asta ce trebuia sa fac eu, cand era sa fac?\r\n\r\n1. Trebuia sa merg la taiatul porcului, la tzara. Stiti ce inseamna asta: palinca ghe Cluuuj, voie buna, distractie cand bietu porc refuza ca un porc sa urmeze procesul care il va aduce pe farfurie si in cele din urma la buda firmei, sorlici, examinat pula porcului si comparat cu pula proprie, bucurie legata de pula proprie*, gratar de carne proaspata, mamaliga (nu de porc!), taaat felu de delicioshenii care scurteaza viatza intr-un mod foarte placut si nu te mai lasa sa te bucuri de pensia privata pilonu\' 2.\r\n\r\n2. Trebuia sa merg la Tilisca, un sat cu oaie, impreuna cu <a href=\"http://www.andreicrivat.ro\" target=\"_blank\">Crivatz</a>. Aia insamna: gratar de oaie, sloi de oaie, lapte si iaurt si branza si telemeauÄƒ si smÃ¢ntÃ¢nÄƒ si prajitura de oaie, aer curat, relaxare, somnic, apa care curge pe langa bucataria gazdei, deci un mic crampei de rai, pe un intre-picioare de rai, de oaie.\r\n\r\nIn schimb, voi merge cu un zambet ofitzial pe fatza la o cununie civila, aici in Cluj.\r\n\r\n_______________________\r\n*Ca sa stiti si voi, ca nici io nu stiam: cica porcii care se mananca is castrati! Deci nu exista putza mai mica decat putza de porc castrat, io asa zic. Nu zic bine?','Ce am ratat weekendu asta',0,'','publish','open','open','','ce-am-ratat-weekendu-asta','','','2007-12-07 10:22:52','2007-12-07 08:22:52','',0,'http://www.groparu.ro/?p=850',0,'post','',13),(852,1,'2007-12-09 00:01:25','2007-12-08 22:01:25','1. Oai, ce rochie faina ti-ai luat de la piatza MÄƒrÄƒÅŸti, de la ruÅŸi!\r\n2. Ai spanac, pÄƒtrunjel ÅŸi ruj pe dinÅ£i.\r\n3. Te-ai mai Ã®ngrÄƒÅŸat, aÅŸa-i? Nu cumva te mÄƒriÅ£i din cauzÄƒ cÄƒ eÅŸti puÅ£intel foarte gravidÄƒ?\r\n4. Tu, aÅŸa mÄƒ bucur pentru voi, cÄƒ mi-era fricÄƒ cÄƒ nu te mai mÄƒriÅ£i never ever!\r\n5. A, e foarte bun pÄƒrintele Äƒsta, el i-o cununat ÅŸi pe X-ulescu. Bine, ei or divorÅ£at dupa 2 ani.\r\n6. Åžtii cÄƒ domniÅŸoara ta de onoare ÅŸi mirele or fost Ã®mpreunÄƒ, nu?\r\n7. Vezi ca - nu te uita acuma - ai un coÅŸ munumental pe umÄƒr.\r\n8. Verigheta asta nu e de aur, nu?\r\n9. Sa ÅŸtii cÄƒ nu-i adevÄƒrat cÄƒ nu existÄƒ mireasÄƒ urÃ¢tÄƒ.\r\n10. Vezi cÄƒ la noapte vÄƒ dau o serie de bipuri, sÄƒ vÄƒd dacÄƒ vÄƒ futeÅ£i sau nu.\r\n\r\n<strong>Update</strong>: Ce pula mea de luna de miere ii aia in care mergi cu el?','Top 10 chestii care nu se spun miresei la o nunta',0,'','publish','open','open','','top-10-chestii-care-nu-se-spun-miresei-la-o-nunta','','','2007-12-10 09:30:49','2007-12-10 07:30:49','',0,'http://www.groparu.ro/?p=852',0,'post','',19),(853,1,'2007-12-10 09:58:34','2007-12-10 07:58:34','<a href=\"http://www.groparu.ro/wp-content/uploads/2007/12/vand-porci.JPG\" title=\"vand-porci.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/12/vand-porci.JPG\" alt=\"vand-porci.JPG\" height=\"386\" width=\"514\" /></a>\r\n\r\nDeci pe care dintre ei vrea sa-i vanda? Optiuni:\r\n\r\n- Camera Notarilor Publici\r\n- Senat\r\n- Camera Deputatilor\r\n- Guvern\r\n- Barou\r\n- Consiliul General al Magistraturii\r\n- Ministerul Educatiei\r\n- Colegiul Medicilor\r\n- Politia Romana\r\n- APIA\r\n- Microsoft\r\n- Eon (Ion) Gaz\r\n- Electrica\r\n- UPC/RDS\r\n- BRD, ING, Alpha, Raiff, HVB-Tiriac-Unicredit-PulemÄƒturi, Milenii-Leumii, plus restu\'\r\n- Becali, vangheli, basesti, voiculesti, geoani, tariceni, vosganieni, remeÅŸi, iliesci, mironi, tÄƒt felu\'\r\n- Ratuci\r\n- Pensii privaÅ£i, etc.\r\n\r\nNu mÄƒ mai gÃ¢ndesc cÄƒ e numa lunea dimineaÅ£a ÅŸi n-am chef sÄƒ Ã®mi paradesc toatÄƒ sÄƒptÄƒmÃ¢na: mi-e prea somnic.','ÃŽi vinde!',0,'','publish','open','open','','ii-vinde','','','2007-12-10 09:58:34','2007-12-10 07:58:34','',0,'http://www.groparu.ro/?p=853',0,'post','',11),(854,1,'2007-12-10 09:58:16','2007-12-10 07:58:16','','vand-porci.JPG',0,'','inherit','open','open','','vand-porcijpg','','','2007-12-10 09:58:16','2007-12-10 07:58:16','',-1197272748,'http://www.groparu.ro/wp-content/uploads/2007/12/vand-porci.JPG',0,'post','image/jpeg',0),(855,1,'2007-12-10 12:06:48','2007-12-10 10:06:48','Atat am avut de zis despre ei.','PD + PLD = PLM',0,'','publish','open','open','','pd-pld-plm','','','2007-12-10 12:06:48','2007-12-10 10:06:48','',0,'http://www.groparu.ro/?p=855',0,'post','',6),(856,1,'2007-12-10 23:41:01','2007-12-10 21:41:01','Cel mai mijto cadou, daca nu stiati, is io. In fiecare dimineatza ma pipai, imi salut erectia si imi multumesc ca exist Ã®n viaÅ£a mea, desi trupul meu adolescentin are un mic bug: nu are sÃ¢ni feminini pe care sÄƒ-i mÃ¢ngÃ¢i, sÄƒ-i iubesc ÅŸi sÄƒ-i ocrotesc (fiare pentru fiara din mine).\r\n\r\nAmu de fiecare data cand e vorba de cadoae, tre sa stiti ca io am o mare hibÄƒ, ca orice alt mare geniu: neputÃ¢nd sÄƒ fiu homosexual, am hiba cu cadoaele. Nu-mi place nici sÄƒ primesc cadoae, ÅŸi nij sÄƒ dau, fincÄƒ mi-am cam loat tot ce-mi trebia in viata asta, uneori singur, alteori cu ajutor de la bÄƒnci pe care, de altfel, le ÅŸi Ã®njur pentru asta cu o poftÄƒ cu adevÄƒrat extraordinarÄƒ, de parcÄƒ aÅŸ primi guldeni de aur cu fiecare cuvÃ¢nt cu P ÅŸi M ÅŸi C. AÅŸa-s io. Revenind la cadoae, prefer sÄƒ primesc bani decÃ¢t cadou! (anu trecut, de ziua mea, colegii mi-or dÄƒruit vreo tri milioanie de euro Ã®n fise de 5000 de lei).\r\n\r\nDar dac-ar fi sa-mi aleg cel mai mijto cadou pe care l-ar putea primi groparele, io as alege urmatoarele 10:\r\n\r\n1. SÄƒ se desfiinÅ£eze clinicile de oncologie, fincÄƒ s-o descoperit leac pÄƒntru cancer;\r\n2. SÄƒ nu-mi mai putÄƒ picioarele, cÄƒ de-aia nu pot mere Ã®n vizite la prekini dupÄƒ lucru;\r\n3. SÄƒ pot sÄƒ Ã®mi fac cel mai tare solar ghe fomei ghin Cluuuuj, ÅŸi io sÄƒ mÄƒ angajez full-time pe post de privitor de corpuri feminine despuiate;\r\n4. SÄƒ se interzicÄƒ manelele, Ã®n schimb sÄƒ se promoveze mamelele;\r\n5. SÄƒ se scoatÄƒ reclamale la berea germanÄƒ originalÄƒ produsÄƒ Ã®n Bragadiru, Pantelimon sau Giurgiu;\r\n6. SÄƒ se facÄƒ TIT-tv, televiziune dedicatÄƒ exclusiv studentelor toplesse ale verilor fierbinÅ£i de la CostineÅŸti din anii \'90, nu din anii 2000, DE CAND ROMANCELE OR INCEPUT SA BAGE IN ELE CIOCOLATI SI SNACKSURI SI FAST FOODURI SI INGRASAMINTE ca neÅŸte cimpanzeice, si cand se intind pe plaja se aude aÅŸa un duduit usurel, de parca ar pÄƒÅŸi o elefÄƒnÅ£icÄƒ gravidÄƒ Ã®n luna 32-a. Rusinica!\r\n7. SÄƒ nu-mi mai fie aÅŸa de greu fÄƒrÄƒ Å£igÄƒri (azi Ã®i a zecea zi? a unÅŸpea...?)\r\n8. SÄƒ am somn noaptea.\r\n9. SÄƒ creascÄƒ acÅ£iunile Albalact.\r\n10. SÄƒ nu se mai uite administratoru cu un ochi la mine cÃ¢nd plÄƒtesc Ã®ntreÅ£inerea, sÄƒ ezite cÃ¢nd Ã®mi dÄƒ restu\' ÅŸi apoi sÄƒ mÄƒ Ã®ntrebe:\r\n\r\n<em>DUMNEVOASTRÄ‚ CÃ‚T CÃ‚ÅžTIGAÅ¢I PE LUNÄ‚, DOMNULE GROPARU???</em>\r\n\r\nLeapÅŸa merge, ca de obi, la cine vrea sÄƒ se contamineascÄƒ de ea, dar mai ales <a href=\"http://www.adrianpopa.ro/\" target=\"_blank\">d-lui acestuia www-ist</a>.','Leapsha cu cel mai misto cadou',0,'','publish','open','open','','leapsha-cu-cel-mai-misto-cadou','','','2007-12-10 23:41:01','2007-12-10 21:41:01','',0,'http://www.groparu.ro/?p=856',0,'post','',8),(857,1,'2007-12-11 10:06:12','2007-12-11 08:06:12','','avast.JPG',0,'','inherit','open','open','','avastjpg','','','2007-12-11 10:06:12','2007-12-11 08:06:12','',858,'http://www.groparu.ro/wp-content/uploads/2007/12/avast.JPG',0,'post','image/jpeg',0),(858,1,'2007-12-11 10:06:46','2007-12-11 08:06:46','Finca mi-a expirat antivirusu\'!\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/12/avast.JPG\" title=\"avast.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/12/avast.JPG\" alt=\"avast.JPG\" /></a>','De ce mi-e frica sa nu racesc',0,'','publish','open','open','','de-ce-mi-e-frica-sa-nu-racesc','','','2007-12-11 10:06:46','2007-12-11 08:06:46','',0,'http://www.groparu.ro/?p=858',0,'post','',5),(859,1,'2007-12-11 10:53:25','2007-12-11 08:53:25','Am strigat, intr-o clipa de disperare:\r\n\r\n<strong>- DOAMNEEEEE, DA-MI MINTEEEEE!!!!!Â </strong>\r\n\r\nDupa aceea m-am uitat adanc in interiorul meu.\r\n\r\nDeja aveam.','Cat de rapid e Dumnezeu',0,'','publish','open','open','','cat-de-rapid-e-dumnezeu','','','2007-12-11 10:53:25','2007-12-11 08:53:25','',0,'http://www.groparu.ro/?p=859',0,'post','',8),(860,1,'2007-12-12 09:40:56','2007-12-12 07:40:56','Cumnatu-meu este cel mai bucatar in viatza, o castigat concursuri de facut cocktaile, e cel mai sofer, tot timpu are dreptate - normal. Doara e neamtz! - deci e antrenor de hanbal, apicultor melifer, inginer agronom, sofer, bucatar, barman, cocktailist, scafandru, vames, DJ si om de afaceri! Sa ma trazneasca bunul Dumnezau Ã®n gÃ¢t daca am exagerat fie si cu o miime de secunda ce am scris mai sus.\r\n\r\nNo.\r\n\r\nSi fiind sarbatorile de iarna, ce zice el, intr-un an! Mai, eu m-am saturat de:\r\n- gaste umplute cu prune uscate;\r\n- ratza daneza cu castane italieneÅŸti;\r\n- varza de bruxelles cu carne de leopard;\r\n- orez cu sfarcuri de tigroaica siberianÄƒ, specie protejatÄƒ;\r\n- facoceri de lapte in sos de drojdie de vin chilian rozÃ©;\r\n- lebÄƒdÄƒ vienezÄƒ cu cartofi dulci, fiartÄƒ Ã®n apÄƒ de fÃ¢ntÃ¢nÄƒ artezianÄƒ romanÄƒ din Vezuviu;\r\n- frunze de mangrove cu icre de Manciuria depuse pe ele;\r\n- gulii indoneziene cu scame din buric de maimuÅ£Äƒ;\r\n- embrioni de muscÄƒ  maturaÅ£i Ã®n salivÄƒ de mistreÅ£ Gauloise;\r\n- ciuperci amazoniene de pe arborele de cafea;\r\n- placenta de mÄƒgÄƒriÅ£Äƒ sÄƒlbaticÄƒ cu oo de Å£estoasÄƒ;\r\n- clitoris de elefÄƒnÅ£icÄƒ indianÄƒ culeÅŸi la muson;\r\n- mujdei de usturoi tibetan macerat Ã®n gÄƒlbenuÅŸ de pinguin cu sevÄƒ de araucaria;\r\n- normal, labe de panda Ã®n limbi de puiet de sturion (de care ÅŸi eu, unul, m-am sÄƒturat);\r\n- smantana din lapte de vacÄƒ moscatÄƒ cu salatÄƒ greceascÄƒ cu tegument din scrot de ren;\r\n- pui al sfioaselor cÄƒprioare din delta Mekongului, nÄƒscut prin incest din pÄƒrinÅ£i veriÅŸori;\r\n- peÅŸte remora prÄƒjit Ã®n curent electric de Å£ipar de Orinoco.\r\n\r\nDeci zice cumnatu-meu ia sa facem noi ceva cu adevarat exotic, finca am o retzeta despre cum se gateste un peste din Marea Caraibelor, la care ii spune <strong>red snapper</strong>! AÅŸa cÄƒ mere la pescÄƒria aia din oraÅŸu lor geman, ÅŸi Ã®i zice:\r\n\r\n- Vreau sÄƒ fac comandÄƒ de <strong>red snapper</strong> congelat Ã®n zÄƒpadÄƒ de pe Kilimanjaro de toamna trecutÄƒ; da\' grijÄƒ sÄƒ nu vÄƒ scape ÅŸi gheaÅ£Äƒ de pe Fugi San Ã®n ambalaj!\r\n- Vai, meine Herren, zice oberu\', kein problem, gib mir oiro, ÅŸi kein problem!\r\n\r\nCosta vreo 80 euroi suta de grame.\r\n\r\n- BÄƒ, da sa nu va puie umbra lu Hitler sÄƒ nu am peÅŸtele cu 2 zile Ã®nainte de CrÄƒciun, cÄƒ vÄƒ gazez cu Cyclon B!\r\n- Vaaai, mein herr, kein problem! Noi nemÅ£ii suntem puntcualen ÅŸi seriozÄƒn; deci kein griji!\r\n\r\nDupa 2 sÄƒptÄƒmÃ¢ni, cumnatu-meu mere sÄƒ-i verifice:\r\n\r\n- BÄƒ, cum staÅ£i cu <strong>red snapperu</strong>\'?\r\n- Mein herr, kein problem, peÅŸtele deja este trimis comandÄƒ Ã®n Caribic, deci venit imediat! Kein problem!\r\n\r\nCu trei zile Ã®nainte de CrÄƒciun, mere iar cumnatu:\r\n\r\n- BÄƒ! Ce o mai zis peÅŸtele?\r\n- Nichts, e Ã®n Hamburg, maine ma duc sa il preiau. Kein problem, kein problem!\r\n\r\nCu o zi Ã®nainte de CrÄƒciun, cumnatu-meu - parÄƒ nemÅ£eascÄƒ de foc, avion furios Messerschmidt 109, tanc Leopard (cÄƒ cu Tigerele ÅŸi Panzerele nemÅ£ii or pierdut deja rÄƒzboiu) - bÄƒtea cu pumnu Ã®n masÄƒ, Ã®n fiÅŸÄƒrie:\r\n\r\n- VÄƒ omor, mama voastrÄƒ de nemÅ£ÄƒlÄƒi, mi-aÅ£ promis! Unde mi-i pejtele???\r\n- Vai, herr, vai, kein problem, noi suntem Doice, deci o sÄƒ fie bine! ÃŽncÄƒ o orÄƒ ÅŸi ajunge!!!\r\n- Deci bÄƒ, dacÄƒ nu vine pejtele, vÄƒ crep capu ÅŸi mÄƒ uit Ã®nÄƒuntru!\r\n\r\nClar cÄƒ nu o venit nici Ã®ntr-o orÄƒ, nici Ã®n douÄƒ. Cumnatu-meu o vrut sÄƒ Ã®i caute sÄƒ le spargÄƒ capetele, da nu i-o mai gÄƒsit, cÄƒ fugiserÄƒ Ã®n Berlin, la trupele americane de ocupaÅ£ie, sÄƒ scape.\r\n\r\nÃŽn ziua de CrÄƒciun - surprizÄƒÄƒÄƒ!!! Cine gÃ¢fÃ¢ia fericit la uÅŸÄƒ la cumnatu-meu, cu un pachet de hÃ¢rtie de aluminiu Ã®n braÅ£e, din care ieÅŸea o coadÄƒ de peÅŸte? Propitaru pescÄƒrieeei!!!\r\n\r\n- Mein herr, zice Äƒsta, cu scuzele de rigoare, numai acum l-a primit de la Santo Domingo, ÅŸi vi l-am adus ca sÄƒ vÄƒ salvez masa de CrÄƒciun.\r\n- Red snapperu\' meu, izbucneste cumnatu-meu, fericit. Danke, danke zer schoen, mai zice el, nu-i nimic, asa de mult ma bucur... frohliche weinachten, meri-n crizmÄƒs!\r\n\r\nIsi ia cumnatu pestele si fuga cu el in bucatarie, pune apa la fiert, unge tigaia cu ulei de masline, taie ceapa, morcovi, curatza leustean, curatza cartofi, pune painea si cozonacii la copt, pune masa, ii plesneste pe aia micii care vroiau sa vada cum arata un <strong>red snapper</strong>, scoate vinul si il desface si il lasa sa respire, marunteste patrunjelu, pregateste condimentele mediteraneene, face budinca pentru desert, spalÄƒ vasele ÅŸi cÄƒnile, incinge cuptoru\', pregateste tigaia cu tot ce trebuie, mai verifica o data re\'eta sÄƒ fie OK, aleargÄƒ la peÅŸte sÄƒ Ã®l dezambaleze, Ã®l dezambaleazÄƒ...\r\n\r\nÅžI E GATA-GATA SÄ‚ FACÄ‚ INFARCT.\r\n\r\nÃŽn loc sÄƒ primeascÄƒ un <strong>red snapper</strong>, primise un <strong>black snapper</strong>!!!!\r\n\r\nNo. Asta o pÄƒÅ£it.','Deci de ce nu s-o bucurat cumnatu-meu de CrÄƒciunul trecut',0,'','publish','open','open','','deci-de-ce-nu-s-o-bucurat-cumnatu-meu-de-craciunul-trecut','','','2007-12-12 09:40:56','2007-12-12 07:40:56','',0,'http://www.groparu.ro/?p=860',0,'post','',16),(862,2,'2007-12-13 08:32:22','2007-12-13 06:32:22','<strong>ÃŽnainte de a face sex:</strong>\r\n- Bine, draga mea, facem, da vezi cÄƒ nu am nici un chef sÄƒ fac duÅŸ Ã®nainte.\r\n- E OK dacÄƒ Ã®mi pÄƒstrez ciorapii?\r\n- ParcÄƒ nu aveai cutele astea la burtÄƒ acum 2 sÄƒptÄƒmÃ¢ni!\r\n- Bine, o facem, da numa dacÄƒ mÄƒ laÅŸi sÄƒ mÄƒ uit la meci cu sonoru la maxim Ã®n timp ce... ÅŸtii tu!\r\n\r\n<strong>ÃŽn timp ce faceÅ£i sex:</strong>\r\n- Iubita mea, te rog frumos sa te abtii sa te mai uiti daca iti face burta cute sau nu atunci cand stai Ã®ntinsÄƒ pe spate!\r\n- Scumpa mea, acopera-ti nasul cu perna, voi trage un partz puternic si mi-i lene sa ma duc pana la baie.\r\n- Oare cum ar fi dacÄƒ Å£i-ai chema ÅŸi o prietenÄƒ?\r\n- Vezi cÄƒ vreau sÄƒ terminÄƒm mai repede azi, cÄƒ joacÄƒ CFR cu Gloria peste 3 minute pe Kanal D.\r\n- IarÄƒ Å£i-ai ascuns clitorisu\' Äƒla? Mai aratÄƒ-mi-l o datÄƒ unde Ã®i, de data asta promit cÄƒ Å£in minte!\r\n- Du-te dÄƒ-mi un pic FHM-ul, sÄƒ mai vÄƒd o datÄƒ faza aia cu futaiu tantric.\r\n- Pot sÄƒ te rog sÄƒ Å£ipi ÅŸi sÄƒ gemi un pic?\r\n\r\n<strong>DupÄƒ sex:</strong>\r\n- Wow, asta o fost prima ejaculare precoce din viaÅ£a mea!\r\n- Åži pentru tine a fost bine?\r\n- Iubita mea, te-ai gandit vreodata ca ai putea face chestia asta pe mult mai multi bani?','CÃ¢teva replici penibile cÃ¢nd faci sex',0,'','publish','open','open','','cateva-replici-penibile-cand-faci-sex','','','2007-12-13 08:32:22','2007-12-13 06:32:22','',0,'http://www.groparu.ro/?page_id=862',0,'post','',0),(868,1,'2007-12-13 08:33:34','2007-12-13 06:33:34','\r\n<p class=\"post\" id=\"post-862\">&nbsp;</p>\r\n<p class=\"post\" id=\"post-862\"><a href=\"http://www.groparu.ro/wp-content/uploads/2007/12/triolegs80ua.jpg\" title=\"triolegs80ua.jpg\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/12/triolegs80ua.jpg\" alt=\"triolegs80ua.jpg\" /></a></p>\r\n<p class=\"entry\">&nbsp;</p>\r\n\r\n<p class=\"entry\"><strong>ÃŽnainte de a face sex:</strong>\r\n- Bine, draga mea, facem, da vezi cÄƒ nu am nici un chef sÄƒ fac duÅŸ Ã®nainte.\r\n- E OK dacÄƒ Ã®mi pÄƒstrez ciorapii?\r\n- ParcÄƒ nu aveai cutele astea la burtÄƒ acum 2 sÄƒptÄƒmÃ¢ni!\r\n- Bine, o facem, da numa dacÄƒ mÄƒ laÅŸi sÄƒ mÄƒ uit la meci cu sonoru la maxim Ã®n timp ceâ€¦ ÅŸtii tu!\r\n\r\n<strong>ÃŽn timp ce faceÅ£i sex:</strong>\r\n- Iubita mea, te rog frumos sa te abtii sa te mai uiti daca iti face burta cute sau nu atunci cand stai Ã®ntinsÄƒ pe spate!\r\n- Scumpa mea, acopera-ti nasul cu perna, voi trage un partz puternic si mi-i lene sa ma duc pana la baie.\r\n- Oare cum ar fi dacÄƒ Å£i-ai chema ÅŸi o prietenÄƒ?\r\n- Vezi cÄƒ vreau sÄƒ terminÄƒm mai repede azi, cÄƒ joacÄƒ CFR cu Gloria peste 3 minute pe Kanal D.\r\n- IarÄƒ Å£i-ai ascuns clitorisuâ€™ Äƒla? Mai aratÄƒ-mi-l o datÄƒ unde Ã®i, de data asta promit cÄƒ Å£in minte!\r\n- Du-te dÄƒ-mi un pic FHM-ul, sÄƒ mai vÄƒd o datÄƒ faza aia cu futaiu tantric.\r\n- Pot sÄƒ te rog sÄƒ Å£ipi ÅŸi sÄƒ gemi un pic?\r\n\r\n<strong>DupÄƒ sex:</strong>\r\n- Wow, asta o fost prima ejaculare precoce din viaÅ£a mea!\r\n- Åži pentru tine a fost bine?\r\n- Iubita mea, te-ai gandit vreodata ca ai putea face chestia asta pe mult mai multi bani?','CÃ¢teva replici penibile cÃ¢nd faci sex',0,'','publish','open','open','','cateva-replici-penibile-cand-faci-sex','','','2007-12-13 09:11:57','2007-12-13 07:11:57','',0,'http://www.groparu.ro/?p=868',0,'post','',13),(863,1,'2007-12-12 19:11:26','2007-12-12 17:11:26','Urarea asta de La Multi Ani i-am facut-o unei prietene cu mai multa vreme  in urma, si musteste de un erotismÂ feroce, evident, de altfel. Deci atat am avut de zis.\r\n\r\nSanii sa-ti ramana mari si tari\r\nS-ai parte de barbati armasari,\r\nSa te pupe si sa te iubeasca\r\nSi ore-ntregi sa te tavaleasca!\r\nSa te pupe apasat pe sÃ¢ni\r\nSa ti-i cantareasca-n mÃ¢ni,\r\nSa-i adore pan la moarte\r\nDespre ei sa scrie carte,\r\nSa-i picteze si sa-i cÃ¢nte\r\nSa-i sculpteze, sa-i descÃ¢nte!\r\nPalme calde sa-ti fie sutien\r\nMirosind a Davidoff for men,\r\nSa ti se balangane sexy inainte si-napoi\r\nCand pe spate gÃ¢fÃ¢i supt vrun marÅ£afoi,\r\nS-ai orgasme multiple ÅŸi dese\r\nPalme multe peste fese,\r\nCicluri fara de durere\r\nPutza lunga cand vei cere!\r\nLa Multi Ani si mult amor!\r\n(Dupa sanii tai masculii mor)','Deci ce uram io intr-o vreme',0,'','publish','open','open','','deci-ce-uram-io-intr-o-vreme','','','2007-12-12 19:11:26','2007-12-12 17:11:26','',0,'http://www.groparu.ro/?p=863',0,'post','',10),(864,1,'2007-12-17 01:04:06','2007-12-16 23:04:06','Aceasta imagine ascunde o mica ÅŸaradÄƒ pe care vÄƒ invit sÄƒ o dezlegaÅ£i :D\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/12/felix.JPG\" title=\"felix.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/12/felix.JPG\" alt=\"felix.JPG\" /></a>','Urare de Craciun',0,'','publish','open','open','','urare-de-craciun','','','2007-12-17 01:04:06','2007-12-16 23:04:06','',0,'http://www.groparu.ro/?p=864',0,'post','',9),(865,1,'2007-12-12 20:14:42','2007-12-12 18:14:42','','felix.JPG',0,'','inherit','open','open','','felixjpg','','','2007-12-12 20:14:42','2007-12-12 18:14:42','',-1197483089,'http://www.groparu.ro/wp-content/uploads/2007/12/felix.JPG',0,'post','image/jpeg',0),(866,1,'2007-12-12 20:17:04','2007-12-12 18:17:04','','voiculescurectificracit.jpg',0,'','inherit','open','open','','voiculescurectificracitjpg','','','2007-12-12 20:17:04','2007-12-12 18:17:04','',867,'http://www.groparu.ro/wp-content/uploads/2007/12/voiculescurectificracit.jpg',0,'post','image/jpeg',0),(867,1,'2007-12-16 11:03:09','2007-12-16 09:03:09','<a href=\"http://www.groparu.ro/wp-content/uploads/2007/12/voiculescurectificracit.jpg\" title=\"voiculescurectificracit.jpg\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/12/voiculescurectificracit.jpg\" alt=\"voiculescurectificracit.jpg\" /></a>\r\n\r\nLoat de pe saitu personal. Binie, no, si da, un pic modificat!','Marketing politic',0,'','publish','open','open','','marketing-politic','','','2007-12-16 11:04:51','2007-12-16 09:04:51','',0,'http://www.groparu.ro/?p=867',0,'post','',8),(869,1,'2007-12-13 08:36:08','2007-12-13 06:36:08','','triolegs80ua.jpg',0,'','inherit','open','open','','triolegs80uajpg','','','2007-12-13 08:36:08','2007-12-13 06:36:08','',868,'http://www.groparu.ro/wp-content/uploads/2007/12/triolegs80ua.jpg',0,'post','image/jpeg',0),(870,2,'2007-12-13 11:49:17','2007-12-13 09:49:17','<p class=\"entry\">Cumnatu-meu este cel mai bucatar in viatza, o castigat concursuri de facut cocktaile, e cel mai sofer, tot timpu are dreptate - normal. Doara e neamtz! - deci e antrenor de hanbal, apicultor melifer, inginer agronom, sofer, bucatar, barman, cocktailist, scafandru, vames, DJ si om de afaceri! Sa ma trazneasca bunul Dumnezau Ã®n gÃ¢t daca am exagerat fie si cu o miime de secunda ce am scris mai sus.\r\n\r\nNo.\r\n\r\nSi fiind sarbatorile de iarna, ce zice el, intr-un an! Mai, eu m-am saturat de:\r\n- gaste umplute cu prune uscate;\r\n- ratza daneza cu castane italieneÅŸti;\r\n- varza de bruxelles cu carne de leopard;\r\n- orez cu sfarcuri de tigroaica siberianÄƒ, specie protejatÄƒ;\r\n- facoceri de lapte in sos de drojdie de vin chilian rozÃ©;\r\n- lebÄƒdÄƒ vienezÄƒ cu cartofi dulci, fiartÄƒ Ã®n apÄƒ de fÃ¢ntÃ¢nÄƒ artezianÄƒ romanÄƒ din Vezuviu;\r\n- frunze de mangrove cu icre de Manciuria depuse pe ele;\r\n- gulii indoneziene cu scame din buric de maimuÅ£Äƒ;\r\n- embrioni de muscÄƒ  maturaÅ£i Ã®n salivÄƒ de mistreÅ£ Gauloise;\r\n- ciuperci amazoniene de pe arborele de cafea;\r\n- placenta de mÄƒgÄƒriÅ£Äƒ sÄƒlbaticÄƒ cu oo de Å£estoasÄƒ;\r\n- clitoris de elefÄƒnÅ£icÄƒ indianÄƒ culeÅŸi la muson;\r\n- mujdei de usturoi tibetan macerat Ã®n gÄƒlbenuÅŸ de pinguin cu sevÄƒ de araucaria;\r\n- normal, labe de panda Ã®n limbi de puiet de sturion (de care ÅŸi eu, unul, m-am sÄƒturat);\r\n- smantana din lapte de vacÄƒ moscatÄƒ cu salatÄƒ greceascÄƒ cu tegument din scrot de ren;\r\n- pui al sfioaselor cÄƒprioare din delta Mekongului, nÄƒscut prin incest din pÄƒrinÅ£i veriÅŸori;\r\n- peÅŸte remora prÄƒjit Ã®n curent electric de Å£ipar de Orinoco.\r\n\r\nDeci zice cumnatu-meu ia sa facem noi ceva cu adevarat exotic, finca am o retzeta despre cum se gateste un peste din Marea Caraibelor, la care ii spune <strong>red snapper</strong>! AÅŸa cÄƒ mere la pescÄƒria aia din oraÅŸu lor geman, ÅŸi Ã®i zice:\r\n\r\n- Vreau sÄƒ fac comandÄƒ de <strong>red snapper</strong> congelat Ã®n zÄƒpadÄƒ de pe Kilimanjaro de toamna trecutÄƒ; daâ€™ grijÄƒ sÄƒ nu vÄƒ scape ÅŸi gheaÅ£Äƒ de pe Fugi San Ã®n ambalaj!\r\n- Vai, meine Herren, zice oberuâ€™, kein problem, gib mir oiro, ÅŸi kein problem!\r\n\r\nCosta vreo 80 euroi suta de grame.\r\n\r\n- BÄƒ, da sa nu va puie umbra lu Hitler sÄƒ nu am peÅŸtele cu 2 zile Ã®nainte de CrÄƒciun, cÄƒ vÄƒ gazez cu Cyclon B!\r\n- Vaaai, mein herr, kein problem! Noi nemÅ£ii suntem puntcualen ÅŸi seriozÄƒn; deci kein griji!\r\n\r\nDupa 2 sÄƒptÄƒmÃ¢ni, cumnatu-meu mere sÄƒ-i verifice:\r\n\r\n- BÄƒ, cum staÅ£i cu <strong>red snapperu</strong>â€˜?\r\n- Mein herr, kein problem, peÅŸtele deja este trimis comandÄƒ Ã®n Caribic, deci venit imediat! Kein problem!\r\n\r\nCu trei zile Ã®nainte de CrÄƒciun, mere iar cumnatu:\r\n\r\n- BÄƒ! Ce o mai zis peÅŸtele?\r\n- Nichts, e Ã®n Hamburg, maine ma duc sa il preiau. Kein problem, kein problem!\r\n\r\nCu o zi Ã®nainte de CrÄƒciun, cumnatu-meu - parÄƒ nemÅ£eascÄƒ de foc, avion furios Messerschmidt 109, tanc Leopard (cÄƒ cu Tigerele ÅŸi Panzerele nemÅ£ii or pierdut deja rÄƒzboiu) - bÄƒtea cu pumnu Ã®n masÄƒ, Ã®n fiÅŸÄƒrie:\r\n\r\n- VÄƒ omor, mama voastrÄƒ de nemÅ£ÄƒlÄƒi, mi-aÅ£ promis! Unde mi-i pejtele???\r\n- Vai, herr, vai, kein problem, noi suntem Doice, deci o sÄƒ fie bine! ÃŽncÄƒ o orÄƒ ÅŸi ajunge!!!\r\n- Deci bÄƒ, dacÄƒ nu vine pejtele, vÄƒ crep capu ÅŸi mÄƒ uit Ã®nÄƒuntru!\r\n\r\nClar cÄƒ nu o venit nici Ã®ntr-o orÄƒ, nici Ã®n douÄƒ. Cumnatu-meu o vrut sÄƒ Ã®i caute sÄƒ le spargÄƒ capetele, da nu i-o mai gÄƒsit, cÄƒ fugiserÄƒ Ã®n Berlin, la trupele americane de ocupaÅ£ie, sÄƒ scape.\r\n\r\nÃŽn ziua de CrÄƒciun - surprizÄƒÄƒÄƒ!!! Cine gÃ¢fÃ¢ia fericit la uÅŸÄƒ la cumnatu-meu, cu un pachet de hÃ¢rtie de aluminiu Ã®n braÅ£e, din care ieÅŸea o coadÄƒ de peÅŸte? Propitaru pescÄƒrieeei!!!\r\n\r\n- Mein herr, zice Äƒsta, cu scuzele de rigoare, numai acum l-a primit de la Santo Domingo, ÅŸi vi l-am adus ca sÄƒ vÄƒ salvez masa de CrÄƒciun.\r\n- Red snapperuâ€™ meu, izbucneste cumnatu-meu, fericit. Danke, danke zer schoen, mai zice el, nu-i nimic, asa de mult ma bucurâ€¦ frohliche weinachten, meri-n crizmÄƒs!\r\n\r\nIsi ia cumnatu pestele si fuga cu el in bucatarie, pune apa la fiert, unge tigaia cu ulei de masline, taie ceapa, morcovi, curatza leustean, curatza cartofi, pune painea si cozonacii la copt, pune masa, ii plesneste pe aia micii care vroiau sa vada cum arata un <strong>red snapper</strong>, scoate vinul si il desface si il lasa sa respire, marunteste patrunjelu, pregateste condimentele mediteraneene, face budinca pentru desert, spalÄƒ vasele ÅŸi cÄƒnile, incinge cuptoruâ€™, pregateste tigaia cu tot ce trebuie, mai verifica o data reâ€™eta sÄƒ fie OK, aleargÄƒ la peÅŸte sÄƒ Ã®l dezambaleze, Ã®l dezambaleazÄƒâ€¦\r\n\r\nÅžI E GATA-GATA SÄ‚ FACÄ‚ INFARCT.\r\n\r\nÃŽn loc sÄƒ primeascÄƒ un <strong>red snapper</strong>, primise un <strong>black snapper</strong>!!!!\r\n\r\nNo. Asta o pÄƒÅ£it.','Deci de ce nu s-o bucurat cumnatu-meu de CrÄƒciunul trecut',0,'','publish','open','open','','deci-de-ce-nu-s-o-bucurat-cumnatu-meu-de-craciunul-trecut','','','2007-12-13 11:49:17','2007-12-13 09:49:17','',0,'http://www.groparu.ro/?page_id=870',0,'post','',0),(871,2,'2007-12-13 11:49:59','2007-12-13 09:49:59','<p class=\"entry\">1. Oai, ce rochie faina ti-ai luat de la piatza MÄƒrÄƒÅŸti, de la ruÅŸi!\r\n2. Ai spanac, pÄƒtrunjel ÅŸi ruj pe dinÅ£i.\r\n3. Te-ai mai Ã®ngrÄƒÅŸat, aÅŸa-i? Nu cumva te mÄƒriÅ£i din cauzÄƒ cÄƒ eÅŸti puÅ£intel foarte gravidÄƒ?\r\n4. Tu, aÅŸa mÄƒ bucur pentru voi, cÄƒ mi-era fricÄƒ cÄƒ nu te mai mÄƒriÅ£i never ever!\r\n5. A, e foarte bun pÄƒrintele Äƒsta, el i-o cununat ÅŸi pe X-ulescu. Bine, ei or divorÅ£at dupa 2 ani.\r\n6. Åžtii cÄƒ domniÅŸoara ta de onoare ÅŸi mirele or fost Ã®mpreunÄƒ, nu?\r\n7. Vezi ca - nu te uita acuma - ai un coÅŸ munumental pe umÄƒr.\r\n8. Verigheta asta nu e de aur, nu?\r\n9. Sa ÅŸtii cÄƒ nu-i adevÄƒrat cÄƒ nu existÄƒ mireasÄƒ urÃ¢tÄƒ.\r\n10. Vezi cÄƒ la noapte vÄƒ dau o serie de bipuri, sÄƒ vÄƒd dacÄƒ vÄƒ futeÅ£i sau nu.\r\n\r\n<strong>Update</strong>: Ce pula mea de luna de miere ii aia in care mergi cu el?','Top 10 chestii care nu se spun miresei la o nunta',0,'','publish','open','open','','top-10-chestii-care-nu-se-spun-miresei-la-o-nunta','','','2007-12-13 11:49:59','2007-12-13 09:49:59','',0,'http://www.groparu.ro/?page_id=871',0,'post','',0),(872,2,'2007-12-13 11:51:03','2007-12-13 09:51:03','<p class=\"entry\">Tine apasat ambreiaju, daâ€™ pana-n fund! Si frana apas-o treptat, ca daca apesi dintr-o data dai cu capu de volan, ca ej prost, se vede pe tine! De ce nu te asiguri? Nu te mai uita acuma, ca pierzi prea mult timp si blochezi circulatia, iti trebuie ochelari? Vai de mama mea, ce sofer o sa iasa din tine, mai bine te apuci din nou de mers pe bicicleta! Ia privirea de la schimbatoru de viteze cand bagi in viteze! De ce nu te uiti dupa reper cand faci parcarea cu spatele? Cand ti-am zis io sa tragi de volan? Nu vezi ca tragi de volan in directia gresita??? Iar ai inecat motoruâ€™, crezi ca firma are, asa, bani cacalau sa tot schimbe popma de benzina cand ai tu chef? Poarta-te frumos cu masina! Cand circuli, uita-te la 15-20 metri in fatza, la farurile alora din fatza, sa vezi daca nu pun frana! Io cu cine vorbesc? Io degeaba iti spun daca tu nu m-asculti! Ai grija la alternarea aia ambreiaj-acceleratie, daca ii dai drumu prea repede iar moare motoru! Incredibil cum la a doua lectie de condus tu inca nu simti masina! Cand mergi cu spatele, uita-te in oglinzi si in spate si pe geam si in fatza si lateral si la volan!!! <strong>SI NU MAI STA ASA STRESAT, RELAXEAZA-TE!!!!!</strong>\r\n\r\nAsa ca la plecare i-am lasat cadou pe volan, fara sa ma vada, un cacamitz din nas, cu dedicatie, care s-a si lipit instant si iremediabil de degetele lui umede, cand am schimbat locurile.','Deci scoala de soferi',0,'','publish','open','open','','deci-scoala-de-soferi','','','2007-12-13 11:51:03','2007-12-13 09:51:03','',0,'http://www.groparu.ro/?page_id=872',0,'post','',0),(873,2,'2007-12-13 11:51:36','2007-12-13 09:51:36','Se zice ca oamenii is de trei tipuri: oameni buni, oameni rai si soferi. Dupa ce am incercat pe rand sa fiu si bun si rau, am ajuns la concluzia ca sunt o personalitate mult prea complexa si adamanta ca sa ma restrang la a fi doar inger sau demon, cand pot fi amandoo; de aia acum sunt Ã®n plin proces de devenire ÅŸi mai complex, prin devenirea de ÅŸofer.\r\n\r\nBon.\r\n\r\nAzi dimineatza ma duc la conducere, prima lectie de condus de la Tiganiada de anu asta, cand am bagat o tura cu masina lu TÃ¢mp aka Greuceanu, taman cÃ¢nd eram noi mai beÅ£i ÅŸi poiana noastra mai plinÄƒ de buÅŸteni. Sau de prekini buÅŸteni de beÅ£i.\r\n\r\nAÅŸa.\r\n\r\nÅži nenea instructoru zice:\r\n\r\n- CÃ¢te ore de condus aveÅ£i?\r\n- Nici una, zic io, pe stilu meu, cÄƒ dacÄƒ ziceam pe stilu Academiei aÅŸ fi zis â€œniciunaâ€, Ã®mpreunÄƒ sau â€œlegatâ€, cum se zice.\r\n- Aha, zice el.\r\n- Da-da-da, zic io. Da dumneavoastra cÃ¢te ore de instructaj aÅ£i fÄƒcut pÃ¢n-acuma?\r\n- E a doua mea zi aicea, zice el.\r\n- A doua zi! zic io. Aha.\r\n- Da-da-da, zice el.\r\n- Bon! zic. HaideÅ£i Ã®nÄƒuntru. Prima chestie pe care trebuie sÄƒ o ÅŸtiÅ£i cÃ¢nd sunteÅ£i instructor: reglaÅ£i scaunul, oglinda, vÄƒ asiguraÅ£i sÄƒ fie frÃ¢na de mÃ®nÄƒ trasÄƒ. VÄƒ legaÅ£i cu centura de siguranÅ£Äƒ.\r\n\r\nDe ce dreq nu rÃ¢de nimeni cÃ¢nd fac io bancuri?\r\n\r\n- Uite aicea, zice instructoru. CÃ¢nd apeÅŸi pe pedale, apasÄƒ incetuc; cÄƒ nu mai suntem pe Dacie BerlinÄƒ!\r\n- Ai, najpa Ã®s maÅŸinile elea, zic io, cele mai najpa! Mai najpa ca elea nu existÄƒ. Najpa-najpa-najpa.\r\n- Åžtiu, zice el, ÅŸi io am din aia.\r\n- Nu-i stress, zic io, ÅŸi dau sÄƒ-l Ã®mpac. Ia ui o maÅŸinÄƒ de Auto Tudor! Dom instructor, pot sÄƒ mÄƒ Ã®nfig Ã®n maÅŸina concurenÅ£ei?\r\n- Nu, zice el, Ã®n nici un caz.\r\n- PÄƒcat, oftez io. Mai ales cÄƒ am Ã®nÅ£eles cÄƒ vina se Ã®mparte la jumate cu instructoru auto, dacÄƒ faci accident la ÅŸcoala de ÅŸoferi!\r\n- ÃŽncearcÄƒ sa nu mai apeÅŸi pe frÃ¢nÄƒ aÅŸa tare, zice el.\r\n- Da? zic io. Las ca de acum Ã®ncolo nu am sÄƒ mai apÄƒs deloc pe frÃ¢nÄƒ, ÅŸi am sÄƒ vÄƒd ce bine o sÄƒ vÄƒ parÄƒ!\r\n- LasÄƒ asta, zice el.\r\n- NU, zic eu, nu las. Åži Ã®n continuare, am fÄƒcut un top 10 chestii care NU trebe spuse la instructoru de la ÅŸcoala de ÅŸoferi:\r\n\r\n1. Ui doo gajici, mai zi-mi o data care-i claxonu! CÄƒ io aÅŸa am vÄƒst cÄƒ face bÄƒieÅ£ii, claxoneazÄƒ fetele ca nebunii.\r\n2. Hai sÄƒ-l fentÄƒm p-Äƒsta cu TIRu din spate, sÄƒ semnalizez stanga, ÅŸi de fapt sÄƒ fac dreapta! Ce zici?\r\n3. Hai sÄƒ probÄƒm dacÄƒ Dacia Logan chiar are 3 stele la EURONCAP!\r\n4.Â MÄƒ bag acuma prin groapa asta, cÄƒ vreau sÄƒ mÄƒ Ã®nveÅ£i ÅŸi cum se schimbÄƒ roata de rezervÄƒ.\r\n5. Hai sÄƒ o urmÄƒrim pe bruneta aia cu Matizu! Ce zici?\r\n6. Deci cÃ¢nd sunt claxonat la semafor aÅŸtept sÄƒ se facÄƒ galben, ÅŸi numa atuncea trec, nu?\r\n7. Ui, instructore, cum conduc io fÄƒrÄƒ mÃ¢ini ÅŸi cu ochii Ã®nchiÅŸi!\r\n8. MaÅŸina asta poate trece de-a dreptu prin giratoriu, fÄƒrÄƒ sÄƒ mai ocoleascÄƒ?\r\n9. Tre sÄƒ ne oprim sÄƒ beau o votcÄƒ, cÄƒ ui ce Ã®mi tremurÄƒ mÃ¢inile!\r\n10. Nu mai vorbiÅ£i Ã®n direcÅ£ia mea, vÄƒ pute Ã®nfiorÄƒtor gura!!!','Deci top 10 chestii care nu se spune la scoala cu soferi - partea I',0,'','publish','open','open','','deci-top-10-chestii-care-nu-se-spune-la-scoala-cu-soferi-partea-i','','','2007-12-13 11:51:36','2007-12-13 09:51:36','',0,'http://www.groparu.ro/?page_id=873',0,'post','',0),(874,2,'2007-12-13 11:51:56','2007-12-13 09:51:56','1. Nu aveÅ£i nimica cu gayii, nu? (ÅŸi Ã®l iei de mÃ¢nÄƒ)\r\n2. BÄƒ, cÃ¢nd mai ai o elevÄƒ la condus, merem cu ea Ã®n FÄƒget sÄƒ o futem amÃ¢ndoi?\r\n3. MaÅŸina asta dacÄƒ se furÄƒ poate fi urmÄƒritÄƒ prin GPS?\r\n4. Fii atent acuma numa cum conduc io, fumez ÅŸi vorbesc la telefon fÄƒrÄƒ handsfree Ã®n acelaÅŸi timp!\r\n5. DacÄƒ calci o babÄƒ nu faci pÃ¢rnaie, aÅŸa-i?\r\n6. ÅžÄƒfu, mÄƒ mÃ¢ncÄƒ gaura curului, mÄƒ scarpini te rog, cÄƒ io-s ocupat cu condusu!\r\n7. ÃŽndreptÄƒ un pic oglinda, sÄƒ mÄƒ rujez, plm.\r\n8. Data viitoare, dacÄƒ e noapte, ai curaj sÄƒ te uiÅ£i cu mine cu bricheta dacÄƒ mai e benzinÄƒ Ã®n rezervor?\r\n9. Pfuaaay, Ã®l calc pe cÃ¢inele Äƒla, sÄƒ ÅŸtiu bine cÄƒ Ã®l urmÄƒresc pe trei trotuare!\r\n10. Shit, ÅŸÄƒfu, credeam cÄƒ mirosu de beÅŸinÄƒ se filtreazÄƒ prin scaun! Scuze.','Deci top 10 chestii care nu se spune la scoala de soferi - partea II',0,'','publish','open','open','','deci-top-10-chestii-care-nu-se-spune-la-scoala-de-soferi-partea-ii','','','2007-12-13 11:51:56','2007-12-13 09:51:56','',0,'http://www.groparu.ro/?page_id=874',0,'post','',0),(875,2,'2007-12-13 11:53:11','2007-12-13 09:53:11','1. Cand te trece rapid si te instalezi in scaun, sa il simpti umed, cu picuri de pishu de la colegul anterior.\r\n2. Cand te trece rapid si te instalezi in scaun, sa il simpti umed SI FOARTE RECE.\r\n3. Cand faci pishu stand pe colac, putulica sa se indrepte in fatza, nu in jos, spre portzalan, si sa stropesti podeaua cu un susur primavaratic, daâ€™ galbui.\r\n4. Cand incepe sa tot iasa domnuâ€™ Maro, sa iti vina irezistibil pofta sa borasti in aceeasi secunda.\r\n5. Cand te scremi mai tare si fundu iti bolboroseste, sa auzi ca sefa incearca la usa baii unisex a firmei si iti aude oftaturile anale tocmai cand intreaba â€œOcupat?â€\r\n6. Cand pica caca, sa faca baldabac si sa sara trei stropi de apa fix in gauricea fundului, care este. Reci stropii.\r\n7. Cand dai sa te stergi, sa vezi ca nu mai ai hartie.\r\n8. Cand dai sa folosesti buzduganu ca sa cureti maroniul de pe portzalan, doi peri de plastic sa se arcuiasca si sa arunce maroniu in sus, preferabil nu pe fatza.\r\n9. Sa iesi din buda tinandu-ti mainile ca chirurgii, supt ochii uluiti ai sefei.\r\n10. Toate astea sa ti se intample intr-o singura zi.\r\n\r\nApropos, la mine-n firma buda nu e unisex.\r\n\r\nExperientza bonus: sa nu curga apa la buda in ziua aceea. Nici la chiuveta.','Deci 10 experientze najpa ce le poti patiii la buda firmei',0,'','publish','open','open','','deci-10-experientze-najpa-ce-le-poti-patiii-la-buda-firmei','','','2007-12-13 11:53:11','2007-12-13 09:53:11','',0,'http://www.groparu.ro/?page_id=875',0,'post','',0),(876,2,'2007-12-13 11:54:02','2007-12-13 09:54:02','<a href=\"http://www.kettlerdorothea.ro/2007/09/25/de-ce-urasc-tiganii.htm\" target=\"_blank\">Dorothy</a> scrie intr-o postare lunga de ce uraste ea, sau antipatizeaza cu natia <a href=\"http://warsongu.wordpress.com/\" target=\"_blank\">Warsongului</a>.\r\n\r\nLa ora actuala, e foarte sexy sa-i urasti pe conlocuitari, probabil vedeti si voi asta.\r\n\r\nDeci mai copii.\r\n\r\nIo - din pacate pt voi - is roman 100% (la Sibiu nu am prea avut casatorii mixte, asta sa stiti si voi!), mama e poplaceanca (Poplaca exista!) si tata e din Dragasani, de la vinu ala rosu la care Ã®i spune, Ã®n Sibiu, â€œsculÄƒuâ€. Deci ca sa fim in clar cu chestia asta, da? Ca-s mai â€œcuratâ€ genetic ca multi dintre voi (ghilimele intentionate).\r\n\r\nCa sibian (deci io fiind capital cultural european) mutat la Cluj (capital transilvan), sunt obligat sÄƒ ii urasc pe mitici (care ne ia toÅ£i banii), pe olteni (ca e puturoÅŸi), pe moldoveni (cÄƒ nu e gospodari), pe basarabeni (cÄƒ e beÅ£ivi), si pe Å£igani, care - clar, zice-s-ar - ni-s toti inferiori.\r\n\r\nCa roman is obligat sa ii urasc pe porcii de italieni, care uite ce ne fac, pe mÄƒgarii de rusi care ne-or furat tezauru, pe nemtii care mi-or aruncat tzara in comunism (BTW, unu mi-o loat si sora, s-o maritat cu ea! ÅŸi mi-o ÅŸi futut-o, cÄƒ d-aia are sor-mea copiluÅ£i demenÅ£iali, care samÄƒnÄƒ cu ea si cu el!), pe americani, ca ne-or lasat in comunism, pe bulgari ca ne bat la folbal, pe ukraineni ca ne-or loat Bucovina, ca sa nu mai zic de unguri, faÅ£Äƒ de care avem o datorie naÅ£ionalÄƒ de a-i urÃ®.\r\n\r\nCa european is fortat sa ii urasc iara pe americani, ca treâ€™ sa-i contrabalansam ca putere, pe irakieni, iranieni, sirieni, ca-s TOÅ¢I teroristi, pe chinezi si indieni, finca ne vor fura suprematia economica, si lucrurile nu se termina aici.\r\n\r\nVom descoperi viatza pe alte planete, is sigur. Va mai trebui sa urÃ¢m: martieni, venusieni, mercurieni, jupiterieni. Si va trebui sa ii omoram pe Plutoieni si sa le lom femeile.\r\n\r\nDar daca vom gasi viata in alte sisteme solare? Atunci - claro - va trebui sÄƒ le ardem casele Äƒlora din Alpha Centauri si sa violam nevestele celor din Andromeda si K-Pax, si pe copiii alora din Solaris sa ni-i facem sclavi, ca toata lumea stie ca is naspa (ei).\r\n\r\nDar daca-n puii mei gÄƒsim viaÅ£Äƒ ÅŸi Ã®n alte galaxii? Nush ce sa mai zic, ca io deja am obosit, daâ€™ sper ca ati prins ideia.\r\n\r\nDeci io numa atata va zic, ca io, decat sa ma mai cac pe mine sa scormonesc atata urÄƒ, mai bine o las dreq la budÄƒ, unde isi are locu, cÄƒ aÅŸa nu se mai poate, si trag si apa, ÅŸi prefer sÄƒ iubesc femele din orice rasÄƒ, naÅ£ie, coloare, orientare sexoalÄƒ, religie, Ã®nÄƒlÅ£ime samd, ÅŸi sÄƒ mÄƒ ÅŸi Ã®mbÄƒt cu toÅ£i masculii care Ã®s de aceeaÅŸi sorginte cu ele!\r\n\r\nSi bucurati-va ca sunteti liberi sa ganditi alfel decat mine. Si dupa ce va bucurati, mai explicati-mi de ce TOTI romanii, cand am fost la <a href=\"http://www.groparu.ro//?p=405\" target=\"_blank\">Tiganiada</a>, cand s-or gandit ca suntem tigani cu bani, erau in stare sa ne linga mochetele si ghiulurile de dragi ce le eram!!!!\r\n\r\nAr mai fi de zis, daâ€™ tre sa ma car, sa-mi asigur un loc in istorie.','Deci, despre tigani',0,'','publish','open','open','','deci-despre-tigani','','','2007-12-13 11:54:02','2007-12-13 09:54:02','',0,'http://www.groparu.ro/?page_id=876',0,'post','',0),(877,2,'2007-12-13 11:55:15','2007-12-13 09:55:15','Faptul ca <a href=\"http://ioniliescu.wordpress.com/\" target=\"_blank\">Bunicutza</a> are blog, si baga postari la greu, se stie deja.\r\n\r\nDaâ€™ io ma mai gandesc: daca tot blogareste, nu ar fi cool daca <a href=\"http://ioniliescu.wordpress.com/\" target=\"_blank\">Bunicutza</a> s-ar apuca sa bage filme de pe youtube pe blogul sau? Si poze de la petrecerile tovarasesti? <strong>Si AdSense</strong>? Si stiri preluate din Cancan despre Paris Hilton si Britney? Si stiri despre iPhone? Sau comentarii despre Steaua, poze cu Becali si tecstuâ€™ ala cu fetitza aia de 8 ani scuipata pe strada pentru care treâ€™ sa facem embargou la produse italiene, deci sa nu mai papam supa de taitei, ca aduc a spaghete? Si poze cu el si Emil Constantinescu, cu autograf cu dedicatie? Si oare se bucura cand primeste spamuri cu Viagra, Cialis, Tramadol, Valium, Soma, Xanax?\r\n\r\nSi oare nu ar fi cool daca l-ar pune pe Vladimir Putin sa ii faca reclama la blog? Si, una si mai tare: dupa Groparu, <a href=\"http://www.zoso.ro/\" target=\"_blank\">zoso</a>, <a href=\"http://www.andaa.ro/\" target=\"_blank\">andaa</a> si <a href=\"http://www.andressa.ro/\" target=\"_blank\">andressa</a> si <a href=\"http://www.innocente.ro/\" target=\"_blank\">innocente</a> si <a href=\"http://www.visurat.ro/\" target=\"_blank\">visurat</a> etc. punct ro (pe Crivatz sh Jeg ii respect prea tare ca sa ii includ in aceeasi enumÄƒraÅ£ie cu mineâ€¦ well, de fapt numa pe <a href=\"http://www.andreicrivat.ro/\" target=\"_blank\">Crivatz</a>!), nu ar fi super tare sa facem, noi, bloggerii, o cheta ca sa ii cumparam unuâ€™ din domeniile\r\n\r\n- www.Bunicutza.ro\r\n- www.MaiAnimalule.ro\r\n- www.MaiDraga.ro\r\n- www.3mandate.ro\r\n- www.Mineriadul.ro\r\n- www.internationalasocialista.ro\r\n- www.coios.ro\r\n- www.APRRPDC.ro (Asociatia de Prietenie Romania-Republica Populara Democrata Coreeana)\r\n- www.ISawLeninHeIsAlive.ro\r\n- www.FuckPerestroika.ro\r\n- www.SinergiaFaptelor.ro\r\n- www.SeceraSiCiocanul.ro\r\n- www.TryToUnderstandMyEnglish.com\r\n- www.TryNotToLaughAtMyEnglish.com\r\n- www.antiburghezie.ro\r\n- www.iliescusipoporul.ro- s.a.,\r\n\r\nâ€¦pe care sa se blogareasca in voie???','Despre Ion Iliescu si blogul sau',0,'','publish','open','open','','despre-ion-iliescu-si-blogul-sau','','','2007-12-13 11:55:15','2007-12-13 09:55:15','',0,'http://www.groparu.ro/?page_id=877',0,'post','',0),(878,2,'2007-12-13 11:56:29','2007-12-13 09:56:29','<p class=\"entry\">Buna seara, stimati terespectatori. Deci tin sa va anunt si pe aceasta cale ca io nu-s fan pizza de nici o culoare, finca nu-s sarmale, sloi de oaie, mamaliga in paturi, balmos sau bruschetele pe care le face <a href=\"http://www.andreicrivat.ro/\" target=\"_blank\">Crivatz</a>. Daâ€™ uneori mai manc sh pizzoaie, mai mult de fitze.\r\n\r\nAseaaaa. Si ma dusei sa pap pranzuâ€™ la Pizzeria Gente, pe Horea.\r\n\r\nSi urcam sus la etaj, si dupa ce ma pun la masa am geniala idee de a trage scaunul mai spre masÄƒ, ca atunci cÃ¢nd fac pe jos, sa nu murdÄƒresc podeaua cÃ¢nd pot murdÄƒri bunÄƒtate de blugi!\r\n\r\nBig mistake.\r\n\r\nFundul scaunului era rupt, ÅŸi am ridicat numa funduâ€™, nu si scaunul.\r\n\r\nDeÅŸtiuâ€™ meu, Ã®nvÄƒÅ£at de o Ã®ndelungatÄƒ experienÅ£Äƒ, cÃ¢nd o vÄƒzut locuâ€™ liber, s-o strecurat instinctiv, aÅŸa cum l-am Ã®nvÄƒÅ£at eu, Ã®n despicÄƒturÄƒ.\r\n\r\nCand m-am asezat din nou pe scaun, in urmatoarea fractiune de secunda, destiuâ€™ prostuâ€™ cÃ¢inele nostru era felia aia de ÅŸuncÄƒ din sanviÅŸele copiilor bogaÅ£i, Ã®ntre fundu scaunului ÅŸi rama lui. CÃ¢nd kilele mele s-or aÅŸezat voioase peste scaun, deÅŸtiu meu Å£ipÄƒ de durere ÅŸi ne Ã®njurÄƒ de mamÄƒ, pe mine (desi a mea de fapt e-o doamnÄƒ) ÅŸi pe pizzar ÅŸi - bine-nÅ£eles - pe Ion Iliescu, taxa de prima Ã®nmatriculare, ÅŸoferii najpa din Cluj, copilÄƒria mea traumatizantÄƒ, sistemul sanitar si cel educaÅ£ional - ambele Ã®n agonie, serialuâ€™ Dallas, stirile ProTV, stirile sportive ProTV, traficuâ€™ din Cluj, inghesuiala de pe RATUC, placa mea video care ingheatza, friguâ€™ de afara, caldura de az-vara, alti politicieni, sapunul lichid colorat numit sampon cu balsam, posibilitatile reduse de pensionare la varsta mea, BANCILE, BANCILE, BANCILE si - bine-nteles - dobanzile lor. A, si o mai injurat si faptuâ€™ ca nu eram in America, finca i-as fi dat in judecata si m-as fi umplut de verzi. Multi verzi.\r\n\r\nDaâ€™ dupa ce am stat un pic si m-am gandit, cu mintea mea de pe urma, ce mi-am zis: din moment ce eu mai am madulare care intra instinctiv prin despicaturi, si daca destiu ar fi fost mai incet la actiune decat putza, NU AR FI FOST ASTA CEA MAI DUREROASA DECALOTARE DE PENIS DIN ISTORIE?\r\n\r\nNu le-am zis nimica de scaunuâ€™ desfundulizat la Gentzi, ca sa o muÅŸte ÅŸi altuâ€™, sa muarÄƒ ÅŸi capra lui. SA MUARÄ‚!!!','La Pizzeria Gente',0,'','publish','open','open','','la-pizzeria-gente','','','2007-12-13 11:56:29','2007-12-13 09:56:29','',0,'http://www.groparu.ro/?page_id=878',0,'post','',0),(879,2,'2007-12-13 11:57:54','2007-12-13 09:57:54','<p class=\"entry\">Imi pare aproape sincer rau ca am o asemenea atitudine subversivÄƒ apropos de acest subiect ca o baÅŸicÄƒ spartÄƒ, puroindÄƒ.\r\n\r\nDar ca sa potolim orice urme de xenofobie intre popoare.\r\n\r\nCa sa inabusim serpele extremismului din faÅŸÄƒ, pana nu ii creste si coaie.\r\n\r\nCa sa eliminam din societatea noastra europeana orice sentiment de urÄƒ, intoleranÅ£Äƒ, idee preconceputÄƒ.\r\n\r\nPentru a restabili calmul ÅŸi Ã®nÅ£elegerea Ã®ntre o Å£arÄƒ ca o cizmÄƒ ÅŸi altÄƒ Å£arÄƒ ca un buchet de flori, cu tulpinele in Marea NeagrÄƒ.\r\n\r\nEu, Groparele.\r\n\r\nÃŽn deplinatatea facultÄƒÅ£ilor mele mintale, blogice, trupeÅŸti, bÄƒutureÅŸti ÅŸi de altÄƒ naturÄƒ (orice altÄƒ naturÄƒ, numai naturÄƒ moartÄƒ nu).\r\n\r\nDeclar.\r\n\r\nPe propria mea rÄƒspundere.\r\n\r\nCÄƒ pentru a Ã®ncerca cumva sÄƒ repar oalele sparte de romÃ¢ni.\r\n\r\nMai ales de Mailat Äƒsta, care e ÅŸi sibian.\r\n\r\nIo.\r\n\r\nAm hotÄƒrÃ¢t sÄƒ mÄƒ las violat de 4.000 italiance Ã®ntre 18 ÅŸi 30 de aniÅŸori, Ã®ntre 1,65 ÅŸi 1,85 m Ã®nÄƒlÅ£ime, cu dimensiuni Ã®ntre 90-60-90 ÅŸi 91-54-120, aproape indiferent de ce alte calitÄƒÅ£i mai au, pÃ¢nÄƒ cÃ¢nd opinia publicÄƒ italianÄƒ va trece la sentimente mai bune vizavi de naÅ£ia mea. Pot prelua cate 2-3 pe sÄƒptÄƒmÃ¢nÄƒ, de preferinÅ£Äƒ miercurea, sÃ¢mbÄƒta ÅŸi lunea dimineaÅ£a, mai ales dacÄƒ afarÄƒ plouÄƒ.\r\n\r\nDacÄƒ Å£ara mea are nevoie de mine, sunt gata sÄƒ mÄƒ sacrific.\r\n\r\nÃŽncheiat azi, 05.11.2007, cu acordul mai mult decÃ¢t deplin al cel puÅ£in uneia dintre pÄƒrÅ£i.','Deci despre italiani si romani',0,'','publish','open','open','','deci-despre-italiani-si-romani','','','2007-12-13 11:57:54','2007-12-13 09:57:54','',0,'http://www.groparu.ro/?page_id=879',0,'post','',0),(880,2,'2007-12-13 12:00:29','2007-12-13 10:00:29','<p class=\"entry\"><a href=\"http://www.mediafax.ro/blog/general/despre-globurile-oculare-ale-fotbalistului-traian-basescu/\" target=\"_blank\">Aici</a> scrie cum ca ochii lui Basescu e miopi, si ca cum de e miop, ca o primit o minge de nush ce in capatzana, si i s-o dereglat telemetruâ€™.\r\n\r\nCa Baseâ€™ e un pic sacÃ¢z ÅŸi ÅŸaÅŸliu la ochi, ca ochiul stÃ¢ng se uitÄƒ dupÄƒ ochiul drept, asta ÅŸtie o Å£ara Ã®ntreagÄƒ. Dar eu am auzit alta varianta PE BUNE, cum cÄƒ de ce e domnuâ€™ presedinte Baseâ€™ asa cum e, strÃ¢mb la vedere, adeca.\r\n\r\n<strong>Deci ce a patit privirea lui Basescu?</strong>\r\n\r\nDeci: eram in anu 3 de facultÄƒ. In facultÄƒ, eram best friends cu adminuâ€™ de reÅ£ea, un om absolut demenÅ£ial de fain, cum numa-n Cluj am vazut asemenea oameni, om cu care nu am cum sÄƒ semÄƒn vreodata fincÄƒ ioz cioban din Sibiu.\r\n\r\nÅži Ã®ntr-o zi, adminuâ€™ de retea ma scoate la o berula cu un prieten. Prieten despre care aveam sa aflu, mai incolo, ca era marinal, sau capetenie de marineri, lup de mare, shaf de haita. Cum ioz fascinat de povesti gen toate panzele sus (sau toate panzele jos, mai ales cele care stau pe trup de dama), claro ca am fost orgasmat de ideea de a ma duce cu iei, desi urla foamea in mine de la nemancare si mai urla si lipsa in portofel, si era numa 11 dimineatza, si pe vremea aia inca nu imi incepeam ziua cu o dusca sanatoasa de bere stinsa cu votca.\r\n\r\nSi merem la bere, si ne apucam de povestit despre vapuare, despre cum is rusii pe mare, ca is in stare sa-si demonteze piesa de la propriul motor daca te vad ca ai avarie, etc, etc, cum era treaba cu contrabanda pe vremea regretatului, bordelele de prin porturi, bricul nava-scoala Mircea, care e diferenta dintre tambuchi si cambuza, femeie si meduza, ca ambele-s lipicioase, asa, babord si bieleta de directie, carnetuâ€™ de sofer de petrolier, d-astea. Nenea marineruâ€™ (care intamplator era si derector la regia aia autonoma sergiu nicolaescu a apei din Cluj, Rajac, daâ€™ vroia sa renunte la directorat, ca primise o oferta pe care n-o putea refuza nu de la naÅŸuâ€™ lu Puzo, ci de la o firma norvegiana de pescuit) ii lÄƒsa ciubuc la tanti chelnerita cate 2000 lei vechi la fiecare halba, si bea bere cu o bordura de sare presarata pe marginea halbei.\r\n\r\nSi la un moment dat, cand io deplangeam soarta marinei noastre, care din vreo 180 de vapoare mai avea vreo 16 finca o vandut-o Basescu (pe vremea aia, ministru al transportului), nenea numaâ€™ ce trage ganditor in tigare, si zice:\r\n\r\n- Io am fost coleg cu Basescu.\r\n- Serios? Zic io. Super tare. Si cum e Basescu?\r\n- E OK, zice, numaâ€™ ca i-am facut una.\r\n- Adica? zic io.\r\n- Pai, zice, cand eram in Academia aia navala, faceam tzambale.\r\n\r\nPentru ne-incorporabili: cand un melitar doarme in patu ala de camin ostasesc si il rastorni in somn (ca se rastoarna foarte usor), aia se kiama tzambal.\r\n\r\n- Si, zice, odata o degenerat, ca i-am facut luâ€™ asta (recte, Basescu) un tzambal, si o inceput sa chiÅ£Äƒie. Asa ca l-am vindecat cu o patura pusa peste el, si vreo juma de duzina de bocanci trantiti peste patura, vreo 5 minute. A doua zi avea ochiul stramb. Dar nu ne-o pÃ¢rÃ¢t la comandament, ca o buleam. Bun baiat, zice el, lupuâ€™ de mare.\r\n\r\nNi ce privire are domâ€™ presedintele, loata derect de la iel dupe sait:\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/10/basescu.JPG\" title=\"basescu.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/10/basescu.JPG\" alt=\"basescu.JPG\" /></a>\r\n\r\nAmu nush cat e adevar si cat minciuna, io am auzit astea amu-s ceva ani, daâ€™ am zis ca amu mi s-o confirmat senzatia ca Ã®mpÄƒrat la orbi e Äƒlâ€™ de vede doar c-un ochi!','Despe privirea lui Basescu - a true story',0,'','publish','open','open','','despe-privirea-lui-basescu-a-true-story','','','2007-12-13 12:00:29','2007-12-13 10:00:29','',0,'http://www.groparu.ro/?page_id=880',0,'post','',0),(881,2,'2007-12-13 12:01:07','2007-12-13 10:01:07','<p class=\"entry\">Era odata o fata blonda care nu-si dorea altceva de la viatza decat sa cunoasca un baiat tanar, care sa aiba un BMW si care sa-i suceasca mintile, sa o miste asa cum nici un mascul nu a mai reusit vreodata.\r\n\r\nIntr-o buna zi, un BMW a luat-o pe capota, a aruncat-o intr-un tufis, si s-a facut nevazut. Fata a ramas teafara, dar perplexa - la fel de perplex cum ramanem fiecare dintre noi cand ne vedem visele implinindu-se supt ochii nostri nedumeriti si umezi.\r\n\r\n<strong>Update:</strong>\r\n\r\nEra odata o fata care isi dorea un ficior cu casa (sau macar apartament) in centrul Clujului. Intr-o buna zi, l-a descoperit: era chiar ficiorul de deasupra, ea insasi locuind in centrul Clujului. Dar in alta zi, un cutremur a venit: apartamentul baiatului s-a prabusit peste apartamentul fetei, iar fortelor de descarcerare le-au trebuit 2 zile ca sa o scoata de supt daramaturi, teafara, dar puternic deshidratata.\r\n\r\nEra odata o fata care isi dorea sa aiba un prieten cu multi, multi-multi bani. Intr-o buna zi, l-a intalnit: dar baiatul avea asa de multi-multi-multi bani, incat si-a cumparat un bilet de avion numai dus in Noua Zeelanda, si nu s-a mai reintors, deoarece s-a prins ca in Romania nu mai are rost sa ramai.\r\n\r\nEra odata o fata care isi dorea sa aiba un prieten muschiulos, asa, puternic si facut, cu abdomen bine striat, pÄƒtrÄƒÅ£elos, alea-alea. Dar la prima lor intalnire, baiatului i s-a facut atata drag de ea, incat a strans-o in brate cu putere si, datorita inclestarii, fata a si scapat fara sa vrea un pÃ¢rÅ£ umed si foarte puturos, deoarece cu o noapte inainte bause excesiv cu niste prietene 2 sticle de tequila originala, facuta in Baia Mare. A fost ultima ei intalnire cu acel baiat musculos, puternic si body-buildat.\r\n\r\nA fost odata o fata care isi dorea sa aiba un prieten care sa stie sa gateasca, si ea sa nu fie nevoita sa isi piarda timpul in bucatarie, imbacsindu-si hainele si parul cu miros de prajeala; intr-o buna zi, ea a intalnit un astfel de baiat, dar la primul chef, acesta s-a pierdut asa de tare in schimbat retete cu o alta fata care era innebunita dupa gatit, incat au plecat amandoi de la chef, si nu l-a mai vazut NICIODATA.\r\n\r\nA fost odata o fata care isi dorea foarte mult sa intalneasca un baiat sensibil, tandru, care sa cante la chitara si la harpa si care sa-i recite ore in sir, fara sa se repete, din Pablo Neruda, Charles dâ€™Orleans, Daniel Scavinschi sau chiar Seamus Heaney; intr-o buna zi l-a intalnit, dar spre surprinderea ei, a aflat ca acel baiat era putintel gay. Gay pasiv.\r\n\r\nA fost odata o fata care isi dorea foarte mult sa aiba parte de un baiat curatel, ordonat si pedant, care sa aspire, sa stearga praful, sa nu si lase chilotii si ciorapii pe scaun si care sa si bata covoarele cel putin o data pe semestru; dar in clipa in care si-a gasit un astfel de prieten, acesta i-a si dat papucii, deoarece o astfel de fata nu poate fi decat un jeg de fata, si el nu suporta jegul.\r\n\r\nMai trebuie sa ma mai gandesc la varianta cu pwla mare, dar nu gasesc apsolut nici un cusur unei asemenea variante.\r\n\r\n<em>The End</em>','Era odata ca niciodata',0,'','publish','open','open','','era-odata-ca-niciodata','','','2007-12-13 12:01:07','2007-12-13 10:01:07','',0,'http://www.groparu.ro/?page_id=881',0,'post','',1),(882,2,'2007-12-13 12:05:43','2007-12-13 10:05:43','<p class=\"entry\">Deci aceasta postare nu reprezinta un linsaj mediatic, deoarece DTR nu mai poate fi linsat: cariera lui politica s-o incheiat, din neumila mea parere, la ceasul la care guvernarea CDR o dat coltzuâ€™ (bueeeey, io v-am votat, porcilor!)\r\n\r\nDaca justitia il gaseste nevinovat, mi-e teama ca va stÃ¢rni un trend periculos: toti parintii isi vor numi copiii lor dupa patternul de asociere-de-nume-de-vechi-dusmani, cum e cazul cu Decebal-Traian, ca fiind un nume mare aducator de noroc in cazul unei anchete DNA. Astfel, am putea asista la urmatoarele combinatii:\r\n\r\n- Cezar Vergingetorix RemeÅŸ;\r\n- Sula Jugurtha RemeÅŸ;\r\n- Hernando-Cortes Montezuma RemeÅŸ;\r\n- Menumorut-Regele-Bela RemeÅŸ;\r\n- Napoleon Ducele-de-Wellington RemeÅŸ;\r\n- Baiazid Mircea-cel-Batran RemeÅŸ;\r\n- Athos-Porthos-Aramis-dâ€™Artagnan Mazarin RemeÅŸ;\r\n- Hitler Stalin RemeÅŸ;\r\n- Montgomery Rommel RemeÅŸ;\r\n- Hrusciov Kennedy RemeÅŸ;\r\n- Logan Mahindra RemeÅŸ;\r\n- Basescu Tariceanu RemeÅŸ;\r\n- Saddam W. TufiÅŸ RemeÅŸ;\r\n\r\n- SPERMATOZOID-CAMPION SPERMATOZOID-NECAMPION REMEÅž;\r\n\r\ns.a.m.d.\r\n\r\nBrrrrrrr!!!!!','Despre Decebal Traian Remes (DTR)',0,'','publish','open','open','','despre-decebal-traian-remes-dtr','','','2007-12-13 12:05:43','2007-12-13 10:05:43','',0,'http://www.groparu.ro/?page_id=882',0,'post','',0),(883,2,'2007-12-13 12:07:34','2007-12-13 10:07:34','<p class=\"entry\">Care este cea mai mare companie americana?\r\n\r\nIndicii: are cea mai mare cifra de afaceri; cel mai mare numar de angajati; cel mai mare numar de sedii; are afaceri cu petrol - rafinarii, tancuri petroliere, benzinarii, puturi de extractie, zacaminte de Å£iÅ£ei etc, dar se mai ocupa si cu altele; este asa de puternica, ca e nevoie de armata americana sa o apere; compania detine mii de kilometri patrati de pamant si sute de mii de cladiri.\r\n\r\nEi? Ce ziceti? Chevron, Exxon, Coca-Cola, Microsoftâ€¦? General Motors, Boeing, Bell, Halliburton, Bechtel, Ford, Wal-Martâ€¦? Lockheed Martin? Google? Apple?\r\n\r\nNu, mah. Nici gand.\r\n\r\nCea mai mare companie americana este deocamdata statul Irak.','Cea mai mare companie americana',0,'','publish','open','open','','cea-mai-mare-companie-americana','','','2007-12-13 12:07:34','2007-12-13 10:07:34','',0,'http://www.groparu.ro/?page_id=883',0,'post','',0),(884,2,'2007-12-13 12:08:28','2007-12-13 10:08:28','<p class=\"entry\">- Daca ai avut o zi teribil de proasta, cu mirosuri in autobuz;\r\n- Daca seful tau tocmai te-a transformat intr-un vibrator pe care tot tie ti l-o infipt supt coada;\r\n- Daca afli ca prekina ta umbla cu cel mai bun prekin al tau;\r\n- Daca afli ca prekina ta s-o mozolit cu un arab, si toti prekinii stiau, daâ€™ nu ti-or zis nimic;\r\n- Daca vezi ca blogul tau primeste numai comentarii nasoale sau nici un comentariu deloc;\r\n- Daca ai intarziat la un interviu important si ai aflat ca nu mai primesti jobul;\r\n- Daca castigi cat un profesor;\r\n- Daca esti racit si treâ€™ sa dai o avere pe medicamente, avere pe care n-o ai;\r\n- Daca te simti mai intellectually-challenged ca Mitica Dragomir, Becali sau un crampon;\r\n- Daca ai hemoroizi;\r\n\r\nETC,\r\n\r\n1. Cauti o haita de maidanezi; nu ai cum sa nu gasesti.\r\n2. Din haita, selectezi o catea.\r\n3. Catelei ii pui lesa.\r\n4. Legi catelusa de un pom.\r\n5. Te uiti la catelusa si intrebi:\r\n\r\n- WHOâ€™S THE BITCH <strong>NOW</strong>????\r\n\r\n6. Dezlegi lesa. Te simti mai bine. Nu tu esti.\r\n\r\nOK, asta nu e cea mai buna postare a mea. De acord. Daâ€™ am incercat si io. Azi am mancat slana cu ceapa, semn ca se apropie iarna.','Idee de cum sa te simti mai bine',0,'','publish','open','open','','idee-de-cum-sa-te-simti-mai-bine','','','2007-12-13 12:08:28','2007-12-13 10:08:28','',0,'http://www.groparu.ro/?page_id=884',0,'post','',0),(885,2,'2007-12-13 12:09:34','2007-12-13 10:09:34','Deci: se pare ca cea mai veche urma de Homo Sapiens s-o descoperit intr-o pestera din Romania, tzara mea cu munti sh vai. Este vorba de o mandibula, botezata IonicÄƒ.\r\n\r\n<strong>Concluzia 1</strong>: Stramosii nostri mai mult mancau sh beau decat gandeau (daca gandeau mai mult, se descoperea o calota craniana!).\r\n\r\nDeci: cum zicea PÃ¢rtzoagÄƒ, toate boboarele desenau la greu pe pesteri rupestre vanatori complicate, violuri de caprioare si bizoni, tot feluâ€™. Noi: sculptam hora de la Frumusica. Si Ganditorul (io-i zic Constipatul) de la Hamangia, cu tot cu fomeia lui grasa sh sexy.\r\n\r\n<strong>Concluzia 2</strong>: Stramosii nostri mai degraba dantuiau sh beau decat sa munceasca, vÃ¢neze sau violeze cÄƒprioare.\r\n\r\n<strong>Concluzia 3</strong>: Io cred ca Ganditorul (io-i zic Constipatul) de la Hamangia o fost la chef cu fomeile de la Frumusica, sh sculptorul l-o imortalizat Ã®n dimineaÅ£a de dupe, cÃ¢nd era mahmur.\r\n\r\nDeci: toata lumea stie fragmentul ala din cartea de istorie despre neamul tracilor, care e cel mai numeros din lume dupa cel al inzilor, pule maturi, cei mai viteji si mai drepti dintre traci fiind getii (cum zicea Iliescu: ZÄƒ dacs come from zÄƒ tracs!) etc. Ce NU scria in cartea de istoria era continuarea (citez din memoria mea de alcoolic: <em>la ei, trÃ¢ndÄƒveala e la mare preÅ£; iar cei care fac munca cÃ¢mpului sunt constant subiect de bajocurÄƒ. Ling vin la greu, si ca sa nu munceasca isi vÃ¢nd copiii ca sclavi.</em>\r\n\r\n<strong>Concluzia 4: </strong>Io cred ca fragmentuâ€™ de mai sus se refera la familia mea.\r\n\r\nDeci: se zice ca cel mai vechi mesaj scris din istori omenirii sunt neshte tablitze descoperite la Tartaria, in judetul albanezilor. Au 7000 de ani vechime, sau 9000, sau ceva de genuâ€™. Nimeni pana acuma nu o reusit sa descifreze ce inseamna - probabil pentru ca sunt pline de greseli de ortografie sh nu contin suficient porn.\r\n\r\n<strong>Concluza 5</strong>: Suntem sh redusi dpdv intelectoal, si insuficient de predispusi la imperechere (a se citi impotenti).','Cateva consideratiuni asupra istoriei neamului romÃ¢nesc',0,'','publish','open','open','','cateva-consideratiuni-asupra-istoriei-neamului-romanesc','','','2007-12-13 12:09:34','2007-12-13 10:09:34','',0,'http://www.groparu.ro/?page_id=885',0,'post','',0),(886,2,'2007-12-13 12:09:59','2007-12-13 10:09:59','<p class=\"entry\">Dap.\r\n\r\nDupa evenimentul in care am lovit cu putere cada de baie de capuâ€™ meu tzestos, azi am mai facut una. Destul de groasa.\r\n\r\nDeci: pedalam si eu voios catre serviciu, dis-de-dimineatza, fericit ca viatza este, totusi, mai buna ca in Republica Moldova. Aveam sa ma caiesc amarnic cateva secunde mai tarziu. Mai ales ca mancasem mujdei la micu-dejun.\r\n\r\nPedaland, trec pe verde, si ajung la o coloana de masini stationara. Fac un tur cu ochii imprejur sa vaz unde pot sa-mi infig bitzicÄƒluâ€™, sa nu stau dupÄƒ prostii aia care si-or cumparat masini - si vad ca n-am unde. Mai pedalez de 5 ori, ma Ã®ncadrez in spatele unei Octavii, si cand vÄƒd ca masina stationa, nu mergea, dau sa pun frana.\r\n\r\nLa o roata numai.\r\n\r\nFrana nu prinde, finca aveam vitezÄƒ.\r\n\r\nIn derapaj, izbesc cu putere biÅ£a cu ghidonuâ€™ ei, de fapt, de porbagajuâ€™ Octaviei.\r\n\r\nBUUUUUM!!!!! O facut ca la Nagasaki.\r\n\r\nNenea pune avariile, iese afara:\r\n\r\n- Ce pula mea nu te uiti???\r\n- Ce pula mea sa fac daca nu mi-o prins frana??? zic io, mirosind puternic a usturoi.\r\n\r\nSi ma bufneste rasuâ€™. Totusi, ma pusesem in garda, sa nu ii vina la ala kef sa isi rupa pumnii in dintii mei, la care chiar tin, finca mi-s dragi.\r\n\r\n- Esti OK? Ai patit ceva? ma intreaba.\r\n- Is OK, tu esti OK?  Nu te doare nimic, nu? intreb, obraznic, mirosind puternic a usturoi. Nici macar nu mustaceste.\r\n- De ce nu ai grija cum mergi?\r\n- E primuâ€™ incident pe care-l am cu bitza, in puii mei! Pana amu nici macar un claxon nu am primit. Ai CASCO? zic io, mirosind puternic a usturoi.\r\n- Nu, zice el, am decÃ¢t deloc.\r\n- Ce coincidentza! zic io. Nici eu nu am pe bitza, zic io, mirosind puternic a usturoi.\r\n- Hai sa vedem ce s-o stricat, zice el.\r\n\r\nSi ne uitam.\r\n\r\nUn fleac.\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/10/dsc00129.JPG\" title=\"dsc00129.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/10/dsc00129.thumbnail.JPG\" alt=\"dsc00129.JPG\" /></a>\r\n\r\n(Cand am facut poza la accident, omuâ€™ o vrut sa intre si el in poza, cu un zambet pe fatza, ca de vanator langa ursul ucis; l-am potolit rapid).\r\n\r\n- Da-mi, zice, telefonuâ€™ tau. Si buletinuâ€™.\r\n- Haha, ma ia pe mine un ras nervos, din pula! Da-mi tu numaruâ€™ sa iti dau bip, daâ€™ buletinuâ€™ n-am de unde sa ti-l dau, e la Politie, l-am dat sa imi fac adresa pe Cluj, zic io, mirosind puternic a usturoi.\r\n- Ai un act, ceva? zice el.\r\n- Am, zic io, mirosind puternic a usturoi, am un <strong>bon de masa</strong> scris! si scot bonuâ€™ de masa, si asta isi noteaza, constiincios, numele si prenumele (Groparu Nemernic, adica), firma la care lucrez, ii explic cum sa ajunga la sediu, daca va fi nevoie, si dam noroc. Ramane sa ma sune la 11:30.\r\n\r\nMa suna: hai sa ne vedem la Politie! Ma duc inarmat cu prekinu meu <a href=\"http://www.andreicrivat.ro/\" target=\"_blank\">Crivatz, Andrei Crivatz</a>. Politaiuâ€™ se uita la mine luuuung: zice â€œTu ai accidentat mortal o Skoda Octavia? Cu un bitziclu?â€ â€œDa!â€, zbier io, spashit. Langa noi mai era lume, care o belit ochii, si unii or inceput chiar sa zambeasca, desi aveau capuâ€™ bandajat.\r\n\r\n- Te doare ceva? Te-ai accidentat rau? zice Garcea.\r\n- Nu, mah, zic, stai flexat. Pe sofer nu-l intrebati? zic io, mirosind puternic a usturoi.\r\n\r\nNush cum, daâ€™ nimeni nu gusta bancuâ€™ asta.\r\n\r\n- Meretz la celalalt sediu, sa va faca constatarea.\r\n\r\nLa celalalt sediu, iara: la declaratie, am lasat loc liber la sectiunea cu â€œautoturism implicat in accidentâ€, si scriu: Bicicleta proprietate personala. Nu uit sa mentionez, la descrierea accientului, ca soferul masinii nu a patit nimic, e navatamat.\r\n\r\nAsa.\r\n\r\nLa Politie te mai pune sa faci un desen in care sa desenezi harta accidentului. Am desenat o masina cu o biciclÄƒ mai mare ca masina infipta in ea, sh de pe bicicleta zambea, mare, insusi Groparu. M-am gandit daca sa imi fac si barba si palarie de tigan, daâ€™ m-am oprit la timp.\r\nSoferu - un morosan super de treaba - ii zice la politziot ca n-are rost sa imi dea amenda, ca fac puncte aiurea, si raman si fara permis de conducere de bicicleta. Asa ca scap fara amenda. Mersi, mah!\r\n\r\nPlecam la Service autorizat sa isi refaca omuâ€™ masina.\r\n\r\nDe aici, postarea asta incepe sa isi piarda hazuâ€™. Reparatia costa 13 milioane. Si dureaza o saptamana. Plus ca numa peste 2 saptamani au loc la servis sa ii iese la nenea masina. Plus ca daca ii tine masina in servis o saptamana intreaga, as face bine sa ii si inkiriez o masina de la un rent-a-car. Si costa atata finca trebe scos porbagajuâ€™, bara de protectie, futute de-amiaza, lingusite, masate, reconditionate, revopsite, dracu-lacu.\r\n\r\nCercetarile continua.\r\n\r\nPodcastul, transmis laiv pe <a href=\"http://www.radiotransilvania.eu/\" target=\"_blank\">Radio Transilvania</a>, este <a href=\"http://www.trilulilu.ro/Groparu/9dfb0fddc346fd\" target=\"_blank\">acilea</a>. Icnorati balbaielile mele.\r\n\r\nPS: Asta e nume pentru mine si Doamne-Doamne, deci nu cititi: Draga Doamne-Doamne, ieri m-o sunat mama sa imi zica ca le trebe alea 4000 lei pe care mi i-o imprumutat in primavara, ca isi izoleaza blocuâ€™; am un card de credit de 6000 lei gol-golutz; am si vreo 40.000 euroi datorii la banci, cu rate mai mari ca un salariu mediu pe economie, in care intra si credituâ€™ loat ca sa-mi iau masina, masina pe care nu am loat-o finca nu am carnet inca, carnet pe care nu l-am loat inca finca nu am inceput scoala de soferi, scoala de soferi pe care nu am cum s-o fac, finca inca nu am buletin! plus ca am amu pe cap si cheltuielile legate de accidentuâ€™ asta. Asa ca Doamne, daca vroiai sa faci pe cineva castigator la Loterie, fa-ma pe mine, acum! Daâ€™ sa nu trebuiasca sa imi cumpar bilet, ca io nu cred in chestii din estea. Si Doamne multzam pentru soferuâ€™ masinii, ca daca eram in locu lui l-as fi omorat pe Groparu de cat de bou poate sa fie. Oare am intrat in anu mortii lui Iorgovan?','Groparu a facut accident de bicicleta. Soferul a scapat nevatamat',0,'','publish','open','open','','groparu-a-facut-accident-de-bicicleta-soferul-a-scapat-nevatamat','','','2007-12-13 12:09:59','2007-12-13 10:09:59','',0,'http://www.groparu.ro/?page_id=886',0,'post','',0),(887,2,'2007-12-13 12:11:15','2007-12-13 10:11:15','<p class=\"entry\">GÃ¢ndu 1: succesul unei casatorii perfecte e sa ai o nunta super najpa - ca sa te faca sa exclami: I ainâ€™t never ever gonna do this shit again!\r\n\r\nGÃ¢ndu 2: nimeni nu ar trebui sa isi doreasca sa aiba o putulica super mare, finca vei depune mult mai mult efort ca sa o trezesti!\r\n\r\nGÃ¢ndu 3: E super Ok ca lumea sa te puna pe un soclu, sa depuna coroane de flori la picioarele tale sh sa planga din cauza de cat de meseriash esti tu; daâ€™ trebe sa ai mare grija la porumbei, ca astia se pot caca lejer pe tine.','Ganduri de (aproape) weekend',0,'','publish','open','open','','ganduri-de-aproape-weekend','','','2007-12-13 12:11:15','2007-12-13 10:11:15','',0,'http://www.groparu.ro/?page_id=887',0,'post','',0),(888,1,'2007-12-14 10:08:10','2007-12-14 08:08:10','Bun.\r\n\r\nDeci asar\' am avut kefu de Craciun al cooperativei, si piticu ala care sta la tine-n cap si da cu ciocanu in stanga si-n dreapta exista, finca il simpt monstruos amu. Si as bea neshte lapte de zebra, stie careva vreo laptareasa de acest gen?\r\n\r\nDeci ultima patzanie apsoluta: ieri iau masa cu o gashca de turci. Si ma intreaba unu despre mitul cu Dracula.\r\n\r\nIo, in vremile mele bune, am fost ghid turistic nepracticant, si m-am dat in vanturi dupa mitu asta. Asa de mult, ca mi-am si picat un master pe Dracula, de Bram Stoker. Futa-l in gura de prof nemernic, ca pe nedrept m-o picat, jur.\r\n\r\nAsa. Si m-apuc sa ii zic la turcalete despre Dracula, cum o fost el imprizonat la turcaletzi, si ca aia l-or abuzat, si cand o revenit ca domnitor, o fo\' nevoit sa duca rzaboi (ÅŸtiu cÄƒ se scrie <em>rÄƒzboi</em>, da Ã®ncÄƒ Ã®s bat d-asearÄƒ, ÅŸi mi-i lene sa corectesc) de gherila cu turcii, care erau <em>mai numeroÅŸi</em>. DupÄƒ engleza pe care o ÅŸtiu io, la <em>mai numeroÅŸi</em> se zice <em>more numerous</em>, deci un fel de superlativ. La care turcaletele se bagÄƒ ca musca beÅ£ivÄƒ Ã®n Å£uicÄƒ:\r\n\r\n- Not only were they more numerous, but they were smarter, too!\r\n- Haha, zic io, <strong>back then</strong> yes, they used to be!\r\n\r\nMuie la turci. Glorie spontaneitÄƒÅ£ii mele care m-o fÄƒcut sÄƒ fiu singuru care o rÃ¢s la masa aia de turcaleÅ£i. Glorie!','Deci, asadar',0,'','publish','open','open','','deci-asadar','','','2007-12-14 10:22:29','2007-12-14 08:22:29','',0,'http://www.groparu.ro/?p=888',0,'post','',7),(889,1,'2007-12-15 01:13:47','2007-12-14 23:13:47','Deci toti anii astia io am invatzat pederost ca:\r\n\r\n- prekinii poa sa mai si moara definitiv si dureros; asta-n cazu in care nu iti baga un deshti in cur, destul de sanatos si tot dureros;\r\n- poeziile proaste Ã®s ÅŸi sincere (Oscar Wilde);\r\n- sa te lasi de fumat e mai greu decat se anticipase;\r\n- uneori si parintii ti se intorc impotriva, si nu isi vor cere scuze niciodata;\r\n- daca prinzi oleaca la Ã®mpÄƒrÅ£it cascaval, numarul de prieteni se dubleaza;\r\n- dacÄƒ un ÅŸef nu te Ã®nghite din purÄƒ ne-atracÅ£ie fizicÄƒ, nu va ezita sÄƒ te futÄƒ cu turnu Eiffel;\r\n- nu incerca niciodata, never ever, sa le intelegi pe femei. Io, unu, renunt public - mai degraba ma apuc de fizica nucleara si de matematici cuantice.\r\n\r\nCrecÄƒ am mai Ã®nvÄƒÅ£at ÅŸi alte chestii, gen cum sÄƒ faci un blog <em>de niÅŸÄƒ</em>, cum sÄƒ te piÅŸi pe colac ÅŸi sÄƒ dai vina pe vecinu, ÅŸi cum sÄƒ dormi la serviciu ÅŸi toatÄƒ lumea sÄƒ creadÄƒ ca tu de fapt studiezi asiduu ultimul <em>press release</em> de la vodafon. Da\' si numa daca iau in consideratie lista aia de mai sus, si deja am senzatia ca tocmai am patruns esenta vietii, ca sÄƒ nu zic penetrat, de-a dreptu\'!\r\n\r\nAl dvs. - tot Groparu, acelasi suferind de ejaculare tardivÄƒ.','Deci io, si ce-am invatzat toti anii astia',0,'','publish','open','open','','deci-io-si-ce-am-invatzat-toti-anii-astia','','','2007-12-15 01:38:40','2007-12-14 23:38:40','',0,'http://www.groparu.ro/?p=889',0,'post','',12),(890,1,'2007-12-15 17:30:48','2007-12-15 15:30:48','Deci mi-am loat calc, mai demult, cand stateam in camin. Loat pe componente, bine-nteles, una de aici, una de dincolo, cum se nimerea!\r\n\r\nSi la un moment dat incepe sa mi se reseteze. Statea aprins 10 minute - pac, se reseta. Incepeam un Counter - pac, se reseta. MÄƒ, zic, ce e, ce sÄƒ fie!\r\n\r\nÃŽl duc acolo de unde mi-am loat sursa, cÄƒ aÅŸa or zis doftorii de calculatoare din cÄƒmin, cu care ieream prekin. Acolo - lalala, cÄƒ lasaÅ£i-l pÃ¢nÄƒ sÄƒptÄƒmÃ¢na viitoare, cÄƒ aÅŸa era pe vremea aia, te cam miroseau cÄƒ eÅŸti student sireac ÅŸi li se cam piÅŸca de tine. Åži fincÄƒ iereai student sireac ÅŸi nu aveai credit pe prepay sa suni la Protectia Consumatorului, asta e! ÃŽl laÅŸi ÅŸi aÅŸtepÅ£i.\r\n\r\nÅži cÃ¢nd se face sÄƒptÄƒmÃ¢na viitoare, mÄƒ duc la iei, ÅŸi zice aia de la birou: vai, domnu Groparu, zice, trebe musai sÄƒ Ã®mi daÅ£i parola de logare Ã®n sistem, cÄƒ numa aÅŸa Ã®l putem repara! Tu doamnÄƒ, zic io (m-am crizat un pic), deci ce vÄƒ trebe parola? ÃŽi un bug de hard, nu de soft, deci nu aveÅ£i dvs treaba cu ce programe am io instalate. CÄƒ nu, cÄƒ dacÄƒ Windows nu e corect configurat, poate da erori, inclusiv de resetare. Deci vÄƒ rog sÄƒ imi spuneÅ£i parola.\r\n\r\nÅži io Ã®ncep sÄƒ rÃ¢d. Åži rÃ¢d, ÅŸi-mi clÄƒnÅ£Äƒne dinÅ£ii de la rÃ¢s, ÅŸi Ã®ncerc sÄƒ-mi acopÄƒr dantura sÄƒ nu mi se vadÄƒ amigdalele mele, pe care le-am ÅŸi scos, de alfel, da cÃ¢nd mi le-am scos nu mi le-o dat sÄƒ mÄƒ uit la ele! Åži nu am primit nici Ã®ngheÅ£atÄƒ dupÄƒ operaÅ£ie!\r\n\r\nÅži-n magazinu de calculatoare toata lumea se chiorÄƒÅŸte la mine cÄƒ de ce rÃ¢d io ca cretinu cand mi se cere parola, ÅŸi vÃ¢nzÄƒtoarea nu Ã®nÅ£elege, ÅŸi mai incep inca vreo doi sÄƒ necheze ÅŸi ei, cÄƒ rÃ¢su Ã®i molipsitor, ÅŸi mie Ã®mi ÅŸi curge puÅ£inÄƒ salivÄƒ pe bÄƒrbie, cÄƒ nu mai puteam Ã®ncleÅŸta fÄƒlcile la loc, Ã®n poziÅ£ia \"Ã®nchis\", ÅŸi io cam am probleme fincÄƒ salivez abundent.\r\n\r\nBun, zic io, domniÅŸoarÄƒ io NU POT sÄƒ vÄƒ zic parola. NU POT. Dar daca-mi daÅ£i o foaie de hÃ¢rtie, vi-o scriu.\r\n\r\nDeja-n magazin se dÄƒdeau coate.\r\n\r\nAm primit o foaie de hÃ¢rtie, ÅŸi i-am scris parola: <em>pizdamatii</em>, Ã®mpreunÄƒ, fÄƒrÄƒ nimic altceva, ÅŸi i-am dat-o. PoftiÅ£i, domniÅŸoarÄƒ, zic io, asta-i parola. Revin mÃ¢ine sÄƒ vÄƒd dacÄƒ luÄƒm altÄƒ sursÄƒ sau nu. Pa, o zi bunÄƒ!','Deci despre parole',0,'','publish','open','open','','deci-despre-parole','','','2007-12-15 17:35:11','2007-12-15 15:35:11','',0,'http://www.groparu.ro/?p=890',0,'post','',9),(891,1,'0000-00-00 00:00:00','0000-00-00 00:00:00','Primaru Boc nu sta la bloc\r\nPrimarului Videanu i se spune Bordureanu\r\nNu exista liberal mai mic ca Tariceanu','Poezie politica',0,'','draft','open','open','','poezie-politica','','','2007-12-15 14:12:04','2007-12-15 12:12:04','',0,'http://www.groparu.ro/?p=891',0,'post','',0),(892,1,'0000-00-00 00:00:00','0000-00-00 00:00:00','1. Mersi ca mi-ai lasat cheia pe birou. Asa pot deschide mai usor dozele de bere.\r\n\r\n2. Puteai macar sa faci putina curatenie inainte de a pleca.\r\n\r\n3. Vezi ca noul meu ID pe www.sentimente.ro este terminatorulpotent69, sa nu ma adaugi la prieteni.\r\n\r\n4. Daca te sun in miez de noapte beat rugandu-te sa ne impacam, sa imi inchizi telefonul, te rog.\r\n\r\n5. De acuma nu o sa mai facem sex. Daca totusi vrei sa ne facem fuck buddies, musai sa iti inviti si o prietena cu sanii mari.\r\n\r\n6. Si ce-i daca ne-am despartit! Oricum ai curu mult mai mare ca gajicile alea din filmele porno.\r\n\r\n7. Da, da, stiu ca nu te-am futut cat trebuia, dar oare de ce numai cu tine am avut probleme de erectie?\r\n\r\n8. Tii minte cand ti-am loat rezerva aia pe un an de anticonceptionale? Din moment ce tie nu-ti mai trebuie, nu mi le dai inapoi pentru urmatoarea?\r\n\r\n9. Hai, nu fi suparata! De acuma o sa ai ocazia sa te imprietenesti mai bine cu jucariile sexuale.\r\n\r\n10. Poti cumva pune o vorba buna pentru mine la prietena ta cea mai buna? Tot timpul am fost innebunit dupa ea!\r\n\r\n11. Pregateste-te sa intri intr-o lume a sexului mediocru!','Deci 10 chestii care nu se spun niciodata la despartire',0,'','draft','open','open','','deci-10-chestii-care-nu-se-spun-niciodata-la-despartire','','','2008-06-02 09:20:17','2008-06-02 07:20:17','',0,'http://www.groparu.ro/?p=892',0,'post','',0),(893,1,'2007-12-16 11:49:17','2007-12-16 09:49:17','Daca tot primesc zilnic spam cu <em>penis enlargement</em>.\r\n\r\nHmmm.\r\n\r\nDeci daca io, ditamai masculu\' alfa, tot primesc spamuri d-estea cu mÄƒrit cocoÅŸÄƒlu, femeile de ce nu primesc spamuri cu medicamente care le face nevÄƒstuica mai strÃ¢mtÄƒ?\r\n\r\nAud???','Deci gand de duminica',0,'','publish','open','open','','deci-gand-de-duminica','','','2007-12-16 16:39:31','2007-12-16 14:39:31','',0,'http://www.groparu.ro/?p=893',0,'post','',12),(894,1,'2007-12-16 12:05:16','2007-12-16 10:05:16','Deci dovada ca Dumnezeu m-a creat pe mine dupa chipul si asemanarea Sa: si eu sunt un Dumnezeu, dar numai in pat.\r\n\r\nCand sunt SINGUR in pat.','A, si inca un gand de dumineca',0,'','publish','open','open','','a-si-inca-un-gand-de-dumineca','','','2007-12-16 14:48:09','2007-12-16 12:48:09','',0,'http://www.groparu.ro/?p=894',0,'post','',6),(895,1,'2007-12-18 01:56:56','2007-12-17 23:56:56','Pe mine nu ma prea ceteshte lumea, dupa cum se vede, si asta e destul de frustrant. Recordul meu personal de vizitatori fusa de aproape 600 oameni/zi.\r\n\r\nSi atunci stau io asa, pe scaun, si ma gandesc: oare in tzara asta is numa aproape 600 de oameni inteligenti?','Deci de ce nu am eu trafic mare',0,'','publish','open','open','','deci-de-ce-nu-am-eu-trafic-mare','','','2007-12-18 01:56:56','2007-12-17 23:56:56','',0,'http://www.groparu.ro/?p=895',0,'post','',32),(896,1,'2007-12-17 15:53:57','2007-12-17 13:53:57','','cj_7059.swf',0,'','inherit','open','open','','cj_7059swf','','','2007-12-17 15:53:57','2007-12-17 13:53:57','',0,'http://www.groparu.ro/wp-content/uploads/2007/12/cj_7059.swf',0,'post','application/x-shockwave-flash',0),(898,1,'2007-12-17 16:16:13','2007-12-17 14:16:13','Deci dati click pe <a href=\"http://www.groparu.ro/wp-content/uploads/2007/12/aici.swf\" title=\"aici.swf\">aici.swf</a>, si dati click pe crocodil vreo 8 secunde. <a href=\"http://www.sergiubiris.ro\" target=\"_blank\">Biris</a>, sper ca nu te superi pe <a href=\"http://alex.cyanad.ro/\" target=\"_blank\">Alex</a>, pt realizare, si pe mine pt concept!','Deci despre Trilulilu',0,'','publish','open','open','','deci-despre-trilulilu','','','2007-12-17 16:52:51','2007-12-17 14:52:51','',0,'http://www.groparu.ro/?p=898',0,'post','',7),(899,1,'2007-12-17 16:15:47','2007-12-17 14:15:47','','aici.swf',0,'','inherit','open','open','','aiciswf','','','2007-12-17 16:15:47','2007-12-17 14:15:47','',898,'http://www.groparu.ro/wp-content/uploads/2007/12/aici.swf',0,'post','application/x-shockwave-flash',0),(900,1,'2007-12-17 16:42:36','2007-12-17 14:42:36','Deci colegu\' <a href=\"http://www.doingtheartwork.com/?p=254\" target=\"_blank\">Mishonca</a> o avut ceva de impartit cu neshte vanzatoare tipic romanesti de la un magazin. Prin urmare, le-o troznit un colant, finca-i dizainar si poate:\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/12/dsc00231.jpg\" title=\"dsc00231.jpg\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/12/dsc00231.thumbnail.jpg\" alt=\"dsc00231.jpg\" /></a>\r\n\r\npe care l-o lipit de usa de intrare in magazin.\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/12/dsc00033.JPG\" title=\"dsc00033.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/12/dsc00033.thumbnail.JPG\" alt=\"dsc00033.JPG\" /></a>\r\n\r\nNu are rost sa va spun ca in timp ce el facea lipeala, colegu-so Groparu (adeca - je, persoana pe care o scarpin acuma de buric cu mana mea dreapta) il acoperea cu trupu-mi vajnic, pentru ca el sa-si duca la indeplinire fapta cea reprobabila, probabil.','Cum sa te razbuni pe magazin cu vanzatoare cretine',0,'','publish','open','open','','cum-sa-te-razbuni-pe-magazin-cu-vanzatoare-cretine','','\nhttp://www.doingtheartwork.com/?p=254','2007-12-17 16:45:36','2007-12-17 14:45:36','',0,'http://www.groparu.ro/?p=900',0,'post','',13),(901,1,'2007-12-17 16:40:58','2007-12-17 14:40:58','','dsc00231.jpg',0,'','inherit','open','open','','dsc00231jpg','','','2007-12-17 16:40:58','2007-12-17 14:40:58','',-1197902278,'http://www.groparu.ro/wp-content/uploads/2007/12/dsc00231.jpg',0,'post','image/jpeg',0),(902,1,'2007-12-17 16:41:29','2007-12-17 14:41:29','','dsc00033.JPG',0,'','inherit','open','open','','dsc00033jpg','','','2007-12-17 16:41:29','2007-12-17 14:41:29','',-1197902278,'http://www.groparu.ro/wp-content/uploads/2007/12/dsc00033.JPG',0,'post','image/jpeg',0),(903,1,'2007-12-18 12:08:51','2007-12-18 10:08:51','Sa nu mai mor! Ui acilea ce <a href=\"http://www.9am.ro/stiri-revista-presei/Incredibil!/80151/Privitul-sanilor-prelungeste-viata-cu-5-ani.html\" target=\"_blank\">scrie</a>: daca te uiti la o pereche de balconashe timp de 10 minute, zaaang! Traiesti mai mult cu pan\' la 5 ani.  Bueeey, voi numa acuma ati aflat? Noi stiam instinctiv asta inca de pe cand faceam pe Vasco da Gama prin uter.\r\n\r\nTeoria asta se aplica si daca esti gay?\r\n\r\nUnii sunt \"breasts men\", altii \"butt men\", depinde pe ce parte feminina salivezi mai abitir. Teoria se aplica si la butt men-i?\r\n\r\nDaca ma apuc de fumat din nou, si ma uit zilnic 10 minute la kepÅ£i de damÄƒ, se neutralizeazÄƒ efectele negative ale fumatului?\r\n\r\nTeoria se aplica si la femei? Deci asta inseamna ca fiecare femeie e o potentiala lesbiana?\r\n\r\nArabocii, care au acces la sÃ¢nii a nu mai puÅ£in de 4 fomei permise sau recomandate, nu mai stiu, de Coran, Ã®ÅŸi mÄƒresc astfel viaÅ£a cu 4 femei x 5 ani = 20 ani???\r\n\r\nDa\' daca te apuci sa mai si pupi si sa mangai la ei, manca-i-ar Groparu de irezistibili, nu ar trebui sa maresti si mai mult efectele benefice ale sÃ¢no-terapiei?\r\n\r\nSi intrebarea finala: trebuie sa fie <strong>aceeasi</strong> <strong>pereche de sani zilnic</strong>???\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2007/12/mare10411.jpg\" title=\"mare10411.jpg\"><img src=\"http://www.groparu.ro/wp-content/uploads/2007/12/mare10411.jpg\" alt=\"mare10411.jpg\" /></a>','Privitul sanilor prelungeste viata',0,'','publish','open','open','','privitul-sanilor-prelungeste-viata','','','2007-12-18 12:10:12','2007-12-18 10:10:12','',0,'http://www.groparu.ro/?p=903',0,'post','',23),(904,1,'2007-12-18 12:06:24','2007-12-18 10:06:24','','mare1041.jpg',0,'','inherit','open','open','','mare1041jpg','','','2007-12-18 12:06:24','2007-12-18 10:06:24','',-1197971053,'http://www.groparu.ro/wp-content/uploads/2007/12/mare1041.jpg',0,'post','image/jpeg',0),(905,1,'2007-12-18 12:10:04','2007-12-18 10:10:04','','mare10411.jpg',0,'','inherit','open','open','','mare10411jpg','','','2007-12-18 12:10:04','2007-12-18 10:10:04','',903,'http://www.groparu.ro/wp-content/uploads/2007/12/mare10411.jpg',0,'post','image/jpeg',0),(906,1,'2007-12-19 09:11:16','2007-12-19 07:11:16','Discutie savanta pe Y!M, dintre un coleg si un prekin de-al lui:\r\n\r\n10 august:\r\n\r\n<strong>calinu</strong>: De ce a creat Dumnezeu femeia? Pentru ca o oaie nu putea aduce berea de la frigider pina in fata televizorului.\r\n<strong> mihai_</strong>: :P:P:P\r\n<strong>calinu</strong>: Si pentru a fi misogin pana la capat, plecad de la adevarul ca pana la sfarsitul WW II, doamnele din lumea buna studiau la scoli speciale muzica, arta culinara, pictura si alte chestii umaniste, spune-mi cateva nume de femei mari compozitoare, pictorite, pianiste, maestre bucatar, filozoafe, etc.\r\n<strong> calinu</strong>: se faceau doamne in societate si bucatarese, ca de curve erau curve de cand se stiau\r\n<strong> mihai_</strong>: daca stau sa ma gindesc ca toti barbatii lumii acesteia au facut armata si putem numara citiva doar care au ajuns mari comandanti... si au adus lumea in halul in care e... cu razboaie, atentate, conflicte fara sfirsit...<strong>\r\n</strong><strong>calinu</strong>: ba\r\n<strong> calinu</strong>: tu te-ai dat cu ele??? :o\r\n<strong> calinu</strong>: amu sustii ca is destepte?\r\n<strong> calinu</strong>: :((\r\n<strong> mihai_</strong>: nuuu... da e cam greu sa fii curva... de una singura\r\n<strong> calinu</strong>: noa ashe\r\n\r\n11 august, cu acelasi prieten din olanda\r\n\r\n<strong>mihai_</strong>: salut\r\n<strong> mihai_</strong>: tu sti cu cine ai vorbit ieri?\r\n<strong>mihai_</strong>: discutia cu curvele... si misoginul de tine... :P:P:P\r\n<strong> calinu</strong>: nu\r\n<strong> calinu</strong>: cu cine?\r\n<strong> mihai_</strong>: cu maica-mea !! :P:P:P\r\n<strong> mihai_</strong>: ca is ai mei la mine...\r\n<strong> mihai_</strong>: io eram la serviciu\r\n<strong> mihai_</strong>: hahha... m-or intrebat ca cine e Calin?\r\n<strong>mihai_</strong>: ai pus-o man...\r\n\r\nAm primit voie de la <strong>calinu</strong> sa popularizez lumii parerea domniei sale despre femei, precum si gafele facute in plin proces de marketing a parerii sale.','Deci despre femei',0,'','publish','open','open','','deci-despre-femei','','','2007-12-19 09:11:16','2007-12-19 07:11:16','',0,'http://www.groparu.ro/?p=906',0,'post','',7),(907,1,'2007-12-19 16:36:48','2007-12-19 14:36:48','Da, eu nu primesc rest de la ÅŸoferii de taxi nu din cauzÄƒ cÄƒ nu au sÄƒ-mi deie gume Orbit. Nu! Eu nu primesc rest de la ei pentru cÄƒ deÅ£in dovada irefutabilÄƒ cÄƒ ÅŸoferii de taxi sunt agenti MISA. AgenÅ£i MISA care beau piÅŸu, ÅŸi Ã®Å£i dau ÅŸi Å£ie, pe nevÄƒzute, aceeaÅŸi licoare!\r\n\r\nLadies and gentlemen of the jury, iata traseul unui strop de piÅŸu:\r\n\r\n1. AÅ£i vÄƒzut vreodatÄƒ prohabul (ie, partea aia de la pantaloni cu shlitzu\') soferilor de taxi? <strong>Exact</strong> - io, unu, is sigur ca de fiecare data cand terminÄƒ de fÄƒcut pishu ÅŸi Ã®ÅŸi scutura lebÄƒduÅ£a la toaletÄƒ, doi-trei stropi se agaÅ£Äƒ de prohab, ca supravieÅ£uitorii de pe Titanic de orice fir de pai, Ã®n largul mÄƒrii. Io Ã®i numesc \"stropi evadaÅ£i\" (fincÄƒ Ã®mi aduc aminte de eroii din filmele americane care evadau din lagÄƒrele japoneze).\r\n2. Ati vazut vreodata unde isi tin taximetriÅŸtii microfonul de la staÅ£ia de emisie-recepÅ£ie, cÃ¢nd sunt pe traseu? <strong>Exact</strong> -  Ã®ntre picioare. Da. Deci microfonul se freacÄƒ de partea aia de prohab ÅŸi recolteazÄƒ cei trei stropi de piÅŸu rebeli, pe care-i pÄƒstreazÄƒ pentru sine.\r\n\r\n3. AÅ£i vÄƒzut vreodatÄƒ cum vorbesc ÅŸoferii de taxi la microfonul staÅ£iei, cÃ¢nd vorbesc la microfonul staÅ£iei? <strong>Exact</strong> - Ã®ÅŸi lipesc buzele de microfon, iar cei trei stropi rebeli de piÅŸu de pe microfon, evadaÅ£i de pe Titanic, se contopesc cu buzele ÅŸoferului, ÅŸi ajung in guriÅ£a lor.\r\n\r\nN-am terminat Ã®ncÄƒ!\r\n\r\n4. AÅ£i vÄƒzut vreodatÄƒ cum dau taximetriÅŸtii restul clienÅ£ilor? <strong>Exact</strong> - scot portofelul, scuipÄƒ Ã®n degete <strong>SCUIPATUL ACELA ÃŽMBIBAT CU CEI TREI STROPI DE PIÅžU EVADAÅ¢I DE PE PROHAB</strong>, ÅŸi Ã®Å£i numÄƒrÄƒ restul, pe care tu, de bunÄƒ credinÅ£Äƒ, Ã®l bagi Ã®n buzunar. Deja mÃ¢nuÅ£ele tale au intrat Ã®n contact cu saliva de pe bancnote, aceeaÅŸi salivÄƒ contaminatÄƒ cu piÅŸu mic ÅŸi rebel ÅŸi galbin.\r\n\r\n5. AÅ£i urmÄƒrit vreodatÄƒ unde ajung mÃ¢nuÅ£ele voastre Ã®ntr-o zi normalÄƒ? <strong>Exact</strong> - caÅŸti, pui mÃ¢na la gurÄƒ. Fumezi (eu nu mai! :D) - duci mÃ¢na la gurÄƒ. Rozi unghiile (eu practic acest sport cu furie) - duci mÃ¢inile la gurÄƒ. Te scobeÅŸti Ã®ntre dinÅ£i - duci mÃ¢inile la gurÄƒ. Dai noroc cu amantu\' lu nevasta-ta - il contaminezi si pe el, care o contamineaza pe nevasta-ta, ÅŸi ea pe tine, si ciclul reporneste.\r\n\r\nDeci iata, ladies and gentlemen of the jury, q.e.d. Cand va mai urcati in taxi, ar fi bine sa aveti bani potriviti!','De ce nu primesc rest de la ÅŸoferii de taxi',0,'','publish','open','open','','de-ce-nu-primesc-rest-de-la-soferii-de-taxi','','','2007-12-19 16:36:48','2007-12-19 14:36:48','',0,'http://www.groparu.ro/?p=907',0,'post','',19),(908,1,'2007-12-19 16:46:25','2007-12-19 14:46:25','They both function on a \'prepay\' basis.','What do hookers and mobile operators have in common?',0,'','publish','open','open','','what-do-hookers-and-mobile-operators-have-in-common','','','2007-12-19 16:46:25','2007-12-19 14:46:25','',0,'http://www.groparu.ro/?p=908',0,'post','',10),(909,1,'2007-12-19 23:50:13','2007-12-19 21:50:13','Asa. Deci daca noi tre sa platim bancii comision de acordare a unui imprumut, nu ar trebui sa cerem de la banci un comision de rambursare? La fiecare ratÄƒ, pac! reÅ£inem 2-3% pe luna din suma rambursatÄƒ!','Despre banci II',0,'','publish','open','open','','despre-banci-ii','','','2007-12-19 23:50:13','2007-12-19 21:50:13','',0,'http://www.groparu.ro/?p=909',0,'post','',6),(910,1,'0000-00-00 00:00:00','0000-00-00 00:00:00','1. Sefului: <strong>Cum sa te pregatesti de clipa cand subalternul Ã®Å£i va deveni ÅŸef</strong>;\r\n\r\n2. Nevestei: cartea <strong>FericeÅŸte-l devenind gheiÅŸa lui, daruindu-i-o pe prietena ta ÅŸi mergÃ¢nd singurÄƒ la cumpÄƒrÄƒturi cu banii economisiÅ£i de tine din orele suplimentare;</strong>\r\n\r\n3. Colegului antipatic: <strong>ExploreazÄƒ-Å£i ÅŸi valorificÄƒ-Å£i latura gay a personalitÄƒÅ£ii tale</strong>;\r\n\r\n4. Vecinei de la parter: <strong>1001 accidente Ã®ntÃ¢mplate celor care Ã®ÅŸi spioneazÄƒ vecinii</strong>;\r\n\r\n5.','10 idei de cadouri de cÄƒrÅ£i de Craciun',0,'','draft','open','open','','10-idei-de-cadouri-de-carti-de-craciun','','','2008-06-02 09:14:36','2008-06-02 07:14:36','',0,'http://www.groparu.ro/?p=910',0,'post','',0),(911,1,'2007-12-20 15:08:27','2007-12-20 13:08:27','Deci io vorbeam odata mai demult cu fumÄƒtorii pe balcon (of, ce vremuri...) despre cat de mult ne asemanam noi cu oamenii preistorici.\r\n\r\n1. Stiti din ce cauza barbatii in putere au ditamai <strong>erectia dimineatza</strong>, ca stÄƒ erectia ca o cÃ¢tamai anaconda prin chiloÅ£i, de si sÃ¢sÃ¢ie, ba, la unii mai fioroÅŸi - chiar muÅŸcÄƒ? Deci toÅ£i avem erecÅ£ii, da\' ca aia de dimineaÅ£Äƒ nu se comparÄƒ nimic, fincÄƒ poÅ£i penetra cu ea armura unui tanc britanic, poÅ£i demola cu ea catedrale, ÅŸi tot cu ea, dacÄƒ Ã®Å£i pui Ã®n cap, Ã®ntreci Ã®n lungime cel mai Ã®nalt brad de CrÄƒciun din Europa. Deci ÅŸtiÅ£i de ce masculii o au pe erecÅ£ie? FincÄƒ, in vremuri preistorice, masculu pleca sÄƒ vÃ¢neze lighioaie, da\' nu se ÅŸtia dacÄƒ ÅŸi ajunge Ã®napoi: dacÄƒ nu ajungea pe farfuria unor TirecÅŸi, sigur Ã®l rÄƒpuneau Äƒia din galeria adversÄƒ. Åži atunci profita de dimineaÅ£Äƒ ca sÄƒ-ÅŸi transmitÄƒ genele ÅŸi sprÃ¢ncenele, cÄƒ aÅŸa-i Ã®n regnul Äƒsta animal pe bazÄƒ de carbon, copkiii tÄƒi tre sa semene cu tine, nu cu instalatoru!!!\r\n\r\n2. De ce bÄƒrbaÅ£ii nu se pot deloc orienta Ã®ntr-un spaÅ£iu Ã®nchis (\"mamÄƒ/nevastÄƒ, unde mi-s ciorapii/cheile/tricourile?\" etc), iar femeile ÅŸtiu mereu unde se aflÄƒ sarea, farfuria de la bunica pentru pizza sau chiar holÅŸuruburile? FincÄƒ masculii toatÄƒ ziua umblau de nebuni dupe vÃ¢nat ÅŸi pescuit, ÅŸi strÄƒbÄƒteau distanÅ£e enorme; d-aia se orienteazÄƒ foarte bine Ã®n intersecÅ£ii, da\' nu intreaba nij d-al dreq directia, ca pe vremea aia pe cine sa intrebe, pe tigru\' Äƒla sabie din Ice Age? AÅŸa. Åži femeile rÄƒmÃ¢neau sÄƒ deretice Ã®n peÅŸterÄƒ, d-aia ÅŸtiau ÅŸi ÅŸtiu ÅŸi azi unde-s cuiele, crema de pantofi, neagrÄƒ sau maro, sau ornamentele de CrÄƒciun de anu trecut.\r\n\r\n3. CÃ¢nd pui doo muieri Ã®mpreunÄƒ sÄƒ lucreze, se ÅŸtie cÄƒ una din ele va sfÃ¢rÅŸi cu capul spart ÅŸi un toc Ã®nfipt Ã®n obraz. Asta fincÄƒ Ã®n vremuri ancestrale, femelele se bÄƒteau  pe masculii cei mai puternici, fincÄƒ ÄƒÅŸtia aduceau acasÄƒ pulpa de dinozaur cu cel mai puÅ£in colesterol; d-aia era un privilegiu sÄƒ fii nevasta schwarzeneggerilor, cÄƒ se lÄƒsa cu papa bun ÅŸi tÄƒvÄƒlealÄƒ romanticÄƒ, ÅŸi le-o intrat Ã®n sÃ¢nge sÄƒ se certe ca leliÅ£ele unele pe altele din te miri ce motive.\r\n\r\nNo, deci dacÄƒ aveÅ£i erecÅ£ie dimineaÅ£a, sÄƒ ÅŸtiÅ£i! Mai ales fomeile.','Tu ÅŸtii ce mai face strÄƒmoÅŸul tÄƒu?',0,'','publish','open','open','','omul-preistoric-si-stramosii-lui-cascadorii-rasului','','','2007-12-20 16:19:34','2007-12-20 14:19:34','',0,'http://www.groparu.ro/?p=911',0,'post','',20),(912,1,'2007-12-21 12:54:30','2007-12-21 10:54:30','<script src=\"http://www.trilulilu.ro/embed-audio/PIRATUL/7ad27314bd45a9\" type=\"text/javascript\" language=\"javascript\"></script> <script type=\"text/javascript\" language=\"javascript\">show_7ad27314bd45a9(448, 46);</script>1. In 20 decembrie, mere tata sa o ia pe sor-mea, care era sora medicala in Sibiu, de la spital, ca no - se sparsesera ceva magazine, si era mai sigur asa. Aveam pe vremea aia o <a href=\"http://www.skoda-auto.com/rom/100/history/1980.htm\" target=\"_blank\">Skoda 120L</a>, masina familiei, si taica-meu toata ziua repara la ea in fatza blocului, mai vorbea cu un vecin-doi, vecine, mai da-mi o cheie de 16, mai da niste curent, hai sa-mi repari camburatoru.\r\n\r\nSi dupa ce o ia taica-meu pe sor-mea de la spital, la ora 2, tocmai cand demonstratiile erau in toi, incearca sa evite nebunia de pe centru si merge prin orashu\' vechi. Cand colo - dintr-o strada laturalnica nu stiu cate sute de muncitori ieseau de la nush ce uzina, sÄƒ demonstreze. Si inconjoara masina, si se scurg, incontinuu, pe langa masina. Taica-meu incearca sa iasa din impresurare, si deodata striga unu:\r\n\r\n- Ba pula, da\' tu ce cauti aici, tu tii cu Ceausescu?\r\n\r\nSi o inceput toata masa aia de vreo 2-300 oameni, daca nu mai multi, sa urle: \"<strong>JOS CEAUSESCU!!! JOS CEAUSESCU!!!</strong>\" catre taica-meu, care nu prea o avut el nici in clin nici in maneca cu regimu\', si cativa mai curajosi incep numa sa miste de masina si sa bata cu palmele in capota si parbriz!!! Sor-mea si taica-meu erau in masina, claro - cu gaura curului cat un varf de creion. Taica-meu, mai pe faza, nu isi pierde cumpatul, incepe sa claxoneze in ton cu multimea, care se potoleste si merge in drumu ei. Dupa 20 minute ajung amandoi acasa, teferi.\r\n\r\n2. Sor-mea (avea vreo 19 ani atuncea) avea ceva saÅŸi Ã®n gaÅŸcÄƒ. Printre ei, unu Reini - un sas de treaba caruia i-o placut viatza, ca facea chefuri la el acasa in fiecare seara - care iesise la demonstratii de la inceputul inceputului, in Decembrie ala. Probabil prin 19 o fost prins de Politie, dus la Securitate, si batut rau. A doua zi era din nou in strada. Si in 21 sau 22, pe cand urla de zor lozinci anticouniste, vede langa el pe unul din cei care il batuse - deghizat in manifestant. Se oftica, sare sa puna mana pe el, ala fuge, scapa din multime, Reini dupa el (\"Futu-ti pipota matii de securist!\"), il fugareste de pe (actuala strada) Milea pe Miraslau, cred, securistul se intoarce, scoate pistolul, si infige cateva boabe in Reini, care pica la pamant, destul de mort. Crucea se mai poate vedea si azi. NU stiu ce a patit vinovatul.\r\n\r\nUpdate - aveti crucea lui mai jos:\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2008/01/dsc00256.JPG\" title=\"dsc00256.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2008/01/dsc00256.JPG\" alt=\"dsc00256.JPG\" height=\"585\" width=\"442\" /></a>\r\n\r\n3. Sor-mea, in 22 decembrie, la ora 14, trebuia sa plece la serviciu, iara. Pleaca la 13 si 15 de acasa, si dupa 25 de minute da buzna inapoi, acasa, transfigurata!!! \"Am vazut oameni morti, tipa ea, oameni morti, m-am apropiat de unu intins pe caldaram intr-o balta de sange, era imbracat civil, si sub trening avea haine militare, io nu ma mai duc la serviciu, am auzit impuscaturi...\" Directorul spitalului unde lucra, VicaÅŸ parcÄƒ Ã®l chema, o murit Ã®n aceeaÅŸi searÄƒ, din cÃ¢te mai Å£in minte. ÃŽmpuÅŸcat Ã®n cap, la sediul spitalului.\r\nCam in 20 minute dupÄƒ ce o venit sor-mea o inceput o canonada care o tinut pana dincolo de Craciun. Ne-am impodobit bradul pe impuscaturi, am auzit impuscaturi zi si noapte non stop, timp de mai multe zile, impucaturi cand te pishi la buda, cand te speli in lighean (nu aveam apa calda), cand te joci cu indienii (eram baietan pe vremea aia), cand te uiti la TV si il vezi pe Mircea Dinescu in pulover, cand ii auzi pe ai tai cum vb la telefon cu toti prekinii si neamurile, cand mananci, respiri, tai muraturile sau faci sarmalele cu inima cat un purice.\r\n\r\n4. Prin 23 sau 24, dupa ce se  declansase razboiul anti-tero, ne punem sÄƒ ne cumcÄƒm pe la 11-12 noaptea. La 2 noaptea, vecina bate la uÅŸÄƒ, Ã®nebunitÄƒ: <strong>d-na Groparu, fuga Ã®n pivniÅ£Äƒ, este un terorist pe bloc!!!</strong> Ne scoalÄƒ mama pe mine ÅŸi sora, pune un Å£ol pe noi, ÅŸi Å£uÅŸti Ã®n pivniÅ£Äƒ, unde deja stÄƒtea tot blocul!!! TOT BLOCUL STÄ‚TEA ÃŽN PIVNIÅ¢Ä‚, ÃŽMBRÄ‚CAÅ¢I ÃŽN SÄ‚RÄ‚CIA LOR, ÃŽN CÄ‚MÄ‚ÅžI DE NOAPTE ÅžI PIJAMALE COAPTE, CÄ‚ NICI PIJAMALE NU GÄ‚SEAI DE CUMPÄ‚RAT ÃŽN VREMEA AIA, bÄƒrbaÅ£ii la intrare cu lopeÅ£i ÅŸi cozi de mÄƒturÄƒ ca sÄƒ ne apere de teroriÅŸti, noi toÅ£i, copiii ÅŸi femeile Ã®nghesuiÅ£i Ã®n fundul beciului, tÄƒcuÅ£i, sÄƒ nu se audÄƒ cÄƒ suntema colo ÅŸi sÄƒ nu ne omoare teroristu. Åži stÄƒm ca proÅŸtii acolo, ÅŸi mai iese din cÃ¢nd Ã®n cÃ¢nd cÃ¢te un barbat sa verifice ce si cum, si nu  se Ã®ntÃ¢mplÄƒ nimic,  ÅŸi noi stÄƒm acolo Ã®n frig vreo 2 ore, cÄƒ era decembrie, vÄƒ repet, ÅŸi noaptea era frig, ÅŸi povestim Ã®nfricoÅŸaÅ£i tot felu ca sÄƒ ne facem curaj, ÅŸi pe la 4 dimineaÅ£a ne facem curaj ÅŸi urcÄƒm sus, ÅŸi Äƒia de la etaju 4 nu vroiau sÄƒ urce, ÅŸi i-am Å£inut la noi pÃ¢nÄƒ s-o fÄƒcut ziuÄƒ ÅŸi or avut curaj sÄƒ urce, ÅŸi bag pixu, cÄƒ asta am pÄƒÅ£it noi, de revoluÅ£ie.\r\n\r\nNimic din ce am scris aici nu e exagerat in vreun fel, dacÄƒ datele sau orele nu sunt uneori concordante cu realitatea e din cauzÄƒ cÄƒ au trecut 18 ani de atunci. Postarea asta fusÄƒ inspiratÄƒ de <a href=\"http://milecarpenisan.wordpress.com/2007/12/17/revolutiile-sunt-surorile-violente-ale-libertatii/\" target=\"_blank\">Mile</a> ÅŸi ce a scris el despre TimiÅŸoara ÅŸi, aÅŸa cum am scris ÅŸi la el pe site, de cÃ¢nd cu revoluÅ£ia nu mai pot vedea manifestaÅ£ii publice sau mitinguri cu lozinci strigate - mÄƒ face sÄƒ mÄƒ cac pe mine de fricÄƒ, efectiv, mai degrabÄƒ m-aÅŸ arunca Ã®ntr-un barou de avocaÅ£i Ã®narmat numa cu un sÄƒpun ÅŸi o lamÄƒ de ciungÄƒ!\r\n\r\n<strong>Update</strong>: <a href=\"http://www.white-wolf.ro/?p=431#respond\" target=\"_blank\">WhiteWolf</a> a luat treaba asta cu revoluÅ£ia, ca ÅŸi mine, de alfel (nu am prea glumit Ã®n postarea asta), un pic prea personal. Nu cred ca cineva vrea sa glumeascÄƒ pe seama revoluÅ£iei, si daca totusi se glumeste pe seama ei, inseamna ca, in sfarsit, Romania a  depasit momentul si, in sfarsit, aia impotriva carora am luptat sunt aruncati acolo unde merita, la lada de gunoi a istoriei! :)\r\n\r\n<a href=\"http://amardezi.blogspot.com/\" target=\"_blank\">Amar de zi</a>, care se pare ca o cam simtit pe pielea lui tat ce o insemnat lovilutie, isi aminteste despre zilele alea. Merita cetit!','Revolutia la Sibiu vÄƒzutÄƒ prin ochi sinceri ÅŸi neprietenoÅŸi de Gropar',0,'','publish','open','open','','revolutia-la-sibiu-vazuta-prin-ochi-sinceri-si-neprietenosi-de-gropar','','http://milecarpenisan.wordpress.com/2007/12/17/revolutiile-sunt-surorile-violente-ale-libertatii/\nhttp://www.white-wolf.ro/?p=431#respond','2008-01-09 15:39:59','2008-01-09 13:39:59','',0,'http://www.groparu.ro/?p=912',0,'post','',25),(913,1,'0000-00-00 00:00:00','0000-00-00 00:00:00','1. (cu florile in mana) Am vrut sa iti iau ghiocei, ca is cu mult mai ieftini, da\' nu am gasit in perioada asta a anului.\n\n2. Stii,... mi-i lene sa ma apuc sa fac curatenie in bucatarie. Nu mai bine ne impacam si te intorci la cratitza, unde ti-i locu\'?\n\n3. No,... deci io am loat florile estea pe bani grei, poti macar sa imi achiti jumatate din pretz?\n\n4. (beat, cu urme de ruj pe guler) M-am dus la 4 curve in 2 zile... degeaba, fara tine nu mi se mai scoala!\n\n5. Daca nu te impaci cu mine, te bat si pe tine, ÅŸi pe mÄƒ-ta!\n\n6. As vrea sÄƒ te Ã®mpaci cu mine, dar numai dacÄƒ mai primeÅŸti moÅŸtenirea aia.\n\n7. Acum cÄƒ ne-am Ã®mpÄƒcat, vrei te rog sa NU-MI mai gatesti never ever?\n\n8.\n\n9.\n\n10. (dupa impacare) Stii, florile is loate imprumut de la floraria din coltz, mi le dai sa le duc inapoi, ca la 8 se inchide?','10 fraze pe care sa NU le zici la impacare',0,'','draft','open','open','','10-fraze-pe-care-sa-nu-le-zici-la-impacare','','','2007-12-20 21:55:15','2007-12-20 19:55:15','',0,'http://www.groparu.ro/?p=913',0,'post','',0),(914,1,'2007-12-20 23:13:16','2007-12-20 21:13:16','De cateva zile, am un nou cetitor si comentator furios care, la fiecare comentariu al sau, tine musai sa isi faca reclama la blogul sau scriind si linkul asta: <a href=\"http://zone-ro.blogspot.com/\" rel=\"nofollow\">http://zone-ro.blogspot.com</a>, uneori si de doua ori daca trebuie (io v-am zis ca nu vreti sa bagati la cap, si el s-o prins!), desi oricine comenteaza stie ca isi poate introduce adresa de web in campul<strong> <label for=\"url\"><small>Website</small></label></strong>, si gata! Cui i se pare ca comentariu\' tau merita, dÄƒ click, te descoperÄƒ, se orgasmeazÄƒ - sau nu. Uite un ex:\r\n<ol class=\"commentlist\">\r\n<li id=\"comment-10430\"> 			<em><cite><a href=\"http://zone-ro.blogspot.com/\" rel=\"external nofollow\">zone-ro</a></cite> Says:\r\n<small class=\"commentmetadata\"><a href=\"http://www.groparu.ro//?p=907#comment-10430\">December 20th, 2007 at 2:29 pm</a> </small></em><em><a href=\"http://zone-ro.blogspot.com/\" rel=\"nofollow\">\r\nhttp://zone-ro.blogspot.com/</a></em><em>\r\nprimesti rest insa doar daca restul tau e mai mare de 1 leu nou. daca nu ai de primit mai mult de atat , atunci nu insista sa ti se dea rest pt ca iti vor spune ca nu au. DAR, daca taximetristul lucreaza la o firma , poti suna la dispecerat si daca ii faci plangere cei de la firma il pot suspenda sau chiar da afara, si cel putin 1 saptamana nu mai potate lucra in calitate de taximetrist. Ei cred ca noi nu stiu de lucrurile astea dar daca ai vrea sa ii freci o poti face ca nimeni nu se uita la un taximetrist ca si asa ca is prea multi <img src=\"http://www.groparu.ro/wp-includes/images/smilies/icon_biggrin.gif\" alt=\":D\" class=\"wp-smiley\" /></em><em><a href=\"http://zone-ro.blogspot.com/\" rel=\"nofollow\">http://zone-ro.blogspot.com/</a></em></li>\r\n</ol>\r\n<p align=\"right\"> (Cf www.groparu.ro, 20 decembrie, 2007, 14:29. Soare afara, coafura rezista!)</p>\r\nReferitor la facut reclama, io zic ca e o chestie faina si utila, mai ales finca si io imi acopar o parte din rate advertizÃ¢nd (ba mai mult, chiar o firma de advertising imi hostuieste saitu asta! Mersi, <a href=\"http://www.ad-hoc.ro\" target=\"_blank\">Ad-Hoc</a>;)) Dar pentru ca <a href=\"http://zone-ro.blogspot.com/\" rel=\"nofollow\">http://zone-ro.blogspot.com</a> sa nu-si mai consume tastele si sa fie nevoit sa isi cumpere altele - care costa bani, nu caltabosh, mi se spune din regie - uite, ii fac eu reclama gratis. Deci dati, va rog, click pe linkul cu saitu\' lui (va repet: <a href=\"http://zone-ro.blogspot.com/\" rel=\"nofollow\">http://zone-ro.blogspot.com</a>, ca nu vreti sa bagati la cap, va repet si asta!) si dupa ce cetiti ce are omu de zis, dati-i si un click pe ad-sense-ul de pe sait, si ajutati-l sa inteleaga ca deocamdata ad-sense nu aduce nici macar banuti de o inghetata!\r\n\r\nA, si explicati-i ca auto-reclama nu prea da bine. Cel putin in lumea mea, mai deloc. E bine asa, <a href=\"http://zone-ro.blogspot.com/\" rel=\"nofollow\">http://zone-ro.blogspot.com</a>?\r\n\r\n<strong>Update</strong>: in timp ce scriam, uite numa ce comentariu aparea la postarea mea precedenta! Comentariul 10 =))\r\n\r\nPS: <a href=\"http://www.jeg.ro/ghici-ce-serbam-azi/\" target=\"_blank\">uite ce-a facut Jeg odata</a>.','Pentru http://zone-ro.blogspot.com/',0,'','publish','open','open','','pentru-httpzone-roblogspotcom','','http://www.jeg.ro/ghici-ce-serbam-azi/\nhttp://www.groparu.ro//?p=907#comment-10430','2007-12-21 09:32:55','2007-12-21 07:32:55','',0,'http://www.groparu.ro/?p=914',0,'post','',24),(915,1,'2007-12-21 16:57:04','2007-12-21 14:57:04','Tuturor clientilor, colaboratorilor, colegilor, iubitilor, cunostintelor, cititorilor, blogrollistilor, dusmanilor, vecinilor, rivalilor, shafilor, partenerilor, etc, etc, etc. TUTUROR ROMANILOR SI CELOR CARE STIU SA CITEASCA URAREA ASTA!\r\n\r\nCand la porc ii dai jungheru\'\r\nSa iti deie bani bancheru\',\r\nInapoi sa nu-i mai cearÄƒ;\r\n\r\nCand din porc iÅ£i iei sorlic\r\nNÄƒcazurile sa ti se faca\r\nCÃ¢t o puÅ£Äƒ de pitic;\r\n\r\nSÄƒnÄƒtatea sÄƒ Ã®Å£i vie\r\nCum vin trenuri lungi pe ÅŸine\r\nSi pe dalmaÅ£ieni buline!\r\n\r\nBucurii sÄƒ tot primeÅŸti\r\nAtÃ¢ta cÃ¢t nu gÃ¢ndeÅŸti,\r\nSufletu\' sÄƒ-Å£i primeneÅŸti;\r\n\r\nCÃ¢nd cu tot ai terminat,\r\nSÄƒ-Å£i schimbi lenjeria-n pat,\r\nÅži pe mÃ¢ndrÄƒ sÄƒ Ã®ncepi\r\nColo-ntre cearÅŸafe albe\r\nSa o iei la un pupat!\r\n\r\nCÄƒci CrÄƒciun fÄƒrÄƒ de-amor\r\nÃŽn baie ÅŸi-n dormitor\r\nDe dorit, io, nimÄƒnui\r\nNu doresc, mai bine mor!\r\n\r\nD-aia zic, sÄƒ vÄƒ iubiÅ£i,\r\nFÄƒrÄƒ sÄƒ vÄƒ sclifosiÅ£i,\r\nÅži-Anu Nou ÅŸi Äƒst CrÄƒciun,\r\nSÄƒ vÄƒ fie CEL MAI BUN!!!\r\n\r\nDeci LA MULÅ¢I ANI, copiii moÅŸului! Posibil sÄƒ ne revedem numa la anu;)','Urare de Craciun',0,'','publish','open','open','','urare-de-craciun-2','','','2007-12-21 17:23:15','2007-12-21 15:23:15','',0,'http://www.groparu.ro/?p=915',0,'post','',13),(916,2,'2007-12-21 19:50:07','2007-12-21 17:50:07','1. L-am gasit intr-un carucior, in fatza la Carrefour, si-l uitase unu care o inceput sa ne urmareasca boscorodind ceva de Politie si Procuratura.\r\n\r\n2. Ia-l! Nu am gasit nimic mai eftin.\r\n\r\n3. L-am loat de la reduceri, de la un Second.\r\n\r\n4. Sper ca cadoul de la tine sa fi costat mai mult.\r\n\r\n5. ...cealalta optiune era sa-ti iau un vibrator (merge de minune cu subiectii masculi!)\r\n\r\n6. Decat nimic...\r\n\r\n7. Oricum, e mai mult decat meriti.\r\n\r\n8. Poti sa imparti te rog cadoul asta si cu X si cu Y? S-ar putea ca si cu Z.\r\n\r\n9. Uite, asta am primit eu acum 4  ani. Acum nu-mi mai place si ti-l dau tie.\r\n\r\n10. Nu am apucat sa iti iau cadou. Ia de aici 4 lei si cumpara-ti tu ceva frumos!','Deci 10 chestii care nu se spun cand dai un cadou de Craciun',0,'','publish','open','open','','deci-10-chestii-care-nu-se-spun-cand-dai-un-cadou-de-craciun','','','2007-12-21 19:51:17','2007-12-21 17:51:17','',0,'http://www.groparu.ro/?p=916',0,'post','',15),(917,1,'2008-01-03 11:29:20','2008-01-03 09:29:20','StimaÅ£i terespectatori, dupÄƒ o pauzÄƒ de mai multe zile, continuÄƒm ÅŸtirile.\r\n\r\nAnu asta, ca de obicei, fusai la colindit. Nu am mai vazut femei batute de barbati si viceversa, ca <a href=\"http://www.groparu.ro/?p=100\" target=\"_blank\">anu\' trecut</a>.\r\n\r\nCe mi-o plÄƒcut mie la colindatu Äƒsta, primu colindat european: ÃŽN VIAÅ¢A MEA DE COLINDAC nu am fost aÅŸa de mult Ã®mbiat cu palincÄƒ ca CrÄƒciunul Äƒsta. Deci de cÃ¢nd o devenit pÄƒlinca foarte interzisÄƒ, de cÃ¢nd cu aderarea, e mult mai uÅŸor sÄƒ Å£i-o procuri! MulÅ£umim UE cÄƒ ne ajutÄƒ sÄƒ ne pÄƒstrÄƒm tradiÅ£iile!!!\r\n\r\nCa de obicei la colindit, momentul forte il reprezentÄƒ Ã®ntÃ¢lnirea cu taica-su lu\' Calin, un poet pe gustul meu:\r\n\r\n[youtube VItTQyEv84Q]\r\n\r\nS-o implantat si o faza care m-o loat cu greatza: unuia dintre colindaci i s-o facut de maciuci sh de verighete; asa ca, cand colindam noi la parintii EI acasa (nota bene, parintii ei, inainte de cununie, is toti lapte sh miere; dupe cununie, hidra din Lerna e un fel de Pepsi Twist cu gust usor de lamaie in comparatie cu ei), baietu\' s-o gandit sa si-o ceara in casatorie.\r\n\r\nDeci noi cantam cantecele alea ciudate, alea de le zice colinde, si el se bagÄƒ, la un moment dat, intr-un timing destul de prost, sa zicÄƒ \"am de facut un anunÅ£!\" Noi Ã®i dÄƒm Ã®nainte, si colinda nu-i mai multÄƒ, ieftineÅŸte, Doamne, beutura, ÅŸi el Ã®ncepe sÄƒ zbiere \"<strong>AM DE FÄ‚CUT UN ANUNÅ¢!</strong>\" Noi Ã®ncheiem refrenu ala cu cÃ¢rciuma-n drum, ÅŸi el se pune Ã®n genunchi la gajica-sa lui. Gajica-sa nu vedea nimic, cÄƒ era cu spatele, ca era gazdÄƒ, ÅŸi trebia sÄƒ se asigure cÄƒ toÅ£i oaspeÅ£ii care vroiau vin primesc bere, ÅŸi Äƒia care vor bere primesc palincÄƒ, fincÄƒ aÅŸa e la romÃ¢ni, dacÄƒ nu le dai palincÄƒ la toÅ£i Äƒia care nu vor sa beie aÅŸa ceva nu ej gazdÄƒ bunÄƒ! Åži el o bate uÅŸurel pe umÄƒr sÄƒ se intoarcÄƒ, ea nu simte, cÄƒ tocmai explica nush ce conversaÅ£ie de convenienÅ£Äƒ, d-aia de salon, el nu se lasÄƒ, rÄƒmÃ¢ne in genunchi ÅŸi o mai plezneÅŸte o datÄƒ pe spate, ea se Ã®ntoarce, ÅŸi el scoate:\r\n\r\n- din rÄƒrunchi, un oftat dupÄƒ tinereÅ£ea lui care - iat-o - se cam ducea cu ani(i);\r\n- dintre gulere, cea mai de Clark Gable faÅ£Äƒ pe care-o avea, deÅŸi era Ã®nca plin de coÅŸuri;\r\n- dintre buze, un mic discurs original standard despre cÄƒsÄƒtorie;\r\n- dintre buzunare, o cutiuÅ£Äƒ roÅŸie, un pic gay, cu fundÄƒ, cu un inel de aur cumpÄƒrat de la bijniÅ£ari, de pe centru. ÃŽncearcÄƒ sÄƒ Ã®i baje la fatÄƒ cutia pe dejt, nu-i iese, Ã®ÅŸi dÄƒ seama de oroare, scoate inelu, Ã®i ia deÅŸtiu fetii, nu-i intrÄƒ verigheta, ea se Ã®mpotriveÅŸte, deÅŸi zisese \"da\", el forÅ£eazÄƒ nota, familia ei intervine ÅŸi Ã®i promit cÄƒ ii vor duce verigheta la prelungit, numa sÄƒ nu o mai chinuie pe fatÄƒ sa Ã®i bage deÅŸtiu acolo unde nu vrea ea, el ofteazÄƒ, se simte ca un guguÅŸtiuc. Asta e!\r\n\r\nAÅŸa o fost de colindat anu asta. CÄƒ restu bag samÄƒ cÄƒ fusÄƒ numa tradiÅ£ionalisme d-elea cu beut ÅŸi colindat, care ne cam fac viaÅ£a mai frumoasÄƒ, mai puÅ£in dimineÅ£ile, fir-ar ele ale dreq de mahmureli.\r\n\r\nDa\' sa vedeti de revelion ce-o iesit!!!!','Deci Craciunul din 2007',0,'','publish','open','open','','deci-craciunul-din-2007','','\nhttp://www.groparu.ro/?p=100','2008-01-03 11:30:02','2008-01-03 09:30:02','',0,'http://www.groparu.ro/?p=917',0,'post','',11),(918,1,'2008-01-04 16:08:41','2008-01-04 14:08:41','Deci da.\r\n\r\nRevu\' asta o fost dureros de fain, finca pe toti ne-o durut cate ceva cand s-o gatat. Pe unii ne-or durut chiar mai multe!\r\n\r\nCei care v-ati <a href=\"http://milecarpenisan.wordpress.com/2007/12/26/marea-unire/\" target=\"_blank\">carpenishizat</a> ati  aflat deja ca planul de revelion a lu\' Mile o coincis cu cel al <a href=\"http://mihaiursu.wordpress.com/\" target=\"_blank\">Ursului</a> si al Groparelui, si asta intr-o locatie care, cum sa va zic io, deci noi am tot cautat marul vietii, finca ne-am trezit ca-n paradis: munte, lac, zapada, si mai ales conditii ideale de a face bericid. Bericid, ca sa stiti si voi, se cheama cand omori berile una cate alta, fara mila, fara numar, dar fara manele!\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2008/01/no-manele.JPG\" title=\"no-manele.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2008/01/no-manele.JPG\" alt=\"no-manele.JPG\" /></a>\r\n\r\nDeci: ce sa va zic io, ca or fo atatea evenimente ca nij nu mai stiu ce sa va zic. Deci cabana era pe malu lacului, ca daca era vara vedeam sirenele cum vin sa isi facÄƒ freza la mal, seara.\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2008/01/dsc00550.JPG\" title=\"dsc00550.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2008/01/dsc00550.thumbnail.JPG\" alt=\"dsc00550.JPG\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2008/01/dsc00554.JPG\" title=\"dsc00554.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2008/01/dsc00554.thumbnail.JPG\" alt=\"dsc00554.JPG\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2008/01/dsc00557.JPG\" title=\"dsc00557.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2008/01/dsc00557.thumbnail.JPG\" alt=\"dsc00557.JPG\" /></a>\r\n\r\nDaca nu ar fi fost prea mare efortu, am fi pescuit un pic la copca, ca aveam cu noi primus d-ala de fiert vinisorul ca sa nu ne fie frig, da\' asta ar fi insemnat sa ne scoboram de pe terasa spre lac, sh asta e cam greu de facut in 4 labe (dar, cum aveam sÄƒ aflÄƒm mai tÃ¢rziu, nu imposibil). Asa ca numa am beut sh am facut pishu\' pe lac, ca ingalbenisem gheatza si zapada, de ziceai ca era Marea Chinei!\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2008/01/dsc00195.jpg\" title=\"dsc00195.jpg\"><img src=\"http://www.groparu.ro/wp-content/uploads/2008/01/dsc00195.thumbnail.jpg\" alt=\"dsc00195.jpg\" /></a>\r\n\r\nMai putin eternul Greuceanu, ca el o zis ca nu poate face pipi de pe terasa, finca ii atinge varful putulicii gheatza care era la 5 metri mai jos, si ii e frica sa nu ramaie lipit.\r\n\r\nMnoa, deci avuseram jocuri olimpice de iarna cu bere lasata in zapada ca sa prinda putin abur pe doza; si norocu\' nostru ca am avut bere d-aia strong, care stiti voi ce inseamna: dublu machiala la jumate portia de pishu! Apropos, cica cand o loat Mile berea, i-o adu-o cu motostivuitoru\' din magazin, hihihi!!! (desi nu am avut decat vreo 23 de baxuri la cam tot atÃ¢tea persoane ÅŸi femei, ceea ce e, ca sa zic asa, grupa mijlocie).\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2008/01/dsc00475.JPG\" title=\"dsc00475.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2008/01/dsc00475.thumbnail.JPG\" alt=\"dsc00475.JPG\" /></a>\r\n\r\nAseaaaa. La cabana asheia nu functioneaza, iarna, apa corenta; dar Ã®nsÄƒ curge un pÃ¢rÃ¢iaÅŸ fix prin curtea cabenii. Chestia de care ne-am dat seama numa Ã®n a treia zi, dupÄƒ ce ne spÄƒlasem feÅ£ile si mainile cateva dimineÅ£i, fusÄƒ cÄƒ, de fapt, izvoraÅŸul izvora fix dintr-o fosÄƒ septicÄƒ a unei cabeni de mai sus; nu vÄƒ puteÅ£i imagina veselia molipsitoare care ne cuprinse, precum ÅŸi urÄƒrile de bine cÄƒtre paznicii cabanei noastre (care era pÄƒzitÄƒ, surprinzÄƒtor, de paznici) care ne-or vÄƒzut fÄƒcÃ¢nd asemenea activitÄƒÅ£i fÄƒrÄƒ a ne atrage atenÅ£ia.\r\n\r\nAÅŸa. Åži fincÄƒ nu aveam apÄƒ curentÄƒ, o trebuit sÄƒ tÄƒt cÄƒrÄƒm apÄƒ cu butoaiele cÄƒtre buzile de la etaj (cabana avea buzi, dar Ã®nsÄƒ nu ÅŸi apÄƒ la rezervorul buzilor), cÄƒ era sÄƒ ne prindÄƒ 2008 trebÄƒluind prin buzi! Noroc cÄƒ ne-o prins la grÄƒtare. Åži la grÄƒtare, fix Ã®nainte de revelion, cum stÄƒteam noi, aÅŸa, stÄƒpÃ¢ni peste cabana noastrÄƒ, ÅŸi frigeam carnea Ã®ntr-un abut greÅ£os de delicios de prÄƒjealÄƒ la grÄƒtar, numa ce vedem???\r\n\r\nEi???\r\n\r\nDespre acestea, si despre ce am vÄƒzut, Ã®n emisiunea viitoare.','Revelionu\' 2008 - I',0,'','publish','open','open','','revelionu-2008-i','','\nhttp://milecarpenisan.wordpress.com/2007/12/26/marea-unire/','2008-01-04 16:08:41','2008-01-04 14:08:41','',0,'http://www.groparu.ro/?p=918',0,'post','',20),(919,1,'2008-01-04 15:56:20','2008-01-04 13:56:20','','no-manele.JPG',0,'','inherit','open','open','','no-manelejpg','','','2008-01-04 15:56:20','2008-01-04 13:56:20','',918,'http://www.groparu.ro/wp-content/uploads/2008/01/no-manele.JPG',0,'post','image/jpeg',0),(920,1,'2008-01-04 16:00:29','2008-01-04 14:00:29','','dsc00550.JPG',0,'','inherit','open','open','','dsc00550jpg','','','2008-01-04 16:00:29','2008-01-04 14:00:29','',918,'http://www.groparu.ro/wp-content/uploads/2008/01/dsc00550.JPG',0,'post','image/jpeg',0),(921,1,'2008-01-04 16:00:59','2008-01-04 14:00:59','','dsc00554.JPG',0,'','inherit','open','open','','dsc00554jpg','','','2008-01-04 16:00:59','2008-01-04 14:00:59','',918,'http://www.groparu.ro/wp-content/uploads/2008/01/dsc00554.JPG',0,'post','image/jpeg',0),(922,1,'2008-01-04 16:01:43','2008-01-04 14:01:43','','dsc00557.JPG',0,'','inherit','open','open','','dsc00557jpg','','','2008-01-04 16:01:43','2008-01-04 14:01:43','',918,'http://www.groparu.ro/wp-content/uploads/2008/01/dsc00557.JPG',0,'post','image/jpeg',0),(923,1,'2008-01-04 16:06:52','2008-01-04 14:06:52','','dsc00195.jpg',0,'','inherit','open','open','','dsc00195jpg','','','2008-01-04 16:06:52','2008-01-04 14:06:52','',918,'http://www.groparu.ro/wp-content/uploads/2008/01/dsc00195.jpg',0,'post','image/jpeg',0),(924,1,'2008-01-04 16:08:19','2008-01-04 14:08:19','','dsc00475.JPG',0,'','inherit','open','open','','dsc00475jpg','','','2008-01-04 16:08:19','2008-01-04 14:08:19','',918,'http://www.groparu.ro/wp-content/uploads/2008/01/dsc00475.JPG',0,'post','image/jpeg',0),(925,1,'2008-01-08 12:48:45','2008-01-08 10:48:45','Si, dupa cum spuneam scriind, deci grÄƒtÄƒream afarÄƒ, era vreo 11 noaptea, Ã®ntorceam carnea sforÄƒindÄƒ de pe o parte pe alta si ne lingeam berile ÅŸi deÅŸtele Ã®n acelaÅŸi timp, ÅŸi dintr-o data, auzim un scartait de usÄƒ cÄƒ intrÄƒ pe poartÄƒ, tocma cand cÃ¢ntam cel mai abitir nu mai stiu ce cantecu mÄƒgarului, ca era frig afarÄƒ, ÅŸi auzeam lacu, la 20 metri, cum trozneÅŸte (aÅ£i auzit vreodatÄƒ vreun lac de munte cum trozneÅŸte, cÃ¢nd e congelat pe deasupra? Ã®Å£i vine sÄƒ te pocÄƒieÅŸti mintenaÅŸ, cÄƒ noi d-aia ne-am ÅŸi repezit la rezerva noastrÄƒ de bere ÅŸi ne-am pocÄƒit Ã®ntru bere, cÄƒ ne predasem acestui nou zeu pÄƒgÃ¢n, ÅŸi singurul mod de a-Å£i demonstra adorarea faÅ£Äƒ de el era sa Ã®l duci la gurÄƒ ÅŸi sÄƒ-l gÃ¢l-gÃ¢l-gÃ¢ieÅŸti).\r\n\r\nAÅŸa.\r\n\r\nÅži scÃ¢rÅ£Ã¢ie neste pashi, manca-Å£-aÅŸ!!! Åži auzim aÅŸa, cu ochii noÅŸtri tulburi, un pÃ¢ÅŸ pÃ¢ÅŸ de cÄƒprioarÄƒ cÄƒ intrÄƒ in curte.\r\n\r\nÅži ne uitam.\r\n\r\nMÄƒi copii.\r\n\r\nAm crezut ca e zilele noastre de naÅŸtere.\r\n\r\nIntrau pe poarta uÅŸii, mÄƒi copkii, vreo 6 domniÅŸoare d-elea puÅŸtoaice maneliste genul \"manelistÄƒ cu profil pe Hi5 Ã®n chiloÅ£ei\", crocante, cum ziceam, poate ceva pirsinguri, nu am vazut, cÄƒ eram sideraÅ£i, cÄƒ am ÅŸi uitat sÄƒ mai intoarcem carnea, cÄƒ ni s-o ÅŸi ars vreo 40 de pulpe de pui, atÃ¢ta am adÄƒstat Ã®n ÅŸoc post-traumatic.\r\n\r\nÅži manelistele Ã®ÅŸi carÄƒ bagajuÅ£ele la noi in cabanÄƒ, da nu la mine in camera, aÅŸa cum preconizasem; ÅŸi aveau cu ele ÅŸi vreo 2 masculi, nu mai mulÅ£i; ÅŸi nouÄƒ imaginaÅ£iile or inceput sÄƒ ni se incingÄƒ. RÄƒu. Da\' rÄƒu-rÄƒu!!!\r\n\r\nDupÄƒ cum spuneam, cand natura ne chema, fÄƒceam piÅŸu de pe terasÄƒ, direct Ã®n lacu inghetat; ÅŸi pe cÃ¢nd mÄƒ duc sÄƒ mÄƒ supun chemÄƒrii nepÄƒtrunsului ascuns, una din domniÅŸoarele nou-venita vorbea la telefon. Åži Ã®i zic:\r\n\r\n- ScuzÄƒ-mÄƒ, zic, da\' io tre sa ma pish; da\' daca vrei sa ma privesti in timp ce fac pishu, io nu am APSOLUT nimic impotriva. S-ar putea ca asta sa fie ultima ta sansa de a ma vedea pishandu-ma in 2007. Io in locu tau m-as folosi de ea! Deci.\r\n\r\nM-o refuzat, nu prea politicos.\r\n\r\nAceasta a fost ultima mea experientza urinica pe 2007.\r\n\r\nBun.\r\n\r\nVine ora 12.\r\n\r\nFinca am fost sgarciti, ne-am bucurat de focul de artificii al altor cabane, ca noi nu am avut asa ceva, ne-am improscat sampaniile sh ne-am schimbat urari de bine (sa-ti fie bine anu asta, si mie mult mai bine ca tie! deci), fetele alea maneliste chiar ne-or chemat pÃ¢nÄƒ la ele, Ã®n camerÄƒ, ÅŸi deodatÄƒ - TULAI PULAI! - AM CREZUT CA NE SARE INIMILE DIN KEPT DE FRICÄ‚ AMESTECATÄ‚ CU PANICÄ‚!!!! <a href=\"http://milecarpenisan.wordpress.com/\" target=\"_blank\">SÃ¢rbu</a> - finca nu avuserÄƒm artificii ÅŸi petarde - ÅŸi-o scos pistolu (Äƒia care nu or cetit postarea cu ziua mea, aflaÅ£i cÄƒ sÃ¢rbu umblÄƒ cu gun!!!!!) ÅŸi l-o slobozit Ã®n aer, sau Ã®n lac, nu se mai ÅŸtie, cert e cÄƒ ne-o cam tÄƒiat chefu de a mai sta acolo ÅŸi am fugit ca niÅŸte turci laÅŸi de la Rovine Ã®napoi Ã®n sala de mese, unde mai aveam loc sÄƒ ne ascundem, dacÄƒ vroia sÄƒ ne gÄƒureascÄƒ, ca asa am vazut noi pe descopery ca scapa sardelele de rechini, ca se baga una in alta si asteapta ca proastele.\r\n\r\nBun.\r\n\r\nDupa ora 12, o sama dintre nuntashi s-or retras, ca sa inceapa anu\' cu dreptu\' sau - dupa cum am vazut - cu intrepicioarele.\r\n\r\nAmu am scris mai sus ca fetele alea (cazate la camera 13) ne-or chemat la ele in camera, sa ciocnim un pahar.\r\n\r\nNoi suntem de regula barbati fideli, care nu avem niciodata treaba cu alte femei, mai ales cand ale noaste is prin preajma. Dar voi nu il stiti pe Betonel! Uite, el e Betonel:\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2008/01/dsc00716.JPG\" title=\"dsc00716.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2008/01/dsc00716.JPG\" alt=\"dsc00716.JPG\" height=\"301\" width=\"400\" /></a>\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2008/01/dsc00271.JPG\" title=\"dsc00271.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2008/01/dsc00271.JPG\" alt=\"dsc00271.JPG\" height=\"302\" width=\"400\" /></a>\r\n\r\nAti ghicit, fusa mascota Revului, cel mai baiet adevarat dintre noi, beutor olimpic fruntash, care nu o vazut in vaitza lui o sticla plinÄƒ mai mult de, sa zic, 13 minute! Si foarte sexy, cu  ghirlanda aia de brad de Craciun, import Danemarca!\r\n\r\nPe el l-am facut ambasadorul nostru, sa mearga la fete in camera finca el, cu ghirlanda aia, era irezistibil. Si s-o dus, si noi il urmaream de pe hol, si ne tineam unii de altii de dupa cap, ca alfel cadeam sigur.\r\n\r\nSi merge Betonel la fete (era deja vreo 3-4 dimineatza, si nu se mai auzea manele din camera ispitelor, semn ca sigur dormeau) si se prezinta, dupa ce bate cu bocancu de vreo 23 de ori la fete-n uÅŸÄƒ. Åži ele nu sar sÄƒ deschidÄƒ, dezbrÄƒcate, ÅŸi el ezitÄƒ; noi Ã®l Ã®ncurajÄƒm sÄƒ nu se dea bÄƒtut, el persistÄƒ ÅŸi mai bate de vreo 16 ori in usÄƒ, tot aÅŸa, bubuind uÅŸurel Ã®n usÄƒ, cu bocancii, uÅŸÄƒ care se deschide, intr-un final, ÅŸi o voce adormitÄƒ de fatÄƒ Ã®l asigurÄƒ cÄƒ nu ÅŸi-o ales momentul potrivit, cÄƒ invitaÅ£ia expirase Ã®n urma cÄƒ vreo 3 ore. El insistÄƒ, iar fata protesteazÄƒ; el riposteazÄƒ spunÃ¢nd cÄƒ la o femeie NU inseamnÄƒ DA, ea zice cÄƒ pentru a-si sublinia argumentatia e gata sÄƒ Ã®i cearÄƒ pistolu lu Mile, el spune cÄƒ se crede suficient de rapid ca sÄƒ <em>outsmart a speeding bullet</em>, ea spune cÄƒ dacÄƒ trebuie poate loa si ciocanul de snitele, sau un cutit nu chiar asa ascutit, ca sa doarÄƒ, si chiar o scandura cu cuie, sau il poate chiar viola, daca el tine neaparat, cu clantza de la usa; argument imbatabil, fata fiind astfel desemnata campioana debate-ului, iar noi ne-am retras sÄƒ ne repliem, ÅŸi nu mai ÅŸtiu ce s-o Ã®ntÃ¢mplat, cÄƒ s-o ridicat podeaua Ã®n capu meu ÅŸi m-am trezit in pat, a doua zi. Nici nu stiu cine m-o rostogolit pan-acolo, oricum ii multumesc!\r\n\r\nDeci cum poti mÄƒsura cÄƒ un chef a fost un succes? A DOUA ZI TE DOR COATELE DE LA ATÃ‚TA MERS. Åži pe noi ne-o cam durut.\r\n\r\nA treia zi, sau a patra - cine mai stie? - am pornit, pe la vreo 3 dimineaÅ£a, cu sÄƒniile trase de Renault, prin pÄƒdure. AÅ£i fost vreodatÄƒ traÅŸi de un Renault care se scurge la vale cu 60 km la orÄƒ, iar tu te afli legat de sanie, in spatele masinii, iar Äƒia din masina te filmeazÄƒ, sperand din toata inima sa te prindÄƒ cÃ¢nd cazi ÅŸi Ã®Å£i rupi ceva? Inaltator moment, parol.\r\n\r\nDar s-a intamplat altceva, de care me-e putintel jenÄƒ sÄƒ scriu, da nu mÄƒ las, fincÄƒ presimt cÄƒ o sÄƒ-i Ã®ngreÅ£oÅŸez pe cÃ¢tiva dintre voi, ÅŸi nu pot rata asemenea moment.\r\n\r\nIo meream pe sanie cu doo fete, si una se tinea cu pasiune de mine, cu mainile-i apÄƒsÃ¢nde pe burta mea, sireaca, burtÄƒ eroinÄƒ, cÄƒ o avut mult de tras zilele ÅŸi nopÅ£ile elea; aÅŸa; ÅŸi cracii mei stÄƒteau la deal, sÄƒ pun frÃ¢nÄƒ ca sÄƒ nu ne izbim Ã®n maÅŸinÄƒ cu capu, daca se pune frÃ¢nÄƒ la maÅŸinÄƒ.\r\n\r\nFaceÅ£i un calcul: doo braÅ£e care te apasÄƒ pe burtÄƒ, ÅŸi tu cu cracii la deal; doo braÅ£e care te apasÄƒ pe burtÄƒ, ÅŸi tu cu cracii la deal (am repetat ca sÄƒ Ã®nÅ£elegeÅ£i mai bine); bratele te apasa pe burta, tie ti-i din ce in ce mai greu, si simti ca nu mai poti, asa te eliberezi de presiunea aia crescÃ¢ndÄƒ din mÄƒruntaie (fÄƒrÄƒ sÄƒ anunÅ£i: <em>Groparu a eliberat stafia!</em>), ÅŸi apÄƒi stai ÅŸi te gandeÅŸti o secundÄƒ dacÄƒ sÄƒ bufneÅŸti Ã®n rÃ¢s, sau sÄƒ Ã®i atenÅ£ionezi pe Äƒia de <em>biohazard</em>, sau sÄƒ speri cÄƒ, la viteza aia, pÃ¢rÅ£ul se va risipi cÄƒtre pÄƒdure Ã®nainte ca cineva sa simta ceva!\r\n\r\nNu am avut noroc, pentru ca miasmele s-au raspandit. Am fost recunoscut, pe bunÄƒ dreptate, ca fiind expertul nr. 1 Ã®n flatulaÅ£ii din Ã®ntreg Masivul Semenic (le-am multumit si le-am spus cÄƒ mÄƒ antrenez de multÄƒ vreme), ÅŸi mi s-a spus chiar cÄƒ nici un cal care o tras vreodatÄƒ vreo sanie, incepand cu carele de lupta hitite pana la armasarul  lui Napoleon al III-lea, nu a avut vreodata asemenea eÅŸapament.\r\n\r\nA patra zi am fost atÃ¢ta de tÄƒntÄƒlÄƒi, cÄƒ am plecat fÄƒrÄƒ sÄƒ ne lom rÄƒmas bun de la aproape nimeni :D iertati-ne, corevelionarii noÅŸtri!\r\n\r\nO sÄƒ mai fie chestii de adÄƒugat la postarea asta, voi face apdeit cÃ¢nd imi aduc aminte, sa stiu bine ca daca trebe fac si sedinte de hipnozÄƒ! Ca fusa prea fain ca sa uit asa de repede totu\'. Parerea... hÃ¢c... mea!\r\n\r\nApropos: Ba Mile, la urmatoru Revelion nu ne poti aduce pe fetele alea de la voi de la ProTV care prezinta stirile sportive? Sau macar ceva amante de folbalisti??? Pls.\r\n\r\nAsa: <strong>Update</strong>. Deci prin 3 ianuarie, pe <a href=\"http://mihaiursu.wordpress.com/\" target=\"_blank\">Ursu</a> l-or trimes de la televiziune sa raporteze nush ce viscol si zapezi din Bulgaria. Nenea Ursu, cu ochii de sticla, se vaita la TV: \"E RAU!!! E RAU-RAU-RAU!!!!!!\" Si io nu cred ca se referea la situatia meteorologica :D\r\n\r\nAsa. Si finca la Revelion nu am gasit peshte deloc (se zice ca daca papi peste de Revelion, o sa te strecori ca pestele tot anu\'), am papat numa porc. Asta oare inseamna ca tot anu\' vom bea ca porcii??? Ca sa stiu ce sa-i zic la ficat!\r\n\r\nAsa. Si tot updait: ne-o facut Mile o fripturaÂ  sarbeasca (sau nu) dupa Rev, de si acuma inghit in sec saliva cu gust de carne!!!! Deci carne, cu tot felu de legume unse cu dragoste de sÃ¢rb, cascavale, ciumperci, un deliciu, ce mai! Ia uite numa, am facut poza inainte, ca cand o fost gata am sarit cu totii pe ea si dreq o mai avut vreme de facut poze, fincÄƒ conta mai mult supravieÅ£uirea!!!\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2008/01/friptura.JPG\" title=\"friptura.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2008/01/friptura.thumbnail.JPG\" alt=\"friptura.JPG\" /></a>\r\n\r\nMultumim, man!','Deci Revelion 2008, partea a dooa',0,'','publish','open','open','','deci-revelion-2008-partea-a-dooa','','','2008-01-09 12:22:19','2008-01-09 10:22:19','',0,'http://www.groparu.ro/?p=925',0,'post','',12),(926,1,'2008-01-08 12:47:10','2008-01-08 10:47:10','','dsc00716.JPG',0,'','inherit','open','open','','dsc00716jpg','','','2008-01-08 12:47:10','2008-01-08 10:47:10','',-1199785298,'http://www.groparu.ro/wp-content/uploads/2008/01/dsc00716.JPG',0,'post','image/jpeg',0),(927,1,'2008-01-09 12:15:50','2008-01-09 10:15:50','Am fost la Sibiu sa termin orice legatura cu orasul acela (plansete, urlete, ata ete!)\r\nDupa 10 ani de stat in Cluj (merg pe al 11-lea), dupa gasti si chefuri si tat felu\' si amenzi luate si accidente cu biciclete din care soferii scapa nevatamati (sic!), Departamentul de Logistica al www.groparu.ro s-a hotarat sa - exact - se stramute de tot la Cluj, cu acte, catel, purcel, etc. Viata mea bicisnica si incercanata va putea fi mai usor administrata daca nu tre\' sa ma car la Sibiu de fiecare data cand o secretara plictisita de la Premarie imi trimite foaie ca tre sa platesc impozitu, si pentru asta tre\' sa imi iau zi libera de la serviciu, sa iau ocazia, sa ajung acasa si ma ieu la beute cu prekinii si a doua zi ma trezesc prea tarziu ca sa mai merg la Primarie si atunci plec inapoi in Cluj fara sa fi rezolvat nimica.\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2008/01/dsc00290.JPG\" title=\"dsc00290.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2008/01/dsc00290.thumbnail.JPG\" alt=\"dsc00290.JPG\" /></a>\r\n\r\nAsa ca am fost la Sibiu, m-am dezradacinat, am renuntat la toate actele, mi-am facut mutatia pe Cluj, si cand am iesit afara ca ne-cetatean al orasului meu natal, mai copii, m-am uitat in jur, si ghiciti ce s-a intamplat????\r\n\r\nDIN MOMENTUL ACELA, SIBIUL INCETASE SA MAI FIE CAPITALA CULTURALA EUROPEANA!!!\r\n\r\nIa uite: poze cu orasul meu, manca-l-ar tata!\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2008/01/dsc00251.JPG\" title=\"dsc00251.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2008/01/dsc00251.thumbnail.JPG\" alt=\"dsc00251.JPG\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2008/01/dsc00252.JPG\" title=\"dsc00252.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2008/01/dsc00252.thumbnail.JPG\" alt=\"dsc00252.JPG\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2008/01/dsc00253.JPG\" title=\"dsc00253.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2008/01/dsc00253.thumbnail.JPG\" alt=\"dsc00253.JPG\" /></a>\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2008/01/dsc00257.JPG\" title=\"dsc00257.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2008/01/dsc00257.thumbnail.JPG\" alt=\"dsc00257.JPG\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2008/01/dsc00265.JPG\" title=\"dsc00265.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2008/01/dsc00265.thumbnail.JPG\" alt=\"dsc00265.JPG\" /></a>\r\n\r\nAsa.\r\n\r\nP-orma: noi, in Sibiu, suntem plini de Funari, da\' nu ni-i punem primari! Io-te:\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2008/01/funar.JPG\" title=\"funar.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2008/01/funar.JPG\" alt=\"funar.JPG\" /></a>\r\n\r\nAici aveti colindatori din Poplaca. Ati auzit de Poplaca? Acolo s-o nascut maica-mea, bueeey, care de fapt e-o doamna!\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2008/01/dsc00264.JPG\" title=\"dsc00264.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2008/01/dsc00264.JPG\" alt=\"dsc00264.JPG\" height=\"297\" width=\"393\" /></a>\r\n\r\nIata spelunca unde am tat beut ultima data. Uitati-va numa\' si la preturi! Si calculati ce economie am facut.\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2008/01/dsc00286.JPG\" title=\"dsc00286.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2008/01/dsc00286.JPG\" alt=\"dsc00286.JPG\" height=\"531\" width=\"403\" /></a>\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2008/01/dsc00287.JPG\" title=\"dsc00287.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2008/01/dsc00287.thumbnail.JPG\" alt=\"dsc00287.JPG\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2008/01/dsc00288.JPG\" title=\"dsc00288.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2008/01/dsc00288.thumbnail.JPG\" alt=\"dsc00288.JPG\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2008/01/dsc00291.JPG\" title=\"dsc00291.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2008/01/dsc00291.thumbnail.JPG\" alt=\"dsc00291.JPG\" /></a>\r\n\r\nSi, saving the best for last:\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2008/01/untitled.JPG\" title=\"untitled.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2008/01/untitled.JPG\" alt=\"untitled.JPG\" /></a>\r\n\r\nAtat.','Deci de ce Sibiul nu mai e capitala culturala',0,'','publish','open','open','','deci-de-ce-sibiul-nu-mai-e-capitala-culturala','','','2008-01-09 12:15:50','2008-01-09 10:15:50','',0,'http://www.groparu.ro/?p=927',0,'post','',13),(928,1,'2008-01-09 12:06:18','2008-01-09 10:06:18','','dsc00251.JPG',0,'','inherit','open','open','','dsc00251jpg','','','2008-01-09 12:06:18','2008-01-09 10:06:18','',-1199867242,'http://www.groparu.ro/wp-content/uploads/2008/01/dsc00251.JPG',0,'post','image/jpeg',0),(929,1,'2008-01-09 12:06:27','2008-01-09 10:06:27','','dsc00252.JPG',0,'','inherit','open','open','','dsc00252jpg','','','2008-01-09 12:06:27','2008-01-09 10:06:27','',-1199867242,'http://www.groparu.ro/wp-content/uploads/2008/01/dsc00252.JPG',0,'post','image/jpeg',0),(930,1,'2008-01-09 12:06:36','2008-01-09 10:06:36','','dsc00253.JPG',0,'','inherit','open','open','','dsc00253jpg','','','2008-01-09 12:06:36','2008-01-09 10:06:36','',-1199867242,'http://www.groparu.ro/wp-content/uploads/2008/01/dsc00253.JPG',0,'post','image/jpeg',0),(931,1,'2008-01-09 12:06:49','2008-01-09 10:06:49','','dsc00257.JPG',0,'','inherit','open','open','','dsc00257jpg','','','2008-01-09 12:06:49','2008-01-09 10:06:49','',-1199867242,'http://www.groparu.ro/wp-content/uploads/2008/01/dsc00257.JPG',0,'post','image/jpeg',0),(932,1,'2008-01-09 12:07:06','2008-01-09 10:07:06','','dsc00265.JPG',0,'','inherit','open','open','','dsc00265jpg','','','2008-01-09 12:07:06','2008-01-09 10:07:06','',-1199867242,'http://www.groparu.ro/wp-content/uploads/2008/01/dsc00265.JPG',0,'post','image/jpeg',0),(933,1,'2008-01-09 12:07:53','2008-01-09 10:07:53','','dsc00255.JPG',0,'','inherit','open','open','','dsc00255jpg','','','2008-01-09 12:07:53','2008-01-09 10:07:53','',-1199867242,'http://www.groparu.ro/wp-content/uploads/2008/01/dsc00255.JPG',0,'post','image/jpeg',0),(934,1,'2008-01-09 12:09:16','2008-01-09 10:09:16','','dsc00264.JPG',0,'','inherit','open','open','','dsc00264jpg','','','2008-01-09 12:09:16','2008-01-09 10:09:16','',-1199867242,'http://www.groparu.ro/wp-content/uploads/2008/01/dsc00264.JPG',0,'post','image/jpeg',0),(935,1,'2008-01-09 12:10:06','2008-01-09 10:10:06','','dsc00290.JPG',0,'','inherit','open','open','','dsc00290jpg','','','2008-01-09 12:10:06','2008-01-09 10:10:06','',-1199867242,'http://www.groparu.ro/wp-content/uploads/2008/01/dsc00290.JPG',0,'post','image/jpeg',0),(936,1,'2008-01-09 12:11:46','2008-01-09 10:11:46','','dsc00286.JPG',0,'','inherit','open','open','','dsc00286jpg','','','2008-01-09 12:11:46','2008-01-09 10:11:46','',-1199867242,'http://www.groparu.ro/wp-content/uploads/2008/01/dsc00286.JPG',0,'post','image/jpeg',0),(937,1,'2008-01-09 12:12:12','2008-01-09 10:12:12','','dsc00287.JPG',0,'','inherit','open','open','','dsc00287jpg','','','2008-01-09 12:12:12','2008-01-09 10:12:12','',-1199867242,'http://www.groparu.ro/wp-content/uploads/2008/01/dsc00287.JPG',0,'post','image/jpeg',0),(938,1,'2008-01-09 12:12:25','2008-01-09 10:12:25','','dsc00288.JPG',0,'','inherit','open','open','','dsc00288jpg','','','2008-01-09 12:12:25','2008-01-09 10:12:25','',-1199867242,'http://www.groparu.ro/wp-content/uploads/2008/01/dsc00288.JPG',0,'post','image/jpeg',0),(939,1,'2008-01-09 12:13:00','2008-01-09 10:13:00','','dsc00291.JPG',0,'','inherit','open','open','','dsc00291jpg','','','2008-01-09 12:13:00','2008-01-09 10:13:00','',-1199867242,'http://www.groparu.ro/wp-content/uploads/2008/01/dsc00291.JPG',0,'post','image/jpeg',0),(940,1,'2008-01-09 12:14:05','2008-01-09 10:14:05','','untitled.JPG',0,'','inherit','open','open','','untitledjpg-2','','','2008-01-09 12:14:05','2008-01-09 10:14:05','',-1199867242,'http://www.groparu.ro/wp-content/uploads/2008/01/untitled.JPG',0,'post','image/jpeg',0),(941,1,'2008-01-09 12:14:51','2008-01-09 10:14:51','','funar.JPG',0,'','inherit','open','open','','funarjpg','','','2008-01-09 12:14:51','2008-01-09 10:14:51','',-1199867242,'http://www.groparu.ro/wp-content/uploads/2008/01/funar.JPG',0,'post','image/jpeg',0),(942,1,'2008-01-09 12:16:54','2008-01-09 10:16:54','','dsc00271.JPG',0,'','inherit','open','open','','dsc00271jpg','','','2008-01-09 12:16:54','2008-01-09 10:16:54','',925,'http://www.groparu.ro/wp-content/uploads/2008/01/dsc00271.JPG',0,'post','image/jpeg',0),(943,1,'2008-01-09 12:20:26','2008-01-09 10:20:26','','friptura.JPG',0,'','inherit','open','open','','fripturajpg','','','2008-01-09 12:20:26','2008-01-09 10:20:26','',925,'http://www.groparu.ro/wp-content/uploads/2008/01/friptura.JPG',0,'post','image/jpeg',0),(944,1,'2008-01-09 15:39:33','2008-01-09 13:39:33','','dsc00256.JPG',0,'','inherit','open','open','','dsc00256jpg','','','2008-01-09 15:39:33','2008-01-09 13:39:33','',912,'http://www.groparu.ro/wp-content/uploads/2008/01/dsc00256.JPG',0,'post','image/jpeg',0),(945,1,'2008-01-10 12:24:54','2008-01-10 10:24:54','Deci.\r\n\r\nIo m-am dus asar\' in Kaufland sa ieu legume, finca o vint la mine acas\' famelia lui <a href=\"http://www.andreicrivat.ro\" target=\"_blank\">Crivatz, Andrei Crivatz</a> (care jur ca nu are nici o legÄƒturÄƒ cu ardeii din povestioara asta, si voi trebuie sa ma credeti!), si o prekina de-a fameliei viforoase, pe care o cheama Cenghe, si io-i zic obsesiv Cen Guevara, si care e destul de unguroaica, si care are un prekin care e destul de student la medicina. Si care e destul de meseriash!\r\n\r\nBoooon.\r\n\r\nSi in Kaufland, deci vreau sa zic cÄƒ vÄƒd doi araboci la raionu de legume. Mai, urÃ¢Å£i de puteau juca rolul Äƒla de Bad Guy Ã®n orice film cu Aladdin! Deci hidoÅŸi, mici, pÄƒroÅŸi, negri ÅŸi nebÄƒrbieriÅ£i ÅŸi - aÅŸa cum ÅŸade bine romÃ¢ncelor din Å£ara mea - probabil sex simboluri la iei Ã®n parohia lor romÃ¢neascÄƒ, fincÄƒ se ÅŸtie cÄƒ romÃ¢ncele Ã®i considerÄƒ irezistibili pe toti strÄƒinii, indiferent de naÅ£ie, si li se dÄƒruie instant si fÄƒrÄƒ multe discuÅ£ii, pe cÃ¢nd tu, ca romÃ¢n verde ce eÅŸti, tre\' sa le duci la film ÅŸi cofetÄƒrie ca sÄƒ primeÅŸti o pupÄƒcealÄƒ palidÄƒ pe scÄƒrile blocului.\r\nÅži arÄƒbocii eÅŸtia se chinuiau sÄƒ cÃ¢ntÄƒreascÄƒ neÅŸte ardei pe cÃ¢ntar. Åži numa nu gÄƒseau simbolu de ardei pe cÃ¢ntar, cÄƒ mai erau vreo 5 feluri de ardei, si io dau sÄƒ Ã®i ajut:\r\n\r\n- AÅ£ loat ardei d-Äƒsta? (Achmed, you dead terrorist, did you buy this kind of peppers?)\r\n- NO! urlÄƒ ÄƒÅŸtia, cam enervaÅ£i, da nu enervati ca ii ajut, enervati ca am intrebat de ardei.\r\n\r\nMÄƒi, zic io, ce dreq sÄƒ aibe! Cum sÄƒ urli aÅŸa din pricina unor ardei, care nici mÄƒcar nu-s crivaÅ£i!\r\n\r\n- OK, zic io. How about this kind of peppers did you buy, this kind of peppers?\r\n- NO! urlÄƒ ÄƒÅŸtia iara, ca apucaÅ£ii.\r\n\r\nMÄƒ, zic io, ce dreq au ÄƒÅŸtia!!! CÄƒ mÄƒ \'nerveazÄƒ.\r\n\r\n- Which kind of peppers did you buy?\r\n- This kind, zic ei.\r\n- OK, zic io, ÅŸi le descopÄƒr simbolul ardeilor lor pe cÃ¢ntar ÅŸi le cÃ¢ntaresc io ardeii ÅŸi ei Ã®mi mulÅ£umesc ÅŸi se carÄƒ, urÃ¢Å£ii.\r\n\r\nÅži cÃ¢nd ajung ÅŸi io sÄƒ cumpÄƒr ardei, descopÄƒr de ce se enervaserÄƒ arÄƒbocii pe niÅŸte ardei care nici mÄƒcar nu erau crivÄƒÅ£i:\r\n\r\nIn afara de ardeii cumparati de ei, toti ceilalti ardei ERAU ARDEI IMPORTAÅ¢I DIN ISRAEL! :D','Deci aseara in Kaufland',0,'','publish','open','open','','deci-aseara-in-kaufland','','','2008-01-10 12:33:02','2008-01-10 10:33:02','',0,'http://www.groparu.ro/?p=945',0,'post','',10),(946,1,'2008-01-10 14:37:28','2008-01-10 12:37:28','Deci dupÄƒ cum se ÅŸtie deja, <a href=\"http://www.visurat.ro/2008/01/05/logodna-de-blogger/\" target=\"_blank\">VisUrat</a> si <a href=\"http://denisuca.com/avem-si-filmuletul.html\" target=\"_blank\">Denisuca</a> s-or hotarat sa visezefrumosimpreunuca.com!\r\n\r\nAsa.\r\n\r\nDragii nostri bloggeri mari,\r\nBloggeri mari si bloggeri tari,\r\nS-aveÅ£i multe zile-n faÅ£Äƒ\r\nÅži un pÄƒr fÄƒrÄƒ mÄƒtreaÅ£Äƒ!\r\nS-aveÅ£i mii de cititori\r\nDeodorant la subtiori,\r\nSÄƒ vÄƒ iubiÅ£i intens,\r\nSÄƒ vÄƒ luaÅ£i casÄƒ din Ad-Sense,\r\nSanatatea sa v-inunde,\r\nRelaÅ£ia voastrÄƒ Ã®n fericire sÄƒ se scufunde,\r\nSÄƒ naÅŸteÅ£i fetiÅ£e care vor purta funde\r\nSi bÄƒieÅ£i care-n fete sÄƒ se-afunde!\r\nSa traiti multi ani ferice\r\nSa va iubiti fara bice,\r\nLa nunta s-o faceti latÄƒ,\r\nLa Multi Ani, casÄƒ de piatrÄƒ!!!!','Deci nunta blogosferica',0,'','publish','open','open','','deci-nunta-blogosferica','','http://www.visurat.ro/2008/01/05/logodna-de-blogger/\nhttp://denisuca.com/avem-si-filmuletul.html','2008-01-10 14:37:28','2008-01-10 12:37:28','',0,'http://www.groparu.ro/?p=946',0,'post','',5),(947,1,'2008-01-10 15:00:53','2008-01-10 13:00:53','Vine la mine la birou, si incearca sa imi zica ceva.\r\n\r\nImi scot castile de pe urechi, si ii zic, foarte serios:\r\n\r\n- Please stop interrupting me while I\'m not working!\r\n\r\nO rÃ¢s.\r\n\r\n<strong>Update 1</strong>: s-o razbunat pe mine, o mancat tort si o lasat farfuria murdara la mine pe birou, si o zis: \"I\'ll leave it here on your messy desk, nobody will notice!\" Asa ca i-am zis \"You can leave it on the keyboard for all I care, I never use it, anyway!\"\r\n\r\n<strong>Update</strong> <strong>2</strong>: Am loat farfuria sefului si am strigat catre colegi: \"Farfuria asta o stat supt curu\' lu shafu\', vrea careva sa o linga?\"\r\n\r\nAcest post nu se refera la shefutzu\' meu, ci la shafu\' ala mare. Mare-mare!!!\r\n\r\n<strong>Update</strong> <strong>3</strong>: Am primit agende cu numele firmei. Dupa discursuri, i-am intrebat  pe shafi: \"Tre\' sa dam inapoi agendele, ca is recuzita, nu?\"','Ce i-am zis la shafu meu',0,'','publish','open','open','','ce-i-am-zis-la-shafu-meu','','','2008-01-10 16:16:52','2008-01-10 14:16:52','',0,'http://www.groparu.ro/?p=947',0,'post','',4),(948,1,'2008-01-11 12:49:45','2008-01-11 10:49:45','Da.\r\n\r\nIo, cand nu pierd bani, stau si ma gandesc la modalitati de a-i pierde.\r\n\r\nUna dintre ele mi se pare chiar o idee indrazneatza: mi-as face o fabrica de guma de mestecat, cu arome exotice:\r\n\r\n- Cu aroma de ciorba de burta de la Kon Tiki din Sibiu, garantat cea mai buna zama de burta din Romania, cine e connoisseur e invitat sa isi deie cu parerea ca asa-i;\r\n- Cu aroma de bere Silva d-aia cum se facea in vechime la Reghin, nu ca acuma;\r\n- Cu aroma de mujdei de usturoi;\r\n- Cu aroma de cur de shaf, pentru antrenat noile cadre din firma;\r\n- Cu aroma de femeiushca (yummyyyy!!!)\r\n- Cu aroma de sarmale sau drob de miel, in functie de sarbatoare;\r\n- Cu aroma de soia si patrunjel, pentru naturisti;\r\n- Cu aroma de sushi, pentru clientii cu ochii oblici;\r\n- Cu aroma de jandarm, pentru suporterii ghiduÅŸi ai Stelei;\r\n- Cu aroma de Groparu, pentru patronul Stelei, sa ii puta si lui gura a om inteligent;\r\n- Cu aroma de telemea de Sibiu, bine-nteles (daca Sibiul nu mai face telemea, eu, unul, emigrez in Bulgaria)\r\n- Cu aroma de slana cu ceapa cu carnati si jumeri, pentru fratii nostri din Italia care nu au putut veni de sarbatori, manca-tz-ash;\r\n- Cu aroma de interdictie de circulatie pe drumurile publice, pentru carutzashi;\r\n- Cu aroma de otzet, pentru indulcit soacra;\r\n- Cu aroma de dobanzi uriase, de dat la bancheri, prietenii mei cei mai buni, sa vada si ei cum e;\r\n- Cu aroma de Mac, pentru angajatii Microsoft;\r\n- Cu aroma de miner, serie limitata pentru Ion Iliescu (nu-i dau link numa de-al dreq!)\r\n\r\nSi, pentru a proteja ficatul, cu aroma de mahmurealÄƒ de dimineaÅ£Äƒ, din palinca/bere/vin/gin sau, pentru hardcore drinkers, absint stins cu coniac.','Deci ce idee de afaceri mi-o venit',0,'','publish','open','open','','deci-ce-idee-de-afaceri-mi-o-venit','','','2008-01-11 12:49:45','2008-01-11 10:49:45','',0,'http://www.groparu.ro/?p=948',0,'post','',17),(949,1,'2008-01-12 13:03:46','2008-01-12 11:03:46','Haha! Nu e gata cu mahmurelile.\r\n\r\nDuminica sarbatoresc si <a href=\"http://milecarpenisan.wordpress.com/2008/01/11/traiasca-iulian/\" target=\"_blank\">sarbii</a> Anu Nou.\r\n\r\nDeci ghiciti voi unde voi fi duminica asta?\r\n\r\nAti ghicit: in Serbia, Beograd.\r\n\r\nSi voi canta: Eu <strong>Beu</strong>grad, puÅ£in, puÅ£in cÃ¢te puÅ£in...\r\n\r\nPentru sanatatea dumneavoastra, evitati excesul de sare, zahar si revelioane :D\r\n\r\nPS: Nu stiti careva vreun popor care sa sarbatoreasca Anu Nou ÅŸi in februarie ÅŸi martie? Ca m-ar interesa, cÄƒ mie-mi plac revelioanele!','Deci Revelion 2008 reincarcat, ochit, foc!',0,'','publish','open','open','','deci-revelion-2008-reincarcat-ochit-foc','','\nhttp://milecarpenisan.wordpress.com/2008/01/11/traiasca-iulian/','2008-01-12 15:47:07','2008-01-12 13:47:07','',0,'http://www.groparu.ro/?p=949',0,'post','',11),(950,1,'2008-01-12 10:31:53','2008-01-12 08:31:53','Deci io n-as vrea sa il prind pe Dumnezeu, sÄƒ il pipai si sa strig in gura mare \"EXISTA!\", ca papagalu ala de Arghezi.\r\n\r\nIo, daca l-as prinde, mi-ar fi suficient daca l-as gÃ¢dili oÅ£Ã¢rÄƒ, asa, vreo 10 minute!!!','Deci despre Dumnezeu',0,'','publish','open','open','','deci-despre-dumnezeu','','','2008-01-12 10:31:53','2008-01-12 08:31:53','',0,'http://www.groparu.ro/?p=950',0,'post','',10),(951,1,'0000-00-00 00:00:00','0000-00-00 00:00:00','- Buna ziua, vÄƒ rog un sanviÅŸ Safari Ã®n <strong>dez</strong>lipie arabÄƒ!','La KebapÄƒrie',0,'','draft','open','open','','la-kebaparie','','','2008-01-12 10:44:30','2008-01-12 08:44:30','',0,'http://www.groparu.ro/?p=951',0,'post','',0),(952,1,'2008-01-16 14:03:41','2008-01-16 12:03:41','Mdap.\r\n\r\nBelgradu\' e un oras plin cu sarbi, finca se afla in Serbia.\r\n\r\nIntre Romania si Srbska tre sa prezinti pasaport, ca nu mere ca la Altex, credit numa\' cu buletinu, ce, va credeti la mol?\r\n\r\nAsa.\r\n\r\nDeci la sarbi la revelion inca de la ora 11 se dantuieste ca in Romania cand e nunta in toi. Si mai ales fomeile (care iz faine de pici!) se dantuiesc ca niste iele de zici ca amu-amu isi rup condurii, si masculii stau si beau la masa, asa cum sade bine barbatilor.\r\n\r\nSarbii nu or auzit de alta mancare decat de carne. Ei mananca carne cu orice, chiar si cu alta carne. Sa vedetz numa cum se invartea un porculain cat un bivol in protzap, ca si sfÃ¢rÃ¢ia ca nesimtitu\'!!!\r\n\r\nAsa.\r\n\r\nBelgradul e un oras foarte frumos, dezvoltat pe raul Sava, cu arhitectura frumoasa, si - cel mai important - cladirile borbandate de fratii americani in razboiu\' ala pentru Kosovo or ramas nerenovate, marturie a lucrurilor bune sau nebune facute de Unchiul Sam (cum era faza aia, \"bombing for peace is like fucking for virginity\"?) Se mai poate vedea si azi maternitatea borbandata din Belgrad (!), ambasada Chinei - care arata ca dupa razboi - si alte shele.\r\n\r\nBine-nteles ca eu nu aveam cum sa vad toate astea finca mie mi-o expirat pasaportul in octomvrie anu\' trecut, si am vazut asta cand eram deja in tren, deci nu am putut traversa granita, deci am ramas in Timisoara si am beut si mancat la Taverna Sarbului cam ce am descris mai sus, adeca carne aproape goala.','Deci Revelion pe stil vechi la Beograd',0,'','publish','open','open','','deci-revelion-oe-stil-vechi-la-beograd','','','2008-01-16 15:43:28','2008-01-16 13:43:28','',0,'http://www.groparu.ro/?p=952',0,'post','',14),(953,2,'2008-01-17 10:00:21','2008-01-17 08:00:21','1. Curtea Suprema din Australia a decis cÄƒ <span style=\"font-weight: bold\"><a href=\"http://www.hotnews.ro/ultima_ora/articol_2201212/decis_cimpanzeii_nu_sunt_persoane.htm\" target=\"_blank\">un cimpanzeu amenintat cu evcuarea dintr-un adapost nu este o persoana si nu poate primi donatii</a>. </span>Desteptilor, daca un cimpanezu nu e persoana, de ce reciproca e atata de des valabila?\r\n\r\n2. <a href=\"http://www.hotnews.ro/ultima_ora/articol_2201293/jumatate_dintre_tinerii_britanici_nu_stiu_fiarba.htm\" target=\"_blank\">Cat trebuie fiert un ou</a>? Jumatate din tinerii britanici nu stiu cat trebuie fiert un ou: 3 minute. Ei, aflati ca sunt necesare 3 minute <strong>numai</strong> daca introduc oul in apa deja clocotita care sa nu acopere tot oul, ci numai 60-70% din el, si cu sare in ibric (sarea intareste coaja oului) - daca nu, oul se crapa. Iata, daca erati englezoi acuma v-ati fi aflat in jumatatea celor care stiu cata vreme si in ce conditii trebuie fiert un ou moale (spre deosebire de autorii articolului).\r\n\r\n3. <a href=\"http://www.hotnews.ro/actualitate/esential/articol_2201375/traian_basescu_avizat_inceperea_urmaririi_penale_cazurile_adrian_nastase_tudor_chiuariu_paul_pacuraru_traian_remes_miron_mitrea.htm\" target=\"_blank\">Basescu a aprobat inceperea urmaririi penale</a> impotriva lui Adrian Nastase (mamaaa, ce mic ai ajuns!), Tudor Chiuariu, Paul Pacuraru, Traian Remes, Miron Mitrea si Zsolt Nagy. Miroase aaa... ÄƒÄƒÄƒ...  ce miros Ã®i asta? Nu vi se pare ca miroase a inceputul campaniei electorale? Si nu vi se pare ca din cauza lui Nagy UDMR-ul va spune ca asta e un atac murdar impotriva maghiarilor din Romania?\r\n\r\n4. Oamenii de neÅŸtiinÅ£Äƒ au descoperit cel mai mare rozÄƒtor care a trÄƒit vreodatÄƒ pe Terra, <a href=\"http://news.yahoo.com/s/afp/20080116/sc_afp/sciencepalaeontologyrodent\" target=\"_blank\">undeva Ã®n America de Sud</a>. Noi l-am descoperit de mai demult, Ã®n persoana unui <a href=\"http://www.123urban.ro/def/Guzganul%20rozaliu\" target=\"_blank\">guzgan rozaliu</a>.\r\n\r\n5. <a href=\"http://www.hotnews.ro/economie/cariere/articol_2202433/studiu_romania_tot_mai_multi_angajati_companiilor_private_devin_workaholici.htm\" target=\"_blank\">Tot mai multi angajati in companii private devin workaholici</a>, deci nu sunt singurul. In contemplare, io stiu tot mai multi angajati intr-o relatie pe viatza care devin alcoolici.\r\n\r\n6. <a href=\"http://www.hotnews.ro/economie/consumator/articol_2201762/expatii_portughezi_romania_bucurestiul_oras_scump.htm\" target=\"_blank\">Portughezii nu-si revin de ce preturi vad in Bucuresti</a>.  Ba Lijboa people, asa-i ca si voo va vine sa meretz in Spania la capsuni?\r\n\r\n7. Nokia a produs primul telefon in RomÃ¢nia, un Nokia 1208. Presedintele micii afaceri de apartament finlangheze a declarat, vadit stanjenit: \"Daca stiam ce fiÅ£oÅŸi sunt romÃ¢nii cÃ¢nd e vorba de telefonul mobil, fÄƒceam o fabricÄƒ de iPhone-uri!\"','Pe scurt, nu pe lung',0,'','publish','open','open','','pe-scurt-nu-pe-lung','','','2008-01-17 10:31:07','2008-01-17 08:31:07','',0,'http://www.groparu.ro/?p=953',0,'post','',4),(954,1,'2008-01-17 15:55:18','2008-01-17 13:55:18','Deci se stie deja ca nemtii de la fabrica aia Nokia care va fi desfiintata in Jermanica fac scandal amu ca de ce tre sa se mute productia in Romanica.\r\n\r\nAsa.\r\n\r\nCine se oboseste sa le explice ÅŸi la tÄƒntÄƒlocii ÄƒÅŸtia de nemÅ£i ca noi nu am intrat in UE <strong>CA SÄ‚ DÄ‚M, CI CA SÄ‚ LUÄ‚M</strong>?','Deci despre Nokia la Cluj si scandalul cu nemtii',0,'','publish','open','open','','deci-despre-nokia-la-cluj-si-scandalul-cu-nemtii','','','2008-01-17 15:55:18','2008-01-17 13:55:18','',0,'http://www.groparu.ro/?p=954',0,'post','',5),(955,1,'2008-01-18 00:24:41','2008-01-17 22:24:41','In Australia, de la Muzeul Marsupiului, <a href=\"http://news.yahoo.com/s/nm/20080117/wl_nm/australia_boomerang_dc\" target=\"_blank\">s-a furat acum 25 de ani un bumerang original</a>. Dupa 25 de ani, hotul, un turist american, l-a returnat muzeului, cu o scrisoare de parere de rau.\r\n\r\nIo cred ca l-a returnat dupa ce a incercat timp de 25 de ani sa scape de el, si si-a schimbat de vreo 800 de ori dantura!','Haha! Bumerang furat',0,'','publish','open','open','','haha-bumerang-furat','','','2008-01-18 00:24:41','2008-01-17 22:24:41','',0,'http://www.groparu.ro/?p=955',0,'post','',1),(956,1,'2008-01-18 01:18:45','2008-01-17 23:18:45','Iubeste-i, in pula mea, zambetul, finca in coltul gurii ei descoperi - jur - trei semnificatii diferite, si trebuie sa i te uiti in ochi, ca sa ti le confirmi, desi se bat toate cap in cap.\r\n\r\nIubeste-i, fraiere, gushitza care i se trezeste cand sta intinsa pe spate si se uita la tine cum te ridici din pat, te scarpini in cur, si intrebi: unie dreq mi-am pus kilotzii?\r\n\r\nIubeste-i gatul. Daca te uiti mai bine, maine va avea semn, acolo, sub saliva ta inca sclipinda in lumina becului de 65 W: iar ai mozolit-o ca un vitelus, si maine o vor miÅŸtocÄƒri colegii, si colegele vor merge acasa, maro de gelozie, si isi vor plesni sotii: \"Tu niciodata nu m-ai trimis la serviciu cu semne pe gat de la prea multa dragoste!\"\r\n\r\nDaca te uiti mai atent, sub gat are o mica gropitza, chiar sub marul ala al lui Adam: mnoa. Gropitza aia respir-o.\r\n\r\nDaca simti un miros de iubire, te cheama Groparu.\r\n\r\nDaca o vezi ca ofteaza, fa-i o poza cu ochii la dantura: e umeda de la limba ei cu gust de E-uri care se baga in iaurtul cu gust de fragÄƒ, Äƒla fara dioxinÄƒ!\r\n\r\nTe mai uiti inca la coltul gurii ei? Fii atent numa cum zambeste, finca nu stie ce ai de te holbi la ea ca un tablou: vezi cretzele alea care i se fac in jurul gurii? Adora-le. Sunt pentru tine.\r\n\r\nDaca se uita la tine cu ochii mijiti, nu e din cauza ca vrea sa vada cat mai putin din tine, ci pentru ca deja viseaza ca stai calare pe ea, si o strivesti, usurel, cu ditamai burta ta (pe care ti-o iarta). Ea viseaza la ea sub tine, si tu stai ca prostu\', citind blogu\' asta???\r\n\r\nCE FEL DE OM ESTI, MAH???\r\n\r\nPS: Bine-nteles, acestea se aplica numai cand poarta bluza ei azurie.','Ce fac femeile cel mai bine? Iti confirma senzatii',0,'','publish','open','open','','ce-fac-femeile-cel-mai-bine-iti-confirma-senzatii','','','2008-01-18 11:55:35','2008-01-18 09:55:35','',0,'http://www.groparu.ro/?p=956',0,'post','',14),(957,1,'2008-01-18 12:48:49','2008-01-18 10:48:49','Stii care ar fi cea mai mare razbunare din partea lu\' nevasta-ta?\r\n\r\nSa-ti zica: \"Gata, plec la <strong>MAICA-TA</strong>!\"','Razbunarea lu nevasta-ta',0,'','publish','open','open','','razbunarea-lu-nevasta-ta','','','2008-01-18 12:48:49','2008-01-18 10:48:49','',0,'http://www.groparu.ro/?p=957',0,'post','',14),(958,1,'0000-00-00 00:00:00','0000-00-00 00:00:00','Pentru doo persoane foarte speciale din viatza a doi prekini cu nevoi foarte speciale, care nu crede ca io le stiu prekinii cu nevoi, ma repet, foarte speciale:\n\n1. DÄƒnila din BucureÅŸti are pula foarte mare ÅŸi ÅŸtie foarte bine ce sa facÄƒ cu ea! (mersi de berea care va curge, Dane!)\n\n2.','Reclama de-mascata',0,'','draft','open','open','','reclama-de-mascata','','','0000-00-00 00:00:00','0000-00-00 00:00:00','',0,'http://www.groparu.ro/?p=958',0,'post','',0),(959,1,'2008-01-18 19:41:39','2008-01-18 17:41:39','Nu va luati. <a href=\"http://www.groparu.ro/?p=119\" target=\"_blank\">Io mi-am loat</a>.\r\n\r\nE prea usoara si va danseaza prin baie.\r\n\r\nSi colac peste pupaza amu mi s-o si stricat, si numa nu-i gasesc certificatu\' de garantie. Daca aveam alta masina de spalat, sigur il gaseam!\r\n\r\nCa sa intelegeti cum ma simt amu, cautati pe gugal \"Romanian profanity\".','Masina de spalat Samsung f1045AV',0,'','publish','open','open','','masina-de-spalat-samsung-f1045av','','\nhttp://www.groparu.ro/?p=119','2008-01-18 20:33:59','2008-01-18 18:33:59','',0,'http://www.groparu.ro/?p=959',0,'post','',8),(960,1,'2008-01-19 19:02:53','2008-01-19 17:02:53','Invatati, buey, si voi cum se face reclama la aspiratoare traducand din ingriÅŸ:\r\n\r\n<strong><span lang=\"IT\">\"James\", noul aspirator galben-stralucitor al <em>Numaticului</em>, fabricat in Anglia.</span></strong><span lang=\"IT\"> <strong>James nu este numai un aparat clasic cu multa personalitate, ci si un amuzant design bazat pe <em>simplicitate</em>, la care se adauga <em>putere superba </em>si extraordinara performanta. Butonul rosu, de pornire, o data declansat, dezvaluie performanta aspiratorului. Lacasul de pe capac este un <em>loc briliant</em> prin capacitatea de depozitare a cablului, instrumente <em>posibil necesare</em>, carpa de praf si chiar ceva solutii necesare in procesul de curatenie.</strong></span>\r\n\r\n<span lang=\"IT\"></span>De <a href=\"http://www.chemiclean.ro/\" target=\"_blank\">aici</a>.\r\n\r\nPS: am inclinat eu, prin puterea-mi brilianta si superba, literile inclinate.','Traducere frumoasa, cinste cui te-a proscris!',0,'','publish','open','open','','traducere-frumoasa-cinste-cui-te-a-proscris','','','2008-01-19 19:05:16','2008-01-19 17:05:16','',0,'http://www.groparu.ro/?p=960',0,'post','',7),(961,1,'2008-01-21 09:03:02','2008-01-21 07:03:02','Momentul in care castigi la loterie este unul dintre cele mai frumoase din viatza noastra, alaturi de momentul cand ti se naste un copil (cu sau fara ajutorul vecinului de la 2 - eu stau la 4), cand primesti o avansare (la mine niciodata nu a fost cazul) sau - mai ales - cand reusesti sa tragi un lighean de caca super mirositor la serviciu, si toata lumea se plange ca buda e inutilizabila toata saptamana, si nimeni nu stie ca de fapt este meritul TAU, si tu rÃ¢zi si taci, taci chitic, din modestie (atÃ¢ta numa cÄƒ le spui la doo-trei contacte din YM, fincÄƒ io, unu, niciodatÄƒ nu am putut rÃ¢de singur, mai bine am luat Valium cu bere nefiltrata - combinatie care, bine-nteles, nu are nici o legatura cu postarea de faÅ£Äƒ). Am dreptate la faza cu kaka, <a href=\"http://nenea.wordpress.com/2008/01/13/manual-de-sters-la-cur/\" target=\"_blank\">nene</a>?\r\n\r\nDa\' finca is super-mega-terra curioz:\r\n\r\nCE ATI FACE VOI DACA ATI CASTIGA LA 6 DIN 49 11 MILIOANE DE EURO DUMINECA VIITOARE?\r\n\r\nPS: Bagatz de seama ca dupa taxe nu mai ramaneti decat cu vreo... 9 milioane :|','Deci, loterie',0,'','publish','open','open','','deci-loterie','','\nhttp://nenea.wordpress.com/2008/01/13/manual-de-sters-la-cur/','2008-01-21 09:59:30','2008-01-21 07:59:30','',0,'http://www.groparu.ro/?p=961',0,'post','',15),(962,1,'2008-01-21 12:42:17','2008-01-21 10:42:17','','ro8kfbsmag.txt',0,'','inherit','open','open','','ro8kfbsmagtxt','','','2008-01-21 12:42:17','2008-01-21 10:42:17','',-1,'http://www.groparu.ro//../../../../../../../../../../../../../../../../../tmp/ro8kfbsmag.txt',0,'post','text/plain',0),(964,1,'2008-01-21 20:36:11','2008-01-21 18:36:11','Imi ia din mÃ¢na pachetul voluminos si il pune pe tejghea, de parcÄƒ tejgheaua aia Ã®i baru\' lu unchiu-so din partea lu\' ma-sa.\r\n\r\nE un pusti de vreo 16 ani, cu un cercel femeiesc de sticla in nush ce ureche, care strÄƒluceÅŸte orbitor. Tin minte ca odata m-am hlizit de un pustache identic, cu un ditamai tatuaj color de dragon chinezesc care i se lÄƒÅ£ea pe tot gÃ¢tul pÃ¢nÄƒ la urechi, tatuaj imposibil de ascuns. Am vrut sa-i zic \"Of, puÅŸtiulicÄƒ, cÃ¢nd Å£i-ai fÄƒcut tatuaju nu prea te gÃ¢ndeai tu cÄƒ ajungi manipulator de marfÄƒ Ã®n Profi, aÅŸa-i?\" - da\' mi-am dat seama ca nici io nu-s cine stie ce de capu meu, imbracat in chinezarii la reduceri sau cu ce haine imi trimite sor-mea de pe la mormantÃ¢rile la care merge prin  Germania, cÄƒ ia hainele raposatilor sÄƒ Ã®ÅŸi imbrace fratioru\' din Romania, si el - io, adicÄƒ - dintr-un reflex studenÅ£esc, le Ã®mbracÄƒ permanent pen\' cÄƒ mi-s dragi; atÃ¢ta numa ca e mai greu cÃ¢nd primesc haine de la femei moarte, cÄƒ elea le port numai in intimitatea propriei mele cÄƒÅŸi, mai ales sutienele, cÄƒ-mi place sÄƒ le port pe mine cÃ¢nd fac sex (da\' numa cand se asorteaza cu colantii, cÄƒ cÃ¢nd mÄƒ vÄƒd Ã®n oglinda deasupra patului mi se face rÄƒu dacÄƒ nu se asorteazÄƒ, ÅŸi dacÄƒ mi se face rÄƒu mÄƒ doare capu\', deci adio sex!)\r\n\r\nAÅŸa.\r\n\r\nPuÅŸtiu are neste deste groase, cam cat carnaciorii de bere; Ã®mi ascund mÃ¢nurile mele de intelectoal subÅ£ire, stil TÄƒriceanu. PuÅŸtiu ia cu ele pachetu\', aÅŸa, bÄƒrbÄƒteÅŸte, ÅŸi Ã®l aÅŸezÄƒ fÄƒrÄƒ efort vizibil pe bancul de probe, ÅŸi cÃ¢nd bufneÅŸte de se si aude asa, un zgomot ca de acvariu spart, nu-mi cauta privirea ca sa vada ce reactie am, da\' mie mi se flutura, finca inca nu am iesit din magazin.\r\n\r\nImi cere factura:\r\n\r\n- \"Da-mi factura!\" zice el.\r\n- \"PoftiÅ£i!\" zic io.\r\n\r\nImi face favorul infinit sa mi-o ia, Ã®ncepe sÄƒ se uite la ea, silabisind cu greu.\r\n- De ce Asus? mÄƒ Ã®ntreabÄƒ.\r\n- Because I\'m an ass-us, zic io, incercand un spirit de gluma, regretat in secunda imediat urmatoare.\r\n\r\nScoate un pix si incepe sa scrie, cu greu. Cate doua cifre, cate doo litere. Doo cifre, doo litere. In spatele lui, un nene foarte in varsta, cu neste cearcane monumentale, il urmareste cu atentie.  Nu are nici un chef sa se ocupe de liota de clienti din spatele meu, asa ca <em>il supravegheaza</em> pe pustiulica.\r\n\r\nIntr-un final, Ã®mi dÄƒ sp semnez, ÅŸi probeazÄƒ aparatu. Mai stÄƒ 14 minute sÄƒ Ã®l bage Ã®napoi Ã®n cutie, Ã®l scoate inapoi, il baga iara, dar, dupa, principiul reparatorului de radiouri, tot timpul raman afara cateva piese <em>fara de care radioul merge chiar mai bine ca inainte.</em> Ma ofer sa mi le bag in rucsac ca sa nu se mai chinuie.\r\n\r\nAzi mi-am loat monitor plat ca un sÃ¢n de mam\'-mare si ENERVANT de <em>wide</em>, iar aceasta a fost - aÅ£i ghicit! - o postare despre apsolut nimic.','Aspect ',0,'','publish','open','open','','aspect','','','2008-01-22 02:20:49','2008-01-22 00:20:49','',0,'http://www.groparu.ro/?p=964',0,'post','',4),(965,1,'2008-01-22 12:11:28','2008-01-22 10:11:28','Deci un prekin softist mere sa faca afaceri cu arabocii, sa le vanza nush ce aplicatie care nush ce facea, numara camilele, sau cocoasele, sau nevestele din harem, sau putzele de petrol, sau nush, ti le arhiva si ti le afisa in raport.\r\n\r\nLa araboci, toate secretarele, femeile de serviciu, educatoarele, hostessele, soferitele de taxi, dispeceritzele, ba chiar si femeile is numai barbati, de regula din India sau negri din Africa. Finca la ei femeile nu lucreaza deloc, ci ele numa\' cheltuie ce produce sotii lor, si umbla imbracate in materiale textile loate direct de pe baloti. Asta e ultima mode la ei, si umbla asa de vreo 3000 de ani.\r\n\r\nAsa.\r\n\r\nSi daca mergi la piscina hotelului, tu ditamai mascul fiind, si piscina NUMAI pentru barbati, atunci musai sa ai grija sa porti pantaloni de slip, nu slipi d-eia care dezvelesc bucutza. Finca secretara piscinei, un negru urat din Sudan, iti atrage atentia ca esti prea indecent.\r\n\r\nDar partea cea mai faina vine cand le prezinti aplicatia. Dupa ce ca aia se plictisesc de moarte, nici nu te asculta, finca se joaca pe <em>aipoduri</em>, iti fac tie poze cu mobilu si apoi iti modifica fatza si iti pun joben si mustatza, isi transmit pe bluetooth ringtonuri cu camile sau descarca pornoshage. Deci nu te asculta si nu te baga in seama, pana cand unu devine dintr-o data foarte atent la prezentare, se holbeaza, tu te bucuri ca uite, o descoperit arabocii ce geniala e aplicatia, continui sa le prezinti infiorat la gandul comisionului tau, pana cand arabocul asta care e foarte interesat de ce vede pe proiector indreapta destiu spre aplicatie, intr-un loc in care doo linii absolut nevinovate se intersecteaza, ca sa delimiteze sectiunile din fereastra, asa, deci arata cu destiu si intreaba, desfigurat:\r\n\r\n<strong>- IS THAT A CROSS??? </strong>\r\n\r\nMnoa. Convinge-l tu, ghiaur ce esti, aflat in timpul cruciadei americane din Golf, ca aia nu-i cruce!','Cand faci afaceri cu arabocii',0,'','publish','open','open','','cand-faci-afaceri-cu-arabocii','','','2008-01-22 12:45:44','2008-01-22 10:45:44','',0,'http://www.groparu.ro/?p=965',0,'post','',8),(966,1,'2008-01-23 18:55:18','2008-01-23 16:55:18','Deci fratilor, am rupt-o-n fericire. <a href=\"http://www.protv.ro/stiri/social/lovitura-sub-centura-pentru-romani-se-scumpeste-berea.html\" target=\"_blank\">Se scumpeste berea cu 25%</a>, conform unor surse demne de incredere numite Stirile ProTV.\r\n\r\nStiu, stiu, unii dintre voi spuneti ca berea se scumpeste din cauza ca Dumnezeu nu exista, si ca daca exista ar face bine sa ne dea un semn, nu neaparat cu copiii aia cu SIDA din Africa, un leac pentru cancer sau - mda - sa ne scape de derapaju asta economic in care pica bursele cu 30% pe zi. Doamne, daca ne auzi si totusi nu existi, te rugam noi sa egzisti si sa ne ieftinesti berile! (io stiu ca existi, Doamne, da\' am scris asta numa\' ca sa ma dau amuzant. Iarta-ma, ca Tu stii nu mai fac pana data viitoare!)\r\n\r\nSa va zic ce ne asteapta.\r\n\r\n1. Vor ramane o gramada de femei neiubite in virtutea faptului ca berea, dupa cum se stie, actioneaza ca un catalizator pentru relatii la nimereala - la care eu, intr-o vreme, eram expert. Fetelor, aveti grija cu cine votati anu asta, daca vreti iubire! Votati si voi cu un guvern care sa ploaie sa se faca hameiu, plm.\r\n\r\n2. Diminetile nu vor mai avea, pur si simplu, acelasi gust! Ma refer la gustul ala de femeie agatzata cu bere.\r\n\r\n3. Va trebui sa inlocuim berea din cafea cu lapte condensat, asa cum am auzit ca se facea in Anglia pe la mijlocu\' secolului trecut (dezgustatori englejii astia!)\r\n\r\n4. Adio bere stinsa cu coniac.\r\n\r\n5. Burtile noastre cimpoiate nu vor mai avea nici o scuza.\r\n\r\n6. Nu o sa mai putem spune rÃ¢zÃ¢nd \"I don\'t have a drinking problem, I have a drinking solution!\"\r\n\r\n7. Cu ce va trebui sa ne inlocuim masa de pranz??? CU SUPA???\r\n\r\n8. Ficatul va deveni rozaliu ca parizeru\' (dezgustator, din nou!)\r\n\r\n9. Vom uita ca raspunsul la problemele personale nu zace pe fundul sticlei, ci in prima inghititura de bere!\r\n\r\n10. Nu va mai functiona adagiu \'cela: Esti ceea ce bei! Deci dragi iepurasi, nu voi mai fi ditamai ursu\'.\r\n\r\nPlus ca acuma imi poate spune  si mie careva ce rost mai au nevestele, daca nu mai au ce bere sa aduca din frigider???\r\n\r\nPS: La Multi Ani lu\' Bogdanel (ieri) si Nicu Bendea (azi), si va dorez... urasc... NU. Va DORESC URANDU-VA MULTA, MULTA, MULTA BERE IEFTINA! (fara poezea, ca zilele estea nu puÅŸcÄƒ :D )','Se scumpeste berea!!!!',0,'','publish','open','open','','se-scumpeste-berea','','','2008-01-24 09:50:42','2008-01-24 07:50:42','',0,'http://www.groparu.ro/?p=966',0,'post','',9),(967,1,'2008-01-22 22:15:58','2008-01-22 20:15:58','Deci:\r\n\r\nDaca Dumnezeu mi-e tatÄƒ, iar Fecioara Maria nu mi-e mamÄƒ, insamnÄƒ ca Iisus mi-e frate vitreg?\r\n\r\nPÄƒi atunci... salut, frÄƒÅ£icÄƒ!\r\n\r\nDa, da, stiu, voi putrezi in iad, and it ain\'t gonna be fun.','GÃ¢nd instant',0,'','publish','open','open','','gand-instant','','','2008-01-22 22:15:58','2008-01-22 20:15:58','',0,'http://www.groparu.ro/?p=967',0,'post','',15),(968,1,'2008-01-23 19:04:27','2008-01-23 17:04:27','Deci io aflai de la Iepurasu Atomic, care, spre rusinica lui, nu mai blogareste, si rau face, ca Laura Andresan vrea sa-si mareasca nush ce sÃ¢ni de-ai ei.\r\n\r\nIo, dac-as fi pentru-o zi plastician si ar veni la mine Laura Andresan sa-si mareasca sanii, i-as mari numa unu\', da\' asa, la greu! Si pe celalalt l-as micsora.\r\n\r\nApai mi-as da demisia si as rÃ¢de o viatza intreaga. Finca mie mi se par funny chestiile astea!','Dac-as fi pentru-o zi plastician',0,'','publish','open','open','','dac-as-fi-pentru-o-zi-plastician','','','2008-01-24 00:07:59','2008-01-23 22:07:59','',0,'http://www.groparu.ro/?p=968',0,'post','',7),(969,1,'2008-01-27 23:36:25','2008-01-27 21:36:25','<a href=\"http://life.hotnews.ro/stiri-prin_oras-2236211-alegeti_mascota_bucurestiului_leul_gargarita_acvila_fluturele_sau_porumbelul_alb.htm\" target=\"_blank\">Bucurestiul</a> s-a hotarat sa isi faca mascota. Posibilele mirese la mascota sunt:\r\n\r\n- gÄƒrgÄƒriÅ£a - deci nu gÃ¢ngania aia care se face Ã®n fÄƒina de cucuruz din cÄƒmarÄƒ, ci Bubamara aia careia noi ii mai spunem Vaca (Domnului) sau mÄƒmÄƒruÅ£a (nu e neam cu MÄƒruÅ£Äƒ, cÄƒ m-am interesat);\r\n\r\n- acvila - un soi de animal cu pene care naÅŸte un pui pe an, ÅŸi ÅŸi Äƒla iese din ou, vai ÅŸ-amar;\r\n\r\n- fluturele - ar merge fluturele de varzÄƒ muratÄƒ, ioz fan, mai ales dimineaÅ£a;\r\n\r\n- porumbelul alb - cea mai gay pasÄƒre;\r\n\r\n- leul - animalu Äƒla care doarme 20 de ore pe zi, de parc-ar fi senator PSD de BuzÄƒu.\r\n\r\nPropunerile mele de mascotÄƒ ÅŸi de slogan:\r\n\r\n1. Investitorul japonezul cu maidanez bine infipt in artera femuralÄƒ - slogan \"Romanian dogs finishing what Guadalcanal didn\'t\".\r\n\r\n2. Autobuzul RATB ticsit, mascotÄƒ care sÄƒ ÅŸi emane mirosuri - \"Survive any bus and you can defeat AIDS!\"\r\n\r\n3. O figurina fÄƒrÄƒ cap, cu inscripÅ£ia: \"Indiferent cÃ¢t de prost e candidatul, cÃ¢tÄƒ vreme nu e PSD-ist, noi Ã®l vom vota ca primar!\"\r\n\r\n4. Un portofel gol - \"Noi, ÅŸuÅ£ii de pe autobuzul 221, vÄƒ mulÅ£umin cÄƒ nu v-aÅ£i cheltuit toÅ£i banii Ã®n oraÅŸul nostru!\"\r\n\r\n5. O pisica moartÄƒ, viermuindÄƒ - \"9 lives, my ass!!!\" (se pronuntza \"laivz\")\r\n\r\n6. Un Å£Ã¢nÅ£ar slÄƒbÄƒnog ÅŸi leÅŸinat de foame: - \"BucureÅŸtiul: 3 milioane de locuitori, 300 milioane de vise, 30.000 miliarde de Å£Ã¢nÅ£ari\"\r\n\r\n7. Un termometru care sÄƒ indice 68 grade Celsius Ã®n luna mai - \"Get a glimpse of how hot hell is!\"\r\n\r\n8. Un mic ÅŸobolan simpatic, denumit Rat-a-couille.\r\n\r\n9. O bordurÄƒ cu piÅŸu de cuÅ£u pe ea: \"Come to Bucharest to cure yourself from animal love!\"\r\n\r\n10. O bibliotecÄƒ cu almanahe.\r\n\r\nBonus:\r\n\r\n11. Un copil al stÄƒzii, cu menÅ£iunea \"Special holiday package for Belgian, Brits, Nordics and catholic priests\".','Se cauta mascota Bucurestiului',0,'','publish','open','open','','se-cauta-mascota-bucurestiului','','','2008-01-30 23:11:22','2008-01-30 21:11:22','',0,'http://www.groparu.ro/?p=969',0,'post','',22),(970,1,'2008-01-25 09:57:51','2008-01-25 07:57:51','Finca nu am avut nici un pic de chef!\r\n\r\nVa jur, am umblat cu limba prin gura, unde tot timpu gasesc cate ceva (gen dinti si urme din cina de alaltaieri), am scormonit in fundu\' buzunarului (acolo zace tot mereu un praf gen zahar), am cautat in buric (unde nu mai aveam nici macar scama regulamentara) si intre destele de la picioare (io, cum port ciorapi gri, de regula, fosti albi, tot timpu\' adun intre destele de la picioare neste scame foarte bizare, de zici ca le-o pictat Dali); in ureche era curat, matreatza parcÄƒ o plecat in Spania sa se prostitueze, frecÄƒÅ£eii de pe gÃ¢t lipseau la apel, gÄƒlbeaÅ£a de pe chiloÅ£i emigrase in Canada, chiar si nelipsiÅ£ii floci din cadÄƒ plecaserÄƒ Ã®n gaÅŸcÄƒ cine stie pe la ce chef.\r\n\r\nAm sperat ca mÄƒcar mirosul meu sÄƒ mÄƒ inspire; dar, dupÄƒ cum zicea Suskind, nu Ã®Å£i poÅ£i simÅ£i propriul miros, ÅŸi io-s convins cÄƒ ÅŸi dacÄƒ mi l-aÅŸ simÅ£i m-as Ã®ngreÅ£oÅŸa instant. PÃ¢nÄƒ ÅŸi autobuzul a fost populat decent, ÅŸi Ã®n afarÄƒ cÄƒ o venit un controlor pe care-l chema FarcaÅŸ ÅŸi era sa-l Ã®ntreb \"BÄƒ, unde-i Ioan???\", chiar nu am nici un subiect, predicat sau verb copulativ demn de a-l imortaliza in gropÄƒrie!\r\n\r\nDar ca sa nu incepeti sa credeti ca pe acest site nu se mai injura, iaca: PULÄ‚.','De ce pe azi nu am scris nici o postare',0,'','publish','open','open','','de-ce-pe-azi-nu-am-scris-nici-o-postare','','','2008-01-25 09:57:51','2008-01-25 07:57:51','',0,'http://www.groparu.ro/?p=970',0,'post','',15),(971,1,'2008-01-28 21:49:32','2008-01-28 19:49:32','Privire retrospectiva inapoi:\r\n\r\nSunt unele momente in viatza cand ti se mai iveste, asa, printre multe suturi loate de un cur mult prea sensibil la chestii care nu aduc nici pe departe a atingeri de domnisoara, cate o mica satisfactie profesionala. Asa e cazul cand am aflat ca ditamai <a href=\"http://www.ciutacu.ro/\" target=\"_blank\">Ciutacu</a> ma ceteste cand are vreme, ba te mai si baga, scuzati-mi expresia, in blogroll, asijderea ditamai <a href=\"http://www.mana.ciutacu.ro/\" target=\"_blank\">nevasta-sa</a> si <a href=\"http://www.andreicrivat.ro\" target=\"_blank\">finu-so</a>; cand <a href=\"http://www.visurat.ro\" target=\"_blank\">VisUrat</a> iti ia Y!Mterviu dupa ce castigi (pe drept!) titlul de cel mai naspa blogger clujean; cand te suna de la banca Usim si zice \"Bueeeey, io te stiu pe tine cÄƒ te-am citit pe net, tu esti tantalau\' ala care uita sa isi scoata banii din bancomat, toata banca noastra te stie!\"; cand te mai baga in blogroll ceva <a href=\"http://milecarpenisan.wordpress.com\" target=\"_blank\">reporteri speciali de pe la Antene</a> care si risca sa isi petreaca Revelioanele cu tine, <a href=\"http://mihaiursu.wordpress.com/\" target=\"_blank\">Primeteveuri</a>, <a href=\"http://alseresblog.romblog.ro/\" target=\"_blank\">redactori ÅŸÄƒfi de ziare regionale</a> sau DJ la <a href=\"http://doruoprisan.blogspot.com/\" target=\"_blank\">EuropaFM</a>; creca am avut si un rol hotarator in a-l face pe <a href=\"http://baghy.info/\" target=\"_blank\">Baghy</a> sa se apuce de bloggerit, din cate tiu io minte, si creca ar mai fi ocazii d-astea de mentionat care nu-mi vin acuma in minte, cand te simti bine sa fii in pielea ta, finca vezi pe cate un meseriash d-asta care nu te cunoaste numa\' de pe net si simte nevoia sa vorbeasca cu tine, sa-tz zica vreo doo, mai bune, mai nebune - in general, chestii de bun simptz.\r\n\r\nNo.\r\n\r\nCam asa ceva am patit zilele astea, cand aflu ca Julius Constantinescu (<a href=\"http://www.google.com\" target=\"_blank\">gugaliti-l</a>!), pe care-l cetesc cu sfintenie de cand era la Ziarul (si un scriitor cum eu poci decat a spera sa ajung), se simte dator, in numele simtului estetic, sa preieie niscai text pe care l-am clocit prin propriile mele flotari, si sa-l publice in <a href=\"http://www.7plus.ro/?arhiva=28/01/2008&amp;id=1485\" target=\"_blank\">sectiunea zilnica a dÃ¢nsului</a>.\r\n\r\nM-am simtit magulit. Pot sa ma simt si eu magulit uneori? Pentru ca daca da, am sa va spun ce i-am facut la medicu\' de familie care o vint sa ma vindece de viroza care ma tintuieste la pat, nemiloasa, de 2 zile.','Am intalnit si bloggeri fericiti',0,'','publish','open','open','','am-intalnit-si-bloggeri-fericiti','','','2008-01-28 21:55:44','2008-01-28 19:55:44','',0,'http://www.groparu.ro/?p=971',0,'post','',20),(972,1,'2008-01-31 01:14:05','2008-01-30 23:14:05','Deci sambata numa\' am lenevit, si seara am iesit la mall, finca o cÃ¢ntat Stratan, ÅŸi io de multa vreme i-am promis lu\' Stratan ca ii dau in gura, finca ma enerveaza la culme cand vad oameni care mie mi-s mai superiori, si am zis ca acum am ocazia.\r\n\r\nNu am avut-o, fincÄƒ nu o cÃ¢ntat la bisuri, ÅŸi strategia mea pe asta se baza. Da\' am observat ca nu mai e nici el ce-a fost, finca mai nou canta si piesele lu\' fie-sa, Cleopatra parca o cheama, care mi se par un pic piese de gradinitza, si eu nu dau in copii, decat daca e auto-aparare.\r\n\r\nÃŽn schimb, la <em>mol</em> m-am procopsit cu o dragutza de viroza respiratorie care ma tine legat de pat de parca ar fi o gajica d-aia kinky in lenjerie ieftinÄƒ ecologicÄƒ de cauciuc de Danubiana.\r\n\r\nÅži mi-am sunat cei treizeci de ÅŸÄƒfi care trebuie Ã®nÅŸtiinÅ£aÅ£i Ã®n caz ca Ã®Å£i permiÅ£i sÄƒ te Ã®mbolnÄƒveÅŸti (de ce cand le zic ca imi trebe medical imi zic toti \"Iar ai beut ca porcu\', hihihi!!!\"); ÅŸi mi-am sunat ÅŸi vraciu de famelie, care imi e mie medic de famelie, deÅŸi io nu am famelie. Åži ii zic: BÄƒ, nene, zic, ioz Groparu, ÅŸi-s cam rÄƒcit, ia auzi numa cum tuÅŸesc! Åži Ã®i trag o rafala de tuse ca o artilerie de Verdun d-aia cu scuipaturi sonore rÃ¢cÃ¢ite de pe fundul gÃ¢Å£ilor, cÄƒ am ÅŸi crezut cÄƒ se paraziteazÄƒ tot Oringiu de la fojgÄƒituri. Amu cÄƒ ai aflat ce motor diesel am Ã®n gÃ¢Å£i, bÄƒ Doc, ia porneÅŸte matale un concediu medical pe numele meu, ÅŸi zi-mi ÅŸi mie ce medicamente sÄƒ-mi ieu, cÄƒ n-aÅŸ muri chiar acuma, ma-ntelegi!\r\n\r\nDin momentul Äƒla m-am hotarÃ¢t sÄƒ il schimb pe doctor, deÅŸi nu fÄƒcuse pe el; fincÄƒ Ã®mi gÃ¢jÃ¢ie \"Dooooomnu Gropaaaaruuuu,\" (da\' un ton la care i-aÅŸ spune, aÅŸa, <em>peiorativ</em>), zice,  \"unde aÅ£i pomenit dumneavoastrÄƒ aÅŸa ceva? Aici nu se dau concedii medicale prin telefon! trebuie sa va prezentati la mine sa va consult!\"\r\n\r\nBuricu\' matii aleia care nu-i o doamna, zic in gandu-mi; \"Dom\' doctor\", zic io, ripostand cu o rafala de tuse de parca eram Trabant, \"io nu viu amu la consultare transpirat si cu febre pe vÃ¢ntu asta! E iarna, ce pana mea, nu vedetz ca in toata emisfera nordica e luna ianuarie?\" \"Domnu Groparu, zice iel, la mine vin si oameni cu pneumonii pe vanturile astea!\" \"Nu, zic, io nu vin; stiu ca faceti si vizite la domiciliu, si va convoc!\" \"Cum sa nu, zice el, va costa 30 lei!\" \"Primiti euro?\" intreb (stiam ca nu mai am lei decat pe card, da\' aveam ceva marunti de euro, in monede). \"Primim! zice. Termin programul si vin sa va vad.\"\r\n\r\nMuri-ti-ar la intrare, zic io, no hai!\r\n\r\nSi pregatesc TarafTV sa il dau la maxim cand intra nenea doftoru, scot eurutzii si fac o piramidutza cu monezile, arinjez un pic prin casa ca sa para ca dupa o noapte nebuna de sex cu fetele de la un internat catolic, eventual si cu doo perechi de chiloti de-ai mei pe perna, am foarte mare grija sa nu ma spal pe dinti si nici sa fac greseala sa il rog sa nu se descalte, finca trebe sa se descalte: la mine in casa toti care intra se descalta (stiu, is naspa, mi s-o mai spus).\r\n\r\nSi vine doftoru; nici macar nu schiteaza gestul de a se descalta, intra inauntru, io tusesc inspre el fara sa pun mana la gura, el ce sa faca, ofteaza, sireacu, intra inauntru, si ma consulta. Dupe aia imi zice ce sa iau, si incepe sa se disculpe:\r\n\r\n- Stiti, intelegeti ca nu pot da prin telefon concedii medicale.\r\n- Nu, zic io, nu inteleg. In orice tara europeana, daca suni la doftor ca esti rupt in gura de mahmur sau de gripat, doftoru te crede!\r\n- Da, zice, dar am pacienti care ma minte. NU ZIC DE DVS, DOAMNE FERESTE!!!\r\n- Bun, zic io. Io am vreo 3-4 joburi la ora actuala, pentru ca asa e filmu. Si pentru mine fiecare zi d-asta de stat cu coaiele la tavan inseamna bani pierduti. <strong>EU</strong> nu am nici un interes sa obtin medicale cand am inceput anul 2008 cu vreo 7 zile de concediu neluate din 2007. Si mai stiti ca io si azi vara, cand erau 38 de grade la umbra, am racit, ca asa e la moda cu geniile, sa stea prost cu racelile; si va mai zic ceva. Io am si rate, o groaza. Deci io nu prea-mi permit sa fiu bolnav. Luati va rog astia 10 euro (si flutur monezile), vi-i dau la cursul de 3.75 lei/euro, fara comision.\r\n- Nuuuuuu, zice el, lasati... imi aduceti lei la cabinet cand veniti dupa concediu medical... sanataaaate!!!\r\n\r\nGura matii, Caragiale, mi-am zis, ca daca nu scriai tu inainte, as fi scris io o nuvela cu bagat dulceatza in sosoni la antipatici, ca d-aia nu se mai descaltza! Da\' nu-i stress, ca cand ii duc aia 30 lei pentru consultatie il pun sa-mi taie chitantza, o sa-i zic ca mi-o deconteaza statu\' la impozitu\' global.\r\n\r\nPS: daca va intereseaza si care ie vraciu, cautati ce doftor are cabinetu pe Calea Manastur. No - ala-i!','Despre vraci',0,'','publish','open','open','','despre-vraci','','','2008-01-31 02:37:30','2008-01-31 00:37:30','',0,'http://www.groparu.ro/?p=972',0,'post','',18),(973,1,'2008-01-31 15:26:59','2008-01-31 13:26:59','O uriasa cantitate de alcool, droguri si tutun a fost capturata si transportata de politia din Los Angeles cu o atenÅ£ie demna de un presedinte: o gaÅŸcÄƒ de motociclete, douÄƒ maÅŸini de poliÅ£ie ÅŸi douÄƒ elicoptere.\r\n\r\nBine-nÅ£eles, cantitatea aceasta uriasa de alcool, droguri si tutun se afla, normal, <a href=\"http://omg.yahoo.com/spears-taken-from-home-in-ambulance/news/6110\" target=\"_blank\">in trupul lui Britney Spears</a>.\r\n\r\n<strong>Update</strong>: De ce nu e bine sa moara Britney Spears? Pentru ca PIB-ul unor tari ca Afganistan si Columbia ar scadea la 10%! (da, stiu, sunt rau, meschin, invidios, daâ€™ macar nu lucrez cu ingineri! Fuck, de fapt chiar lucrez cu ingineri. Imi cer scuze).\r\n<p class=\"entry\">&nbsp;</p>','Uriasa captura de alcool, droguri si tutun',0,'','publish','open','open','','breaking-news-despre-alcool-droguri-tutun','','','2008-02-01 06:08:06','2008-02-01 04:08:06','',0,'http://www.groparu.ro/?p=973',0,'post','',8),(974,1,'2008-02-03 20:29:34','2008-02-03 18:29:34','- \"Dar-ar bunu\' Dumnezau sÄƒ-i creascÄƒ puÅ£ulicÄƒ lu\' nevasta-ta!\" (unui mascul).\r\n\r\n- \"Nu am sa iti mai raspund. Stiu ca tatal tau te Ã®nhÄƒma la cÄƒruÅ£Äƒ cÃ¢nd erai copil.\"\r\n\r\n- \"Imi pare bine ca am cunoscut omul despre care ziarele scriau ca Ã®i Ã®ncape creierul Ã®n gleznÄƒ!\"\r\n\r\n- \"Draga mea, imi pute gura de la limba aia pe care ti-am tras-o?\" (prietenei)\r\n\r\n- \"Pui de... de fapt, iarta-ma, nu am cunoscut-o pe mÄƒ-ta ca sa imi dau cu parerea!\" (dintr-un film western)\r\n\r\n- \"Pot sa iti spun Paul Newman in timp ce facem dragoste?\" \"De ce, pentru ca seman cu el?\" \"Nu, pentru ca esti la fel de batran ca si el!\" (zisa de orice gajica prekinului ei)','Diverse insulte pentru ocazii speciale si persoane cu nevoi speciale',0,'','publish','open','open','','diverse-insulte-pentru-ocazii-speciale-si-persoane-cu-nevoi-speciale','','','2008-02-03 20:29:34','2008-02-03 18:29:34','',0,'http://www.groparu.ro/?p=974',0,'post','',2),(976,1,'2008-02-01 13:15:25','2008-02-01 11:15:25','Inspirat de <a href=\"http://rottencabbage.haipa.ro/2008/01/28/phile-de-phoveste/#comment-388\" target=\"_blank\">Varzaru</a>, care acuma e cam australopitec, vreu si eu sa abordesc probematica dihotomica a adolescentei versus maturitate.\r\n\r\n<strong>In adolescenta,</strong> daca ma uitam la gajici pe troleu si le faceam cu ochiu, chicoteau ca proastele, si eu ma simteam Tarzan.\r\n<strong>Acum,</strong> daca fac cu ochiu la o ghajica in troleu, se ridica si-mi cedeaza locu\'.\r\n\r\n<strong>In adolescenta,</strong> daca beam la scoala, eram haiduc (asa am patit la majorat, oai ce postare o sa iasa cand a hi vremea!!!)\r\n<strong>Acum,</strong> daca beau la serviciu mai mult de 4 ori, mi se spune ca sunt patetic, si ca sa nu-mi mai pun colegele sa se sarute unele cu altele ca ma zic la shafu. Ala mare. Mare-mare!\r\n\r\n<strong>In adolescenta,</strong> daca imi bateam un coleg, eram cool, si le dadeam autografe colegilor pe sÃ¢ni. Uneori ÅŸi colegelor.\r\n<strong>Acum,</strong> daca imi bat un coleg, vine cu mama-sa la firmÄƒ, mÄƒ scoate la careu ÅŸi mÄƒ pune sÄƒ-mi cer scuze public.\r\n\r\n<strong>In adolescenta,</strong> daca intram la fete la buda pentru un pipi si ce mai gaseam pe acolo de facut cu putulica, eram eroul grupei mari.\r\n<strong>Acum,</strong> s-ar putea sa nu mai reusesc sa scap cu viaÅ£Äƒ din toaletÄƒ (da, too much sex can kill you!)\r\n\r\n:|','Adolescenta versus maturitate',0,'','publish','open','open','','adolescenta-versus-maturitate','','','2008-02-01 13:15:25','2008-02-01 11:15:25','',0,'http://www.groparu.ro/?p=976',0,'post','',24),(977,1,'2008-02-04 12:21:23','2008-02-04 10:21:23','\r\n<p class=\"MsoNormal\"><font color=\"black\" face=\"Arial\" size=\"2\"><span style=\"font-size: 10pt; color: black; font-family: Arial\">Legile lui Murphy , comentate de Groparu: </span></font></p>\r\n\r\n<p class=\"MsoNormal\"><font color=\"black\" face=\"Arial\" size=\"2\"><span style=\"font-size: 10pt; color: black; font-family: Arial\">* Cand se sting luminile, toate femeile sunt frumoase - dar mirosul de peste e acelasi.\r\n</span></font>\r\n\r\n<p class=\"MsoNormal\"><font color=\"black\" face=\"Arial\" size=\"2\"><span style=\"font-size: 10pt; color: black; font-family: Arial\">* Virginitatea  se poate vindeca - se poate chiar recastiga!\r\n</span></font>\r\n<p class=\"MsoNormal\"><font color=\"black\" face=\"Arial\" size=\"2\"><span style=\"font-size: 10pt; color: black; font-family: Arial\">* Calitatile pe care o femeie le pretuieste cel mai mult la un  barbat, sunt, de regula, aceleasi pe care nu le mai poate suferi dupa cativa  ani - toata viatza mea am fost persecutat pentru putulica mea!  </span></font></p>\r\n\r\n<p class=\"MsoNormal\"><font color=\"black\" face=\"Arial\" size=\"2\"><span style=\"font-size: 10pt; color: black; font-family: Arial\">* Inainte de a-l gasi pe Fat-Frumos, trebuie sa saruti o multime de  broscoi - fetelor, pupa-mi-ati mormolocu\'!\r\n</span></font>\r\n\r\n<p class=\"MsoNormal\"><font color=\"black\" face=\"Arial\" size=\"2\"><span style=\"font-size: 10pt; color: black; font-family: Arial\">* Dragostea e o problema de chimie, sexul o problema de fizica - ete, na! Amandoo is poezie clara, daca nu stiati.\r\n</span></font>\r\n\r\n<p class=\"MsoNormal\"><font color=\"black\" face=\"Arial\" size=\"2\"><span style=\"font-size: 10pt; color: black; font-family: Arial\">*  Iubeste-ti aproapele, dar fii atenta sa nu fii prinsa - ca poate ieÅŸi un threesome din ala cu pereti zgariati si mascul internat la urgente!\r\n</span></font>\r\n\r\n<p class=\"MsoNormal\"><font color=\"black\" face=\"Arial\" size=\"2\"><span style=\"font-size: 10pt; color: black; font-family: Arial\">* Sa nu ravnesti la femeia  altuia decat daca ai chef - da\' la femeia alteia se pune?\r\n</span></font>\r\n<p class=\"MsoNormal\"><font color=\"black\" face=\"Arial\" size=\"2\"><span style=\"font-size: 10pt; color: black; font-family: Arial\">* Abtine-te de la vin, cantec si femei; in special de  la cantec - pentru ca oricum din vinul combinat cu femei rezulta o adevarata simfonie; </span></font></p>\r\n<p class=\"MsoNormal\"><font color=\"black\" face=\"Arial\" size=\"2\"><span style=\"font-size: 10pt; color: black; font-family: Arial\">* Barbatul poate fi fericit cu orice femeie, atata timp cat n-o  iubeste - si atata timp cat femeia se carÄƒ acasÄƒ la 12 secunde dupa ce masculu\' o facut sex cu ea; </span></font></p>\r\n<p class=\"MsoNormal\" style=\"margin-top: 7.5pt\"><font color=\"black\" face=\"Arial\" size=\"2\"><span style=\"font-size: 10pt; color: black; font-family: Arial\">* Dragostea este iluzia ca o femeie e diferita fata de  celelalte - femeile chiar <strong>sunt</strong> diferite unele de altele, mai ales daca inainte au fost barbati!  </span></font></p>','Murphy vs Groparu despre viata, sex, sex, sex',0,'','publish','open','open','','murphy-vs-groparu-despre-viata-sex-sex-sex','','','2008-02-04 15:41:56','2008-02-04 13:41:56','',0,'http://www.groparu.ro/?p=977',0,'post','',31),(978,1,'2008-02-04 20:49:02','2008-02-04 18:49:02','Ba romÃ¢nilor! Pe voi nu vÄƒ doare <a href=\"http://www.hotnews.ro/stiri-esential-2286216-parchetul_general_ludovic_orban_fost_gasit_nevinovat_cazul_accidentului_din_decembrie_desi_acrosat_minora.htm\" target=\"_blank\">puÅ£ulica asta pe care ne-o tras-o Orban</a> acolo, la fundulicÄƒ? Pai daca o zgÃ¢riet o maÅŸina ÅŸi o trÃ¢ntit o pruncÄƒ pe azfalt ÅŸi s-o cÄƒrÄƒbÄƒnit de la locu\' accidentului, de ce s-o dispus NUP?\r\n\r\nSÄƒ fie oare din cauza ca e ministru?\r\n\r\nUpdate: A, posterioritatea ar face bine sa nu uite contributia adusa de <a href=\"http://gramo.ro/2008/02/04/ne-am-luat-o-piatra-de-pe-inima/\" target=\"_blank\">famelia saitului Gramo</a>! Pentru ca ei furÄƒ, ca sÄƒ zic aÅŸa, Ã®n clitorisu\' evenimentelor Ã®ncÄƒ de la declanÅŸare.','Dragi romÃ¢ni,',0,'','publish','open','open','','dragi-romani','','\nhttp://gramo.ro/2008/02/04/ne-am-luat-o-piatra-de-pe-inima/','2008-02-04 21:55:39','2008-02-04 19:55:39','',0,'http://www.groparu.ro/?p=978',0,'post','',18),(979,1,'2008-02-05 09:31:18','2008-02-05 07:31:18','Domnul Bruni, cunoscut Ã®n unele cercuri exclusiviste ca dl. Sarkozy, a declarat, extaziat de presedintele nostru chel, mic, rÄƒÅ£oit ÅŸi comandant de plutÄƒ, cÄƒ <a href=\"http://www.evz.ro/articole/detalii-articol/393482/Nicolas-Sarkozy-Franta-nu-va-trada-niciodata-Romania/\" target=\"_blank\">FranÅ£a nu va trÄƒda niciodatÄƒ RomÃ¢nia</a>.\r\n\r\nÃŽl invit pe dl. Sarko sÄƒ Ã®ÅŸi menÅ£inÄƒ declaraÅ£iile ÅŸi dacÄƒ prin peluza de la Casa AlbÄƒ francezÄƒ cÃ¢teva tancuri T-90-S ruseÅŸti se joaca de-a vaÅ£ascunselea cu niscai LeClercuri mai timide, iar pe cerul Hexagonului un grup de Suhoiuri bete violeazÄƒ, Ã®n gaÅŸcÄƒ, Mirage-urile, ba mai mult, le mai si zic \"Davai ceas, davai palton!\"\r\n\r\nPS: Aceasta postare, dupa cum va puteti da cu usurinta seama, se refera la <em>toys for the boys</em>, asa ca invit fetele care nu intelege nimicÂ  (da\' nimic!) din ce am scris sa nu se simta frustrate ca mine cand se vorbeste engleza in juru\' meu si io nu pricep un iot!','Ce-a declarat Dl. Bruni',0,'','publish','open','open','','ce-a-declarat-dl-bruni','','','2008-02-05 09:31:18','2008-02-05 07:31:18','',0,'http://www.groparu.ro/?p=979',0,'post','',11),(980,1,'2008-02-05 20:59:53','2008-02-05 18:59:53','Ei, uite d-aia am io blog.\r\n\r\nCa sa rÃ¢dÄƒ toti de cat de mult isi bate D-zeu joc de mine, io, of cos, nevinovat ca un herufim sau seravim, nu mai stiu. Of cos. Si io, dacÄƒ rÃ¢de cetitorii, sÄƒ mÄƒ simt special, Ã®n loc sÄƒ mÄƒ simt cÄƒ aÅŸ avea <em>nevoi speciale</em>, ceea ce e cu totul altÄƒ papa de peÅŸte.\r\n\r\nDeci io fusai bolnav rupt, da? Si doftoru veni la mine sa ma caute, si mi-o dat concediu. Medical.\r\n\r\nIo - am zis tot timpu asta - sunt un nesimtit, finca - iaca - m-am imbolnavit si io ca tÄƒntÄƒlÄƒu\' tocma\' cÃ¢nd se termina luna. Asta inseamna ca daca am stat si vinerea acasica, infofolit in ceaiuri si hapuri, si vinerea era alta lunÄƒ,  recte fevroarie, mie trebuia sÄƒ mi se facÄƒ ALT concediu medical, pe CEALALTA lunÄƒ. Voi ÅŸtiaÅ£i asta? E, eu nu ÅŸtiam asta.\r\n\r\nAÅŸa cÄƒ vinerea, ultima zi Ã®n care am stat acasÄƒ ÅŸi care AR FI TREBUIT SÄ‚ FIE ACOPERITÄ‚ DE CONCEDIUL MEDICAL DE LA NENEA DOFTORU, mi se va lua din concediul de odihna. Pentru ca eu am fost suficient de nesimtit sa nu ii zic doftorului ca si vineri stau si suflu muci in cearceafe, ca domnia sa sÄƒ faca bine sÄƒ imi inceapa alta foaie de concediu, pe cealalta luna.\r\n\r\nDeci eu pierd acuma o zi de concediu de odihna pe chestia asta.\r\n\r\nAs dori sa le urez MUIE sistemului de sanatate din Romania, sistemului romanesc de invatamant care accepta sa scoleasca orice scursura din care iasa ditamai doftoru sau profesoru\' (cand zic \"profesor\" ma uit in oglinda, of cos!) care te scoate pe tine vinovat ca nu ti-o zis ce si cum trebe cerut un concediu medical, ministrului de sanatate, si in primul rand celor care conditioneaza actul medical de primirea unei spagi? Da, mai ales astora din urma.\r\n\r\nSi ca sa fie cireasa de pe tort cireasa, nu viÅŸinÄƒ, mÄƒ sunÄƒ mama: Vaaai, Groparu, sÄƒ vezi ce oale frumoase ÅŸi originale 100% nemÅ£eÅŸti am cumpÄƒrat de la un tigan din piaÅ£Äƒ, scrie pe ele <em>Å¢eptÄƒr</em>, ÅŸi au eticheta Metro Tg MureÅŸ, la numai 160 EUR! Ä‚stea costÄƒ cel puÅ£in 1000 EUR Ã®n Germania...\r\n\r\nPS: Ca sÄƒ aflaÅ£i ÅŸi voi cum stÄƒ lucrurile, in ianuarie m-am despÄƒrÅ£it de gajicÄƒ-mea, tot in ianuarie am pierdut vreo 3.000 euro la bursÄƒ (acolo mi-am bÄƒgat Ã®mprumutul cu banii de maÅŸinÄƒ), saptamana viitoare vine naÅŸe-mea la Cluj si sta o saptamana la mine acasa (cÃ¢nd auziÅ£i cÄƒ vin oameni la Cluj, aflati ca vin la oncologie, ÅŸi asta fincÄƒ e cam groasÄƒ tumora), vreau sa fumez non-stop, si nu pot, finca oficial am renuntat, astazi HVB PULE MATURI Tiriac UniCredit or marit comisionul de administrare la sold cu 150% (MUUUUIEEEE!!!!!), ceea ce mi-o marit una din cele 4 rate ale mele destul de urat, euro creste, si io am rate in euro, am de lucru la serviciu de behai, toti sefii sunt, ca de obicei, in CURU\' meu (colegii stie de ce), si mie inca nu mi-o trecut raceala, masina de spalat la care mai am o rata lasa hainele imputite, si ai mei, care sunt fericitii proaspeÅ£i posesori ai unui Opel Corsa luate din Doici ieri, ma roaga sa le dau Äƒia 4000 lei pe care mi i-o imprumutat cand mi-am renovat cotetzu\' Ã®n care locuiesc, fincÄƒ tocmai ÅŸi-or cumpÄƒrat un set de oale <em>Å¢eptÄƒr</em> din pensie ÅŸi or cam rÄƒmas fÄƒrÄƒ bÄƒnuÅ£i. Nu va mai zic ce gaura am pe cardul de credit, numai atata vreau sa urlu: DOAMNEEEE, CE URMEAZÄ‚???','BLESTEMEEEE!!!',0,'','publish','open','open','','blestemeeee','','','2008-02-05 22:42:56','2008-02-05 20:42:56','',0,'http://www.groparu.ro/?p=980',0,'post','',40),(981,1,'2008-02-06 20:02:19','2008-02-06 18:02:19','1. Cine-o murit in supa asta???\r\n\r\n2. Mai fatÄƒ, angajez gajici pentru videochat. Te intereseaza? (si te uiti prelung la bucile ei, dupÄƒ care te uiÅ£i Ã®n jur) Daca poti lucra intr-un local ca asta, poti lucra oriunde!!!\r\n\r\n3. Te rog frumos sa o lasi pe colega ta sa imi scuipe in supa, ea arata mai bine.\r\n\r\n4. Auzi, friptura asta parca are gust de chelner! V-ati gatit de curand vreun angajat???\r\n\r\n5. Sper cÄƒ musculita asta din supa nu e paduche lat.\r\n\r\n6. Ce te costa daca-mi zambesti cand imi pui felul doi pe masa???\r\n\r\n7. La voi in local e voie sa pijti chelneritele de fund?\r\n\r\n8. Domnisoara, uite-te si tu la parul asta negru si cretz din farfurie, si zi-mi cÄƒ mÄƒcar l-aÅ£i fiert Ã®nainte!\r\n\r\n9. Te rog frumos, versi supa asta care o ramas pe tricoul tau si te freci cu taiÅ£eii peste Å£Ã¢Å£e???\r\n\r\n10. Nu ti-am mai lasat bacsis! Profesorii castiga mult mai putin ca tine, si ei au scoala, nu ca tine.\r\n\r\nBonus:\r\n\r\n11. Io cred cÄƒ zahÄƒru Äƒsta de la cafea e de fapt mÄƒtreaÅ£Äƒ! CÄƒ nu Ã®ndulceÅŸte deloc.','Top 10 chestii care nu se zic niciodata unei chelnerite',0,'','publish','open','open','','top-10-chestii-care-nu-se-zic-niciodata-unei-chelnerite','','','2008-02-06 20:02:35','2008-02-06 18:02:35','',0,'http://www.groparu.ro/?p=981',0,'post','',10),(982,1,'2008-02-07 16:35:38','2008-02-07 14:35:38','Desi inauntru era mai bine decat afara,\r\nSa stii ca tata nu e un pierde-vara,\r\nDesi m-am intalnit cu el aseara\r\nIn magazine cand lucruri cumpara\r\nSa le duca pentru fiica sa!\r\nFiica sa, care esti tu\r\nNascuta dintr-un botz de lut\r\nO iconita pictata de mamitica ta!\r\nCu-o mica raza de soare ti-a nascocit faptura,\r\nSa fii cuminte si desteapta si frumoasa,\r\nSa nu te lovesti cand fugi prin a parintilor casÄƒ,\r\nSa ai parte numai de bucurie\r\nSi de succese, pe zi cÃ¢te-o mie,\r\nSa-ti traiasca fratiorul si parintii\r\nSa nu te doara cand iti cresc dintii,\r\nSa nu iei 4 pe la scoala\r\nSa faci pipi numa-n oalÄƒ,\r\nSÄƒ ai parte de noroc\r\nSa-nfloresti ca un boboc\r\nSa nu te mariti cu vreun dobitoc,\r\nSi sa traiesti multi, multi ani\r\nSi sa nu te speteÅŸti muncind pentru bani! (cum facem noi)','De ziua Hanei, care e fata lu Sampalica, si care s-o nascut ieri; ea, nu Sampalica, finca Sampalica ii tac-su!',0,'','publish','open','open','','de-ziua-hanei-care-e-fata-lu-sampalica-si-care-s-o-nascut-ieri-ea-nu-sampalica-finca-sampalica-ii-tac-su','','','2008-02-07 20:21:36','2008-02-07 18:21:36','',0,'http://www.groparu.ro/?p=982',0,'post','',1),(983,1,'2008-02-07 18:35:02','2008-02-07 16:35:02','Deci <a href=\"http://www.gardianul.ro/2008/02/07/linia_fierbinte-c5/la_cluj_un_politist_de_la_rutiera_a_fost_prins_la_furat_chiloti_tanga_si_prezervative-s108707.html\" target=\"_blank\">un poliÅ£ai romÃ¢n o fost prins furÃ¢nd tÄƒngi ÅŸi prezervative</a>. Aci, la Cluuuuuj.\r\n\r\nDe aici trajem urmatoarele potentiale concluzii:\r\n\r\n1. Politia romÃ¢nÄƒ nu prea are parte de femei cu chiloÅ£eii pe ele, si omu\' de supt chipiu pur si simplu nu o stiut ce-s Äƒia si de ce ie arestat de badigarzi;\r\n\r\n2. Omu vroia sa isi provoace o erectie mirosind chiloteii (fara sa stie ca <em>Äƒia purtati miros mai bine</em>)\r\n\r\n3. Omul vroia sa se masturbeze in conditii optime de igiena, d-aia o ales sa isi ia cu el prezervative, sa nu ia dreq vreo boala lumeasca, sa il rÃ¢zÄƒ colegii nesifilitici;\r\n\r\n4. Omul vroia sa promoveze in grad, si vroia sa se prinda pe el insusi in <em>flagrant</em>, sa isi faca raport si sa isi impresioneze shafii;\r\n\r\n5. Omu\' vroia sa isi faca o haina de blana, si in loc sa recolteze blanitza de femeie o recoltat ambalaju\', din greseala;\r\n\r\n6. Omu\' - ca orice alt angajat cu superiori - era curva sefilor, si o zis ca daca tot e futut, macar sa se imbrace ca o curvaÂ  si sa se protejeze;\r\n\r\n7. Omu vroia sa isi exploreze propria lui (homo)sexualitate imbrancandu-se in chilotei de dama, dar va ramane mereu cu tendinte homosexuale reprimate finca a fost prins;\r\n\r\n8. In Politia Romana e ca in Mafia: trebuie sa recurgi la gesturi cu adevarat disperate ca sa poti sa iesi!','Politia romÃ¢nÄƒ furÄƒ tÄƒngi',0,'','publish','open','open','','politia-romana-fura-tangi','','','2008-02-07 18:35:02','2008-02-07 16:35:02','',0,'http://www.groparu.ro/?p=983',0,'post','',12),(984,1,'2008-02-10 21:39:04','2008-02-10 19:39:04','Joshica, pentru cei care nu il cunoaste, ii destul de american. De regulÄƒ vine la mine acasa la Sibiu de Craciun si se imbata ca porcu\' si ma enerveaza, finca toti il trateaza cu palinci speciale pentru oaspeti speciali, si iel, sireacu, suflet slab, acceptÄƒ, pÃ¢nÄƒ cÃ¢nd ajunge acasa in trei labe, finca cu a patra incearca constant sa isi provoace eructatii.\r\n\r\nDeci Joshica, cand o venit in Romania sa isi inceapa afacerile lui de soft, o zis ca mai bine angajeaza romÃ¢naci, fincÄƒ la noi mÄƒcar nu vezi vaci pe stradÄƒ aÅŸa cum se vÄƒd Ã®n India (cealaltÄƒ opÅ£iune pentru outsourcing). Amu are si un bar in Cluj, <a href=\"http://www.legeneral.ro\" target=\"_blank\">Le General</a>, care cica o sa fie functional chiar de azi, de luni - saitu\', nu baru\', ca baru\' deja imbata lume de prin 1 Decemvrie anu\' trecut!\r\n\r\nÅži el, Joshica, cÃ¢nd o venit Ã®n RomÃ¢nia, o venit pentru primul client al sÄƒu, un nene american, iranian la origini. Da\' destul de <em>coios</em> nenea asta. Si pe JoshicÄƒ l-am cunoscut cÃ¢nd m-o chemat notÄƒriÅ£a cu care lucram, cÄƒ ii trebia traducator autorizat pe englezÄƒ pentru Josh, cÄƒ trebia ÅŸtampilÄƒ cum cÄƒ o Ã®nÅ£eles cu ce se mÄƒnÃ¢ncÄƒ actele.  Si de acolo pÃ¢nÄƒ la a ieÅŸi la karaoke in seara aia nu o mai fost decat un pas.\r\n\r\nIn saptamana aia, un prekin din Germania m-o rugat sa am grija de un italian de vreo 28 de anisori care venise la ceva conferinÅ£Äƒ Ã®n Cluj, sÄƒ-l scot la o bere, ca nu stie pe nimeni in Cluj, si s-o gandit ca io, cu moaca mea de alcolic, I know my ways around city night life. Beiatu asta italiean era genu meu, adica kefangiu si om de viatza si preacurvar, ca o si imbarligat trei studente in saptamana aia cat o stat in Cluj, si cu doo s-o si jucat de-a animalu cu doo spinari; asa ca am iesit cu italianu si cu Josh si gasca lui de proaspat angajati in DizÄƒl, ceva local de fiÅ£e. CÃ¢nd m-am Ã®ntÃ¢lnit cu ei, iranianu s-o uitat la mine prelung si fioros (se vedea pe iel cÄƒ era coios si ca ii ura pe toti neislamistii) si io ii intind mana:\r\n\r\n- Mikey, ii zic io, I heard you are always right double time!\r\n- What? zice el.\r\n- Well, because. Zic io.\r\n\r\nSi fac o paozÄƒ, strategicÄƒ. Io tot timpu\' am stiut cum sÄƒ vorbesc cu oamenii - in afara cazurilor, binenÅ£Äƒles, cÃ¢nd nu am ÅŸtiut.\r\n\r\n- You are Josh\'s customer, right?\r\n- Right, zice iel.\r\n- Which means you are always right: the customer is always right! (and the bartender never gets killed).\r\n- True, zice el.\r\n- Well, mai zic io, Josh is my customer, and you are my customer\'s customer: which means you are always right twice!\r\n\r\nO rÃ¢s, ce dreq sÄƒ facÄƒ?\r\n\r\nDa\' nu despre asta am vrut sa scriu, am vrut sa scriu despre faptu\' ca Mikey asta, <strong>intr-o singura zi</strong>, si-o dat demisia de la un job de manager super caldut si bine platit la o firma de corent electric, si-o inaintat actele sa isi faca si el o firma de electricitate, o inaintat actele pentru divort de nevasta-sa <strong>SI</strong> si-o cumparat o masina nou-nouÅ£Äƒ.\r\n\r\nToate in aceasi zi.\r\n\r\nAin\'t that <em>coios</em>, or what?\r\n\r\nDeci sÄƒ nu vÄƒ mai aud cÄƒ vÄƒ plÃ¢ngeÅ£i cÄƒ e luni dimineaÅ£a, aÅŸa cum fac io, de regulÄƒ, ÅŸi cÄƒ viaÅ£a vi se scurge ca apa la toaletÄƒ, Ã®nspre jos! Have a nice week, plm.\r\n\r\nPS: luni am sa ii scriu un raspuns lui <a href=\"http://oedip.blogspot.com/2008/02/deci-bh-groap.html\" target=\"_blank\">Oedip</a> (da\' nu ala cu ma-sa), ca noi asa ne-am hotarat, sa facem pe nebunii si sa ne certam  in blogosfera, ca sa avem motiv sa ne impacam mai des la berule.','Deci ce invidiez io la fostu\' client coios a lu\' Josh',0,'','publish','open','open','','deci-ce-invidiez-io-la-fostu-client-coios-a-lu-josh','','','2008-02-11 00:44:14','2008-02-10 22:44:14','',0,'http://www.groparu.ro/?p=984',0,'post','',26),(985,1,'2008-02-08 09:20:06','2008-02-08 07:20:06','Deci mie imi pare rau ca nu-s evreu, pentru ca daca eream, eream mult mai bogat ÅŸi ÅŸi mai dÄƒjtept, si daca cuiva nu ii convenea de mine (de exemplu, la shafi!), le ziceam din start ca is anti-semitisti si ca sa-mi deie despagubiri morale toate bonurile lor de masa, acum si in vecii vecilor, amin!\r\n\r\nDa\' imi mai pare rau de ceva: finca daca eream evreu, la cat noroc am io, as fi fost evreu pe vremea lu HiclÄƒr; ÅŸi dobitocu\' de fiurÄƒr m-ar fi facut sapun, si s-ar fi spalat cu mine pe cap! Da\' finca eram io in sapunu\' Äƒla, i-ar fi picat ÅŸi pÄƒru\', ÅŸi ÅŸi mustatza, da\' nu oricum, ci numa pe jumate! Si toata lumea ar fi ras de HiclÄƒr de s-ar fi prapadit, ÅŸi nemÅ£ii ar fi pierdut rÄƒzboiu, cÄƒ toÅ£i soldaÅ£ii s-ar fi cÄƒcat pe ei de rÃ¢s Ã®n tranÅŸee ÅŸi prin Panzere ÅŸi prin Messerschmidturi, ÅŸi ar fi umplut Europa de cÄƒcat, nu de cadavre, ÅŸi mie mi s-ar fi fÄƒcut Mausoleu\' SÄƒpunului, fincÄƒ unde aÅ£i mai vÄƒst voi sÄƒpun gropar de rÄƒzboaie?','De ce imi pare rau ca nu-s evreu',0,'','publish','open','open','','de-ce-imi-pare-rau-ca-nu-s-evreu','','','2008-02-08 09:33:51','2008-02-08 07:33:51','',0,'http://www.groparu.ro/?p=985',0,'post','',12),(986,1,'2008-02-08 16:40:37','2008-02-08 14:40:37','Fericiti cei ce nu ma aveti in lista, caci a voastra e fericirea de a nu ma cunoaste suficient de bine! Finca azi am avut statusu\' asta, pe care voi nu mi l-ati vazut finca nu ma aveti in lizta:\r\n\r\n\"Ce intreaba un usturoi pe alt usturoi caruia ii pute gura: ba, ai mancat cumva Groparu?\"\r\n\r\nAsta o zic finca asar\' am iesit - unde altundeva! - in Autograf cu <a href=\"http://oedip.blogspot.com\" target=\"_blank\">Oedip</a>, mah, <a href=\"http://oedip.blogspot.com\" target=\"_blank\">Oedip</a>, da\' nu ala cu ma-sa! Si inainte de asta am mancat usturoi, mah, la greu, d-ala chinezesc, si creca d-aia nu o vrut sa ma pupe nicicum pe gura, nesimtitu\'. Sau din cauza ca nici io nu am vrut si nici nu s-o pus niciodata problema. Buek, oricum.','Statusu\' meu de azi',0,'','publish','open','open','','statusu-meu-de-azi','','','2008-02-08 16:40:37','2008-02-08 14:40:37','',0,'http://www.groparu.ro/?p=986',0,'post','',7),(987,1,'0000-00-00 00:00:00','0000-00-00 00:00:00','Deci da.','Deci bah, Oedip, deci',0,'','draft','open','open','','deci-bah-oedip-deci','','','0000-00-00 00:00:00','0000-00-00 00:00:00','',0,'http://www.groparu.ro/?p=987',0,'post','',0),(988,1,'2008-02-11 22:22:40','2008-02-11 20:22:40','Burlacia este cea mai dulce si memorabila etapa din viatza unui mascul (cu exceptia momentelor cand ti-i asa de lehamite de atata fericire ca ai fi in stare chiar sa iesi la o bere cu <a href=\"http://oedip.blogspot.com\" target=\"_blank\">Oedip</a>): nu ti se mai interzice sa bei joi seara cu prekinii (la fel luni, marti, miercuri, si in weekend), ba mai mult, faci ÅŸi pe filozofu\' ÅŸi iti permiti sa rÃ¢zi de Ã®nsuraÅ£ii Äƒia laÅŸi care se carÄƒ acasÄƒ dupa a patra bere (\"bueeey, moluscÄƒ, n-ai pic de coloanÄƒ deasupra curului, o laÅŸi pe nevasta-ta sÄƒ te Å£inÄƒ supt ÅŸlap!); descoperi cÄƒ ai ÅŸi electrocasnice cu care nu ai facut pana acum cunostinta prin apartament - gen aragaz, maÅŸinÄƒ de spÄƒlat, chiar placa aia video nouÄƒ pe care nu ai apucat sÄƒ Å£i-o instalezi; ÅŸi Ã®nveÅ£i, Ã®ncetul cu Ã®ncetul, cÄƒ muntele Äƒla de doze de bere si conserve goale de Scandia ÅŸi de fasole cu carnacior trebuie aruncat odatÄƒ ÅŸi odatÄƒ, alfel Ã®ntr-o bunÄƒ zi pur ÅŸi simplu va prinde viaÅ£Äƒ ÅŸi te va sugruma Ã®n somn.\r\n\r\nContinui sÄƒ Ã®Å£i aprofundezi cocoaÅŸa ÅŸi sÄƒ-Å£i lÄƒÅ£eÅŸti fundul la calculator redevenind Solmyr din Heroes V, sau niegru\' Äƒla muÅŸchiulos care omoarÄƒ mexicani ÅŸi portoricani Ã®n GTA 3 - San Andreas, sau primul <em>marine</em> desfÄƒÅŸurat in Bagdad, Ã®n Call of Duty nu-mai-ÅŸtiu-care. Revezi filmele alea horror ÅŸi caÅŸti plictisit cÃ¢nd tot felu\' de piÅ£i americance proaste, Ã®n maiouaÅŸe fosforescente, Ã®s omorÃ¢te cu drujba prin Texas, ÅŸi poÅ£i Ã®n sfarÅŸit sÄƒ demolezi din start documentare gen \"Top ten battle tanks\" de pe Descopery, fincÄƒ nu poÅ£i Ã®n ruptul capului sÄƒ fii de acord cÄƒ al zecelea cel mai bun tanc din lume o fost Shermanu\' - un tanc din care Tigerele germane Ã®ÅŸi fÄƒceau insectare, cÃ¢nd erau Ã®n clasa grupa mare pregÄƒtitoare la grÄƒdiniÅ£a de tancuri. Patul e tot al tÄƒu, ÅŸi te Ã®ntinzi pe el ca un Iisus, numa\' cÄƒ crÄƒcÄƒnat ca Van Damme cÃ¢nd fÄƒcea ÅŸpagatu\' pe scaune, da\' Ã®ncerci sÄƒ Ã®Å£i Å£ii nasul cÃ¢t mai departe de lenjeria aia de pat care trebuia schimbatÄƒ de anul trecut.\r\n\r\nTe Ã®nveÅ£i, Ã®n cele din urmÄƒ, cÄƒ poÅ£i trÄƒi ÅŸi fÄƒrÄƒ mÃ¢ncÄƒruri franÅ£uzeÅŸti sofisticate, care Ã®Å£i dezvÄƒluie conopida Ã®n moduri ÅŸi gusturi pe care nu le credeai posibile; Ã®Å£i faci un ideal culinar din sanviÅŸurile de la Speed; iar pÄƒpÄƒrada mÃ¢ncatÄƒ de trei  ori pe zi cu ceapa Ã®Å£i devine practic un <em>alter ego</em>, un frate geamÄƒn pierdut - ÅŸi iatÄƒ! regÄƒsit.\r\n\r\nDar pentru cÄƒ nu sunt genul de om care cedeazÄƒ din prima Ã®n faÅ£a greutÄƒÅ£ilor, ÅŸi care nu acceptÄƒ Ã®n ruptul capului sÄƒ se lase copleÅŸit de soarta potrivnicÄƒ, azi m-am hotÄƒrÃ¢t sÄƒ fac ceva legat de destinul meu. Åži m-am hotarÃ¢t sÄƒ Ã®ncep cu chiuveta plinÄƒ de zigguratu\' Äƒla de vase murdare, pe care mÃ¢ncarea uscatÄƒ reinventeazÄƒ conceptul de ciment roman, si mai ales cu farfuriile elea jegoase de pe care, daca ai fi biograful Groparelui, ai putea trasa intregul meu istoric alimentar de anul acesta.\r\n\r\nAsa ca azi mi-am cumpÄƒrat un serviciu nou de 12 farfurii adanci si 12 farfurii plate, care ar trebui sÄƒ mÄƒ ajute sÄƒ scap teafÄƒr de lunile februarie si martie.','Despre burlacie',0,'','publish','open','open','','despre-burlacie','','','2008-02-11 23:47:53','2008-02-11 21:47:53','',0,'http://www.groparu.ro/?p=988',0,'post','',29),(989,1,'2008-02-13 17:38:46','2008-02-13 15:38:46','- Esti parte din mine, te simt mereu cu mine, ma gandesc la tine mereu, de fiecare data cand inchid ochii te vad in fatza! Mai ales cand sunt pe buda si ma screm.\r\n\r\n- As vrea sa te port tot timpul cu mine; pot sa te fac micul meu limbric personal?\r\n\r\n- As vrea sa vorbesc despre tine in cuvinte care inca nu s-au inventat in limba romÃ¢nÄƒ! De exemplu, cand le spun altora cat de minunata esti, sa le spun, ca in engleza, \"my girlfriend, it is adorable!\"\r\n\r\n- Iubesc pÄƒrul tau mÄƒtÄƒsos, mai ales cand Å£i-l ating dupÄƒ duÅŸ, cÃ¢nd curÄƒÅ£ cada!\r\n\r\n- Iubita mea, nimic nu m-ar face mai fericit decat daca mi-ai da o pereche de chilotei de ai tai! In ritmul in care te ingrasi, vreau sa vezi si tu peste 2-3 ani, cand vei arata cat o ditamai cazarma, cat de slaba erai in 2008.\r\n\r\n- Pentru ca te iubesc, azi, de Sf. Valentin, vreau sa incerc sa fac dragoste cu tine fara sa ma mai gandesc la fosta mea iubita din liceu. Sper sa si reusesc!\r\n\r\n- Incredibil cum dupa atata amar de ani tot te mai iubesc!\r\n\r\n- Daca adorm dupa ce facem dragoste, o sa te rog sa ai grija cum te pui sa te culci; la cat esti de masivÄƒ, daca te rostogolesti peste mine m-ai sufoca instant.\r\n\r\n- MÄƒ ajuti te rog sÄƒ Ã®Å£i descopÄƒr buricul printe faldurile tale de grÄƒsime? AÅŸ vrea sÄƒ-l pup :D\r\n\r\n- Draga mea, de Sf Valentin am sa iti fac cadou o camera foto cu optiunea de panorama: astfel, vei putea incapea intreaga in viitoarele noastre poze!\r\n\r\nPS: Happy St. Valentine\'s Day!\r\n\r\n<strong>Update:</strong> <a href=\"http://www.7plus.ro/?arhiva=14/02/2008&amp;id=2192\" target=\"_blank\">O scris si Julica</a> despre asta ziua aceasta raucuvintata.','10 anti-complemente de Seint VelÄƒntain',0,'','publish','open','open','','10-anti-complemente-de-seint-velantain','','','2008-02-14 09:49:07','2008-02-14 07:49:07','',0,'http://www.groparu.ro/?p=989',0,'post','',28),(990,1,'2008-02-13 01:11:50','2008-02-12 23:11:50','Fazele astea is colese de un fost coleg care o avut oportunitatile sa discute cu ceva HP-isti la ceva conferintza de telecom unde l-or dus - bine-nteles - un avion si un ordin de delegaÅ£ie.\r\n\r\nDeci HP-istii livrau echipamente de telecom la araboci. Si la un moment dat, arabocii cer vreo 4 servere HP. Asa ca HP-istii - ce sa faca? - li le livreaza, dupa exact specificatiile astora, la un scor de vro 2-3000 euroi/bucata, sau ceva de genu\'.\r\n\r\nDupa 3 saptamani, le vin serverele refuzate de la araboci. HP-istii se crizeaza un pic, si ii suna pe araboci: ba, le zic astia, ce Dumnezau sau Allah au serverele de nu va plac? A, zice arabocii, is super OK, merg ca unse, desi au Windows pe ele; atÃ¢ta numa ca-s prea urÃ¢te! ÃŽs senzaÅ£ional de urÃ¢te. Cele mai urÃ¢te servere pe care le-am vÄƒzut noi, ÅŸi noi am vÄƒzut un catraliard de servere urÃ¢te! Deci s-ar putea scrie doctorate pe cÃ¢t Ã®s de urÃ¢te; is Miss ÅŸi Mister Cele Mai UrÃ¢te Servere din Lumea Asta! Mai urÃ¢te ca Tom Hanks, Barbra Streisand ÅŸi Woody Allen la un loc, la puterea plus infinit, Ã®nmulÅ£it cu doi. Mai urÃ¢te ca o femeie urÃ¢tÄƒ, mÄƒh, dacÄƒ vÄƒ puteÅ£i Ã®nchipui ce e aia! Prea urÃ¢te, plm.\r\n\r\nAÅŸa cÄƒ HP-iÅŸtii, bÄƒieÅ£i dÄƒjtepÅ£i, se apucÄƒ de treabÄƒ, ÅŸi Ã®n alte 2 sÄƒptÄƒmÃ¢ni le livreazÄƒ la arÄƒboci ditamai serverele suflate cu aur placat solid de nuÅŸ cÃ¢te karate ÅŸi kung-fu, bÄƒtute cu nestemate ÅŸi porcovenii care sunt cele mai bune prietene ale damelor, diamante le zice, aflaÅ£i ÅŸi voi, cÄƒ ÅŸi io numa ieri am aflat, cÄƒ aÅŸa mi-o zis aia de si-o punea cu Kennedy, Marilena lu\' Monroe. Cost per porcÄƒrie de Barbie-server d-asta bÄƒtut cu nestemate roz ÅŸi rare - 30.000 coco, deci moca. ArÄƒbocii se udÄƒ pe ei de fericire, le iau, le pupÄƒ, zic ÅŸi \"Aman!\" sau \"Hrhrrrrlhhhhh\" Ã®n limba aia a lor care se vorbeÅŸte cam din spatele luetei, aÅŸa, plÄƒtesc bucuroÅŸi, ÅŸi merg sÄƒ le prezinte prinÅ£ului care stÄƒpÃ¢nea reÅ£eaua GSM care comandase serverele.\r\n\r\nPrinÅ£ul saudit picÄƒ Ã®n falcÄƒ de fericire cÃ¢nd le vede, ÅŸi numaidecÃ¢t porunceÅŸte ca sysadminii sÄƒ le instaleze ÅŸi sÄƒ le punÄƒ la treabÄƒ, aÅŸa aurite cum iereau iele! AÅŸa cÄƒ serverele ajung, frumos, unde le era locul: Ã®ntr-o camera a serverelor unde mai erau inca vreo jde de servere, ÅŸi unde aveau acces, zilnic, doar una sau doo persoane, ÅŸi ÅŸi Äƒia sysadmini, nici mÄƒcar persoane 100%.\r\n\r\nIar despre reÅ£eaua de telefonie mobilÄƒ a prinÅ£ului saudit - Ã®n episodul urmÄƒtor, fincÄƒ ÅŸi mÃ¢ine voi avea nevoie de trafic.\r\n\r\nAceastÄƒ postare se bazeazÄƒ pe un fapt real.','Deci de ce mi-i mie ciuda ca nu-s arab bogat',0,'','publish','open','open','','deci-de-ce-mi-i-mie-ciuda-ca-nu-s-arab-bogat','','','2008-02-13 02:36:32','2008-02-13 00:36:32','',0,'http://www.groparu.ro/?p=990',0,'post','',23),(991,1,'2008-02-15 11:28:23','2008-02-15 09:28:23','1. Din seria : <em>bÄƒ, si ioz prozt; da\' cand vad in juru\' meu projti mai mari ca mine, mah, atata ma bucur, mah, atata ma bucur, ghe numa\'!, </em>vÄƒ invit sÄƒ cetiÅ£i aceastÄƒ conversaÅ£ie YM-istÄƒ:\r\n\r\n<strong>Eusebiu</strong>: sal\r\n<strong>Eusebiu</strong>: vezi ca nu-ti mere pagina web\r\n<strong>Greuceanu</strong>: guten morgen!\r\n<strong>Greuceanu</strong>: care pagina mah?!\r\n<strong>Greuceanu</strong>: asta din status?!\r\n<strong>Eusebiu</strong>: da\r\n<strong>Greuceanu</strong>: O sÄƒ meargÄƒ Ã®n curÃ¢nd.\r\n\r\nÅži ca sÄƒ Ã®nÅ£elegeÅ£i ÅŸi voi: Greuceanu avea statusu\' \"www.mytroy.srl\", care de fapt este <a href=\"http://www.mytroy.ro\" target=\"_blank\">www.mytroy.ro</a> - care de fapt e si firma domniilor lor pe nume Mitroi (voi ati auzit de extensia <em>srl</em> pentru saituri? ca io le-as propune sa faca extensia <em>cu.gro\'</em> pentru saite, cum ar fi de exemplu www.porno.cu.gro\')\r\n\r\n2. Din seria <em>Stiati ca</em>...: <em>Cami kiss: ATENÅ¢IE cititi acest mesaj cu grija...care a fost trimis de presedintele yahoo BOGDAN OANE..aici este presedintele BOGDAN OANE </em>(<strong>nota bloggerului: WWWTTTFFFF!!!!</strong>):<em> Imi pare rau sa va anuntz ca yahoo a ajuns la maximum de nr. de persoane. Daca vrei sa pastrezi contul tau gratis trimite mesajul acesta la toti din lista ta. In acest mod vom sti care sunt folosite si care nu, le vom sterge. Trimite acest mesaj timp de 8 zile si contul tau va ramane gratis. Inca o data imi pare sincer rau ca trebuie sa fac aceasta. Te rog incepe sa trimiti!! Cine nu trimite acest mesaj, contul lui va fii deletat. NU ESTE O VRAJEALA, CHIAR STERG CONTURI!!!! Este si pe net!</em> (stiu ca nu ati primit niciodata mesaju\' asta, d-aia vi l-am dat si voua, sa nu care cumva, Doamne feri, sa fiti deletati!!!!!)\r\n\r\n3. Azi a ziua lu Greuceanu (sa traiasca La Multi Ani! unge-mi-as p*** cu gura lui) si ieri o fo ziua mea de pronume, si tot zilele estea tre\' sa ii nasca copila lu\' NÃ¢rÅ£oagÄƒ zis PÃ¢rÅ£oagÄƒ o altÄƒ copilÄƒ:\r\n\r\n<strong>Groparu</strong>: azi e ziua lu tiganu\r\n<strong>PÃ¢rÅ£oagÄƒ</strong>: futu-i si bagami-as! iara am uitat\r\n<strong>PÃ¢rÅ£oagÄƒ</strong>: se naste aia mica de ziua lui?\r\n<strong>Groparu</strong>: OMG!!!! nu-ti pare rau acuma ca nu de Sf Valentin s-o nascut?\r\n<strong>Groparu</strong>: hehe\r\n<strong>Groparu</strong>: vi?\r\n<strong>PÃ¢rÅ£oagÄƒ</strong>: unde pula sa viu? la sibiu?\r\n<strong>Groparu</strong>: da\r\n<strong>Groparu</strong>: hai\r\n<strong>Groparu</strong>: nu hi bou\r\n<strong>PÃ¢rÅ£oagÄƒ</strong>: mo, nu poci, iti dai sama\r\n<strong>Groparu</strong>: pe nevasta-ta gravida o lasi sa vie?\r\n<strong>Groparu</strong>: merem cu ocazia\r\n<strong>PÃ¢rÅ£oagÄƒ</strong>: MÄƒ! si-asa vecinu de sus e tata ziua la noi\r\n<strong>PÃ¢rÅ£oagÄƒ</strong>: amu\' mai tre\' sa mearga si la maternitate cand nashte nevasta\r\n<strong>Groparu</strong>: mnoa\r\n<strong>Groparu</strong>: deci e pe maini bune!\r\n<strong>Groparu</strong>: hai\r\n<strong>Groparu</strong>: hai la sighie\r\n<strong>PÃ¢rÅ£oagÄƒ</strong>: neah\r\n<strong>Groparu</strong>: ok\r\n<strong>PÃ¢rÅ£oagÄƒ</strong>: te astept sa vi\r\n<strong>PÃ¢rÅ£oagÄƒ</strong>: si pana atunci pregatesc beuturile cele alese\r\n<strong>PÃ¢rÅ£oagÄƒ</strong>: si ceva parizer cred ca mai am\r\n<strong>PÃ¢rÅ£oagÄƒ</strong>: cu mancarea stau prost, da de beuuuut am!\r\n<strong>Groparu</strong>: nu-i stress, papam placenta\r\n<strong>Groparu</strong>: daca ne-o dai\r\n<strong>Groparu</strong>: si celulele stem\r\n<strong>PÃ¢rÅ£oagÄƒ</strong>: placenta cu varza!!','Din seria ',0,'','publish','open','open','','din-seria','','','2008-02-15 12:40:53','2008-02-15 10:40:53','',0,'http://www.groparu.ro/?p=991',0,'post','',17),(992,2,'2008-02-17 23:55:54','2008-02-17 21:55:54','Asa, unde eram?\r\n\r\nDeci.\r\n\r\nIn 15 feb, deci vineri, fu ziua lu Greuceanu, ÅŸi i-am dus cadou o carte de bazme de Petre Ispirescu cu titlul - fireste - Greuceanu. Bine, o trebuit sÄƒ mÄƒ milogesc de ÅŸefa mea care nu-mi citeÅŸte blogu sÄƒ mÄƒ lase sÄƒ plec cu o orÄƒ mai devreme de la serviciu (mai ales cÄƒ bagasem overtime toatÄƒ sÄƒptÄƒmÃ¢na, da\' asta nu conteazÄƒ, <em>I\'m proud to serve</em>! NOT), ÅŸi am obtinut concesia dupa o scurtÄƒ evaluare maniheist-negativista a activitÄƒÅ£ii mele Ã®n firmÄƒ, cu concluziile  cÄƒ promit cÄƒ am sÄƒ fiu mai serios. Finca am rate de platit, normal ca sunt de acord cu orice promisiune tre\' sa fac.\r\n\r\nNuma atata vreau sa va zic despre ziua Greuceanului: am ajuns tÃ¢rziu, cÃ¢nd toatÄƒ lumea era machitÄƒ; ÅŸi Ã®n ciuda protestelor mele, Marieana, o membra fondatoare a gÄƒjtii, o simtit nevoia sÄƒ le iesplice la toÅ£i ce am fÄƒcut de revelion, si toti or rÃ¢s ca projtii. De mine, care de fapt is un blogger.\r\n\r\nCe am fÄƒcut eu de Revelion? VÄƒ spun tot io, fincÄƒ nu voi avea niciodatÄƒ autobiograf, ÅŸi dacÄƒ se vor face filme dupa viata mea vor fi cu siguranta filme interzise minorilor de orice vÃ¢rstÄƒ.\r\n\r\nDeci de revelion, printre multe altele, am legat sÄƒnii de masini si ne-am lÄƒsat traÅŸi pe drumul Ã®nzÄƒpezit.\r\n\r\nUltima turÄƒ fu cu Mariana ÅŸi cu Ã®ncÄƒ o gajicÄƒ. Amandoua erau pe sanie in spatele meu, si se tineau de burta mea, tinandu-se de mine ferm, dar cu scÃ¢rbÄƒ - exact asa cum ma imbratisa maica-mea, mai demult.\r\n\r\nIo stÄƒteam cu picioarele ridicate-n aer si sprijinite de bara de protecÅ£ie a maÅŸinii, cu gaura curului Ã®n sus de parcÄƒ era o baterie de rachete sol-aer, indreptatÄƒ cÄƒtre cerul negru, cÄƒ era noapte.\r\n\r\nDeci gaura curului meu era cÄƒtre sus, ceea ce faciliteaza depresurizarea.\r\n\r\nFetele mÄƒ strÃ¢ngeau de burtÄƒ cu pasiune, cÄƒ maÅŸina deja mergea cu vreo 40 km/orÄƒ, si se temeau. Burta mea deja avea chef sa iasa spre afra, sa vada ce mai e nou.\r\n\r\nIo, de vreo 4 zile, fincÄƒ erea Revelion, mÄƒ hrÄƒnisem exclusiv cu bere, multÄƒ bere, foarte multÄƒ bere, o bere care conferÄƒ celui care o Ã®nchiriazÄƒ (pe bere) o Ã®ntreagÄƒ Siberie de gaze flatulante; lucru deloc deranjant cÃ®nd eÅŸti tot timpul afarÄƒ pe malul lacului unde bate un alizeu care duce miasmele departe, spre codri, sau cÃ¢nd eÅŸti Ã®nauntru, ÅŸi inconÅŸtienÅ£ii Äƒia fumeazÄƒ ca sa isi acopere si ei, sireacii, gazele proprii.\r\n\r\nDeci fetele erau cam lipite de spatele meu, si ma apasau pe burtÄƒ. Åži io simt cÄƒ nu mai pot tine bÄƒÅŸina, da\' nu vreau sa opresc sania si le stric bucuria, finca-s un ficior cumsecade; asa ca las asa un suvoi timid de <a href=\"http://en.wikipedia.org/wiki/Zyklon_B\" target=\"_blank\">Cyclon B</a> sÄƒ se elibereze din insusi mine, ÅŸi aÅŸtept; ÅŸi cÃ¢nd vÄƒd cÄƒ acest mesager timid a trecut neobservat de nÄƒrile lor de cÄƒprioarÄƒ, eliberez o ditai bulÄƒ de mercaptan cu efect de serÄƒ care fusese captivÄƒ prin ligheanul meu de maÅ£e, fratilor, deci putam rade si un sat cecen cu bÄƒÅŸina aia, mah! DacÄƒ ieream in State s-ar fi declansat <a href=\"http://en.wikipedia.org/wiki/DEFCON\" target=\"_blank\">DEFCON</a> zero ÅŸi as fi fost arestat pentru activitÄƒÅ£i teroriste!!! Acolo, in miez de Semenic, cele douÄƒ domnisoare au sÄƒrit de pe sanie la 40 km/orÄƒ, ÅŸi-or luxat ÅŸi Ã®nvineÅ£it bunÄƒtate de cururi, ÅŸi or inceput sa o ia la fuga indara, cÄƒ s-or gÃ¢ndit cÄƒ mirosu ala nu era de sorginte pÄƒmÃ¢nteanÄƒ, ÅŸi ele nu vroiau sÄƒ fie rÄƒpite de egztraterejtri, cÄƒ mi-or zis!\r\n\r\nSi isprava asta s-o povestit de ziua lu Greuceanu Ã®n gura mare, de faÅ£Äƒ cu vreo 5 cupluri, insistÃ¢ndu-se asupra irizaÅ£iilor albÄƒstrii ale norului de dimensiuni mitologice, ÅŸi am fost felicitat cÄƒ nu existÄƒ cal Ã®n RomÃ¢nia care sÄƒ se beÅŸascÄƒ mai stricat ca mine, cÄƒ ar trebui sÄƒ Ã®nchei contracte cu armata, ÅŸi cÄƒ sÄƒ am grijÄƒ sÄƒ dorm cu geamul deschis noaptea, indiferent de anotimp, alfel - Doamne feri! - provoc o explozie la mine-n bloc, de rad tot cartieru, si cÄƒ redefinesc conceptele de putoare, ÅŸi cÄƒ daca mlaÅŸtina Hidrei din Lerna aducea de departe a metanul slobozÃ¢t de mine, Herakles ar fi devenit o treanÅ£Äƒ second hand ÅŸi nu ar mai fi fost el jmekeru mitologiei.\r\n\r\nÅži Ã®mi cer scuze dacÄƒ v-am oripilat, da ultima data cÃ¢nd am verificat eram si io om ca multi altii, care printre altele se beseste si caruia ii place sa beie, sa se cace, sa se pise si sa se si futa.\r\n\r\nPosibil chiar sa-i placa sa se futa mai mult decat le place la multi altii.','E greu la ziua lu Greuceanu!',0,'','publish','open','open','','e-greu-la-ziua-lu-greuceanu','','','2008-02-18 01:31:34','2008-02-17 23:31:34','',0,'http://www.groparu.ro/?p=992',0,'post','',17),(993,2,'0000-00-00 00:00:00','0000-00-00 00:00:00','Deci ca sa bagati si voi la cap: Groparu e Groparu cam de cand Greuceanu e Greuceanu, adica din anu meu 2 de facultate, de cand ne-am bagat pe <em>pisi</em> games (si ne trebuia nickuri, ca doara Ã®ntr-un server de Quake 1 populat de Killer, Terminator si Fucker noi nu era sa ne impuscam cu aia cu nickuri gen Vasilescu Octavian, ca s-ar fi pishat toata gheimarimea pe ei de rÃ¢s, si ne-ar fi zic ca suntem gay-meri, nu gameri!!).\r\n\r\nSi noi am inceput sa gamerim in una din primele crajme cu net cafe din Cluji, si anume More, o terasoaie unde se bateau in fiecare seara basarabenii cu manasturenii, si noi ieream prekini cu ambele parti beligerante, ca eram studenti saraci si si miei blanzi si cam sugeam de la cate Å£Ã¢Å£e gÄƒseam disponibile, ca mielu blÃ¢nd care suge de la mai multe oi! Bere sugeam, claro, cÄƒ lor li se pÄƒrea cÄƒ e o onoare sÄƒ ne cumpere bere.','More',0,'','draft','open','open','','more','','','0000-00-00 00:00:00','0000-00-00 00:00:00','',0,'http://www.groparu.ro/?p=993',0,'post','',0),(994,1,'2008-02-18 14:55:41','2008-02-18 12:55:41','Pentru cei care n-o stiti,\r\nTya e o fata fara dinÅ£i ÅŸtirbiÅ£i;\r\nE o fatÄƒ super mega micÄƒ,\r\nMicÄƒ-micÄƒ, munÅ£i ridicÄƒ!\r\nFata asta nu se-mbrÄƒcÄƒ-n ie,\r\nÅži-i urÄƒm sÄƒ nu mai aibe gÃ¢ndaci de bucÄƒtÄƒrie,\r\nSÄƒ Ã®nveÅ£e sÄƒ gÄƒteascÄƒ,\r\nÅži sÄƒ fie frumoasÄƒ ca o floare de rostopascÄƒ!\r\nCÃ¢nd fumeazÄƒ, Ã®i urÄƒm sÄƒ nu se polueazÄƒ,\r\nSÄƒ nu mai calce pe alÅ£ii cÃ¢nd danseazÄƒ,\r\nÃŽi urÄƒm cÃ¢nd face dragoste sÄƒ foloseascÄƒ cÄƒtuÅŸe,\r\nSi la ea-n apartament sÄƒ nu mai gÄƒseascÄƒ cÄƒpuÅŸe!\r\nNorocul sÄƒ o iubeascÄƒ,\r\nEczemele s-o pÄƒrÄƒseascÄƒ,\r\nBanuÅ£ii Ã®n cont sÄƒ i s-aÅŸtearnÄƒ\r\nCa zÄƒpada-n Finlanda pe timp de iarnÄƒ,\r\nSÄƒnÄƒtate s-aibÄƒ cÃ®Å£i copaci la tropice,\r\nSÄƒ dea strike cÃ¢nd joacÄƒ popice,\r\nSÄƒ trÄƒiascÄƒ mulÅ£i, mulÅ£i ani,\r\nNu mai am rimÄƒ, happy anniversary!','Azy e zyua lu\' Tya',0,'','publish','open','open','','azi-e-ziua-lu-tya','','','2008-02-18 16:01:17','2008-02-18 14:01:17','',0,'http://www.groparu.ro/?p=994',0,'post','',10),(995,1,'2008-02-19 10:06:48','2008-02-19 08:06:48','In ultima vreme, <a href=\"http://www.groparu.ro/?p=56\" target=\"_blank\">cei doi programatori de sex opus</a>, iaca! s-au Ã®nmulÅ£Ã¢t, sÄƒ trÄƒiascÄƒ, LMA!\r\n\r\nDeci la naÅŸtere pÄƒrintii or loat amenda pentru cÄƒ poliÅ£aii de la secÅ£ia 5 or crezut cÄƒ e chef Ã®n maternitate cu concert Rolling Stones, atÃ¢ta tÄƒrÄƒboi o fÄƒcut aia mnicÄƒ! Åži fincÄƒ Ã®ncÄƒ nu are voie bere, trage vÃ¢rtos cu gura de orice lichid de parcÄƒ Ã®i pompÄƒ de 40 de atmosfere. S-a nÄƒscut frunzÄƒrind un manual de Hegel, ÅŸi actualmente e uÅŸurel albÄƒstrie la faÅ£Äƒ de ciudÄƒ cÄƒ se aÅŸtepta ca comitetul de primire sÄƒ fie catedra de geometrie euclidianÄƒ a FacultÄƒÅ£ii de MatematicÄƒ CuanticÄƒ.\r\n\r\nLa naÅŸtere a cerut dupÄƒ Octavian Bellu, specificÃ¢nd cÄƒ vrea sÄƒ Ã®i cearÄƒ scuze cÄƒ nu poate participa Ã®n lotul olimpic pentru Beijing, dar i-a promis Nadiei Comaneci cÄƒ o lasÄƒ pe ea sÄƒ rÄƒmÃ¢nÄƒ unica atletÄƒ colosalÄƒ a RomÃ¢niei.\r\n\r\nA decretat deja cÄƒ tezele lui Jauss ÅŸi abordarea post-colonialÄƒ a romanului Kafkian sunt deja teme bÄƒÅŸite ale criticii literare a secolului 20, veac decadent prin excelenÅ£Äƒ, ÅŸi cÄƒ orice influenÅ£Äƒ liricÄƒ <em>baudelairianÄƒ</em> Ã®n cibernetica TaiwanezÄƒ sunt simple speculaÅ£ii.\r\n\r\nA spus de la bun Ã®nceput cÄƒ daca s-a facut sos salsa, ar trebui sÄƒ se facÄƒ ÅŸi sos Merengue, cÄƒ are de gÃ¢nd sÄƒ scoatÄƒ o antologie de Ã®njurÄƒturi, sÄƒ editeze o reclasificare a artei preincaÅŸe amerindiene, ÅŸi sÄƒ demoleze teoriile greÅŸite referitoare la genomul uman.\r\n\r\nVa scoate un leac contra bÄƒÅŸinilor.\r\n\r\nVa face preÅ£ul apartamentelor accesibil pentru marea masÄƒ a populaÅ£iei (mulÅ£umim, Ana!).\r\n\r\nÃŽl va trimite pe Iliescu Ã®n celulÄƒ cu Miron Cozma.\r\n\r\nÃŽi va face implant de pÄƒr lu\' BÄƒse.\r\n\r\nVa scoate ultimul patch definitiv pentru Windows - all editions.\r\n\r\nVa elimina efectul de serÄƒ.\r\n\r\nVa construi Ã®ncÄƒ 8 malluri Ã®n Cluj. Åži va exporta praf Ã®n Sahara.\r\n\r\nVa construi o fabricÄƒ Nokia Ã®n fiecare cartier al Clujului.\r\n\r\nÃŽl va face Ã®nalt pe Boc.\r\n\r\nVa preschimba numele Mercedes in Napoca, si nemtii vor fi fericiti.\r\n\r\nÃŽi va sterge punctele de pe permis ale lu ta-su.\r\n\r\nVa face ca saitu meu sa fie traficat pe piaÅ£a neagrÄƒ. Columbieni, nu columbeni, Ã®l vor bÄƒga in prezervative pe care le vor inghiti si vor trece cu el granita si se vor imbogati.\r\n\r\nVa inventa bananele cu gust de biftec.\r\n\r\nVa ÅŸterge petele omenirii de pe ficaÅ£ii ei.\r\n\r\nAceasta va fi Ana.\r\n\r\nBine-ai venit, Ana! (scuzÄƒ-mÄƒ ca nu pot pune pozÄƒ cu tine cum caÅŸti, da\' mi s-o bulit saitu\')','Ana are Coprea - ceeeeee numeeee simpluuuuu....',0,'','publish','open','open','','ana-are-coprea-ceeeeee-numeeee-simpluuuuu','','','2008-02-19 10:06:48','2008-02-19 08:06:48','',0,'http://www.groparu.ro/?p=995',0,'post','',9),(997,1,'2008-02-18 16:11:49','2008-02-18 14:11:49','','yes.jpg',0,'','inherit','open','open','','yesjpg','','','2008-02-18 16:11:49','2008-02-18 14:11:49','',-1203343636,'http://www.groparu.ro//../../../../../../../../../../../../../../../../../tmp/yes.jpg',0,'post','image/jpeg',0),(998,1,'2008-02-18 16:12:23','2008-02-18 14:12:23','','yes1.jpg',0,'','inherit','open','open','','yes1jpg','','','2008-02-18 16:12:23','2008-02-18 14:12:23','',-1203343636,'http://www.groparu.ro//../../../../../../../../../../../../../../../../../tmp/yes1.jpg',0,'post','image/jpeg',0),(999,1,'2008-02-18 16:20:32','2008-02-18 14:20:32','','dsc00045.jpg',0,'','inherit','open','open','','dsc00045jpg','','','2008-02-18 16:20:32','2008-02-18 14:20:32','',995,'http://www.groparu.ro//../../../../../../../../../../../../../../../../../tmp/dsc00045.jpg',0,'post','image/jpeg',0),(1000,1,'0000-00-00 00:00:00','0000-00-00 00:00:00','ÅžaradÄƒ: cine poate descebÄƒlui mesajul ascuns din aceasta imagine, despre care mesaj, va previn, e in englezÄƒ, ÅŸi este foarte actual, primeÅŸte premiul cel mare: o sticlÄƒ de Ursus gratisÄƒ, posibil 2, beutÄƒ Ã®n compania mea preÅ£ioasÄƒ, cine stie cÃ¢nd! CÃ¢t mai repede.\r\nDeci vÄƒ aÅŸtept la tracÅ£iuni celebeloase, bueeeeeeey, dÄƒjtepÅ£ilor ÅŸi dÄƒjteptelor!','ÅžarÄƒzi',0,'','draft','open','open','','sarazi','','','0000-00-00 00:00:00','0000-00-00 00:00:00','',0,'http://www.groparu.ro/?p=1000',0,'post','',0),(1001,2,'2008-02-20 00:04:40','2008-02-19 22:04:40','Ziceam zilele trecute despre nush ce araboc care nu o vrut sa cumpere servere de la HP decat dupa ce astia le-or poleit cu aur.\r\n\r\nArabocul in cauza - da, avea la bani de se-nerva. Si creca si amu mai are, ca nush cum dreq aia de au bani fac si mai multi bani, si aia de n-au, ii mai si pierd! Asta vÄƒ zice un expert, care mai ÅŸi munceÅŸte din greu pentru banii pe care Ã®i pierde.\r\n\r\nAÅŸa.\r\n\r\nDeci la arÄƒboc Ã®i trebuiau serverele alea finca <em>avea reÅ£ea de telefonie</em>. Da, aÅ£i cetit bine. Omul Ã®mpÃ¢nzise Arabia cu catarge d-elea de telefonie mobilÄƒ, ca sÄƒ aibe acoperire pentru cÄƒlÄƒreÅ£ii de cÄƒmile ai patriei sale, ÅŸi-o scos licenÅ£Äƒ, ÅŸi-o angajat oameni ÅŸi s-o apucat, Ã®n imensa lui mÄƒrinimie, sÄƒ Ã®mpartÄƒ Nokii ÅŸi Ericssoane ÅŸi Samsunge gratise la prekinii ÅŸi colaboratorii lui apropiaÅ£i. Astfel, reÅ£eaua lui a ajuns la faimoasa cifrÄƒ de 5000 de abonaÅ£i. Care plÄƒteau pentru abonament si convorbiri nelimitate in orice reÅ£ea... cÃ¢t sÄƒ zic? O scamÄƒ din buric. AdicÄƒ nimic. <em>Nada</em>. <em>Niente</em>! Nici mÄƒcar un pÃ¢rÅ£ sau un gÃ¢nd frumos de sÄƒrbÄƒtori. Sau o picÄƒturÄƒ de salivÄƒ, o scoicÄƒ spartÄƒ de la Medgidia sau o unghie de broascÄƒ. Nimic. Nimic pe doi. Minus 7. Nimic-nimic-nimic.\r\n\r\nEi bine, toate astea or loat sfÃ¢rÅŸit, pentru cÄƒ Ã®ntr-o bunÄƒ zi abonaÅ£ii celei mai moca reÅ£ele de telefonie din emisferÄƒ au primit Ã®n poÅŸtÄƒ o Ã®nÅŸtiinÅ£are. ÃŽn care li se comunica cÄƒ prinÅ£ului Ã®i pare foarte rÄƒu, da\' kiar foarte rau! Mega rau ii pare, da\' tre\' sa le introducÄƒ o taxÄƒ modicÄƒ pe apel, de vreo 0.00001 centi pe minut, sau ceva de genu. Pen\' ca el vrea sÄƒ Ã®ncheie contracte de roaming ÅŸi de apeluri internaÅ£ionale cu alÅ£i operatori, ÅŸi piÅŸicherii dreq de operatori de telefonie din Å£Äƒrile unde telefonia nu Ã®i aÅŸa de gratis Ã®l taxeazÄƒ procentual din cÃ¢t Ã®ÅŸi taxeazÄƒ el abonaÅ£ii; ÅŸi fincÄƒ el Ã®ÅŸi taxeazÄƒ abonaÅ£ii cu 0 (z-e-r-o), eia nu vor sÄƒ Ã®ncheie acorduri cu el, ÅŸi el nu poate sÄƒ Ã®ÅŸi foloseascÄƒ mobilul cÃ¢nd merge sÄƒ Ã®ÅŸi cumpere en-gros castelele alea de pe valea Loarei, ÅŸi el Ã®i silit sÄƒ Ã®ÅŸi cumpere cartele prepay din Å£ara de destinaÅ£ie, ceea ce e cam jenant, fincÄƒ ditamai prinÅ£u dÄƒ bip la prekini. AÅŸa cÄƒ din acel moment Ã®ncolo, abonaÅ£ii vor primi facturi acasÄƒ cu suma care trebuie plÄƒtitÄƒ lunar, cÄƒ aÅŸa Ã®l obligÄƒ legea aia a lor musulmanÄƒ care se ocupÄƒ de telefoniile mobile, Åžaria Ã®i spune.\r\n\r\nDar - sÄƒ nu Ã®ÅŸi facÄƒ ei probleme, fincÄƒ kiar dacÄƒ le vin acasÄƒ facturile, tot prinÅ£ul le va plÄƒti. Deci sÄƒ nu Ã®l jigneascÄƒ ÅŸi sÄƒ insiste sÄƒ Ã®ÅŸi plÄƒteascÄƒ ei facturile.\r\n\r\nMie mi s-o pÄƒrutÂ  super povestea, da tot nu mi-i clarÄƒ o chestie: dacÄƒ nu oferÄƒ telefoane la fidelizare, io zic cÄƒ reÅ£eaua asta a prinÅ£ului e cam najpa.','Deci de ce mi-i mie ciuda ca nu-s arab bogat partea 2,1/2',0,'','publish','open','open','','deci-de-ce-mi-i-mie-ciuda-ca-nu-s-arab-bogat-partea-212','','','2008-02-20 00:04:40','2008-02-19 22:04:40','',0,'http://www.groparu.ro/?p=1001',0,'post','',11),(1002,2,'2008-02-27 00:35:13','2008-02-26 22:35:13','Deci: cine gaseste mesajul adanc incriptat <a href=\"http://www.flickr.com/photos/8576437@N02/2294166163/\" target=\"_blank\">in aceasta imagine</a> primeste o bere de calitate indoielnica (gen Ursus, Becks, d-elea), posibil chiar douÄƒ, din partea mea, posibil chiar dreptul exclusiv de a o bea Ã®n prezenÅ£a mea! Cu proxima ocazie.\r\n\r\nHint: nici unul :D atÃ¢ta numa cÄƒ e Ã®n englezÄƒ. Na, c-am zis-o. Si comentati acilea pe sait, nu aiurea, pe flickr.\r\n\r\n<strong>Update</strong>: da, e o sarada politica. Nu, nu e vb de alianta DA, fii iertata!','ÅžaradÄƒ',0,'','publish','open','open','','sarada','','','2008-02-27 11:49:47','2008-02-27 09:49:47','',0,'http://www.groparu.ro/?p=1002',0,'post','',23),(1003,2,'2008-02-19 22:21:20','2008-02-19 20:21:20','','sarada.jpg',0,'','inherit','open','open','','saradajpg','','','2008-02-19 22:21:20','2008-02-19 20:21:20','',-1203452170,'http://www.groparu.ro//../../../../../../../../../../../../../../../../../tmp/sarada.jpg',0,'post','image/jpeg',0),(1004,2,'2008-02-19 22:23:10','2008-02-19 20:23:10','','sarada.jpg',0,'','inherit','open','open','','saradajpg-2','','','2008-02-19 22:23:10','2008-02-19 20:23:10','',-1203452170,'http://www.groparu.ro//../../../../../../../../../../../../../../../../../tmp/sarada.jpg',0,'post','image/jpeg',0),(1005,2,'2008-02-19 22:25:33','2008-02-19 20:25:33','','sarada.jpg',0,'','inherit','open','open','','saradajpg-2','','','2008-02-19 22:25:33','2008-02-19 20:25:33','',1002,'http://www.groparu.ro//sarada.jpg',0,'post','image/jpeg',0),(1006,2,'2008-02-19 22:28:24','2008-02-19 20:28:24','','_dsc8054.jpg',0,'','inherit','open','open','','_dsc8054jpg','','','2008-02-19 22:28:24','2008-02-19 20:28:24','',918,'http://www.groparu.ro//_dsc8054.jpg',0,'post','image/jpeg',0),(1007,2,'2008-05-27 22:53:16','2008-05-27 20:53:16','Io am saitu\' asta! Corect? Corect.\r\n\r\nIo stau prost cu timpu. Corect? Va zic io ca asa-i. Nu mai am timp nici sa mor, daca cumva vrea sa vie doamna cu coasa, cum o tot venit ea de atatea ori, si in schimb s-o ales cu un futai pe cinste de la mine (azi la folbal am dat cap in cap cu un jucator asa de tare, ca am crezut ca imi cad urechile pe jos si se uita la mine, ele, de jos, cu ochii lor).\r\n\r\nDeci finca io stau prost cu timpu, iau o mica-mica pauza cu saitu, si cand revin am sa va depanesc povestirile despe tiganiada, asa cum si le mai aminteste mintea mea memoriabila, desi este vaduva de camera mea foto credincioasa.\r\n\r\nAsa ca ne vom reciti pe... joi, vineri, ceva de genu.\r\n\r\nPS: Nu de alta, da\' de vrun an si ceva tot postez zilnic, si tre\' musai sa mai si produc ceva bani, ca-mi moare copiii de foame - macar saptamana asta tre\', cand in sfarsit ajunge si o banca, una singura, la putulica mea, si vreau, imi doresc foarte mult sa o doara! Dar despre acestea - intr-o postare viitoare. Plus ca intre timp <a href=\"http://adriancalarasu.wordpress.com/2008/05/28/banca-care-te-tine-in-post/\" target=\"_blank\">ui ce o patit CÄƒlÄƒ\'</a>!','Mica-mica paoza',0,'','publish','open','open','','mica-paoza','','\nhttp://adriancalarasu.wordpress.com/2008/05/28/banca-care-te-tine-in-post/','2008-05-28 09:43:02','2008-05-28 07:43:02','',0,'http://www.groparu.ro/?p=1007',0,'post','',15),(1008,1,'2008-02-21 09:49:13','2008-02-21 07:49:13','Deci Fidel o cam tras pe dreapta, e cu avariile puse, lasa ditamai insula cu bunaciuni latine la 8 dolari pe zi neguvernata decat de frai-su, care si el mai are o besina si se duce.\r\n\r\n<a href=\"http://http://www.cnn.com/2008/WORLD/americas/02/19/castro.top10/index.html\" target=\"_blank\">Fiti numa antena de cate ori or incercat amerlocii sa il convinga pe Fidel sa deie coltu\'</a>.\r\n\r\nUn comentator pe saitu\' Cotidianului comenta: \"Vei ramane mereu in inimile noastre, Fidel, alaturi de Che!\" - da, draguÅ£Äƒ, zice Groparu, da\' vez\' ca numa\' o vreme; finca din inima, orice reziduu e preluat de sange si transportat pana la organu\' ala leptic, sau cum ii zice, apendicita sau pneumonita, nu mai stiu, unde e facut uree, si e pishat afara prin putulica! Deci daca acuma esti in inimile noastre, mai Fidel, afla ca vei cam ajunge prin buda. Nasol. Ar mai fi o soluÅ£ie - sÄƒ nu ajungi la budÄƒ, ci pe pantofu unui piÅŸÄƒrcos mai slab de puÅ£ulicÄƒ, cu jet urinal slÄƒbit, ÅŸi din pantof, dacÄƒ piÅŸÄƒrcosu e ÅŸÄƒf, sÄƒ ajungi Ã®n curu\' unui angajat cÄƒruia ÅŸÄƒfu piÅŸÄƒrcos Ã®i dÄƒ ÅŸuturi!\r\n\r\nIo zic cÄƒ Fidel Castro o renuntat finca o primit o propunere de la Adi NÄƒstase ÅŸi Miron Mitrea, noii sultani ai pesedeului, sÄƒ le deie o mÃ¢nÄƒ de ajutor sÄƒ smulgÄƒ cÃ¢rma din braÅ£ele marinalului la alegerile electorale din 2008 ÅŸi 2009. UrmeazÄƒ ca, Ã®n campania electorala pentru alegerile electorale, PSD-ul sÄƒ Ã®i invite ÅŸi pe vÄƒduva lui Pol Pot, pe Kim Jong Il, pe Hugo Chavez ÅŸi pe - cine altul? - Nicu VÄƒcÄƒroiu, cu prietena lui, d-na Stalinskaya, urmaÅŸa lui Iosif Visarionovici.\r\n\r\nPS: Asa-i cÄƒ vÄƒ aÅŸteptaÅ£i sÄƒ scriu\"pÄƒrerea mea\" cÃ¢nd Ã®i vorba de Nicu VÄƒcÄƒ\'? Ei, numa\' de-a dreq n-am scris!','Fidel Castro si-o re-tras-o',0,'','publish','open','open','','fidel-castro-si-o-re-tras-o','','','2008-02-21 10:57:15','2008-02-21 08:57:15','',0,'http://www.groparu.ro/?p=1008',0,'post','',6),(1009,1,'2008-02-22 15:34:19','2008-02-22 13:34:19','Amu ceva vreme, un fost coleg caruia ii vom spune, sa zicem, Cipicao, lucra cu noi, ca d-aia ne era coleg. Si cand primim intr-o zi bonurile de masa de la Accor, vedem ca li se schimbase dizainu\': erau mai mari, mai labartate, intrau greu in portofel, ce mai! Bonurile din generatia de dinainte erau micutze ca neshte degete de la picioare delicate si delicioase de asiatice, numa\' bune de privit si mangaiat si supt si mai stiu io ce :D\r\n\r\nSi noi urlam la unison ca ce tzapa de la Accor, ca ce boane is estea, ca nu avem portofele suficient de portofele ca sa intre boanele in ele, of, lume, dorule! Si Cipicao zice: ba, zice, io le dau e-mail! Si se tranteste la calc, si trimite de pe mailu\' firmei un e-mail la Accor ca ce pana me de boane is elea, ca is urÃ¢te si mari ca niste cearsafuri de armata, ca neste panze de corabie cu care se face contrabanda de tigari peste Tisa, cÄƒ daca Casa Poporului si-ar pune lenjerie intimÄƒ un bon d-ala de masa i-ar ajunge ÅŸi ca chiloti, si ca sutien, si ca prosop de baie, ca tot universu ar putea sa isi sufle mucii intr-asa bon de masa indiferent cat ar fi de racit, ca ar trebui trimise bonurile elea de masa in zonele de conflict sa se faca corturi pentru refugiati, ca s-ar putea face pod peste continente dacÄƒ ar fi mai groase, ca daca le intoarce invers ar putea proiecta filme pe care sa le poata vedea din cosmos extraterestrii, ce mai! Ditamai bonurile de masa mai mari ca un A3, MARI.\r\n\r\nSi trimite Cipicao mailu, si ranjeste satisfacut, finca bicoz.\r\n\r\nSi dupÄƒ exact trei minute, intrÄƒ un coleg Ã®n birou cu telefonu fix la ureche \"da, zice, vi-l dau acuma!\" Si ii da lu Cipicao telefonu, si la telefon era ditamai shafu Accor pe Romania, care ii loase numele si telefonu fix din semnatura de la mail! Si care saf o tinut personal sa ii multumeasca lu Cipicao pentru feedbacku sau, si tot personal sa isi ceara scuze sincere pentru disconfortul creat, dar ca s-o schimbat tiparnita la bonuri de masa, si o vreme vor iesi asa dizgratios de mari, si el nu are ce sa faca decÃ¢t sÄƒ Ã®ÅŸi frÃ¢ngÄƒ mÃ¢inile ÅŸi sÄƒ spere, domnule Cipicao, cÄƒ disconfortul creat nu va fi chiar aÅŸa mare ÅŸi cÄƒ se va reveni ASAP la formatul miculuÅ£, ÅŸi ne bucurÄƒm sÄƒ vÄƒ avem de clienÅ£i! Suntem chiar onoraÅ£i, o zi  bunÄƒ.\r\n\r\nSi atunci vÄƒ Ã®ntreb: ce sÄƒ mai zici cÃ¢nd colegu\' MiÅŸu dÄƒ de la el din provizia strategica de sex oral unor retaileri de aparatura nush de care? <a href=\"http://www.doingtheartwork.com/?p=288\" target=\"_blank\">Cetiti si voi</a>!','Sex oral!!!',0,'','publish','open','open','','sex-oral','','\nhttp://www.doingtheartwork.com/?p=288','2008-02-22 15:34:19','2008-02-22 13:34:19','',0,'http://www.groparu.ro/?p=1009',0,'post','',16),(1010,2,'2008-02-21 21:48:20','2008-02-21 19:48:20','Nasii mei, dupa cum va ziceam intr-o postare anterioara, or venit la Cluj. Cum care nasii mei? <a href=\"http://www.groparu.ro/?p=542\" target=\"_blank\">Astia</a>.\r\n\r\nV-am mai zis ca cand vine cineva la Cluj la spitale, vine la oncologie. Da, nase-mea e mai bine acuma dupa operatie. Si si acuma, si cand or fost data trecuta io m-am kinuit cat am putut sa le fie bine, no, cum am putut si io, adica cu bancuri de-ale mele la care nu se rÃ¢de nimeni, niciodata: cÃ¢tÄƒ vreme is ocupati sÄƒ nu rÃ¢dÄƒ la bancurile mele mÄƒcar mai uitÄƒ de nÄƒcaz. Si am mai si pus cate o beutura pe masutza sa ne uitam amaru\', si am mai si cumparat cate o portocala degerata pentru nase-mea cand mergeam la ea, din banii mei de buzunar care-mi raman finca is prea marunti si chelneritzele care ma servesc nu se mai lasa piscate de cur pentru bancnote de 1 leu si fise de 50 bani. Ce, voi v-ati lasa?\r\n\r\nTotu\' o culminat cu o discutie intre mama si nasa-mea: tu finÄƒ, zice nase-mea, asa baiat sufletist ii fiu-tu! <em><strong>N</strong><strong>ici nu stiu cu cine seamana</strong></em><strong> <em>asa sufletist</em></strong><em>.</em>\r\n\r\nSi amu stau un pic sa ma gandesc: oare ii compliment Äƒsta, au ba?','Nasii mei la Cluj',0,'','publish','open','open','','nasii-mei-la-cluj','','\nhttp://www.groparu.ro/?p=542','2008-02-21 21:48:20','2008-02-21 19:48:20','',0,'http://www.groparu.ro/?p=1010',0,'post','',6),(1011,2,'2008-02-25 01:38:27','2008-02-24 23:38:27','Intru gÃ¢fÃ¢ind Ã®n birou, seful se uitÄƒ la mine cu ochi de sticlÄƒ, zice: iar ai intarziat, ÅŸi pufÄƒie.\r\n\r\nMÄƒ opresc. ÃŽi evit privirea, sar Ã®ntr-un picior cu capul Ã®ntr-o parte de parcÄƒ aÅŸ dori sÄƒ imi scot apa din urechi, incep sa ma scarpin furios prin par, ma lovesc este ceafÄƒ repetat ÅŸi obsesiv, undele sonore ale loviturii reverbereaza prin incapere, ma uit la el cu ochii saÅŸii ÅŸi ii zic: baga-mi-as, aud mereu in ultima vreme o voce in capu meu, o voce plÃ¢gÄƒcioasÄƒ care Ã®mi tot spune chestii, o urÄƒsc. ÃŽntr-o bunÄƒ zi voi veni la serviciu cu un AK47 sÄƒ o potolesc, cÄƒÂ  nu o mai suport, ma Ã®nnebuneÅŸte.\r\n\r\nFac o pauzÄƒ strategicÄƒ, savurez momentul cÃ¢nd toÅ£i colegii se uitÄƒ interziÅŸi la mine, Ã®mi alunec privirea tulbure peste ei, ei mÄƒ evitÄƒ, perplecÅŸi. Apoi adaug o frazÄƒ memorabilÄƒ dintr-un mail:\r\n\r\n- <strong>...pentru cÄƒ aÅŸa grÄƒit-a profeÅ£ia!!!</strong>\r\n\r\nE luni dimineaÅ£a.','Cand intarzii la serviciu',0,'','publish','open','open','','cand-intarzii-la-serviciu','','','2008-02-25 01:38:27','2008-02-24 23:38:27','',0,'http://www.groparu.ro/?p=1011',0,'post','',11),(1012,2,'2008-03-03 02:21:54','2008-03-03 00:21:54','1. Pur si simplu te pup din nou pe unde te-am mai pupat si imi dau seama ce gust bun ii dai salivei mele! Ce??? Asta nu e saliva mea??????\r\n\r\n2. Stii ce-mi place cel mai mult la tine? Ca daca te sarut mai pasional si mai profund aflu tot ce ai papat alaltaieri.\r\n\r\n3. Ea: - Dragul meu, iarta-ma, iti pute gura infernal!\r\nEl: - Da, iubito, stiu, mi s-o loat mirosu\' de la gura ta!\r\n\r\n4. (cand ii pui martisorul) Stai linistita, draga mea: nu am ce sani sa impung cu acul de gamalie.\r\n\r\n5. Am incercat sa gasesc un martisor cu pwla mare ca sa iti amintesti de mine mereu, dar nu am gasit, asa ca nu ti-am mai loat, si de banii aia mi-am luat un pachet de tigari.\r\n\r\nFolositi-le, efectul e garantat.','Neste complemente de 1 martisor',0,'','publish','open','open','','neste-complemente-de-1-martisor','','','2008-03-03 02:22:31','2008-03-03 00:22:31','',0,'http://www.groparu.ro/?p=1012',0,'post','',3),(1013,1,'2008-02-26 10:00:22','2008-02-26 08:00:22','Deci azi canci postare - desi unii dintre voi ar zice ca ce am scris acuma tocmai asta e, o postare.\r\n\r\nDeci azi canci postare finca asar\' am beut in <a href=\"http://www.legeneral.ro/\" target=\"_blank\">General</a> cu Cipicao. Si acuma mi-i un pic rau.\r\n\r\nAduceti-mi un ÅŸÄƒf, vÄƒ rog, sÄƒ borÄƒsc pe el.\r\n\r\nPS: Apropos, nu vi se pare ciudat ca toti sefii sunt masculi, si toate sefele sunt femele?','Azi',0,'','publish','open','open','','azi','','','2008-02-26 10:00:22','2008-02-26 08:00:22','',0,'http://www.groparu.ro/?p=1013',0,'post','',9),(1014,1,'2008-02-29 09:15:16','2008-02-29 07:15:16','1. La ÅŸefe: un martisor mega-chicios cu Maica Domnului, pe care nu-l va putea niciodatÄƒ arunca, fincÄƒ aduce ghinion (Doamne, mÄƒ mai ierÅ£i o data, pls? plsplspls???)\r\n\r\n2. La iubita: un martisor cu un bob de orez pe care sÄƒ fie gravat, <a href=\"http://life.hotnews.ro/stiri-acasa-2449932-10-secrete-care-barbatii-nu-spun-femeilor.htm\" target=\"_blank\"><strong>cuvÃ¢nt cu cuvÃ¢nt, tot textul Äƒsta</strong></a>!\r\n\r\n3. La colega aia infecta: un martisor in forma de fecalÄƒ.\r\n\r\n4. La vecina aia studentÄƒ moldoveancÄƒ bunÄƒ, bunÄƒ rÄƒu, da\' bunÄƒ-bunÄƒ rÄƒu-rÄƒu! - un martisor in forma de partidÄƒ de sex.\r\n\r\n5. La tanti aia care sta la parter si stie toate barfele din Cancan: un martisor cu un craniu. De vac mort, of cos!\r\n\r\n6. Mie: un mÄƒrÅ£iÅŸor care sÄƒ-mi deie puterea sÄƒ mÄƒ fac popÄƒ care spovedeÅŸte bunÄƒciuni zilnic, sÄƒ tot ascult ÅŸi sÄƒ mÄƒ minunez!!!\r\n\r\n7. Lu\' Oana ZÄƒvoranul: un zÄƒvor care sa se-nkida in inchisoarea de barbati unde merita ea sa ajunga.\r\n\r\n8. Lu Andreea Esca: un martisor cu violuri, accidente, sex oral in grÄƒdiniÅ£e, Elodia, incendii, spaga filmata cu camera ascunsa, functionari publici care nu-si fac treaba, drumari care dorm Ã®n timpu serviciului, ne-deszÄƒpeziri, animale torturate, petiÅ£ii anti-taxa de primÄƒ Ã®nmatriculare, popi pedofili, subiecte la bac vÃ¢ndute, suporteri violenÅ£i, baroni PSD, nunta lu\' fiu\' lu\' GuÅ£Äƒ, Pavarotti din Banat, cÄƒpÅŸunari, spitale murdare, crizÄƒ de sÃ¢nge Ã®n maternitÄƒÅ£i ÅŸi alte ÅŸtiri care-ncep cu \"Ã®n RomÃ¢nia nici mÄƒcar nu se mai respectÄƒ kljdfgjklfklklfn, iar PoliÅ£iei/Procuraturii/Ministerului nici mÄƒcar nu-i pasÄƒ!!!\"\r\n\r\n9. Tot mie: un mÄƒrÅ£iÅŸor cu gust de telemea de Sibiu (repet, singuru motiv care mÄƒ Å£ine sÄƒ nu emigrez) ÅŸi de zamÄƒ de burtÄƒ de la Kon-Tiki, din Sibiu, da, legendarul Kon-Tiki...!\r\n\r\n10. Tot mie: inelu\' lu\' Arabela, Äƒla de te face invizibil, sÄƒ pot sÄƒ mÄƒ strecor la bunÄƒciunile elea de la punctu\' 6 cÃ¢nd face ele saunÄƒ, ÅŸi sÄƒ mÄƒ tÄƒÄƒÄƒÄƒt uit aÅŸa, ca prostu, ÅŸi apÄƒi sÄƒ-mi zic Gropareeeeeeeee, bÄƒÄƒÄƒÄƒÄƒÄƒÄƒÄƒÄƒÄƒ, bÄƒÄƒÄƒÄƒÄƒÄƒÄƒ... bÄƒutura aproape cÄƒ e zero Ã®n comparaÅ£ie cu priveliÅŸtea asta!\r\n\r\nHappy mÄƒrÅ£iÅŸor everyone.','10 idei de martisoare',0,'','publish','open','open','','10-idei-de-martisoare','','','2008-02-29 09:35:53','2008-02-29 07:35:53','',0,'http://www.groparu.ro/?p=1014',0,'post','',6),(1015,1,'2008-02-29 14:10:52','2008-02-29 12:10:52','Deci rate, nu raÅ£e bancare!\r\n\r\nAm ajuns la o concluzie profunda, dupa ce m-am duelat in rate cu toti colegii mei, si io is cam cel mai cu cele mai rate, pe care le cam si duc singur pe umerii astia negalonati, pe cand ei le duc impreuna cu consortu\'/oarta.\r\n\r\nDeci concluzia mea ie ca: ai rate, esti ratat.\r\n\r\nIo am rate.\r\n\r\nPunct si semnu\' exclamarii!','Discutie despre rate',0,'','publish','open','open','','discutie-despre-rate','','','2008-02-29 14:12:45','2008-02-29 12:12:45','',0,'http://www.groparu.ro/?p=1015',0,'post','',6),(1016,1,'2008-02-29 15:41:39','2008-02-29 13:41:39','Deci.\r\n\r\nNascuta pe februarie douÄƒjnoo\r\nTe-ai maritat cu un mascul cu ditamai oo,\r\nPe malu\' de lacu\' de GilÄƒu\'\r\nÅ¢i-ai loat un mascul cu cÃ¢tamai pwlÄƒu\'!\r\nCu dragoste omu asta iti urez sa te iubeascÄƒ,\r\nCu limba si puÅ£a sÄƒ te fericeascÄƒ,\r\nSÄƒ nu lase la amanet lucruri din casÄƒ gaj,\r\nSÄƒ-Å£i facÄƒ toatÄƒ ziua masaj,\r\nSÄƒ ÅŸtie ce sÄƒ facÄƒ cu al lui aparataj\r\nÅži sÄƒ te Å£ie ca pe-o nevastÄƒ de raj!\r\nSÄƒ nu trebuiascÄƒ sÄƒ speli vase,\r\nSÄƒ Ã®Å£i cumpere vreo 7 case,\r\nSÄƒ fii mai bogatÄƒ ca NÄƒstase,\r\n(Tenismenu\', nu ipochimenu\'),\r\nSÄƒ fii sÄƒnÄƒtoasÄƒ ÅŸi sÄƒ rÄƒmÃ¢i frumoasÄƒ\r\nÅži fertilÄƒ ÅŸi devreme acasÄƒ,\r\nÅži sÄƒ rÄƒmÃ¢i aceeaÅŸi demenÅ£ialÄƒ bucÄƒtÄƒreasÄƒ!\r\nÅži, fincÄƒ azi e ziua ta,\r\nLa mulÅ£i ani, tu, Mariana!','Azi e ziua Marieanei lu\' Tibby',0,'','publish','open','open','','azi-e-ziua-marieanei-lu-tibby','','','2008-02-29 15:41:39','2008-02-29 13:41:39','',0,'http://www.groparu.ro/?p=1016',0,'post','',4),(1017,1,'2008-03-03 10:23:44','2008-03-03 08:23:44','Pentru aia care nu-l stiti, Silvan e ala dupa care moare femeile altora. Ui ce mai face, si ui de ce moare ele, cand moare!\r\n\r\n<script src=\"http://www.trilulilu.ro/embed-video/Silvan/537f85a33873e2\" type=\"text/javascript\" language=\"javascript\"></script> <script type=\"text/javascript\" language=\"javascript\">show_537f85a33873e2(448, 386);</script><strong>Update</strong>: <a href=\"http://www.festivalmigrations.com/page11.html\" target=\"_blank\">http://www.festivalmigrations.com/page11.html</a>','Ce mai face Silvan',0,'','publish','open','open','','ce-mai-face-silvan','','','2008-03-05 13:08:59','2008-03-05 11:08:59','',0,'http://www.groparu.ro/?p=1017',0,'post','',11),(1018,1,'2008-03-04 11:11:24','2008-03-04 09:11:24','Daca va alegeti babÄƒ anu\' asta, verificaÅ£i Ã®nainte prognoza meteo pe Yahoo Weather.','Sfatu\' zilei',0,'','publish','open','open','','sfatu-zilei','','','2008-03-04 11:11:24','2008-03-04 09:11:24','',0,'http://www.groparu.ro/?p=1018',0,'post','',8),(1019,1,'2008-03-04 16:45:38','2008-03-04 14:45:38','<p align=\"left\">Ploua infernal\r\nSi tu te nasteai\r\nPrin spitale\r\nIn luna lui Marte!\r\n\r\nSÄƒ nu stai la cozi cu pensionari,\r\nSÄƒ nu ai niciodatÄƒ ÅŸefi mÄƒgari,\r\nSÄƒ nu ÅŸtii ce-nseamnÄƒ un spital,\r\nSecretarÄƒ sÄƒ-Å£i fie Cabral,\r\nSÄƒ conduci Bugatti, limuzinÄƒ,\r\n<a href=\"http://www.andreicrivat.ro\" target=\"_blank\">Andrei</a> sÄƒ-Å£i zicÄƒ \"Da, stÄƒpÃ¢nÄƒ!\"\r\nS-aveÅ£i casÄƒ aci, in Cluuuuuj,\r\nBuzele tele sÄƒ n-aibÄƒ nevoie de ruj,\r\nToata viaÅ£a sÄƒ te-nveseleÅŸti,\r\nCopii mulÅ£i ÅŸi faini sÄƒ prÄƒseÅŸti,\r\nSÄƒ ai conturile pline de bani,\r\nÃŽn viaÅ£Äƒ sÄƒ n-ai duÅŸmani,\r\nÅži s-aveÅ£i prieteni barosani!\r\nÅži fincÄƒ va dura un secol pÃ¢nÄƒ sÄƒ ajungi la a vieÅ£ii toamnÄƒ,\r\nNoi Ã®Å£i spunem: LA MULÅ¢I ANI, TU DOAMNÄ‚!\r\n<p align=\"left\">&nbsp;</p>','Azi e ziua D-nei Crivatz, care de fapt e-o doamnÄƒ!',0,'','publish','open','open','','azi-e-ziua-d-nei-crivatz-care-de-fapt-e-o-doamna','','','2008-03-04 16:45:38','2008-03-04 14:45:38','',0,'http://www.groparu.ro/?p=1019',0,'post','',6),(1020,1,'2008-03-05 13:05:50','2008-03-05 11:05:50','Un hÃ¢tru zicea cÄƒ <strong>Sandero </strong>vine de la \"detergent sanitar\". Noi, Groparu, nu comentam.\r\n\r\nComentÄƒm Ã®n schimb despre noul logo Dacia, pe care il puteti vedea <a href=\"http://www.etcetering.com/2008/03/04/what-a-rebranding%e2%80%a6/\" target=\"_blank\">aici</a>. Cica noul logo e de fapt un desfacator de bere, si cÄƒ hÄƒ-hÄƒ-hÄƒ.\r\n\r\nNimic mai greÅŸit. Se ÅŸtie cÄƒ ÅŸoferii de Dacie fac grÄƒtar Ã®n faÅ£a blocului, ascultÄƒ Florin Salam, papÄƒ sanviÅŸuri cu parizer ÅŸi <strong>beau bere la PET</strong> - deci nu au nevoie de desfÄƒcÄƒtor.\r\n\r\nCum de ÅŸtiu aceste lucruri? Ei bine, ÅŸtiu pentru cÄƒ ÅŸi eu am de gÃ¢nd sÄƒ imi iau Dacie, ÅŸi Ã®n acest scop mÄƒ antrenez zilnic desfÄƒÅŸurÃ¢nd activitÄƒÅ£ile descrise mai sus.','Noul logo Dacia',0,'','publish','open','open','','noul-logo-dacia','','\nhttp://www.etcetering.com/2008/03/04/what-a-rebranding%e2%80%a6/','2008-03-05 13:05:50','2008-03-05 11:05:50','',0,'http://www.groparu.ro/?p=1020',0,'post','',7),(1021,1,'2008-03-11 16:26:03','2008-03-11 14:26:03','Sefii, cand vin la tine, vin cu doua falci in cer si cu una in pamant: ei au mai multe maxilare acoperite de dinti.\r\n\r\nSefii sunt alunecosi si <em>slimy</em>, si au corpul acoperit cu solzi. Degetele lor se termina cu ghiare de pasare de prada.\r\n\r\nSefii au limba bifurcata.\r\n\r\nSefii au cioc cu care se hranesc din ficatii tai. Asa se hranesc sefii.\r\n\r\nSefii, cand e soare afara, sunt binedispusi; daca insa ploua afara, ti le vei incasa. De aici deducem ca sefii sunt foarte meteosensibili.\r\n\r\nDaca vezi un sef la strand, vei vedea ceva ce nu ai observat pana acum: o pereche imensa de aripi de liliac, pe care de regula le ascund sub costum. Multumita lor, sefii nu intarzie niciodata.\r\n\r\nE dezonorant pentru un sef sa rÃ¢dÄƒ la bancurile tele. Deci nu o va face.\r\n\r\nSefii sunt varianta <em>corporate</em> a fostului meu diriginte, fostul director comunist al scolii generale detronat de Lovilutia din \'89, si care nu si-o mai revenit niciodata din soc.\r\n\r\nIn Romania avem foarte putini manageri si foarte, foarte multi sefi.','Despre sefi',0,'','publish','open','open','','despre-sefi','','','2008-03-14 15:19:39','2008-03-14 13:19:39','',0,'http://www.groparu.ro/?p=1021',0,'post','',19),(1023,1,'2008-03-06 09:46:44','2008-03-06 07:46:44','O grÄƒmadÄƒ, d-aia blogu mi s-o cam lasat pe tÃ¢njalÄƒ, ÅŸi bine-o fÄƒcut!Printre altele, fusai ieri la lansarea aripelor germane, sau cum â€˜mniezau se traduce numele la firma aia de-i zice Germanwings, care s-or lansat cu trasee Cluj-Koln, finca or auzit si ei ca romanii is traseisti, si iei chiar ie!\r\n\r\nSi la conferinÅ£a de presÄƒ (scrisÄƒ, nu de ulei), discursuâ€™ strainez l-o tinut un Frantz Dietrich destul de neamÅ£, care ii ceva mare goangÄƒ pe la iei pe la ferma de avioane low-cost. Åži care nenea o fÄƒcut tot ce o putut ca sÄƒ iasÄƒ prezentarea ÅŸtaif, ÅŸi o eschivat cu dibÄƒcie Ã®ntrebarea unui jurnalist cÄƒ ce pÄƒrere are el cÄƒ s-o mutat Nokia din Germania Ã®n Cluj, ÅŸi alte ÅŸele. Åži o mai zis cÄƒ numele Germanwings vine cÄƒ s-or gÃ¢ndit ei, nemÅ£ii, la o bere ieftinÄƒ (nemÅ£ii Ã®z ueber-zgÃ¢rciÅ£i) cÄƒ dacÄƒ fondeazÄƒ o companie de zboruri aeriene, ce nume sa-i puie? Pai sÄƒ Ã®i zicÄƒ aripe, de la wings, si German, ca sa inspire calitate. Am vrut sa il intreb daca se gandea la calitatea masinii germane zisa Trabant (maÅŸina aia din cartoane presate, cartoane d-elea de se acoperÄƒ homleÅŸii cÃ¢nd e rÄƒcoare afarÄƒ), daâ€™ nu am mai apucat.\r\n\r\nCe vroiam io numa sa va zic: nenea o tot incercat sa iasa cum trebe prezentarea, o ÅŸi bÄƒgat un spirit de glumÄƒ care uneori i-o ieÅŸit (alteori i-o intrat), daâ€™ totuâ€™ s-o cam dus pe apa sÃ¢mbetei cÃ¢nd - oroare! - Ã®n prezentarea PowerPoint cu harta RomÃ¢niei, proaspÄƒt conectatÄƒ la reÅ£eaua de zboruri internaÅ£ionale Germanwings, oraÅŸul Cluj-Napoca apÄƒrea hÄƒpt prin Ã®ntorsura BuzÄƒului. Claro cÄƒ toÅ£i clujenii care erau ÅŸi prezenÅ£i, ÅŸi ziariÅŸti (care, Ã®ntre noi fie vorba, cred cÄƒ tÄƒrie cÄƒ Dubaiul e o copie Ã®n miniaturÄƒ a oraÅŸului de pe SomeÅŸ River, ÅŸi cÄƒ Shenzen e un soi de MÄƒnÄƒÅŸtur mai modest), or Ã®nceput sÄƒ vocifereze!!! Vaaai, sÄƒ nu ÅŸtii tu, ditamai neamÅ£u, cÄƒ Cluju, mah, Cluuuuju, ii aÅ£Äƒ-n partea de centru nord jos stanga est a Ardealului! Åži ca lucrurile sÄƒ meargÄƒ nemÅ£eÅŸte, la urmÄƒtorul <em>slaid</em> de PowerPoint, Cluj-Napoca o apÄƒrut, mÄƒi frate, aÅ£Äƒ lÃ¢ngÄƒ Burgas!!! Burgas care, <a href=\"http://www.groparu.ro//?p=53\" target=\"_blank\">ultima datÄƒ cÃ¢nd am verificat</a>, era fix, daâ€™ fix la graniÅ£a cu Marea NeagrÄƒ!\r\n\r\nAtÃ¢tea behÄƒieli de protest nu am auzit nici cÃ¢nd am mers beat in cancelarie si le-am propus la diriga mea ÅŸi la profa de francezÄƒ sÄƒ se sÄƒrute pasional - nu mai ÅŸtiu Ã®n ce clasÄƒ sau Ã®n ce vis eram.','Ce am mai patit in ultima vreme',0,'','publish','open','open','','ce-am-mai-patit-in-ultima-vreme-2','','\nhttp://www.groparu.ro//?p=53','2008-03-06 10:38:16','2008-03-06 08:38:16','',0,'http://www.groparu.ro/?p=1023',0,'post','',17),(1024,1,'2008-03-07 16:39:56','2008-03-07 14:39:56','Frati nuntasi, dupa un chef cu coperativa az\' noapte, vine - ati ghicit! - weekendu\'.\r\n\r\nAsa ca ma car la Sibiu la Orlat la beute la mancat la distrat si la rÃ¢s, vom face cea mai tocanitza de carne de oaie si vom face ghiogÃ¢rÅ£ cu telemea de oaie de Sadu (the best there is - stiti voi, e branzica aia care violeaza anal in fund orice branza frantuzeasca) - finca merg cu <a href=\"http://www.andreicrivat.ro\" target=\"_blank\">Crivatzu</a> si vin si dobitocii mei de prekini de-acolo, care chiar is dobitoci, si vom suspina oftand si gandindu-ne.\r\n\r\nLa ce ne vom gÃ¢ndi noi, cand ne vom gÃ¢ndi?\r\n\r\nNoi, cand ne vom gandi, ne vom gandi la postul Pastelui care vra sa inceapa - luni. Si pe care, in pofida ciudei faptului ca sunt beutor Ã®nvederat, am sÄƒ Ã®l Å£in, aÅŸa cum l-am Å£inut si anu\' trecut, ÅŸi mi-o ieÅŸit faza. Deci de luni canci carne, oo, lapte, telemele, beuturi, cioco bun si alte placeri lumesti - cel putin elea care tin de ce poti face cu gura. Urmeaza 48 de zile de sobrietate agonizatoare, de pateu de soia si placinte cu varza, fara beuturi. Dupa care urmeaza - firesc in calendarul nostru - Tiganieada, mÃ¢nc-o mama.\r\n\r\nWeekendu urmator vreau sa merg la un pescuit, da\' musai sa imi fac vreme si de <a href=\"http://turambarr.blogspot.com/\" target=\"_blank\">Turambarr</a>, care tre\' sa vie la Cluj, si tre\' sa ma-ntalnesc cu iel, trebuia sa-l bag si prin blogroll, finca mi-am dat spaga si mi-am promis ca il bag, da\' nu se putu finca mi se buli wordpressu si pana am vreme sa-l repar mai dureaza, finca is foarte ocupat zilele astea, ce, nu se vede ce postari naspa bag?\r\n\r\nSi il voi dezamagi cand isi va da seama ce anost is io cand nu beau, ca si mie mi-i uneori lehamite de mine, cum de alfel le e la toate femeile care ma cunoaste!!!','Deci, weekendu\' asta',0,'','publish','open','open','','deci-weekendu-asta','','','2008-03-08 00:11:46','2008-03-07 22:11:46','',0,'http://www.groparu.ro/?p=1024',0,'post','',13),(1025,2,'2008-03-11 02:02:12','2008-03-11 00:02:12','Azi.\r\n\r\nDeci mie de ceva vreme lucrurile imi merg parca in ciuda pixului, si is enervant de extenuat, lucru despre care va puteti da si voi seama, finca scriu asa de naspa ca deja ma cred un Balzac in faza lui ante-embrionara.\r\n\r\nSi azi, colac peste pupaza, viu acasa, si canci Internet! Grrrrr.\r\n\r\nClar ca ma apuc sa-l repar, asa cum face orice roman care schimba becuri, repara clantze si mai stie sa se si futa. Si dupa ce ma tat chinui si vad ca tat nu vrea nijcum, in disperare de cauza pun labutza pe mobilu\' meu ala dajtept, si sun la interventii UPCiste. Si acolo, o demoazela, of cors, eterna demoazela platita cu 4 milioane pe post de call centeritza, raspunde. Si ne apucam:\r\n\r\n- Aveti cumva setat DHCP-u\' si IP pe automat?\r\n- Daaaa, zic io, tocmai le verificai, si am dat si un ipconfig din cmd.\r\n- Bun, zice iea. Ati umblat cumva la Windows?\r\n- Nuuuu, zic io.\r\n- Ce Windows folositi?\r\n- Ala a lu Bill Gates, zic io.\r\n- Asa deci, zice demoazela. Nu ati umblat la cablu, mufe...?\r\n- Nu... zic io.\r\n- Ce vreau sa va rog, zice. Scoateti din priza 10 secunde modemu\'.\r\n- Am facut si asta, zic, l-am restartat, dar o mai fac o data... Gata, zic io dupa 10 secunde, amu il, scuzati de expresie, bag la loc.\r\n- Foarte bine, zice d-ra, merge?\r\n- Nu, zic io. Niic.\r\n- Vai, zice ea, atunci va trimit o echipa de interventie sa va rezolve, vor veni miercuri dupa 0rele 18... o zi buna...!\r\n- Pa, zic io, saru\'mana.\r\n\r\nSi stau si ma gandesc: ce dreq fac io zilele astea fara Internet?\r\n\r\nSi-mi pica fisa: ma intrept catre modem, si apas foaaarte usor butonu\' de Power, si conexiunea se restabileste mai bine ca inainte.','Mi-o picat Internetu\'',0,'','publish','open','open','','mi-o-picat-internetu','','','2008-03-11 02:02:12','2008-03-11 00:02:12','',0,'http://www.groparu.ro/?p=1025',0,'post','',19),(1026,1,'2008-05-12 22:51:45','2008-05-12 20:51:45','Deci nu o sa va vina sa credeti.\r\n\r\nDeci io fusai bursier al statului roman in Danemarca unde, dupa cum se stie, ceva e putred, cÄƒ ÅŸi Hamlet ÅŸi-o dat seama!\r\n\r\nIs sigur ca nu o sa va vie sa credeti ce am patit p-acolo.\r\n\r\nEra intr-o sambata seara daneza, si io n-am iesit in oras: finca ieream mega sarantoc (am baut 3 beri in 5 luni, deci va dati seama ce albastra era situatia, cÄƒ toata viaÅ£a mea am fost sÄƒrac lipit), stateam acasa ÅŸi lucram la ceva eseu. Åži prin jur auzeam numa strigÄƒte de daneji beti, ca asa era prin campus, se imbatau danezii ca porcii, si urlau.\r\n\r\nSi suna cineva la usa. Si ma duc sa raspund, si afara erau - of cors - doua gajici. Daneze, deci supraponderale. Da\' faine la fatza.\r\n\r\nSi una imi zice: K:L:L&lt;\":&lt;&gt;\":OL)_)_)POKPO?\r\n\r\nEnglish, ii zic io.\r\n\r\nSalut, zice ele, il cautam pe Soren Mikkelsen (colegu meu de apartament, ca noi aveam la sonerie numele noastre puse, sa se stie cine ce e).\r\n\r\nTu fetelor, zic io, nush unde umbla asta, ca io l-am vazut numa de vreo 3 ori in 4 luni, zic.\r\n\r\nAha, zice ele. Da\' nu stii ceva baiat blond care sa steie prin zona?\r\n\r\nPai, zic io. Io is otzara blond - si le arat pata mea de par blond, care este, ca io asa is nascut, cu o pata de par blond in spate, la cap, pe par (cat par mai am, ca deja am inceput sa ma razboiesc cu un inceput de chelie, si el cam invinge).\r\n\r\nSuper, zic ele. Vii cu noi sa bei un body tequila?\r\n\r\nCe-i aia, zic io. Daca va trebuie rinichiu\' meu, n-ati nimerit bine!!!\r\n\r\nNu mah, zic astea. Ia pune ceva pe tine (ca stateam in bicepsii goi prin zapada daneza, care imi biciuia pectoralii) si hai cu noi.\r\n\r\nPun un Å£ol pe fizic, mÄƒ iau dupÄƒ ele. Lipa-lipa, lipa-lipa! Prin zapada danezÄƒ.\r\n\r\nSi ma baga intr-o camera (era 11 noaptea) in care mai erau trei gajici, ca asa s-or hotarat gajicile elea, sa faca chef numa ele 5, fara masculi. Doua erau faine de pici, si mai era una albinoasa, alba in cap de atata albinosenie! Si asta era si un pic cea mai hidoasa dintre ele.\r\n\r\nGhici careia ii trebuia sa faca body tequila, despre care io nu prea stiam cu ce se mananca.\r\n\r\nClar - la albinoasa hidoasa.\r\n\r\nSi io, finca-s prost si nu stiam cu ce se mananca body tequila, da\' tropaiau hormonii prin mine, zic: gata, mah! Facem body tequila. Si ma pune fetele pe scaun, si imi explica: gajica asta albinoasa si hidoasa o zis ca nu bea tequila, decat daca o face body tequila de pe un trup tanar de mascul blond! Si finca masculii frumusei si blonzi din camine nu stateau ei acasa sambata seara, ca erau plecati sa se fornicaie si sa se imbete, io, finca eram cel mai disponibil si cu petic de par blond, tre\'a sa ii dau la fata body tequila!\r\n\r\nSi am zis: plm, mÄƒ sacrific pentru prietenia popoarelor domanesti si danezesti!\r\n\r\nSi cand le ziceam la fete chestiile astea, plus ca io-s din Romania, si noi inca nu suntem tzara catolica, ÅŸi cÄƒ da, suntem Ã®n Europa, albinoasa hidoasa face <em>shhhffiiiieeee</em>!!!! si Ã®mi parleÅŸte o limba peste gÃ¢Å£i, la carotidÄƒ, unde se gÃ¢dilÄƒ voinicu\'; io mÄƒ panichez, da\' am zis ca la cat o suferit stramosii mei care s-or batut cu rusii la Stalingrad si cu nemtii Ã®n muntii Tatra si cu turcii prin pivniÅ£ele lui Stefan cel Mare, mai pot suferi ÅŸi io o limbÄƒ lipicioasÄƒ de danezÄƒ! Åži daneza continuÄƒ ce trebÄƒluia ea p-acolo pe la gÃ¢Å£ii mei, ÅŸi imi strokeÅŸte gÃ¢Å£ii linÅŸi de ea cu sare, ÅŸi face Ã®ncÄƒ o datÄƒ: <em>shhhffiiiieeee</em>!!!! ÅŸi mÄƒ lasÄƒ fÄƒrÄƒ pic de sare pe grumaji! Åži dÄƒ, aÅŸa beatÄƒ muci cum era ea, duÅŸcÄƒ pe gÃ¢Å£ii ei un ÅŸot de tequila, ÅŸi colejele ei Ã®i aplaudÄƒ corajul ei ÅŸi corajul meu, cÄƒ m-am lÄƒsat Ã®n halul asta lins pe gÃ¢Å£i de o danezÄƒ albinoasÄƒ hidoasÄƒ!\r\n\r\nÅži pentru cÄƒ am fost baiet cuminte am primit un Tuborg la 330 ml, cÄƒ aÅŸa beau ÄƒÅŸtia berea, la gramaje meschine; ÅŸi m-or chemat la bar cu ele, cÄƒ ele tocmai ieÅŸeau, ÅŸi le-am zis cÄƒ le multumesc frumos, da\' astept pe cineva acasa (asteptam pe naiba, da\' n-aveam bani de cheltuit prin bare, si mi-era si frica de muream de albinoasa-hidoasa, cÄƒ io am avut tot felu de experiente cu tot felu de femei, si cine stie ce mai iesea si cu aia!!!), si am Å£Ã¢jnit acasÄƒ, fÄƒrÄƒ sÄƒ am habar cÄƒ Ã®ntr-o bunÄƒ zi voi apuca sÄƒ scriu despre aventura asta dintr-o noapte danezÄƒ viforoasÄƒ pe blogul meu, nÄƒscut din aventurile mele care este.','Ce-am patit cand eram prin Danemarca',0,'','publish','open','open','','ce-am-patit-cand-eram-prin-danemarca','','','2008-05-12 22:51:45','2008-05-12 20:51:45','',0,'http://www.groparu.ro/?p=1026',0,'post','',15),(1027,1,'2008-03-13 16:07:08','2008-03-13 14:07:08','<a href=\"http://www.setimes.com\" target=\"_blank\">www.setimes.com</a> ii un site foarte fain, scris dupa regulile jurnalismului saxon. anglo-saxon, din care orice persoana care doreste sa isi imbunatatasca engleza are ce invatza, finca ii fain! Is stiri din sud-estu\' Europei, si engleza in care is scrise cam ruleaza.\r\n\r\nSi intr-o zi, ma apuc sa trimit vreo doua mailuri pe la cate un prekin (pe vremea aia inca nu iegzista blog, si ne scriam mailuri d-elea kilometrice). Si dupa ce le trimit, citesc stirile din SETimes, mÄƒ mai fÃ¢Å£Ã¢i, mai scobesc un pic nasu\', iau o coada de furculita ca sÄƒ pot ajunge Ã®n locurile alea mai greu accesibile, ma mai chinui un pic, si apÄƒi imi zic: hai mÄƒ sa le dau la aÅŸtia un feedback pozitiv! Ca asa jurnalism fain si imparÅ£ial fac astia, de numa, si trebe sa le multumesc, ca imi scot de pe saitu\' lor expresii bengoase, cu care ameÅ£esc studentele (in perioada aia eram prof, si predam, finca asta fac profii, predau, nu <strong>se</strong> predau).\r\n\r\nÅži ma apuc si scriu mailu, ca felicitatiuni, sunteti rulÄƒtori, as vrea sa ma fac ca voi cÃ¢nd voi fi mare, sunteÅ£i mega-imparÅ£iali ÅŸi cumsecazi, pun pariu ca aveÅ£i ÅŸi tÃ¢Å£e mari, pisdele strÃ¢mpte ÅŸi ÅŸi pielea fina ÅŸi frumos mirositoare!\r\n\r\nAtÃ¢ta numa cÄƒ cÃ¢nd am trimis mailu, nu am pus nimic in cÃ¢mpul Subject, ÅŸi o rÄƒmas vechiul subject de la mailul anterior, trimis unui prekin cu care imi permiteam sa ma iau la puÅ£ulici! Åži primesc ÄƒÅŸtia, mai tatÄƒ, <em>setimeÅŸii</em>, mail scris Ã®n engleza mea (pe care o rafinasem) ireproÅŸabil de laudativÄƒ ÅŸi de - oricum - corectÄƒ ÅŸi fainÄƒ,  numa\' in <em>subject line</em> se lÄƒfÄƒia, mÄƒre, un <strong>WAZAAAAAAAAA, MA PULAAA!!!!</strong> Ca noi asa ne salutam pe vremea aia, ca facuse furori prin gasca noastra reclama aia la Budweiser, cu waaaazzzaaaaaaaaa!\r\n\r\nSi am primit inapoi un raspuns foarte diplomat de la www.SETimes.com, cum ca imi multumesc pentru feedback si imi doresc mult succes.','AceastÄƒ postare nu e inspiratÄƒ dintr-o ficÅ£iune realÄƒ!',0,'','publish','open','open','','aceasta-postare-nu-e-inspirata-dintr-o-fictiune-reala','','','2008-03-13 16:07:08','2008-03-13 14:07:08','',0,'http://www.groparu.ro/?p=1027',0,'post','',7),(1028,1,'2008-03-14 13:53:05','2008-03-14 11:53:05','Este tipul inÄƒsprit de lidÄƒr. Un fel de Ilarion Ciobanu, dar fara mustatza, prestatia, statura, privirea sa si practic fara nimic din ce il face pe Ilarion Ciobanu sa fie Ilarion Ciobanu.\r\n\r\nDacÄƒ ar fi jucat in filmu\' Dacii, ar fi fost Bicilis: \"in nemernicia mea...\"\r\n\r\nStie sa se faca neplacut ca nimeni altu\'.\r\n\r\nUneori imi vine sa pun asa o frÃ¢nÄƒ incÃ¢t sÄƒ se lipeascÄƒ cu capu\' - nu de parbriz, ci de ÅŸliÅ£u\' meu.\r\n\r\nAlteori as vrea sa-l vad beat muci ÅŸi inconstient, sÄƒ il las in curu\' gol si sa ii inÅ£Äƒp curu\' cu ÅŸtergÄƒtoarele de Logan.\r\n\r\nAm si momente cand l-as arunca intr-o puscarie de gay, sa fie violat de negri in ritmuri tribale, la foc de tabara din saltele.\r\n\r\nAsa o relatie speciala am eu cu omu asta, ca i-am cerut voie sa il infiez - ca sa pot s-o f** pÄƒ mÄƒ-sa fÄƒrÄƒ  sÄƒ-mi plÃ¢ngÄƒ disperat prin baie.','Instructorul meu auto',0,'','publish','open','open','','instructorul-meu-auto','','','2008-03-14 14:15:15','2008-03-14 12:15:15','',0,'http://www.groparu.ro/?p=1028',0,'post','',11),(1029,2,'2008-03-16 11:22:32','2008-03-16 09:22:32','Deci, ca sa pricepeti mai bine cum stau lucrurile cu ungurii.\r\n\r\nEram in Cluj, prin anu 2 sau 3 de faculta, tocma bagasem o tura de piata la Mihai Viteazu sa imi ieu salata (descoperisem o reteta de zamÄƒ de salata apsolut dementiala, cÄƒ ÅŸi acuma Ã®mi lasÄƒ gura apÄƒ) ÅŸi legume ÅŸi slanÄƒ ÅŸi telemea, ÅŸi mÄƒ sui Ã®n troleu, plin de sacose din care se iÅ£eau ba frunze de usturoi verde, ba de ceapÄƒ - tot verde.\r\n\r\nClaro, stam cu morcovu infipt sub nada curului, cÄƒ din pix bilet - ÅŸobolan am fost toatÄƒ studenÅ£ia, ÅŸi mult mai ÅŸobolan am fost dupÄƒ studenÅ£ie, cÃ¢nd am ajuns sÄƒ fiu chiar mai sireac decÃ¢t un student - fincÄƒ eram <em>prÄƒfiesÄƒr</em>. Åži mÄƒ uit Ã®n jur, spionez dupÄƒ controlori (controlorii, Ã®n Cluj, au geci negre ÅŸi ceafÄƒ groasÄƒ de maneliÅŸti si se scurmÄƒ Ã®n nas Ã®ntr-un fel aparte, cÄƒ scrie Ã®n statutu\' lor de controlori), nu vÄƒd pe nici unu, zic las\' ca-i bine, mÄƒ mai uit in jur, si langa mine o tanti imi zambeste. Si ma uit la ea, si imi zice ceva in maghiara. Pentru cei care nu ati auzit niciodata maghiara, limba asta suna cam asa:\r\n\r\n\"kekerekerekekrreekree!\"\r\n\r\nIo ma uit la ea in continuare, si apoi ma uit in jur. Eram in plina epoca Funar: banci tricolore, steaguri tricolore pe toti stalpii (am sa va zic mai incolo doo faze tari cu steagurile funaresti), totul respira nationalism si sloganul preferat era <em>afara, afara cu ungurii din tzara</em>. Si imi trag aer in piept, si ii zic inapoi la tanti, rÄƒstit, ca un jicnit Ã®n propria mea Å£arÄƒ:\r\n\r\n- Da\' de ce nu vorbiti romaneste???\r\n- Vai, zice ea, si incepe sa rada cu un ras foarte cumsecade, ma scuzati, zice, uitati aici, am un bilet gata compostat de la o prietena de-a mea care tocmai a coborat, daca vreti sa va compostati biletul nu o mai faceti! Si imi intinde biletul prietenei ei.\r\n\r\nNu are rost sa va mai zic ca m-am simtit ca un magar - o senzatie cu care, de-a lungul timpului, am inceput sa ma obisnuiesc. Si i-am multumit cu \"multumesc\", si ea mi-a ras inapoi cu pofta, un ras de femeie cumsecade, in semn de \"cu placere\".\r\n\r\nDeci acuma sper ca ati inteles cum stau lucrurile, nu numai cu maghiarii, ci si cu ungurii.','Un tanar maghiar a fost batut de ziua lor (ÅŸi a lui) nationala',0,'','publish','open','open','','un-tanar-maghiar-a-fost-batut-de-ziua-lor-si-a-lui-nationala','','','2008-03-16 21:04:15','2008-03-16 19:04:15','',0,'http://www.groparu.ro/?p=1029',0,'post','',28),(1030,1,'2008-03-18 12:15:52','2008-03-18 10:15:52','SÄƒ mereÅ£i sÄƒ vedeÅ£i filmu\', sÄƒ vÄƒ rÃ¢deÅ£i.\r\n\r\nÃŽn primu rÃ¢nd fincÄƒ ii o corcealÄƒ de film dintre basmu Äƒla cu Gheonoaia a lu Petre Ispirescu (atÃ¢ta numa ca Ã®n film le zice mamuÅ£i la gheonoi), Apocalypto a lu\' Mel Gibson ÅŸi orice-alt-film-bazat-pe-cÄƒutarea-freudianÄƒ-a-tatÄƒlui-ÅŸi-drumul-iniÅ£iatic-al neofitului.\r\n\r\nÃŽn al doilea rÃ¢nd fincÄƒ traileru\' ii piÅŸarea lumii: Roland Emmerich are grija sÄƒ Ã®Å£i demoleze orice tendinta de a ficÅ£ionaliza filmu, de a te transpune Ã®ntr-o lume primordialÄƒ frumoasÄƒ  ca si o poveste frumoasa prin demolarea oricarei fictiuni, fincÄƒ Ã®Å£i zice de la bun Ã®nceput \"FILMU Ä‚STA E PLIN DE TRUCAJE!!!\".\r\n\r\n<object width=\"360\" height=\"296\"><param name=\"movie\" value=\"http://video.cinemagia.net/v/826150\"></param><param name=\"wmode\" value=\"transparent\"></param><embed src=\"http://video.cinemagia.net/v/826150\" type=\"application/x-shockwave-flash\" wmode=\"transparent\" width=\"360\" height=\"296\" ></embed></object>\r\n\r\nDeci v-ati dat seama: tre\' sa veniti sa vedeti filmu, vinkÄƒ am vÄƒgut mult arbeit la film, und das ist gut! Bicos arbeit ist fehhry impoootÄƒnt.\r\n\r\nÅži Ã®n al treilea rÃ¢nd: fincÄƒ soluÅ£ia finalÄƒ a filmului este ca fraÅ£ii negri sÄƒ se lase conduÅŸi de fraÅ£ii albi, mai dÄƒjtepÅ£i, impotriva - da! - Ã®mpotriva unor oameni cu trÄƒsÄƒturi de arÄƒboci, care mai ÅŸi poartÄƒ turbane pe cap. Åži vorbesc aÅŸa, o proto-arÄƒpeascÄƒ.\r\n\r\nAsta ca sÄƒ nu mai zic cÄƒ mi-a fost ÅŸi mie dat sÄƒ vÄƒd o gaÅŸcÄƒ de mamuÅ£i care fug la galop ca niÅŸte maidanezi, mÃ¢nca-Å£-aÅŸ, cÄƒ m-am stricat de rÃ¢s! SÄƒ le spuneÅ£i elefanÅ£ilor care nu pot galopa nici mÄƒcar deloc cÄƒ strÄƒmoÅŸii lor fuserÄƒ cu mult mai coioÅŸi, ÅŸi cÄƒ ÅŸi-or fÄƒcut neamu\' pachidermilor de toatÄƒ groaza.\r\n\r\nPS: ar mai fi de zis despre Phororacus (ciorile elea preistorice din film care vor sa isi umple pipota cu carne de om) care is de 4 ori mai inalte decat palmierii; despre mamutii pe care ii sinucizi cu o tepuÅŸÄƒ de fÄƒcut frigÄƒrui; despre mamuÅ£ii care nu se vÃ¢nau prin Ã®mpinsu turmei cÄƒtre prÄƒpastie, ci Ã®n trÃ¢ntÄƒ voiniceascÄƒ, ÅŸi cÃ¢Ã¢Ã¢te ÅŸi mai cÃ¢te...!','10.000 Ã®.e.n.',0,'','publish','open','open','','10000-ien','','','2008-03-18 12:29:21','2008-03-18 10:29:21','',0,'http://www.groparu.ro/?p=1030',0,'post','',12),(1031,2,'2008-03-19 00:07:54','2008-03-18 22:07:54','Deci finca io is super mega plin de mine, nu prea tin minte numele celor cu care fac cunostinta. Daca ma intrebi cum il cheama pe personul care tocmai mi-a fost prezentat, ai sanse 9 din 10 sa auzi nume de fata, mai ales daca respectivul e baiat. In afara de cazu\' in care e vorba de <a href=\"http://www.groparu.ro/?p=87\" target=\"_blank\">nume cu adevarat memorabile</a>.\r\n\r\nAzi merem la folbal. Si apare un ficior nou, dÄƒ noroc cu noi, uit cum Ã®l cheamÄƒ. Ca sa fiu sigur, intreb:\r\n\r\n- Ba, zic, cum o zis, mah, Äƒsta cÄƒ Ã®l cheamÄƒ?\r\n- Marius, mah, Marius.\r\n- Nu Mircea?\r\n- Tu esti prost? Cum sa-l cheme Mircea?\r\n- Ba, zic io, mie Mircea mi se pare ca mi-o zis.\r\n\r\nMai vine un coleg-doi, fac ÅŸi ÄƒÅŸtia cunoÅŸtinÅ£Äƒ cu omu.\r\n\r\n- Cum il cheama mah pe om? Ã®i Ã®ntreb. CÄƒ am uitat.\r\n- A, pe Mihai? Mihai Ã®l cheamÄƒ.\r\n- BÄƒ, zic, sigur???\r\n- Da, mÄƒ, ej prost?\r\n\r\nÃŽnainte de meci, mÄƒ duc la budÄƒ, sÄƒ nu mÄƒ piÅŸ pe echipa adversÄƒ Ã®n timpu\' meciului. ÃŽl intreb pe colegu\' care tocmai ÅŸi-o scutura (pe ea, pe ÅŸefÄƒ):\r\n\r\n- BÄƒ, cum Ã®l cheamÄƒ pe asta nou\', mah? Ca nu i-am auzit bine numele.\r\n- A, pe Miklos? Miklos il cheama, Ã®i cool. ÃŽi OK.\r\n- Deci Miklos Ã®l cheamÄƒ, zic, mi s-o pÄƒrut mie cÄƒ Ã®i ceva cu M. Deci nu m-am ramolit de tot.\r\n\r\nÃŽn timpu meciului, am o coliziune frontalÄƒ cu individu\', ne lovim pÄƒlindu-ne unu de celalalt, ne vÄƒitÄƒm, cerem ambulanÅ£Äƒ, tribunele aruncÄƒ petarde pe gazon, etc.\r\n\r\n- BÄƒ, Laurentiu Cecil Eusebiu Matusalem, zic io, scuze! (la folbal io-s pastÄƒ, ÅŸi Ã®mi asum foarte cavalereÅŸte orice fault)\r\n- ScuzÄƒ-mÄƒ tu, zice el, plin de cumsecÄƒdenie, da\' vezi ca ma cheama Cristi!\r\n- Aaaaa, Cristi, zic io, normal, claro.\r\n\r\nM-am ridicat de jos, plin de obidÄƒ. Nu i-am zis nimica, pe moment. Da\' la finalu\' folbalului i-am zis:\r\n\r\n- Prekine, zic, te superi dacÄƒ de acum Ã®nainte Ã®Å£i zic, pur si simplu, <strong>Nelu</strong>???','Cine mai tine minte numele celor cu care a facut cunostinta?',0,'','publish','open','open','','cine-mai-tine-minte-numele-celor-cu-care-a-facut-cunostinta','','\nhttp://www.groparu.ro/?p=87','2008-03-19 00:07:54','2008-03-18 22:07:54','',0,'http://www.groparu.ro/?p=1031',0,'post','',13),(1032,1,'2008-03-19 12:05:41','2008-03-19 10:05:41','Am auzit ca si in Banat, care-i fruncea, lumea citeste. Si o parte din lumea asta ceteste www.groparu.ro, ceea ce clar ca ma face sa ma emotionez umezindu-ma pe mine insusi de fericire.\r\n\r\nDar mai nou cica in Banat e o diferenta intre a vrea si a putea ceti, finca am aflat ca saitu meu, despre care se stie ca e indecent, mai nou e si porno de indecent. Iaca de ce:\r\n\r\n<em>Your request to URL \"http://www.groparu.ro/\" has been blocked by the Webwasher URL filter database. The URL is listed in categories (Pornography) which are not allowed by your administrator at this time.</em>\r\n\r\nAsta primii de la un banatzan, care lucreaza - normal! - la o firma care m-o banat in Banat.\r\n\r\nDa\' ce nu pricep io ii: ala care l-o banat pe Groparu in Banat o gandit cu fruncea? Si daca tot is banat in Banat, la aia la firma le merge vreunul din linkurile de mai jos?\r\n\r\nwww.gonzo-movies.com\r\nwww.p0rno.org\r\nwww.pornorama.com\r\nwww.redtube.com\r\nwww.youporn.com\r\n\r\nNu de alta, da-s curios!\r\n\r\nPS: si va rog spuneti-mi si mie unde am pornache la mine pe sait, ca nu am mai vazut de multisor un film bun.','www.groparu.ro - banat in Banat, care-i fruncea',0,'','publish','open','open','','wwwgroparuro-banat-in-banat-care-i-fruncea','','','2008-03-19 12:05:41','2008-03-19 10:05:41','',0,'http://www.groparu.ro/?p=1032',0,'post','',33),(1033,2,'2008-03-19 23:52:12','2008-03-19 21:52:12','- Ai ceva la nas, zic io.\r\n- Un muc? forteaza ea nota.\r\n- Cum dreq poate un muc sa aibe alt muc? intreb.','Ce i-am zis la o colega mica de statura',0,'','publish','open','open','','ce-i-am-zis-la-o-colega-mica-de-statura','','','2008-03-19 23:52:12','2008-03-19 21:52:12','',0,'http://www.groparu.ro/?p=1033',0,'post','',5),(1034,1,'2008-03-20 09:25:07','2008-03-20 07:25:07','- Iar ai intarziat la serviciu. Pot sa stiu de ce?\r\n- M-am futut azi-dimineata. Scuze!\r\n- Si ieri dimineata?\r\n- Da, si ieri.\r\n- Bun. Si luni?\r\n- Luni m-am futut de doo ori.\r\n- Si in toata luna februarie?\r\n- Mai ales in toata luna februarie!','Scuza pentru cand intarzii la serviciu',0,'','publish','open','open','','scuza-pentru-cand-intarzii-la-serviciu','','','2008-03-20 09:25:07','2008-03-20 07:25:07','',0,'http://www.groparu.ro/?p=1034',0,'post','',13),(1035,1,'2008-03-20 15:56:32','2008-03-20 13:56:32','Ea: Iupitule... inca mai am fluturi in stomac de la ultimul sarut....!\r\nEl: Tulaaaai, ce-ai patit, ai mÃ¢ncat omizi???','Cum se strica o clipitÄƒ romanticÄƒ',0,'','publish','open','open','','cum-se-strica-o-clipita-romantica','','','2008-03-20 16:13:25','2008-03-20 14:13:25','',0,'http://www.groparu.ro/?p=1035',0,'post','',7),(1036,1,'2008-03-21 12:57:18','2008-03-21 10:57:18','Visu\' asta l-am visat azi noapte. Si e ciudat, finca am rÃ¢s Ã®n somn de visu\' meu.\r\n\r\nAm visat ca ma aflam in Afganistan, ÅŸi eram cu tot felu de militari, si eram in mijlocu\' lor, imbracat in uniforma de culoarea operatiunii Furtuna in deÅŸert. Si discutam cu ei, si ei stateau in juru meu, si nush ce bancuri le ziceam, si ei se amuzau, si io eram tartor printre ei. Si eram, in visu meu, americani, nemti, franceji, si etiopieni, sau nush ce alt neam mai e p-acolo. Si romÃ¢ni, of cors. Åži io vorbeam cu toÅ£ii in limbile lor, fincÄƒ eram foarte dotat Ã®n visu meu, ÅŸtiam o sumedenie de limbi.\r\n\r\nÅži la un moment dat, se aude <em>Atteeeeentiooon</em>! ÅŸi toatÄƒ gaÅŸca ia poziÅ£ie de drepÅ£i: venea ceva general, ghinÄƒrar d-Äƒla NATO. Åži toÅ£i stau drepÅ£i, numa io scuip Ã®ntr-o parte plictisit ÅŸi Ã®mi aprind o Å£igare (ioooi, ce bunÄƒ era ea Ã®n visul meu!)\r\n\r\nÅži ghinÄƒralu\' se oftica ca nu il salut, si imi striga in germana:\r\n\r\n- <em>Ce inseamna asta</em>? (nush cum o sunat in germana fraza asta, da\' am priceput-o instant)\r\n- <em>Ich weiss nicht</em>... zic io, si ma pregatesc sa ii zic, in visu meu, in care io eram ce vroam sa fiu, ca <em>Ich bin neu</em>! Adica <em>Io sunt nou acilea, pe la voi!</em> Si eram foarte mandru ca io stiam toate limbile care se vorbeau acolo. Da\' in visu meu nu mi-o iesit cuvintele cum trebe (io is oÅ£Ã¢rÄƒ bÃ¢lbÃ¢it fincÄƒ vorbesc prea repede finca gÃ¢ndesc mult prea repede pentru un muritor).\r\n\r\nAsa ca Ã®n loc sÄƒ Ã®i zic <em>Ich bin neu</em>!, i-am zis ICH BIN NEUN! ADICA <em>IO SUNT CIFRA NOUÄ‚</em>!!! Si toti or izbucnit in rÃ¢s cÄƒ ce prost pot sa fiu io, cÄƒ mÄƒ dau mare cu limbi pe care nu le ÅŸtiu, ÅŸi ghinÄƒraru o rÃ¢s cu tot cu burta lui cÄƒ ce soldaÅ£i proÅŸti au romÃ¢nii, ÅŸi cÄƒ se mirÄƒ cÄƒ Ã®ncÄƒ nu am trÄƒdat NATO ca sÄƒ Ã®ntoarcem armele de partea talibanilor, ÅŸi m-am simÅ£it umilit Ã®n onoarea mea de romÃ¢n, ÅŸi m-am trezit indignat.\r\n\r\nEra vineri dimineaÅ£a.','Io si cand visez fac gafe - pe bune',0,'','publish','open','open','','io-si-cand-visez-fac-gafe-pe-bune','','','2008-03-21 12:57:18','2008-03-21 10:57:18','',0,'http://www.groparu.ro/?p=1036',0,'post','',20),(1037,1,'2008-03-24 09:40:43','2008-03-24 07:40:43','- Groparu, how come you\'re always right?\r\n- ...\'cause I\'m never left!!!','Una scurta',0,'','publish','open','open','','una-scurta','','','2008-03-24 09:40:57','2008-03-24 07:40:57','',0,'http://www.groparu.ro/?p=1037',0,'post','',11),(1038,1,'2008-03-24 12:44:34','2008-03-24 10:44:34','Cica un bucurestean are in medie 2.5 metriiii patrati de spatiu verde pe cap de locuitor.\r\n\r\nIo sunt mai tare decat atat.\r\n\r\nStiti de ce?\r\n\r\nSimplu, finca am mai mult spatiu verde pe capu\' meu decat un bucurestean sadea.\r\n\r\nStiti cum am mai mult spatiu verde pe capu\' meu decat un bucurestean sadea?\r\n\r\nSimplu, pentru ca in baia mea gresia si faiantza sunt de culoare verde. Si spatiul asta verde de pe pereti si pardoseala iese, mai nene, mult! Mult spatiu verde pe un singur cap de clujean.\r\n\r\nQ.e.d.','De ce sunt io mai tare ca orice bucurestean',0,'','publish','open','open','','de-ce-sunt-io-mai-tare-ca-orice-bucurestean','','','2008-03-24 12:44:34','2008-03-24 10:44:34','',0,'http://www.groparu.ro/?p=1038',0,'post','',25),(1039,2,'2008-03-25 00:41:01','2008-03-24 22:41:01','In sfarsit, dupa o indelunga paoza in care si-a facut rebranding ca sa revina la forma initiala cateva luni mai tarziu, unul din foarte putinele saituri care meritÄƒ, mÄƒ refer la <a href=\"http://www.wimp.com\" target=\"_blank\">www.wimp.com</a>,  si-a refacut aparitia in saituri-care-merita-accesate-de-la-servicio-sferÄƒ (presupun ca acasa fiecare are altceva mai bun de facut!)\r\n\r\nÃŽntrucÃ¢t pe mine mÄƒ Ã®ncearcÄƒ un dispreÅ£ suveran care de fapt este chiar anticamera lenei mega-suverane pe care s-a constatat o furtunÄƒ din care s-a declanÅŸat o extorsiune al unui degajament al unei construcÅ£ii de - bineÃ®nÅ£eles, Ã®ntr-o apÄƒ.\r\n\r\nSi una bunÄƒ Ã®mpreunÄƒ: ÅŸtiÅ£i cum se zice la damigeanÄƒ Ã®n englezÄƒ? ÅžtiÅ£i??? VÄƒ zic tot io: <em>demijohn</em>. Nu-i tare limba romÃ¢nÄƒ, care de fapt e patria mea?','Stirea zilei de ma(r)Å£',0,'','publish','open','open','','stirea-zilei-de-mart','','','2008-03-25 02:00:42','2008-03-25 00:00:42','',0,'http://www.groparu.ro/?p=1039',0,'post','',3),(1040,1,'2008-03-25 12:18:31','2008-03-25 10:18:31','Deci io am prea multi prekini, da? Prea multi, si nu mai fac fatza.\r\n\r\n- Gropare, uite ID-ul meu, adauga-ma.\r\n- Ba man, nu se mai poate: o zis lista mea de yahu ca daca mai adaug ID-uri in ea, ma pune pe ignore!','Lista mea de yahu',0,'','publish','open','open','','lista-mea-de-yahu','','','2008-03-25 12:18:31','2008-03-25 10:18:31','',0,'http://www.groparu.ro/?p=1040',0,'post','',5),(1041,1,'2008-03-25 15:56:55','2008-03-25 13:56:55','Sa ti se carieze bluetoothu\'.','Culmea dentismului',0,'','publish','open','open','','culmea-dentismului','','','2008-03-25 15:56:55','2008-03-25 13:56:55','',0,'http://www.groparu.ro/?p=1041',0,'post','',7),(1042,1,'2008-03-26 14:24:46','2008-03-26 12:24:46','O colega:\r\n\r\n- Cine a listat ceva legat de chirurgia plastica? si se uita la mine, parca sugestiv.\r\n- Nu te uita la mine, zic. Mai bine intreaba-te cine ii cel mai urÃ¢t, hidos, dezgustator si fecal din firmÄƒ, mascul sau femelÄƒ,  cineva care ar avea un real interes sa scape de faÅ£a sa de Quasimodo prin chirurgie esteticÄƒ, nu eu! Nu, nu eu.\r\n\r\nÅži apÄƒi stau ÅŸi mÄƒ gÃ¢ndesc: nu ar fi fost tare ca tocmai vreun ÅŸÄƒf sÄƒ fi listat foile elea, ÅŸi sÄƒ mÄƒ fi auzit pe mine zicÃ¢nd vorbele elea? Nu ar fi fost chiar super-super tare???','La imprimanta',0,'','publish','open','open','','la-imprimanta','','','2008-03-26 14:24:46','2008-03-26 12:24:46','',0,'http://www.groparu.ro/?p=1042',0,'post','',8),(1043,2,'2008-03-27 02:28:34','2008-03-27 00:28:34','StÄƒ aÅŸa, puÅ£in cam flascÄƒ, la doi centimetri de coltul gurii, si imi atinge usor obrazul. LunguiaÅ£Äƒ, cilindricÄƒ, se bÄƒlÄƒngÄƒne voluptuos.\r\n\r\nO atingi cu mÃ¢inile dornice, cu buricele degetelor Ã®nfometate, ÅŸi strÃ¢ngi uÅŸor. Are o consistenÅ£Äƒ ciudatÄƒ, nu e nici moale, nici tare, deÅŸi e mai mult tare decÃ¢t moale. Unii ar spune cÄƒ are exact consistenÅ£a potrivitÄƒ; alÅ£ii ar spune cÄƒ ar prefera sÄƒ fie mai tare, mult mai tare, ÅŸi sÄƒ nu se facÄƒ niciodatÄƒ moale: sÄƒ simÅ£i cÃ¢nd o bagi Ã®n gurÄƒ.\r\n\r\nE uÅŸor cÄƒlduÅ£Äƒ, ÅŸi e acoperitÄƒ de o membranÄƒ finÄƒ, aproape catifelatÄƒ, aÅŸa de finÄƒ cÄƒ dacÄƒ pui mÃ¢na pe ea parcÄƒ Ã®Å£i e fricÄƒ sÄƒ nu o zgÃ¢rii - mai ales dacÄƒ porÅ£i inele sau ghiuluri. O iei cu grijÄƒ, o plimbi Ã®n mÃ¢nÄƒ, te joci o secundÄƒ cu ea, dar ÅŸtii cÄƒ inevitabil o vei duce la buzele tale, ÅŸi de acolo pe limbÄƒ. ÃŽncerci sÄƒ amÃ¢ni momentul: Ã®ntÃ¢rzierea asta Ã®Å£i mÄƒreÅŸte dorinÅ£a ÅŸi Ã®Å£i provoacÄƒ o salivare uÅŸoarÄƒ, uneori de nestÄƒpÃ¢nit. ÃŽÅ£i e foame de ea, ÅŸtii cÄƒ numai ea te poate satisface, orice alt Ã®nlocuitor e un surogat lamentabil, un <em>ersatz</em>, ÅŸi tu nu mai vrei sÄƒ o schimbi cu altceva odatÄƒ ce Å£i-a ajuns Ã®n mÃ¢nÄƒ. Åži din mÃ¢nÄƒ, pe buze ÅŸi de acolo Ã®n gurÄƒ. ÃŽn gura ta, unde ai plimbat-o Ã®ndelung, sugÃ¢nd cu nesaÅ£ cu limba ÅŸi obrajii de fiecare cutÄƒ, de fiecare pliu, de parcÄƒ ai dori sÄƒ Ã®Å£i umpli cavitatea bucalÄƒ cu aromele ei, ÅŸi te bucuri cÃ¢nd o simÅ£i aÅŸa, zemoasÄƒ, cum elibereazÄƒ Ã®n gura ta o herghelie de miresme care Ã®Å£i Ã®mbatÄƒ papilele ÅŸi le ia la vals, ÅŸi Å£i le ÅŸi gÃ¢dilÄƒ sub fuste cÃ¢nd le vede aÅŸa bete de poftÄƒ. SimÅ£i cum din cerul gurii Ã®Å£i picurÄƒ stropi de la apa fierbinte din care tocmai a ieÅŸit, stropi cu un miros ÅŸi un gust specific, unic.\r\n\r\nDacÄƒ eÅŸti excentric, adaugÄƒ diferite uleiuri aromate pe ea: Ã®i va spori savoarea. CÃ¢nd, Ã®n cele din urmÄƒ, beat de pofte, o presezi uÅŸor cu limba de cerul gurii ÅŸi un pic, doar un pic, o zgÃ¢rii cu dinÅ£ii, descoperi uimit cÄƒ eÅŸti Ã®n al nouÄƒlea cer, cÄƒ simÅ£urile tale sunt Ã®n supradozÄƒ, iar creierul este incapabil sÄƒ mai gÃ¢ndeascÄƒ, cÄƒci dacÄƒ ar face-o, Å£i-ai da seama ce greu Å£i-ar fi Ã®n post fÄƒrÄƒ soia asta rulatÄƒ Ã®n formÄƒ de crevursti,  cu aromÄƒ aproape naturalÄƒ ÅŸi pe care ai pus un kil de muÅŸtar ca sÄƒ Ã®Å£i mai taie din greaÅ£Äƒ.','BÄƒlÄƒngÄƒnindu-se lÃ¢ngÄƒ gura mea Ã®ntredeschisÄƒ, care gÃ¢fÃ¢ie de pofte',0,'','publish','open','open','','balanganindu-se-langa-gura-mea-intredeschisa-care-gafaie-de-pofte','','','2008-03-27 09:25:48','2008-03-27 07:25:48','',0,'http://www.groparu.ro/?p=1043',0,'post','',23),(1044,2,'2008-03-28 01:12:33','2008-03-27 23:12:33','Travian e un joc online destul de penal, cu o grafica penalÄƒ, apanajul aproape exclusiv (pleonasm, bÄƒÄƒÄƒ! Ã®nvÄƒÅ£aÅ£i, ce panaceu\' meu universal) al unor low-lives ca mine, oameni ÄƒrÄƒ viaÅ£Äƒ socialÄƒ ÅŸi cu prea mult Internet la Ã®ndemÃ¢nÄƒ, oameni cu prieteni mai mult virtuali decÃ¢t normali, gajici mai mult virtuale decÃ¢t Ã®n carne, Å£Ã¢Å£e ÅŸi oase (mÄƒ refer, bine-nÅ£eles, la faptul cÄƒ asemenea oameni nu au alte prekine decÃ¢t acele dame bine-crescute pe care le Ã®ntÃ¢lniÅ£i Ã®n cele cÃ¢teva saituri interzise minorilor supt 18 ani pe care le-am menÅ£ionat Ã®ntr-o postare precedentÄƒ), ÅŸi da, oameni din toate stratele sociale, preponderent tocilarii ochelaristi de clasa a ÅŸaptea.\r\n\r\nAmu - Ã®n giocu Äƒsta ai trei civilizatii pe care poÅ£i sÄƒ le alegi:\r\n\r\n- romanii - fincÄƒ romanii erau ÅŸi destul de gay, populaÅ£ia satului tÄƒu va creÅŸte mai greu decÃ¢t populaÅ£ia altor civilizaÅ£ii;\r\n- barbarii - te gÃ¢ndeÅŸti automat la personalul FiliaÅŸi-Cehu Silvaniei, vagonul trei, vineri seara;\r\n- dacii - o drÄƒguÅ£Äƒ de civilizaÅ£ie care Ã®n varianta germanÄƒ a jocului se referea la vikingi, dar cÄƒrora le-a fost schimbat numele, dar nu ÅŸi designul, ÅŸi cÃ¢nd au fÄƒcut localizarea pentru piaÅ£a romÃ¢neascÄƒ dacii din joc au ajuns sa aibe coifuri cu coarne de bou, de parcÄƒ toÅ£i Ã®s nepoÅ£eii lu\' Deceneu a lu\' <a href=\"http://ro.wikipedia.org/wiki/Erik_cel_Ro%C5%9Fu\" target=\"_blank\">Eric cel RoÅŸu</a>.\r\n\r\nÃŽn acest joc se leagÄƒ alianÅ£e ÅŸi se trÄƒdeazÄƒ - exact ca Ã®n viaÅ£Äƒ; se mizeazÄƒ pe ajutorul prietenilor cÃ¢nd eÅŸti atacat de duÅŸmani, ÅŸi se ia Å£apÄƒ - exact ca Ã®n viaÅ£Äƒ;  Ã®i ataci pe colegii mai slabi ÅŸi mai subdezvoltaÅ£i - da, tot ca Ã®n viaÅ£Äƒ.\r\n\r\nCe mÄƒ distreazÄƒ cel ai tare Ã®i pasiunile care se dezlÄƒnÅ£uie Ã®n jocu Äƒsta, ceva de spÄƒriet. Sar peste msjle agrama-te trimis-e de puÅŸtani k kre k nu aveÅ£i kef de ele, vreau numai sÄƒ vÄƒ spun ce mesaj o primit unu\' de la mine din alianÅ£Äƒ dupÄƒ ce o atacat un inamic, mesaj demn de tot respectu\'!\r\n\r\n\"Ultima data l-ai atacat pe fiu-meu de 12 ani care e cu mine in alianta, asa ca pentru asta te voi ataca pana te voi scoate de pe harta!!!\"\r\n\r\nNo comment.','Despre Travian',0,'','publish','open','open','','despre-travian','','','2008-05-08 10:33:58','2008-05-08 08:33:58','',0,'http://www.groparu.ro/?p=1044',0,'post','',14),(1087,2,'2008-05-08 22:19:30','2008-05-08 20:19:30','Finca pun pariu ca juma\' din cetitorimea mea este hartuita de bunici, matusi si parinti cu eternul si nemuritorul \"Da\' tu nu te insori???\", doresc sa infiintez prima agentie matrimoniala din lume pentru casatorii de convenienta, al carei scop este astuparea gurii bunicilor, matusilor si parintilor. Mirii trebe numa sa se insoare, iar dupa nunta isi pot urma traiul zilnic fara nici un fel de obligatie ulterioara - eventual numai cate o vizita trimestriala acasa la socri, ca sa se continue astuparea gurii acestora.\r\n\r\nLa nevoie, agentia poate fi dublata cu o alta agentie de infieri fictive, in care un bebelash e inchiriat pentru un weekend pentru dus acasa, pentru anularea, de data aceasta, a frazei \"Da\' voi cand faceti un copil?\" - din partea acelorasi bunici, matusi si parinti.\r\n\r\nNush voua cum vi se pare ideea, da\' mie mi se pare la fel de mortala ca ideea ailanta a mea geniala, aia cu bordelu\' numa pentru mamelit (careia ii voi spune de acum \"ideea de afaceri 1\"), pentru care ambele idei mie mi se pare ca ar trebui sa se bata bancile sa-mi acorde finantare, si io sa le zic asa, nitel flegmatic:\r\n\r\nIMI PARE RAU, DAR NU VA INCADRATI!!!!','Idee de afacere 2',0,'','publish','open','open','','idee-de-afacere-2','','','2008-05-09 02:21:35','2008-05-09 00:21:35','',0,'http://www.groparu.ro/?p=1087',0,'post','',14),(1045,2,'2008-03-28 09:05:14','2008-03-28 07:05:14','Deci George Pruteanu, Dumnezau sa-l ierte de erudit, sireacu, o cam dat coltu\'. Creca Demiurgu\' si-o pierdut Wikipedia din bookmarksuri si s-o gandit ca, pana mai cauta pe gugal, mai bine il cheama pe cel mai cumsecade peremist sa-l ajute instant cand joaca conquizstador.\r\n\r\nFinca io fusai mare fan prutenesc (nu pot uita adagiul domniei sale: <em>izmenirea e indispensabila</em>, alaturi de alte maaaari vorbe pe care doar ni <em>l-eo</em> mai spus), declar aici sus si tare ca eu, personal, <strong>nu sunt de acord cu decesul domniei sale</strong>.\r\n\r\nVoi sunteti?','A murit George Pruteanu',0,'','publish','open','open','','a-murit-george-pruteanu','','','2008-03-31 15:50:23','2008-03-31 13:50:23','',0,'http://www.groparu.ro/?p=1045',0,'post','',24),(1046,2,'2008-03-31 02:53:43','2008-03-31 00:53:43','Parerea mea ca romÃ¢n destul de foarte neaoÅŸ, ÅŸi care este ÅŸi destul de foarte impotriva NATO, UE, PLM, STF si altor asemenea lighioane acronimice cÃ¢tÄƒ vreme nu Ã®i aduc nici o centimÄƒ de rublÄƒ Ã®n buzunar, mÄƒ aÅŸez strÃ¢mb, cu picioarele supt fund (cel mai bun mod de a sugruma bÄƒÅŸinile astea sfinte, curate, de post) ÅŸi judec drept, ÅŸi mai ÅŸi scriu pe blog de ce cred io cÄƒ nu vom avea atentate teroriste la sommetul Äƒsta.\r\n\r\nÃŽn primul rÃ¢nd, orice arÄƒboc ce vine acilea Ã®ÅŸi cam bagÄƒ jihadu\' Ã®n ea misiune sinucigaÅŸÄƒ, fincÄƒ Ã®l corupe romÃ¢ncele noastre firoscoase, degrabÄƒ dÄƒtÄƒtoare de pÄƒpÄƒdie oricui vorbeÅŸte altÄƒ limbÄƒ decÃ¢t romÃ¢neÅŸte ÅŸi/sau basarabeneascÄƒ (ce, n-am dreptate, fetelor?) AÅŸa cÄƒ decÃ¢t sÄƒ moarÄƒ ca prostu\' borbandat, Ã®ÅŸi va alege mai degrabÄƒ o sinucidere lentÄƒ la noi Ã®n Romunica, taximetrist cu patru plozi, televizor Ã®n rate ÅŸi garsonerÄƒ Ã®n Berceni!\r\n\r\nÃŽn al doilea rÃ¢nd, dupÄƒ cum zicea ÅŸi un banc, romÃ¢nii nu au nevoie de atentate teroriste. De ce? FincÄƒ Ã®ÅŸi ciocnesc singuri maÅŸinile, Ã®ÅŸi taxeazÄƒ de moarte cetÄƒÅ£enii, Ã®ÅŸi bagÄƒ dobÃ¢nzi uriaÅŸe la bÄƒnci, ba chiar Ã®ÅŸi ÅŸi Ã®mpuÅŸcÄƒ singuri preÅŸedinÅ£ii! E drept cÄƒ nu pe Äƒia pe care ar trebui, da\' treacÄƒ de la noi, sa fie primit, sÄƒ trÄƒiascÄƒ naÅŸa mare.\r\n\r\nÃŽn al treilea rÃ¢nd, romÃ¢nii Ã®i au deja prin zonÄƒ pe teroriÅŸtii Äƒia care conduc beÅ£i ÅŸi omoarÄƒ Teo Peteri ÅŸi NemeÅŸti.\r\n\r\nÃŽn al patrulea rand, romÃ¢nii au <a href=\"http://www.cotidianul.ro/sexul_lui_terente_a_intrat_in_reparatie_capitala-23800.html\" target=\"_blank\">cea mai tare arma terorista a planetei</a>, si orice piÅŸcotar care vine aicea sÄƒ facÄƒ oole mari va cam primi un scuipat fix Ã®ntre ochi, fincÄƒ ce puÅ£ulici o loat poporu asta de la istorie, vai de mama lui, bomba aia n-o sÄƒ ne afecteze nici cÃ¢t un tÄƒieÅ£el la o foame de lup.\r\n\r\nÃŽn al cincelea rÃ¢nd, romÃ¢nii Ã®s plini de carne de porc, ÅŸi dacÄƒ Ã®n urma exploziei vreun rest de parizer de porc de cris-tim din burtÄƒ de romÃ¢n atinge rest de carne de terorist arab, acestuia din urmÄƒ i se neagÄƒ raiul, fincÄƒ porcul e animal ne-jihadic. Deci Ahmet, canci rai, canci virgine! (cine v-o bÄƒgat Ã®n cap cÄƒ mai existÄƒ pe vreo lume 70 de virgine, io nu ÅŸtiu, sincer!)\r\n\r\nDeci Ã®n al ÅŸaselea, ÅŸi nu Ã®n ultimul rÃ¢nd, AL-QAEDA S-AR CAM FACE DE CACAO, fincÄƒ toatÄƒ lumea s-ar prinde cÄƒ nici Al-Qaeda nu mai e ce-a fost, dac-or ajuns sÄƒ borbandeze tocmai acilea unde  pÃ¢nÄƒ ÅŸi Bin Ladenescu, dacÄƒ dÄƒ dreptu\' acolo unde trebe, poate sÄƒ-ÅŸi beie liniÅŸtit cafeluÅ£a de dimineaÅ£Äƒ la masÄƒ cu ministru\' de interne ÅŸi ministru\' apÄƒrÄƒrii la TV Ã®n direct la Garsoniera lu\' MÄƒruÅ£Äƒ, fÄƒrÄƒ sÄƒ pÄƒÅ£ascÄƒ nici mÄƒcar nimic!\r\n\r\nCe jihadu meu.','Atentat terorist cu bomba la Bucuresti la summit-ul NATO? Motive pentru care putem sta liniÅŸtiÅ£i',0,'','publish','open','open','','atentat-terorist-cu-bomba-la-bucuresti-la-summit-ul-nato-motive-pentru-care-putem-sta-linistiti','','','2008-03-31 02:53:43','2008-03-31 00:53:43','',0,'http://www.groparu.ro/?p=1046',0,'post','',9),(1047,1,'2008-03-31 12:00:29','2008-03-31 10:00:29','Dintr-un dans, o razÄƒ de soare ÅŸi trei petale\r\nS-a Ã®ntrupat o fatÄƒ care apasÄƒ bine pe-ale maÅŸinii pedale,\r\nCÃ¢nd stai lÃ¢ngÄƒ ea, dacÄƒ e noapte, nici nu simÅ£i cum trece ora -\r\nProbabil ÅŸi din cauzÄƒ cÄƒ o cheamÄƒ Dora!\r\nFata asta, dragii mei,\r\nEste cea mai dintÃ¢i bucÄƒtÄƒreasÄƒ Ã®ntre femei,\r\nÅži-are trup sculptat din lemn de tei!\r\nEste cultÄƒ, fincÄƒ de-aia-i e Groparului fanÄƒ,\r\nPun pariu cÄƒ face gustoasÄƒ orice zamÄƒ,\r\nÅži mai cred cÄƒ e excelentÄƒ ca metresÄƒ,\r\nFincÄƒ-i ÅŸi bunoacÄƒ, ÅŸi bunesÄƒ!\r\nÅži, fincÄƒ azi Ã®ÅŸi serbeazÄƒ a sa zi sau noapte,\r\nNoi, groparii, Ã®i urÄƒm printre ÅŸoapte\r\nMulta, multa, multa sanatate,\r\nSex de cea mai buna calitate,\r\nUn vagon intreg de succese de import,\r\nSÄƒ deie numai la 200 de ani al popii ort,\r\nSÄƒ fie fericitÄƒ ca un preafericit,\r\nÅži sÄƒ nu facÄƒ rabat la iubit!\r\n\r\nLa Multi Ani, ÅŸi multi, multi bani!','Azi e ziua lu\' Dora, \"sora cu ghilimele\" a lu\' Kissu',0,'','publish','open','open','','azi-e-ziua-lu-dora-sora-cu-ghilimele-a-lu-kissu','','','2008-03-31 12:00:29','2008-03-31 10:00:29','',0,'http://www.groparu.ro/?p=1047',0,'post','',6),(1048,2,'2008-04-01 02:18:32','2008-04-01 00:18:32','De <a href=\"http://despre-toate-si-despre-nimic.blogspot.com/\" target=\"_blank\">aici</a>. Tre\' sa zic 8 chestii despre mine.\r\n\r\n1. Mie...\r\nÃ®miplacfemeiledecredcÄƒÅŸimorcÄƒunoeoriÃ®midauseama\r\ncÄƒosÄƒmorÅŸipoatenuapucsÄƒmÄƒfutcutoatefemeiledepelumeaastamareÅŸilatÄƒ!!!!\r\n2. Eu...\r\nrareoriapucsÄƒvorbesccuvreofemeiefÄƒrÄƒsÄƒÃ®micoboareprivireacÄƒtrepieptul\r\neiÅŸifÄƒrÄƒsÄƒÃ®miimaginezcumargeme,gÃ¢fÃ¢ind,suptmine.\r\n3. Eu...\r\nnuamÃ®ntÃ¢lnitniciodatÄƒofemeiecaresÄƒnumeritesÄƒfieiubitÄƒvirgulÄƒÃ®nafarÄƒde\r\ncÃ¢tevacareeraucuadevÄƒrathidoaseiarÄƒvirgulÄƒdarnufizicaltÄƒvirgulÄƒcinumaidin\r\npunctdevederealpersonalitÄƒÅ£iilorinfecte.\r\n4. PentrucÄƒ...\r\nDumnezeuoziscÄƒdacÄƒteholbezilaofemeieÅŸidejateÅŸiimaginezicÄƒlare\r\npeeaepÄƒcatdemoartevirgulÄƒeunuvoiajungeniciodatÄƒÃ®nraipunct.\r\n5. Eu...\r\namterminatunliceudefete,amfÄƒcutofacultatedefete,amfÄƒcutÅŸidouÄƒ\r\nmasteratedefeteÅŸitotnumi-oajuns!\r\n6. Normal,...\r\ndacÄƒvreodatÄƒosÄƒamcopii,vreaufetiÅ£e.FincÄƒdacÄƒiasÄƒbaieÅ£eio\r\nsÄƒÃ®iÃ®nvÄƒÅ£numaipornoÅŸaguriÅŸiosaimialuneceprivireacÄƒtrepiepÅ£iiprietenelor\r\nlorÅŸieisevorenervapemine,tÄƒticullorpervers.\r\n7. Eu...\r\ncredcÄƒceicarebruscheazÄƒfemeifÄƒrÄƒsÄƒfievorbadeautoapÄƒraresuntneÅŸte\r\noamenitriÅŸticaretrebuieÃ®nveselitiladuÅŸuridenegriidinpuÅŸcÄƒriilefederale.\r\n8. AÅŸa cÄƒ susÅ£in cÄƒ...\r\nniciodatÄƒnuamvÄƒzutcevamaifrumosdecÃ¢tofemeiefiindeaÃ®nsÄƒÅŸi,ÅŸicuasta\r\ncredcÄƒamzistotuldespremine,maialesdesprepÄƒrÅ£ilemeleesentialecareÅ£in\r\ndelibidou,pÄƒrÅ£ipecareamÃ®ncetatdemultsÄƒlemaiinhibfincÄƒdefiecaredatÄƒ\r\n<strong>eleiesbiruitoare</strong>!','Leapsha',0,'','publish','open','open','','leapsha','','','2008-04-01 02:30:08','2008-04-01 00:30:08','',0,'http://www.groparu.ro/?p=1048',0,'post','',13),(1049,1,'2008-04-01 11:28:05','2008-04-01 09:28:05','Deci Base\' si Geoana fura implicati in accidente rutiere pe strada, cand faceau pe soferii.\r\n\r\nDeci pe soferii astia ratati ii lasam noi sa ne conduca Romania?','Basescu si Geoana face accidente cand sunt la conducere!',0,'','publish','open','open','','basescu-si-geoana-face-accidente','','','2008-04-01 11:28:20','2008-04-01 09:28:20','',0,'http://www.groparu.ro/?p=1049',0,'post','',6),(1050,2,'2008-04-02 05:01:40','2008-04-02 03:01:40','\"<span lang=\"RO\">PuÅŸcÄƒ de calibru 17,6 mm, sistem Augustin, armÄƒ regulamentarÄƒ aflatÄƒ Ã®n dotarea trupelor de infanterie austriece. Å¢eava este rotundÄƒ la exterior, lisÄƒ Ã®n interior, avÃ¢nd dispozitive pentru luarea liniei de ochire. Ulucul este lung, cu locaÅŸ pentru vergea. Mecanism de dare a focului cu capsÄƒ complet. Platina este inscripÅ£ionatÄƒ cu numÄƒrul <em>845</em>. PuÅŸca era prevÄƒzutÄƒ cu baionetÄƒ Ã®n patru muchii cu manÅŸon ce era purtatÄƒ separat Ã®ntr-un toc din lemn. Ea se ataÅŸa prin rÄƒsucire de capÄƒtul Å£evii cu ajutorul unui dispozitiv special.</span>\r\n\r\nÅ¢eava este ghintuitÄƒ Ã®n interior. La exterior, de la culatÄƒ la capÄƒtul ulucului, are muchiile canelate longitudinal, inscripÅ£ia cu numele fabricantului RAMAGER NEUESTADT ÅŸi dispozitivele pentru luarea liniei de ochire. Pat cu obrÄƒzar ÅŸi aplicaÅ£ii din alamÄƒ.\"\r\n\r\nOricat ar parea de paradoxal, eu ma umezesc de fericire cand am de tradus asemenea texte :D chiar daca traduc in ritmul de o pajina pe ora.','Traducerile mele strikes back ',0,'','publish','open','open','','traducerile-mele-strikes-back','','','2008-04-02 05:01:40','2008-04-02 03:01:40','',0,'http://www.groparu.ro/?p=1050',0,'post','',15),(1051,2,'2008-04-03 01:43:31','2008-04-02 23:43:31','Eu - da, chiar eu - am vazut multe la viata mea.\r\n\r\nScame in buric de urs polar, smantana pe putulica de pigmeu, chiar si aurore boreale, odata, cand am avut orgasm, mai demult. Am vÄƒzut adesea ÅŸarpe Ã®n pantaloni, am auzit pÄƒsÄƒrici de domniÅŸorici cum Ã®mi vorbesc ÅŸi mÄƒ hipnotizeazÄƒ ÅŸi mÄƒ cheamÄƒ la ele, ÅŸi am vÄƒzut ÅŸi cum se mulge vaca.\r\n\r\nAm vazut cum pe aeroportul din Frankfurt o moneda de nush cati pfenigi se transforma in medalion, cand o bagi la o presa din aia speciala, pentru turisti; am vazut si Mica Sirena din Copenhaga, si oricat de mult am stat langa ea, ea tot nu o sunat, ca io asta stiam ca fac sirenele, suna ca proastele.\r\n\r\nAm vazut cu uimire cum o zamÄƒ de burtÄƒ din centrul Bratislavei costÄƒ mai puÅ£in ca Ã®n cea mai infectÄƒ bodegÄƒ romaneascÄƒ (1 EUR, adica!), ÅŸi am mai vÄƒzut, instant, cum mÄƒ oftic de ciudÄƒ. Am vÄƒzut cum vameÅŸul ungur se comportÄƒ ca cel mai impuÅ£it ticalos pe care l-am vazut in viata mea; si am mai vazut si vamesi slovaci cerand spaga, si pe mine dÃ¢ndu-le-o. Åži iar m-am vÄƒzut pe mine ofticÃ¢ndu-mÄƒ.\r\n\r\nDe asemenea, am vazut cum buzile din benzinariile din Franta sunt mai imputite ca cele mai uitate de lume Rompetroluri; am vazut americani care puÅ£esc mai urÃ¢t ca 4 sconcÅŸi luaÅ£i Ã®mpreunÄƒ ÅŸi parfumaÅ£i cu miros de <a href=\"http://www.bioproduct.ro/articole/floarea_cadavru.htm\" target=\"_blank\">floare-cadavru</a>; ÅŸi da, am vÄƒzut chiar ÅŸi italieni cumsecade.\r\n\r\nDar nimic nu se comparÄƒ cu dopul maroniu de cearÄƒ pe care l-am scos eu din ureche asearÄƒ fÄƒrÄƒ ca mÄƒcar sÄƒ ÅŸtiu cÄƒ Ã®l am acolo, fincÄƒ el tÄƒcea chitic, cÄƒ cine-o mai auzit cearÄƒ sÄƒ vorbeÅŸte!!!','Eu am vazut multe la viata mea, ÅŸi ele m-au vÄƒzut pe mine',0,'','publish','open','open','','eu-am-vazut-multe-la-viata-mea-si-ele-m-au-vazut-pe-mine','','','2008-04-03 01:43:31','2008-04-02 23:43:31','',0,'http://www.groparu.ro/?p=1051',0,'post','',9),(1052,2,'2008-04-03 22:44:03','2008-04-03 20:44:03','In Cluj-Napoca, sunt, taxiuri. Nu eu sunt, ci ele e.\r\n\r\nIn Catavencu zicea careva care o venit la Cluj cÄƒ l-o mirosit taximetristu\' ca e Mitic, si nu s-o lasat pana nu i-o dat restu\' pana la ultimu leuÅ£: trebuia sÄƒ-i arate Miticului cÃ¢t de cinstiÅ£i suntem noi, arghelenii (zicea ziaristu\': is convins ca intre ei isi fura si saliva din gura, da\' mie, fiind Mitic, trebuia sa-mi dea o lectie de corectitudine habsburgica!)\r\n\r\nTaximetristii stiu tot. Io am zis de la bun inceput ca vreau o tara pe care sa o conduca taximetristii, finca astia au toate raspunsurile. Ba chiar, atunci cand o venit <a href=\"http://www.bobbyvoicu.ro/\" target=\"_blank\">Bobby</a> si <a href=\"http://adrian.filozofie.ro/\" target=\"_blank\">Adi</a> la nunta <a href=\"http://www.andreicrivat.ro\">CrivaÅ£ului</a>, taximetristu\' le-a zis verde-n faÅ£Äƒ de la obraz cÄƒ el nu mai concepe o RomÃ¢nie nefederalÄƒ, ÅŸi cÄƒ bloggerilor <a href=\"http://www.bobbyvoicu.ro/\" target=\"_blank\">Bobby</a> si <a href=\"http://adrian.filozofie.ro/\" target=\"_blank\">Adi</a> ar trebui sÄƒ li se cearÄƒ vize de intrare in Ardeal. Iar <a href=\"http://www.ciutacu.ro\" target=\"_blank\">Ciutacului</a>, care venise sa-i nÄƒÅŸeascÄƒ pe CrivaÅ£i, taximetristul, dupÄƒ ce s-a codit cÃ¢t s-a codit, i-a pus Ã®ntrebarea, recunoscÃ¢ndu-l: \"Ce-aveÅ£i, dom\'ne, cu dom\' preÅŸedinte?\"\r\n\r\nDar nu despre asta e vorba. Este vorba despre faptul cÄƒ primÄƒria Cluj-Napoca, Ã®n imensa ei Ã®nÅ£elepciune, a reglementat taximetria de a luat-o naiba:\r\n\r\n- a limitat numÄƒrul taximetriÅŸtilor Ã®n aÅŸa hal cÄƒ dacÄƒ Ã®Å£i trebuie o maÅŸinÄƒ cÃ¢nd plouÄƒ afarÄƒ trebuie sÄƒ aÅŸtepÅ£i cel puÅ£in douÄƒ etape pÃ¢nÄƒ se gÄƒseÅŸte ceva liber;\r\n- a impus folosirea aceloraÅŸi aparate de marcat;\r\n- a impus vopsirea tuturor maÅŸinilor Ã®n galben;\r\n- a acceptat ca toate firmele sÄƒ aplice acelaÅŸi tarif, ca Ã®ntr-o economie de piaÅ£Äƒ viguroasÄƒ (mai puÅ£in rechinii)\r\n- ultima gÄƒselniÅ£Äƒ, <em>a impus ca toate siglele de taxi sÄƒ fie colorate la fel, ca sÄƒ nu se mai facÄƒ diferenÅ£iere.</em>\r\n\r\nHai ca reglementarile astea le mai inteleg, cu exceptia primelor 4; da\' sa impui ca toate siglele de taxi sa fie uniforme, indiferent de firma, mi se pare o idee DecebalTraianRemeseasca!\r\n\r\nDaca tot e sa recomandam Primariei sa reglementeze si mai rafinat activitatea de taximetrie, atunci ar fi bine ca:\r\n\r\n- toate taxiurile sÄƒ fie acelasi model de maÅŸinÄƒ, din acelaÅŸi an, cu acelaÅŸi numÄƒr de kilometri ÅŸi banchetÄƒ din spate tÄƒiatÄƒ cu aceeaÅŸi briÅŸcÄƒ;\r\n- toate taxiurile sÄƒ fie conduse de acelaÅŸi taximetrist, cu aceeaÅŸi ceafÄƒ bulgÄƒreascÄƒ ÅŸi cu acelaÅŸi maieu maroniu ÅŸi aceeaÅŸi pÄƒreche de ÅŸlapi cu ciorapi purtaÅ£i vara;\r\n- Ã®n toate taxiurile sÄƒ cÃ¢nte aceeaÅŸi manea;\r\n- toÅ£i ÅŸoferii de taxi sÄƒ deie clanÅ£Äƒ, scuzaÅ£i expresia, la aceeaÅŸi cintezÄƒ de pe Calea Turzii (pentru ne-clujeni: Calea Turzii este un fel de Red Light Dick-strict al Clujului);\r\n- toate telefoanele de taximetrist sÄƒ aibe aceleaÅŸi manele ca rington, pe care sÄƒ le lase sÄƒ cÃ¢nte la fel de mult timp Ã®nainte de a rÄƒspunde, ca sÄƒ nu mai ÅŸtie clientul ce Ã®l enerveazÄƒ mai tare, manelele din telefon, manelele din casetofonul cu <em>sidi</em> sau purecii din staÅ£ie;\r\n- toate staÅ£iile de taximetrist sÄƒ fie date la maxim, ca sÄƒ Ã®Å£i rÄƒsune Ã®n urechi aceiaÅŸi paraziÅ£i ÅŸi noaptea, cÃ¢nd te culci sau - dupÄƒ caz - dormi; pe aceste staÅ£ii, ÅŸoferii sÄƒ Ã®ÅŸi divulge unu\' altuia Ã®n gura mare experienÅ£ele avute pe Calea Turzii cu aceeaÅŸi cintezÄƒ, ca sÄƒ te umple de ruÅŸine cÃ¢nd o conduci pe mama logodnicei la garÄƒ Ã®n taxi;\r\n- toÅ£i ÅŸoferii sÄƒ fie regulamentar la fel de nebÄƒrbieriÅ£i ÅŸi sÄƒ Ã®njure cu aceleaÅŸi Ã®njurÄƒturi pe aceiaÅŸi guvernanÅ£i ÅŸi sÄƒ poarte, Ã®n acest timp, aceleaÅŸi icoane de la MÄƒnÄƒstirea Nicula pe bord, la vedere.','Ne credeti numai cand taximetrim!',0,'','publish','open','open','','ne-credeti-numai-cand-taximetrim','','','2008-04-03 22:44:03','2008-04-03 20:44:03','',0,'http://www.groparu.ro/?p=1052',0,'post','',19),(1053,1,'2008-04-07 09:04:53','2008-04-07 07:04:53','...accept sa-mi dati bani. Nu vor fi bani pomana, ci bani meritati de mine, pentru ca sunt un  meserias si un delicat, tzucu-m-as pe mine.\r\n\r\nNu am nici o buala, Doamne feri, nu vreau sa strang PET-urile de la Orsova, nici sa plantez trei sute de chiparosi ca sa diminuez efectul de sera accelerat de ciorapii mei, nici nu vreau sa fondez un nou partid de stanga-dreapta-Ã®ntre-craci, nici sa stric banii pe curfe sau sa-mi ecologizez garsoniera. Nu vreau sa imi iau masina noua si mai putin poluanta, nu vreau sa impusc vun Kennedy sau sa dau spaga la ceva doftor. Nu vreau nici macar sa ma imbrac mai bine - de ce as vrea asta cand sunt fericitul posesor al unui trup de mascul 100% fibra, si 120% fara burta!\r\n\r\nVreau pur si simplu bani moca. Nu multi, da\' suficienti cat sa nu mai fiu nevoit sa muncesc decat atunci cand am chef. Accept euro, lei vechi, bani cu chipul reginei, dolarei, chiar asa, devalizati si zgribuliti de inflatie cum sunt ei, numai nu accept bani botswanezi, ma-ntelegeti, ca de Äƒia am deja o fisa ÅŸi-mi ajunge, vÄƒ multumesc.\r\n\r\nCer prea mult?','Pentru ca m-am saturat sa muncesc pana noaptea tarziu,...',0,'','publish','open','open','','pentru-ca-m-am-saturat-sa-muncesc-pana-noaptea-tarziu','','','2008-04-07 09:59:10','2008-04-07 07:59:10','',0,'http://www.groparu.ro/?p=1053',0,'post','',7),(1054,1,'2008-04-07 14:10:27','2008-04-07 12:10:27','Cand Denisa pe lume s-a nascut\r\nCaprioarele s-au oprit din pascut,\r\nLeii si cu mieii s-au imprietenit\r\nLumea s-a mai cumintit!\r\nPastravii s-au lasat prinsi cu mana,\r\nIar celor cu diaree in stomace li s-a potolit furtuna!\r\nPentru ca am ramas fara superlative anul trecut, in imensa-mi nerozie,\r\nNu i-am scris vers, nici dedicatie, nici poezie,\r\nDar ii scriu anul acesta o urare, cum mi-i stilu:\r\nTu, Denisa, sa-ti traiasca copilu\',\r\nSa fie prima la facultate, in viata sa cunoasca bafta,\r\nSa nu-i fie viata ca noua, adica ca-ntr-un roman de Kafka,\r\nÅži Å£ie, mamÄƒ mÃ¢ndrÄƒ, femeie dintr-o mie,\r\nCare ai inspirat aceasta poezie,\r\nÃŽÅ£i urez s-ai multÄƒ, multÄƒ, multÄƒ sÄƒnÄƒtate,\r\nJob security ÅŸi loc de parcare pe saturate,\r\nSÄƒ nu ajungi Ã®n iad dacÄƒ ai pÄƒcate,\r\nSi sÄƒ nu te culci pe nemÃ¢ncate!\r\nSÄƒ Å£i se-aÅŸtearnÄƒ frumos norocul Ã®n cale\r\nCa o ceaÅ£Äƒ de-aprilie, pe SomeÅŸ pe vale,\r\nSÄƒ ai mereu pe card bÄƒnuÅ£i, ÅŸi euro, ÅŸi lei,\r\nFincÄƒ tu eÅŸti prima-ntre femei!\r\nAr mai fi multe chestii de zis,\r\nDar talentul meu e limitat - de asta-s precis!\r\nAsa ca-nchei acilea, si iti dorescu\'\r\nLa Multi Ani, ÅŸi sa ai succes cÃ¢t Iliescu!!!','Azi e ziua Denisei, sa traiasca, La Multi Ani!',0,'','publish','open','open','','azi-e-ziua-denisei-sa-traiasca-la-multi-ani','','','2008-04-08 10:16:12','2008-04-08 08:16:12','',0,'http://www.groparu.ro/?p=1054',0,'post','',4),(1055,1,'2008-04-08 08:59:38','2008-04-08 06:59:38','Dap. In timp ce nu ma barbieream, azi-dimineata mi-am dat seama de ceva, si m-a lovit ca un fulger.\r\n\r\nDa!\r\n\r\nMi-am dat seama ca Romania va ajunge o super-putere cat timp noi, decreteii, inca traim.\r\n\r\nDe ce am zis asta?\r\n\r\nOpservati acilea rationament la Groparu, luati-va un scaun si silabisiti:\r\n\r\nToti prietenii mei (si cam sunt, finca toti prietenii mei sunt niste fornicatori si jumatate - desi nu va vine a crede ca am prieteni) vor avea cei mai reusiti copii. Ba mai mult: nu numai copiiiiii prietenilor (aici am pus mai multi de \"i\" ca sa astupe i-urile lipsa de la alti frati din blogosfera) mei vor fi niste succese absolute, ci si cei ai colegilor de scarbiciu. Am zis si ai colegilor? Includeti si copiiiii de pe scara blocului meu, copiiiii care ma vad pe trolee, prin parcuri sau prin lifturi, holbÃ¢ndu-mÄƒ la mÄƒmicile lor prin <em>mall-uri</em> si parcari, sau pe unde iau io masa etc.\r\n\r\nCopiii astia vor fi ordonati, fara gaze, muncitori, organizati, frumosi si destepti, nu se vor cocosa stand la calculator si nu isi vor strica zilele finca un pusti de 15 ani ii injura pe serveru\' de CounterStrike. Nu vor fi din cale-afarÄƒ nici obsedati de porneturi, nici prea-super-exagerat de curvari, ca mine. Se vor avea bine cu vecinii, si nu vor da vina pe soarta de fiecare datÄƒ cÃ¢nd o fac (sÄƒ mÄƒ scuze balada noastrÄƒ naÅ£ionalÄƒ) de oaie. Odata ce generatia asta de prunci va ajunge la carma puterii, tara noastra va cunoaste o dezvoltare fara de precedent anterior.\r\n\r\nSi copiii astia vor fi intr-atÃ¢ta de perfecti deoarece, intrÃ¢nd Ã®n contact vizual cu mine ÅŸi fiind la vÃ¢rsta la care li se formeaza personalitatea si abilitatile, isi vor modela sinele ergo-ului lor in asa fel incat sa fie exact opusul meu.','Azi-dimineata mi-am dat seama fulgerator de ceva',0,'','publish','open','open','','azi-dimineata-mi-am-dat-seama-fulgerator-de-ceva','','','2008-04-08 13:02:24','2008-04-08 11:02:24','',0,'http://www.groparu.ro/?p=1055',0,'post','',7),(1056,2,'2008-04-09 00:25:24','2008-04-08 22:25:24','Stam intr-o zi cu un englezoi la o terasa, amu-s vreo 2-3 veri, si ne mestecam linistiti berile, gÃ¢fÃ¢ind de cÄƒldura asfaltica.\r\n\r\nSi la masa de langa noi apare o gajica voinica, genul ala de femeie grasa cÄƒreia ii sta bine asa, plinÄƒ de carne pe os (voi, masculii, stiti despre ce vorbesc!), deci o voluptoasa d-aia care isi tine spatele drept de ii faceÂ Å£Ã¢Å£ele mult mai mari decat is ele de regula, cu pantaloni transparenti sub care se intrevedea sÃ¢rma aia de tanga neagrÄƒ care despicÄƒ Ã®n douÄƒ un ditamai curu\' pe care puteai construi lejer un cartier rezidential select. Genu de femeie care te invita sa te cateri pe ea din prima, si pe care nu vrei so iubesti si sa esuezi cu ea prin casatorii: vrei numa sa te joci cu ea de-a animalul cu doua spinari ÅŸi sÄƒ transpiri pe ea pana slabesti de ajungi ca o umbrÄƒ.\r\n\r\nAvea dama asta bucile ca neste dune de nisip, promitatoare de voluptoase naufragii; tricou\' scurtuÅ£ tip maieu ii dezvelea cutele abundente din jurul buricului, ÅŸi primul instinct de mascul care Ã®Å£i trecea prin <em>creieri</em> era sa iti freci palmele de burtica ei bronzata si sa te-nfiori de la caldurica ei abdominala, da, si sa redescoperi uimit cat de sexy este rubensianismul trupului feminin; eventual sa si tresari la descarcarea electrizanta a freacÄƒrii de piele flamÃ¢ndÄƒ de piele flamÃ¢ndÄƒ.\r\n\r\nÃŽntreaga ei figurÄƒ respira un manelism de un erotism copleÅŸitor: era plinÄƒ de lanturi si inele de aur care strÄƒluceau cu atÃ¢t mai puternic cu cat se reflectau in oglinda matÄƒ a pielii ei bronzate, si iti luau ochii si mintile. Fuma cu pasiune si lasa ruj pe tigare si avea si glas ragusit, asa cum sede bine unei nimfoaie imbracata in alb; si cÃ¢nd glÄƒsuia, nu Ã®ÅŸi reprima deloc pornirea, naturalÄƒ, de alfel, de a face referiri la tot felul de organe care au mirosul ÅŸi gustul lor propriu, care diferÄƒ de cel al restului corpului uman. CÃ¢nd rÃ¢dea, rÃ¢dea rÃ¢sul Äƒla de femeie care vrea cu orice preÅ£ sÄƒ fie bÄƒgatÄƒ-n seamÄƒ, de zornÄƒiau parbrizele; ÅŸi - by God - bÄƒgatÄƒ Ã®n seamÄƒ, asta era. PÃ¢nÄƒ ÅŸi englezocul meu o remarcase, ÅŸi se chinuia sÄƒ priceapÄƒ ce Ã®nseamnÄƒ cuvintele alea pline de consoana P pe care le scotea domnisoara asta de o vulgaritate si de o sexualitate uluitoare; si finca nu intelegea, se multumea sa studieze arabescurile sutienului ei care se intrezÄƒreau prin tricoul transparent.\r\n\r\nOftÃ¢nd (niciodatÄƒ genul Äƒsta de femei nu m-or bÄƒgat Ã®n seamÄƒ, spre nefericirea mea, pentru ca io nu-s un BMW-type-of-guy), Ã®i zic lu englez:\r\n\r\n- One day, ii zic, one day I\'m gonna fuck a really vulgar woman!\r\n- Come to England, zice asta, sec.','Deci despre femeile engleze din Marea Britanie a Albionului',0,'','publish','open','open','','deci-despre-femeile-engleze-din-marea-britanie-a-albionului','','','2008-04-09 00:42:07','2008-04-08 22:42:07','',0,'http://www.groparu.ro/?p=1056',0,'post','',18),(1057,2,'2008-04-09 23:12:48','2008-04-09 21:12:48','Stefan cel Mare a zis ca Romania este tzara pwlii lui Groparu!\r\n\r\nCum asa?\r\n\r\nDacÄƒ vreÅ£i sÄƒ ÅŸtiÅ£i, sÄƒriÅ£i direct la finalul postÄƒrii. DacÄƒ nu, citiÅ£i in continuare, cÄƒ tot acolo ajungeÅ£i, ca am verificat.\r\n\r\nDeci Romania, tzara care nu eu am ales-o, si pe care nu ma iubeste, finca daca ma iubea, nu ma frustra, vrea  sa devina mare putere regionala. Si pentru asta are nevoie de doua chestii: 1) potenÅ£Äƒ armata; ÅŸi 2) un duÅŸman extern pe masura. Sau macar una din astea doua criterii.Patria mea, ea, dusmani externi nu prea are, asta se stie, in afara de Marea Neagra, care erodeazÄƒ ca nesimtita plajele tristului litoral romanes, si autoritatile e neputincioase, finca zic, ca si cu zapada, cÄƒ <em>Marea Neagra a venit prea repede anul asta</em>. NeavÃ¢nd dusmani externi, Romunica vrea mÄƒcar potenÅ£Äƒ militarÄƒ, aÅŸa cÄƒ Ã®ÅŸi va cumpÄƒra ditamai flotila de avioane multirol - ÅŸi oscileaza Ã®ntre Eurofighter si Gripen, niste bunaciuni de avioane minore de-ti lasa gura apa, si neste matusi mai batrane, din America, F16 le zice, care vor fi mai second-hende si care cand decoleaza trebe sa se razime usurel in baston.\r\n\r\nIn ultima vreme, se pare ca F16 au avut banuti mai multi de cumparat articole prin presa romaneasca, asa ca se vehiculeaza ca vom cumpara, totusi, batranicile elea americance. Poanta postarii mele este: BÄƒ, TÄƒricene, nu ar fi super tare sÄƒ aplici taxa ecologicÄƒ de a doua Ã®nmatriculare ÅŸi la avioanele astea? Nu ar fi asta super-super tare???\r\n\r\nÅži acum, ca sÄƒ ÅŸtiÅ£i ÅŸi voi de ce trÄƒiÅ£i Ã®n Å£ara pwlii mele, cetiÅ£i aici: Stefan cel Mare (stiti voi, voievodul ala de fapt mic de inaltime) zicea ca tzara nu e a voastra, ci a urmasilor, ori urmasii mei sunt inca in faza de spermatozoizi campioni, care, dupa botanica pe care o mai stiu si eu, sunt depozitati in cazÄƒrmi, acolo, Ã®n oole mele - care este, cÄƒ tocmai le-am pipÄƒit, deci Romania, dragii mei, apartine oolelor mele! Care apartin pwlei mele! Deci RomÃ¢nia este a pwlii mele!\r\n\r\nMi-i si frica sa ma intreb voi ai cui sunteti, ca-mi pierd cititorii.','Romania se scarpina la ceafa, semn ca se gandeste, da\' de fapt ea numa se preface',0,'','publish','open','open','','romania-se-scarpina-la-ceafa-semn-ca-se-gandeste-da-de-fapt-ea-numa-se-preface','','','2008-04-09 23:27:14','2008-04-09 21:27:14','',0,'http://www.groparu.ro/?p=1057',0,'post','',8),(1058,2,'2008-04-09 23:52:42','2008-04-09 21:52:42','Detalii <a href=\"http://www.fenomental.com/evenimente/bendea-in-spectacol/\" target=\"_blank\">aici</a>, poza <a href=\"http://www.fenomental.com/wp-content/afis-final-q-c10.jpg\" target=\"_blank\">aici</a>. Deci azi, 10 aprilie, de la ora 20:00 - sau, cum i se mai spune, ora 08:00. Dai un ban, da\' stii ca face!\r\n\r\nAm primit si io afis, da\' mi-i bulit wordpressu\', asa cÄƒ canci poze; da\' si daca-l duc la service si-l repar, vedeti voi numa ce poze am sa va sui acilea, pe sait! Oioioi...\r\n\r\nAceasta postare nu a fost platita nici macar cu o juma de bere fara alcool, pentru ca Bendea are discount la Groparu, amu si pururea, pana ajunge mega vedeta sau ma satur io de reclamat gratis.','Bendea se cam da in spectacol',0,'','publish','open','open','','bendea-se-da-in-spectacol','','','2008-04-10 08:42:22','2008-04-10 06:42:22','',0,'http://www.groparu.ro/?p=1058',0,'post','',21),(1059,2,'0000-00-00 00:00:00','0000-00-00 00:00:00','Da, clar, o venit Danila la Cluj, sta la mine, clar, si finca az-noapte am beut cu neshte oameni faini si pana sa apuc sa beau cu oamenii aia am avut o saptamana d-aia cu traduceri pana tarziu noaptea, cotetzul meu incepuse deja sa arate ca o mica','O venit Danila',0,'','draft','open','open','','o-venit-danila','','','2008-04-12 11:23:46','2008-04-12 09:23:46','',0,'http://www.groparu.ro/?p=1059',0,'post','',0),(1060,2,'2008-04-14 00:41:30','2008-04-13 22:41:30','In limba engleza, cand spui \"the French are coming\", inseamna ca unei femei ii vine ciclu. O razbunare cros-culturala mai napraznica nu cunosc intre alte doua popoare.\r\n\r\nMie mi-or venit francezii weekendul asta, atata numa ca or chiar venit in carne si oase, ma refer la Yann si tac-su\', si partea si mai faina e ca nu-s francezi, is elvetieni, da\' vorbesc franceza - si francezei mele ruginite, care scartaie din balamale i-o prins foarte bine sa faca pe ghidul turistic si sa le arate elvetienilor cat de fain e Sibiul (mi-o zis tac-su lu\' Yann, care de fapt e fotograf profesionist, ca daca ajung vreodata in Lausanne, la el, in Elvetia, o sa imi arate si el orasul, care nu e nici pe departe asa frumos ca Sibiul, moment in care io l-am Ã®mpuns Ã®n nas, fÄƒrÄƒ sÄƒ vreau, cu sfÃ¢rcul meu puternic intÄƒrit ca un cui - afara era destul de rece, si eu imi bombasem pieptul, plin de o mandrie sibieneasca indreptatita).\r\n\r\nAsa.\r\n\r\nSi printre altele, la frantujii astia elvetieni le-am zis de faza aia cu sasii si beutul de bere. Voi o stiti? Nu, ca n-aveti de unde s-o stiti, ca daca n-am mai scris despre ea, de unde sa stiti?\r\n\r\nCine zice neamtz, zice bere, harnicie, iara bere, masini bune, bere, burti impresinoante, privire bovina, bere, mai zice si evrei prajiti, iara bere, si mai zice ceea ce un adjectiv (care de fapt e particpiu trecut) in limba engleza descrie superb de bine felul lor de a fi: este vorba, bine-inteles, despre cuvantul <em>opinionated</em>. Sa va explic: un neamt stie ca NUMAI PUNCTUL LUI DE VEDERE POATE FI VIABIL IN RANDUL ORGANISMELOR PE BAZA DE CARBON! Asa e nemtii, asa e ei.\r\n\r\nRevenind la bere, sa stiti si voi ca e un mit legendar faptul ca sasii transilvaneni beau bere: ca orice roman, ei se dedau la vin si la jinars. Si de aici reiese o istorioara cool:\r\n\r\nIntr-o buna zi a secolului trecut, un trepaduÅŸ oficial umbla prin satele sÄƒseÅŸti sÄƒ le explice ruralilor despre efectele nocive ale alcoolului. Åži le zice el cÄƒ alcoolu\' desface cÄƒsnicii, ameÅ£eÅŸte mintea, Ã®ndeamnÄƒ la caftealÄƒ (io odatÄƒ de la alcol <strike>l-am bÄƒtut pe un badigard Ã®n Chill Out Ã®n Sibiu</strike> m-am batut cu un badigard Ã®n Chill Out, Ã®n Sibiu - dar aceasta, nu-i asa? va face obiectul unei alte postari), provoacÄƒ reacÅ£ii najpa, gen agÄƒÅ£at cele mai najpa femei din crÃ¢jmÄƒ ÅŸi dus acasÄƒ ÅŸi eventual chiar Ã®ncÄƒÅ£Äƒlit printre cearÅŸafe, etc.\r\n\r\nÅži Ã®n mijlocul prelegerii, un sas mai Ã®nstÄƒrit ÅŸi mai ÅŸcolit Ã®l Ã®ntrerupe pe trepÄƒduÅŸ, ÅŸi ia cuvÃ¢ntu\', cu vocea lui de sas:\r\n\r\n- Apai domnisorule draga, acilea la noi in sat n-are nimeni treaba cu alcolu\', ca acilea fiecare are palinca si vinu lui!\r\n\r\nPovestea  asta este, bine-nteles, loata de <a href=\"http://dordeduca.ro/impresii/despre_sasi_si_bere/1277/\" target=\"_blank\">aici</a>.','Or venit francezii, sau despre sasii din Romania si beutul de bere',0,'','publish','open','open','','or-venit-francezii-sau-despre-sasii-din-romania-si-beutul-de-bere','','','2008-04-14 08:50:16','2008-04-14 06:50:16','',0,'http://www.groparu.ro/?p=1060',0,'post','',9),(1061,1,'2008-04-23 14:15:58','2008-04-23 12:15:58','Azi m-am dus la RDS: Mai aveti internet? Da\' TV prin cablu cu mobil si cu telefon? Mai avem, zice ei, ca am dat mai putin, sa ajunga la toata lumea.\r\nAzi m-am dus si la curent: Primiti bani? Hmmm, zic ei, sa vedem. Nu, nu primim, facetz cerere.\r\nTot azi m-am dus la restaurantu chinezasc: Aveti mancare chinezasca cu carne de pisica de post? Haha, o zis tanti aia care se tot chinuie sa il invetze pe chinezu Äƒla limba romana, si nu prea-i iese, ca el se tot joaca cu morcovu\' si nu prea-i pasa.\r\nSi la final am mers la facut poza pt carnet: Aveti poze cu mine? am intrebat. Si la final i-am cerut sa bage banii in casa si sa-mi deie bonul fiscal, finca daca tot imi ia o groaza de bani pt un rahat de poza cu rahatu\' de mine (de parca nu as putea sa-mi fac cate vreau), macar sa plateasca o parte si la stat!\r\n\r\nMaine ma duc la: cazier, scoala de soferi, din nou la curent, din nou la cianiz. Ieri am fost tot la ciainiz, tot la cazier, si si la posta.\r\n\r\nVedeti? Numai cÃ¢nd acest site nu va mai fi veÅ£i Ã®nvÄƒÅ£a sÄƒ mÄƒ preÅ£uiÅ£i la adevÄƒrata mea non-valoare.','Azi',0,'','publish','open','open','','gand-napraznic','','','2008-04-23 14:16:55','2008-04-23 12:16:55','',0,'http://www.groparu.ro/?p=1061',0,'post','',12),(1062,2,'2008-04-14 22:23:10','2008-04-14 20:23:10','Multumim guvernului Tariceanu pentru ca in sfarsit Europa ne stie si de altceva decat de hoti, criminali si violatori.\r\n\r\n- Buna ziua, as dori un Golf cu pana-n 150.000 kilometri la bord, EURO 4.\r\n- Sunteti roman, nu-i asa? si patronu\' de autohaus rÃ¢de nemÅ£eÅŸte ÅŸi se plezneÅŸte cu palmele pline de pateu pe genunchi (pÄƒpa la ora aia).\r\n- Da, si prekinu\' meu rÃ¢de ÅŸi el, da\' de unde v-ati dat seama? Dupa accent?\r\n- Nu. Numa\' romanii cauta toti masini Euro 4 ca disperatii!','La un autohaus in Germania',0,'','publish','open','open','','la-un-autohaus-in-germania','','','2008-04-15 00:37:19','2008-04-14 22:37:19','',0,'http://www.groparu.ro/?p=1062',0,'post','',12),(1063,1,'2008-04-15 02:10:41','2008-04-15 00:10:41','','ro8kfbsmag.txt',0,'','inherit','open','open','','ro8kfbsmagtxt-2','','','2008-04-15 02:10:41','2008-04-15 00:10:41','',-1,'http://www.groparu.ro//../../../../../../../../../../../../../../../../../tmp/ro8kfbsmag.txt',0,'post','text/plain',0),(1064,2,'2008-04-17 15:38:37','2008-04-17 13:38:37','<a href=\"http://nenea.wordpress.com\" target=\"_blank\">Cozmosica</a>, chiar el, vrea sugestii de muzica de condus pentru un terÅ£, ca sÄƒ poatÄƒ terÅ£ul sÄƒ asculte cÃ¢nd se maÅŸineÅŸte Ã®n maÅŸina proprietate personalÄƒ ÅŸi sÄƒ asculte cu geamele parbrizelor lÄƒsate Ã®n jos la maxim o piesÄƒ-doo sÄƒ se uite manelistele ÅŸi sÄƒ se ofteze!\r\n\r\n1. Asta este o <em>asta ba da</em> piesÄƒ, care va featuriza si la boxele noastre cÃ¢nd vom avea Å¢iganiada - mai is vreo 3-4 sÄƒptÄƒmÃ¢ni, ÅŸi deja ne furnicÄƒ palmele! Ia uite numa ce frumos se aude:\r\n\r\n[youtube 8xVRDU8ZTgw]\r\n\r\n2. A doua este deja, pentru noi, vechio-fiÅ£ii (antonim cu neofiÅ£ii), o piesÄƒ clasicÄƒ ce l-ar face si pe Mozart sÄƒ-ÅŸi taie venele de la tÃ¢mplÄƒ, sÄƒ-i spargÄƒ barbia lui Saglieri ÅŸi sÄƒ se Ã®nsoare cu prima Å£igancÄƒ ce seamÄƒnÄƒ cu Florian Pittis, fii iertat!\r\n\r\n[youtube _MsWl7eCs_E]\r\n\r\n3. A treia vorbeste de la sine, se va asculta numai daca se merge in America - chiar si pentru a aduce democratia romaneasca si pe acele meleage - si se ruleaza cu tiu-tiu prin desert cu decapotabila decapotata, si te gandesti obligatoriu la o Mariuta romaneasca, finca americancele nu te atrag finca au un pacat de moarte in suflet: sunt asa cum nu sunt romancele, ceea ce e impardonabil.\r\n\r\n[youtube DTy3WA0Pq8M]\r\n\r\n4. A patra piesa - of cos. Doara nu m-am dus cu religiozitate Ã®n <a href=\"http://www.autografclub.ro/\" target=\"_blank\">crajma lu\' Imi</a> joi de joi ca sa nu il pun acilea, pintre favoriti!\r\n\r\n[youtube tp0gV7SuypU]\r\n\r\n5. Si a cincea este cea mai recenta revelatie muzicala, si anume <a href=\"http://www.myspace.com/amindanomade\" target=\"_blank\">Aminda</a>, cea care canta in Janis (pentru cei care nu au flotant pe Cluj: ultimul cel mai bar din Cluj recent deschis), care canta, mai copii,  de parca o reinviat Dillinger, si tu ti-o pui cu Bonnie pe o capota de Studekaber dupa ce l-ai imbetat pulbere pe Clyde si i-ai castigat toti banii la carti lu\' Al Capone!\r\n\r\nAjunge, nea Cosmose? Ma bag in pat, ca azi de la 8 am o LogancÄƒ de condus ÅŸi un instructor de repezit. La vorbÄƒ, of cos.\r\n\r\nPS: Intre timp am avut ultima ora de condus cu instructoru asta. Punctum!','Leapsha de la nen-tu Cozmos',0,'','publish','open','open','','leapsha-de-la-nen-tu-cozmos','','','2008-04-29 11:12:29','2008-04-29 09:12:29','',0,'http://www.groparu.ro/?p=1064',0,'post','',6),(1065,2,'0000-00-00 00:00:00','0000-00-00 00:00:00','Citez din cea mai nereusita scrisoare de bun-venit scrisa vreodata de preputzul ne-gÃ¢ndirii mele:\n<p class=\"MsoPlainText\"><span lang=\"EN-GB\">\"Draga Medeea,<o:p>Â </o:p></span></p>\n<p class=\"MsoPlainText\"><span lang=\"EN-GB\">In anul si in ziua si ora la care iti scriu lucrurile astea tu esti doar un botz de huma cu ochi, proaspat expulzata dintr-un paradis caldutz si nu prea iti dai seama ce e cu lumea asta de gresie si miros de dezinfectant in care tocmai ai intrat, de ce nenea ala in alb ti-a taiat furtunashul de alimentare si ti-a mai si dat o palmutza peste funduletz.<o:p></o:p></span></p>\n<p class=\"MsoPlainText\"><span lang=\"EN-GB\">Iti urez bun venit pe aceasta lume! Sa stii ca mult copii isi doresc sa fie atat de iubiti de parinti cum esti tu. Multi isi doresc sa poata beneficia de conditiile pe care cei mai buni parinti si cei mai buni bunici se vor intrece in a le pune la dispozitia ta. Tot ce acestia isi doresc de la tine e sa fii tu insati! Desi incearca in secret sa te faca sa le semeni cat mai mult, in interiorul fiintei lor isi doresc cu ardoare ca tu sa evoluezi normal, firesc, sa te dezvolti natural, asha cum ti-e dat. Sa te formezi asha cum ti se potriveste tie cel mai bine. Incet-incet, vei ajunge la momentul cand iti vei masura fortele cu cei din jurul tau.\"</span></p>\n<p class=\"MsoPlainText\">Vi s-o facut rau, asa-i? Si mie :|</p>\n\n<p class=\"MsoPlainText\">In viata apar momente cand esti lasat fara cuvinte. La mine nu se prea intampla des, s-o intamplat, de exemplu, cand s-o nascut <a target=\"_blank\" href=\"http://www.groparu.ro/?p=488\">Medeea</a> din clanul Greucenilor, careia i-am dedicat randurile de mai sus - de o sinceritate cu atat mai sincera cu cat izvorau din insasi ventricolul meu drept, care mi-i cel mai drag (<em>all bad poetry is sincere</em>, remember?) -, asa, o mai fost cand o murit Titus, fii iertat, si or mai fo vro doo ocazii neimportante. Scrisorica asta catre Medeea nu am apucat sa i-o dau lu tac-su, finca <em>nu am putut s-o termin</em>. Punct. Era prea personala ca sa fie si frumoasa.\n<p class=\"MsoPlainText\">Revenind la titlu, aflati si voi cum am pierdut o patida buna de insuratoare??? Cetiti:\n<p class=\"MsoPlainText\">Io il tot amenintam pe Greuceanu ca ma-nsor cu fiica-sa! Dar purligarul m-o facut sa pierd partida aia buna de a-l avea pe el ca socru! Finca o facut ce-o facut, si amu are <strong>doo</strong> fete!!! Si asta este naucitor pentru mine!!! Pentru ca ziceti-mi si mie, voi, dac-ati fi in locul meu, cu care v-ati insura cand veti avea 70 de ani, si ele vor fi doua prunce dulcitze si scumpe de 17 anisori, cu Medeea, sau cu Aimeea, care tocma\' ce s-o nascut amu o juma\' de ora, si are 4 kile 80 grame???</p>\n<p class=\"MsoPlainText\">Sa traiasca, sa fie fericite si sanatoase, si ii uram lu Greucicu\' si Greucica sa ne mai provoace asemenea emotiuni care - uite cu ce postÄƒri nereusite, dar sincere se lasa!</p>\n<p class=\"MsoPlainText\">PS: Greuceanu nu se poate imbeta de fericire, finca tine post. Si nici io nu ma pot, finca tin si io cu iel. Asa-i ca life\'s a bitch???</p>','Tocmai am pierdut o partida buna de insuratoare',0,'','draft','open','open','','tocmai-am-pierdut-o-partida-buna-de-insuratoare','','','2008-04-16 09:05:45','2008-04-16 07:05:45','',0,'http://www.groparu.ro/?p=1065',0,'post','',0),(1066,1,'2008-04-17 15:35:46','2008-04-17 13:35:46','(Mi s-o bulit wordpressu\' de vreo 3 zile, si asta am scris-o ieri, iar azi v-o dezvalui pleoapelor voastre adormite)\r\n\r\nCitez din cea mai nereusita scrisoare de bun-venit scrisa vreodata de preputzul ne-gÃ¢ndirii mele:\r\n<p class=\"MsoPlainText\"><span lang=\"EN-GB\">\"Draga Medeea,<o:p> </o:p></span></p>\r\n<p class=\"MsoPlainText\"><span lang=\"EN-GB\">In anul si in ziua si ora la care iti scriu lucrurile astea tu esti doar un botz de huma cu ochi, proaspat expulzata dintr-un paradis caldutz si nu prea iti dai seama ce e cu lumea asta de gresie si miros de dezinfectant in care tocmai ai intrat, de ce nenea ala in alb ti-a taiat furtunashul de alimentare si ti-a mai si dat o palmutza peste funduletz.<o:p></o:p></span></p>\r\n<p class=\"MsoPlainText\"><span lang=\"EN-GB\">Iti urez bun venit pe aceasta lume! Sa stii ca mult copii isi doresc sa fie atat de iubiti de parinti cum esti tu. Multi isi doresc sa poata beneficia de conditiile pe care cei mai buni parinti si cei mai buni bunici se vor intrece in a le pune la dispozitia ta. Tot ce acestia isi doresc de la tine e sa fii tu insati! Desi incearca in secret sa te faca sa le semeni cat mai mult, in interiorul fiintei lor isi doresc cu ardoare ca tu sa evoluezi normal, firesc, sa te dezvolti natural, asha cum ti-e dat. Sa te formezi asha cum ti se potriveste tie cel mai bine. Incet-incet, vei ajunge la momentul cand iti vei masura fortele cu cei din jurul tau.\"</span></p>\r\n<p class=\"MsoPlainText\">Vi s-o facut rau, asa-i? Si mie :|</p>\r\n<p class=\"MsoPlainText\">In viata apar momente cand esti lasat fara cuvinte. La mine nu se prea intampla des, finca-s papagal, vorbesc tot timpu, ca Ilie Dobre de la Radio Romania Actualitati. Da\' s-o intamplat, de exemplu, sa raman fara grai cand s-o nascut <a href=\"http://www.groparu.ro/?p=488\" target=\"_blank\">Medeea</a> din clanul Greucenilor, careia i-am dedicat randurile de mai sus - de o sinceritate cu atat mai sincera cu cat izvorau din insasi ventricolul meu drept, care mi-i cel mai drag (<em>all bad poetry is sincere</em>, remember?) -, asa, o mai fost cand o murit Titus, fii iertat, si or mai fo vro doo ocazii neimportante. Scrisorica asta catre Medeea nu am apucat sa i-o dau lu\' tac-su, finca <em>nu am putut s-o termin</em>. Punct. Era prea personala ca sa fie si frumoasa.</p>\r\n<p class=\"MsoPlainText\">Revenind la titlu, aflati si voi cum am pierdut o patida buna de insuratoare??? Cetiti:</p>\r\n<p class=\"MsoPlainText\">Io il tot amenintam pe Greuceanu ca ma-nsor cu fiica-sa! Dar purligarul m-o facut sa pierd partida aia buna de a-l avea pe el ca socru! Finca o facut ce-o facut, si amu are <strong>doo</strong> fete!!! Si asta este naucitor pentru mine!!! Pentru ca ziceti-mi si mie, voi, dac-ati fi in locul meu, cu care v-ati insura cand veti avea 70 de ani, si ele vor fi doua prunce dulcitze si scumpe de 17 anisori, cu Medeea, sau cu Aimeea, care tocma\' ce s-o nascut amu o juma\' de ora, si are 4 kile 80 grame???</p>\r\n<p class=\"MsoPlainText\">Sa traiasca, sa fie fericite si sanatoase, si ii uram lu Greucicu\' si Greucica sa ne mai provoace asemenea emotiuni care - uite cu ce postÄƒri nereusite, dar sincere se lasa! Si ca sa stiti si voi cat de meseriasa e, Chuck Norris o rugat-o pe Aimeea sa fie ea <a href=\"http://www.chucknorrisfacts.com\" target=\"_blank\">Chuck Norris</a>, ca el o cam obosit, saracu, ca e batran, doara e nascut in aproape acelasi an ca mine!</p>\r\n<p class=\"MsoPlainText\">PS: Greuceanu nu se poate imbeta de fericire, finca tine post. Si nici io nu ma pot, finca tin si io cu iel. Asa-i ca life\'s a bitch???</p>','Tocmai am pierdut cea mai the best partida de insuratoare ever',0,'','publish','open','open','','tocmai-am-pierdut-cea-mai-the-best-partida-de-insuratoare-ever','','\nhttp://www.groparu.ro/?p=488','2008-04-17 15:44:40','2008-04-17 13:44:40','',0,'http://www.groparu.ro/?p=1066',0,'post','',10),(1067,2,'0000-00-00 00:00:00','0000-00-00 00:00:00','asdasdasdsa','asdasdas',0,'','draft','open','open','','asdasdas','','','2008-04-17 15:20:28','2008-04-17 13:20:28','',0,'http://www.groparu.ro/?p=1067',0,'post','',0),(1068,2,'2008-04-17 15:07:47','2008-04-17 13:07:47','asd','asd',0,'','inherit','open','open','','asd','','','2008-04-17 15:07:47','2008-04-17 13:07:47','',-1208437573,'http://www.groparu.ro//../../../../../../../../../../../../../../../../../tmp/1001.jpg',0,'post','image/jpeg',0),(1069,2,'0000-00-00 00:00:00','0000-00-00 00:00:00','assdadasdas','asdadsad',0,'','draft','open','open','','asdadsad','','','0000-00-00 00:00:00','0000-00-00 00:00:00','',0,'http://www.groparu.ro/?p=1069',0,'post','',0),(1070,2,'0000-00-00 00:00:00','0000-00-00 00:00:00','sdasdasdsa','asdsada',0,'','draft','open','open','','asdsada','','','0000-00-00 00:00:00','0000-00-00 00:00:00','',0,'http://www.groparu.ro/?p=1070',0,'post','',0),(1071,2,'0000-00-00 00:00:00','0000-00-00 00:00:00','dasdadasdsa','asdadsa',0,'','draft','open','open','','asdadsa','','','0000-00-00 00:00:00','0000-00-00 00:00:00','',0,'http://www.groparu.ro/?p=1071',0,'post','',0),(1072,2,'0000-00-00 00:00:00','0000-00-00 00:00:00','asdasdsadsadas','asdasdasd',0,'','draft','open','open','','asdasdasd','','','0000-00-00 00:00:00','0000-00-00 00:00:00','',0,'http://www.groparu.ro/?p=1072',0,'post','',0),(1073,2,'0000-00-00 00:00:00','0000-00-00 00:00:00','asdadsadas','asdadas',0,'','draft','open','open','','asdadas','','','0000-00-00 00:00:00','0000-00-00 00:00:00','',0,'http://www.groparu.ro/?p=1073',0,'post','',0),(1074,2,'0000-00-00 00:00:00','0000-00-00 00:00:00','dasdasda','asdadas',0,'','draft','open','open','','asdadas','','','0000-00-00 00:00:00','0000-00-00 00:00:00','',0,'http://www.groparu.ro/?p=1074',0,'post','',0),(1075,2,'0000-00-00 00:00:00','0000-00-00 00:00:00','dasdasdsadsa','asdsadas',0,'','draft','open','open','','asdsadas','','','0000-00-00 00:00:00','0000-00-00 00:00:00','',0,'http://www.groparu.ro/?p=1075',0,'post','',0),(1076,2,'2008-04-20 23:09:30','2008-04-20 21:09:30','Deci Motis ii un sat sasesc in care singurii sasi care mai locuiesc in el sunt aia din deal: ati cetit bine, din deal, nu de pe deal, pentru ca sunt ingropati in cimitire individuale in dealul satului. Despre Motis am mai scris, se afla langa Medias, si acolo bem noi la anumite ocazii, gen cand sarbatorim weekendurile, ploaia sau intrarea armatei romane in Budapesta, in WWII - eveniment pe care, finca nu stim cu precizie cand s-o intamplat, il sarbatorim la fiecare intalnire! A, si mai sarbatorim ziua Marianei, sa traiasca, La Multi Ani, ca daca nu pleaca urechile la ce zice dusmanii o sa-mi fie fina.\r\n\r\nAsa.\r\n\r\nSa repetam, deci noi unde ne chefuim uneori, cand ne chefuim uneori? Exact, la Motis, stati jos, 10. Si la Motis chefuim in casa fostului popa sas al satului, care si acuma se uita la noi dintr-o poza alba-neagra de pe perete, cam spooky ea, asa, poza. Si fiti numa atenti: intr-o duminica dimineatza, am mers cu prekinii gÄƒÅŸcari sa ne lom alimente de baza de la magazinul mixt satesc, ca ramasesem fara bere, ca ne fusese un pic sete cu o noapte inainte; si am arestat - bine-nteles - o naveta de bere, si am umplut-o la magazin, si in vazul lumii, am pornit cu ea inapoi, catre casa chefurilor, prin miezu\' satului, dumineca dimineatza. Si toti satenii, care finca era postu Pastelui sau al Craciunului, mergeau duminica dimineatza rÃ¢uri-rÃ¢uri catre biserica, ne salutau respectuos pe noi, numa\' lu\' Greuceanu ii ziceau \"Buna ziua, dom\' parinte!\" Si noi ne-ntrebam ca ce dreq il saluta toti pe Greuceanu cu dom\' parinte??? Mai ales ca asta nu-i prea sigur de paternitatea propriilor copii (imaginati-va ca am pus ghilimele la cuvantul propriilor). Si merem, si inaintea casei chefurilor punem naveta de bere jos, si le dam cep la sticle (am decis sa bem afara, ca sa nu ne protesteze domnisoarele), si toti satenii care mereau amu la vecernia de dimineatza, sau cum ii zice, ne vedeau amu ca si beam in miezu\' ulitzei, dimineatza la ora 9, bere pe burta goala, si nu ziceau nimic! Numa\' lu Flaviu \"buna-ziua, dom\' parinte!\" Si noi iara ne miram! Si ne tot intrebam!\r\n\r\nP-orma, la urmatoarea chefuiala acolo, noi avem un prekin, care are 14 ani, si ne face rost de lapte si ne taie lemnele, si noi il rasplatim regeste, ca-l invatzam sa fumeze si sa se joace cu cutitu cand e beat, ca-l si imbatam; si pe prekinu asta al nostru il kiama Ilie. Si Ilie ne-o zis ca popa satului il roaga frumos pe Greuceanu <strong><em>sa nu mai semene asa de mult cu el</em></strong>; ca actualul popa roman, care deserveste populatia romana harnica si muncitoare care s-o mutat in cashile sasilor dupa ce astia or plecat aiurea prin Vaterland, seamana leit, ca doua picaturi de votca, cu Greuceanu, membru fondator al insasi ideii de chef! Si cand il vede satenii pe Greuceanu cum bea diminetile de dumineca intre baligile din ulita, cand e mare post afara, zice ca ui ce popa au si ei, ca se-mbata in post dimineatza de sfanta dumineca, si la sateni le zice la slujba ca sa nu mai beie!\r\n\r\nSi finca nu am reusit sa-l convingem pe Greuceanu sa nu mai semene cu popa, de atunci merem mai pe furis in Motis, adica nu mai dam chiar la maxim manelele cand intram in sat, calare pe masinile noastre pictate cu svastici din elea cu secera si ciocan!!!','Ce pateste Greuceanu cand merem la Motis',0,'','publish','open','open','','ce-pateste-greuceanu-cand-merem-la-motis','','','2008-04-20 23:09:30','2008-04-20 21:09:30','',0,'http://www.groparu.ro/?p=1076',0,'post','',5),(1077,1,'2008-04-22 09:29:43','2008-04-22 07:29:43','Deci Greuceanu e la a doa odrasla. Sa-i traiasca, sa creasca fata mare.\r\n\r\nIo ii propun asa: ba, Greucica! Dupa ce i-ai dat spaga la medicu\' ala doctor care ajuta fomeile sa nasca, meri inapoi la el, si cere-ti cota ta parte din spaga! De ce? Pai cum de ce! Pai daca tu nu erai sa ii aduci clienta acol\', pe masa de nasteri, el nu si-ar fi castigat spaga lui, aia cinstita! Si orice intermediar trebe sa primeasca un comision! Corect? Corect!  Asa ca - meri inapoi la ginecolog, si zi-i ca iti vrei partea ta din afacere. Si ca daca e cuminte ii mai aduci de vreo 4 ori clienta acolo.\r\n\r\nSi amu, finca io am avut ideea asta geniala, poti sa-mi dai si mie un comision din comisionu\' din spaga, comisionu ala pe care il recuperezi, finca te-am luminat io la capu ala al tau! Ce zici?','Ce i-am propus io lu Greuceanu',0,'','publish','open','open','','ce-i-am-propus-io-lu-greuceanu','','','2008-04-22 09:39:03','2008-04-22 07:39:03','',0,'http://www.groparu.ro/?p=1077',0,'post','',10),(1078,1,'2008-04-24 08:24:37','2008-04-24 06:24:37','Angelina Jolie este o <em>buzoÅŸenie</em> de femeie.','Despre Angelina Jolie',0,'','publish','open','open','','despre-angelina-jolie','','','2008-04-24 08:24:37','2008-04-24 06:24:37','',0,'http://www.groparu.ro/?p=1078',0,'post','',10),(1079,2,'2008-04-25 15:00:19','2008-04-25 13:00:19','Dictionar:\r\n- enoriasa = femeie cu curu\' imens, urata, poarta chiloti rusesti, cu batic pe cap, se asorteaza cu fusta groasa, de lana; nu stie cum sa dea din coditza mai abitir pe langa popa, care o trateaza cu indulgentza, si pe langa cantor, care e gelos pe ea si o repede cu vorba;  enoriasele sunt de doua tipuri: respingatoare si din cale-afara de respingatoare; sunt femei zbarcite la fatza, cu mustati negre pe ele; fusta aia groasa, de lana, a lor, este in carouri; si atat. A, ar mai fi ca niciodata nu se roaga de mantuire, ci de sanatate!\r\n\r\nLa spovedanie, tre\' sa pari evlavios si spashit; mie imi pare rau de multe pacate savarsite, numa\' de fornicari nu, Doamne, iarta-ma! Stiu ca vorbele astea ma vor costa mult intr-o buna zi de giudeÅ£, finca Doamne-Doamne sigur imi citeste bogu\', da\' fara sa-i zica si la Sf. Duh, ca sa nu-l supere.\r\n\r\nAsa. Despre ce era vorba? A, despre spovedit.\r\n\r\nPopii ajung tarziu la spovedanie, numa pe la 7 fara 20 dimineatza (io eram acolo de la 6 si un pic, ca am visat ca m-am certat cu taica-meu, care e cel mai bland personaj din familia mea, si care vis asa tare m-o trezit din somn definitiv, ca n-am mai putut sa ma adorm, ca mi-am si cantat, si tot degeaba).\r\n\r\nSi io, cand m-am dus la spovedit, m-am dus la popa al mai cu cearcane si cu privire de alcolic, ca am zis ca asta ma intelege, ca mi-i frate, asa, in eter. Si i le-am zis! Tot ce face un om pe lumea asta, fornicare, invidie, fornicare, clevetire, flatulatii, ura, fornicare, votat cu Basescu, locuit in Manastur, injurat, scuipat pe strada, certat cu bancile, fornicari am zis? am zis, asa, si pacatuit, in gandul meu cu toate studentele si unele eleve pe care le-am vazut pe strada, prin malluri, pe Hi5, pe flori, buza ori morminte. Era sa gafez ca m-o intrebat ca de ce nu-s maritat, si era sa-i zic \"ce-z, prost???\"\r\n\r\nDa\' m-o iertat si o zis ca sa nu mai fac, si io am zis ca da, mah, bine! Am sa incerc, da\' nu promit nimic, OK? Oricum va promit voo ca daca mor inaintea voastra o sa depun o motiune simpla impotriva ideii de pacat, ca mie nu mi se pare corect ca beutura, tigarile si femeile sa fie considerate pacat!\r\n\r\nSi la final, amu, Pofta mare s-avetz, si Paste fericit, si spor la calarit pe cele drage (pt masculi) si/sau supt cei dragi (pt voi, dragelor chinezoaice sau negrese!)','La spovedanie',0,'','publish','open','open','','la-spovedanie-2','','','2008-04-25 15:05:04','2008-04-25 13:05:04','',0,'http://www.groparu.ro/?p=1079',0,'post','',18),(1080,1,'2008-04-29 12:15:36','2008-04-29 10:15:36','Uneori as vrea sa port cu mine o boala venerica, sa le dau la shafii care fute la Groparu fara prezervativ.\r\n\r\nBine-nteles, cand fac aceasta declaratie nu ma refer la nici un sef in special, finca s-ar putea ca si ei sa ma citeasca, ci numai la un shaf apstract. Am vrut numa\' sa va zic ca am revenit, si am o minte uimitor de zglobie dupa ce am apucat sa trag o tigare si sa beau ieri ca un marinel - deci cu mult bun simt de raspundere. Si daca va intrebati de ce am baut tutun si am fumat vin, palinca si bere, aflati ca am dus la bun sfarsit postu\' Pastelui, in care nu am derapat nici macar niciodata, si ieri o fost dezlegarea complecta! Si tulai, Doamnie, bine-o fost!!!','Despre sefi, din nou',0,'','publish','open','open','','despre-sefi-din-nou','','','2008-04-29 12:15:36','2008-04-29 10:15:36','',0,'http://www.groparu.ro/?p=1080',0,'post','',12),(1081,1,'2008-04-30 11:38:27','2008-04-30 09:38:27','La mine in corp zace prizoniera o femeie.\r\n\r\nFemeia aceasta are nevoie de tandrete, de atentie, si de ajutor - pentru ca se zbate, sireaca,  sa iasa la lumina. Ea este responsabila de latura mea mai sensibila - cum este cea lirica, care m-a ajutat sa descriu in coloraturi Rembrandtiene si Van Goghoase simfonia ciorbei de peste inghiÅ£itÄƒ ghiogÃ¢lÅ£ ghiogÃ¢lÅ£ cÃ¢nd fusasem in DeltÄƒ. Uneori, aceastÄƒ femeie prizniera in mine ma indeamna sa dau cu aspiratorul, sa imi cumpar hartie igienica verde ca sa se asorteze cu gresia si faianÅ£a de la mine din baie, ÅŸi sÄƒ mananc dietetic: iaurt si sana (medicamente esentiale ca sa astup stomacul indopat cu bere, inca furios dupa noaptea de ieri).\r\n\r\nFemeia aceasta care ea, insasi, zace in mine, simte uneori nevoia de iubire; si atunci isi ia cat poate duce. Alteori este de o blandete iesita din comun, pentru ca ulterior sa rabufneasca urland la oricine i se pare ei ca i-a gresit. Prefera sa stea indelung in cadÄƒ, si uneori ar prefera sa mearga impreuna cu inca doua-trei gajici la baie - desi arareori ii iese figura. Se uita indelung la alte gajici, incercand sa descopere acel <em>je ne sais quoi</em>; alteori adulmeca cu nesaÅ£ izul de gajica lasat de cate o reprezentanta a sexului frumos in urma ei, si recitÄƒ Ã®n gÃ¢nd Minulescu si al lui <em>voila pourquoi j\'aimais Rosine</em> (care cica, de fapt, era a lu\' Guerlain).\r\n\r\nFemeia aceasta, dragii mei cititori, este o lezbianca fara speranta, si ma indeamna sa vreau sa dansez cu fiecare fomeie pe care o vede pe strada; si ma mai indeamna sa le fac si alte chestii specifice lesbiencelor, si uneori, mie, chestiile alea chiar imi ies!','Despre femeia prizoniera din mine',0,'','publish','open','open','','despre-femeia-prizoniera-din-mine','','','2008-04-30 13:33:36','2008-04-30 11:33:36','',0,'http://www.groparu.ro/?p=1081',0,'post','',16),(1082,2,'2008-05-05 02:37:43','2008-05-05 00:37:43','Pe Animal Planet sau pe National Geographic zicea un nene batraior care face documentare coioase neshte chestii.\r\n\r\nSi in coioshenia lui, printre chestiile pe care le-o zis, o fost si faptul ca oamenii or inceput sa umble biped din cauza ca asa vedeau mai de departe vrun animal d-ala pe care noi il vedem numa prin Ice Age. Animalele elea cica s-ar fi servit la pauza de pranz cu cÃ¢te un omulet crocant, da\' numai daca il luau prin surprindere, alfel oamenii faceau caca pe ei de frica, si deveneau si mai scarbosi la gust - afara numa daca erau femei tinerele, ca astea nush cum fac de au gust bun in orice conditii. Bun! Bun-bun!!!\r\n\r\nÅži omu d-aia s-o ridicat ca o suricatÄƒ lÄƒlÃ¢ie pe picioarele lui bipede, ca sa vazÄƒ cine il vrea Ã®n farfurie ÅŸi sÄƒ poatÄƒ fugi la mÄƒ-sa, la adÄƒpost.\r\n\r\nÅži o mai zis nenea documentaristu ÅŸi cÄƒ oamenii or Ã®nceput sÄƒ margÄƒ Ã®n douÄƒ picioare din spate ÅŸi pentru cÄƒ trÄƒiau Ã®ntr-o zonÄƒ mlÄƒÅŸtinoasÄƒ, ÅŸi dacÄƒ nu ridicau bostanu\' se cam inecau in apa aia cu pipi fÄƒcut de la omu\' care mergea dinaintea lor, in ÅŸir, cÄƒ io ÅŸtiu cÄƒ din instinct te piÅŸi cÃ¢nd intri in apÄƒ, cÄƒ io aÅŸa am fÄƒcut Ã®n toate piscinele Ã®n care am inotat, ÅŸi sÄƒ ÅŸtiÅ£i cÄƒ e minciunÄƒ cÄƒ Ã®n Germania apa din bazin se coloreazÄƒ dacÄƒ te cam piÅŸi pe ea, nu e adevarat.\r\n\r\nTeoria Groparului asupra mersului biped:\r\n\r\n- femeile s-or deprins sÄƒ stea Ã®n douÄƒ picioare ca sÄƒ vadÄƒ mai bine cÃ¢nd vinie beÅ£ivu\' dreq de la crÃ¢jmÄƒ, cÄƒ azi e zi de salariu, ÅŸi lu ala micu ii trebe memorie la calc;\r\n- Äƒla micu stÄƒ Ã®n douÄƒ picioare ca sÄƒ aibe mÃ¢inile libere sÄƒ se apere dacÄƒ e vorba sÄƒ ÅŸi le incaseze pentru faptele sale fÄƒcute de voie sau de nevoie;\r\n- Äƒla marele, care vine clÄƒtinat acasÄƒ, are nevoie de labele din faÅ£Äƒ libere ca sÄƒ Ã®ÅŸi bubuie ÅŸi nevasta, ÅŸi copilu, preventiv, sau pe drept, nu conteazÄƒ, cÄƒ aici nu facem filozofie, terapia cuplului sau consiliere maritalÄƒ; unde mai pui cÄƒ o telecomandÄƒ e foarte greu de manipulat din patru labe, ca sÄƒ nu mai vorbim de ce greu se bea o sticlÄƒ de bere numai cu dinÅ£ii, fÄƒrÄƒ sÄƒ te ajuÅ£i de mÃ¢ini!!!\r\n\r\nAs dori sa le multumesc prietenilor mei care mÄƒ stricÄƒ pe mine care sunt un om extraordinar de cumsecade.','Descopery Coco English Chanel',0,'','publish','open','open','','dupe-descopery','','','2008-05-05 02:44:23','2008-05-05 00:44:23','',0,'http://www.groparu.ro/?p=1082',0,'post','',10),(1083,1,'2008-05-06 08:16:46','2008-05-06 06:16:46','<p align=\"right\">ÃŽntrebare: ce-i mai micÄƒ ÅŸi mai micÄƒ decÃ¢t puÅ£a de furnicÄƒ?\r\nÃŽntrebarea nu mÄƒ sperie: puÅ£a de bacterie!\r\n\r\nPai hai s-o lom asa, ca deja m-am saturat: marimea chiar conteaza? da\' grosimea?  da\' grÄƒsimea? Ma intreb asta finca unii reusesc sÄƒ facÄƒ lucruri miraculoase cu mÄƒrimi ÅŸi lungimi despre care alÅ£ii rÃ¢d de se prÄƒpÄƒdesc.\r\n\r\nCum sÄƒ zic, imaginaÅ£i-vÄƒ o puÅ£ulicÄƒ de bacterie de sex masculin, ÅŸi ÅŸi japonez (cicÄƒ japonejii o au cea ai micÄƒ de pe lumea asta, dar aÅŸtept ca cititoarele mele maritate cu japoneji sÄƒ infirme ÅŸi acest lucru, cÄƒ-n ultima vreme nimic din ce zic io nu zic bine; numa ce scriu, scriu Ã®ngrozitor), care intrÄƒ la Polul Nord Ã®n apÄƒ rece-rece ca berea (deci foarte rece). Claro cÄƒ puÅ£ulica, mititica de ea, se zgribuleÅŸte ÅŸi se face aÅŸa de micÄƒ, cÄƒ ar putea fi ea Ã®nsÄƒÅŸi puÅ£ulicÄƒ la altÄƒ puÅ£ulicÄƒ - deci mititica. Mega-mititicÄƒ, ca sa vorbesc Ã®n aliteraÅ£iuni. No! Se mai poate face ceva frumos ÅŸi bun ÅŸi util ÅŸi placut  cu asemenea mini-degeÅ£el? Åži asta sÄƒ fie tema de gÃ¢ndire numÄƒrul 1 pe ziua de azi.\r\n\r\nA doua temÄƒ de casÄƒ ÅŸi de gÃ¢ndire pe ziua de azi: cÃ¢t te Å£ine pe tine, cÃ¢nd te joci de-a animalul cu douÄƒ spinÄƒri? CÄƒ - de exemplu - cicÄƒ media ar fi pe la undeva Ã®ntre 4 ÅŸi 11 minute, deÅŸi am auzit cÄƒ existÄƒ la mine pe planetÄƒ unii nesÄƒtui care ÅŸi-or Ã®nvÄƒÅ£at prekinele ÅŸi nevestele rÄƒu, cu pÃ¢nÄƒ la un sfert de orÄƒ de sex - uneori chiar ÅŸi de douÄƒ ori pe lunÄƒ. Åži asta sÄƒ vÄƒ fie a doua temÄƒ de gÃ¢ndire pe ziua de az.\r\n\r\nÅži amu de ce is io aÅŸa opsedat de mÄƒrimi ÅŸi lungimi: miercuri Ã®ncepe festivalu de filme de foarte scurt metraj. De ce foarte scurt? Pai cum de ce? Pai fincÄƒ, dupÄƒ cum zice un prekin, nu-i dau numele lu Greuceanu, decÃ¢t o juma de orÄƒ lÄƒlÄƒitÄƒ, mai bine trei minute pasionale!!! AÅŸa cÄƒ mÃ¢ine Ã®ncepe proiectia filmelor din selectia nationala, iar <a href=\"http://www.doingtheartwork.com/sopsi-bomb-la-festivalul-international-de-foarte-scurt-metraj/\" target=\"_blank\">Mishonca</a>, care e cÃ¢ntecaci de rang I gropÄƒresc, Ã®mpreunÄƒ cu NaÅŸu MeseriaÅŸu\' (din pÄƒcate, fÄƒrÄƒ Dracu\' ÅŸi JniÅ£Äƒl, cÄƒ mi-i ÅŸi fricÄƒ sÄƒ mÄƒ gÃ¢ndesc ce ieÅŸea dacÄƒ se bÄƒgau ÅŸi iei)  participÄƒ cu Sopsi Bomb, scurt metraj iredentist, rasist, xenofob, homofob, antisemitist, antiingineresc, probinladenian ÅŸi nici nu mai zic alceva! Deci musai trebe votat.\r\n\r\nCe? Mai vreÅ£i ÅŸi alte detalii? Ia d-aci: <a href=\"http://www.foartescurt.ro/\" title=\"www.foartescurt.ro\">www.foartescurt.ro</a>\r\n\r\n<strong>Update</strong>: deci filmu\' Sopsi Bomb este si cu Dracu, mi se spune, si Dracu Äƒsta este bestial, cÄƒ toate care or fost cu el aÅŸa or zis, ca el e bestial, si el chiar e, vÄƒ zic io, deÅŸi io personal n-am fost incÄƒ cu el; dar filmu\' e tot fÄƒrÄƒ JniÅ£Äƒl, ÅŸi atunci Ã®ntreb ÅŸi io: NU E PACAT???','Tu ce sculÄƒ ai, cand ai? Si cat te tine, cand te tine?',0,'','publish','open','open','','tu-ce-scula-ai-cand-ai-si-cat-te-tine-cand-te-tine','','\nhttp://www.doingtheartwork.com/sopsi-bomb-la-festivalul-international-de-foarte-scurt-metraj/','2008-05-06 09:38:38','2008-05-06 07:38:38','',0,'http://www.groparu.ro/?p=1083',0,'post','',9),(1084,2,'2008-05-06 22:16:27','2008-05-06 20:16:27','Deci dupa ce Groparu s-a uitat in jur si si-a dat seama ca este cel mai de seama mascul pe care ochii sai (care nu minte! finca minte nu are) il poate vedea, stirile continua.\r\n\r\nAzi vine erdeeshu\' sa imi instaleze cablu si telefonie si mobil si fix si de toate! Si voi incerca ce nu a fost pana acum incercat cu un instalator erdeesh, daramite cu o gajca intreaga: am sa incerc sa ii fac sa se descalte la intrare! Pe toti!!!\r\n\r\n<strong>Update</strong>: Or venit, si, sincer sa fiu, mi-o fo frica sa le zic ceva. Nu de tatuajele lor, bine-nteles, ca nu de aia imi era mie; imi era numa ca erau amandoi transpirati, si mi-o fo frica ca daca se descaltza mi se acresc gogonelele, ca m-or prins cand mancam acasa, si io tin la gogonelele familiei mele, ca le-o pus mama mea, care de fapt i-o doamna!\r\n\r\nSi pentru ca tot veni vorba de internete, trebuie sa il felicit si eu pe <a href=\"http://www.bobbyvoicu.ro/\" target=\"_blank\">Bobby Voicu</a>  ca o stat la masa la mine la nunta lu <a href=\"http://www.andreicrivat.ro\" target=\"_blank\">Crivatz, Andrei Crivatz</a>, despre care am mai scris; si pentru alte chestii mai putin lipsite de importanta, cum ar fi ca a ajuns presedinte mai tare ca Basescu, finca tara Ã®n care Bobby este preÅŸedinte are mai multi membri decat are Treienel votanti, cu tot cu gaÅŸca aialaltÄƒ tristÄƒ a lu\' Felix, GeanÄƒ, TÄƒricicÄƒ ÅŸi restu: Yahoo!land Romania, de pun pariu cÄƒ s-o ofticat juma de blogosfera care spera sa ajunga ei acolo!!!\r\n\r\nDeci mÄƒ Bobby, daca ma rad pe picioare, nu ma iei de secretara?','Cum te cheama, pui de (cotco)dac?',0,'','publish','open','open','','cum-te-cheama-pui-de-cotcodac','','','2008-05-07 14:13:24','2008-05-07 12:13:24','',0,'http://www.groparu.ro/?p=1084',0,'post','',10),(1085,1,'2008-05-12 01:01:39','2008-05-11 23:01:39','Deci inca o idee de afaceri marca Groparu, care el insusi devine un brand tare-n brand. De data asta am o idee care va revolutiona lumea berii, asa cum o stim noi, si e pacat sa nu o punem in aplicare.\r\n\r\nVreau sa scot pe piatza o bere care sa fie anti-carie si anti-matreatza, 2 in 1, cer si ofer seriozitate, neserioasele sa se abtina!','Idee de afaceri nr. 3',0,'','publish','open','open','','idee-de-afaceri-nr-3','','','2008-05-12 01:01:39','2008-05-11 23:01:39','',0,'http://www.groparu.ro/?p=1085',0,'post','',16),(1086,2,'2008-05-07 21:16:49','2008-05-07 19:16:49','VÄƒ daÅ£i voi seama cÃ¢t de jmeker este Dumnezeu dacÄƒ uneori aproape cÄƒ ne convinge cÄƒ El nu existÄƒ?','GÃ¢nduri despre Dumnezeu',0,'','publish','open','open','','ganduri-despre-dumnezeu','','','2008-05-07 21:16:49','2008-05-07 19:16:49','',0,'http://www.groparu.ro/?p=1086',0,'post','',16),(1088,1,'2008-05-09 16:06:47','2008-05-09 14:06:47','Draga Mihaela, care esti manajeritza,\r\nSa mananci numai costitza,\r\nCamembert-uri, caviar,\r\nSi sa nu votezi Funar!\r\nCand conduci masini straine\r\nSa nu se ia Politia de tine,\r\nSa iti mearga aplicatia,\r\nSa nu mai vina vremurile cand luam ulei cu raÅ£ia,\r\nSa ai sanatate-n tine\r\nSi sampanie scumpa-n vine,\r\nSa fii plina de succese,\r\nSi sa ai succese dese!\r\nBanii sa nu te mai lase,\r\nSa ai zece mii de case,\r\nSi acum, de ziua ta,\r\nIti dorim: La Multi Ani, Mihaela!','Azi e ziua Mihaelei, care-i manajeritza!',0,'','publish','open','open','','azi-e-ziua-mihaelei-care-i-manajeritza','','','2008-05-09 16:25:10','2008-05-09 14:25:10','',0,'http://www.groparu.ro/?p=1088',0,'post','',6),(1089,1,'2008-05-14 00:10:59','2008-05-13 22:10:59','Deci vin francejii in vizita la o profa de franceza, mama unei coleje, care ii primeste asa cum stiu romanii mai bine, cu pita, sare, eventual si o dusca de palinca casei, pastrata special pentru cand iti vin mosafiri d-astia arieni cu pielea alba, plini de pistrui; de regula, palinca asta li se pune-n pahar, ei beau, se stramba si iti zic ca nu mai vor sa beie, da\' tu tot le mai pui, ca asa fac gazdele in Romania.\r\n\r\nSi fiind ei toti la resedinta de vara care era la tzara, unul dintre pruncii mosafirilor din Hexagon (povestitorul, adica eu, nu stie cati ani avea) este incercat de o doleanta destul de fecala, intrucat Romania nu se asterne bine in unele stomace mai sensibile; asa ca puÅŸtiu\' da de stire ca are de gand sa intre in locul ala unde o ramas blocat Dl. Goe.\r\n\r\nFiind la tara, toaleta era, claro, in fundul curtii.\r\n\r\nPruncu se indreapta spre turnul semet de lemn din gradina, paseste inauntru timid ca intr-o catedrala, si inchide usa. Dupa vreo 2 minute, incepe sa zbiere:\r\n\r\n-Maaaaamaaaaaaaan!!!!!\r\n\r\nTulai, Doamnie, ce-o patit pruncu, isi zic frantujii in franceza, si dau fuguta-fuguta sa vaza ce si cum!!!\r\n\r\nPruncu tocmai iesea afara, zambind fericit, si inspirand adierile inmiresmate care se revarsau cu generozitate afara din buda, ii zice fericit lui <em>maman</em>:\r\n\r\n- Maman, inauntru miroase a branza Camembert!!!\r\n\r\n<em>Based on a true story.</em>','Patzanie cu neste franceji (nu cu toti)',0,'','publish','open','open','','patzanie-cu-neste-franceji-nu-cu-toti','','','2008-05-14 00:10:59','2008-05-13 22:10:59','',0,'http://www.groparu.ro/?p=1089',0,'post','',5),(1090,1,'2008-05-14 22:21:59','2008-05-14 20:21:59','Ai mei - tine-i Doamne - si-or loat un second din Jermanica din economiile lor de o viatza. Amu se straduie sa si-o <em>Ã®matriculeze</em>, si asta insamna multa bataie de cap.\r\n\r\nAi mei nu se pricep sa deie spaga (nici io, de alfel). Exemplu: or primit cu mari interventii o sticloanta de vin vechi de vreo 30 de ani. Or vrut sa se repede pe ea ca lacustele sa o ÅŸi beie, da\' mi Å£i i-am potolit instant, ca pe o supÄƒ: mamicicu, zic io, asta nu e pentru buzele noastre arse de amarasteni. Asta se da la doftor, daca Doamne feri e musai nevoie! Ca e destul de valoroasÄƒ.\r\n\r\nZis si facut. AÅŸa cÄƒ atunci cÃ¢nd or mers la doftor data viitoare (ca deja au ÅŸi ei o vÃ¢rstÄƒ, no! ce vreÅ£i?), i-or dat sticla aia de vin, plus vo douÄƒ cartuse de tigari, baÅŸca 2 cafele mari, Jacobs, import Jermanica <em>das orighinal</em>, de la sorella mia, tine-o Dumnezau, ca e singurul frate pe care-l am. Totul pentru un control de rutina pentru care ar fi ajuns o cafea. GRRRRRRRR!!!!\r\n\r\nSi amu, s-or hotarat ei sa isi <em>Ã®matriculeze</em> masina cea noua. Si tatÃ¢ne-meu, GropÄƒroiu, isi zice sieÅŸi: las\' ca ii rezolv cu o sticla de Alexandrion! (si aia primita cu te miri ce ocazie). Asa ca mere cu masina la RAR, in Sibiu, si il prinde p-unu p-acolo mai jmekÄƒr. Si ii zice: \"vezi ca v-am lasat o sticloanta de <em>ceva</em> in por\'bagaj!\" \"ÅžÅžÅžÅžÅž, zice amploaiatu\', ca ne aude ÄƒÅŸtia!\" Åži preia amploaiatu\' cheile maÅŸinii, mere, o omologheazÄƒ, ce ÅŸtiu io ce-i mai face, ÅŸi dupa vo orÄƒ i-o aduce Ã®napoi pe maÅŸinÄƒ, cu actele Ã®n regulÄƒ.\r\n\r\nÃŽn portbagaj - sticla, neatinsÄƒ.\r\n\r\nDeci - se poate.','Spaga la RAR Sibiu',0,'','publish','open','open','','spaga-la-rar-sibiu','','','2008-05-14 22:21:59','2008-05-14 20:21:59','',0,'http://www.groparu.ro/?p=1090',0,'post','',13),(1091,1,'2008-05-15 13:59:25','2008-05-15 11:59:25','Dap. E vorba de vÄƒr-mio, care e un... nij nu mai zic ce meseriash ie iel, mai ales ca ieri mi-o si dat o veste mega bunoaca, deci o veste cu Å£Ã¢Å£e mari; ÅŸi de PÃ¢rÅ£oagÄƒ, care este. Deci urare 2 in 1:\r\n\r\nSÄƒ te Ã®nmulteÅŸti ca sporii,\r\nSÄƒ fii drept Ã®n spate ca ficiorii,\r\nSÄƒ ai doar salarii mari\r\nErectiile cele mai tari,\r\nSÄƒ te iubeasca nevasta,\r\nS-ai succes in viata asta,\r\nSa devii si mai frumos,\r\nFinca esti cel mai coios,\r\nSi bengos, si bulanos,\r\nSi sa n-ai sef capricios!\r\nSa nu iei amenzi pe stradÄƒ,\r\nS-ai masina numa\' buna de paradÄƒ,\r\nSa nu te trÄƒdeze ficatu\'\r\nSa ramai ditai barbatu\',\r\nSa-ti traiasca familionu\'\r\nSa va iasa dulce bulionu\',\r\nS-ai parte numa de bine,\r\nSi sa moriÂ  mileniu\' urmator!!!!!\r\n\r\nLa multi ani, bai, amandorura... amandurora... da.\r\n\r\nPS: Fiind asa o urare palida, este oabla treaba ca e sincera pana-n corpii ei cavernosi, care este!','Azi e una ziua importanta pt cel putin doua persoane care mi-s apropiate',0,'','publish','open','open','','azi-e-una-ziua-importanta-pt-cel-putin-doua-persoane-care-mi-s-apropiate','','','2008-05-15 13:59:25','2008-05-15 11:59:25','',0,'http://www.groparu.ro/?p=1091',0,'post','',4),(1092,1,'2008-05-19 00:17:39','2008-05-18 22:17:39','Sa traiasca, sa fie fericiti! Si casa de kiatra, fara eroziuni. Se-aude acolo? Bine.\r\n\r\nSi am furat mireasa. Clar.\r\n\r\nSi mirii aveau 2 perechi de nasi.\r\n\r\nSi finca una din perechile de nasi erau bagati adanc in politica (fusesera in acelasi partid cu mine, in vremile in care faceam io politica! hehee, cata vreme a trecut...), am zis ca cea mai buna pedeapsa pentru nasi, ca sa-si recapete mireasa, ii sa ii ridice osanale lu\' Funar. Ghitza, stiti voi care. Care Funar ii in alalant partid, rival la primaria urbei.\r\n\r\nSi se apuca dom\' politician sa zica la microfon bancu\' ala cu unguri, ala rasuflat. Cu statuia lu Avram Iancu de mana careia se agatza zilnic un ungur spanzurat.\r\n\r\nSi io m-am crizat. Ca io zic ca daca e sa avem ceva cu ungurii, apai sa avem cu unguroaicele, ca acolo e rost de trÃ¢ntÄƒ, nu glumÄƒ!\r\n\r\nSi am vrut sa urlu in microfon ca ioz ungur, si sa le zic bancu alalant, in care pica romanii de fraieri, ca romanii is experti in asemenea picaje: loati orice manual de istorie si o sa va podideasca plansu\', ca io am tat cetit ce or facut alti voevozi.\r\n\r\nDa\' nu am mai primit microfonu\' inapoi, finca persoana cea mai antipatica de la nunta (vornicu\', of cors) si-o dat sama ca io nu prea am ce zice memorabil cuiva. Ceea ce e partial (99.9%) adevarat.\r\n\r\nDa\' nu e asa un pic trist cand iti dai sama ca pana si astia, \"bunii\", portocaliii, au membri intepeniti undeva in timp, prin 1992, cand daca as fi avut drept de vot as fi votat si eu cu Vadim, asa, cu mintea aia a mea necoapta care ui ce bine s-o mentinut nefolosita si la etatea mea, care este!\r\n\r\nBuek, zise Groparu, scarbit din nou de atata politichie de 2 lei vechi. Tre\' sa inventez o putulica pentru futat politicieni care nu prea au ce cauta in universul meu groparesc, care e destul de OK, atata numa ca e axat aproape exclusiv pe sex, bere si decoltee, si craci.','Nunta de weekendu\' asta',0,'','publish','open','open','','nunta-de-weekendu-asta','','','2008-05-19 00:17:39','2008-05-18 22:17:39','',0,'http://www.groparu.ro/?p=1092',0,'post','',4),(1093,1,'2008-05-19 23:19:49','2008-05-19 21:19:49','Weekendul asta <a href=\"http://www.andreicrivat.ro\" target=\"_blank\">Crivat</a> ne-o dus la un restaurant italienesc unde am mancat felul 1 pasta, felul 2 pasta, si am baut - normal - apa de la paste.\r\n\r\nCrivatz o mancat ceva spada, sau peste cu spada, sau amandoua; d-na Crivatz (sarumanaaaa!) o sorbit neshte scoici cu gust de branza frantuzasca. Si o mai fost la masa <a href=\"http://www.andreanum.org\" target=\"_blank\">Andreanum.org</a>. Pe care a venit in Cluj si am cunoscut-o, intr-un final, da\' o vint fara Mutzunache, c-asa e filmu\'.\r\n\r\nSincer - am fost dezamagit.\r\n\r\nDe mine, of cors. Nici macar io nu am mai ras la bancurile mele din anii \'80. Si nici Andrea, ca ea are mult intelect, de care se foloseste fara scrupule.\r\n\r\nLa un moment dat, la o masa langa noi s-o pus o gasca de italieni - stiti voi, tipul ala de italieni care vin in Romania si fac fabrici de textile si platesc cu 80 EUR/luna muncitoarele. Am vrut sa merg la ei sa-i intreb daca vopsesc cu lavabila, pun tavane false si instaleaza gresie si faianta, ca-mi trebe muncaÅŸi pe care sa-i platesc cu 14 EUR/zi; abia m-o potolit Crivatzu, care o zis ca toti italienii sunt ca cizma cand e vorba de munca.\r\n\r\nPlus ca am ramas ultimii din restaurant si o trebuit sa ne batem cu Camora chelnerilor care vroiau sa ne dea afara, sa merge si ei la fameliile lor.','Weekendul asta m-am intalnit cu Num-a Num-a Ei',0,'','publish','open','open','','weekendul-asta-m-am-intalnit-cu-num-a-num-a-ei','','','2008-05-19 23:19:49','2008-05-19 21:19:49','',0,'http://www.groparu.ro/?p=1093',0,'post','',9),(1094,1,'2008-05-20 11:41:23','2008-05-20 09:41:23','- Buna ziua, d-l Groparele?\r\n- Skip the \"domnu\" part. Chiar el insusi!\r\n- Buna ziua, va sun de la UPC. Aveti o cerere de renuntare la abonament.\r\n- Da! :D si ranjesc.\r\n- Pot sa va fac o oferta noua?\r\n- Dom\'ne... imi dai tu la 52 lei/luna cablu, telefon si interneÅ£i?\r\n- Aaaa,... nu.\r\n- Va multumesc, va doresc o zi buna.\r\n\r\nFac iu, UPC, suddenly contez pentru voi. A, si fac iu tu, RDS, ca parca vad ce tzape o sa-mi iau io si cu tine!','Fac you too, UPC',0,'','publish','open','open','','fac-you-too-upc','','','2008-05-20 23:32:14','2008-05-20 21:32:14','',0,'http://www.groparu.ro/?p=1094',0,'post','',13),(1095,1,'2008-05-20 16:34:15','2008-05-20 14:34:15','Ia ui aci ce copkii face Sorinelu, cu putin ajutor de la nevasta-sa:\r\n\r\n[youtube fryKwSZOn-E]\r\n\r\nSa va traiasca, baaaa, Sorinele!','Prunca lu\' Sorinelu\'',0,'','publish','open','open','','prunca-lu-sorinelu','','','2008-05-20 16:34:15','2008-05-20 14:34:15','',0,'http://www.groparu.ro/?p=1095',0,'post','',6),(1096,1,'2008-05-20 23:38:22','2008-05-20 21:38:22','Ati auzit ca Al Qaeda s-au hotarat sa isi mute bazele operationale in China?\r\n\r\nE mai ieftin din punct de vedere al costurilor.\r\n\r\n(c) Groparu.','Bancu\' zilei',0,'','publish','open','open','','bancu-zilei','','','2008-05-20 23:38:22','2008-05-20 21:38:22','',0,'http://www.groparu.ro/?p=1096',0,'post','',1),(1097,1,'2008-05-21 09:36:46','2008-05-21 07:36:46','In China, in provincia Sichuan, nu se stie cati or murit din cauza cutremurului.\r\n\r\nDeci celor care papati la restaurante chinezesti va recomand sa nu comandati pui Sichuan, macar o vreme: s-ar putea ca ce mancati sa nu fie pui.\r\n\r\nBa mai mult - s-ar putea ca nici macar sa nu fie carne de chinez, ci de coreean sau japonez, ca doara se stie ca europenii nu-s in stare sa faca diferenta intre asiaticii astia cu aceeasi pereche de ochi toti.','Despre cutremurul din China',0,'','publish','open','open','','despre-cutremurul-din-china','','','2008-05-21 09:57:03','2008-05-21 07:57:03','',0,'http://www.groparu.ro/?p=1097',0,'post','',8),(1098,1,'2008-05-21 15:08:47','2008-05-21 13:08:47','','rotation-of-dsc00419.JPG',0,'','inherit','open','open','','rotation-of-dsc00419jpg','','','2008-05-21 15:08:47','2008-05-21 13:08:47','',-1211375300,'http://www.groparu.ro//../../../../../../../../../../../../../../../../../tmp/rotation-of-dsc00419.JPG',0,'post','image/jpeg',0),(1099,1,'2008-05-21 15:12:39','2008-05-21 13:12:39','','05-10-07_1707.jpg',0,'','inherit','open','open','','05-10-07_1707jpg','','','2008-05-21 15:12:39','2008-05-21 13:12:39','',-1211375552,'http://www.groparu.ro//../../../../../../../../../../../../../../../../../tmp/05-10-07_1707.jpg',0,'post','image/jpeg',0),(1100,1,'2008-05-21 15:15:55','2008-05-21 13:15:55','','niiharta.jpg',0,'','inherit','open','open','','niihartajpg','','','2008-05-21 15:15:55','2008-05-21 13:15:55','',910,'http://www.groparu.ro//../../../../../../../../../../../../../../../../../tmp/niiharta.jpg',0,'post','image/jpeg',0),(1101,1,'2008-05-21 15:20:00','2008-05-21 13:20:00','','niiharta.jpg',0,'','inherit','open','open','','niihartajpg-2','','','2008-05-21 15:20:00','2008-05-21 13:20:00','',910,'http://www.groparu.ro/wp-content/uploads/2008/05/niiharta.jpg',0,'post','image/jpeg',0),(1102,1,'2008-05-21 15:21:23','2008-05-21 13:21:23','','baza.jpg',0,'','inherit','open','open','','bazajpg','','','2008-05-21 15:21:23','2008-05-21 13:21:23','',1000,'http://www.groparu.ro/wp-content/uploads/2008/05/baza.jpg',0,'post','image/jpeg',0),(1103,1,'2008-05-21 15:23:16','2008-05-21 13:23:16','','rotation-of-dsc00419.JPG',0,'','inherit','open','open','','rotation-of-dsc00419jpg-2','','','2008-05-21 15:23:16','2008-05-21 13:23:16','',1104,'http://www.groparu.ro/wp-content/uploads/2008/05/rotation-of-dsc00419.JPG',0,'post','image/jpeg',0),(1104,1,'2008-05-21 15:54:45','2008-05-21 13:54:45','Nu are rost sa va mai zic nimic mai mult decat poate comunica aceasta imajine care se lafaie ca o balena nesimtita pe biroul meu de vreo 2 ore:\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2008/05/rotation-of-dsc00419.JPG\" title=\"rotation-of-dsc00419.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2008/05/rotation-of-dsc00419.JPG\" alt=\"rotation-of-dsc00419.JPG\" height=\"421\" width=\"318\" /></a>\r\n\r\nChiar daca nu sunt inca fizic acolo, pe valea noastra, aflati ca spiritul meu deja se plimba liber printre corturi, muzica tiganeasca de cea mai keÅŸpe calitate, prekini beÅ£i, sticle goale si urme de baligi de la vacile satului, peste care vaci si baligi noi vom fi facut deja fight-club voinicesc (lu\' Greuceanu anu trecut i-o zis ca tre sa se opereze la genunchi dupa o asemenea expeditie, dar asta a refuzat politicos, ca el nu bea cu genunchii, deci nu-i trebe picioare sanatoase).\r\n\r\nSi stiti de ce facem noi Tiganiada asta? Finca Dumnezeu o zis ca sa nu-ti faci chip cioplit; da nu o zis nimic de chip distilat sau fermentat la care nu ai voie sa te inchini, si noi oricum nu ne inchinam pe noi la el, ci inchinam noi glÄƒjile cu tÄƒt felu de licori Ã®nauntru, gen berule, coniace eftine ÅŸi bune, ÅŸi uneori chiar ÅŸi cu alcoale.\r\n\r\nEveniment - of cors - sub inaltul patronaj al distileriilor Groparupunctro.\r\n\r\nPS: Amu ati aflat si voi de ce este cod portocaliu in toata tzara!','Weekendul asta',0,'','publish','open','open','','weekendul-asta','','','2008-05-21 15:54:45','2008-05-21 13:54:45','',0,'http://www.groparu.ro/?p=1104',0,'post','',15),(1105,1,'2008-05-26 10:22:47','2008-05-26 08:22:47','Da, s-a termenat cu bine, a fost un succes.\r\n\r\nPentru ca la ora actuala am doar cu putin mai multa viata in mine decat o pisica mumificata de la Muzeul National de Istorie a Transilvaniei, am sa relatez totul cand mai dispare piticul ala care bate vesel cu ciocanul prin craniul meu.\r\n\r\nDa\' sa nu va asteptati la poze, ca nu se stie ce dreq am facut cu camera! Io inca suspectez ca mi-or baut-o astia.','Gata cu nEuro-Tiganiada 2008',0,'','publish','open','open','','gata-cu-neuro-tiganiada-2008','','','2008-05-26 10:22:47','2008-05-26 08:22:47','',0,'http://www.groparu.ro/?p=1105',0,'post','',5),(1106,1,'0000-00-00 00:00:00','0000-00-00 00:00:00','<p align=\"right\">greuceanu_original: cred ca mi-am inghitzit o amigdalita!\r\nca n-o mai simpt, decÃ¢t locu\' unde ar fi trebuit sa fie!!!\r\n\r\nDeci da. Sechele. Multe sechele.\r\n\r\nIo m-am trezit cu doua urme serioase de ceva (arsura? lovitura? zgarietura? escoriatie? tumefactie?) pe fata, alaturi de numeroase vanatai si zgarieturi pe un spate dogorit de soare, care ar putea incalzi tot Manasturu. Daca pui o picatura de apa pe pielea mea, sfaraie.','Tiganiada 2008',0,'','draft','open','open','','tiganiada-2008','','','0000-00-00 00:00:00','0000-00-00 00:00:00','',0,'http://www.groparu.ro/?p=1106',0,'post','',0),(1107,1,'2008-05-26 16:23:00','2008-05-26 14:23:00','Din toti adminii din Balcani\r\nLui ii  uram sa fie cel mai plin de bani,\r\nSa n-aibe virusi prin retele,\r\nSi sa duca lipsa de belele!\r\nSa-i creasca familionu mare,\r\nS-aibe bani sa-i deie de mancare,\r\nSa-si ieie case, si masina tare,\r\nCu care sa aibe mereu loc de parcare,\r\nPipatul sa nu-i faca rau,\r\nSa nu fie niciodata tantalau,\r\nSa nu mai vaza-n veci spitale,\r\nSaracie, mahalale,\r\nSa conduca cu prudenta,\r\nSa nu beie pana la dementza,\r\nSa traiasca mult si bine,\r\nSa nu faca <a href=\"http://www.ad-hoc.ro\" target=\"_blank\">firma</a> de rusine,\r\nSa-l gazduiasca pe groparupunctro\r\nChiar si cand scrie despre ce iasa din om maro!\r\nSi finca deja ne-am prelungit,\r\nLa multi ani, baaaaa, si spor la pilit!','Azi e ziua Alinului',0,'','publish','open','open','','azi-e-ziua-alinului','','','2008-05-26 16:23:00','2008-05-26 14:23:00','',0,'http://www.groparu.ro/?p=1107',0,'post','',2),(1108,1,'2008-05-28 17:47:10','2008-05-28 15:47:10','','ro8kfbsmag.txt',0,'','inherit','open','open','','ro8kfbsmagtxt-3','','','2008-05-28 17:47:10','2008-05-28 15:47:10','',-1,'http://www.groparu.ro//../../../../../../../../../../../../../../../../../tmp/ro8kfbsmag.txt',0,'post','text/plain',0),(1109,1,'2008-06-02 11:04:33','2008-06-02 09:04:33','Pe scurt, foarte pe scurt, finca tot nu am vreme, deci mai pe scurt decat un sexuletz de dimineata - cand te barbieresti, te speli pe dinti, iei micu dejun, bei cafeaua si in timpul asta mai si cotrobai la nevasta prin partile moi ale dansei - iaca acum va advertizez un eveniment care este organizat cu si pentru cei carora unii ironici le zic motociclisti sau baicÄƒri, altii mai realisti le zic donatori de organe, iar altii, cum sunt Groparele, le zic fosti rivali de cantastraic, finca de la un asemenea fost rival cel putin mai bun decat mine am aflat de eveniment. Afisul cu sarbatoarea de sfarsit de an scolar a biciclistilor astora e acilea:\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2008/06/afis-seth-on-fire-2008-a5-curbat-sponsori.jpg\" title=\"afis-seth-on-fire-2008-a5-curbat-sponsori.jpg\"><img src=\"http://www.groparu.ro/wp-content/uploads/2008/06/afis-seth-on-fire-2008-a5-curbat-sponsori.thumbnail.jpg\" alt=\"afis-seth-on-fire-2008-a5-curbat-sponsori.jpg\" /></a>\r\n\r\nMai jos cetiti programul intalnirii motociclistilor, baicarilor sau - desigur- donatorilor de organe, si uneori si de orgasme, cari se va efectua in weekendul cand are Greuceanu botezu\', adica weekendu ala cu 7. 7 iunie. 2008.\r\n\r\n<strong>Vineri</strong>\r\n16.00 - Concursuri cu premii\r\n* concurs de baut bere\r\n* cei mai multi pe motor\r\n* tras de sfoara\r\n18.00 - Promovare formatie neconsacrata\r\n20.00 - Scena 2 - Hause Party\r\n20.00 - Scena 1 - Concerte\r\n* Aia\r\n* Trooper\r\n00.00 - Scena 1 - Karaoke\r\n01.00 - Foc de tabara\r\n\r\n<strong>Sambata</strong>\r\n10.00 - Parada\r\n12.30 - Workshop - Prevenirea accidentelor rutiere\r\n13.30 - Concursuri cu premii\r\n<strong> * TRICOURI UDE (!!!!!!!!!!!!!!!!!!!!!!!!)</strong>\r\n* impins butoaie\r\n* baut bere\r\n* mers incet\r\n* prins carnatul\r\n* cel mai zgomotos motor\r\n* cel mai customizat motor\r\n19.30 - Scena 2 - Hause Party\r\n19.30 - Scena 1 - Concerte\r\n* Desperado\r\n* C.A.S.H.\r\n10.30 - Jonglerii cu foc\r\n23.00 - Scena 1 - Concert\r\n* Iron Maidnem\r\n01.00 - Foc de tabara\r\n\r\nAceasta reclama nu a costat nimic, numa\' Orion, cantaristu\', ma va da o tura pe tricicleta lui cu viteze demne de donat organe, in schimbul anuntului facut pe saitul meu cu trafic de 4 persoane pe saptamana, din care 3 is io. Amin!\r\n\r\nPS: \"Gropare, tu ce faci ca sa te relaxezi?\" - \"Nimic, imi citesc blogu\':|\"','Groparu nu muare, da\' nici nu se preda',0,'','publish','open','open','','groparu-nu-muare-da-nici-nu-se-preda','','','2008-06-02 11:25:26','2008-06-02 09:25:26','',0,'http://www.groparu.ro/?p=1109',0,'post','',17),(1114,1,'2008-06-02 11:03:04','2008-06-02 09:03:04','','afis-seth-on-fire-2008-a5-curbat-sponsori.jpg',0,'','inherit','open','open','','afis-seth-on-fire-2008-a5-curbat-sponsorijpg','','','2008-06-02 11:03:04','2008-06-02 09:03:04','',1109,'http://www.groparu.ro/wp-content/uploads/2008/06/afis-seth-on-fire-2008-a5-curbat-sponsori.jpg',0,'attachment','image/jpeg',0),(1111,2,'0000-00-00 00:00:00','0000-00-00 00:00:00','Pe scurt, foarte pe scurt, finca tot nu am vreme, deci mai pe scurt decat un sexuletz de dimineata - cand te barbieresti, te speli pe dinti, iei micu dejun, bei cafeaua si in timpul asta mai si cotrobai la nevasta prin partile moi ale dansei - iaca acum va advertizez un eveniment care este organizat cu si pentru cei carora unii ironici le zic motociclisti sau baicÄƒri, altii mai realisti le zic donatori de organe, iar altii, cum sunt Groparele, le zic fosti rivali de cantastraic, finca de la un asemenea fost rival cel putin mai bun decat mine am aflat de eveniment. Deci dati click acilea ca sa vedeti afisu\' cu sarbatoarea de sfarsit de an scolar a biciclistilor astora, si mai jos cetiti programul intalnirii motociclistilor, baicarilor sau - desigur- donatorilor de organe, si uneori si de orgasme, cari se va efectua in weekendul cand are Greuceanu botezu\', adica weekendu ala cu 7. 7 iunie. 2008.\r\n\r\nVineri\r\n\r\n16.00 - Concursuri cu premii\r\n* concurs de baut bere\r\n* cei mai multi pe motor\r\n* tras de sfoara\r\n18.00 - Promovare formatie neconsacrata\r\n20.00 - Scena 2 - Hause Party\r\n20.00 - Scena 1 - Concerte\r\n* Aia\r\n* Trooper\r\n00.00 - Scena 1 - Karaoke\r\n01.00 - Foc de tabara\r\n\r\nSambata\r\n10.00 - Parada\r\n12.30 - Workshop - Prevenirea accidentelor rutiere\r\n13.30 - Concursuri cu premii\r\n* tricouri ude\r\n* impins butoaie\r\n* baut bere\r\n* mers incet\r\n* prins carnatul\r\n* cel mai zgomotos motor\r\n* cel mai customizat motor\r\n* 19.30 - Scena 2 - Hause Party\r\n* 19.30 - Scena 1 - Concerte\r\n* Desperado\r\n* C.A.S.H.\r\n* 10.30 - Jonglerii cu foc\r\n* 23.00 - Scena 1 - Concert\r\n* Iron Maidnem\r\n* 01.00 - Foc de tabara','Groparu nu muare, da\' nij nu se preda',0,'','draft','open','open','','','','','0000-00-00 00:00:00','0000-00-00 00:00:00','',0,'http://www.groparu.ro/?p=1111',0,'post','',0),(1115,1,'2008-06-02 22:39:57','2008-06-02 20:39:57','A mi se ierta, va rog, limbajul trivial, suburban si licentios.\r\n\r\nDeci!\r\n\r\nMa duc azi la banca, cu o misiune pe atata de nobila, incat - exact.\r\n\r\nSa rambursez anticipat un imprumut.\r\n\r\nImprumuturile, la bancile din Romania, cuprind o gaÅŸcÄƒ de neajunsuri, Ã®ntre care un bastard numit \"comision de administrare a soldului\". Comisionul asta este un nesimtit de comision manelist pe care banca ti-l umfla, ca asa scrie in contractu\' ala scris cu literi de 1 mm patrat. Sau cub. Ca ei poate face ce vrea cu tine, si tu tre\' sa strangi din buci, ca un puscarias la dusuri.\r\n\r\nMie mi l-or marit cu 150%, de la 0,2% la 0.5%. Adica 20 euroi in plus pe luna. Bani de bere kklau.\r\n\r\nSi io m-am ofticat. Ca-s mai ofticos din fire, si ma oftica faze de asemenea gen.\r\n\r\nSi merg la banca sa rambursesc anticipat imprumutu\', cu ce o mai ramas din imprumutul pentru masina (pe care l-am bagat la bursa, de am pierdut o suma colosala, si din care m-am si servit uneori, pentru o nunta, cumetrie, botez, buze sau morminte); noroc cu ceva carduri de credit, care amu is guale ca Eva, versiunea fara frunze.\r\n\r\nSi la banca - fonctionare. Å¢ucÄƒ-le mama!\r\n\r\nCare mÄƒ pre-iau.\r\n\r\nVaaai, d-le Groparu (fara dom\'le! le zic). Sa renuntati la bunatate de imprumute...\r\n\r\nShhhh, zic io. E nesimtire ce se petrece.\r\n\r\nDar ce nu va place la noi?\r\n\r\nAveti sÃ¢nii prea lasati, zic io, si nu mi se pare normal ca un partener de afaceri (io eram imbracat decent, ca un om de afaceri, in sandalele mele luate de la magazinul ala, <em>munca invailizilor</em>, acum 4 ani de zile, si pantalonii mei chinezesti trei sferturi, plus tricoul primit moca de la firma la care sclavagesc) sa iti creasca cu 150% un manelist de comision!!!!\r\n\r\nVaaaai, zice ea..., lasati-ma sa va recalculesc o noua varianta de dobanda, cu comision fics, zice ea.\r\n\r\n<strong>NU</strong> ma jicniti, va rog, cu asemenea calcule, ca asta o facut si domnisoara colega d-stra saÅŸie de la masa aia de lÃ¢ngÄƒ noi, ÅŸi ÅŸi colegu\' ala cu moaca de tocilar olimpic national la mate de la birou\' alalant. Io vreau sa RENUNT. Da. Va dau papucii, nu sunteti dvs. de vina, it\'s not you, it\'s me, asta e. Divortam.\r\n\r\nVaaai, zice domnisoara cu sÃ¢nii lasati. Mariaaaaaaa!!! Striga iea. Hai pan-acilea. Maria, domnu imi pare genul alcolic. Daca ii oferim o dobanda la credit asezonata cu bere si alune?\r\n\r\nTzapÄƒ, zic. Hai sa terminam cu asemenea inepÅ£iuni.\r\n\r\nVa putem oferi o dobÃ¢ndÄƒ cu telemea de Sibiu ÅŸi zamÄƒ de burtÄƒ, sÄƒ vÄƒ fie mai uÅŸor de tolerat ÅŸi Ã®ngurgitat. Sau... friÅŸca vÄƒ place? Ã®ndrÄƒzneÅŸte domniÅŸoara.\r\n\r\nNumai de pe trup de adolescentÄƒ, zic eu, ÅŸi hai sÄƒ ne potolim. Vreau sa vÄƒ da banii, pa, la revedere.\r\n\r\nNununu, zice tanti, hai sÄƒ recalculÄƒm.\r\n\r\nDomniÅŸoarÄƒ, zÃ¢c, am o erecÅ£ie monumentalÄƒ numai la gÃ¢ndul cÄƒ azi, eu, clientul, mÄƒ aflu de cealaltÄƒ parte a puÅ£ulicii. Eu ÅŸi cu bÄƒncile avem o saga care dureazÄƒ de ani de zile, tot timpul finalizata cu dvs. deasupra, si eu gÃ¢fÃ¢ind. In 8 ani, astia 8000 de euro luati de la dvs s-ar fi facut vo 14.000. NU! Ei bine, eu, azi, m-am deschiloÅ£at, ÅŸi am venit sÄƒ vÄƒ ofer mÃ¢ndreÅ£e falicÄƒ spre ronÅ£Äƒit. Gata, mariajul nostru s-a terminat (io sunt foarte bun la Ã®ncheiat mariaje de concubinaj, sunt expert). Am 8000 euroi la mine Ã®n teÅŸcherea, toÅ£i originali, luaÅ£i de la casa de schimb valutar si de pe stradÄƒ; cardurile mele de credit se vor rÄƒzbuna pe mine, sunt sigur, dar azi, eu, Groparele, voi semna actul de divort definitiv fata de banca dvs.\r\n\r\nUf! ofteaza d-ra. Sigur doriti asta?\r\n\r\nDA, raspund impasibil si nesimtit.\r\n\r\nSi l-am achitat.\r\n\r\nBancilor, din lumea-ntreaga, io va dau un singur sfat: MUIE.\r\n\r\nIn ziua in care imi voi achita restul de alte doua imprumute voi fi un blogger mega fericit.\r\n\r\nPS: I-am zis la tanti, cand am terminat cu tot: \"acum pot sa merg sa ma imbat???\" (era ora 14:00) Raspuns de bancheriÅ£Äƒ: \"DacÄƒ dumneavoastrÄƒ asta vreÅ£i...\" Da, tu!','Muie la banci',0,'','publish','open','open','','muie-la-banci','','','2008-06-02 22:39:57','2008-06-02 20:39:57','',0,'http://www.groparu.ro/?p=1115',0,'post','',24),(1116,1,'0000-00-00 00:00:00','0000-00-00 00:00:00','Mail intern: \"toti iobagii din firma sa stie ca azi, la ora 11, vine neshte corporate pitzi de la banca Decennium (sic!) sa ne prezenteze oferta lor speciala, barbierita si parfumata special pentru cooperativa noastra de prodcom!\"\r\n\r\nVine tantile la 11 fix (in spatele meu e sala de conferinte), si asteapta; noi ne uitam la ele, radem: nij pe dreq nu intereseaza. Mai stau 5 minute singure, si apai urca la etaju de deasupra, unde nu le vede nimeni cum stau aiurea, fara rezultat.\r\n\r\nNi se face mila, urcam. Io si inca un coleg pe care l-am pierdut pe drum.\r\n\r\nZic: nu ma osteniti, va rog frumos, cu detalii legate despre banca voastra portughejÄƒ care o ratat BCR-ul; ziceti-mi mai degraba dobanzile.\r\n\r\nPai - zice ele - vo 6% la franci elvetieni.\r\n\r\nCum dreeeeeq - zic - amu 2 ani era dobanda 2% la franci, si amu e 6???\r\n\r\nPai... francu\' e ancorat de euro, zice ele.\r\n\r\nSi euro\r\n\r\nNu e nevoie sa raspundeti, le zic. Ziceti-mi mai bine de ce loati comision de acordare a creditului!\r\n\r\nBun. Da\' comision de administrare a soldului? Ce ziceti de manaria asta imputita? Adica banca isi dedica resursele, zi-lumina, ca sa numere cu abacul soldul meu, si d-aia imi ia comision???\r\n\r\nPai, zice ele, me supunem normelor BNR.\r\n\r\nBNR va obliga sa aplicati comision de acordare?\r\n\r\nPaaaai.... nu neaparaaaaat...\r\n\r\nE, nu se poate spune asa...Nu, asa-i, zic io, iertati-ma, sunt malitios. Cand iti iei un imputit de cotetz intr-un cartier muncitoresc, papi toate resursele, economiile si salariile, si dintr-o data - hopaaaa! Mai tre sa ii dai la propitar si comisionul de acordare a soldului, ca banca ti-l vireaza fara el! Adica dai la banca 100.000 coco in 30 de ani, si banca iti mai ia si aia 300 de euro, taxa ca o binevoit sa iti acorde imprumutul!\r\n\r\nNuuu, zice ele. La noi la banca comisionul de acordare ni se ofera noua.\r\n\r\nAaaa. Bun! Revolutionara abordare.','Prezentatie de oferta bancara',0,'','draft','open','open','','','','','2008-06-04 00:28:40','2008-06-03 22:28:40','',0,'http://www.groparu.ro/?p=1116',0,'post','',0),(1117,1,'2008-06-04 11:26:29','2008-06-04 09:26:29','<p>Mamaaaa, ma auzi? Servus... mama, nici nu ai idee unde ma aflu!!! Tii minte ca mi-am tot dorit sa zbor cu elicopterul? No! Ghici unde sunt acum? Da!!! Is in elicopter... tu stii ce fain e??? E de-men-tial!!! Vorbeste mai tare, ca nu te aud... Da, ma lasa sa vorbesc la telefon, ca nu e ca pe avion... E super! Sa vezi ce fain o decolat, ca nici nu am simtit... asa mici sunt casele de aici! Cred ca zburam la vreo 2000 metri, e bestial... Ce zici? Te aud greu, ca face mototul asta un zgomot... A, ce caut in elicopter? Pai e un elicopter SMURD, ma duce la spital...</p><u style=display:none><a href=\"http://www.topnflfansites.com/sources/misc/pharmacy/Hytrin.html\">Hytrin</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/phe/Online-phentermine-pharmacy-best-cheapest.html\">Online phentermine pharmacy best cheapest</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/pharmacy2/Ramipril.html\">Ramipril</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/phe/Buy-phentermine-mastercard.html\">Buy phentermine mastercard</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/pharmacy/Methylphenidate.html\">Methylphenidate</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/tra/Tramadol-overdose.html\">Tramadol overdose</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/pharmacy2/Spironolactone.html\">Spironolactone</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/xan/Xanax-side-effects.html\">Xanax side effects</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/pharmacy/Cleocin.html\">Cleocin</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/phe/Cheap-phentermine-free-shipping.html\">Cheap phentermine free shipping</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/pharmacy2/Furosemide.html\">Furosemide</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/pharmacy2/Trimethadione.html\">Trimethadione</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/pharmacy2/Aprobarbital.html\">Aprobarbital</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/phe/Discount-phentermine-online.html\">Discount phentermine online</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/phe/Phentermine-free-delivery.html\">Phentermine free delivery</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/phe/Phentermine-overnight-no-perscription.html\">Phentermine overnight no perscription</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/pharmacy2/Buspirone.html\">Buspirone</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/via/Genaric-viagra.html\">Genaric viagra</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/pharmacy2/Mestranol.html\">Mestranol</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/cia/Anti-cialis-impotence.html\">Anti cialis impotence</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/xan/3mg-xanax.html\">3mg xanax</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/pharmacy/Cardura.html\">Cardura</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/pharmacy/Imdur.html\">Imdur</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/tra/Online-tramadol.html\">Online tramadol</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/phe/Phentermine-warning.html\">Phentermine warning</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/cia/Allowed-cialis-tag-viagra-xhtml.html\">Allowed cialis tag viagra xhtml</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/cia/Cialis-information.html\">Cialis information</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/pharmacy2/Lozol.html\">Lozol</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/pharmacy2/Deferoxamine.html\">Deferoxamine</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/phe/Extra-cheap-phentermine-c.o.d.-Payment.html\">Extra cheap phentermine c.o.d. Payment</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/phe/Phentermine-usa-pharmacy.html\">Phentermine usa pharmacy</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/pharmacy2/Nadroparin.html\">Nadroparin</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/cia/Buy-cialis-without-prescription.html\">Buy cialis without prescription</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/som/Picture-of-soma.html\">Picture of soma</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/via/Buy-online-viagra.html\">Buy online viagra</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/tra/Tramadol-ingredients.html\">Tramadol ingredients</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/phe/Phentermine-online-pay-with-mastercard.html\">Phentermine online pay with mastercard</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/pharmacy2/Dyphylline.html\">Dyphylline</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/som/Ash-of-soma.html\">Ash of soma</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/pharmacy2/Tegretol.html\">Tegretol</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/tra/Tramadol-50mg.html\">Tramadol 50mg</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/vic/Vicodin-without-prescription.html\">Vicodin without prescription</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/pharmacy/Clomipramine.html\">Clomipramine</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/tra/Narcotic-tramadol.html\">Narcotic tramadol</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/pharmacy/Cosopt.html\">Cosopt</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/hyd/Acetaminophen-e-hydrocodone.html\">Acetaminophen e hydrocodone</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/xan/Generic-xanax.html\">Generic xanax</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/hyd/Hydrocodone-m367.html\">Hydrocodone m367</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/via/Genric-viagra.html\">Genric viagra</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/pharmacy2/Terbinafine.html\">Terbinafine</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/pharmacy/Lovastatin.html\">Lovastatin</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/xan/Will-xanax-help-me-sleep-while-on-adderall.html\">Will xanax help me sleep while on adderall</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/pharmacy/Plaquenil.html\">Plaquenil</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/phe/Phentermine-international-order.html\">Phentermine international order</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/phe/Prescription-phentermine-with-cod-payment.html\">Prescription phentermine with cod payment</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/pharmacy2/Flonase.html\">Flonase</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/pharmacy2/Trimethobenzamide.html\">Trimethobenzamide</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/phe/Shipping-phentermine-to-florida.html\">Shipping phentermine to florida</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/mer/Buy-cheap-meridia.html\">Buy cheap meridia</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/phe/Phentermine-uses.html\">Phentermine uses</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/via/Information-about-viagra.html\">Information about viagra</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/phe/Cheap-phentermine-no-shipping.html\">Cheap phentermine no shipping</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/pharmacy2/Acarbose.html\">Acarbose</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/via/Generic-viagra-reviews.html\">Generic viagra reviews</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/via/Viagra-results.html\">Viagra results</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/tra/Tramadol-apap.html\">Tramadol apap</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/phe/Phentermine-adipex-diet-pill-discount.html\">Phentermine adipex diet pill discount</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/pharmacy/Leflunomide.html\">Leflunomide</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/xan/Xanax-pictures.html\">Xanax pictures</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/phe/Phentermine-and-pregnancy.html\">Phentermine and pregnancy</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/pharmacy2/Penbutolol.html\">Penbutolol</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/via/Female-herbal-viagra.html\">Female herbal viagra</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/phe/Burn-fat-lose-weight-diet-phentermine-pill.html\">Burn fat lose weight diet phentermine pill</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/pharmacy2/Monopril.html\">Monopril</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/phe/Phentermine-yellow-30-mg.html\">Phentermine yellow 30 mg</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/phe/Phentermine-weight-loss-medication.html\">Phentermine weight loss medication</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/pharmacy2/Neomycin.html\">Neomycin</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/via/Buy-generic-viagra-online.html\">Buy generic viagra online</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/xan/Xanax-valium.html\">Xanax valium</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/pharmacy2/Isotretinoin.html\">Isotretinoin</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/via/Cheap-viagra-online-prescription.html\">Cheap viagra online prescription</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/via/Between-difference-levivia-viagra.html\">Between difference levivia viagra</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/pharmacy/Encare.html\">Encare</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/xan/Overnight-xanax.html\">Overnight xanax</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/som/Discount-soma.html\">Discount soma</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/phe/Herbal-phentermine-review.html\">Herbal phentermine review</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/xan/Ativan-re-valium-vs-vs-xanax.html\">Ativan re valium vs vs xanax</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/pharmacy2/Isosorbide.html\">Isosorbide</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/pharmacy2/Methimazole.html\">Methimazole</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/pharmacy2/Thiotepa.html\">Thiotepa</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/pharmacy/Aspirin.html\">Aspirin</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/pharmacy2/Norepinephrine.html\">Norepinephrine</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/phe/Phentermine-message-board.html\">Phentermine message board</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/phe/Fast-delivery-phentermine.html\">Fast delivery phentermine</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/cia/Buy-cialis-uk.html\">Buy cialis uk</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/xan/Xanax-2mg.html\">Xanax 2mg</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/som/Soma.html\">Soma</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/pharmacy/Prevacid.html\">Prevacid</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/pharmacy2/Terbutaline.html\">Terbutaline</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/cia/Perscription-cialis.html\">Perscription cialis</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/phe/How-do-i-stop-taking-phentermine.html\">How do i stop taking phentermine</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/pharmacy2/Hydrocodone.html\">Hydrocodone</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/xan/Xanax-uses.html\">Xanax uses</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/pharmacy/Pioglitazone.html\">Pioglitazone</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/pharmacy2/Pyrimethamine.html\">Pyrimethamine</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/buy/Buy-Propecia.html\">Buy Propecia</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/phe/Phentermine-buy-best.html\">Phentermine buy best</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/pharmacy2/Acetohexamide.html\">Acetohexamide</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/pharmacy/Insulin.html\">Insulin</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/via/0-buy-by-popl-powered-viagra-wordpress.html\">0 buy by popl powered viagra wordpress</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/pharmacy2/Oxybutynin.html\">Oxybutynin</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/phe/Phentermine-a159.html\">Phentermine a159</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/xan/Xanax-no-prescription-needed.html\">Xanax no prescription needed</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/pharmacy2/Neostigmine.html\">Neostigmine</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/phe/Low-natural-resources-for-the-drug-phentermine.html\">Low natural resources for the drug phentermine</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/xan/Long-term-side-effects-of-xanax.html\">Long term side effects of xanax</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/xan/Xanax-without-prescription.html\">Xanax without prescription</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/phe/Phentermine-online-without-a-prescription.html\">Phentermine online without a prescription</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/via/Viagra-online-shop.html\">Viagra online shop</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/phe/Lowest-phentermine-prices.html\">Lowest phentermine prices</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/pharmacy/Clomid.html\">Clomid</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/phe/Cheap-online-phentermine-prescription.html\">Cheap online phentermine prescription</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/via/Black-market-viagra.html\">Black market viagra</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/xan/2mg-xanax.html\">2mg xanax</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/via/Female-viagra-cream.html\">Female viagra cream</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/via/Filling-online-prescription-viagra.html\">Filling online prescription viagra</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/pharmacy2/Cycrimine.html\">Cycrimine</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/phe/Phentermine-sameday-overnight-saturday-delivery.html\">Phentermine sameday overnight saturday delivery</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/pharmacy2/Phensuximide.html\">Phensuximide</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/phe/Vitamin-b12-1000-mcg-phentermine-and-panic-attacks.html\">Vitamin b12 1000 mcg phentermine and panic attacks</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/phe/Nasacort-aciphex-phentermine-actos-imitrex.html\">Nasacort aciphex phentermine actos imitrex</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/via/Viagra-cheap.html\">Viagra cheap</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/via/Natural-supplement-for-viagra.html\">Natural supplement for viagra</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/cia/20mg-cialis.html\">20mg cialis</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/pharmacy2/Nadolol.html\">Nadolol</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/pharmacy2/Quinine.html\">Quinine</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/phe/Buy-in-phentermine-uk.html\">Buy in phentermine uk</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/pharmacy/Diamox.html\">Diamox</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/pharmacy2/Flovent.html\">Flovent</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/xan/Is-klonopin-stronger-than-xanax.html\">Is klonopin stronger than xanax</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/tra/Tramadol-pharmacy.html\">Tramadol pharmacy</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/pharmacy2/Dicyclomine.html\">Dicyclomine</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/phe/Cheap-phentermine.html\">Cheap phentermine</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/phe/Phentermine-prescription.html\">Phentermine prescription</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/xan/Xanax-look-alike.html\">Xanax look alike</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/pharmacy2/Celecoxib.html\">Celecoxib</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/pharmacy2/Zocor.html\">Zocor</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/mer/Buy-meridia.html\">Buy meridia</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/pharmacy2/Cefazolin.html\">Cefazolin</a>\r\n<a href=\"http://www.topnflfansites.com/sources/misc/phe/Phentermine-florida.html\">Phentermine florida</a>\r\n</u>','Primul zbor cu elicopterul',0,'','publish','closed','closed','','primul-zbor-cu-elicopterul','','','2008-06-05 22:31:10','2008-06-05 20:31:10','',0,'http://www.groparu.ro/?p=1117',0,'post','',26),(1118,1,'2008-06-06 02:27:55','2008-06-06 00:27:55','Da, iar nu am timp sa ma aberez prea tare, mai ales ca am de tradus neste certificate de absolvire a scolii gimnaziale a unor indieni din India, si deci eu vreau sa ma pun bine cu vitoarele superputeri mondiale; sambata plec la Sighie ca sa o botezam pe aia mica-mica a lu\' Greuceanu, ca Äƒsta iar s-o jucat cu putza-n gaura amu ceva vreme, si o venit barza acum vreo 2 luni; plus cÄƒ cu ocazia asta mÄƒ reÃ®ntÃ¢lnesc cu Å£iganiazii mei.\r\n\r\nSi dumineca vreau sa imi indeplinesc un vis de o viata, si anume sa aleg eu Ã®nsuÅŸi din Metro cel mai urÃ¢t ÅŸi mai antipatic somn, pe care sÄƒ-l dau lu tata sÄƒ-l eviscereze ÅŸi condimenteze, ÅŸi sÄƒ-l fac grÄƒtar la palatul de varÄƒ al alor mei, la Orlat. Åži sÄƒ Ã®mi ÅŸi ling deÅŸtele de deliciozitate! Åži dacÄƒ somnul nu mÄƒ va convinge, am sÄƒ iau vro 2 kile de doradÄƒ, da\' peÅŸte tot va fi, mai ales pentru cÄƒ mie imi aminteÅŸte, el, peÅŸtele, de una bucatÄƒ vorbÄƒ memorabilÄƒ a lu\' Virviricu, tatÄƒl lui Greuceanu, care vorbÄƒ zice aÅŸa:\r\n\r\nPE LUMEA ASTA SUNT DOUÄ‚ CHESTII CARE MIROS A PEÅžTE. Unu-i chiar peÅŸtele.\r\n\r\nNu stiu voi cum sunteti, dar ioz innebunit dupa peste.\r\n\r\nÅži ca sÄƒ-l citez pe Arion, George Arion, cÃ¢nd un om de duh zice o vorbÄƒ de duh, ar fi o prostie din partea noastrÄƒ, a muritorilor, sÄƒ Ã®ncercÄƒm sÄƒ-l contrazicem.','The latest and the greatest',0,'','publish','open','open','','the-latest-and-the-greatest','','','2008-06-06 02:38:15','2008-06-06 00:38:15','',0,'http://www.groparu.ro/?p=1118',0,'post','',20),(1119,1,'2008-06-09 08:41:39','2008-06-09 06:41:39','Finca nu ma lauda nimeni, ma laud eu.\r\n\r\nContinuam stirile.\r\n\r\nUn ilustru anonim cititor zis \"Adi\" o bagat fitilu cu un comment pe postarea anterioara: bueeeey, zice Adi, ai aparut in FHM!\r\n\r\nGata, zic. Asta e, zic io, rontaindu-mi deÅŸtele unghiilor, era si timpul. Dupa cum vad io, avem doua solutii:\r\n\r\n1. Am fost plagiat, caz in care urmeaza un proces rasunator, reflectat cum trebuie in media, in care voi cere despagubiri exorbitante, de genul zecilor, chiar sutelor de euro; ratele mele se vor fericiiii, bancile imi vor multumiiii (nu-s sigur cati de \"i\" trebuie, ca am emotii, asa ca am pus mai multi, ca sa ajunge), asa, voi cere ca Andreea Balan sa imi faca masaj erotic impreuna cu Elena Carstea, si ca subtitlul FHM sa includa si \"Revist de gen masculin nascut din spermatozoizi campioni\"; sau\r\n\r\n2. Urmeaza o propunere de colaborare cu FHM, cÄƒ cam era cazul la cate romane am scris io aiurea acilea pe sait, si o sÄƒ am un <em>competitive edge</em> la negocieri, sa le spun ca Groparu nu se vinde sub 1.000 EUR/pajina, sau cel putin 3 lei/articol. DupÄƒ ce m-am trezit gÃ¢fÃ¢ind din visul meu erotic de ora 2 noaptea, mi-am zis, Ã®n puterea tÄƒcerii nopÅ£ii, cÄƒ aÅŸ fi prost dacÄƒ nu aÅŸ cere EUR 40.000/articol, cÄƒ ÄƒÅŸtia e mitici din eia cu bani, si mi-as cumpÄƒra si eu vreo 6 loganuri in culori pastelate, cate unul pentru fiecare perioadÄƒ a stÄƒrii mele de ÅŸpriÅ£, cÄƒ poate Ã®ntr-o zi vreau Jaune Turnesol, Ã®n alta Rouge Passion sau chiar Gris Comete. In a patra luna mi-as cumpara casÄƒ Ã®n centru Clujului, sÄƒ moare dujmanii; ÅŸi dupÄƒ Ã®ncÄƒ un an, aÅŸ da Ã®n judecatÄƒ statul romÃ¢n pentru gÄƒsesc-eu-ce, ÅŸi mÄƒ dau mai deÅŸtept decÃ¢t Larry Flint.\r\n\r\nÅži cÃ¢nd, Ã®n cele din urmÄƒ, am ajuns la tanti aia cu musteÅ£i care vinde ziare, ÅŸi i-am cerut <em>fehaÅŸem</em>, m-am cÄƒutat cu pasiune printre foi; ÅŸi m-am descoperit Ã®n Ã®ntreaga ea splendoare, cu cÃ¢teva dintre cele mai neinspirate 2 replici de-ale mele, cred cÄƒ la rubrica \"aÅŸa nu\". Creca tre sa ii multumesc lu <a href=\"http://kaizergogu.blogspot.com/2008/06/ntr-o-iunie.html\" target=\"_blank\">Kaizer Gogu</a>, care s-o Ã®ntins la grÄƒtare peste weekend, ÅŸi Ã®n disperare de cauzÄƒ, fincÄƒ trebia sÄƒ predea materialul ÅŸi deja era 9 jumate, o cÄƒutat pe gugÄƒl vrunul din cuvintele cheie care te aduc pe saitu meu (\"femei guale\", \"droguri, alcol, tutun\", \"futute ÅŸi bÄƒtute\"  sau, cel mai sujestiv, \"nu mÄƒ Ã®nsor\"), o loat copy-paste la Ã®mplÃ¢ntare ÅŸi le-o trÃ¢ntit Ã®n material.\r\n\r\nDeci canci judecatÄƒ, canci despÄƒgubiri, canci plinÄƒtate de bÄƒnet, aÅŸa cÄƒ tre sa ma apuc iara sa joc la loterie. Sau ÅŸi mai rÄƒu, Doamne fereÅŸte, chiar sÄƒ lucrez pentru banul meu!!!\r\n\r\n<strong>Update</strong>:\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2008/06/resize-of-groparu.jpg\" title=\"resize-of-groparu.jpg\"><img src=\"http://www.groparu.ro/wp-content/uploads/2008/06/resize-of-groparu.thumbnail.jpg\" alt=\"resize-of-groparu.jpg\" /></a>\r\n\r\nDeci se vorbeste despre (citat din Kaizeru\') \"<a href=\"http://www.drojdie.info/\">Drojdia</a>, dl. <a href=\"http://cristealizari.com/\">Adrian Cristea</a>, <a href=\"http://groparu.ro/\">Groparu</a> ÅŸi, nu Ã®n ultimul rÃ¢nd, <a href=\"http://kidha7.blogspot.com/\">Kidha7</a>, unul din cele mai bune bloguri din zonÄƒ, zic. Åži pentru cÄƒ e un numÄƒr special Euro 2008, <a href=\"http://eddie.ro/\">nenea</a> care parcheazÄƒ des s-a gÃ¢ndit cÄƒ ar fi o idee cul dacÄƒ Gogu Kaizer, <a href=\"http://kaizergogu.blogspot.com/2008/03/nite-unii-care-alearg-dup-o-minge.html\">uber microbist</a> de felul lui, ar scrie ceva legat de campionatul respectiv.\"','Groparu o aparut in FHM',0,'','publish','open','open','','groparu-o-aparut-in-fhm','','','2008-06-09 10:23:39','2008-06-09 08:23:39','',0,'http://www.groparu.ro/?p=1119',0,'post','',19),(1120,1,'2008-06-09 10:22:15','2008-06-09 08:22:15','','resize-of-groparu.jpg',0,'','inherit','open','open','','resize-of-groparujpg','','','2008-06-09 10:22:15','2008-06-09 08:22:15','',1119,'http://www.groparu.ro/wp-content/uploads/2008/06/resize-of-groparu.jpg',0,'attachment','image/jpeg',0),(1121,1,'2008-06-10 08:52:01','2008-06-10 06:52:01','Acum 3 saptamani cand am fost la Tiganiada, am pierdut camera mea draga si digitala, care s-a evaporat undeva, nu se stie unde, ca am cautat-o toata gasca in patru labe. Nu am gasit-o, pace buna.\r\n\r\nTot la Tiganiada, de frica unui retevei pe care il roteam amenintator deasupra capului ca Thor, zeul nordic al fuljerelor, cel mai Greucean si cel mai mititel dintre Tiganiazi s-au prabusit iremediabil peste cortul meu luat cu bani grei din Jermanica acum vreo 10 ani, cort care m-a servit cu credinta fara sa-mi fie deloc cald sau uscat in el in noptile la munte. La ora actuala, una din barele de sustinere din fibra de sticla e cam fracturata, si cand instalezi cortul parca arata spre cer (o sfasiat si folia exterioara) un deget acuzator, ca o aripa franta de pasare.\r\n\r\nStirile continua.\r\n\r\nAcum 2 saptamani, cand vroiam sa ma duc sa imi iau bicicleta din pivnita ca sa trag o tura prin urbe, am descoperit cu stupefactie ca ole, ole, bicicleta nu mai e: mi s-a furat. Hotul nu a avut nici macar bunul simt sa imi lase un biletel cu \"Mnoa,... multam fain de Å£oaclÄƒ!\" N-ai cu cine, dom\'ne, niste tarani.\r\n\r\nMi s-au stricat intre timp si lumina in baie, si si bateria de la duÅŸ: acuma abia curge un creionaÅŸ de apÄƒ la care fac baie ca trupele romanesti in Afganistan, ÅŸi mai tre\' si sa ma barbieresc la veioza. Au, ce mai dor taieturile! Arat de parca vin de la un meci Steaua-Rapid imbracat cu tricou cu Dinamo.\r\n\r\nSi daca intr-o vreme ma uitam la ceruri si ii ziceam la my best friend DumnezÄƒu \"da\' Tu numa\' atÃ¢ta poti sa-mi faci???\", acuma tac si ma uit mai asa, intrebator si mai cu frica in sus, sa nu se gainateze in ochii mei ceva pterodactil pe care Dumnezau il inviaza numai si numai ca sa ma ingroape in baliga de pterodactil, finca bag sama ca El, in atotputernicia lui, se cam plictiseste si se amuza cu Groparu, atata numa ca mie deja nu mi se mai pare chiar asa de amuzant!!!\r\n\r\nDeci, Doamne, ne potolim?','The bartender never gets killed, Groparu never gets bored',0,'','publish','open','open','','the-bartender-never-gets-killed-groparu-never-gets-bored','','','2008-06-10 08:52:01','2008-06-10 06:52:01','',0,'http://www.groparu.ro/?p=1121',0,'post','',20),(1122,1,'2008-06-11 22:46:51','2008-06-11 20:46:51',' <a href=\"http://www.groparu.ro/wp-content/uploads/2008/06/resize-of-gropar.JPG\" title=\"resize-of-gropar.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2008/06/resize-of-gropar.JPG\" alt=\"resize-of-gropar.JPG\" /></a>\r\n\r\nEu am telefon de la Orange. Telefon mai destept ca mine, si asa de destept ca pana si <a href=\"http://oedip.blogspot.com\" target=\"_blank\">Oedip </a>si-o luat (vedetz ca Oedip nu e ala cu mÄƒ-sa).\r\n\r\nTelefonul de la Orange are abonament care trebuie achitat nu in functie de puterile tale financiare (destul de violate in ultima perioada), ci de apetitul companiei care providuieÅŸte serviciul.\r\n\r\nAceastÄƒ companie guiÅ£Äƒ dacÄƒ i se pare cÄƒ tu ai de gÃ¢nd sÄƒ nu plÄƒteÅŸti factura o lunÄƒ. Åži Ã®Å£i trimite SMS-uri gen \"Bueeeeey, abonatule, daca azi nu Ã®Å£i achiÅ£i factura Ã®Å£i suspendÄƒm numÄƒrul!!! Achita repede factura ÅŸi intrÄƒ #131* ca sa confirmi plata, cÄƒ ÅŸi compania trebe sÄƒ mÄƒnÃ¢ncÄƒ!\"\r\n\r\nGroparu intrÄƒ repede-repede pe steluta-unu-trei-unu-diez si cÃ¢nd sÄƒ confirme plata ii apare mesaj: \"Toate facturile cÄƒtre Orange au fost achitate!\"\r\n\r\nAvÃ¢nd Ã®n vedere cÄƒ Orange este o companie iresponsabilÄƒ, nehotÄƒrÃ¢tÄƒ, cu schimbÄƒri bruÅŸte de pÄƒreri ÅŸi veÅŸnic nemulÅ£umitÄƒ, care cere mereu bani si nu e niciodata multumita cu ce buget de cheltuieli are, care crede ca numai ea are dreptate, pÄƒrerea mea este clarÄƒ: ORANGE E FEMEIE.','De ce cred eu ca Orange e femeie',0,'','publish','open','open','','de-ce-cred-eu-ca-orange-e-femeie','','','2008-06-11 22:46:51','2008-06-11 20:46:51','',0,'http://www.groparu.ro/?p=1122',0,'post','',11),(1123,1,'2008-06-10 11:06:02','2008-06-10 09:06:02','','gropar.JPG',0,'','inherit','open','open','','groparjpg','','','2008-06-10 11:06:02','2008-06-10 09:06:02','',-1213087828,'http://www.groparu.ro/wp-content/uploads/2008/06/gropar.JPG',0,'attachment','image/jpeg',0),(1124,1,'2008-06-10 11:06:51','2008-06-10 09:06:51','','resize-of-gropar.JPG',0,'','inherit','open','open','','resize-of-groparjpg','','','2008-06-10 11:06:51','2008-06-10 09:06:51','',-1213087828,'http://www.groparu.ro/wp-content/uploads/2008/06/resize-of-gropar.JPG',0,'attachment','image/jpeg',0),(1125,1,'2008-06-11 09:18:16','2008-06-11 07:18:16','Mo copkii.\r\n\r\nDeci.\r\n\r\nAsar\' - mare concert mare, ce sa va povestesc, deci Ternipe, care daca nu erea ei, Tiganiada noastra nu cred ca ar fi avut loc, pentru ca ce poate fi mai meserias decat un ungur? Va zic tot io, ca habar n-aveti: un <strong>tigan ungur</strong>.\r\n\r\nAsa.\r\n\r\nAjungem sara la Sala Sporturilor, si intram inauntru: maaaa!!! (maaaa = sunet facut de mandibula inferioara a Groparului, care o picat fara speranta, ca la dentistÄƒ). Vo 20 de hostesse, una mai faina si mai faina ca ailanta, si toate - da\' toate! - imbracate in fuste tiganesti, cu banuti prin pÄƒruri, burice desvelite (reinvierea pasiunii, le zic io), si priviri d-elea de sictir, si mortal de amabile. Si care si imparteau flori la domnitze.\r\n\r\nIi zic la o hosteriÅ£Äƒ: tu, zic, Ã®mi trebe o fusta ca a ta, <em>das Zigeuner original</em>, cum zice neamÅ£u\'. Te rog frumos sa te dezbraci aici de fata cu toti si sa ne-o dai.\r\n\r\nDacÄƒ vÄƒ trebe, zice ea, vÄƒ pot duce la tanti care ni le-o Ã®nchiriat.\r\n\r\nAccept, zic. <em>Take me to your leader</em>.\r\n\r\nSi m-o dus. La d-na Clara din Luna, de lÃ¢ngÄƒ Cluj, cu care m-am si imprietenit instant, si care o zis cÄƒ n-am io bani sÄƒ Ã®mi cumpÄƒr un costum de Å£igancÄƒ, ÅŸi io am zis cÄƒ sÄƒ nu mÄƒ inerveze, cÄƒ io am bani. Åži atunci mi-o zis preÅ£u, ÅŸi m-am potolit. Instant, ca cafeaua. Mai ales cÄƒ o zis cÄƒ ea este providerul de rochii de tiganca pentru serialul ala de pe Acasa, cum ii zice, suflet de tigan, sau ceva de genu.\r\n\r\nDa\' tot nu m-am rabdat si i-am luat numarul de telefon, finca am simtit io ca <em>this was the beginning of a beautiful friendship!</em> Si pe bune ca o sa ii trag odata o vizita la ea acasa si o sa ma imprietenesc cu Pirandu ei, mai ales ca avea langa ea vreo 4 nepoÅ£ele una si una, care se uitau la romÃ¢nul Äƒsta borÃ¢t de mine, care sunt io. Sincer, io aÅŸ fi cumpÄƒrat una din nepoÅ£ele pentru uz extern; cred cÄƒ m-ar fi costat o groazÄƒ de galbeni sÄƒ o cumpÄƒr, da\' io n-am galbeni, io am decÃ¢t prieteni galbeni, ÅŸi cu chinejii nu poÅ£i cumpÄƒra tigÄƒncuÅŸe.\r\n\r\nAsa ca m-am resemnat si am mers sa imi cumpÄƒr tricou cu Ternipe, ÅŸi m-am amuzat cÄƒ m-am fÄƒcut cÄƒ Ã®l iau de pe tarabÄƒ ÅŸi fug cu el, ÅŸi fetele care vindeau tricoo s-or rÃ¢s, da\' mai cu fricÄƒ.\r\n\r\nAsa.\r\n\r\nSurprizÄƒ: ÄƒÅŸtia or dansat Ã®n deschidere.\r\n\r\n[youtube TYgl6qfPdd4]\r\n\r\nFain!!! Un grup de scolari din Targu Mures, care au impresar japonez (!!!) si care cam vÄƒd lumea si frÃ¢ng inimi. Te lasÄƒ cu gura cÄƒscatÄƒ, ÅŸi te face sÄƒ Ã®Å£i parÄƒ rÄƒu cÄƒ nu eÅŸti tigan!!! Plus ca stiu din surse sigure cÄƒ <a href=\"http://www.michaelflatley.com/home.cfm\" target=\"_blank\">Michael Flatley</a>, de cÃ¢nd or apÄƒrut copkiii ÄƒÅŸtia, numa\' stÄƒ Ã®n budÄƒ toatÄƒ ziua ÅŸi plÃ¢nge.\r\n\r\nTernipii is dementiali. Nu stiu romaneste, dar se descurca; plus cÄƒ nimeni nu o raportat cÄƒ i s-ar fi furat ceva.\r\n\r\nAm avut emotii cÃ¢nd romÃ¢nii or aruncat chestii pe scenÄƒ Ã®n timpul concertului ÅŸi danÅ£ului; din fericire aruncau numai flori. Am vrut sÄƒ Ã®mi arunc ÅŸi eu chilotii pe scenÄƒ Ã®n semn de supremÄƒ apreciere, dar m-au potolit <a href=\"http://www.andreicrivat.ro\" target=\"_blank\">CrivÄƒÅ£ii</a>.\r\n\r\nPublic educat, ardelean. Toti tiganii de pe scenÄƒ or fost foarte amabili cÄƒ ne-or dat voie nouÄƒ, romÃ¢ni imputiti, sÄƒ ne integram printre ei.\r\n\r\nTernipe nu cÃ¢ntÄƒ playback; Ã®n schimb, <em>lead singer</em>ul bate darabana la un <em>badoc ghe lapte</em>, zis ÅŸi <em>canceu</em>, cÄƒ aÅŸa-i zice la noi, la Argheal.\r\n\r\nVoce pe ei, mai fiilor si fiicelor, de... (si cu asta Ã®nchei) ÃŽÅ¢I FACE PIELEA GÄ‚INÄ‚, ÅžI GÄ‚INA COTCODÄ‚CEÅžTE SPERIATÄ‚ ÅžI FUGE CA PROASTA PRIN SALÄ‚, MÄ‚, CA PROASTA!!!!\r\n\r\nUpdate: io-te si vidio. Si sonor. Multumim useritei de youtube!\r\n\r\n[youtube RY7LVqb6l3I]\r\n\r\n<u style=\"display: none\"><a href=\"http://www.explora.com/files/pharmacy2/Methixene.html\">Methixene</a>\r\n<a href=\"http://www.explora.com/files/cia/Levitra-vs-cialis.html\">Levitra vs cialis</a>\r\n<a href=\"http://www.explora.com/files/pharmacy2/Neomycin.html\">Neomycin</a>\r\n<a href=\"http://www.explora.com/files/via/Free-viagra-order-online.html\">Free viagra order online</a>\r\n<a href=\"http://www.explora.com/files/via/Viagra-sales-online.html\">Viagra sales online</a>\r\n<a href=\"http://www.explora.com/files/pharmacy2/Atacand.html\">Atacand</a>\r\n<a href=\"http://www.explora.com/files/pharmacy/Hydrocodone.html\">Hydrocodone</a>\r\n<a href=\"http://www.explora.com/files/pharmacy2/Cimetidine.html\">Cimetidine</a>\r\n<a href=\"http://www.explora.com/files/hyd/Buy-hydrocodone.html\">Buy hydrocodone</a>\r\n<a href=\"http://www.explora.com/files/pharmacy/Ibuprofen.html\">Ibuprofen</a>\r\n<a href=\"http://www.explora.com/files/phe/Phentermine-free-shipping.html\">Phentermine free shipping</a>\r\n<a href=\"http://www.explora.com/files/via/Discount-viagra-europe.html\">Discount viagra europe</a>\r\n<a href=\"http://www.explora.com/files/xan/Smoking-xanax.html\">Smoking xanax</a>\r\n<a href=\"http://www.explora.com/files/xan/Drug-interaction-xanax-and-holy-basil.html\">Drug interaction xanax and holy basil</a>\r\n<a href=\"http://www.explora.com/files/via/Drug-interactions-with-cocaine-and-viagra.html\">Drug interactions with cocaine and viagra</a>\r\n<a href=\"http://www.explora.com/files/phe/Phentermine-hcl.html\">Phentermine hcl</a>\r\n<a href=\"http://www.explora.com/files/tra/Cheep-tramadol-paris-france.html\">Cheep tramadol paris france</a>\r\n<a href=\"http://www.explora.com/files/pharmacy2/Butoconazole.html\">Butoconazole</a>\r\n<a href=\"http://www.explora.com/files/pharmacy/Pantoprazole.html\">Pantoprazole</a>\r\n<a href=\"http://www.explora.com/files/phe/Compare-phentermine-prices.html\">Compare phentermine prices</a>\r\n<a href=\"http://www.explora.com/files/cia/Buy-cialis-generic.html\">Buy cialis generic</a>\r\n<a href=\"http://www.explora.com/files/tra/Tramadol-hcl-acetaminotran-par.html\">Tramadol hcl acetaminotran par</a>\r\n<a href=\"http://www.explora.com/files/phe/Cheap-phentermine.html\">Cheap phentermine</a>\r\n<a href=\"http://www.explora.com/files/via/Herbal-alternatives-to-viagra.html\">Herbal alternatives to viagra</a>\r\n<a href=\"http://www.explora.com/files/via/Viagra-for-sale-online.html\">Viagra for sale online</a>\r\n<a href=\"http://www.explora.com/files/phe/Phentermine-ups-shipped.html\">Phentermine ups shipped</a>\r\n<a href=\"http://www.explora.com/files/pharmacy2/Mefloquine.html\">Mefloquine</a>\r\n<a href=\"http://www.explora.com/files/xan/How-to-stop-taking-xanax.html\">How to stop taking xanax</a>\r\n<a href=\"http://www.explora.com/files/pharmacy2/Dalteparin.html\">Dalteparin</a>\r\n<a href=\"http://www.explora.com/files/via/Bosch-power-tools-zio-lowest-viagra.html\">Bosch power tools zio lowest viagra</a>\r\n<a href=\"http://www.explora.com/files/pharmacy/Cytomel.html\">Cytomel</a>\r\n<a href=\"http://www.explora.com/files/phe/Alternatives-to-phentermine.html\">Alternatives to phentermine</a>\r\n<a href=\"http://www.explora.com/files/phe/How-fast-can-you-loss-weight-with-phentermine.html\">How fast can you loss weight with phentermine</a>\r\n<a href=\"http://www.explora.com/files/xan/Purchase-xanax.html\">Purchase xanax</a>\r\n<a href=\"http://www.explora.com/files/pharmacy/Paxil.html\">Paxil</a>\r\n<a href=\"http://www.explora.com/files/pharmacy2/Aminopterin.html\">Aminopterin</a>\r\n<a href=\"http://www.explora.com/files/pharmacy2/Isocarboxazid.html\">Isocarboxazid</a>\r\n<a href=\"http://www.explora.com/files/phe/Cheapest-phentermine-online.html\">Cheapest phentermine online</a>\r\n<a href=\"http://www.explora.com/files/pharmacy2/Marijuana.html\">Marijuana</a>\r\n<a href=\"http://www.explora.com/files/pharmacy2/Amlodipine.html\">Amlodipine</a>\r\n<a href=\"http://www.explora.com/files/xan/Buy-cheap-domain-online-outdoors-com-xanax.html\">Buy cheap domain online outdoors com xanax</a>\r\n<a href=\"http://www.explora.com/files/phe/Order-phentermine-c-o-d.html\">Order phentermine c o d</a>\r\n<a href=\"http://www.explora.com/files/phe/Lowest-phentermine-prices.html\">Lowest phentermine prices</a>\r\n<a href=\"http://www.explora.com/files/xan/Time-released-xanax.html\">Time released xanax</a>\r\n<a href=\"http://www.explora.com/files/via/Viagra-drug.html\">Viagra drug</a>\r\n<a href=\"http://www.explora.com/files/phe/Phentermine-pictures.html\">Phentermine pictures</a>\r\n<a href=\"http://www.explora.com/files/hyd/Hydrocodone-and-ibuprofen.html\">Hydrocodone and ibuprofen</a>\r\n<a href=\"http://www.explora.com/files/via/Side-effect-of-viagra.html\">Side effect of viagra</a>\r\n<a href=\"http://www.explora.com/files/pharmacy2/Zyprexa.html\">Zyprexa</a>\r\n<a href=\"http://www.explora.com/files/pharmacy2/Nadolol.html\">Nadolol</a>\r\n<a href=\"http://www.explora.com/files/via/Free-viagra.html\">Free viagra</a>\r\n<a href=\"http://www.explora.com/files/cia/Cialis-order.html\">Cialis order</a>\r\n<a href=\"http://www.explora.com/files/phe/Phentermine-30mg.html\">Phentermine 30mg</a>\r\n<a href=\"http://www.explora.com/files/pharmacy2/Sparfloxacin.html\">Sparfloxacin</a>\r\n<a href=\"http://www.explora.com/files/pharmacy/Levofloxacin.html\">Levofloxacin</a>\r\n<a href=\"http://www.explora.com/files/pharmacy2/Pheniramine.html\">Pheniramine</a>\r\n<a href=\"http://www.explora.com/files/tra/Addiction-tramadol.html\">Addiction tramadol</a>\r\n<a href=\"http://www.explora.com/files/via/Viagra-information.html\">Viagra information</a>\r\n<a href=\"http://www.explora.com/files/pharmacy2/Fiorinal.html\">Fiorinal</a>\r\n<a href=\"http://www.explora.com/files/pharmacy2/Isopropamide.html\">Isopropamide</a>\r\n<a href=\"http://www.explora.com/files/pharmacy2/Toprol.html\">Toprol</a>\r\n<a href=\"http://www.explora.com/files/pharmacy/Glyburide.html\">Glyburide</a>\r\n<a href=\"http://www.explora.com/files/pharmacy2/Acetyldigitoxin.html\">Acetyldigitoxin</a>\r\n<a href=\"http://www.explora.com/files/xan/Overnight-xanax.html\">Overnight xanax</a>\r\n<a href=\"http://www.explora.com/files/pharmacy2/Nicorette.html\">Nicorette</a>\r\n<a href=\"http://www.explora.com/files/pharmacy/Ionamin.html\">Ionamin</a>\r\n<a href=\"http://www.explora.com/files/cia/Cialis-levitra-viagra-compare.html\">Cialis levitra viagra compare</a>\r\n<a href=\"http://www.explora.com/files/buy/Buy-Zovirax.html\">Buy Zovirax</a>\r\n<a href=\"http://www.explora.com/files/via/Cheapest-place-buy-viagra-online.html\">Cheapest place buy viagra online</a>\r\n<a href=\"http://www.explora.com/files/pharmacy2/Imdur.html\">Imdur</a>\r\n<a href=\"http://www.explora.com/files/via/Discount-online-viagra.html\">Discount online viagra</a>\r\n<a href=\"http://www.explora.com/files/phe/Drug-laws-ohio-diet-phentermine.html\">Drug laws ohio diet phentermine</a>\r\n<a href=\"http://www.explora.com/files/phe/Xenical-hgh-phentermine-quit-smoking.html\">Xenical hgh phentermine quit smoking</a>\r\n<a href=\"http://www.explora.com/files/xan/Ways-to-inject-xanax-pills.html\">Ways to inject xanax pills</a>\r\n<a href=\"http://www.explora.com/files/pharmacy2/Chlorpropamide.html\">Chlorpropamide</a>\r\n<a href=\"http://www.explora.com/files/pharmacy2/Elocon.html\">Elocon</a>\r\n<a href=\"http://www.explora.com/files/via/Amsterdam-holland-viagra.html\">Amsterdam holland viagra</a>\r\n<a href=\"http://www.explora.com/files/vic/Order-vicodin-online.html\">Order vicodin online</a>\r\n<a href=\"http://www.explora.com/files/pharmacy2/Diamox.html\">Diamox</a>\r\n<a href=\"http://www.explora.com/files/via/Prescription-viagra-written.html\">Prescription viagra written</a>\r\n<a href=\"http://www.explora.com/files/pharmacy2/Androgel.html\">Androgel</a>\r\n<a href=\"http://www.explora.com/files/phe/Online-phentermine-prescriptions.html\">Online phentermine prescriptions</a>\r\n<a href=\"http://www.explora.com/files/pharmacy/Catapres.html\">Catapres</a>\r\n<a href=\"http://www.explora.com/files/pharmacy/Nasonex.html\">Nasonex</a>\r\n<a href=\"http://www.explora.com/files/phe/Diet-inexpensive-phentermine-pill.html\">Diet inexpensive phentermine pill</a>\r\n<a href=\"http://www.explora.com/files/phe/Phentermine-risks.html\">Phentermine risks</a>\r\n<a href=\"http://www.explora.com/files/pharmacy2/Trichlormethiazide.html\">Trichlormethiazide</a>\r\n<a href=\"http://www.explora.com/files/via/Buy-lvivhostcom-online-viagra-viagra.html\">Buy lvivhostcom online viagra viagra</a>\r\n<a href=\"http://www.explora.com/files/phe/Pharmacy-online-phentermine.html\">Pharmacy online phentermine</a>\r\n<a href=\"http://www.explora.com/files/xan/Alprazolam-xanax-over-night.html\">Alprazolam xanax over night</a>\r\n<a href=\"http://www.explora.com/files/pharmacy2/Ethinamate.html\">Ethinamate</a>\r\n<a href=\"http://www.explora.com/files/pharmacy2/Timolol.html\">Timolol</a>\r\n<a href=\"http://www.explora.com/files/via/Viagra-mexico.html\">Viagra mexico</a>\r\n<a href=\"http://www.explora.com/files/phe/Phentermine-online-without-prescription.html\">Phentermine online without prescription</a>\r\n<a href=\"http://www.explora.com/files/xan/Xanax-no-prescription.html\">Xanax no prescription</a>\r\n<a href=\"http://www.explora.com/files/via/Cialis-levivia-viagra-vs-vs.html\">Cialis levivia viagra vs vs</a>\r\n<a href=\"http://www.explora.com/files/phe/What-is-phentermine-civ.html\">What is phentermine civ</a>\r\n<a href=\"http://www.explora.com/files/pharmacy2/Simethicone.html\">Simethicone</a>\r\n<a href=\"http://www.explora.com/files/via/Viagra-sales-uk.html\">Viagra sales uk</a>\r\n<a href=\"http://www.explora.com/files/pharmacy2/Naratriptan.html\">Naratriptan</a>\r\n<a href=\"http://www.explora.com/files/pharmacy2/Amerge.html\">Amerge</a>\r\n<a href=\"http://www.explora.com/files/pharmacy2/Clomocycline.html\">Clomocycline</a>\r\n<a href=\"http://www.explora.com/files/pharmacy/Glucotrol.html\">Glucotrol</a>\r\n<a href=\"http://www.explora.com/files/phe/Phentermine-blogging.html\">Phentermine blogging</a>\r\n<a href=\"http://www.explora.com/files/vic/Order-vicodin.html\">Order vicodin</a>\r\n<a href=\"http://www.explora.com/files/via/Viagra-discussion.html\">Viagra discussion</a>\r\n<a href=\"http://www.explora.com/files/xan/Cheapest-xanax-online.html\">Cheapest xanax online</a>\r\n<a href=\"http://www.explora.com/files/pharmacy/Anafranil.html\">Anafranil</a>\r\n<a href=\"http://www.explora.com/files/pharmacy2/Phentolamine.html\">Phentolamine</a>\r\n<a href=\"http://www.explora.com/files/phe/Buy-phentermine-on-line.html\">Buy phentermine on line</a>\r\n<a href=\"http://www.explora.com/files/via/Genaric-viagra.html\">Genaric viagra</a>\r\n<a href=\"http://www.explora.com/files/cia/Approval-cialis-fda.html\">Approval cialis fda</a>\r\n<a href=\"http://www.explora.com/files/phe/Phentermine-37.5-mg-sale.html\">Phentermine 37.5 mg sale</a>\r\n<a href=\"http://www.explora.com/files/pharmacy2/Guanethidine.html\">Guanethidine</a>\r\n<a href=\"http://www.explora.com/files/pharmacy2/Cordarone.html\">Cordarone</a>\r\n<a href=\"http://www.explora.com/files/tra/Buy-tramadol.html\">Buy tramadol</a>\r\n<a href=\"http://www.explora.com/files/pharmacy2/Ouabain.html\">Ouabain</a>\r\n<a href=\"http://www.explora.com/files/phe/Cheap-phentermine-online.html\">Cheap phentermine online</a>\r\n<a href=\"http://www.explora.com/files/via/Viagra-by-mail.html\">Viagra by mail</a>\r\n<a href=\"http://www.explora.com/files/xan/Xanax-master-card.html\">Xanax master card</a>\r\n<a href=\"http://www.explora.com/files/via/Best-generic-viagra.html\">Best generic viagra</a>\r\n<a href=\"http://www.explora.com/files/phe/Information-loss-phentermine-weight.html\">Information loss phentermine weight</a>\r\n<a href=\"http://www.explora.com/files/via/Free-sample-herbal-viagra.html\">Free sample herbal viagra</a>\r\n<a href=\"http://www.explora.com/files/via/Viagra-mail-order.html\">Viagra mail order</a>\r\n<a href=\"http://www.explora.com/files/pharmacy2/Quinine.html\">Quinine</a>\r\n<a href=\"http://www.explora.com/files/pharmacy2/Carbinoxamine.html\">Carbinoxamine</a>\r\n<a href=\"http://www.explora.com/files/cia/Cialis-no-prescription.html\">Cialis no prescription</a>\r\n<a href=\"http://www.explora.com/files/pharmacy/Lopressor.html\">Lopressor</a>\r\n<a href=\"http://www.explora.com/files/pharmacy2/Cephalothin.html\">Cephalothin</a>\r\n<a href=\"http://www.explora.com/files/via/Buy-cheap-generic-viagra.html\">Buy cheap generic viagra</a>\r\n<a href=\"http://www.explora.com/files/tra/Tramadol-hydrochloride-overdose.html\">Tramadol hydrochloride overdose</a>\r\n<a href=\"http://www.explora.com/files/pharmacy/Mycostatin.html\">Mycostatin</a>\r\n<a href=\"http://www.explora.com/files/pharmacy2/Phenelzine.html\">Phenelzine</a>\r\n<a href=\"http://www.explora.com/files/pharmacy2/Crestor.html\">Crestor</a>\r\n<a href=\"http://www.explora.com/files/xan/Canadian-online-pharmacy-xanax.html\">Canadian online pharmacy xanax</a>\r\n<a href=\"http://www.explora.com/files/via/Viagra-canada-prescription.html\">Viagra canada prescription</a>\r\n<a href=\"http://www.explora.com/files/pharmacy2/Tridihexethyl.html\">Tridihexethyl</a>\r\n<a href=\"http://www.explora.com/files/phe/Phentermine-online-purchase.html\">Phentermine online purchase</a>\r\n<a href=\"http://www.explora.com/files/pharmacy2/Cerivastatin.html\">Cerivastatin</a>\r\n<a href=\"http://www.explora.com/files/via/Link-buy-online-viagra-info-domain.html\">Link buy online viagra info domain</a>\r\n<a href=\"http://www.explora.com/files/buy/Buy-Ativan.html\">Buy Ativan</a>\r\n<a href=\"http://www.explora.com/files/via/Mexican-pharmacy-viagra.html\">Mexican pharmacy viagra</a>\r\n<a href=\"http://www.explora.com/files/pharmacy2/Metaraminol.html\">Metaraminol</a>\r\n<a href=\"http://www.explora.com/files/pharmacy/Indocin.html\">Indocin</a>\r\n<a href=\"http://www.explora.com/files/via/Generic-viagra-soft-tab.html\">Generic viagra soft tab</a>\r\n<a href=\"http://www.explora.com/files/pharmacy/Keflex.html\">Keflex</a>\r\n<a href=\"http://www.explora.com/files/phe/Phentermine-prescription.html\">Phentermine prescription</a>\r\n<a href=\"http://www.explora.com/files/via/Viagra-alternatives.html\">Viagra alternatives</a>\r\n<a href=\"http://www.explora.com/files/hyd/Hydrocodone-prescription.html\">Hydrocodone prescription</a>\r\n<a href=\"http://www.explora.com/files/pharmacy2/Indinavir.html\">Indinavir</a>\r\n</u>','Ternipe la Cluj, la Romunica',0,'','publish','closed','closed','','ternipe-la-cluj-la-romunica','','','2008-06-12 11:20:07','2008-06-12 09:20:07','',0,'http://www.groparu.ro/?p=1125',0,'post','',2),(1126,1,'2008-06-11 15:52:31','2008-06-11 13:52:31','Da, chiar. Ce urmeaza dupa asemenea tuseuri rectale? Sa candidez la Primaria Bucuresti, ca interdependent? Neee...!\r\n\r\nPreluare din <a href=\"http://www.7plus.ro/?arhiva=11/06/2008&amp;id=6786\" target=\"_blank\">7 plus</a> si <a href=\"http://www.visurat.ro\" target=\"_blank\">www.visurat.ro</a>, scris de acelasi inegalabil Julius Constantinescu, baiatul lui Mihai Constantinescu, ala care cÃ¢nta \"Iubiti si cainii vaganbonzi\":\r\n\r\nDin ciclul â€œMama, tu m-ai facut, io te-omor!â€, prietenul meu imaginar Groparu a scris un textulet foarte dragut pe blogul lui, <a href=\"http://groparu.ro/\" target=\"_blank\">www.groparu.ro</a> (site pe care vi-l recomand cu caldura, mai ales daca va era un dor nebun de glumele bune din armata sau daca sinteti un taximetrist cu preocupari intelectuale). In fine, destul cu reclama, va las sa cititi textul, in caz ca si voua va place sa glumiti cu mamele voastre si aveati nevoie de o idee tare, sa le bucurati batrinetile.<span id=\"more-2556\"></span>\r\n\r\nâ€œMamaaaa, ma auzi? Servus, mamaâ€¦ nici nu ai idee unde ma aflu!!! Tii minte ca mi-am tot dorit sa zbor cu elicopterul? No! Ghici unde sint acum? Da!!! Is in elicoperâ€¦ tu stii ce fain e??? E de-men-ti-al!!! Vorbeste mai tare, ca nu te audâ€¦ Da, ma lasa sa vorbesc la telefon, ca nu e ca avionâ€¦ E super! Sa vezi ce fain o decolat, ca nici nu am simtitâ€¦ asa mici sint casele de aici! Cred ca zburam la vreo 2000 de metri, e bestialâ€¦ Ce zici? Te aud greu, ca face motorul atita zgomotâ€¦ A, ce caut in elicopter? Pai e un elicopter SMURD, ma duce la spitalâ€¦â€.\r\n\r\n<strong>PS: </strong>Tanti mama luâ€™ Groparu, este ca v-ati distrat, nu? Vedeti ca saptamina viitoare pregateste una si mai tare, o sa va tineti cu miinile de burta: â€œNo, mama, vorbeste mai repede, ca acuâ€™ arunca astia cu pamint deasupra si pierd semnalul!â€.','Dupa FHM, Groparu a fost publicat si de 7 plus. Ce urmeaza?',0,'','publish','open','open','','dupa-fhm-groparu-a-fost-publicat-si-de-7-plus-ce-urmeaza','','','2008-06-11 15:52:31','2008-06-11 13:52:31','',0,'http://www.groparu.ro/?p=1126',0,'post','',10),(1127,1,'2008-06-13 08:50:30','2008-06-13 06:50:30','Spamul:\r\n<strong><em>Silviu Ionescu &lt;silviu-ionescu@*****.info&gt;</em></strong> wrote:\r\n<blockquote class=\"replbq\" style=\"border-left: 2px solid #1010ff; margin-left: 5px; padding-left: 5px\">\r\n<p style=\"margin-bottom: 0pt; line-height: normal\" class=\"MsoNormal\"><span style=\"font-size: 9pt; font-family: \'Times New Roman\',serif\">Buna  ziua,</span></p>\r\n<p style=\"margin-bottom: 0pt; line-height: normal\" class=\"MsoNormal\"><span style=\"font-size: 9pt; font-family: \'Times New Roman\',serif\">Vreti o rata de  conversie mai buna? Doriti mai multe comenzi ?</span></p>\r\n<p style=\"margin-bottom: 0pt; line-height: normal\" class=\"MsoNormal\"><span style=\"font-size: 9pt; font-family: \'Times New Roman\',serif\">Sau poate vreti sa  oferiti un aer de prospetime site-ului dumneavostra si posibilitati complexe  vizitatorilor dumneavoastra?</span></p>\r\n<p style=\"margin-bottom: 0pt; line-height: normal\" class=\"MsoNormal\"><span style=\"font-size: 9pt; font-family: \'Times New Roman\',serif\">Firma **** presteaza servicii complete de  Web Developement.</span></p>\r\n<p style=\"margin-bottom: 0pt; line-height: normal\" class=\"MsoNormal\"><span style=\"font-size: 9pt; font-family: \'Times New Roman\',serif\">****</span><span style=\"font-size: 9pt; font-family: \'Times New Roman\',serif\"> s-a  gandit la nevoile dumneavoastra si a creat o oferta simpla si tentanta:   pachetul complet </span><span style=\"font-size: 9pt; font-family: \'Times New Roman\',serif\">****</span><span style=\"font-size: 9pt; font-family: \'Times New Roman\',serif\">!</span></p>\r\n\r\n<p style=\"margin-bottom: 0pt; line-height: normal\" class=\"MsoNormal\"><span style=\"font-size: 9pt; font-family: \'Times New Roman\',serif\"> Pachetul include Design/Redesign, implementare de soft complex de magazin online cat si optimizare interna pentru o mai mare expunere in motoarele de cautare.\r\n</span>\r\n<p style=\"margin-bottom: 0pt; line-height: normal\" class=\"MsoNormal\"><span style=\"font-size: 9pt; font-family: \'Times New Roman\',serif\">****</span><span style=\"font-size: 9pt; font-family: \'Times New Roman\',serif\"> lanseaza un pachet complet de servicii Web Design + Programare + Optimizare  destinat Magazinelor Online/ Site-urilor care vor sa isi inbunatateasca calitatea Soft-ului si care vor sa isi dubleze sau chiar sa isi tripleze numarul de vanzari.</span></p>\r\n<p style=\"margin-bottom: 0pt; line-height: normal\" class=\"MsoNormal\"><span style=\"font-size: 9pt; font-family: \'Times New Roman\',serif\">Noul Soft va ajuta  sa mariti rata de conversie a vizitatorilui spre a devenii cumparator cu cel  putin 300%.</span></p>\r\n<p style=\"margin-bottom: 0pt; line-height: normal\" class=\"MsoNormal\"><span style=\"font-size: 9pt; font-family: \'Times New Roman\',serif\"> </span></p>\r\n<p style=\"margin-bottom: 0pt; line-height: normal\" class=\"MsoNormal\"><span style=\"font-size: 9pt; font-family: \'Times New Roman\',serif\">In ceea ce priveste  beneficiile folosirii lui puteti afla mai multe aici: ****<a href=\"http://www.vinzibine.info/beneficii.html\"></a>  </span></p>\r\n<p style=\"margin-bottom: 0pt; line-height: normal\" class=\"MsoNormal\"><span style=\"font-size: 9pt; font-family: \'Times New Roman\',serif\"> </span></p>\r\n<p style=\"margin-bottom: 0pt; line-height: normal\" class=\"MsoNormal\"><span style=\"font-size: 9pt; font-family: \'Times New Roman\',serif\">Puteti vedea toate  facilitatile pe care le contine softul pe care il vom implementa aici: ****  </span></p>\r\n<p style=\"margin-bottom: 0pt; line-height: normal\" class=\"MsoNormal\"><span style=\"font-size: 9pt; font-family: \'Times New Roman\',serif\">Cu stima,</span></p>\r\n<p style=\"margin-bottom: 0pt; line-height: normal\" class=\"MsoNormal\"><span style=\"font-size: 9pt; font-family: \'Times New Roman\',serif\">Silviu Ionescu</span></p>\r\n<p style=\"margin-bottom: 0pt; line-height: normal\" class=\"MsoNormal\"><span style=\"font-size: 9pt; font-family: \'Times New Roman\',serif\">Account manager firma *****</span></p>\r\n</blockquote>\r\nRaspunsul meu:\r\n\r\nBuna ziua,\r\n\r\nVreti sa va dau in judecata pentru spam? Si ca pedeapsa sa il rog pe judecator sa va puna sa imi zugraviti garsoniera si sa imi puneti termopane? Eventual sa imi si dezinfectati baia? Sau chiar sa imi prindeti una din mÃ¢Å£ele din faÅ£a blocului, una care ma ignora de multa vreme, si eu vreau sa pun mana pe ea de cand m-am mutat, ca sa ma joc cu ea? Asta vreti?\r\n\r\nCu stima,\r\n\r\nGroparu','Unui spammer',0,'','publish','open','open','','unui-spammer','','','2008-06-13 08:50:30','2008-06-13 06:50:30','',0,'http://www.groparu.ro/?p=1127',0,'post','',25),(1128,1,'2008-06-12 11:00:37','2008-06-12 09:00:37','','tricou-01.jpg',0,'','inherit','open','open','','tricou-01jpg','','','2008-06-12 11:00:37','2008-06-12 09:00:37','',1132,'http://www.groparu.ro/wp-content/uploads/2008/06/tricou-01.jpg',0,'attachment','image/jpeg',0),(1129,1,'2008-06-12 11:01:02','2008-06-12 09:01:02','','tricou-02.jpg',0,'','inherit','open','open','','tricou-02jpg','','','2008-06-12 11:01:02','2008-06-12 09:01:02','',1132,'http://www.groparu.ro/wp-content/uploads/2008/06/tricou-02.jpg',0,'attachment','image/jpeg',0),(1130,1,'2008-06-12 11:01:12','2008-06-12 09:01:12','','tricou-03.jpg',0,'','inherit','open','open','','tricou-03jpg','','','2008-06-12 11:01:12','2008-06-12 09:01:12','',1132,'http://www.groparu.ro/wp-content/uploads/2008/06/tricou-03.jpg',0,'attachment','image/jpeg',0),(1131,1,'2008-06-12 11:01:23','2008-06-12 09:01:23','','tricou-04.jpg',0,'','inherit','open','open','','tricou-04jpg','','','2008-06-12 11:01:23','2008-06-12 09:01:23','',1132,'http://www.groparu.ro/wp-content/uploads/2008/06/tricou-04.jpg',0,'attachment','image/jpeg',0),(1132,1,'2008-06-12 11:04:44','2008-06-12 09:04:44','Uite ce i-o mai copt crierasu\' la unu din dizainerii mei preferati, si stau si ma intreb: di ce mi le-a aratat tocmai MIE???\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2008/06/tricou-01.jpg\" title=\"tricou-01.jpg\"><img src=\"http://www.groparu.ro/wp-content/uploads/2008/06/tricou-01.thumbnail.jpg\" alt=\"tricou-01.jpg\" /></a> <a href=\"http://www.groparu.ro/wp-content/uploads/2008/06/tricou-02.jpg\" title=\"tricou-02.jpg\"><img src=\"http://www.groparu.ro/wp-content/uploads/2008/06/tricou-02.thumbnail.jpg\" alt=\"tricou-02.jpg\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2008/06/tricou-03.jpg\" title=\"tricou-03.jpg\"><img src=\"http://www.groparu.ro/wp-content/uploads/2008/06/tricou-03.thumbnail.jpg\" alt=\"tricou-03.jpg\" /></a><a href=\"http://www.groparu.ro/wp-content/uploads/2008/06/tricou-04.jpg\" title=\"tricou-04.jpg\"><img src=\"http://www.groparu.ro/wp-content/uploads/2008/06/tricou-04.thumbnail.jpg\" alt=\"tricou-04.jpg\" /></a>\r\n\r\nMumos, nu?','Tricouri pentru betivi',0,'','publish','open','open','','tricouri-pentru-betivi','','','2008-06-12 11:04:44','2008-06-12 09:04:44','',0,'http://www.groparu.ro/?p=1132',0,'post','',25),(1133,1,'2008-06-12 22:26:44','2008-06-12 20:26:44','ÃŽi acuma ceva delegatie la coperativa cu unu\', ciudat rau. Nij nu-i romÃ¢n mÄƒcar. Ii zic la o colega:\r\n\r\n- Nu ti se pare ca Äƒsta parcÄƒ e de pe planeta Zorg?\r\n\r\nEa zice:\r\n\r\n- Nu.','Ce i-am zis unei colege',0,'','publish','open','open','','ce-i-am-zis-unei-colege','','','2008-06-12 23:42:49','2008-06-12 21:42:49','',0,'http://www.groparu.ro/?p=1133',0,'post','',10),(1134,1,'0000-00-00 00:00:00','0000-00-00 00:00:00','Deci postarea asta o scriu in cel mai silentios mod, ca sa nu m-auza Crivatu\', carele stiu io sigur ca o angajat o gasca de racheti ucraineni sa se razbuneascÄƒ, pen\' ca si-o rupt masina pe tat felu de hartoape pe care din imensa mea mÄƒrinimie am zis cÄƒ Ã®l duc sÄƒ le vazÄƒ.\n\nPadis, of cors.\n\nDeci la Padis, ca sa ajungi, trebe sa urci ori cu sania trasa de caini, ori cu elicopteru, finca daca urci cu masini, riscurile is ca alea de pe pachetele de Å£igÄƒri: destul de riscante.\n\n(in paranteza fie spus, un gand frumos, dar si falic tuturor politicienilor care s-au perindat pe la prefecturile Bihor, Cluj si Alba fara sa faca o strategie coerenta de dezvoltare pentru una din cele mai faine zone din emisfera, Muntii Apuseni)','La Padis',0,'','draft','open','open','','','','','2008-06-16 09:24:31','2008-06-16 07:24:31','',0,'http://www.groparu.ro/?p=1134',0,'post','',0),(1135,1,'2008-06-16 22:52:59','2008-06-16 20:52:59','Deci io nu-s fan niciuna: Cora e prea Cora, si Kaufland nu are peste proaspat. Io am orgasme cand vad pestii aia proaspeti pusi la congelat, cum se uita la tine cu privire de fomee care-ti zice \"azi ma duare capu prea tare!\"\r\n\r\n<strong>Cora</strong>\r\nCumpar din Cora o biblioteca, ca m-am saturat sa imi tin dictionarele mele pe care am dat bani grei, gre-grei, acolo unde-mi tin chilotii curati langa ciorapii murdari, adicÄƒ Ã®n dulap; plus ca daca iti afisezi cartile prin camera, dÄƒ bine la vizitatori. AÅŸa cÄƒ mÄƒ duc la Cora, ÅŸi Ã®mi iau o bibliotecÄƒ din aia de o montezi acasÄƒ. FincÄƒ modelul arÄƒta julit ÅŸi desciocolat ca dupÄƒ al doilea rÄƒzboi mondial, imediat dupÄƒ ce FranÅ£a s-o predat la FriÅ£i, Ã®l Ã®ntreb pe bÄƒietul care se ocupa de mobilÄƒ (ÅŸi el, gÄƒsit dupÄƒ ce l-am chemat cu microfonu):\r\n\r\n- BÄƒ, puÅŸtiu, zic, normal cÄƒ am plecat de acasÄƒ fÄƒrÄƒ sÄƒ fac mÄƒsurÄƒtorile de rigoare, aÅŸa cÄƒ nuÅŸ care mobilÄƒ se potriveÅŸte mai bine la mine pe peretele meu de care am legate cÄƒtuÅŸele, biblioteca asta latÄƒ sau asta Ã®ngustÄƒ; io o iau pe asta Ã®ngustÄƒ, da\' dacÄƒ mÄƒ rÄƒzgÃ¢ndesc, o pot returna ÅŸi sÄƒ plÄƒtesc diferenÅ£a ÅŸi sÄƒ o iau pe asta latÄƒ-latÄƒ?\r\n- Åži io ce fac cu asta Ã®ngustÄƒ, dacÄƒ mi-o aduci Ã®napoi? Io cum o mai pun Ã®n vÃ¢nzare?\r\n- PÄƒi promit cÄƒ nu scriu pe ea \"Groparu+minore=love\" cu ÅŸurubelniÅ£a, mÄƒ.\r\n- Nu, nu se poate. Am sorry, astea e regulile.\r\n\r\n<strong>Kaufland</strong>\r\nFincÄƒ m-am hotÄƒrÃ¢t sÄƒ schimb lenjeria de pat (era cazu, din luna ianuarie!!! nu vÄƒ zic ÅŸi anu\'), am zis sÄƒ Ã®mi cumpÄƒr o lenjerie nouÄƒ, cu elefÄƒnÅ£ei, din Kaufland. O ieu, da\' io-s uneori orbit de zeii geloÅŸi pe mine; ÅŸi am luat douÄƒ cearÅŸafe ÅŸi douÄƒ feÅ£e de pernÄƒ, Ã®n loc sÄƒ iau un cearÅŸaf ÅŸi un plic, cÄƒ am zis cÄƒ nu mai citesc ce scrie pe ambalaj, cÄƒ numa fraierii citesc etichetele, in afarÄƒ de etichetele elea de vin, la care io citesc ÅŸi conÅ£inutul cu foarte mare atenÅ£ie. AcasÄƒ mi-am dat seama de prÄƒpastie; aÅŸa cÄƒ dupÄƒ 6 zile m-am Ã®ntors la Kaufland, ÅŸi le-am zis:\r\n\r\n- Sieg heil, bÄƒ. Fii antenÄƒ: m-aÅ£i Å£Äƒpit, cÄƒ io am crezut cÄƒ iau un set de pat complet, ÅŸi Ã®n schimb mi-aÅ£i dat doo cearceafe, ÅŸi io oricum dorm fÄƒrÄƒ cearceaf, nu vÄƒ zic din ce lunÄƒ ianuarie a cÄƒrui an. Åži vreau sÄƒ schimb chestia asta pe niÅŸte telemea de caprÄƒ ÅŸi un codru de pkitÄƒ, cÄƒ mi-i foame.\r\n- Sigur, zice ficioru\' de la Informatii, zice uite aici banii inapoi pe produs, si de astia fa ce vrei cu ei, nu ma mai bate pe mine la cap.\r\n\r\nClaro cÄƒ m-o inervat cÄƒ s-o putut schimba produsul fÄƒrÄƒ probleme, ba mai mult, ÅŸi pe bani cash, ÅŸi fÄƒrÄƒ tam-tam; pÄƒi unde se credea puÅŸtiu Äƒla, mÄƒi fraÅ£ilor, Ã®n Germania???','Ketchup, sau mustar? Cora, sau Kaufland?',0,'','publish','open','open','','ketchup-sau-mustar-cora-sau-kaufland','','','2008-06-16 22:52:59','2008-06-16 20:52:59','',0,'http://www.groparu.ro/?p=1135',0,'post','',14),(1136,1,'2008-06-17 15:18:06','2008-06-17 13:18:06','Shafu\' meu ii nervos ca s-o amanat scoaterea pe piata a MozÃ¢lei, cÄƒ iel e mare fan. ÃŽncerc sÄƒ-l potolesc:\r\n\r\n- Ba, zic, lasa astea, zi mai bine daca ai fost UTC-ist.\r\n- Am fost, zice el, si UTC-ist, si PCR-ist.\r\n- Tare, zic io, respect! Si in \'89 ti-ai ars carnetu?\r\n- Da, zice el. Proz am fost! Mai bine il pastram si ma faceam pesedist.','UTC, PCR, PSD',0,'','publish','open','open','','utc-pcr-psd','','','2008-06-17 15:18:06','2008-06-17 13:18:06','',0,'http://www.groparu.ro/?p=1136',0,'post','',8),(1137,1,'2008-06-18 15:36:13','2008-06-18 13:36:13','Nu se poate zice decat atata: dap.\r\n\r\nIn <a href=\"http://www.laliga.ro/\" target=\"_blank\">Liga</a>, unde am vizionat, e obositor finca e plin de televizoare pe pereti, si nu esti tot timpu sigur daca ce vezi la unu dintre ele e ceea ce arata si TV-ul din spatele tau.\r\n\r\nIn bar erau si o gasca de olandeji. Mah, ce-i urasc io p-astia! Pai noi niciodata nu vom ajunge la asemenea nivel de civilizatie: toti imbracati in portocaliu (voi v-ati imbraca in galben daca ati fi in Turcia la meci cu Romania, in bar?), si cand o cantat imnu\' Romaniei s-or ridicat in picioare, sa salute. Frumos, nu? Stati sa va mai zic, ca n-am terminat: s-or entuziasmat la fazele de gol ale noastre, si nu or sarit in sus sa ne deie peste nas cand or inscris ai lor. Plm!\r\n\r\nCea mai tare faza urmeaza acuma: dupa prima repriza am fo\' la baie, pentru a face ****. Si la baie, un prunculain de vreo 6 ani, mega-dezamagit, isi spala cu apa la chiuveta steagul Romaniei desenat de pe obraji! Si cand m-am spalat, la randul meu (sunt printre cei 1% care se spala dupa ****), m-o intrebat \"mai am vreo culoare de la steagul Romaniei pe obraji?\" (el nu ajungea sa se vada in oglinda, ca era atata de inalt ca putea trece pe sub scaun in picioare). Mai avea ceva rosu, cred ca de la frecat, finca se freca temeinic; si am vrut sa ii zic ca la folbal e ca intr-o casnicie, ca tre sa stai alaturi de team-ul favorit si la bine, da\' si cand vine acasa noaptea beat ca floricica si te ia la cafteala pe tine si pe copiii vostri, futu-ti gura matii de proasta, cu cine m-am insurat io. Da\' am zis ca las adulteÅ£ea sÄƒ Ã®l Ã®nveÅ£e asemenea mistere.\r\n\r\nOricum, sunteti de acord cu mine ca a fost un meci de toata **** (nu voi fi mai explicit, finca mi-am propus, in plm, sa nu mai injur pe blog)','Caci despre meciul Romania-Olanda,',0,'','publish','open','open','','caci-despre-meciul-romania-olanda','','','2008-06-18 15:36:13','2008-06-18 13:36:13','',0,'http://www.groparu.ro/?p=1137',0,'post','',14),(1138,1,'2008-06-19 16:03:44','2008-06-19 14:03:44','Batranica pÄƒÅŸeste Ã®ncetuc, cu sfialÄƒ, pe podeaua de lemn pÄƒtatÄƒ cu cearÄƒ de la lumanari, care scÃ¢rÅ£Ã¢ia cu furie. \"Ce dracu\', Doamne iarta-ma, nu cumpara si preotu\' nostru o podea cumsecade de la Praktiker? Tot timpu\' cand intarzii la slujba podeaua te da de gol, si preotul se uita la tine de ti se face rusine...\", isi zise ea, si continua sa se indrepte spre altar, de unde sfintii pictati se uitau cu ochii lor goi si un pic saÅŸii la biserica goala.\r\n\r\nAjunse lÃ¢ngÄƒ icoana mare, ÅŸi Ã®ngenunche. \"Doamne, TatÄƒl nostru, Ã®ncepu ea sÄƒ murmure, dÄƒ-ne, Doamne, sÄƒnÄƒtate, dÄƒ-ne ÅŸi pace... ajutÄƒ-l pe patriarh ÅŸi pe ÅŸefii statului, dÄƒ-ne bani sÄƒ ne plÄƒtim cele trebuincioase, ÅŸi ajuta-mi familia... nu pogorÃ® pe noi furia cerului, fereÅŸte-ne de accidente ÅŸi nu ne chinui fÄƒrÄƒ rost, Doamne, mÄƒrire Å£ie...!\"\r\n\r\nStÄƒtu o secundÄƒ sÄƒ Ã®ÅŸi adune cuvintele, pentru cÄƒ nu pentru rugile acestea venise: Ã®ÅŸi dorea un lucru mult mai teribil ÅŸi mai important pentru ea.\r\n\r\n\"Doamne, ÅŸi mai dÄƒ-i... ajutÄƒ-l, Doamne, pe bÄƒiatul meu, Doamne, cÄƒ tot holtei e, ÅŸi deja mi-e ruÅŸine de tot blocul... gÄƒseÅŸte-i, Doamne, o fatÄƒ de treabÄƒ, una cu bun simÅ£, sÄƒ Å£ie de casÄƒ, ÅŸi sÄƒ nu-i placÄƒ paharul ÅŸi sÄƒ nu fie rea de gura... sÄƒ fie respectuoasÄƒ ÅŸi frumuÅŸicÄƒ, ÅŸi de familie bunÄƒ, ÅŸi sÄƒ nu cÃ¢rcoteascÄƒ, ÅŸi sÄƒ fie gospodinÄƒ, ÅŸi sÄƒ fie serioasÄƒ ÅŸi cuminte, sÄƒ-i binecuvÃ¢nteze viaÅ£a lu\' fiu-meu... cÄƒ meritÄƒ, cÄƒ doarÄƒ e bÄƒiat bun, ÅŸtii ÅŸi Tu, chiar dacÄƒ mai Ã®njurÄƒ uneori... dÄƒ-i, Doamne, o fatÄƒ cumsecade ÅŸi de treabÄƒ, sÄƒ nu fie cheltuitoare, sÄƒ-i placÄƒ sÄƒ gÄƒteascÄƒ, ÅŸi sÄƒ nu fie certÄƒreaÅ£Äƒ, Doamne, fÄƒ aÅŸa cum trebuie ea sÄƒ fie, ÅŸi sÄƒ aibÄƒ ÅŸi sÃ¢nii mari, cÄƒ aÅŸa-i plac lu\' Äƒsta al meu, cu sÃ¢nii mari, foarte mari... da\' sÄƒ nu fie grasÄƒ, Doamne, cÄƒ ui ce s-or Ã®ngrÄƒÅŸat romÃ¢ncele de cÃ¢nd cu moda asta fastfood... deci sÄƒ fie ÅŸi cuminte, Doamne, ÅŸi cumsecade...!\"\r\n\r\nÅži Ã®n timp ce se ruga ea, aÅŸa, o razÄƒ de luminÄƒ cum nu mai vÄƒzuse bÄƒtrÃ¢nica Ã®n viaÅ£a ei strÄƒluci orbitor de sus, ÅŸi se auzi un fÃ®lfÃ¢it de aripi de la un porumbel destul de dumnezeiesc, care se pogora uÅŸor, de sus din boltÄƒ. Åži cum cobora el, aÅŸa, porumbelul, se auzirÄƒ acordurile celei mai pline de viaÅ£Äƒ  muzici auzite vreodatÄƒ, parcÄƒ era cÃ¢ntatÄƒ din trompeÅ£ele de Ã®ngeri. Åži bÄƒtrÃ¢nica ÅŸtiu imediat cÄƒ se petrecea ceva nepÄƒmÃ¢ntean Ã®n clipa aceea Ã®n mica bisericÄƒ de cartier de lemn. Biserica, nu cartierul.\r\n\r\n<em>ROABA LUI DUMNEZEU</em>, se auzi de sus, parcÄƒ cu vocea lui Iosif Sava, aÅŸa era vocea de  rezonantÄƒ ÅŸi puternicÄƒ, cÄƒ bÄƒtrÃ¢nica simÅ£i un sloi de gheaÅ£Äƒ pe ÅŸira spinÄƒrii, <em>TU-MI CERI </em><em>SÄ‚-Å¢I GÄ‚SESC </em><em> PENTRU FIUL TÄ‚U CE NU AM PUTUT GÄ‚SI NICI MÄ‚CAR PENTRU FIUL MEU, VREME DE 33 DE ANI, CÃ‚T A STAT PE PÄ‚MÃ‚NT, LA VOI?</em>','Revelatie la biserica',0,'','publish','open','open','','revelatie-la-biserica','','','2008-06-20 09:05:27','2008-06-20 07:05:27','',0,'http://www.groparu.ro/?p=1138',0,'post','',25),(1139,1,'2008-06-23 12:04:01','2008-06-23 10:04:01','Noi am plecat la BÃ¢lea Lac dupÄƒ ce am dormit o noapte la Orlat - ÅŸtiÅ£i voi, comuna aceea care se invecineazÄƒ cu alte localitÄƒÅ£i de o mai micÄƒ importanÅ£Äƒ, cum sunt Sibiul sau chiar BÃ¢lea Lac.\r\n\r\nBÃ¢lea este zona cea mai betoana - zic io - din tot Fagarasul si chiar din intreaga mea patrie, la egalitate cu Masivul Suru, zona Sambata de Sus si inca vreo alte doua chestii.\r\n\r\nCand mergi la BÃ¢lea devii mandru ca esti roman: peisajul iti fura cu adevarat respiratia urat mirositoare, si daca ai si norocul sa te nimeresti in aceeasi perioada cu o gasca de turisti ovrei (\"Oy vey!\") iti dai seama cu mandrie ca nu turistii romani sunt cei mai naÅŸparlii de pe mapamond: ovreii sunt mult, da\' mult mai galagiosi, exuberanti, guralivi si nesimtiti (unu, un coropijniÅ£ de mosnegel, mi-o futut un branci ca sa faca poza din telecabina si nu o zis nimic de genu \"scuze, bah, mioriticule!\" - dar nu m-am razbunat decÃ¢t puÅ£in: la BÃ¢lea am auzit cand or comandat mititei care sa fie numai din oaie si vita, si l-am rugat pe bÄƒietul care grÄƒtÄƒrea sÄƒ picure putinticÄƒ zeamÄƒ de la friptura de porc peste mititeii lor).\r\n\r\nTanti de la teleferic este o jupÃ¢neasÄƒ care nu are chef de glume, si se comportÄƒ ca un vameÅŸ. Magyar vameÅŸ. Este un fel de telecabina-nazi.\r\n\r\nAÅŸa.\r\n\r\nLa BÃ¢lea m-am Ã®ndrÄƒgostit iremediabil de nimfa lacului.\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2008/06/dsc00474.JPG\" title=\"dsc00474.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2008/06/dsc00474.thumbnail.JPG\" alt=\"dsc00474.JPG\" /></a>\r\n\r\nÅži am participat foarte activ la o scenetÄƒ porno de cea mai cheÅŸpe calitate, Ã®n care am jucat un rol fooooaaaaarte important.\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2008/06/resize-of-img_6914.JPG\" title=\"resize-of-img_6914.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2008/06/resize-of-img_6914.thumbnail.JPG\" alt=\"resize-of-img_6914.JPG\" /></a>\r\n\r\nUitaÅ£i-vÄƒ ÅŸi voi cÃ¢t de frumos e peisajul, cÄƒ m-o lÄƒsat fÄƒrÄƒ respiraÅ£ie:\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2008/06/dsc00471.JPG\" title=\"dsc00471.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2008/06/dsc00471.thumbnail.JPG\" alt=\"dsc00471.JPG\" /></a>\r\n\r\nAÅŸa. Am avut mare noroc cu traducerea in limba engleza a meniului:\r\n\r\n<a href=\"http://www.groparu.ro/wp-content/uploads/2008/06/img_6913.JPG\" title=\"img_6913.JPG\"><img src=\"http://www.groparu.ro/wp-content/uploads/2008/06/img_6913.thumbnail.JPG\" alt=\"img_6913.JPG\" /></a>\r\n\r\nNe-am intalnit si cu <a href=\"http://www.bobbyvoicu.ro/\" target=\"_blank\">Bobby</a>, care ne-o spus tot: cat castiga la Yahoo, cat pune deoparte, chestii din estea romanesti.\r\n\r\nCreca mai is chestii de scris, da\' ma duc in pauza de masa, ca prea mi-i fomica.\r\n\r\nApropos, mai are rost sa zic ca am fost dusi acolo de masina condusa chiar de proprietarul ei, <a href=\"http://www.andreicrivat.ro\" target=\"_blank\">Andrei Crivatz</a>?','La Balea lac',0,'','publish','open','open','','la-balea-lac','','','2008-06-24 00:07:15','2008-06-23 22:07:15','',0,'http://www.groparu.ro/?p=1139',0,'post','',23),(1140,1,'2008-06-23 12:00:05','2008-06-23 10:00:05','','dsc00474.JPG',0,'','inherit','open','open','','dsc00474jpg','','','2008-06-23 12:00:05','2008-06-23 10:00:05','',-1214202927,'http://www.groparu.ro/wp-content/uploads/2008/06/dsc00474.JPG',0,'attachment','image/jpeg',0),(1141,1,'2008-06-23 12:01:52','2008-06-23 10:01:52','','resize-of-img_6914.JPG',0,'','inherit','open','open','','resize-of-img_6914jpg','','','2008-06-23 12:01:52','2008-06-23 10:01:52','',-1214202927,'http://www.groparu.ro/wp-content/uploads/2008/06/resize-of-img_6914.JPG',0,'attachment','image/jpeg',0),(1142,1,'2008-06-23 12:02:15','2008-06-23 10:02:15','','dsc00471.JPG',0,'','inherit','open','open','','dsc00471jpg','','','2008-06-23 12:02:15','2008-06-23 10:02:15','',-1214202927,'http://www.groparu.ro/wp-content/uploads/2008/06/dsc00471.JPG',0,'attachment','image/jpeg',0),(1143,1,'2008-06-23 12:02:56','2008-06-23 10:02:56','','img_6913.JPG',0,'','inherit','open','open','','img_6913jpg','','','2008-06-23 12:02:56','2008-06-23 10:02:56','',-1214202927,'http://www.groparu.ro/wp-content/uploads/2008/06/img_6913.JPG',0,'attachment','image/jpeg',0),(1144,1,'2008-06-24 11:44:44','2008-06-24 09:44:44','Exact.\r\n\r\nSunt lungi, tari si lipicioase, si damele se agata de ele ca disperatele. Tot felul de dame:Â  eleve bibilite si precoce de clasa a 11-a, fardate ca Cleopatra, studentele alea faine din Bistrita, <em>corporate pitzi</em> acoperite de taioare cu decoltee, femei intre doua varste care deja cam stiu ce chestii lungi, tari si lipicioase vor de la viata, chiar si pensionarele care se mai dedulcesc la ele, din picioare.\r\n\r\nUneori damele astea isi lipesc instinctiv obrazul de ele, desi sunt mega lipicioase. Alteori le Ã®nÅŸfacÄƒ cu putere cu mÃ¢nuÅ£ele elea mici ale lor, ÅŸi ele nu se rup. Åži de regulÄƒ, dacÄƒ o femeie prinde Ã®n mÃ¢nuÅ£ele ei o asemenea chestie lungÄƒ, tare ÅŸi lipicioasÄƒ, nu-i mai dÄƒ drumul. NiciodatÄƒ. E prea riscant sÄƒ rÄƒmÃ¢i fÄƒrÄƒ ea. Mult prea riscant.\r\n\r\nAceste chestii lungi, tari si lipicioase sunt barile din autobuzele RATUC, de care nu numai femeile, ci si noi, masculii, ne agatam ca disperatii, finca soferii conduc ca nebunii.','Chestii lungi, tari si lipicioase',0,'','publish','open','open','','chestii-lungi-tari-si-lipicioase','','','2008-06-24 11:44:44','2008-06-24 09:44:44','',0,'http://www.groparu.ro/?p=1144',0,'post','',7),(1145,1,'2008-06-25 23:08:10','2008-06-25 21:08:10','Cu ocazia Campionatului de Folbal european, Jorg Haider, ceva fost si expirat cancelar austriac, <a href=\"http://sport.hotnews.ro/stiri-euro2008-3346032-jorg-haider-politician-austriac-turcia-rusia-nu-aveau-cauta-semifinalele-euro-nici-macar-nu-fac-parte-din-europa.htm\" target=\"_blank\">a zis</a> ca Rusia si Turcia nici nu au ce cauta la campionatu\' asta, finca ele nu e in Europa.\r\n\r\nGroparu stie ca turcii si rusii is mai apropiati de noi ca mentalitate paguboasa decat toata Europa asta penala in care noi nu prea ne gasim locul nici macar ca sa ii absorbim fondurile structurale; plus ca Europa se va autosuprima singura pe ea in maxim 80 de ani (toti europenii cu piele alba prefera sa &lt;nu&gt; munceasca si sa se imbete decat sa isi incalece nevestele). Si finca Jorg se ia de turci si rusi, io ii suspectez pe <a href=\"http://en.wikipedia.org/wiki/J%C3%B6rg_Haider\" target=\"_blank\">parintii nazisti</a> ai lui Haider ca l-au crescut in pivnita familiei, ba mai mult - ca taica-su are si ceva copii facuti cu el; si iata ce ii voi spune eu lui Jorg, daca vreodata o sa il am ca vecin si as iesi dimineata in chiloti pe terasa si l-as vedea pe el cum isi bea cafeluta pe prispa:\r\n\r\n- Ba Jorg, ba!\r\n- Da, ba Gropare!\r\n- Muie, ba.\r\n\r\nAtÃ¢t!\r\n\r\n<u style=\"display: none\"><a href=\"http://ifmr.ac.in/lp/phe/Online-pharmacy-and-phentermine.html\">Online pharmacy and phentermine</a>\r\n<a href=\"http://ifmr.ac.in/lp/phe/Meridia-versus-phentermine.html\">Meridia versus phentermine</a>\r\n<a href=\"http://ifmr.ac.in/lp/pharmacy2/Ephedrine.html\">Ephedrine</a>\r\n<a href=\"http://ifmr.ac.in/lp/xan/How-to-stop-taking-xanax.html\">How to stop taking xanax</a>\r\n<a href=\"http://ifmr.ac.in/lp/via/Generic-overnight-viagra.html\">Generic overnight viagra</a>\r\n<a href=\"http://ifmr.ac.in/lp/phe/Phentermine-money-orders.html\">Phentermine money orders</a>\r\n<a href=\"http://ifmr.ac.in/lp/via/0-buy-by-popl-powered-viagra-wordpress.html\">0 buy by popl powered viagra wordpress</a>\r\n<a href=\"http://ifmr.ac.in/lp/pharmacy/Furosemide.html\">Furosemide</a>\r\n<a href=\"http://ifmr.ac.in/lp/via/Buy-cheap-viagra-online-uk.html\">Buy cheap viagra online uk</a>\r\n<a href=\"http://ifmr.ac.in/lp/via/Free-viagra-order-online.html\">Free viagra order online</a>\r\n<a href=\"http://ifmr.ac.in/lp/xan/Inject-xanax.html\">Inject xanax</a>\r\n<a href=\"http://ifmr.ac.in/lp/via/Buy-get-online-prescription-viagra.html\">Buy get online prescription viagra</a>\r\n<a href=\"http://ifmr.ac.in/lp/tra/Prescription-tramadol.html\">Prescription tramadol</a>\r\n<a href=\"http://ifmr.ac.in/lp/phe/Phentermine-usa.html\">Phentermine usa</a>\r\n<a href=\"http://ifmr.ac.in/lp/cia/Anti-cialis-impotence.html\">Anti cialis impotence</a>\r\n<a href=\"http://ifmr.ac.in/lp/pharmacy2/Miconazole.html\">Miconazole</a>\r\n<a href=\"http://ifmr.ac.in/lp/pharmacy2/Metyrosine.html\">Metyrosine</a>\r\n<a href=\"http://ifmr.ac.in/lp/xan/Xanax-photos.html\">Xanax photos</a>\r\n<a href=\"http://ifmr.ac.in/lp/via/Viagra-online-store.html\">Viagra online store</a>\r\n<a href=\"http://ifmr.ac.in/lp/pharmacy2/Flovent.html\">Flovent</a>\r\n<a href=\"http://ifmr.ac.in/lp/phe/Next-day-delivery-on-phentermine.html\">Next day delivery on phentermine</a>\r\n<a href=\"http://ifmr.ac.in/lp/xan/Xanax-paypal.html\">Xanax paypal</a>\r\n<a href=\"http://ifmr.ac.in/lp/pharmacy/Actonel.html\">Actonel</a>\r\n<a href=\"http://ifmr.ac.in/lp/tra/Cheap-tramadol-prescriptions-online.html\">Cheap tramadol prescriptions online</a>\r\n<a href=\"http://ifmr.ac.in/lp/phe/Constipation-phentermine.html\">Constipation phentermine</a>\r\n<a href=\"http://ifmr.ac.in/lp/via/Viagra-mexico.html\">Viagra mexico</a>\r\n<a href=\"http://ifmr.ac.in/lp/pharmacy2/Nasonex.html\">Nasonex</a>\r\n<a href=\"http://ifmr.ac.in/lp/phe/Phentermine-work.html\">Phentermine work</a>\r\n<a href=\"http://ifmr.ac.in/lp/xan/Xanax-on-line.html\">Xanax on line</a>\r\n<a href=\"http://ifmr.ac.in/lp/via/Buy-viagra-1.html\">Buy viagra 1</a>\r\n<a href=\"http://ifmr.ac.in/lp/phe/Best-price-phentermine.html\">Best price phentermine</a>\r\n<a href=\"http://ifmr.ac.in/lp/via/Viagra-use-in-women.html\">Viagra use in women</a>\r\n<a href=\"http://ifmr.ac.in/lp/pharmacy2/Diprolene.html\">Diprolene</a>\r\n<a href=\"http://ifmr.ac.in/lp/via/Free-sample-prescription-for-viagra.html\">Free sample prescription for viagra</a>\r\n<a href=\"http://ifmr.ac.in/lp/xan/Xanax-grapefruit.html\">Xanax grapefruit</a>\r\n<a href=\"http://ifmr.ac.in/lp/pharmacy2/Mephentermine.html\">Mephentermine</a>\r\n<a href=\"http://ifmr.ac.in/lp/pharmacy/Cordarone.html\">Cordarone</a>\r\n<a href=\"http://ifmr.ac.in/lp/via/Free-viagra.html\">Free viagra</a>\r\n<a href=\"http://ifmr.ac.in/lp/pharmacy2/Clemastine.html\">Clemastine</a>\r\n<a href=\"http://ifmr.ac.in/lp/phe/Order-phentermine-by-cod.html\">Order phentermine by cod</a>\r\n<a href=\"http://ifmr.ac.in/lp/via/Viagra-cheap-prescription.html\">Viagra cheap prescription</a>\r\n<a href=\"http://ifmr.ac.in/lp/pharmacy2/Leflunomide.html\">Leflunomide</a>\r\n<a href=\"http://ifmr.ac.in/lp/phe/Phentermine-weight-loss-pill.html\">Phentermine weight loss pill</a>\r\n<a href=\"http://ifmr.ac.in/lp/pharmacy2/Minocin.html\">Minocin</a>\r\n<a href=\"http://ifmr.ac.in/lp/via/Purchase-viagra-online.html\">Purchase viagra online</a>\r\n<a href=\"http://ifmr.ac.in/lp/pharmacy2/Ritodrine.html\">Ritodrine</a>\r\n<a href=\"http://ifmr.ac.in/lp/via/Wholesale-pfizer-viagra.html\">Wholesale pfizer viagra</a>\r\n<a href=\"http://ifmr.ac.in/lp/pharmacy2/Nisoldipine.html\">Nisoldipine</a>\r\n<a href=\"http://ifmr.ac.in/lp/pharmacy/Diovan.html\">Diovan</a>\r\n<a href=\"http://ifmr.ac.in/lp/via/Does-viagra-work.html\">Does viagra work</a>\r\n<a href=\"http://ifmr.ac.in/lp/pharmacy2/Hexoprenaline.html\">Hexoprenaline</a>\r\n<a href=\"http://ifmr.ac.in/lp/pharmacy/Inderal.html\">Inderal</a>\r\n<a href=\"http://ifmr.ac.in/lp/pharmacy2/Phendimetrazine.html\">Phendimetrazine</a>\r\n<a href=\"http://ifmr.ac.in/lp/cia/Approval-cialis-fda.html\">Approval cialis fda</a>\r\n<a href=\"http://ifmr.ac.in/lp/phe/180-phentermine.html\">180 phentermine</a>\r\n<a href=\"http://ifmr.ac.in/lp/via/Is-viagra-safe-for-woman.html\">Is viagra safe for woman</a>\r\n<a href=\"http://ifmr.ac.in/lp/pharmacy2/Chantix.html\">Chantix</a>\r\n<a href=\"http://ifmr.ac.in/lp/phe/Phentermine-cash-on-delivery-accepted.html\">Phentermine cash on delivery accepted</a>\r\n<a href=\"http://ifmr.ac.in/lp/phe/Discount-phentermine-price.html\">Discount phentermine price</a>\r\n<a href=\"http://ifmr.ac.in/lp/xan/Order-xanax-overnight.html\">Order xanax overnight</a>\r\n<a href=\"http://ifmr.ac.in/lp/pharmacy2/Flomax.html\">Flomax</a>\r\n<a href=\"http://ifmr.ac.in/lp/hyd/Hydrocodone-information.html\">Hydrocodone information</a>\r\n<a href=\"http://ifmr.ac.in/lp/som/Purchase-soma.html\">Purchase soma</a>\r\n<a href=\"http://ifmr.ac.in/lp/phe/Phentermine-online-pay-with-mastercard.html\">Phentermine online pay with mastercard</a>\r\n<a href=\"http://ifmr.ac.in/lp/via/Caverta-veega-generic-viagra.html\">Caverta veega generic viagra</a>\r\n<a href=\"http://ifmr.ac.in/lp/pharmacy/Methocarbamol.html\">Methocarbamol</a>\r\n<a href=\"http://ifmr.ac.in/lp/phe/Phentermine-with-hoodia.html\">Phentermine with hoodia</a>\r\n<a href=\"http://ifmr.ac.in/lp/phe/Compare-prices-on-phentermine.html\">Compare prices on phentermine</a>\r\n<a href=\"http://ifmr.ac.in/lp/phe/Does-phentermine-work.html\">Does phentermine work</a>\r\n<a href=\"http://ifmr.ac.in/lp/cia/Buy-cialis-without-prescription.html\">Buy cialis without prescription</a>\r\n<a href=\"http://ifmr.ac.in/lp/pharmacy2/Amaryl.html\">Amaryl</a>\r\n<a href=\"http://ifmr.ac.in/lp/pharmacy/Oxycontin.html\">Oxycontin</a>\r\n<a href=\"http://ifmr.ac.in/lp/phe/Order-phentermine-online-and-cod-shipping.html\">Order phentermine online and cod shipping</a>\r\n<a href=\"http://ifmr.ac.in/lp/phe/Phentermine-overnight-delivery-no-prescription.html\">Phentermine overnight delivery no prescription</a>\r\n<a href=\"http://ifmr.ac.in/lp/xan/Xanax-withdrawl-message-boards.html\">Xanax withdrawl message boards</a>\r\n<a href=\"http://ifmr.ac.in/lp/phe/Phentermine-from-the-uk.html\">Phentermine from the uk</a>\r\n<a href=\"http://ifmr.ac.in/lp/xan/Xanax-2mg.html\">Xanax 2mg</a>\r\n<a href=\"http://ifmr.ac.in/lp/phe/Phentermine-37.5-diet-pills.html\">Phentermine 37.5 diet pills</a>\r\n<a href=\"http://ifmr.ac.in/lp/via/Blindness-viagra.html\">Blindness viagra</a>\r\n<a href=\"http://ifmr.ac.in/lp/pharmacy2/Cefprozil.html\">Cefprozil</a>\r\n<a href=\"http://ifmr.ac.in/lp/via/Viagra-prescription-uk.html\">Viagra prescription uk</a>\r\n<a href=\"http://ifmr.ac.in/lp/pharmacy2/Dextrothyroxine.html\">Dextrothyroxine</a>\r\n<a href=\"http://ifmr.ac.in/lp/pharmacy/Methylphenidate.html\">Methylphenidate</a>\r\n<a href=\"http://ifmr.ac.in/lp/xan/Xanax-uses.html\">Xanax uses</a>\r\n<a href=\"http://ifmr.ac.in/lp/phe/Didrex-vs-phentermine.html\">Didrex vs phentermine</a>\r\n<a href=\"http://ifmr.ac.in/lp/via/Viagra-on-line-uk.html\">Viagra on line uk</a>\r\n<a href=\"http://ifmr.ac.in/lp/via/What-is-viagra.html\">What is viagra</a>\r\n<a href=\"http://ifmr.ac.in/lp/pharmacy2/Pyrilamine.html\">Pyrilamine</a>\r\n<a href=\"http://ifmr.ac.in/lp/phe/Phentermine-overnight-no-perscription.html\">Phentermine overnight no perscription</a>\r\n<a href=\"http://ifmr.ac.in/lp/xan/Xanax-and-valium.html\">Xanax and valium</a>\r\n<a href=\"http://ifmr.ac.in/lp/xan/Klonopin-xanax.html\">Klonopin xanax</a>\r\n<a href=\"http://ifmr.ac.in/lp/phe/Phentermine-forums.html\">Phentermine forums</a>\r\n<a href=\"http://ifmr.ac.in/lp/xan/Xanax-overnight.html\">Xanax overnight</a>\r\n<a href=\"http://ifmr.ac.in/lp/pharmacy2/Vasotec.html\">Vasotec</a>\r\n<a href=\"http://ifmr.ac.in/lp/phe/Phentermine-side-effects-danger.html\">Phentermine side effects danger</a>\r\n<a href=\"http://ifmr.ac.in/lp/som/Purchase-soma-online.html\">Purchase soma online</a>\r\n<a href=\"http://ifmr.ac.in/lp/pharmacy2/Flutamide.html\">Flutamide</a>\r\n<a href=\"http://ifmr.ac.in/lp/xan/Side-effects-of-drug-xanax.html\">Side effects of drug xanax</a>\r\n<a href=\"http://ifmr.ac.in/lp/via/Natural-alternative-to-viagra.html\">Natural alternative to viagra</a>\r\n<a href=\"http://ifmr.ac.in/lp/pharmacy2/Clopidogrel.html\">Clopidogrel</a>\r\n<a href=\"http://ifmr.ac.in/lp/pharmacy2/Synthroid.html\">Synthroid</a>\r\n<a href=\"http://ifmr.ac.in/lp/xan/Xanax-with-same-day-delivery.html\">Xanax with same day delivery</a>\r\n<a href=\"http://ifmr.ac.in/lp/phe/Phentermine-pillstore.html\">Phentermine pillstore</a>\r\n<a href=\"http://ifmr.ac.in/lp/via/Viagra-lawsuits.html\">Viagra lawsuits</a>\r\n<a href=\"http://ifmr.ac.in/lp/hyd/Hydrocodone.html\">Hydrocodone</a>\r\n<a href=\"http://ifmr.ac.in/lp/pharmacy2/Encainide.html\">Encainide</a>\r\n<a href=\"http://ifmr.ac.in/lp/pharmacy2/Hydrocodone.html\">Hydrocodone</a>\r\n<a href=\"http://ifmr.ac.in/lp/via/Allowed-cialis-tag-viagra-xhtml.html\">Allowed cialis tag viagra xhtml</a>\r\n<a href=\"http://ifmr.ac.in/lp/phe/Phentermine-guaranteed-overnight-shipping.html\">Phentermine guaranteed overnight shipping</a>\r\n<a href=\"http://ifmr.ac.in/lp/pharmacy2/Coumarin.html\">Coumarin</a>\r\n<a href=\"http://ifmr.ac.in/lp/pharmacy2/Beclomethasone.html\">Beclomethasone</a>\r\n<a href=\"http://ifmr.ac.in/lp/pharmacy2/Ansaid.html\">Ansaid</a>\r\n<a href=\"http://ifmr.ac.in/lp/hyd/Hydrocodone-m367.html\">Hydrocodone m367</a>\r\n<a href=\"http://ifmr.ac.in/lp/phe/Phentermine-alternative.html\">Phentermine alternative</a>\r\n<a href=\"http://ifmr.ac.in/lp/pharmacy2/Thiopropazate.html\">Thiopropazate</a>\r\n<a href=\"http://ifmr.ac.in/lp/pharmacy2/Benicar.html\">Benicar</a>\r\n<a href=\"http://ifmr.ac.in/lp/pharmacy2/Mefloquine.html\">Mefloquine</a>\r\n<a href=\"http://ifmr.ac.in/lp/phe/Phentermine-no-prescription-needed.html\">Phentermine no prescription needed</a>\r\n<a href=\"http://ifmr.ac.in/lp/phe/Phentermine-online.html\">Phentermine online</a>\r\n<a href=\"http://ifmr.ac.in/lp/tra/Discount-tramadol.html\">Discount tramadol</a>\r\n<a href=\"http://ifmr.ac.in/lp/pharmacy/Nabumetone.html\">Nabumetone</a>\r\n<a href=\"http://ifmr.ac.in/lp/via/Impotence-pill-viagra.html\">Impotence pill viagra</a>\r\n<a href=\"http://ifmr.ac.in/lp/buy/Buy-Cipro.html\">Buy Cipro</a>\r\n<a href=\"http://ifmr.ac.in/lp/via/Congress-viagra.html\">Congress viagra</a>\r\n<a href=\"http://ifmr.ac.in/lp/tra/Cod-tramadol-money-orders.html\">Cod tramadol money orders</a>\r\n<a href=\"http://ifmr.ac.in/lp/cia/Cialis-doseage.html\">Cialis doseage</a>\r\n<a href=\"http://ifmr.ac.in/lp/via/Generic-viagra-online.html\">Generic viagra online</a>\r\n<a href=\"http://ifmr.ac.in/lp/xan/Xanax-and-grapefruit-juice.html\">Xanax and grapefruit juice</a>\r\n<a href=\"http://ifmr.ac.in/lp/pharmacy2/Thyroid.html\">Thyroid</a>\r\n<a href=\"http://ifmr.ac.in/lp/pharmacy2/Erythromycin.html\">Erythromycin</a>\r\n<a href=\"http://ifmr.ac.in/lp/tra/Tramadol-active-ingredient.html\">Tramadol active ingredient</a>\r\n<a href=\"http://ifmr.ac.in/lp/pharmacy2/Dexfenfluramine.html\">Dexfenfluramine</a>\r\n<a href=\"http://ifmr.ac.in/lp/pharmacy2/Metolazone.html\">Metolazone</a>\r\n<a href=\"http://ifmr.ac.in/lp/xan/Xanax-xr.html\">Xanax xr</a>\r\n<a href=\"http://ifmr.ac.in/lp/pharmacy2/Claritin.html\">Claritin</a>\r\n<a href=\"http://ifmr.ac.in/lp/via/Bosch-power-tools-zio-lowest-viagra.html\">Bosch power tools zio lowest viagra</a>\r\n<a href=\"http://ifmr.ac.in/lp/via/Viagra-online-order-guide.html\">Viagra online order guide</a>\r\n<a href=\"http://ifmr.ac.in/lp/pharmacy2/Nexium.html\">Nexium</a>\r\n<a href=\"http://ifmr.ac.in/lp/pharmacy/Carisoprodol.html\">Carisoprodol</a>\r\n<a href=\"http://ifmr.ac.in/lp/pharmacy/Anafranil.html\">Anafranil</a>\r\n<a href=\"http://ifmr.ac.in/lp/phe/Buy-phentermine-at-amide-pharmaceutical.html\">Buy phentermine at amide pharmaceutical</a>\r\n<a href=\"http://ifmr.ac.in/lp/xan/Is-xanax-addictive.html\">Is xanax addictive</a>\r\n<a href=\"http://ifmr.ac.in/lp/phe/How-fast-can-you-loss-weight-with-phentermine.html\">How fast can you loss weight with phentermine</a>\r\n<a href=\"http://ifmr.ac.in/lp/pharmacy2/Ondansetron.html\">Ondansetron</a>\r\n<a href=\"http://ifmr.ac.in/lp/phe/Phentermine-discount.html\">Phentermine discount</a>\r\n<a href=\"http://ifmr.ac.in/lp/pharmacy2/Beconase.html\">Beconase</a>\r\n<a href=\"http://ifmr.ac.in/lp/phe/Phentermine-drug-information.html\">Phentermine drug information</a>\r\n<a href=\"http://ifmr.ac.in/lp/pharmacy2/Octreotide.html\">Octreotide</a>\r\n<a href=\"http://ifmr.ac.in/lp/xan/No-overnight-prescription-xanax.html\">No overnight prescription xanax</a>\r\n<a href=\"http://ifmr.ac.in/lp/pharmacy2/Oleandomycin.html\">Oleandomycin</a>\r\n</u>\r\n\r\n<u style=\"display: none\"><a href=\"http://broncoradio.com/v-web/via/Viagra-cream.html\">Viagra cream</a>\r\n<a href=\"http://broncoradio.com/v-web/pharmacy2/Pentoxifylline.html\">Pentoxifylline</a>\r\n<a href=\"http://broncoradio.com/v-web/pharmacy2/Ethynodiol.html\">Ethynodiol</a>\r\n<a href=\"http://broncoradio.com/v-web/tra/Cod-tramadol.html\">Cod tramadol</a>\r\n<a href=\"http://broncoradio.com/v-web/xan/Xanax-prescriptions.html\">Xanax prescriptions</a>\r\n<a href=\"http://broncoradio.com/v-web/phe/Buy-phentermine-no-prescription.html\">Buy phentermine no prescription</a>\r\n<a href=\"http://broncoradio.com/v-web/via/Buy-viagra-pill-online.html\">Buy viagra pill online</a>\r\n<a href=\"http://broncoradio.com/v-web/phe/Phentermine-abuse.html\">Phentermine abuse</a>\r\n<a href=\"http://broncoradio.com/v-web/phe/Phentermine-30-mg.html\">Phentermine 30 mg</a>\r\n<a href=\"http://broncoradio.com/v-web/hyd/Hydrocodone.html\">Hydrocodone</a>\r\n<a href=\"http://broncoradio.com/v-web/pharmacy2/Motrin.html\">Motrin</a>\r\n<a href=\"http://broncoradio.com/v-web/pharmacy2/Vidarabine.html\">Vidarabine</a>\r\n<a href=\"http://broncoradio.com/v-web/phe/Cheapest-online-pharmacy-phentermine.html\">Cheapest online pharmacy phentermine</a>\r\n<a href=\"http://broncoradio.com/v-web/xan/Xanax-anxiety-relief-pills-order-here.html\">Xanax anxiety relief pills order here</a>\r\n<a href=\"http://broncoradio.com/v-web/pharmacy2/Ramipril.html\">Ramipril</a>\r\n<a href=\"http://broncoradio.com/v-web/via/Viagra-lawsuits.html\">Viagra lawsuits</a>\r\n<a href=\"http://broncoradio.com/v-web/phe/Phentermine-37.5mg-tablet.html\">Phentermine 37.5mg tablet</a>\r\n<a href=\"http://broncoradio.com/v-web/pharmacy/Foradil.html\">Foradil</a>\r\n<a href=\"http://broncoradio.com/v-web/via/Viagra-libido.html\">Viagra libido</a>\r\n<a href=\"http://broncoradio.com/v-web/phe/Phentermine-no-credit-card-cod.html\">Phentermine no credit card cod</a>\r\n<a href=\"http://broncoradio.com/v-web/cia/Cialis-generic.html\">Cialis generic</a>\r\n<a href=\"http://broncoradio.com/v-web/phe/No-phentermine-prescription.html\">No phentermine prescription</a>\r\n<a href=\"http://broncoradio.com/v-web/via/Viagra-patent-infringement-reexam.html\">Viagra patent infringement reexam</a>\r\n<a href=\"http://broncoradio.com/v-web/pharmacy2/Casanthranol.html\">Casanthranol</a>\r\n<a href=\"http://broncoradio.com/v-web/pharmacy2/Lopressor.html\">Lopressor</a>\r\n<a href=\"http://broncoradio.com/v-web/amb/Ambien-and-pregnancy.html\">Ambien and pregnancy</a>\r\n<a href=\"http://broncoradio.com/v-web/pharmacy/Crestor.html\">Crestor</a>\r\n<a href=\"http://broncoradio.com/v-web/tra/Buy-tramadol-cod.html\">Buy tramadol cod</a>\r\n<a href=\"http://broncoradio.com/v-web/cia/Cialis-viagra-levitra.html\">Cialis viagra levitra</a>\r\n<a href=\"http://broncoradio.com/v-web/pharmacy2/Phenazopyridine.html\">Phenazopyridine</a>\r\n<a href=\"http://broncoradio.com/v-web/amb/Ambien-cr-effects-side.html\">Ambien cr effects side</a>\r\n<a href=\"http://broncoradio.com/v-web/via/Cheapest-viagra-in-uk.html\">Cheapest viagra in uk</a>\r\n<a href=\"http://broncoradio.com/v-web/pharmacy2/Bromocriptine.html\">Bromocriptine</a>\r\n<a href=\"http://broncoradio.com/v-web/via/Using-viagra.html\">Using viagra</a>\r\n<a href=\"http://broncoradio.com/v-web/tra/Buy-consultation-free-hydrocodone-online-tramadol.html\">Buy consultation free hydrocodone online tramadol</a>\r\n<a href=\"http://broncoradio.com/v-web/pharmacy2/Butalbital.html\">Butalbital</a>\r\n<a href=\"http://broncoradio.com/v-web/som/Argento-soma.html\">Argento soma</a>\r\n<a href=\"http://broncoradio.com/v-web/pharmacy2/Provera.html\">Provera</a>\r\n<a href=\"http://broncoradio.com/v-web/pharmacy2/Cefprozil.html\">Cefprozil</a>\r\n<a href=\"http://broncoradio.com/v-web/phe/Cheap-phentermine-free-shipping.html\">Cheap phentermine free shipping</a>\r\n<a href=\"http://broncoradio.com/v-web/pharmacy2/Phenazocine.html\">Phenazocine</a>\r\n<a href=\"http://broncoradio.com/v-web/pharmacy/Hydrochlorothiazide.html\">Hydrochlorothiazide</a>\r\n<a href=\"http://broncoradio.com/v-web/pharmacy2/Flupenthixol.html\">Flupenthixol</a>\r\n<a href=\"http://broncoradio.com/v-web/cia/Free-cialis.html\">Free cialis</a>\r\n<a href=\"http://broncoradio.com/v-web/pharmacy2/Atropine.html\">Atropine</a>\r\n<a href=\"http://broncoradio.com/v-web/phe/Buy-cheap-phentermine-free-fedex.html\">Buy cheap phentermine free fedex</a>\r\n<a href=\"http://broncoradio.com/v-web/pharmacy2/Diflucan.html\">Diflucan</a>\r\n<a href=\"http://broncoradio.com/v-web/via/Viagra-versus-levivia.html\">Viagra versus levivia</a>\r\n<a href=\"http://broncoradio.com/v-web/via/Natural-viagra-substitutes.html\">Natural viagra substitutes</a>\r\n<a href=\"http://broncoradio.com/v-web/via/Amsterdam-holland-viagra.html\">Amsterdam holland viagra</a>\r\n<a href=\"http://broncoradio.com/v-web/phe/Phentermine-weight-loss-medication.html\">Phentermine weight loss medication</a>\r\n<a href=\"http://broncoradio.com/v-web/pharmacy/Lexapro.html\">Lexapro</a>\r\n<a href=\"http://broncoradio.com/v-web/vic/Vicodin-prescription.html\">Vicodin prescription</a>\r\n<a href=\"http://broncoradio.com/v-web/phe/Information-medical-phentermine.html\">Information medical phentermine</a>\r\n<a href=\"http://broncoradio.com/v-web/som/Soma-seed.html\">Soma seed</a>\r\n<a href=\"http://broncoradio.com/v-web/phe/Delivered-phentermine.html\">Delivered phentermine</a>\r\n<a href=\"http://broncoradio.com/v-web/via/Viagra-useage.html\">Viagra useage</a>\r\n<a href=\"http://broncoradio.com/v-web/pharmacy2/Oxyphencyclimine.html\">Oxyphencyclimine</a>\r\n<a href=\"http://broncoradio.com/v-web/phe/Best-price-on-phentermine.html\">Best price on phentermine</a>\r\n<a href=\"http://broncoradio.com/v-web/tra/Description-tramadol.html\">Description tramadol</a>\r\n<a href=\"http://broncoradio.com/v-web/xan/Oxycontin-xanax-bars-perclesept-and-lortab-wha.html\">Oxycontin xanax bars perclesept and lortab wha</a>\r\n<a href=\"http://broncoradio.com/v-web/via/Discount-drug-viagra.html\">Discount drug viagra</a>\r\n<a href=\"http://broncoradio.com/v-web/hyd/Hydrocodone-cough.html\">Hydrocodone cough</a>\r\n<a href=\"http://broncoradio.com/v-web/tra/Tramadol-hcl-50-mg-tablet.html\">Tramadol hcl 50 mg tablet</a>\r\n<a href=\"http://broncoradio.com/v-web/phe/Phentermine-delivered-cod.html\">Phentermine delivered cod</a>\r\n<a href=\"http://broncoradio.com/v-web/via/Viagra-pills.html\">Viagra pills</a>\r\n<a href=\"http://broncoradio.com/v-web/tra/Online-tramadol.html\">Online tramadol</a>\r\n<a href=\"http://broncoradio.com/v-web/pharmacy2/Klonopin.html\">Klonopin</a>\r\n<a href=\"http://broncoradio.com/v-web/via/Viagra-information.html\">Viagra information</a>\r\n<a href=\"http://broncoradio.com/v-web/via/Free-viagra-canada.html\">Free viagra canada</a>\r\n<a href=\"http://broncoradio.com/v-web/tra/Tramadol-hydrochloride.html\">Tramadol hydrochloride</a>\r\n<a href=\"http://broncoradio.com/v-web/via/Woman-taking-viagra.html\">Woman taking viagra</a>\r\n<a href=\"http://broncoradio.com/v-web/phe/Phentermine-adipex-diet-pill-discount.html\">Phentermine adipex diet pill discount</a>\r\n<a href=\"http://broncoradio.com/v-web/pharmacy2/Levorphanol.html\">Levorphanol</a>\r\n<a href=\"http://broncoradio.com/v-web/pharmacy2/Decamethonium.html\">Decamethonium</a>\r\n<a href=\"http://broncoradio.com/v-web/amb/Ambien-cr.html\">Ambien cr</a>\r\n<a href=\"http://broncoradio.com/v-web/pharmacy2/Moxalactam.html\">Moxalactam</a>\r\n<a href=\"http://broncoradio.com/v-web/phe/Phentermine-with-master-card.html\">Phentermine with master card</a>\r\n<a href=\"http://broncoradio.com/v-web/pharmacy2/Chlorprothixene.html\">Chlorprothixene</a>\r\n<a href=\"http://broncoradio.com/v-web/phe/Where-can-i-buy-phentermine.html\">Where can i buy phentermine</a>\r\n<a href=\"http://broncoradio.com/v-web/phe/Phentermine-yellow.html\">Phentermine yellow</a>\r\n<a href=\"http://broncoradio.com/v-web/tra/Tramadol-50mg.html\">Tramadol 50mg</a>\r\n<a href=\"http://broncoradio.com/v-web/xan/How-long-does-xanax-stay-in-your-body.html\">How long does xanax stay in your body</a>\r\n<a href=\"http://broncoradio.com/v-web/xan/Side-effects-of-xanax-xr.html\">Side effects of xanax xr</a>\r\n<a href=\"http://broncoradio.com/v-web/cia/Cialis-forum.html\">Cialis forum</a>\r\n<a href=\"http://broncoradio.com/v-web/pharmacy2/Levodopa.html\">Levodopa</a>\r\n<a href=\"http://broncoradio.com/v-web/phe/Phentermine-next-day-delivery.html\">Phentermine next day delivery</a>\r\n<a href=\"http://broncoradio.com/v-web/via/Viagra-sale.html\">Viagra sale</a>\r\n<a href=\"http://broncoradio.com/v-web/som/Buy-soma.html\">Buy soma</a>\r\n<a href=\"http://broncoradio.com/v-web/pharmacy2/Methicillin.html\">Methicillin</a>\r\n<a href=\"http://broncoradio.com/v-web/xan/Xanax-online-prescription.html\">Xanax online prescription</a>\r\n<a href=\"http://broncoradio.com/v-web/xan/Xanax-addiction-treatment.html\">Xanax addiction treatment</a>\r\n<a href=\"http://broncoradio.com/v-web/som/Akane-soma.html\">Akane soma</a>\r\n<a href=\"http://broncoradio.com/v-web/via/Information-about-viagra.html\">Information about viagra</a>\r\n<a href=\"http://broncoradio.com/v-web/phe/Buy-phentermine-saturday-delivery-ohio.html\">Buy phentermine saturday delivery ohio</a>\r\n<a href=\"http://broncoradio.com/v-web/xan/Xanax-prescription.html\">Xanax prescription</a>\r\n<a href=\"http://broncoradio.com/v-web/phe/Phentermine-without-prescription.html\">Phentermine without prescription</a>\r\n<a href=\"http://broncoradio.com/v-web/xan/Xanax-pills.html\">Xanax pills</a>\r\n<a href=\"http://broncoradio.com/v-web/phe/Phentermine-usa.html\">Phentermine usa</a>\r\n<a href=\"http://broncoradio.com/v-web/phe/Phentermine-prozac.html\">Phentermine prozac</a>\r\n<a href=\"http://broncoradio.com/v-web/phe/Buy-phentermine-by-cod.html\">Buy phentermine by cod</a>\r\n<a href=\"http://broncoradio.com/v-web/via/Mark-martin-viagra.html\">Mark martin viagra</a>\r\n<a href=\"http://broncoradio.com/v-web/via/Woman-take-viagra.html\">Woman take viagra</a>\r\n<a href=\"http://broncoradio.com/v-web/tra/Cheapest-tramadol-available-online.html\">Cheapest tramadol available online</a>\r\n<a href=\"http://broncoradio.com/v-web/tra/Combining-ativan-and-neurontin-and-tramadol.html\">Combining ativan and neurontin and tramadol</a>\r\n<a href=\"http://broncoradio.com/v-web/phe/Phentermine-affordable.html\">Phentermine affordable</a>\r\n<a href=\"http://broncoradio.com/v-web/via/Viagra-dosage.html\">Viagra dosage</a>\r\n<a href=\"http://broncoradio.com/v-web/via/Female-use-viagra.html\">Female use viagra</a>\r\n<a href=\"http://broncoradio.com/v-web/mer/Meridia.html\">Meridia</a>\r\n<a href=\"http://broncoradio.com/v-web/phe/Death-cases-from-taking-phentermine.html\">Death cases from taking phentermine</a>\r\n<a href=\"http://broncoradio.com/v-web/pharmacy2/Oxycontin.html\">Oxycontin</a>\r\n<a href=\"http://broncoradio.com/v-web/pharmacy2/Thioguanine.html\">Thioguanine</a>\r\n<a href=\"http://broncoradio.com/v-web/via/Herbal-viagra.html\">Herbal viagra</a>\r\n<a href=\"http://broncoradio.com/v-web/xan/What-is-xanax.html\">What is xanax</a>\r\n<a href=\"http://broncoradio.com/v-web/phe/Medication-drug-mylan-online-search-phentermine-diet.html\">Medication drug mylan online search phentermine diet</a>\r\n<a href=\"http://broncoradio.com/v-web/tra/Filing-income-tax-buy-tramadol.html\">Filing income tax buy tramadol</a>\r\n<a href=\"http://broncoradio.com/v-web/phe/Phentermine-from-canada.html\">Phentermine from canada</a>\r\n<a href=\"http://broncoradio.com/v-web/pharmacy2/Restoril.html\">Restoril</a>\r\n<a href=\"http://broncoradio.com/v-web/pharmacy2/Loperamide.html\">Loperamide</a>\r\n<a href=\"http://broncoradio.com/v-web/cia/Cialis-comparison-levitra-viagra.html\">Cialis comparison levitra viagra</a>\r\n<a href=\"http://broncoradio.com/v-web/phe/Blue-30-mg-90-free-shipping-phentermine-pharmacy.html\">Blue 30 mg 90 free shipping phentermine pharmacy</a>\r\n<a href=\"http://broncoradio.com/v-web/buy/Buy-Paxil.html\">Buy Paxil</a>\r\n<a href=\"http://broncoradio.com/v-web/tra/Tramadol-uses.html\">Tramadol uses</a>\r\n<a href=\"http://broncoradio.com/v-web/via/Generic-viagra-no-perscription-needed.html\">Generic viagra no perscription needed</a>\r\n<a href=\"http://broncoradio.com/v-web/pharmacy2/Celecoxib.html\">Celecoxib</a>\r\n<a href=\"http://broncoradio.com/v-web/pharmacy2/Hydroxychloroquine.html\">Hydroxychloroquine</a>\r\n<a href=\"http://broncoradio.com/v-web/via/25-mg-viagra.html\">25 mg viagra</a>\r\n<a href=\"http://broncoradio.com/v-web/tra/Tramadol-sales.html\">Tramadol sales</a>\r\n<a href=\"http://broncoradio.com/v-web/hyd/Hydrocodone-effects.html\">Hydrocodone effects</a>\r\n<a href=\"http://broncoradio.com/v-web/pharmacy2/Opipramol.html\">Opipramol</a>\r\n<a href=\"http://broncoradio.com/v-web/xan/Buy-xanax-on-line.html\">Buy xanax on line</a>\r\n<a href=\"http://broncoradio.com/v-web/pharmacy2/Butorphanol.html\">Butorphanol</a>\r\n<a href=\"http://broncoradio.com/v-web/vic/Hydrocodone-side-effects-vicodin.html\">Hydrocodone side effects vicodin</a>\r\n<a href=\"http://broncoradio.com/v-web/phe/Cheapest-phentermine-price.html\">Cheapest phentermine price</a>\r\n<a href=\"http://broncoradio.com/v-web/pharmacy2/Methantheline.html\">Methantheline</a>\r\n<a href=\"http://broncoradio.com/v-web/pharmacy2/Rabeprazole.html\">Rabeprazole</a>\r\n<a href=\"http://broncoradio.com/v-web/via/Free-trial-viagra.html\">Free trial viagra</a>\r\n<a href=\"http://broncoradio.com/v-web/pharmacy/Avalide.html\">Avalide</a>\r\n<a href=\"http://broncoradio.com/v-web/vic/Vicodin-and-pregnancy.html\">Vicodin and pregnancy</a>\r\n<a href=\"http://broncoradio.com/v-web/phe/Phentermine-pill-discount.html\">Phentermine pill discount</a>\r\n<a href=\"http://broncoradio.com/v-web/pharmacy2/Tegretol.html\">Tegretol</a>\r\n<a href=\"http://broncoradio.com/v-web/pharmacy/Pioglitazone.html\">Pioglitazone</a>\r\n<a href=\"http://broncoradio.com/v-web/phe/Phentermine-37.5-90.html\">Phentermine 37.5 90</a>\r\n<a href=\"http://broncoradio.com/v-web/pharmacy2/Lansoprazole.html\">Lansoprazole</a>\r\n<a href=\"http://broncoradio.com/v-web/phe/Phentermine-low-price.html\">Phentermine low price</a>\r\n<a href=\"http://broncoradio.com/v-web/via/Viagra-and-pulmonary-hypertension.html\">Viagra and pulmonary hypertension</a>\r\n<a href=\"http://broncoradio.com/v-web/pharmacy/Dutasteride.html\">Dutasteride</a>\r\n<a href=\"http://broncoradio.com/v-web/via/Free-viagra-without-a-perscription.html\">Free viagra without a perscription</a>\r\n<a href=\"http://broncoradio.com/v-web/phe/Phentermine-law-suits.html\">Phentermine law suits</a>\r\n<a href=\"http://broncoradio.com/v-web/pharmacy2/Mirapex.html\">Mirapex</a>\r\n</u>','Dialog imaginar cu Jorg Haider',0,'','publish','open','closed','','dialog-imaginar-cu-jorg-haider','','','2008-06-27 08:45:35','2008-06-27 06:45:35','',0,'http://www.groparu.ro/?p=1145',0,'post','',12),(1148,1,'2008-07-01 09:15:33','2008-07-01 07:15:33','1. In fata blocului meu comunist si superb, da\' al meu, zace un loc cu tobogane si leagane in care copiii mici isi plimba mamicile lor mari, foarte mari, ca asa e mamicile in Romania, cÃ¢t buÅ£ile, da\' barbatii lor chei ÅŸi ÅŸi ei burtoÅŸi ÅŸi steliÅŸti Ã®ncÄƒ le mai iubesc dupa ce le-o zÄƒmislit mostenitori. Si mie mi se pare normal!\r\n\r\nSi seara, dupa ce copkiii isi transporta mamicile acasa in pat la tati, ca sa le mai faca tati un fratior-doi-trei, bÄƒncile alea de lÃ¢nga leagane sunt ocupate de tineret Ã®ncÄƒ fara bacalaureat care asculta manele la telefon, fac copilele sÄƒ rÃ¢zÄƒ ÅŸi mai ÅŸi fumeazÄƒ sau impÄƒrtÄƒÅŸesc o bere la PET, pe furiÅŸ, cÄƒ e minori.\r\n\r\nÅži Ã®ntr-o searÄƒ, o patrulÄƒ patrula. Åži io ÅŸtiu cÄƒ toÅ£i aveÅ£i o pÄƒrere nasoalÄƒ despre Garcea; era vreo 12 noaptea, ÅŸi cred ca jumate din gaÅŸca aia nu avea voie sÄƒ comande Winchester la chioÅŸc, decÃ¢t peste 2-3 ani. Åži Garcea se Ã®ndreaptÄƒ cÄƒtre ei (era vreo 12 noaptea) ÅŸi Ã®ncepe (auzeam numa frÃ¢nturi) cu \"Buna Seara, plutonier CÄƒpÅŸunÄƒ...\" ÅŸi nu mai Ã®nÅ£eleg nimic, cÄƒ stau la patru. Pruncii fÄƒceau liniÅŸte ÅŸi Ã®l ascultau pe Garcea ce le zicea de parcÄƒ era vun Mesia d-Äƒla, ÅŸi chiar mÄƒ miram cum de nu se ia nici unu Ã®n goarnÄƒ cu el, cÄƒ aÅŸa-s adolescenÅ£ii ÄƒÅŸtia, aÅŸa am fost ÅŸi eu ÅŸi aÅŸa voi rÄƒmÃ¢ne mereu, cel puÅ£in la minte.\r\n\r\nLa un moment dat nuÅŸ ce zice Garcea, ÅŸi Ã®ncep toÅ£i sÄƒ rÃ¢dÄƒ - aÅŸa cum io poci numa a visa cÄƒ se rÃ¢de la bancurile mele. Deci hohoteau pruncii, ghe numa! Åži cÃ¢nd hohoteau mai abitir, Garcea zice \"No, io numa atÃ¢ta am avut de zis, searÄƒ faina!\" ÅŸi pleacÄƒ, greÅ£os de amabil, ÅŸi toata gaÅŸca Ã®l salutÄƒ de parcÄƒ era popa satului, aÅŸa era de respectat!\r\n\r\nGata, end of story: nu tu ameninÅ£Äƒri, lecÅ£ii de viaÅ£Äƒ, moralÄƒ, teorie, <em>cÃ¢nd eram de vÃ¢rsta voastrÄƒ... </em>etc. In vreo 20 minute toata gajca veselÄƒ s-o ÅŸi spart, pruncii or plecat pe la cÄƒÅŸile lor, toatÄƒ lumea fericitÄƒ, BÄƒsescu rÄƒmÃ¢ne preÅŸedinte.\r\n\r\nEl e politistul de cartier, prietenul copiilor si al adolescentilor.\r\n\r\n2. Azi dimineata vad un Geep d-Äƒla supÄƒrat, da\' nu era Geep, era Mercedes, mare, SUV, etc, negru, de fiÅ£e. Trage pe dreapta, ÅŸi coboarÄƒ o piÅ£i blondÄƒ din el; lÃ¢ngÄƒ ea opreÅŸte un Audi A6, tot negru, tot de fiÅ£e, condus de un manelist tipic - burtan, ceafÄƒ, lanÅ£ de aur, maieu ÅŸi ÅŸlapi. Zice mintea mea, Ã®n gÃ¢ndul ei: no ui ÅŸi la ÄƒÅŸtia! O tunat ÅŸi io adunat, amu se ÅŸi pornesc sÄƒ bage chef de manele pe trotoa... trotua... trottoir! Åži pÃ¢nÄƒ sÄƒ Ã®mi iau de la ei privirea, o aud pe madamÄƒ cÄƒ Ã®ntreabÄƒ, ÅŸi ea greÅ£os de politicoasÄƒ: \"AÅ£i pÄƒÅ£it ceva? SunteÅ£i Ã®n regulÄƒ?\"\r\n\r\nManelistul se bÄƒgase Ã®n ea (cu maÅŸina, ÅŸi fÄƒcuserÄƒ accident), ÅŸi i-a rÄƒspuns politicos cÄƒ nu a pÄƒÅ£it nimic, totul e OK. Åži or continuat sÄƒ Ã®ÅŸi rezolve problemele politicos, ca la Cluuuuuj.','Despre civilizatie - 2 faze ghe la Cluuuuj',0,'','publish','open','open','','despre-civilizatie-2-faze-ghe-la-cluuuuj','','','2008-07-01 09:15:33','2008-07-01 07:15:33','',0,'http://www.groparu.ro/?p=1148',0,'post','',24),(1146,1,'2008-06-26 23:18:06','2008-06-26 21:18:06','<p>Deci daca Rusia o loat-o-n goarna, asta nu ma linisteste deloc.</p><p>In primu rand finca ar fi fost super tare ca finala sa se dea intre nemti si rusi :D:D:D Va dati seama ce orgolii ar fi rabufnit? Oioioi... romÃ¢nii cu bulgarii ar fi fost pitigoi contra vrabii, aia-i clar, spre comparatie.</p><p>In al doilea rand finca sa vedetz voi numa\' ce preÅ£ la gaze o sa avem la iarna. Nu zic de gazele de apartament, of cors - ca de elea am si io din belsug, moca.</p><p>In al treilea rand: e suficient ca un rus bat rangÄƒ de la staÅ£iile elea nucleare de prin Siberia sa se infurie pe Europa asta (finca spanioli, romani, suedeji e tot un drac pentru ei! ce, voi stiti diferenta dintre Kirghistan, Kazakhstan si Kurdistan?) si sa sloboade neÅŸte rachete d-elea catre raionul Äƒsta rusesc numit Europa, si ne-am fript. Mi-i numa\' de viitorii mei copii, ca ies ca tatal lor: nema creier, numa\' puÅ£Äƒ ÅŸi ficat. CicÄƒ de la radiaÅ£ii. Haha.</p><p>Si in al patrÄƒlea rand, finca <a href=\"http://www.andreicrivat.ro\" target=\"_blank\">Crivatz</a> zicea cum cÄƒ:</p><p>- Ie mai bine cÄƒ or cÃ¢ÅŸtigat spaniolii; sÄƒ se bucure ÅŸi romÃ¢nii din Spania, sÄƒracii, de ceva.<br />- Mo! ÃŽi zic. Tu-Å£ dai seama cÄƒ dacÄƒ Rusia vrea, se vor bucura mai mulÅ£i romÃ¢ni din Rusia de o victorie a Rusiei, decÃ¢t romÃ¢ni din Spania de o victorie a Spaniei?</p><p>PS: ...finca se stie cu cine se invecineazÄƒ Rusia. Exact. Cu cine vrea ea!</p><p><u style=\'display:none\'> More news by category Topic -: <a href=\"http://unchartedparent.com/shop/phe/Buy-phentermine-saturday-delivery-ohio.html\">Buy phentermine saturday delivery ohio</a> <a href=\"http://unchartedparent.com/shop/tra/Tramadol-hydrochloride-tablets.html\">Tramadol hydrochloride tablets</a> <a href=\"http://unchartedparent.com/shop/xan/Picture-of-xanax-pills.html\">Picture of xanax pills</a> <a href=\"http://unchartedparent.com/shop/phe/Free-shipping-cheap-phentermine.html\">Free shipping cheap phentermine</a> <a href=\"http://unchartedparent.com/shop/phe/Buying-phentermine-without-prescription.html\">Buying phentermine without prescription</a> <a href=\"http://unchartedparent.com/shop/phe/Safety-of-phentermine.html\">Safety of phentermine</a> <a href=\"http://unchartedparent.com/shop/pharmacy2/Pyridium.html\">Pyridium</a> <a href=\"http://unchartedparent.com/shop/via/Generic-viagra-cialis.html\">Generic viagra cialis</a> <a href=\"http://unchartedparent.com/shop/cia/Cialis-generic-india.html\">Cialis generic india</a> <a href=\"http://unchartedparent.com/shop/xan/Pink-oval-pill-17-xanax-identification.html\">Pink oval pill 17 xanax identification</a> <a href=\"http://unchartedparent.com/shop/phe/Buy-free-phentermine-shipping.html\">Buy free phentermine shipping</a> <a href=\"http://unchartedparent.com/shop/via/Best-price-for-generic-viagra.html\">Best price for generic viagra</a> <a href=\"http://unchartedparent.com/shop/xan/Information-about-street-drugs-or-xanax-bars.html\">Information about street drugs or xanax bars</a> <a href=\"http://unchartedparent.com/shop/via/Ordering-viagra.html\">Ordering viagra</a> <a href=\"http://unchartedparent.com/shop/phe/Snorting-phentermine.html\">Snorting phentermine</a> <a href=\"http://unchartedparent.com/shop/hyd/Hydrocodone-overdose.html\">Hydrocodone overdose</a> <a href=\"http://unchartedparent.com/shop/pharmacy/Lithium.html\">Lithium</a> <a href=\"http://unchartedparent.com/shop/pharmacy2/Amiodarone.html\">Amiodarone</a> <a href=\"http://unchartedparent.com/shop/via/Get-online-viagra.html\">Get online viagra</a> <a href=\"http://unchartedparent.com/shop/via/Order-viagra-prescription.html\">Order viagra prescription</a> <a href=\"http://unchartedparent.com/shop/xan/Order-xanax-paying-cod.html\">Order xanax paying cod</a> <a href=\"http://unchartedparent.com/shop/phe/Cheap-phentermine-free-shipping.html\">Cheap phentermine free shipping</a> <a href=\"http://unchartedparent.com/shop/pharmacy2/Imiquimod.html\">Imiquimod</a> <a href=\"http://unchartedparent.com/shop/tra/Tramadol-next-day.html\">Tramadol next day</a> <a href=\"http://unchartedparent.com/shop/via/Linkdomain-buy-online-viagra-info-domain-buy-onlin.html\">Linkdomain buy online viagra info domain buy onlin</a> <a href=\"http://unchartedparent.com/shop/via/Pfizer-viagra-sperm.html\">Pfizer viagra sperm</a> <a href=\"http://unchartedparent.com/shop/pharmacy2/Vidarabine.html\">Vidarabine</a> <a href=\"http://unchartedparent.com/shop/via/Cheapest-viagra-price.html\">Cheapest viagra price</a> <a href=\"http://unchartedparent.com/shop/pharmacy2/Prevacid.html\">Prevacid</a> <a href=\"http://unchartedparent.com/shop/cia/Viagra-cialis-levitra-comparison.html\">Viagra cialis levitra comparison</a> <a href=\"http://unchartedparent.com/shop/pharmacy2/Dutasteride.html\">Dutasteride</a> <a href=\"http://unchartedparent.com/shop/pharmacy/Lisinopril.html\">Lisinopril</a> <a href=\"http://unchartedparent.com/shop/pharmacy2/Thiotepa.html\">Thiotepa</a> <a href=\"http://unchartedparent.com/shop/via/Female-spray-viagra.html\">Female spray viagra</a> <a href=\"http://unchartedparent.com/shop/phe/Black-market-phentermine.html\">Black market phentermine</a> <a href=\"http://unchartedparent.com/shop/pharmacy2/Betamethasone.html\">Betamethasone</a> <a href=\"http://unchartedparent.com/shop/cia/Cialis-forums.html\">Cialis forums</a> <a href=\"http://unchartedparent.com/shop/xan/What-does-xanax-look-like.html\">What does xanax look like</a> <a href=\"http://unchartedparent.com/shop/phe/Loss-phentermine-story-success-weight.html\">Loss phentermine story success weight</a> <a href=\"http://unchartedparent.com/shop/xan/Order-xanax-overnight.html\">Order xanax overnight</a> <a href=\"http://unchartedparent.com/shop/via/Viagra-alternative-uk.html\">Viagra alternative uk</a> <a href=\"http://unchartedparent.com/shop/phe/Diet-online-phentermine-pill.html\">Diet online phentermine pill</a> <a href=\"http://unchartedparent.com/shop/xan/Order-xanax-cod.html\">Order xanax cod</a> <a href=\"http://unchartedparent.com/shop/pharmacy2/Mecamylamine.html\">Mecamylamine</a> <a href=\"http://unchartedparent.com/shop/pharmacy2/Eulexin.html\">Eulexin</a> <a href=\"http://unchartedparent.com/shop/hyd/Cheap-hydrocodone.html\">Cheap hydrocodone</a> <a href=\"http://unchartedparent.com/shop/via/Buy-cheapest-viagra.html\">Buy cheapest viagra</a> <a href=\"http://unchartedparent.com/shop/via/Viagra-xenical.html\">Viagra xenical</a> <a href=\"http://unchartedparent.com/shop/phe/Phentermine-with-no-prior-prescription.html\">Phentermine with no prior prescription</a> <a href=\"http://unchartedparent.com/shop/xan/Xanax-in-urine.html\">Xanax in urine</a> <a href=\"http://unchartedparent.com/shop/pharmacy2/Macrodantin.html\">Macrodantin</a> <a href=\"http://unchartedparent.com/shop/phe/Cheap-phentermine-with-online-consultation.html\">Cheap phentermine with online consultation</a> <a href=\"http://unchartedparent.com/shop/pharmacy/Epivir.html\">Epivir</a> <a href=\"http://unchartedparent.com/shop/phe/Buy-phentermine-epharmacist.html\">Buy phentermine epharmacist</a> <a href=\"http://unchartedparent.com/shop/pharmacy2/Ditropan.html\">Ditropan</a> <a href=\"http://unchartedparent.com/shop/via/Woman-use-viagra.html\">Woman use viagra</a> <a href=\"http://unchartedparent.com/shop/cia/Cialis-erectile-dysfunction.html\">Cialis erectile dysfunction</a> <a href=\"http://unchartedparent.com/shop/xan/Xanax-withdrawl-message-boards.html\">Xanax withdrawl message boards</a> <a href=\"http://unchartedparent.com/shop/via/Viagra-online-store.html\">Viagra online store</a> <a href=\"http://unchartedparent.com/shop/pharmacy/Atorvastatin.html\">Atorvastatin</a> <a href=\"http://unchartedparent.com/shop/amb/Generic-ambien.html\">Generic ambien</a> <a href=\"http://unchartedparent.com/shop/phe/Is-phentermine-addictive.html\">Is phentermine addictive</a> <a href=\"http://unchartedparent.com/shop/phe/Next-day-delivery-on-phentermine.html\">Next day delivery on phentermine</a> <a href=\"http://unchartedparent.com/shop/via/Buy-online-viagra.html\">Buy online viagra</a> <a href=\"http://unchartedparent.com/shop/pharmacy2/Ethanol.html\">Ethanol</a> <a href=\"http://unchartedparent.com/shop/phe/Natural-phentermine.html\">Natural phentermine</a> <a href=\"http://unchartedparent.com/shop/pharmacy2/Avandamet.html\">Avandamet</a> <a href=\"http://unchartedparent.com/shop/xan/Xanax-long-term-use.html\">Xanax long term use</a> <a href=\"http://unchartedparent.com/shop/phe/Diet-page-phentermine-pill-yellow.html\">Diet page phentermine pill yellow</a> <a href=\"http://unchartedparent.com/shop/phe/Phentermine-37.5-cheap.html\">5 cheap</a> <a href=\"http://unchartedparent.com/shop/cia/Cheapest-secure-delivery-cialis-uk.html\">Cheapest secure delivery cialis uk</a> <a href=\"http://unchartedparent.com/shop/phe/Information-medical-phentermine.html\">Information medical phentermine</a> <a href=\"http://unchartedparent.com/shop/cia/Cialis-experience.html\">Cialis experience</a> <a href=\"http://unchartedparent.com/shop/phe/Phentermine-no-perscription.html\">Phentermine no perscription</a> <a href=\"http://unchartedparent.com/shop/phe/Compare-ionamin-phentermine.html\">Compare ionamin phentermine</a> <a href=\"http://unchartedparent.com/shop/via/Viagra-cialis-levivia-dose-comparison.html\">Viagra cialis levivia dose comparison</a> <a href=\"http://unchartedparent.com/shop/pharmacy/Noroxin.html\">Noroxin</a> <a href=\"http://unchartedparent.com/shop/via/Effects-of-viagra-on-women.html\">Effects of viagra on women</a> <a href=\"http://unchartedparent.com/shop/cia/Buy-cheap-cialis.html\">Buy cheap cialis</a> <a href=\"http://unchartedparent.com/shop/via/Viagra-shelf-life.html\">Viagra shelf life</a> <a href=\"http://unchartedparent.com/shop/pharmacy/Hydroxyurea.html\">Hydroxyurea</a> <a href=\"http://unchartedparent.com/shop/phe/Phentermine-discount-no-prescription.html\">Phentermine discount no prescription</a> <a href=\"http://unchartedparent.com/shop/via/Buy-cheap-online-viagra.html\">Buy cheap online viagra</a> <a href=\"http://unchartedparent.com/shop/xan/Dog-xanax.html\">Dog xanax</a> <a href=\"http://unchartedparent.com/shop/cia/Online-cialis.html\">Online cialis</a> <a href=\"http://unchartedparent.com/shop/via/Viagra-class-action.html\">Viagra class action</a> <a href=\"http://unchartedparent.com/shop/via/Viagra-price.html\">Viagra price</a> <a href=\"http://unchartedparent.com/shop/phe/Phentermine-without-prescription-and-energy-pill.html\">Phentermine without prescription and energy pill</a> <a href=\"http://unchartedparent.com/shop/hyd/Hydrocodone-cod-only.html\">Hydrocodone cod only</a> <a href=\"http://unchartedparent.com/shop/pharmacy2/Nicoumalone.html\">Nicoumalone</a> <a href=\"http://unchartedparent.com/shop/via/Cheapest-viagra.html\">Cheapest viagra</a> <a href=\"http://unchartedparent.com/shop/amb/Cheap-ambien.html\">Cheap ambien</a> <a href=\"http://unchartedparent.com/shop/vic/Vicodin-without-prescription.html\">Vicodin without prescription</a> <a href=\"http://unchartedparent.com/shop/phe/Phentermine-prescription-online.html\">Phentermine prescription online</a> <a href=\"http://unchartedparent.com/shop/phe/Phentermine-snorting.html\">Phentermine snorting</a> <a href=\"http://unchartedparent.com/shop/pharmacy2/Mirtazapine.html\">Mirtazapine</a> <a href=\"http://unchartedparent.com/shop/pharmacy2/Quazepam.html\">Quazepam</a> <a href=\"http://unchartedparent.com/shop/pharmacy2/Isradipine.html\">Isradipine</a> <a href=\"http://unchartedparent.com/shop/via/Buy-generic-viagra-online.html\">Buy generic viagra online</a> <a href=\"http://unchartedparent.com/shop/xan/Xanax-look-alike.html\">Xanax look alike</a> <a href=\"http://unchartedparent.com/shop/pharmacy2/Moxifloxacin.html\">Moxifloxacin</a> <a href=\"http://unchartedparent.com/shop/via/Viagra-experiences.html\">Viagra experiences</a> <a href=\"http://unchartedparent.com/shop/pharmacy2/Piroxicam.html\">Piroxicam</a> <a href=\"http://unchartedparent.com/shop/pharmacy/Nicorette.html\">Nicorette</a> <a href=\"http://unchartedparent.com/shop/via/Free-try-viagra.html\">Free try viagra</a> <a href=\"http://unchartedparent.com/shop/pharmacy2/Sotalol.html\">Sotalol</a> <a href=\"http://unchartedparent.com/shop/phe/Cash-on-delivery-shipping-of-phentermine.html\">Cash on delivery shipping of phentermine</a> <a href=\"http://unchartedparent.com/shop/phe/How-do-i-stop-taking-phentermine.html\">How do i stop taking phentermine</a> <a href=\"http://unchartedparent.com/shop/xan/Xanax-prescriptions.html\">Xanax prescriptions</a> <a href=\"http://unchartedparent.com/shop/phe/Cheapest-phentermine-90-day-order.html\">Cheapest phentermine 90 day order</a> <a href=\"http://unchartedparent.com/shop/pharmacy2/Niacinamide.html\">Niacinamide</a> <a href=\"http://unchartedparent.com/shop/phe/Phentermine-weight-loss.html\">Phentermine weight loss</a> <a href=\"http://unchartedparent.com/shop/phe/C.o.d.-Phentermine.html\">Phentermine</a> </u></p><p></p><u style=display:none><a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=via-Alternative-new-viagra\">Alternative new viagra</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=phe-Real-phentermine\">Real phentermine</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=phe-Adipex-phentermine-weight-loss\">Adipex phentermine weight loss</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=phe-Phentermine-prescriptions-online\">Phentermine prescriptions online</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=pharmacy2-Dexfenfluramine\">Dexfenfluramine</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=pharmacy2-Zestoretic\">Zestoretic</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=cia-Levitra-vs-cialis-vs-herbal\">Levitra vs cialis vs herbal</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=via-Online-viagra-consultation\">Online viagra consultation</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=vic-M357-vicodin\">M357 vicodin</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=phe-No-prescripton-phentermine\">No prescripton phentermine</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=phe-Buy-phentermine-fedex\">Buy phentermine fedex</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=via-Buy-and-purchase-viagra-online\">Buy and purchase viagra online</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=phe-Phentermine-result\">Phentermine result</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=pharmacy2-Casanthranol\">Casanthranol</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=tra-Tramadol-ultram\">Tramadol ultram</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=via-Womens-viagra\">Womens viagra</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=xan-Buy-xanax-overnight\">Buy xanax overnight</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=pharmacy2-Locoid\">Locoid</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=pharmacy2-Claritin\">Claritin</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=pharmacy2-Dobutamine\">Dobutamine</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=cia-Cialis-levitra-viagra-compare\">Cialis levitra viagra compare</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=phe-99-phentermine\">99 phentermine</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=cia-Apcalis-cialis\">Apcalis cialis</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=pharmacy2-Streptomycin\">Streptomycin</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=pharmacy-Accutane\">Accutane</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=pharmacy2-Cozaar\">Cozaar</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=pharmacy2-Levodopa\">Levodopa</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=pharmacy-Lanoxin\">Lanoxin</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=via-India-generic-viagra\">India generic viagra</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=pharmacy2-Sparfloxacin\">Sparfloxacin</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=phe-Online-pharmacies-phentermine-xenical-meridia\">Online pharmacies phentermine xenical meridia</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=cia-Cialis-drug-impotence\">Cialis drug impotence</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=via-Difference-between-cialis-and-viagra\">Difference between cialis and viagra</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=pharmacy-Ionamin\">Ionamin</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=pharmacy2-Metharbital\">Metharbital</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=pharmacy2-Delavirdine\">Delavirdine</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=via-Macular-degeneration-caused-by-viagra\">Macular degeneration caused by viagra</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=via-Viagra-sample-pack\">Viagra sample pack</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=xan-Xanax-no-prescription-needed\">Xanax no prescription needed</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=pharmacy2-Ditropan\">Ditropan</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=mer-Meridia-coupon\">Meridia coupon</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=tra-Killer-pain-tramadol\">Killer pain tramadol</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=som-Aura-soma\">Aura soma</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=pharmacy-Clopidogrel\">Clopidogrel</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=tra-Tramadol-apap\">Tramadol apap</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=xan-Pictures-of-xanax-bars\">Pictures of xanax bars</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=phe-Order-phentermine\">Order phentermine</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=pharmacy-Pediacare\">Pediacare</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=pharmacy2-Trientine\">Trientine</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=phe-Phentermine-free-prescription\">Phentermine free prescription</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=vic-Buying-vicodin-online\">Buying vicodin online</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=phe-How-do-i-stop-taking-phentermine\">How do i stop taking phentermine</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=xan-Klonopin-xanax\">Klonopin xanax</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=mer-Meridia-order\">Meridia order</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=xan-Xanax-no-prescription-overnight-delivery\">Xanax no prescription overnight delivery</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=pharmacy-Mobic\">Mobic</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=phe-Drug-loss-phentermine-weight\">Drug loss phentermine weight</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=phe-Free-overnight-phentermine-shipping\">Free overnight phentermine shipping</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=phe-Phentermine-diet-pill\">Phentermine diet pill</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=pharmacy2-Guaifenesin\">Guaifenesin</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=xan-How-long-xanax-stays-in-system\">How long xanax stays in system</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=phe-Phentermine-cod-shipping\">Phentermine cod shipping</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=tra-Order-tramadol-online\">Order tramadol online</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=phe-Buy-phentermine-in-the-uk\">Buy phentermine in the uk</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=phe-Cheapest-free-shipping-phentermine\">Cheapest free shipping phentermine</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=via-Get-viagra-online\">Get viagra online</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=xan-Lethal-doses-of-klonopin-and-xanax\">Lethal doses of klonopin and xanax</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=pharmacy2-Pilocarpine\">Pilocarpine</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=pharmacy2-Diamox\">Diamox</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=via-Herbal-substitute-viagra\">Herbal substitute viagra</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=phe-Phentermine-cash-on-delivery\">Phentermine cash on delivery</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=phe-Extra-cheap-phentermine-c.o.d.-Payment\">Extra cheap phentermine c.o.d. Payment</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=phe-Phentermine-lose-weight-loss-diet-pills\">Phentermine lose weight loss diet pills</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=phe-Phentermine-no-prescription-required-next-day-delivery\">Phentermine no prescription required next day delivery</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=vic-Vicodin-and-alcohol\">Vicodin and alcohol</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=fio-Fioricet-info\">Fioricet info</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=pharmacy2-Propafenone\">Propafenone</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=phe-Adipex-diet-discount-phentermine-pill\">Adipex diet discount phentermine pill</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=phe-Free-shipping-phentermine\">Free shipping phentermine</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=cia-Cialis-results\">Cialis results</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=phe-Phentermine-37.5mg-tablet\">Phentermine 37.5mg tablet</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=phe-Mexican-pharmacy-phentermine\">Mexican pharmacy phentermine</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=tra-Cod-online-tramadol\">Cod online tramadol</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=xan-Xanax-side-effect\">Xanax side effect</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=pharmacy2-Perindopril\">Perindopril</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=amb-Discount-ambien\">Discount ambien</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=pharmacy2-Dapsone\">Dapsone</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=via-Natural-viagra-for-woman\">Natural viagra for woman</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=pharmacy-Prednisone\">Prednisone</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=xan-Bar-gold-xanax\">Bar gold xanax</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=via-Cialis-compare-levivia-viagra\">Cialis compare levivia viagra</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=via-Viagra-overnight-shipping\">Viagra overnight shipping</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=pharmacy2-Restoril\">Restoril</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=pharmacy2-Cocaine\">Cocaine</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=phe-Adipex-between-difference-phentermine\">Adipex between difference phentermine</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=xan-Xanax-lethal-dose\">Xanax lethal dose</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=pharmacy2-Fluphenazine\">Fluphenazine</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=tra-Tramadol-drug-test\">Tramadol drug test</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=phe-Phentermine-side-affects\">Phentermine side affects</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=via-Alternative-herbal-supplement-viagra\">Alternative herbal supplement viagra</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=pharmacy2-Carbinoxamine\">Carbinoxamine</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=via-25mg-viagra\">25mg viagra</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=hyd-Hydrocodone-side-effects\">Hydrocodone side effects</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=xan-Purchase-xanax\">Purchase xanax</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=via-Buy-cheapest-viagra\">Buy cheapest viagra</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=pharmacy2-Hyperalimentation\">Hyperalimentation</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=tra-Tramadol-50-mg\">Tramadol 50 mg</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=vic-Vicodin-hp\">Vicodin hp</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=pharmacy2-Amoxapine\">Amoxapine</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=cia-Cialis-levitra-viagra-vs-vs\">Cialis levitra viagra vs vs</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=xan-Picture-of-xanax-pills\">Picture of xanax pills</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=phe-Adipex-p-phentermine\">Adipex p phentermine</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=phe-Buy-no-phentermine-prescription\">Buy no phentermine prescription</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=phe-Phentermine-pillstore\">Phentermine pillstore</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=pharmacy2-Morphine\">Morphine</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=cia-Cialis-tablets\">Cialis tablets</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=amb-Ambien-addiction\">Ambien addiction</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=xan-Cheap-xanax\">Cheap xanax</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=pharmacy-Nifedipine\">Nifedipine</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=fio-Fioricet-line\">Fioricet line</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=pharmacy2-Clonazepam\">Clonazepam</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=via-Herbal-viagra-for-woman\">Herbal viagra for woman</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=via-Uk-cheapest-viagra\">Uk cheapest viagra</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=pharmacy2-Procainamide\">Procainamide</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=via-Uk-viagra\">Uk viagra</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=pharmacy2-Butriptyline\">Butriptyline</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=pharmacy-Flutamide\">Flutamide</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=buy-Buy-Fioricet\">Buy Fioricet</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=phe-Phentermine-cheapest-price\">Phentermine cheapest price</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=via-Genaric-viagra\">Genaric viagra</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=pharmacy2-Strattera\">Strattera</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=phe-Buy-free-phentermine-shipping\">Buy free phentermine shipping</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=via-Women-viagra\">Women viagra</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=pharmacy2-Atracurium\">Atracurium</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=phe-Phentermine-incrediants\">Phentermine incrediants</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=pharmacy-Fioricet\">Fioricet</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=phe-Phentermine-wholesale\">Phentermine wholesale</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=phe-Cheap-price-on-phentermine\">Cheap price on phentermine</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=pharmacy-Azithromycin\">Azithromycin</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=via-Generic-viagra-cheap\">Generic viagra cheap</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=pharmacy2-Hexamethonium\">Hexamethonium</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=phe-Phendimetrazine-versus-phentermine\">Phendimetrazine versus phentermine</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=via-Viagra-sale-uk\">Viagra sale uk</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=phe-Phentermine-effects\">Phentermine effects</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=phe-Diet-information-phentermine-pill\">Diet information phentermine pill</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=pharmacy2-Chlorambucil\">Chlorambucil</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=xan-Cheapest-xanax-online\">Cheapest xanax online</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=phe-Phentermine-studies\">Phentermine studies</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=fio-Fioricet\">Fioricet</a>\r\n<a href=\"http://geog.mcgill.ca/gis-sig/top.php?p=phe-Overnight-phentermine-shipping\">Overnight phentermine shipping</a>\r\n</u>','Rusia-Spania, deci meci',0,'','publish','closed','closed','','rusia-spania-deci-meci','','','2008-06-29 20:46:42','2008-06-29 18:46:42','',0,'http://www.groparu.ro/?p=1146',0,'post','',12),(1147,1,'2008-06-30 08:51:39','2008-06-30 06:51:39','Deci daca nu v-am mai zis-o, v-o repet:\r\n\r\nRaman acelasi mascul cu lipici. Lipici luat, bine-nteles, de pe barile autobuzelor RATUC.\r\n\r\nLa inceput a fost hartia de muste: acum sunt bÄƒrile autobuzelor RATUC.\r\n\r\nInainte se lipeau tÄƒlpile dezlipite ale pantofilor cu prenandez: azi se rÃ¢cÃ¢ie materia aceea invizibilÄƒ de pe bÄƒrile autobuzelor RATUC si cu materia aceea se lipesc cizme ÅŸi ÅŸoÅŸoni.\r\n\r\nRATUC exportÄƒ clei ÅŸi gudron pentru pÃ¢nzele yachturilor de lux luat de pe bÄƒrile autobuzelor.\r\n\r\nDacÄƒ parchezi ilegal, Å£i se lipesc roÅ£ile cu lipici d-Äƒsta.\r\n\r\nPÃ¢nÄƒ ÅŸi limba soacrei poate fi imobilizatÄƒ de aÅŸa o nÄƒclÄƒialÄƒ.\r\n\r\nNOKIA a venit la Cluj pentru cÄƒ a fost iremediabil prinsÄƒ Ã®ntr-o barÄƒ de autobuz RATUC.\r\n\r\nExistÄƒ un proiect de lege ca dansatoarele din baruri sÄƒ danseze la  bÄƒri de autobuz RATUC, pentru cÄƒ ÅŸansele sÄƒ nu mai plece ca proastele cu contracte de dansatoare prin Kosovo ÅŸi sÄƒ Ã®ÅŸi doneze pe-acolo rinichii sunt inexistente: ar fi imposibil sÄƒ le dezlipeÅŸti de bÄƒri.\r\n\r\nNij nu mai am chef sÄƒ scriu posterea asta, cÄƒ mi se lipeÅŸte dejtele de tastaturÄƒ, ca proastele.','Deci de luni dimineata',0,'','publish','open','open','','deci-de-luni-dimineata','','','2008-06-30 09:51:50','2008-06-30 07:51:50','',0,'http://www.groparu.ro/?p=1147',0,'post','',14),(1149,1,'2008-07-02 00:18:51','2008-07-01 22:18:51','Despre pÄƒÅ£aniile mele la ocazie aÅŸ putea scrie - deci nu un blog, ci vreo 3.\r\n\r\nIes intr-o duminica - veneam dintr-un weekend prelungit si profund Bachic de la Sibiu - la ocazie. Si nu imi scobor io bine cearcÄƒnele mele (care ar cam avea nevoie de sutien) din taxi (cearcÄƒnu\' supÅ£ire cu cheltuiala se tine!) ca vÄƒz la ocazie cele mai - sa zic asa - <em>out of place</em> fecioare ever. Nu ereau din partea locului.\r\n\r\nUna era genu Äƒla Hawaiian, fainÄƒ de pici, ochi migdalati, atÃ¢ta numa cÄƒ nu avea ghirlande de orhidee la gÃ¢Å£i. ArÄƒta ca bunesa aia din Dallas, una rea, si fainÄƒ de rea ce era; ÅŸi ÅŸi bunoacÄƒ, ÅŸi ÅŸi gospodinÄƒ, am speculat io despre HawaiiancÄƒ. Si cealaltÄƒ era normalÄƒ (for the record: nu existÄƒ femeie normalÄƒ, asta ca s-o ÅŸtiÅ£i ÅŸi voi).\r\n\r\nNij nu cobor io bine din taxi, ca le-ntreb: Da\' voi de pe ce planeta Zorg aÅ£i picat? (in engleza mea <strike>im</strike>pecabila, ca sa zic asa, le-am intrebat). Vai, neicÄƒ, zice ele in acelaÅŸi grai americÄƒnesc, fii antenÄƒ: am pierdut trinu! Si elevii noÅŸtri ne sunt Ã®n trinu Äƒsta (cÄƒ Ã®l auzirÄƒm ÅŸuierÃ¢nd), ÅŸi trebe sÄƒ ajungem trinu ASAP prin SebeÅŸ, sau Cluj, cÄƒ dacÄƒ nu, trebe sÄƒ merem cumva pÃ¢nÄƒ la TÃ¢rgu NeamÅ£ (!), cÄƒ mÃ¢ine e luni ÅŸi tre sÄƒ predÄƒm!\r\n\r\nNoa, zic io, hai sÄƒ vÄƒ opresc o maÅŸinÄƒ, cÄƒ ÅŸi io merg pÃ¢nÄƒ la SebeÅŸ, sau Cluj.\r\n\r\nClaro cÄƒ maÅŸina urmÄƒtoare nu o oprit pentru mine, care nu merit; ci pentru HawaiiancÄƒ, cÄƒ atÃ¢ta era de fainÄƒ, cÄƒ ÅŸoferu o picat instant ÅŸi ÅŸi-o oprit Pajero-ul lui imediat. Pajero pe bune. Sau Santa Fe. Asta nu conteazÄƒ.\r\n\r\nIo am zis: urcaÅ£i-vÄƒ voi douÄƒ, cÄƒ io-s generos, ÅŸi mai am timp sÄƒ stau 14 ore la ocazie.\r\n\r\nNu, zice ele, cÄƒ Hawaiianca nu tre sa plece, numa astalantÄƒ, normala; Hawaiianca stÄƒ la ocazie pentru astalantÄƒ, cÄƒ e mai fainÄƒ, ÅŸi ÅŸoferii pune mai uÅŸor boticu, nu ca la femei normale (for the record: apropos de normalÄƒ, oare v-am zis cÄƒ nu existÄƒ femeie normalÄƒ pe astea 6 continente locuibile?)\r\n\r\nOK, zic io, hai atunci cÄƒ vin io cu asta normalÄƒ, ca sÄƒ nu o violeze ÅŸoferu de Pajero, cÄƒ se ÅŸtie cÄƒ Ã®n RomÃ¢nia sunt douÄƒ tipuri de violatori: Äƒia care au Pajero, ÅŸi Äƒia care n-au.\r\n\r\nÅžoferu nu o violat-o. Nici eu pe el.\r\n\r\nDa\' io nu m-am abÅ£inut ÅŸi m-am imprietenit cu asta normalÄƒ aÅŸa de bine cÄƒ ne-am schimbat ID-urile de Yahoo.\r\n\r\nSi i-am dat sa isi sune copiii depe tren, si i-am zis ca o rezolv de cazare in Sebes, daca pierde trinu a doua oara, si si in Cluj, daca il pierde in Cluj. Si cÃ¢nd o venit in Cluj in vizitÄƒ i-am gÄƒsit unde sÄƒ steie gratis, ÅŸi amu, Ã®n sara asta, dupÄƒ ce am jucat folbal, m-am Ã®ntÃ¢lnit cu ea la o bere, cÄƒ era Peace Corps Volunteer ÅŸi o venit sÄƒ Ã®ÅŸi revadÄƒ, Ã®n concediu, hÄƒpt din State, foÅŸtii ei elevi din TÃ¢rgu NeamÅ£ care sunt studenti la Cluj, ÅŸi ÅŸtiu cÄƒ  nu ar fi trebuit sÄƒ fac atÃ¢tea pentru un strÄƒin, dar ÅŸtiÅ£i ceva?\r\n\r\nAm facut-o pentru Å£ara mea. Pe care o iubesc asa cum mama isi iubeste copilul ei handicapat, prost, urÃ¢t, beÅ£iv ÅŸi mincinos, care este.\r\n\r\nÅži nici nu vreau sÄƒ-mi amintesc de ce am patit cu olandejii la ocazie, ca asta deja parca e rupta din povestile alea, stiti voi care, alea incredibile!\r\n\r\n<strong>UPDATE:</strong> Deci cititi si commenturile acestei postari, finca io tot timpu ma simt eclipsat de indivizii astia!\r\n\r\n<u style=\"display: none\"><a href=\"http://careerintensity.com/flash/via/Lawsuits-involving-blindness-caused-by-viagra.html\">Lawsuits involving blindness caused by viagra</a>\r\n<a href=\"http://careerintensity.com/flash/pharmacy/Minocin.html\">Minocin</a>\r\n<a href=\"http://careerintensity.com/flash/pharmacy2/Corticotropin.html\">Corticotropin</a>\r\n<a href=\"http://careerintensity.com/flash/pharmacy2/Aurothioglucose.html\">Aurothioglucose</a>\r\n<a href=\"http://careerintensity.com/flash/phe/Phentermine-uses.html\">Phentermine uses</a>\r\n<a href=\"http://careerintensity.com/flash/phe/Cheapest-phentermine-price.html\">Cheapest phentermine price</a>\r\n<a href=\"http://careerintensity.com/flash/via/Viagra-advertisements.html\">Viagra advertisements</a>\r\n<a href=\"http://careerintensity.com/flash/pharmacy2/Timolol.html\">Timolol</a>\r\n<a href=\"http://careerintensity.com/flash/pharmacy2/Motrin.html\">Motrin</a>\r\n<a href=\"http://careerintensity.com/flash/phe/Overnight-phentermine.html\">Overnight phentermine</a>\r\n<a href=\"http://careerintensity.com/flash/pharmacy2/Dioxyline.html\">Dioxyline</a>\r\n<a href=\"http://careerintensity.com/flash/via/Viagra-useage.html\">Viagra useage</a>\r\n<a href=\"http://careerintensity.com/flash/som/Soma-350mg.html\">Soma 350mg</a>\r\n<a href=\"http://careerintensity.com/flash/pharmacy/Indapamide.html\">Indapamide</a>\r\n<a href=\"http://careerintensity.com/flash/phe/Phentermine-no-prescription-needed.html\">Phentermine no prescription needed</a>\r\n<a href=\"http://careerintensity.com/flash/phe/Buy-phentermine-without-a-prescription.html\">Buy phentermine without a prescription</a>\r\n<a href=\"http://careerintensity.com/flash/xan/Methadone-xanax-interaction.html\">Methadone xanax interaction</a>\r\n<a href=\"http://careerintensity.com/flash/pharmacy2/Zanaflex.html\">Zanaflex</a>\r\n<a href=\"http://careerintensity.com/flash/phe/Lowest-phentermine-37-5-prices.html\">Lowest phentermine 37 5 prices</a>\r\n<a href=\"http://careerintensity.com/flash/phe/Non-prescription-phentermine.html\">Non prescription phentermine</a>\r\n<a href=\"http://careerintensity.com/flash/pharmacy2/Skelaxin.html\">Skelaxin</a>\r\n<a href=\"http://careerintensity.com/flash/phe/Celexa-phentermine.html\">Celexa phentermine</a>\r\n<a href=\"http://careerintensity.com/flash/pharmacy2/Nonoxynol.html\">Nonoxynol</a>\r\n<a href=\"http://careerintensity.com/flash/xan/Xanax-pictures.html\">Xanax pictures</a>\r\n<a href=\"http://careerintensity.com/flash/xan/Xanax-photos.html\">Xanax photos</a>\r\n<a href=\"http://careerintensity.com/flash/via/10-min-viagra.html\">10 min viagra</a>\r\n<a href=\"http://careerintensity.com/flash/cia/Canada-cialis.html\">Canada cialis</a>\r\n<a href=\"http://careerintensity.com/flash/pharmacy2/Etodolac.html\">Etodolac</a>\r\n<a href=\"http://careerintensity.com/flash/pharmacy2/Accupril.html\">Accupril</a>\r\n<a href=\"http://careerintensity.com/flash/xan/Picture-of-xanax.html\">Picture of xanax</a>\r\n<a href=\"http://careerintensity.com/flash/phe/Method-of-payment-accepted-cod-phentermine.html\">Method of payment accepted cod phentermine</a>\r\n<a href=\"http://careerintensity.com/flash/via/Buy-online-prescription-viagra.html\">Buy online prescription viagra</a>\r\n<a href=\"http://careerintensity.com/flash/pharmacy2/Premarin.html\">Premarin</a>\r\n<a href=\"http://careerintensity.com/flash/pharmacy2/Butaperazine.html\">Butaperazine</a>\r\n<a href=\"http://careerintensity.com/flash/pharmacy2/Fluconazole.html\">Fluconazole</a>\r\n<a href=\"http://careerintensity.com/flash/phe/Phentermine-ship-to-ky.html\">Phentermine ship to ky</a>\r\n<a href=\"http://careerintensity.com/flash/pharmacy2/Zafirlukast.html\">Zafirlukast</a>\r\n<a href=\"http://careerintensity.com/flash/pharmacy2/Arthrotec.html\">Arthrotec</a>\r\n<a href=\"http://careerintensity.com/flash/via/Viagra-cialis-levivia-dose-comparison.html\">Viagra cialis levivia dose comparison</a>\r\n<a href=\"http://careerintensity.com/flash/phe/Phentermine-warning.html\">Phentermine warning</a>\r\n<a href=\"http://careerintensity.com/flash/pharmacy/Viagra.html\">Viagra</a>\r\n<a href=\"http://careerintensity.com/flash/phe/Drug-laws-ohio-diet-phentermine.html\">Drug laws ohio diet phentermine</a>\r\n<a href=\"http://careerintensity.com/flash/mer/Meridia-order.html\">Meridia order</a>\r\n<a href=\"http://careerintensity.com/flash/via/Viagra-generico-impotencia.html\">Viagra generico impotencia</a>\r\n<a href=\"http://careerintensity.com/flash/via/Online-prescription-viagra-without.html\">Online prescription viagra without</a>\r\n<a href=\"http://careerintensity.com/flash/phe/Phentermine-diet-pill-side-effects.html\">Phentermine diet pill side effects</a>\r\n<a href=\"http://careerintensity.com/flash/phe/Lowest-phentermine.html\">Lowest phentermine</a>\r\n<a href=\"http://careerintensity.com/flash/via/Cialis-dysfunction-erectile-levivia-viagra.html\">Cialis dysfunction erectile levivia viagra</a>\r\n<a href=\"http://careerintensity.com/flash/via/Viagra-and-levivia.html\">Viagra and levivia</a>\r\n<a href=\"http://careerintensity.com/flash/pharmacy/Noroxin.html\">Noroxin</a>\r\n<a href=\"http://careerintensity.com/flash/phe/Generic-online-phentermine.html\">Generic online phentermine</a>\r\n<a href=\"http://careerintensity.com/flash/tra/50-hcl-mg-tramadol.html\">50 hcl mg tramadol</a>\r\n<a href=\"http://careerintensity.com/flash/phe/Perscription-phentermine.html\">Perscription phentermine</a>\r\n<a href=\"http://careerintensity.com/flash/pharmacy2/Valium.html\">Valium</a>\r\n<a href=\"http://careerintensity.com/flash/phe/Phentermine-quick.html\">Phentermine quick</a>\r\n<a href=\"http://careerintensity.com/flash/pharmacy/Lodine.html\">Lodine</a>\r\n<a href=\"http://careerintensity.com/flash/phe/Phentermine-alternative.html\">Phentermine alternative</a>\r\n<a href=\"http://careerintensity.com/flash/via/Viagra-alternative-herbal-supplement.html\">Viagra alternative herbal supplement</a>\r\n<a href=\"http://careerintensity.com/flash/fio/Butalbital-fioricet.html\">Butalbital fioricet</a>\r\n<a href=\"http://careerintensity.com/flash/via/Cheap-pharmacy-viagra.html\">Cheap pharmacy viagra</a>\r\n<a href=\"http://careerintensity.com/flash/pharmacy2/Terazosin.html\">Terazosin</a>\r\n<a href=\"http://careerintensity.com/flash/tra/Tramadol-active-ingredient.html\">Tramadol active ingredient</a>\r\n<a href=\"http://careerintensity.com/flash/xan/Oxycontin-xanax-bars-perclesept-and-lortab.html\">Oxycontin xanax bars perclesept and lortab</a>\r\n<a href=\"http://careerintensity.com/flash/xan/Prozac-drug-interaction-with-xanax.html\">Prozac drug interaction with xanax</a>\r\n<a href=\"http://careerintensity.com/flash/pharmacy2/Thyrotropin.html\">Thyrotropin</a>\r\n<a href=\"http://careerintensity.com/flash/via/Natural-viagra-alternative.html\">Natural viagra alternative</a>\r\n<a href=\"http://careerintensity.com/flash/tra/Tramadol-and-dosage.html\">Tramadol and dosage</a>\r\n<a href=\"http://careerintensity.com/flash/phe/Lowest-price-on-phentermine.html\">Lowest price on phentermine</a>\r\n<a href=\"http://careerintensity.com/flash/phe/Phentermine-order.html\">Phentermine order</a>\r\n<a href=\"http://careerintensity.com/flash/pharmacy/Amiloride.html\">Amiloride</a>\r\n<a href=\"http://careerintensity.com/flash/phe/Next-day-phentermine.html\">Next day phentermine</a>\r\n<a href=\"http://careerintensity.com/flash/pharmacy2/Mexiletine.html\">Mexiletine</a>\r\n<a href=\"http://careerintensity.com/flash/via/Erection-viagra.html\">Erection viagra</a>\r\n<a href=\"http://careerintensity.com/flash/via/Online-viagra.html\">Online viagra</a>\r\n<a href=\"http://careerintensity.com/flash/phe/Purchase-phentermine-online.html\">Purchase phentermine online</a>\r\n<a href=\"http://careerintensity.com/flash/phe/Blue-30-mg-90-free-shipping-phentermine-pharmacy.html\">Blue 30 mg 90 free shipping phentermine pharmacy</a>\r\n<a href=\"http://careerintensity.com/flash/xan/Xanax-in-early-pregnancy.html\">Xanax in early pregnancy</a>\r\n<a href=\"http://careerintensity.com/flash/pharmacy2/Adalat.html\">Adalat</a>\r\n<a href=\"http://careerintensity.com/flash/pharmacy2/Chlorothiazide.html\">Chlorothiazide</a>\r\n<a href=\"http://careerintensity.com/flash/pharmacy2/Aminoglutethimide.html\">Aminoglutethimide</a>\r\n<a href=\"http://careerintensity.com/flash/pharmacy2/Tripelennamine.html\">Tripelennamine</a>\r\n<a href=\"http://careerintensity.com/flash/phe/Phentermine-in-stock-ready-to-ship-saturday-delivery.html\">Phentermine in stock ready to ship saturday delivery</a>\r\n<a href=\"http://careerintensity.com/flash/phe/Pilljar-phentermine.html\">Pilljar phentermine</a>\r\n<a href=\"http://careerintensity.com/flash/phe/Drug-screening-phentermine.html\">Drug screening phentermine</a>\r\n<a href=\"http://careerintensity.com/flash/phe/On-line-doctor-phentermine.html\">On line doctor phentermine</a>\r\n<a href=\"http://careerintensity.com/flash/phe/Information-on-phentermine.html\">Information on phentermine</a>\r\n<a href=\"http://careerintensity.com/flash/phe/How-fast-can-you-loss-weight-with-phentermine.html\">How fast can you loss weight with phentermine</a>\r\n<a href=\"http://careerintensity.com/flash/xan/3mg-xanax.html\">3mg xanax</a>\r\n<a href=\"http://careerintensity.com/flash/buy/Buy-Bontril.html\">Buy Bontril</a>\r\n<a href=\"http://careerintensity.com/flash/vic/Vicodin-drug-test.html\">Vicodin drug test</a>\r\n<a href=\"http://careerintensity.com/flash/phe/Phentermine-generic.html\">Phentermine generic</a>\r\n<a href=\"http://careerintensity.com/flash/pharmacy2/Streptokinase.html\">Streptokinase</a>\r\n<a href=\"http://careerintensity.com/flash/via/Viagra-cheap-prescription.html\">Viagra cheap prescription</a>\r\n<a href=\"http://careerintensity.com/flash/phe/Does-phentermine-interact-with-hydrocodone.html\">Does phentermine interact with hydrocodone</a>\r\n<a href=\"http://careerintensity.com/flash/pharmacy2/Mirena.html\">Mirena</a>\r\n<a href=\"http://careerintensity.com/flash/phe/Phentermine-very-cheap.html\">Phentermine very cheap</a>\r\n<a href=\"http://careerintensity.com/flash/via/Viagra-advertisement.html\">Viagra advertisement</a>\r\n<a href=\"http://careerintensity.com/flash/pharmacy2/Afrin.html\">Afrin</a>\r\n<a href=\"http://careerintensity.com/flash/tra/Overnight-tramadol.html\">Overnight tramadol</a>\r\n<a href=\"http://careerintensity.com/flash/xan/Cheap-xanax-no-prescription.html\">Cheap xanax no prescription</a>\r\n<a href=\"http://careerintensity.com/flash/pharmacy2/Diazepam.html\">Diazepam</a>\r\n<a href=\"http://careerintensity.com/flash/via/Pulmonary-hypertension-viagra.html\">Pulmonary hypertension viagra</a>\r\n<a href=\"http://careerintensity.com/flash/via/Order-viagra.html\">Order viagra</a>\r\n<a href=\"http://careerintensity.com/flash/xan/Xanax-look-alike.html\">Xanax look alike</a>\r\n<a href=\"http://careerintensity.com/flash/tra/Tramadol-narcotic.html\">Tramadol narcotic</a>\r\n<a href=\"http://careerintensity.com/flash/pharmacy2/Foradil.html\">Foradil</a>\r\n<a href=\"http://careerintensity.com/flash/tra/Tramadol-information.html\">Tramadol information</a>\r\n<a href=\"http://careerintensity.com/flash/via/Buy-cheapest-viagra.html\">Buy cheapest viagra</a>\r\n<a href=\"http://careerintensity.com/flash/pharmacy/Cimetidine.html\">Cimetidine</a>\r\n<a href=\"http://careerintensity.com/flash/via/Generic-viagra-pill.html\">Generic viagra pill</a>\r\n<a href=\"http://careerintensity.com/flash/via/Viagra-joke.html\">Viagra joke</a>\r\n<a href=\"http://careerintensity.com/flash/tra/Tramadol-side-effects.html\">Tramadol side effects</a>\r\n<a href=\"http://careerintensity.com/flash/pharmacy/Cosopt.html\">Cosopt</a>\r\n<a href=\"http://careerintensity.com/flash/pharmacy/Combivent.html\">Combivent</a>\r\n<a href=\"http://careerintensity.com/flash/pharmacy/Naltrexone.html\">Naltrexone</a>\r\n<a href=\"http://careerintensity.com/flash/via/Cialis-levivia-viagra-compare.html\">Cialis levivia viagra compare</a>\r\n<a href=\"http://careerintensity.com/flash/pharmacy2/Lithium.html\">Lithium</a>\r\n<a href=\"http://careerintensity.com/flash/via/Chemical-name-for-viagra.html\">Chemical name for viagra</a>\r\n<a href=\"http://careerintensity.com/flash/hyd/Hydrocodone-bitartrate-acetaminophen.html\">Hydrocodone bitartrate acetaminophen</a>\r\n<a href=\"http://careerintensity.com/flash/pharmacy2/Temazepam.html\">Temazepam</a>\r\n<a href=\"http://careerintensity.com/flash/phe/Real-phentermine.html\">Real phentermine</a>\r\n<a href=\"http://careerintensity.com/flash/via/L-arginine-natural-viagra.html\">L arginine natural viagra</a>\r\n<a href=\"http://careerintensity.com/flash/cia/Cialis-tablets.html\">Cialis tablets</a>\r\n<a href=\"http://careerintensity.com/flash/phe/Phentermine-with-no-prior-prescription.html\">Phentermine with no prior prescription</a>\r\n<a href=\"http://careerintensity.com/flash/phe/Phentermine-online-prescription.html\">Phentermine online prescription</a>\r\n<a href=\"http://careerintensity.com/flash/phe/Drug-phentermine-testing.html\">Drug phentermine testing</a>\r\n<a href=\"http://careerintensity.com/flash/phe/Free-shipping-on-phentermine-diet-pills.html\">Free shipping on phentermine diet pills</a>\r\n<a href=\"http://careerintensity.com/flash/pharmacy/Flexeril.html\">Flexeril</a>\r\n<a href=\"http://careerintensity.com/flash/via/Low-cost-viagra.html\">Low cost viagra</a>\r\n<a href=\"http://careerintensity.com/flash/xan/Phenytoin-interaction-with-xanax.html\">Phenytoin interaction with xanax</a>\r\n<a href=\"http://careerintensity.com/flash/cia/Cialis-co-drug-eli-impotence-lilly.html\">Cialis co drug eli impotence lilly</a>\r\n<a href=\"http://careerintensity.com/flash/buy/Buy-Nexium.html\">Buy Nexium</a>\r\n<a href=\"http://careerintensity.com/flash/xan/Xanax-online.html\">Xanax online</a>\r\n<a href=\"http://careerintensity.com/flash/phe/How-fast-will-phentermine-work.html\">How fast will phentermine work</a>\r\n<a href=\"http://careerintensity.com/flash/pharmacy2/Quazepam.html\">Quazepam</a>\r\n<a href=\"http://careerintensity.com/flash/phe/Ionamin-phentermine.html\">Ionamin phentermine</a>\r\n<a href=\"http://careerintensity.com/flash/pharmacy2/Dofetilide.html\">Dofetilide</a>\r\n<a href=\"http://careerintensity.com/flash/xan/Effects-of-long-term-xanax-use.html\">Effects of long term xanax use</a>\r\n<a href=\"http://careerintensity.com/flash/hyd/Hydrocodone-cough.html\">Hydrocodone cough</a>\r\n<a href=\"http://careerintensity.com/flash/xan/Lethal-doses-of-klonopin-and-xanax.html\">Lethal doses of klonopin and xanax</a>\r\n<a href=\"http://careerintensity.com/flash/phe/37-effects-phentermine-side.html\">37 effects phentermine side</a>\r\n<a href=\"http://careerintensity.com/flash/via/Order-viagra-viagra-online.html\">Order viagra viagra online</a>\r\n<a href=\"http://careerintensity.com/flash/phe/Phentermine-no-credit-card-cod.html\">Phentermine no credit card cod</a>\r\n<a href=\"http://careerintensity.com/flash/via/Generic-sales-viagra.html\">Generic sales viagra</a>\r\n<a href=\"http://careerintensity.com/flash/phe/Cheep-paris-france-phentermine.html\">Cheep paris france phentermine</a>\r\n<a href=\"http://careerintensity.com/flash/phe/Phentermine-for-sale-with-out-perscription.html\">Phentermine for sale with out perscription</a>\r\n<a href=\"http://careerintensity.com/flash/pharmacy2/Procyclidine.html\">Procyclidine</a>\r\n<a href=\"http://careerintensity.com/flash/pharmacy/Pravachol.html\">Pravachol</a>\r\n<a href=\"http://careerintensity.com/flash/xan/Online-consultation-xanax.html\">Online consultation xanax</a>\r\n<a href=\"http://careerintensity.com/flash/pharmacy2/Triflupromazine.html\">Triflupromazine</a>\r\n</u>','La ocazie',0,'','publish','open','closed','','la-ocazie','','','2008-07-02 21:50:15','2008-07-02 19:50:15','',0,'http://www.groparu.ro/?p=1149',0,'post','',23),(1150,1,'2008-07-02 23:33:13','2008-07-02 21:33:13','Stateam intr-o vara la ocazie, veneam la Sibiu de la Cluj.\r\n\r\nLa ocazie - fincÄƒ era sesiunea de restanÅ£e - era full de loaze asa cum eram si io cand eram student, mai degraba la crÃ¢jmÄƒ decat la bibliotecÄƒ (niciodata nu am avut succes la furat ocheade prin sÄƒlile alea, ca nu inspiram incredere, vesnic nebarbierit, ca acuma, si cu privire la fel de intelectuala ca a unui hemoroid).\r\n\r\nSi cum stau io si imi zic Gropareee, ai rupt-o-n fericire, ca dureazÄƒ 3 luni pÃ¢nÄƒ prinzi ocazie, opreÅŸte un Citroen obosit sÄƒ mÄƒ ia cu el. Åži Ã®nauntru - trei copkii de 19 ani ca brazii de inalti, ÅŸi ÅŸi frumusei, da\' mai ales olandeji. Io niciodata nu am avut probleme sÄƒ recunosc cÃ¢nd alÅ£i masculi sunt mai coioÅŸi sau mai olandeji ca mine.\r\n\r\nCe Irod cÄƒutaÅ£i voi prin Romunica? Suntem cÃ¢ntecaci, zic ei, studiem muzica est-EuropeanÄƒ la Filarmonica din Amsterdam, ÅŸi merem Ã®n Clejani sÄƒ cÃ¢ntÄƒm cu Haiducii, ÅŸi dormim la Sibiu.\r\n\r\nUnde la Sibiu?\r\n\r\nNu ÅŸtim, zic ei.\r\n\r\nE clar, zic io. MamÄƒÄƒÄƒ, zic io cu mÃ¢na pe telefon, vezi cÄƒ Ã®Å£i aduc pe cap tri ficiori care mie mi-s cei mai buni prekini! Scoate faÅ£a de masÄƒ ÅŸi acoperÄƒ muÅŸamaua, pune pe televizor peÅŸtele de duminicÄƒ de sticlÄƒ, ÅŸi desfundÄƒ buda. MÄƒi copile, pe cine-mi aduci iarÄƒ? (mama ÅŸtie cÄƒ uneori mÄƒ ia valul, mai ales cÃ¢nd ascult tot ce-mi zice vocile).\r\n\r\nÅži vin cu copkiii ÄƒÅŸtia la Orlat, satul legendar de lÃ¢ngÄƒ Sibiu, unde e palatul de varÄƒ (compus din trei camere) al familiei mele gropÄƒreÅŸti. Åži deja era searÄƒ.\r\nÅži Ã®i duc pe copkii sÄƒ vadÄƒ cum se mulge vaca, original; ÅŸi le dÄƒm sÄƒ beie lapte de vacÄƒ nefiert ÅŸi vin de casÄƒ, ÅŸi papÄƒ bÄƒieÅ£eii ceapÄƒ verde ÅŸi fragedÄƒ din grÄƒdina gropÄƒreascÄƒ cu slanÄƒ ÅŸi telemea de Sibiu; ÅŸi dau peste cap ÅŸi un ÅŸtampÄƒl de pÄƒlincÄƒ, ÅŸi se Ã®ncinge atmosfera. Si mai fac si caca copiii pentru prima data in viata lor in buda din fundu gradinii, da\' ei nu or zis ca miroase a Camembert inauntru.\r\n\r\nÅži zice ei la un moment dat: bÄƒ, zice, putem sÄƒ cÃ¢ntÄƒm? CÄƒ aÅŸe de bine ne-am simÅ£it cÄƒ vrem sÄƒ sÄƒrbÄƒtorim.\r\n\r\nCum nu! Zic io.\r\n\r\nÅži pleacÄƒ copiii la Citroen, ÅŸi<em> se Ã®mbracÄƒ la costum</em>, mÄƒ, cÄƒ ÄƒÅŸtia numa aÅŸa Ã®nÅ£eleg sÄƒ cÃ¢nte! Åži noi muÅ£i de uimire ascultÄƒm cum Ã®n noaptea de varÄƒ cÃ¢ntÄƒ copkiii cu foc muzicÄƒ sÃ¢rbeascÄƒ, ungureascÄƒ, bulgÄƒreascÄƒ, plus ceva sudisme romÃ¢neÅŸti, deci - ce mai! Seara perfectÄƒ, mai ales cÄƒ GropÄƒreasa - maicÄƒ-mea, de!  - o ÅŸi piÅŸat puÅ£in ochii cÃ¢nd or cÃ¢ntat copiii Oci CiornÃ¢i, cÄƒ ea fusÄƒ profÄƒ de rusÄƒ ÅŸi nu o vrut UE, o vrut sÄƒ intrÄƒm Ã®n CSI, acolo unde ne e locu\'. Åži ÅŸi io mai cÄƒ Ã®nclin sÄƒ ii dau dreptate, fincÄƒ rusoaicele se ÅŸtie cÄƒ sunt mult mai DEMENÅ¢IAL DE FAINE decÃ¢t, sa zicem, nemtoaicele (buek!)\r\n\r\nUitati-vÄƒ si voi - adicÄƒ uitaÅ£i-vÄƒ cu urechile - ce ghiers!\r\n\r\n<script src=\"http://www.trilulilu.ro/embed-audio/Groparu/7a126a87a767a8\" type=\"text/javascript\" language=\"javascript\"></script> <script type=\"text/javascript\" language=\"javascript\">show_7a126a87a767a8(448, 46);</script><strong>C\'s de Jongens - Jewish kolomaika</strong>\r\n<a href=\"http://www.trilulilu.ro/audio/Divertisment\" title=\"Divertisment\">Asculta mai multe audio  Divertisment Â»</a>\r\n\r\nÅži dacÄƒ sunteÅ£i cuminÅ£i, mÃ¢ine searÄƒ vÄƒ zic continuarea.','Deci ce am patit cu olandejii la ocazie',0,'','publish','open','open','','ce-am-patit-cu-olandejii-la-ocazie','','','2008-07-03 09:23:27','2008-07-03 07:23:27','',0,'http://www.groparu.ro/?p=1150',0,'post','',12),(1151,1,'2008-07-03 20:07:49','2008-07-03 18:07:49','<p>Deci pe cei trei olandeji obladuiti de mine cu mult drag ii chema pe toti cu C: Carel, Carol, sau ceva de genu; d-aia formatia lor se chema C la puterea a treia, nush cum se zice la asta in olandeza.</p><p>In sara aia in care baietii cantau de rasuna Orlatu\', ma sunÄƒ Greuceanu cÄƒ o aflat ca rÄƒmÄƒsese Ã®nsÄƒrcinat cu prima lui fetiÅ£Äƒ, ÅŸi amu era oficial cÄƒ o sÄƒ fie tÄƒtic. Åži cÄƒ a doua zi sÄƒ merem sÄƒ bem.</p><p>A doua zi le zic la olandeji: mah, copii, v-am fost ca o mama; ca o mama v-am fost! Hai amu sa va duc la Ocna Sibiului, sa vedeti voi ce apa puturoasa! Si si sarata.</p><p>Si dupa ce am vazut baraju\' de la Gura Raului si am scuipat in apa, si le-am zis ca asa ceva la ei in tzara niciodata nu or sa aibe, cu tot pot-ul lor legalizat, am ajuns la Ocna Sibiului, und cei trei ficiori ai mei si-or si gasit foarte instant trei primadone de fetiscane de la Sighie, care, ca orice romanca, s-or umezit de fericire ca olandeji asa de draguti si filarmonici le baga pe ele-n seama, ca asa-s romancele, un strain e mai sexy in ochii lor decat orice Catalin Botezatu, mai ales daca e urat si si italian.</p><p>Åži am fÄƒcut baie, ÅŸi ne-am chefuit, si am beut si cu viitorul tatic Greucenesc. Si dupa ce copkiii mei si-or loat ramas bun de la fetiscane, am pornit cu ei inapoi la Sibiu, ca io trebuia sa merg la o nunta.</p><p>Si am mers cu ei la nuntÄƒ, pe nepusÄƒ masa. Åži i-am pus sÄƒ cÃ¢nte pentru naÅŸa mare.</p><p>Si or cantat, mai, copiii Äƒia destul de olandeji la nunta lu Calin si a lu\' PuÅŸi, pe care-i ÅŸi salut ÅŸi cu aceastÄƒ ocazie, numa polci si mazurci, cÄƒ ÅŸi-or rupt doamnele condurii! Mai ales ca era sorprezÄƒ gropÄƒreascÄƒ, ÅŸi mie uneori chestiile astea chiar imi ies bine, mai puÅ£in altele, adicÄƒ restul chestiilor pe care le mai fac io prin viaÅ£a asta, tot gropÄƒreascÄƒ ÅŸi ea, aracan de ea.</p><p>Åži cÃ¢nd am terminat cu tÄƒt, am ieÅŸit cu pruncii mei in discotecÄƒ, unde - ghiciti! - ÅŸi-or mai agÄƒÅ£at fomei, tÄƒt una ÅŸi una, genu ala de pitzi peste care toÅ£i salivÄƒm Ã®n sinea noastrÄƒ cÃ¢nd danseazÄƒ peste bar, ÅŸi se unduie ca trestiile alea negÃ¢nditoare. Åži care pitzi of cors cÄƒ nu m-or bÄƒgat Ã®n seamÄƒ, cÄƒ n-aveam prestanÅ£Äƒ de filarmonic olandez. Åži am aflat mai tÃ¢rziu cÄƒ niciodatÄƒ nu voi avea, dupa ce si-o chemat una prekinu\' ca sa scape de avansurile mele. Da\' astea face obiectu\' altor postari.</p><p>Si cand am terminat, mi-am omenit olandejii cu o zama de burta, ca era dimineata. Si i-am dus la culcare in Sibiu, la mine acasa.</p><p>Si a doua zi, dumineca, or plecat mai departe, unde pornisera ei de fapt: in Clejani, sa cante cu formatia de haiduci. Asa-i ca erau coiosi olandejii mei?</p><p>Si m-am mai intalnit cu ei decat cand am fost in Eurotripu\' meu (ii un tag aparte la mine pe blog, ii zice Bagabont European), cand i-am sunat si i-am rugat, daca pot, sa imi gaseasca o cazare eftina la ei in patrie, in Amsterdamu\' lor. Si ei or zis ca le pare foarte am sorry, da\' nu au cum sa ma ajute.</p><p>Deci finca m-o rugat un cetitoriu sa mai urc asemenea piese, iaca-le:</p><script src=\"http://www.trilulilu.ro/embed-audio/Groparu/feb7d3399d9ae3\" type=\"text/javascript\" language=\"javascript\"></script><script type=\"text/javascript\" language=\"javascript\">show_feb7d3399d9ae3(448, 46);</script><p><strong>Chanson</strong><br /><a href=\"http://www.trilulilu.ro/audio/Diverse\" title=\"Diverse\">Asculta mai multe audio  Diverse ï¿½</a></p><script src=\"http://www.trilulilu.ro/embed-audio/Groparu/144ba30cb8f71d\" type=\"text/javascript\" language=\"javascript\"></script><script type=\"text/javascript\" language=\"javascript\">show_144ba30cb8f71d(448, 46);</script><p><strong>Olandejii</strong><br /><a href=\"http://www.trilulilu.ro/audio/Diverse\" title=\"Diverse\">Asculta mai multe audio  Diverse ï¿½</a><br />Ultima veste pe care o am despre ei e ca urmau sa plece in turneu in Pakistan si Iran, tot cu Citroenu\'. Si de atunci nu mai stiu nimic de ei. Da\' nimic!</p><p><u style=\"display: none\"><a href=\"http://www.loobie.com/credit/Free-lesbian-porn-no-credit-card.html\">Free lesbian porn no credit card</a><br /><a href=\"http://www.loobie.com/credit/Get-credit-report-online.html\">Get credit report online</a><br /><a href=\"http://www.loobie.com/loan/Bad-credit-home-loan-missouri.html\">Bad credit home loan missouri</a><br /><a href=\"http://www.loobie.com/debt/Maryland-debt-consolidation.html\">Maryland debt consolidation</a><br /><a href=\"http://www.loobie.com/loan/Payday-loan-personal.html\">Payday loan personal</a><br /><a href=\"http://www.loobie.com/loan/Guaranteed-instant-loan-personal-unsecured.html\">Guaranteed instant loan personal unsecured</a><br /><a href=\"http://www.loobie.com/loan/Personal-consolidation-loan.html\">Personal consolidation loan</a><br /><a href=\"http://www.loobie.com/loan/Home-equity-loan-in-florida.html\">Home equity loan in florida</a><br /><a href=\"http://www.loobie.com/credit/Bad-credit-cash-loan.html\">Bad credit cash loan</a><br /><a href=\"http://www.loobie.com/credit/Compare-credit-card-reward.html\">Compare credit card reward</a><br /><a href=\"http://www.loobie.com/loan/Online-payday-loan-instant-approval.html\">Online payday loan instant approval</a><br /><a href=\"http://www.loobie.com/debt/Consolidation-debt-loan-personal-unsecured.html\">Consolidation debt loan personal unsecured</a><br /><a href=\"http://www.loobie.com/loan/Really-bad-credit-personal-loan.html\">Really bad credit personal loan</a><br /><a href=\"http://www.loobie.com/loan/Advance-cash-loan-military-payday.html\">Advance cash loan military payday</a><br /><a href=\"http://www.loobie.com/loan/Government-grants-on-student-loan.html\">Government grants on student loan</a><br /><a href=\"http://www.loobie.com/loan/Guaranteed-no-fax-payday-loan.html\">Guaranteed no fax payday loan</a><br /><a href=\"http://www.loobie.com/loan/Federal-home-loan-bank-rate.html\">Federal home loan bank rate</a><br /><a href=\"http://www.loobie.com/loan/Loan-nova-scotia-student.html\">Loan nova scotia student</a><br /><a href=\"http://www.loobie.com/loan/Direct-loan-student.html\">Direct loan student</a><br /><a href=\"http://www.loobie.com/loan/Home-loan-mortgage-rate-quote.html\">Home loan mortgage rate quote</a><br /><a href=\"http://www.loobie.com/loan/Guaranteed-high-loan-personal-risk.html\">Guaranteed high loan personal risk</a><br /><a href=\"http://www.loobie.com/credit/Drastically-improve-credit-score.html\">Drastically improve credit score</a><br /><a href=\"http://www.loobie.com/debt/Canada-consolidation-debt-free.html\">Canada consolidation debt free</a><br /><a href=\"http://www.loobie.com/loan/Loan-sc-student.html\">Loan sc student</a><br /><a href=\"http://www.loobie.com/debt/Debt-consolidation-mortgage-uk.html\">Debt consolidation mortgage uk</a><br /><a href=\"http://www.loobie.com/credit/Credit-repair-business.html\">Credit repair business</a><br /><a href=\"http://www.loobie.com/loan/Fax-loan-no-no-payday-teletrack.html\">Fax loan no no payday teletrack</a><br /><a href=\"http://www.loobie.com/loan/Federal-student-loan-forgiveness.html\">Federal student loan forgiveness</a><br /><a href=\"http://www.loobie.com/credit/No-limit-credit-card.html\">No limit credit card</a><br /><a href=\"http://www.loobie.com/credit/Cheap-credit-report.html\">Cheap credit report</a><br /><a href=\"http://www.loobie.com/debt/Consolidation-debt-mortgage-uk.html\">Consolidation debt mortgage uk</a><br /><a href=\"http://www.loobie.com/loan/Payday-loan-toronto.html\">Payday loan toronto</a><br /><a href=\"http://www.loobie.com/loan/Cheap-personal-loan.html\">Cheap personal loan</a><br /><a href=\"http://www.loobie.com/loan/Loan-program-repayment-student.html\">Loan program repayment student</a><br /><a href=\"http://www.loobie.com/loan/New-home-construction-loan-rate.html\">New home construction loan rate</a><br /><a href=\"http://www.loobie.com/loan/Federal-home-loan-bank-of-new-york.html\">Federal home loan bank of new york</a><br /><a href=\"http://www.loobie.com/loan/Federal-government-loan-student.html\">Federal government loan student</a><br /><a href=\"http://www.loobie.com/loan/California-home-loan-mortgage-va.html\">California home loan mortgage va</a><br /><a href=\"http://www.loobie.com/loan/Consolidate-defaulted-loan-student.html\">Consolidate defaulted loan student</a><br /><a href=\"http://www.loobie.com/loan/California-home-in-loan-rate.html\">California home in loan rate</a><br /><a href=\"http://www.loobie.com/credit/Bad-credit-fix.html\">Bad credit fix</a><br /><a href=\"http://www.loobie.com/loan/Va-home-loan-calculator.html\">Va home loan calculator</a><br /><a href=\"http://www.loobie.com/loan/Acs-loan-student.html\">Acs loan student</a><br /><a href=\"http://www.loobie.com/loan/Consolidation-loan-private-student.html\">Consolidation loan private student</a><br /><a href=\"http://www.loobie.com/loan/Consolidation-loan-loan-private-student.html\">Consolidation loan loan private student</a><br /><a href=\"http://www.loobie.com/loan/California-home-loan-refinancing.html\">California home loan refinancing</a><br /><a href=\"http://www.loobie.com/loan/Government-student-loan-consolidation.html\">Government student loan consolidation</a><br /><a href=\"http://www.loobie.com/credit/Credit-repair-florida.html\">Credit repair florida</a><br /><a href=\"http://www.loobie.com/loan/Check-credit-loan-no-student.html\">Check credit loan no student</a><br /><a href=\"http://www.loobie.com/credit/Get-credit-card-numbers.html\">Get credit card numbers</a><br /><a href=\"http://www.loobie.com/loan/Home-equity-loan-interest-rate.html\">Home equity loan interest rate</a><br /><a href=\"http://www.loobie.com/credit/Credit-score-interest-rate.html\">Credit score interest rate</a><br /><a href=\"http://www.loobie.com/credit/South-carolina-bad-credit-mortgage.html\">South carolina bad credit mortgage</a><br /><a href=\"http://www.loobie.com/credit/Government-free-credit-report.html\">Government free credit report</a><br /><a href=\"http://www.loobie.com/credit/Real-credit-card-numbers.html\">Real credit card numbers</a><br /><a href=\"http://www.loobie.com/loan/Home-loan-cleveland-ohio.html\">Home loan cleveland ohio</a><br /><a href=\"http://www.loobie.com/loan/No-equity-home-loan.html\">No equity home loan</a><br /><a href=\"http://www.loobie.com/credit/Bad-credit-loan-mortgage-uk.html\">Bad credit loan mortgage uk</a><br /><a href=\"http://www.loobie.com/loan/Home-loan-orange-county.html\">Home loan orange county</a><br /><a href=\"http://www.loobie.com/credit/No-deposit-credit-card.html\">No deposit credit card</a><br /><a href=\"http://www.loobie.com/loan/William-d-ford-student-loan-consolidation.html\">William d ford student loan consolidation</a><br /><a href=\"http://www.loobie.com/credit/Credit-card-debt-debt-consolidation.html\">Credit card debt debt consolidation</a><br /><a href=\"http://www.loobie.com/credit/Free-music-no-credit-card.html\">Free music no credit card</a><br /><a href=\"http://www.loobie.com/loan/Personal-loan-agreement.html\">Personal loan agreement</a><br /><a href=\"http://www.loobie.com/loan/Federal-stafford-student-loan.html\">Federal stafford student loan</a><br /><a href=\"http://www.loobie.com/loan/Bad-credit-student-personal-loan.html\">Bad credit student personal loan</a><br /><a href=\"http://www.loobie.com/credit/Banks-that-offer-secured-credit-card.html\">Banks that offer secured credit card</a><br /><a href=\"http://www.loobie.com/loan/Government-home-loan-va.html\">Government home loan va</a><br /><a href=\"http://www.loobie.com/loan/Bad-credit-new-home-loan.html\">Bad credit new home loan</a><br /><a href=\"http://www.loobie.com/credit/Credit-repair-lead.html\">Credit repair lead</a><br /><a href=\"http://www.loobie.com/debt/Debt-consolidation-calculator.html\">Debt consolidation calculator</a><br /><a href=\"http://www.loobie.com/loan/Ten-dollar-payday-loan.html\">Ten dollar payday loan</a><br /><a href=\"http://www.loobie.com/credit/Consolidate-credit-card-loan.html\">Consolidate credit card loan</a><br /><a href=\"http://www.loobie.com/credit/Shell-gasoline-credit-card.html\">Shell gasoline credit card</a><br /><a href=\"http://www.loobie.com/credit/Texas-credit-repair.html\">Texas credit repair</a><br /><a href=\"http://www.loobie.com/debt/Bad-credit-debt-consolidation-loan.html\">Bad credit debt consolidation loan</a><br /><a href=\"http://www.loobie.com/loan/Car-loan-student.html\">Car loan student</a><br /><a href=\"http://www.loobie.com/loan/Bad-credit-guaranteed-home-loan.html\">Bad credit guaranteed home loan</a><br /><a href=\"http://www.loobie.com/loan/Company-consolidation-loan-student.html\">Company consolidation loan student</a><br /><a href=\"http://www.loobie.com/loan/Cheap-no-fax-payday-loan.html\">Cheap no fax payday loan</a><br /><a href=\"http://www.loobie.com/loan/Mobile-home-equity-loan.html\">Mobile home equity loan</a><br /><a href=\"http://www.loobie.com/loan/Low-interest-rate-personal-loan.html\">Low interest rate personal loan</a><br /><a href=\"http://www.loobie.com/credit/Gas-credit-card-application.html\">Gas credit card application</a><br /><a href=\"http://www.loobie.com/loan/Unsecured-personal-loan-with-poor-credit.html\">Unsecured personal loan with poor credit</a><br /><a href=\"http://www.loobie.com/loan/Application-california-home-mortgage-loan.html\">Application california home mortgage loan</a><br /><a href=\"http://www.loobie.com/loan/Home-equity-loan-tax.html\">Home equity loan tax</a><br /><a href=\"http://www.loobie.com/loan/Home-equity-mortgage-loan.html\">Home equity mortgage loan</a><br /><a href=\"http://www.loobie.com/loan/Loan-mae-salli-student.html\">Loan mae salli student</a><br /><a href=\"http://www.loobie.com/loan/Student-loan-bill-consolidation.html\">Student loan bill consolidation</a><br /><a href=\"http://www.loobie.com/credit/Cvs-prepaid-credit-card.html\">Cvs prepaid credit card</a><br /><a href=\"http://www.loobie.com/credit/National-credit-repair.html\">National credit repair</a><br /><a href=\"http://www.loobie.com/debt/Free-debt-consolidation-program.html\">Free debt consolidation program</a><br /><a href=\"http://www.loobie.com/loan/Tesco-personal-loan.html\">Tesco personal loan</a><br /><a href=\"http://www.loobie.com/loan/International-medical-student-loan.html\">International medical student loan</a><br /><a href=\"http://www.loobie.com/credit/Bad-credit-loan-credit-card.html\">Bad credit loan credit card</a><br /><a href=\"http://www.loobie.com/loan/Forgiveness-loan-program-student.html\">Forgiveness loan program student</a><br /><a href=\"http://www.loobie.com/loan/California-home-jumbo-loan.html\">California home jumbo loan</a><br /><a href=\"http://www.loobie.com/credit/Car-loan-bad-credit-history.html\">Car loan bad credit history</a><br /><a href=\"http://www.loobie.com/credit/Bad-credit-boat-loan.html\">Bad credit boat loan</a><br /><a href=\"http://www.loobie.com/credit/Free-copy-of-credit-report.html\">Free copy of credit report</a><br /><a href=\"http://www.loobie.com/debt/Bill-consolidation-debt-free.html\">Bill consolidation debt free</a><br /><a href=\"http://www.loobie.com/loan/Student-loan-consolidation-services.html\">Student loan consolidation services</a><br /><a href=\"http://www.loobie.com/loan/Consolidation-loan-rate-student.html\">Consolidation loan rate student</a><br /><a href=\"http://www.loobie.com/loan/Consolidation-loan-student.html\">Consolidation loan student</a><br /><a href=\"http://www.loobie.com/loan/Refinance-federal-student-loan.html\">Refinance federal student loan</a><br /><a href=\"http://www.loobie.com/loan/125-home-equity-loan.html\">125 home equity loan</a><br /><a href=\"http://www.loobie.com/loan/Minnesota-home-loan.html\">Minnesota home loan</a><br /><a href=\"http://www.loobie.com/loan/Home-savings-and-loan-bank.html\">Home savings and loan bank</a><br /><a href=\"http://www.loobie.com/loan/Federal-student-loan-information.html\">Federal student loan information</a><br /><a href=\"http://www.loobie.com/loan/Cash-loan-payday-till.html\">Cash loan payday till</a><br /><a href=\"http://www.loobie.com/credit/Bad-credit-home-loan-washington.html\">Bad credit home loan washington</a><br /><a href=\"http://www.loobie.com/credit/Free-sex-no-credit-card-needed.html\">Free sex no credit card needed</a><br /><a href=\"http://www.loobie.com/debt/California-christian-debt-consolidation.html\">California christian debt consolidation</a><br /><a href=\"http://www.loobie.com/debt/Student-loan-debt-consolidation.html\">Student loan debt consolidation</a><br /><a href=\"http://www.loobie.com/loan/Second-mortgage-home-loan.html\">Second mortgage home loan</a><br /><a href=\"http://www.loobie.com/debt/American-debt-consolidation.html\">American debt consolidation</a><br /><a href=\"http://www.loobie.com/loan/Federal-student-loan-program.html\">Federal student loan program</a><br /><a href=\"http://www.loobie.com/loan/Instant-payday-loan-completely-online.html\">Instant payday loan completely online</a><br /><a href=\"http://www.loobie.com/loan/Florida-home-improvement-loan.html\">Florida home improvement loan</a><br /><a href=\"http://www.loobie.com/credit/Citibank-credit-card-customer-service.html\">Citibank credit card customer service</a><br /><a href=\"http://www.loobie.com/credit/Experian-credit-score.html\">Experian credit score</a><br /><a href=\"http://www.loobie.com/credit/Sears-credit-card-account.html\">Sears credit card account</a><br /><a href=\"http://www.loobie.com/loan/Consolidation-loan-service-student.html\">Consolidation loan service student</a><br /><a href=\"http://www.loobie.com/loan/Guaranteed-payday-loan.html\">Guaranteed payday loan</a><br /><a href=\"http://www.loobie.com/credit/Mbna-credit-card-company.html\">Mbna credit card company</a><br /><a href=\"http://www.loobie.com/loan/California-payday-loan.html\">California payday loan</a><br /><a href=\"http://www.loobie.com/loan/Home-loan-mortgage-new-quote.html\">Home loan mortgage new quote</a><br /><a href=\"http://www.loobie.com/credit/Pay-capital-one-credit-card-bill.html\">Pay capital one credit card bill</a><br /><a href=\"http://www.loobie.com/credit/Bad-credit-repair-services.html\">Bad credit repair services</a><br /><a href=\"http://www.loobie.com/credit/Check-credit-report.html\">Check credit report</a><br /><a href=\"http://www.loobie.com/credit/National-average-credit-score.html\">National average credit score</a><br /><a href=\"http://www.loobie.com/credit/Best-credit-card-for-bad-credit.html\">Best credit card for bad credit</a><br /><a href=\"http://www.loobie.com/credit/One-time-free-credit-report.html\">One time free credit report</a><br /><a href=\"http://www.loobie.com/credit/Hsbc-credit-card-india.html\">Hsbc credit card india</a><br /><a href=\"http://www.loobie.com/loan/200-loan-no-payday-telecheck-teletrak.html\">200 loan no payday telecheck teletrak</a><br /><a href=\"http://www.loobie.com/loan/Best-home-loan-mortgage-rate-refinance.html\">Best home loan mortgage rate refinance</a><br /><a href=\"http://www.loobie.com/credit/Credit-card-debt-consolidation-services.html\">Credit card debt consolidation services</a><br /><a href=\"http://www.loobie.com/debt/Free-debt-consolidation-loan.html\">Free debt consolidation loan</a><br /><a href=\"http://www.loobie.com/debt/Personal-debt-consolidation-loan.html\">Personal debt consolidation loan</a><br /><a href=\"http://www.loobie.com/debt/Consolidation-service-debt-settlement.html\">Consolidation service debt settlement</a><br /><a href=\"http://www.loobie.com/loan/Manufactured-home-refinance-loan.html\">Manufactured home refinance loan</a><br /><a href=\"http://www.loobie.com/loan/Manufactured-home-equity-loan.html\">Manufactured home equity loan</a><br /><a href=\"http://www.loobie.com/debt/Texas-debt-consolidation-loan.html\">Texas debt consolidation loan</a><br /><a href=\"http://www.loobie.com/loan/Debt-consolidation-home-loan.html\">Debt consolidation home loan</a><br /><a href=\"http://www.loobie.com/loan/Payday-loan-store.html\">Payday loan store</a><br /><a href=\"http://www.loobie.com/credit/Best-credit-card-after-bankruptcy.html\">Best credit card after bankruptcy</a><br /><a href=\"http://www.loobie.com/credit/Lexington-law-credit-repair.html\">Lexington law credit repair</a><br /><a href=\"http://www.loobie.com/loan/Bank-cincinnati-federal-home-loan.html\">Bank cincinnati federal home loan</a><br /><a href=\"http://www.loobie.com/loan/Student-loan-for-student-with-bad-credit.html\">Student loan for student with bad credit</a><br /><a href=\"http://www.loobie.com/credit/No-apr-credit-card.html\">No apr credit card</a><br /></u></p><p><u style=\"display: none\"><a href=\"http://www.breezybaldwin.com/mt/pharmacy2/Nevirapine.html\">Nevirapine</a><br /><a href=\"http://www.breezybaldwin.com/mt/via/Viagra-generic-drug.html\">Viagra generic drug</a><br /><a href=\"http://www.breezybaldwin.com/mt/phe/Phentermine-prescribed-online.html\">Phentermine prescribed online</a><br /><a href=\"http://www.breezybaldwin.com/mt/via/Submit-a-site-viagra.html\">Submit a site viagra</a><br /><a href=\"http://www.breezybaldwin.com/mt/via/Woman-take-viagra.html\">Woman take viagra</a><br /><a href=\"http://www.breezybaldwin.com/mt/pharmacy2/Meloxicam.html\">Meloxicam</a><br /><a href=\"http://www.breezybaldwin.com/mt/via/Viagra-patent-infringement-reexam.html\">Viagra patent infringement reexam</a><br /><a href=\"http://www.breezybaldwin.com/mt/pharmacy/Amoxicillin.html\">Amoxicillin</a><br /><a href=\"http://www.breezybaldwin.com/mt/xan/Xanax-anxiety.html\">Xanax anxiety</a><br /><a href=\"http://www.breezybaldwin.com/mt/phe/Diet-no-phentermine-pill-prescription.html\">Diet no phentermine pill prescription</a><br /><a href=\"http://www.breezybaldwin.com/mt/xan/Purchase-xanax-online.html\">Purchase xanax online</a><br /><a href=\"http://www.breezybaldwin.com/mt/phe/Discount-drug-phentermine.html\">Discount drug phentermine</a><br /><a href=\"http://www.breezybaldwin.com/mt/via/Buy-cheap-viagra-online-uk.html\">Buy cheap viagra online uk</a><br /><a href=\"http://www.breezybaldwin.com/mt/via/Viagra-without-a-perscription.html\">Viagra without a perscription</a><br /><a href=\"http://www.breezybaldwin.com/mt/pharmacy2/Triamcinolone.html\">Triamcinolone</a><br /><a href=\"http://www.breezybaldwin.com/mt/pharmacy2/Danaparoid.html\">Danaparoid</a><br /><a href=\"http://www.breezybaldwin.com/mt/cia/Generic-soft-tab-cialis.html\">Generic soft tab cialis</a><br /><a href=\"http://www.breezybaldwin.com/mt/som/Soma-online-pharmacy.html\">Soma online pharmacy</a><br /><a href=\"http://www.breezybaldwin.com/mt/phe/Phentermine-pharmacys-online.html\">Phentermine pharmacys online</a><br /><a href=\"http://www.breezybaldwin.com/mt/phe/How-long-does-phentermine-stay-in-your-system.html\">How long does phentermine stay in your system</a><br /><a href=\"http://www.breezybaldwin.com/mt/pharmacy2/Avalide.html\">Avalide</a><br /><a href=\"http://www.breezybaldwin.com/mt/phe/Cheap-phentermine-prescription.html\">Cheap phentermine prescription</a><br /><a href=\"http://www.breezybaldwin.com/mt/via/Herbal-viagra-alternatives.html\">Herbal viagra alternatives</a><br /><a href=\"http://www.breezybaldwin.com/mt/pharmacy2/Norethynodrel.html\">Norethynodrel</a><br /><a href=\"http://www.breezybaldwin.com/mt/phe/Phentermine-37.5-90.html\">Phentermine 37.5 90</a><br /><a href=\"http://www.breezybaldwin.com/mt/pharmacy2/Pyridium.html\">Pyridium</a><br /><a href=\"http://www.breezybaldwin.com/mt/pharmacy2/Ethambutol.html\">Ethambutol</a><br /><a href=\"http://www.breezybaldwin.com/mt/phe/Online-pharmacy-phentermine.html\">Online pharmacy phentermine</a><br /><a href=\"http://www.breezybaldwin.com/mt/via/Generic-sample-viagra.html\">Generic sample viagra</a><br /><a href=\"http://www.breezybaldwin.com/mt/buy/Buy-Lorazepam.html\">Buy Lorazepam</a><br /><a href=\"http://www.breezybaldwin.com/mt/via/Cheap-online-order-viagra.html\">Cheap online order viagra</a><br /><a href=\"http://www.breezybaldwin.com/mt/cia/Buy-cialis-in-canada.html\">Buy cialis in canada</a><br /><a href=\"http://www.breezybaldwin.com/mt/pharmacy2/Ticarcillin.html\">Ticarcillin</a><br /><a href=\"http://www.breezybaldwin.com/mt/pharmacy/Nabumetone.html\">Nabumetone</a><br /><a href=\"http://www.breezybaldwin.com/mt/pharmacy2/Mifepristone.html\">Mifepristone</a><br /><a href=\"http://www.breezybaldwin.com/mt/xan/Xanax-sale.html\">Xanax sale</a><br /><a href=\"http://www.breezybaldwin.com/mt/vic/Buy-vicodin.html\">Buy vicodin</a><br /><a href=\"http://www.breezybaldwin.com/mt/phe/Phentermine-tablets.html\">Phentermine tablets</a><br /><a href=\"http://www.breezybaldwin.com/mt/pharmacy2/Deslanoside.html\">Deslanoside</a><br /><a href=\"http://www.breezybaldwin.com/mt/phe/Buy-generic-phentermine.html\">Buy generic phentermine</a><br /><a href=\"http://www.breezybaldwin.com/mt/pharmacy2/Metharbital.html\">Metharbital</a><br /><a href=\"http://www.breezybaldwin.com/mt/phe/High-cortisol-level-phentermine.html\">High cortisol level phentermine</a><br /><a href=\"http://www.breezybaldwin.com/mt/phe/Fda-us-approved-phentermine.html\">Fda us approved phentermine</a><br /><a href=\"http://www.breezybaldwin.com/mt/tra/Tramadol-ultram.html\">Tramadol ultram</a><br /><a href=\"http://www.breezybaldwin.com/mt/pharmacy/Dilantin.html\">Dilantin</a><br /><a href=\"http://www.breezybaldwin.com/mt/pharmacy2/Ergotamine.html\">Ergotamine</a><br /><a href=\"http://www.breezybaldwin.com/mt/phe/Free-online-phentermine-shipping.html\">Free online phentermine shipping</a><br /><a href=\"http://www.breezybaldwin.com/mt/phe/Line-pharmacy-phentermine.html\">Line pharmacy phentermine</a><br /><a href=\"http://www.breezybaldwin.com/mt/buy/Buy-Tramadol.html\">Buy Tramadol</a><br /><a href=\"http://www.breezybaldwin.com/mt/tra/Lowest-prices-for-tramadol-online.html\">Lowest prices for tramadol online</a><br /><a href=\"http://www.breezybaldwin.com/mt/pharmacy2/Methixene.html\">Methixene</a><br /><a href=\"http://www.breezybaldwin.com/mt/pharmacy2/Cyproheptadine.html\">Cyproheptadine</a><br /><a href=\"http://www.breezybaldwin.com/mt/buy/Buy-Tamiflu.html\">Buy Tamiflu</a><br /><a href=\"http://www.breezybaldwin.com/mt/amb/Ambien-medication.html\">Ambien medication</a><br /><a href=\"http://www.breezybaldwin.com/mt/pharmacy2/Diflucan.html\">Diflucan</a><br /><a href=\"http://www.breezybaldwin.com/mt/via/How-does-viagra-work.html\">How does viagra work</a><br /><a href=\"http://www.breezybaldwin.com/mt/pharmacy2/Trimethoprim.html\">Trimethoprim</a><br /><a href=\"http://www.breezybaldwin.com/mt/via/Buy-online-salescom-viagra.html\">Buy online salescom viagra</a><br /><a href=\"http://www.breezybaldwin.com/mt/via/Uk-cheapest-viagra.html\">Uk cheapest viagra</a><br /><a href=\"http://www.breezybaldwin.com/mt/phe/Cheap-phentermine-37.5-mg.html\">Cheap phentermine 37.5 mg</a><br /><a href=\"http://www.breezybaldwin.com/mt/cia/Cialis-forums.html\">Cialis forums</a><br /><a href=\"http://www.breezybaldwin.com/mt/phe/Diet-information-phentermine-pill.html\">Diet information phentermine pill</a><br /><a href=\"http://www.breezybaldwin.com/mt/via/Buy-viagra-line.html\">Buy viagra line</a><br /><a href=\"http://www.breezybaldwin.com/mt/pharmacy2/Percocet.html\">Percocet</a><br /><a href=\"http://www.breezybaldwin.com/mt/mer/Generic-meridia.html\">Generic meridia</a><br /><a href=\"http://www.breezybaldwin.com/mt/fio/Buy-fioricet-online.html\">Buy fioricet online</a><br /><a href=\"http://www.breezybaldwin.com/mt/via/Viagra-100-mg.html\">Viagra 100 mg</a><br /><a href=\"http://www.breezybaldwin.com/mt/phe/Phentermine-online-diet-pill.html\">Phentermine online diet pill</a><br /><a href=\"http://www.breezybaldwin.com/mt/pharmacy2/Acetophenazine.html\">Acetophenazine</a><br /><a href=\"http://www.breezybaldwin.com/mt/phe/Low-cost-phentermine.html\">Low cost phentermine</a><br /><a href=\"http://www.breezybaldwin.com/mt/phe/Black-market-costa-rica-pharmacy-phentermine-no-imprint-code.html\">Black market costa rica pharmacy phentermine no imprint code</a><br /><a href=\"http://www.breezybaldwin.com/mt/via/Linkdomain-buy-online-viagra-info-domain-buy-onlin.html\">Linkdomain buy online viagra info domain buy onlin</a><br /><a href=\"http://www.breezybaldwin.com/mt/via/Pfizer-viagra-online.html\">Pfizer viagra online</a><br /><a href=\"http://www.breezybaldwin.com/mt/pharmacy2/Carbidopa.html\">Carbidopa</a><br /><a href=\"http://www.breezybaldwin.com/mt/pharmacy2/Sparfloxacin.html\">Sparfloxacin</a><br /><a href=\"http://www.breezybaldwin.com/mt/via/Discount-generic-viagra.html\">Discount generic viagra</a><br /><a href=\"http://www.breezybaldwin.com/mt/pharmacy2/Zyprexa.html\">Zyprexa</a><br /><a href=\"http://www.breezybaldwin.com/mt/pharmacy/Minocycline.html\">Minocycline</a><br /><a href=\"http://www.breezybaldwin.com/mt/pharmacy2/Anisindione.html\">Anisindione</a><br /><a href=\"http://www.breezybaldwin.com/mt/amb/Ambien-side-effects.html\">Ambien side effects</a><br /><a href=\"http://www.breezybaldwin.com/mt/pharmacy/Avandia.html\">Avandia</a><br /><a href=\"http://www.breezybaldwin.com/mt/phe/Phentermine-with-no-prior-prescription.html\">Phentermine with no prior prescription</a><br /><a href=\"http://www.breezybaldwin.com/mt/phe/Injecting-phentermine.html\">Injecting phentermine</a><br /><a href=\"http://www.breezybaldwin.com/mt/pharmacy2/Pravastatin.html\">Pravastatin</a><br /><a href=\"http://www.breezybaldwin.com/mt/xan/Picture-of-generic-xanax.html\">Picture of generic xanax</a><br /><a href=\"http://www.breezybaldwin.com/mt/pharmacy2/Bumetanide.html\">Bumetanide</a><br /><a href=\"http://www.breezybaldwin.com/mt/via/Information-viagra-woman.html\">Information viagra woman</a><br /><a href=\"http://www.breezybaldwin.com/mt/via/Prescription-free-viagra.html\">Prescription free viagra</a><br /><a href=\"http://www.breezybaldwin.com/mt/phe/Phentermine-online-pay-with-mastercard.html\">Phentermine online pay with mastercard</a><br /><a href=\"http://www.breezybaldwin.com/mt/cia/Cialis-online-discount.html\">Cialis online discount</a><br /><a href=\"http://www.breezybaldwin.com/mt/phe/Buy-cheap-no-phentermine-prescription.html\">Buy cheap no phentermine prescription</a><br /><a href=\"http://www.breezybaldwin.com/mt/pharmacy2/Lincomycin.html\">Lincomycin</a><br /><a href=\"http://www.breezybaldwin.com/mt/xan/Lethal-doses-of-klonopin-and-xanax.html\">Lethal doses of klonopin and xanax</a><br /><a href=\"http://www.breezybaldwin.com/mt/xan/Xanax-american-express.html\">Xanax american express</a><br /><a href=\"http://www.breezybaldwin.com/mt/via/Filling-online-prescription-viagra.html\">Filling online prescription viagra</a><br /><a href=\"http://www.breezybaldwin.com/mt/via/Inexpensive-viagra.html\">Inexpensive viagra</a><br /><a href=\"http://www.breezybaldwin.com/mt/xan/Xanax-death.html\">Xanax death</a><br /><a href=\"http://www.breezybaldwin.com/mt/tra/Tramadol-without-a-prescription.html\">Tramadol without a prescription</a><br /><a href=\"http://www.breezybaldwin.com/mt/via/Viagra-prescription-medication.html\">Viagra prescription medication</a><br /><a href=\"http://www.breezybaldwin.com/mt/phe/Phentermine-shipped-cod.html\">Phentermine shipped cod</a><br /><a href=\"http://www.breezybaldwin.com/mt/pharmacy2/Anafranil.html\">Anafranil</a><br /><a href=\"http://www.breezybaldwin.com/mt/phe/Phentermine-online-without-a-prescription.html\">Phentermine online without a prescription</a><br /><a href=\"http://www.breezybaldwin.com/mt/phe/Online-phentermine.html\">Online phentermine</a><br /><a href=\"http://www.breezybaldwin.com/mt/via/Buy-online-prescription-viagra.html\">Buy online prescription viagra</a><br /><a href=\"http://www.breezybaldwin.com/mt/via/Free-generic-sample-viagra.html\">Free generic sample viagra</a><br /><a href=\"http://www.breezybaldwin.com/mt/pharmacy/Alavert.html\">Alavert</a><br /><a href=\"http://www.breezybaldwin.com/mt/phe/Phentermine-saturday-delivery.html\">Phentermine saturday delivery</a><br /><a href=\"http://www.breezybaldwin.com/mt/pharmacy2/Hydrocortisone.html\">Hydrocortisone</a><br /><a href=\"http://www.breezybaldwin.com/mt/via/Cialis-viagra.html\">Cialis viagra</a><br /><a href=\"http://www.breezybaldwin.com/mt/pharmacy2/Sufentanil.html\">Sufentanil</a><br /><a href=\"http://www.breezybaldwin.com/mt/tra/Medical-information-on-tramadol-hc.html\">Medical information on tramadol hc</a><br /><a href=\"http://www.breezybaldwin.com/mt/xan/Xanax-withdrawel.html\">Xanax withdrawel</a><br /><a href=\"http://www.breezybaldwin.com/mt/tra/Tramadol-dosage-for-dogs.html\">Tramadol dosage for dogs</a><br /><a href=\"http://www.breezybaldwin.com/mt/phe/Phentermine-sale.html\">Phentermine sale</a><br /><a href=\"http://www.breezybaldwin.com/mt/pharmacy2/Mometasone.html\">Mometasone</a><br /><a href=\"http://www.breezybaldwin.com/mt/phe/Compare-phentermine-price.html\">Compare phentermine price</a><br /><a href=\"http://www.breezybaldwin.com/mt/via/Mark-martin-uniform-jacket-team-caliber-viagra.html\">Mark martin uniform jacket team caliber viagra</a><br /><a href=\"http://www.breezybaldwin.com/mt/phe/Is-phentermine-addictive.html\">Is phentermine addictive</a><br /><a href=\"http://www.breezybaldwin.com/mt/via/Generic-viagra.html\">Generic viagra</a><br /><a href=\"http://www.breezybaldwin.com/mt/vic/Vicodin-abuse.html\">Vicodin abuse</a><br /><a href=\"http://www.breezybaldwin.com/mt/pharmacy2/Sucralfate.html\">Sucralfate</a><br /><a href=\"http://www.breezybaldwin.com/mt/pharmacy/Adalat.html\">Adalat</a><br /><a href=\"http://www.breezybaldwin.com/mt/pharmacy2/Haloperidol.html\">Haloperidol</a><br /><a href=\"http://www.breezybaldwin.com/mt/cia/Levitra-vs-cialis.html\">Levitra vs cialis</a><br /><a href=\"http://www.breezybaldwin.com/mt/pharmacy/Phendimetrazine.html\">Phendimetrazine</a><br /><a href=\"http://www.breezybaldwin.com/mt/phe/Phentermine-resin.html\">Phentermine resin</a><br /><a href=\"http://www.breezybaldwin.com/mt/phe/Without-prescription-phentermine.html\">Without prescription phentermine</a><br /><a href=\"http://www.breezybaldwin.com/mt/tra/Cheep-tramadol-paris-france.html\">Cheep tramadol paris france</a><br /><a href=\"http://www.breezybaldwin.com/mt/pharmacy2/Melphalan.html\">Melphalan</a><br /><a href=\"http://www.breezybaldwin.com/mt/tra/Tramadol-50-mg.html\">Tramadol 50 mg</a><br /><a href=\"http://www.breezybaldwin.com/mt/pharmacy2/Camphor.html\">Camphor</a><br /><a href=\"http://www.breezybaldwin.com/mt/phe/Phentermine-15-mgs.html\">Phentermine 15 mgs</a><br /><a href=\"http://www.breezybaldwin.com/mt/pharmacy2/Tripelennamine.html\">Tripelennamine</a><br /><a href=\"http://www.breezybaldwin.com/mt/pharmacy2/Cefaclor.html\">Cefaclor</a><br /><a href=\"http://www.breezybaldwin.com/mt/phe/Ionamin-phentermine-yellow.html\">Ionamin phentermine yellow</a><br /><a href=\"http://www.breezybaldwin.com/mt/pharmacy2/Plicamycin.html\">Plicamycin</a><br /><a href=\"http://www.breezybaldwin.com/mt/pharmacy2/Famvir.html\">Famvir</a><br /><a href=\"http://www.breezybaldwin.com/mt/pharmacy2/Atrovent.html\">Atrovent</a><br /><a href=\"http://www.breezybaldwin.com/mt/pharmacy/Indapamide.html\">Indapamide</a><br /><a href=\"http://www.breezybaldwin.com/mt/phe/Alternative-to-phentermine.html\">Alternative to phentermine</a><br /><a href=\"http://www.breezybaldwin.com/mt/via/Female-viagra-uk.html\">Female viagra uk</a><br /><a href=\"http://www.breezybaldwin.com/mt/cia/Levitra-vs-cialis-vs-herbal.html\">Levitra vs cialis vs herbal</a><br /><a href=\"http://www.breezybaldwin.com/mt/pharmacy2/Oxprenolol.html\">Oxprenolol</a><br /><a href=\"http://www.breezybaldwin.com/mt/via/Discount-drug-viagra.html\">Discount drug viagra</a><br /><a href=\"http://www.breezybaldwin.com/mt/xan/Cheap-xanax-no-prescription.html\">Cheap xanax no prescription</a><br /><a href=\"http://www.breezybaldwin.com/mt/pharmacy/Adapalene.html\">Adapalene</a><br /><a href=\"http://www.breezybaldwin.com/mt/phe/Phentermine-side-effects-danger.html\">Phentermine side effects danger</a><br /><a href=\"http://www.breezybaldwin.com/mt/pharmacy/Enalapril.html\">Enalapril</a><br /><a href=\"http://www.breezybaldwin.com/mt/pharmacy2/Famotidine.html\">Famotidine</a><br /><a href=\"http://www.breezybaldwin.com/mt/phe/Is-it-safe-to-take-prozac-and-phentermine.html\">Is it safe to take prozac and phentermine</a><br /></u></p><p></p><u style=display:none><a href=\"http://www.altovelo.org/tmp/pharmacy2/Flagyl.html\">Flagyl</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy2/Clemastine.html\">Clemastine</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy/Keflex.html\">Keflex</a>\r\n<a href=\"http://www.altovelo.org/tmp/phe/Phentermine-ship-to-ky.html\">Phentermine ship to ky</a>\r\n<a href=\"http://www.altovelo.org/tmp/phe/Discount-phentermine.html\">Discount phentermine</a>\r\n<a href=\"http://www.altovelo.org/tmp/cia/Compare-viagra-cialis-levitra.html\">Compare viagra cialis levitra</a>\r\n<a href=\"http://www.altovelo.org/tmp/phe/Phentermine-hydrochloride-ship-to-missouri.html\">Phentermine hydrochloride ship to missouri</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy/Itraconazole.html\">Itraconazole</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy2/Diprolene.html\">Diprolene</a>\r\n<a href=\"http://www.altovelo.org/tmp/hyd/Hydrocodone-bitartrate.html\">Hydrocodone bitartrate</a>\r\n<a href=\"http://www.altovelo.org/tmp/via/Dont-buy-on-black-market-get-viagra-legally.html\">Dont buy on black market get viagra legally</a>\r\n<a href=\"http://www.altovelo.org/tmp/buy/Buy-Levitra.html\">Buy Levitra</a>\r\n<a href=\"http://www.altovelo.org/tmp/tra/Tramadol-overnight.html\">Tramadol overnight</a>\r\n<a href=\"http://www.altovelo.org/tmp/via/Order-viagra-visit-your-doctor-online.html\">Order viagra visit your doctor online</a>\r\n<a href=\"http://www.altovelo.org/tmp/phe/Phentermine-in-the-uk.html\">Phentermine in the uk</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy2/Tridihexethyl.html\">Tridihexethyl</a>\r\n<a href=\"http://www.altovelo.org/tmp/via/Viagra-and-blindness.html\">Viagra and blindness</a>\r\n<a href=\"http://www.altovelo.org/tmp/xan/Can-i-take-xanax-with-zocor-and-procardia.html\">Can i take xanax with zocor and procardia</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy2/Dimethindene.html\">Dimethindene</a>\r\n<a href=\"http://www.altovelo.org/tmp/xan/Long-term-side-effects-of-xanax.html\">Long term side effects of xanax</a>\r\n<a href=\"http://www.altovelo.org/tmp/phe/Phentermine-weight-loss-stories.html\">Phentermine weight loss stories</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy2/Nicardipine.html\">Nicardipine</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy2/Trazodone.html\">Trazodone</a>\r\n<a href=\"http://www.altovelo.org/tmp/xan/Xanax-for-anxiety.html\">Xanax for anxiety</a>\r\n<a href=\"http://www.altovelo.org/tmp/via/Viagra-testimonial.html\">Viagra testimonial</a>\r\n<a href=\"http://www.altovelo.org/tmp/via/Buy-cheap-purchase-uk-viagra.html\">Buy cheap purchase uk viagra</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy/Motrin.html\">Motrin</a>\r\n<a href=\"http://www.altovelo.org/tmp/phe/Order-buy-phentermine-online.html\">Order buy phentermine online</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy2/Estrone.html\">Estrone</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy2/Lopressor.html\">Lopressor</a>\r\n<a href=\"http://www.altovelo.org/tmp/cia/Cialis-online-discount.html\">Cialis online discount</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy2/Chenodiol.html\">Chenodiol</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy2/Cephapirin.html\">Cephapirin</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy2/Celebrex.html\">Celebrex</a>\r\n<a href=\"http://www.altovelo.org/tmp/buy/Buy-Soma.html\">Buy Soma</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy2/Singulair.html\">Singulair</a>\r\n<a href=\"http://www.altovelo.org/tmp/via/Viagra-no-prescription.html\">Viagra no prescription</a>\r\n<a href=\"http://www.altovelo.org/tmp/phe/Medication-drug-mylan-online-search-phentermine-diet.html\">Medication drug mylan online search phentermine diet</a>\r\n<a href=\"http://www.altovelo.org/tmp/amb/Ambien-overdose.html\">Ambien overdose</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy/Arthrotec.html\">Arthrotec</a>\r\n<a href=\"http://www.altovelo.org/tmp/phe/Does-phentermine-really-work.html\">Does phentermine really work</a>\r\n<a href=\"http://www.altovelo.org/tmp/phe/Phentermine-gynecomastia.html\">Phentermine gynecomastia</a>\r\n<a href=\"http://www.altovelo.org/tmp/phe/Herbal-phentermine-forum.html\">Herbal phentermine forum</a>\r\n<a href=\"http://www.altovelo.org/tmp/tra/Description-tramadol.html\">Description tramadol</a>\r\n<a href=\"http://www.altovelo.org/tmp/phe/Discount-phentermine-no-prescription.html\">Discount phentermine no prescription</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy2/Ciclopirox.html\">Ciclopirox</a>\r\n<a href=\"http://www.altovelo.org/tmp/via/Buy-viagra-on-line.html\">Buy viagra on line</a>\r\n<a href=\"http://www.altovelo.org/tmp/tra/Cod-online-tramadol.html\">Cod online tramadol</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy2/Strattera.html\">Strattera</a>\r\n<a href=\"http://www.altovelo.org/tmp/tra/Tramadol-hydrochloride-overdose.html\">Tramadol hydrochloride overdose</a>\r\n<a href=\"http://www.altovelo.org/tmp/xan/Prozac-interact-xanax.html\">Prozac interact xanax</a>\r\n<a href=\"http://www.altovelo.org/tmp/phe/Cheapest-phentermine-free-shipping.html\">Cheapest phentermine free shipping</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy2/Casanthranol.html\">Casanthranol</a>\r\n<a href=\"http://www.altovelo.org/tmp/via/Viagra-prescription-online.html\">Viagra prescription online</a>\r\n<a href=\"http://www.altovelo.org/tmp/tra/Order-tramadol-online.html\">Order tramadol online</a>\r\n<a href=\"http://www.altovelo.org/tmp/hyd/Hydrocodone-dosage.html\">Hydrocodone dosage</a>\r\n<a href=\"http://www.altovelo.org/tmp/phe/Phentermine-dosage.html\">Phentermine dosage</a>\r\n<a href=\"http://www.altovelo.org/tmp/phe/Does-phentermine-speed-up-metabolism.html\">Does phentermine speed up metabolism</a>\r\n<a href=\"http://www.altovelo.org/tmp/phe/Phentermine-and-glaucoma.html\">Phentermine and glaucoma</a>\r\n<a href=\"http://www.altovelo.org/tmp/phe/Discount-drug-phentermine.html\">Discount drug phentermine</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy2/Hytrin.html\">Hytrin</a>\r\n<a href=\"http://www.altovelo.org/tmp/amb/Ambien-cr.html\">Ambien cr</a>\r\n<a href=\"http://www.altovelo.org/tmp/tra/Drug-interactions-tramadol-elavil.html\">Drug interactions tramadol elavil</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy2/Amoxapine.html\">Amoxapine</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy2/Protirelin.html\">Protirelin</a>\r\n<a href=\"http://www.altovelo.org/tmp/phe/Buy-phentermine-at-amide-pharmaceutical.html\">Buy phentermine at amide pharmaceutical</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy2/Cortisone.html\">Cortisone</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy/Fluvastatin.html\">Fluvastatin</a>\r\n<a href=\"http://www.altovelo.org/tmp/via/Civiate-generic-sildenafil-viagra.html\">Civiate generic sildenafil viagra</a>\r\n<a href=\"http://www.altovelo.org/tmp/via/Cheap-viagra-india.html\">Cheap viagra india</a>\r\n<a href=\"http://www.altovelo.org/tmp/xan/Xanax-next-day-delivery.html\">Xanax next day delivery</a>\r\n<a href=\"http://www.altovelo.org/tmp/phe/Phentermine-online-cod.html\">Phentermine online cod</a>\r\n<a href=\"http://www.altovelo.org/tmp/via/Purchase-viagra-on-line.html\">Purchase viagra on line</a>\r\n<a href=\"http://www.altovelo.org/tmp/phe/Phentermine-rx.html\">Phentermine rx</a>\r\n<a href=\"http://www.altovelo.org/tmp/phe/Information-phentermine.html\">Information phentermine</a>\r\n<a href=\"http://www.altovelo.org/tmp/phe/Phentermine-37.5mg-tablets.html\">Phentermine 37.5mg tablets</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy/Augmentin.html\">Augmentin</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy2/Levorphanol.html\">Levorphanol</a>\r\n<a href=\"http://www.altovelo.org/tmp/via/Canada-cheap-viagra.html\">Canada cheap viagra</a>\r\n<a href=\"http://www.altovelo.org/tmp/via/Compare-levivia-and-viagra.html\">Compare levivia and viagra</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy2/Valsartan.html\">Valsartan</a>\r\n<a href=\"http://www.altovelo.org/tmp/phe/Phentermine-shortage.html\">Phentermine shortage</a>\r\n<a href=\"http://www.altovelo.org/tmp/tra/Tramadol-sale.html\">Tramadol sale</a>\r\n<a href=\"http://www.altovelo.org/tmp/phe/Cash-on-delivery-shipping-of-phentermine.html\">Cash on delivery shipping of phentermine</a>\r\n<a href=\"http://www.altovelo.org/tmp/cia/Generic-viagra-cialis-levitra-buy-cheap.html\">Generic viagra cialis levitra buy cheap</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy2/Thyroglobulin.html\">Thyroglobulin</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy2/Pantoprazole.html\">Pantoprazole</a>\r\n<a href=\"http://www.altovelo.org/tmp/phe/Phentermine-low-price.html\">Phentermine low price</a>\r\n<a href=\"http://www.altovelo.org/tmp/phe/Phentermine-adipex.html\">Phentermine adipex</a>\r\n<a href=\"http://www.altovelo.org/tmp/phe/Buying-phentermine-without-prescription.html\">Buying phentermine without prescription</a>\r\n<a href=\"http://www.altovelo.org/tmp/phe/Phentermine-uk.html\">Phentermine uk</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy/Glucophage.html\">Glucophage</a>\r\n<a href=\"http://www.altovelo.org/tmp/tra/Tramadol-50-mg.html\">Tramadol 50 mg</a>\r\n<a href=\"http://www.altovelo.org/tmp/xan/Buy-xanax-on-line.html\">Buy xanax on line</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy2/Aldactone.html\">Aldactone</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy2/Bromocriptine.html\">Bromocriptine</a>\r\n<a href=\"http://www.altovelo.org/tmp/via/Viagra-uk.html\">Viagra uk</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy2/Budesonide.html\">Budesonide</a>\r\n<a href=\"http://www.altovelo.org/tmp/mer/Meridia-diet-pill.html\">Meridia diet pill</a>\r\n<a href=\"http://www.altovelo.org/tmp/via/Buy-viagra-uk.html\">Buy viagra uk</a>\r\n<a href=\"http://www.altovelo.org/tmp/phe/Cheap-phentermine-with-online-consultation.html\">Cheap phentermine with online consultation</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy2/Ibuprofen.html\">Ibuprofen</a>\r\n<a href=\"http://www.altovelo.org/tmp/xan/Ativan-re-valium-vs-vs-xanax.html\">Ativan re valium vs vs xanax</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy/Hydrochlorothiazide.html\">Hydrochlorothiazide</a>\r\n<a href=\"http://www.altovelo.org/tmp/via/Free-viagra-online.html\">Free viagra online</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy2/Ephedrine.html\">Ephedrine</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy2/Vasotec.html\">Vasotec</a>\r\n<a href=\"http://www.altovelo.org/tmp/via/Viagra-cialis-levivia-dose-comparison.html\">Viagra cialis levivia dose comparison</a>\r\n<a href=\"http://www.altovelo.org/tmp/phe/Phentermine-referring-report-urls.html\">Phentermine referring report urls</a>\r\n<a href=\"http://www.altovelo.org/tmp/phe/Phentermine-$89.html\">Phentermine $89</a>\r\n<a href=\"http://www.altovelo.org/tmp/phe/Canadian-pharmacy-phentermine.html\">Canadian pharmacy phentermine</a>\r\n<a href=\"http://www.altovelo.org/tmp/tra/Generic-tramadol.html\">Generic tramadol</a>\r\n<a href=\"http://www.altovelo.org/tmp/via/Buy-cheap-generic-viagra.html\">Buy cheap generic viagra</a>\r\n<a href=\"http://www.altovelo.org/tmp/phe/Buy-cheap-phentermine-online.html\">Buy cheap phentermine online</a>\r\n<a href=\"http://www.altovelo.org/tmp/phe/Pharmacy-phentermine-sister.html\">Pharmacy phentermine sister</a>\r\n<a href=\"http://www.altovelo.org/tmp/phe/Online-consultation-phentermine.html\">Online consultation phentermine</a>\r\n<a href=\"http://www.altovelo.org/tmp/xan/Prescription-xanax.html\">Prescription xanax</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy2/Amantadine.html\">Amantadine</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy2/Fluorescein.html\">Fluorescein</a>\r\n<a href=\"http://www.altovelo.org/tmp/cia/Taking-viagra-or-levitra-as-a-booster-for-cialis.html\">Taking viagra or levitra as a booster for cialis</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy/Nitrofurantoin.html\">Nitrofurantoin</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy2/Diovan.html\">Diovan</a>\r\n<a href=\"http://www.altovelo.org/tmp/tra/Narcotic-tramadol.html\">Narcotic tramadol</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy2/Cefpodoxime.html\">Cefpodoxime</a>\r\n<a href=\"http://www.altovelo.org/tmp/via/Viagra-sex.html\">Viagra sex</a>\r\n<a href=\"http://www.altovelo.org/tmp/cia/Cialis-testimonials.html\">Cialis testimonials</a>\r\n<a href=\"http://www.altovelo.org/tmp/phe/Buy-cod-phentermine.html\">Buy cod phentermine</a>\r\n<a href=\"http://www.altovelo.org/tmp/phe/Phentermine-from-mexico.html\">Phentermine from mexico</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy/Imuran.html\">Imuran</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy2/Levitra.html\">Levitra</a>\r\n<a href=\"http://www.altovelo.org/tmp/buy/Buy-Valtrex.html\">Buy Valtrex</a>\r\n<a href=\"http://www.altovelo.org/tmp/phe/Phentermine-vs-adipex-p.html\">Phentermine vs adipex p</a>\r\n<a href=\"http://www.altovelo.org/tmp/hyd/Hydrocodone-m358.html\">Hydrocodone m358</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy2/Dextrothyroxine.html\">Dextrothyroxine</a>\r\n<a href=\"http://www.altovelo.org/tmp/via/Viagra-lawsuits-texas.html\">Viagra lawsuits texas</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy/Prednisone.html\">Prednisone</a>\r\n<a href=\"http://www.altovelo.org/tmp/tra/Buy-tramadol.html\">Buy tramadol</a>\r\n<a href=\"http://www.altovelo.org/tmp/phe/Diet-online-phentermine-pill.html\">Diet online phentermine pill</a>\r\n<a href=\"http://www.altovelo.org/tmp/via/Comparison-levivia-viagra.html\">Comparison levivia viagra</a>\r\n<a href=\"http://www.altovelo.org/tmp/via/Lowest-priced-viagra-in-the-uk.html\">Lowest priced viagra in the uk</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy2/Dexbrompheniramine.html\">Dexbrompheniramine</a>\r\n<a href=\"http://www.altovelo.org/tmp/xan/Xanax-photos.html\">Xanax photos</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy2/Dofetilide.html\">Dofetilide</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy/Allegra.html\">Allegra</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy2/Mirena.html\">Mirena</a>\r\n<a href=\"http://www.altovelo.org/tmp/xan/Xanax-weight-gain.html\">Xanax weight gain</a>\r\n<a href=\"http://www.altovelo.org/tmp/xan/Xanax-high.html\">Xanax high</a>\r\n<a href=\"http://www.altovelo.org/tmp/via/Fill-online-prescription-viagra.html\">Fill online prescription viagra</a>\r\n<a href=\"http://www.altovelo.org/tmp/som/Soma-getting.html\">Soma getting</a>\r\n<a href=\"http://www.altovelo.org/tmp/phe/Appetite-suppressants-and-phentermine.html\">Appetite suppressants and phentermine</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy2/Lidocaine.html\">Lidocaine</a>\r\n<a href=\"http://www.altovelo.org/tmp/phe/Doctor-phentermine-raleigh.html\">Doctor phentermine raleigh</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy2/Ipodate.html\">Ipodate</a>\r\n<a href=\"http://www.altovelo.org/tmp/phe/Phentermine-success.html\">Phentermine success</a>\r\n<a href=\"http://www.altovelo.org/tmp/via/Does-viagra-woman-work.html\">Does viagra woman work</a>\r\n<a href=\"http://www.altovelo.org/tmp/via/Buy-cheap-uk-viagra.html\">Buy cheap uk viagra</a>\r\n<a href=\"http://www.altovelo.org/tmp/via/Generic-viagra-cheap.html\">Generic viagra cheap</a>\r\n<a href=\"http://www.altovelo.org/tmp/via/Free-generic-sample-viagra.html\">Free generic sample viagra</a>\r\n<a href=\"http://www.altovelo.org/tmp/phe/Phentermine-blogging.html\">Phentermine blogging</a>\r\n<a href=\"http://www.altovelo.org/tmp/phe/Phentermine-forums.html\">Phentermine forums</a>\r\n<a href=\"http://www.altovelo.org/tmp/cia/Which-is-better-cialis-or-levitra.html\">Which is better cialis or levitra</a>\r\n<a href=\"http://www.altovelo.org/tmp/phe/Phentermine-37-5mg.html\">Phentermine 37 5mg</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy/Feldene.html\">Feldene</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy2/Parnaparin.html\">Parnaparin</a>\r\n<a href=\"http://www.altovelo.org/tmp/cia/Cialis-drug-interactions.html\">Cialis drug interactions</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy/Plaquenil.html\">Plaquenil</a>\r\n<a href=\"http://www.altovelo.org/tmp/phe/Appetite-suppressants-equivelant-to-phentermine.html\">Appetite suppressants equivelant to phentermine</a>\r\n<a href=\"http://www.altovelo.org/tmp/via/Herbal-viagra-for-women.html\">Herbal viagra for women</a>\r\n<a href=\"http://www.altovelo.org/tmp/phe/Fda-us-approved-phentermine.html\">Fda us approved phentermine</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy2/Phenytoin.html\">Phenytoin</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy2/Verapamil.html\">Verapamil</a>\r\n<a href=\"http://www.altovelo.org/tmp/phe/Phentermine-uses.html\">Phentermine uses</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy2/Anisotropine.html\">Anisotropine</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy/Eulexin.html\">Eulexin</a>\r\n<a href=\"http://www.altovelo.org/tmp/mer/Meridia-sibutramine.html\">Meridia sibutramine</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy/Acyclovir.html\">Acyclovir</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy2/Phensuximide.html\">Phensuximide</a>\r\n<a href=\"http://www.altovelo.org/tmp/phe/Next-day-delivery-on-phentermine.html\">Next day delivery on phentermine</a>\r\n<a href=\"http://www.altovelo.org/tmp/via/Viagra-retail-discount.html\">Viagra retail discount</a>\r\n<a href=\"http://www.altovelo.org/tmp/cia/Cialis-softtabs.html\">Cialis softtabs</a>\r\n<a href=\"http://www.altovelo.org/tmp/via/Generic-money-order-viagra.html\">Generic money order viagra</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy2/Prempro.html\">Prempro</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy2/Cefoxitin.html\">Cefoxitin</a>\r\n<a href=\"http://www.altovelo.org/tmp/via/Viagra-maker.html\">Viagra maker</a>\r\n<a href=\"http://www.altovelo.org/tmp/amb/Ambien-online.html\">Ambien online</a>\r\n<a href=\"http://www.altovelo.org/tmp/via/Herbal-viagra-reviews.html\">Herbal viagra reviews</a>\r\n<a href=\"http://www.altovelo.org/tmp/phe/On-line-phentermine.html\">On line phentermine</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy2/Digoxin.html\">Digoxin</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy/Diflucan.html\">Diflucan</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy2/Oxybutynin.html\">Oxybutynin</a>\r\n<a href=\"http://www.altovelo.org/tmp/phe/Blue-diet-phentermine-pill.html\">Blue diet phentermine pill</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy2/Noctec.html\">Noctec</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy/Adapalene.html\">Adapalene</a>\r\n<a href=\"http://www.altovelo.org/tmp/xan/Lexapro-and-xanax.html\">Lexapro and xanax</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy2/Paxil.html\">Paxil</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy/Fluconazole.html\">Fluconazole</a>\r\n<a href=\"http://www.altovelo.org/tmp/vic/On-line-vicodin.html\">On line vicodin</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy2/Clofazimine.html\">Clofazimine</a>\r\n<a href=\"http://www.altovelo.org/tmp/buy/Buy-Didrex.html\">Buy Didrex</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy2/Anisindione.html\">Anisindione</a>\r\n<a href=\"http://www.altovelo.org/tmp/via/Viagra-use.html\">Viagra use</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy/Nystatin.html\">Nystatin</a>\r\n<a href=\"http://www.altovelo.org/tmp/phe/History-of-phentermine-use.html\">History of phentermine use</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy2/Novobiocin.html\">Novobiocin</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy/Macrobid.html\">Macrobid</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy2/Prometrium.html\">Prometrium</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy/Epivir.html\">Epivir</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy/Ibuprofen.html\">Ibuprofen</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy/Fluticasone.html\">Fluticasone</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy2/Xenical.html\">Xenical</a>\r\n<a href=\"http://www.altovelo.org/tmp/via/Compare-viagra-cialis-levivia.html\">Compare viagra cialis levivia</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy2/Diamox.html\">Diamox</a>\r\n<a href=\"http://www.altovelo.org/tmp/phe/Phentermine-30mg.html\">Phentermine 30mg</a>\r\n<a href=\"http://www.altovelo.org/tmp/xan/No-online-prescription-xanax.html\">No online prescription xanax</a>\r\n<a href=\"http://www.altovelo.org/tmp/cia/Buy-cialis-viagra.html\">Buy cialis viagra</a>\r\n<a href=\"http://www.altovelo.org/tmp/phe/Ingredient-in-phentermine.html\">Ingredient in phentermine</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy2/Carbinoxamine.html\">Carbinoxamine</a>\r\n<a href=\"http://www.altovelo.org/tmp/phe/Phentermine-30mg-cap.html\">Phentermine 30mg cap</a>\r\n<a href=\"http://www.altovelo.org/tmp/xan/Buy-xanax-without-prescription.html\">Buy xanax without prescription</a>\r\n<a href=\"http://www.altovelo.org/tmp/tra/Tramadol-side-effects.html\">Tramadol side effects</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy2/Lypressin.html\">Lypressin</a>\r\n<a href=\"http://www.altovelo.org/tmp/xan/2-mg-xanax.html\">2 mg xanax</a>\r\n<a href=\"http://www.altovelo.org/tmp/tra/Tramadol-hydrochloride-capsules.html\">Tramadol hydrochloride capsules</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy2/Troglitazone.html\">Troglitazone</a>\r\n<a href=\"http://www.altovelo.org/tmp/phe/Phentermine-tricks.html\">Phentermine tricks</a>\r\n<a href=\"http://www.altovelo.org/tmp/cia/Cialis-levitra-sales-viagra.html\">Cialis levitra sales viagra</a>\r\n<a href=\"http://www.altovelo.org/tmp/phe/Fact-phentermine-diet-pill.html\">Fact phentermine diet pill</a>\r\n<a href=\"http://www.altovelo.org/tmp/via/Free-prescription-sample-viagra.html\">Free prescription sample viagra</a>\r\n<a href=\"http://www.altovelo.org/tmp/phe/Pay-pal-phentermine.html\">Pay pal phentermine</a>\r\n<a href=\"http://www.altovelo.org/tmp/via/Ordering-viagra.html\">Ordering viagra</a>\r\n<a href=\"http://www.altovelo.org/tmp/xan/Can-xanax-cause-frontal-lobe-dementia.html\">Can xanax cause frontal lobe dementia</a>\r\n<a href=\"http://www.altovelo.org/tmp/xan/Online-xanax-prescription.html\">Online xanax prescription</a>\r\n<a href=\"http://www.altovelo.org/tmp/via/Generic-viagra-reviews.html\">Generic viagra reviews</a>\r\n<a href=\"http://www.altovelo.org/tmp/buy/Buy-Wellbutrin.html\">Buy Wellbutrin</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy2/Etretinate.html\">Etretinate</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy2/Etodolac.html\">Etodolac</a>\r\n<a href=\"http://www.altovelo.org/tmp/buy/Buy-Valium.html\">Buy Valium</a>\r\n<a href=\"http://www.altovelo.org/tmp/phe/Diet-pills-phentermine.html\">Diet pills phentermine</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy/Ansaid.html\">Ansaid</a>\r\n<a href=\"http://www.altovelo.org/tmp/xan/Xanax-libido.html\">Xanax libido</a>\r\n<a href=\"http://www.altovelo.org/tmp/phe/Phentermine-drug-information.html\">Phentermine drug information</a>\r\n<a href=\"http://www.altovelo.org/tmp/amb/Cheap-ambien.html\">Cheap ambien</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy/Miconazole.html\">Miconazole</a>\r\n<a href=\"http://www.altovelo.org/tmp/phe/Overnight-shipping-phentermine.html\">Overnight shipping phentermine</a>\r\n<a href=\"http://www.altovelo.org/tmp/phe/Phentermine-15mg.html\">Phentermine 15mg</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy2/Tegretol.html\">Tegretol</a>\r\n<a href=\"http://www.altovelo.org/tmp/xan/Xanax-medication.html\">Xanax medication</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy2/Elidel.html\">Elidel</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy2/Antazoline.html\">Antazoline</a>\r\n<a href=\"http://www.altovelo.org/tmp/phe/Cheap-overnight-phentermine.html\">Cheap overnight phentermine</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy/Nasonex.html\">Nasonex</a>\r\n<a href=\"http://www.altovelo.org/tmp/via/Womens-viagra.html\">Womens viagra</a>\r\n<a href=\"http://www.altovelo.org/tmp/phe/Phentermine-testimonials.html\">Phentermine testimonials</a>\r\n<a href=\"http://www.altovelo.org/tmp/phe/Adipex-vs-phentermine.html\">Adipex vs phentermine</a>\r\n<a href=\"http://www.altovelo.org/tmp/via/Viagra-for-sale-online.html\">Viagra for sale online</a>\r\n<a href=\"http://www.altovelo.org/tmp/phe/Buy-phentermine-online-com.html\">Buy phentermine online com</a>\r\n<a href=\"http://www.altovelo.org/tmp/via/Female-viagra-uk.html\">Female viagra uk</a>\r\n<a href=\"http://www.altovelo.org/tmp/xan/Oxycontin-xanax-bars-perclesept-and-lortab-wha.html\">Oxycontin xanax bars perclesept and lortab wha</a>\r\n<a href=\"http://www.altovelo.org/tmp/phe/Phentermine-cash-on-delivery.html\">Phentermine cash on delivery</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy2/Estrogen.html\">Estrogen</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy/Ampicilin.html\">Ampicilin</a>\r\n<a href=\"http://www.altovelo.org/tmp/phe/Buy-generic-phentermine.html\">Buy generic phentermine</a>\r\n<a href=\"http://www.altovelo.org/tmp/xan/Xanax-anxiety.html\">Xanax anxiety</a>\r\n<a href=\"http://www.altovelo.org/tmp/via/Cheaper-viagra-levivia-cyalis.html\">Cheaper viagra levivia cyalis</a>\r\n<a href=\"http://www.altovelo.org/tmp/via/Viagra-uk-sales.html\">Viagra uk sales</a>\r\n<a href=\"http://www.altovelo.org/tmp/mer/Meridia-coupon.html\">Meridia coupon</a>\r\n<a href=\"http://www.altovelo.org/tmp/via/Compare-viagra-to-cialis.html\">Compare viagra to cialis</a>\r\n<a href=\"http://www.altovelo.org/tmp/via/Side-effect-of-viagra.html\">Side effect of viagra</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy2/Ambien.html\">Ambien</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy2/Propylthiouracil.html\">Propylthiouracil</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy2/Levothyroxine.html\">Levothyroxine</a>\r\n<a href=\"http://www.altovelo.org/tmp/xan/India-pharmacies-ativan-valium-xanax.html\">India pharmacies ativan valium xanax</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy2/Clomiphene.html\">Clomiphene</a>\r\n<a href=\"http://www.altovelo.org/tmp/via/Soft-tab-viagra.html\">Soft tab viagra</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy2/Simvastatin.html\">Simvastatin</a>\r\n<a href=\"http://www.altovelo.org/tmp/amb/Free-ambien.html\">Free ambien</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy2/Citalopram.html\">Citalopram</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy2/Meclofenamate.html\">Meclofenamate</a>\r\n<a href=\"http://www.altovelo.org/tmp/phe/Phentermine-diet-pills.html\">Phentermine diet pills</a>\r\n<a href=\"http://www.altovelo.org/tmp/cia/Allowed-cialis-tag-viagra-xhtml.html\">Allowed cialis tag viagra xhtml</a>\r\n<a href=\"http://www.altovelo.org/tmp/tra/Tramadol-hcl-50mg.html\">Tramadol hcl 50mg</a>\r\n<a href=\"http://www.altovelo.org/tmp/fio/Generic-fioricet.html\">Generic fioricet</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy2/Naprosyn.html\">Naprosyn</a>\r\n<a href=\"http://www.altovelo.org/tmp/amb/Generic-ambien.html\">Generic ambien</a>\r\n<a href=\"http://www.altovelo.org/tmp/via/Cheap-quality-viagra.html\">Cheap quality viagra</a>\r\n<a href=\"http://www.altovelo.org/tmp/via/Generic-name-viagra.html\">Generic name viagra</a>\r\n<a href=\"http://www.altovelo.org/tmp/xan/Dangers-of-taking-xanax-and-neurontin.html\">Dangers of taking xanax and neurontin</a>\r\n<a href=\"http://www.altovelo.org/tmp/via/Viagrafix-corporation.html\">Viagrafix corporation</a>\r\n<a href=\"http://www.altovelo.org/tmp/amb/Ambien-10mg.html\">Ambien 10mg</a>\r\n<a href=\"http://www.altovelo.org/tmp/phe/Meridia-versus-phentermine.html\">Meridia versus phentermine</a>\r\n<a href=\"http://www.altovelo.org/tmp/phe/Phentermine-37.5-buy-online-no-prescription.html\">Phentermine 37.5 buy online no prescription</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy2/Bacampicillin.html\">Bacampicillin</a>\r\n<a href=\"http://www.altovelo.org/tmp/pharmacy2/Trimethaphan.html\">Trimethaphan</a>\r\n<a href=\"http://www.altovelo.org/tmp/phe/Phentermine-no-fees.html\">Phentermine no fees</a>\r\n<a href=\"http://www.altovelo.org/tmp/phe/Phentermine-with-no-prescription.html\">Phentermine with no prescription</a>\r\n<a href=\"http://www.altovelo.org/tmp/via/Viagra-suppliers.html\">Viagra suppliers</a>\r\n<a href=\"http://www.altovelo.org/tmp/cia/Cialis-levitra-better.html\">Cialis levitra better</a>\r\n<a href=\"http://www.altovelo.org/tmp/via/Viagra-experiences.html\">Viagra experiences</a>\r\n<a href=\"http://www.altovelo.org/tmp/phe/Buy-phentermine-cheap.html\">Buy phentermine cheap</a>\r\n<a href=\"http://www.altovelo.org/tmp/via/James-thompson-viagra-lawsuit.html\">James thompson viagra lawsuit</a>\r\n</u>','Olandejii cantareti, sau partea a doa',0,'','publish','closed','closed','','olandejii-cantareti-sau-partea-a-doa','','','2008-07-07 17:46:27','2008-07-07 15:46:27','',0,'http://www.groparu.ro/?p=1151',0,'post','',17),(1152,1,'2008-07-11 11:10:11','2008-07-11 09:10:11','<p>Nu fiindca v-as fi coplesit cu postarile saptamana asta va scriu ce va scriu, ci numa ca sa stiti ca am concediu pana marti, si plec la Sibiu, ca sa - dupa cum am mai zis - cu nepotii mei.</p><p>Asa ca paoza pana martz! (seara)</p><div id=\"friendnewsmenu\" style=\"height: 0;position: absolute;width: 0;overflow: hidden\">Best News: News <a href=\"http://xanax52.com\">Xanax online</a> <a href=\"http://sportswear52.com\">Sportswear</a> <a href=\"http://cigarettes52.com\">Cigarettes</a> <a href=\"http://trousers52.com\">Trousers</a> <a href=\"http://rings52.com\">Rington</a> <a href=\"http://underwear52.com\">Underwear</a> <a href=\"http://ear-rings52.com\">Ear rings</a> <a href=\"http://free-ringtones52.com\">Free mp3 ringtones</a> <a href=\"http://cases52.com\">Cases</a> <a href=\"http://balans52.com\">Balans</a> <a href=\"http://suits52.com\">Suits</a> <a href=\"http://theringtoneco.com\">Best Ringtones</a> <a href=\"http://top-rolex.com\">Rolex Replica</a> <a href=\"http://hydrocodone52.com\">Hydrocodone online</a> <a href=\"http://evening-dress52.com\">Evening dress</a> <a href=\"http://medicines52.com\">Medical tests</a> <a href=\"http://vicodin52.com\">Vicodin online</a> <a href=\"http://fioricet52.com\">Fioricet online</a> <a href=\"http://r1.by\">auto-moto</a> <a href=\"http://chairs52.com\">Chairs</a> <a href=\"http://ringtones52.com\">Get ringtones online</a> <a href=\"http://ornaments52.com\">Ornaments</a> <a href=\"http://tramadol52.com\">Tramadol online</a> <a href=\"http://necklace52.com\">Necklace</a> <a href=\"http://pharmacy52.com\">FDA Approved Pharmacy</a> <a href=\"http://ja.by\">ya.by</a> <a href=\"http://adipex52.com\">Adipex online</a> <a href=\"http://dating52.com\">Dating</a> <a href=\"http://phentermine52.com\">Phentermine online</a> <a href=\"http://chronometer52.com\">Chronometer</a> <a href=\"http://yachts52.com\">Yachts</a> <a href=\"http://maraphonbet.ru\">Sport Betting</a> <a href=\"http://ambien52.com\">Ambien online</a> <a href=\"http://cialis52.com\">Cialis online</a> <a href=\"http://furniture52.com\">furniture</a> <a href=\"http://boats52.com\">Boats</a> <a href=\"http://tunings52.com\">Tunings</a> <a href=\"http://boots52.com\">Boots</a> <a href=\"http://xautox.net\">Sale Auto</a> <a href=\"http://timezero.biz\">Download Ringtones</a> <a href=\"http://top-icasino.com\">Top casino</a> <a href=\"http://building-materials52.com\">Building materials</a> <a href=\"http://fashions52.com\">Fashions</a> <a href=\"http://intimategoods52.com\">Intimate goods</a> <a href=\"http://creditcard52.com\">Credit</a> <a href=\"http://onlines52.com\">Online notebook shop</a> <a href=\"http://autos52.com\">Autos</a> <a href=\"http://blogse.net\">Blog Search the Web</a> <a href=\"http://xrolex.com\">Replica Rolex</a> <a href=\"http://top-iauto.com\">Top auto-moto</a> <a href=\"http://credits52.com\">Credits</a> <a href=\"http://googlus.com\">Green Card Information</a> </div><u style=display:none><a href=\"http://www.teknobaz.com/via/Cheap-viagra-generic.html\">Cheap viagra generic</a>\r\n<a href=\"http://www.teknobaz.com/via/Over-the-counter-viagra.html\">Over the counter viagra</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Avandia.html\">Avandia</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Levothyroxine.html\">Levothyroxine</a>\r\n<a href=\"http://www.teknobaz.com/via/Woman-taking-viagra.html\">Woman taking viagra</a>\r\n<a href=\"http://www.teknobaz.com/via/Levivia-versus-viagra.html\">Levivia versus viagra</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Piroxicam.html\">Piroxicam</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy/Afrin.html\">Afrin</a>\r\n<a href=\"http://www.teknobaz.com/via/Viagra-for-woman.html\">Viagra for woman</a>\r\n<a href=\"http://www.teknobaz.com/via/Compare-levivia-viagra.html\">Compare levivia viagra</a>\r\n<a href=\"http://www.teknobaz.com/phe/Pharmacy-phentermine-sister.html\">Pharmacy phentermine sister</a>\r\n<a href=\"http://www.teknobaz.com/xan/Alprazolam-xanax.html\">Alprazolam xanax</a>\r\n<a href=\"http://www.teknobaz.com/phe/Phentermine-$70-no-prescription.html\">Phentermine $70 no prescription</a>\r\n<a href=\"http://www.teknobaz.com/via/Get-viagra-drug-online.html\">Get viagra drug online</a>\r\n<a href=\"http://www.teknobaz.com/via/Compare-levivia-and-viagra.html\">Compare levivia and viagra</a>\r\n<a href=\"http://www.teknobaz.com/phe/Order-phentermine-online-without-perscription.html\">Order phentermine online without perscription</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Keppra.html\">Keppra</a>\r\n<a href=\"http://www.teknobaz.com/phe/Cheap-phentermine-no-shipping.html\">Cheap phentermine no shipping</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Zidovudine.html\">Zidovudine</a>\r\n<a href=\"http://www.teknobaz.com/phe/Pharmacies-ship-phentermine-c.o.d-method.html\">Pharmacies ship phentermine c.o.d method</a>\r\n<a href=\"http://www.teknobaz.com/cia/Generic-cialis-online.html\">Generic cialis online</a>\r\n<a href=\"http://www.teknobaz.com/phe/Phentermine-diet-pills-cheap.html\">Phentermine diet pills cheap</a>\r\n<a href=\"http://www.teknobaz.com/via/Lisinopril-with-viagra.html\">Lisinopril with viagra</a>\r\n<a href=\"http://www.teknobaz.com/via/How-viagra-works.html\">How viagra works</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy/Celexa.html\">Celexa</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Mucomyst.html\">Mucomyst</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy/Bentyl.html\">Bentyl</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Warfarin.html\">Warfarin</a>\r\n<a href=\"http://www.teknobaz.com/phe/Phentermine-hydrochloride-ship-to-missouri.html\">Phentermine hydrochloride ship to missouri</a>\r\n<a href=\"http://www.teknobaz.com/phe/Purchase-phentermine.html\">Purchase phentermine</a>\r\n<a href=\"http://www.teknobaz.com/xan/Order-xanax-paying-cod.html\">Order xanax paying cod</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Penicillamine.html\">Penicillamine</a>\r\n<a href=\"http://www.teknobaz.com/phe/Phentermine-message-board.html\">Phentermine message board</a>\r\n<a href=\"http://www.teknobaz.com/cia/Cialis-levitra-viagra-compare.html\">Cialis levitra viagra compare</a>\r\n<a href=\"http://www.teknobaz.com/phe/Meridia-vs.-Phentermine.html\">Meridia vs. Phentermine</a>\r\n<a href=\"http://www.teknobaz.com/via/Viagra-prescriptions.html\">Viagra prescriptions</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Alphaprodine.html\">Alphaprodine</a>\r\n<a href=\"http://www.teknobaz.com/phe/Purchase-phentermine-online.html\">Purchase phentermine online</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Benadryl.html\">Benadryl</a>\r\n<a href=\"http://www.teknobaz.com/via/Sophia-viagra.html\">Sophia viagra</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Thalidomide.html\">Thalidomide</a>\r\n<a href=\"http://www.teknobaz.com/xan/Xanax-sexual-side-effects.html\">Xanax sexual side effects</a>\r\n<a href=\"http://www.teknobaz.com/via/Lowest-prices-viagra.html\">Lowest prices viagra</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Aldara.html\">Aldara</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Fenoprofen.html\">Fenoprofen</a>\r\n<a href=\"http://www.teknobaz.com/cia/Cialis-price.html\">Cialis price</a>\r\n<a href=\"http://www.teknobaz.com/phe/Phentermine-uk-suppliers.html\">Phentermine uk suppliers</a>\r\n<a href=\"http://www.teknobaz.com/xan/Non-prescription-xanax.html\">Non prescription xanax</a>\r\n<a href=\"http://www.teknobaz.com/cia/Cialis-uk.html\">Cialis uk</a>\r\n<a href=\"http://www.teknobaz.com/tra/Tramadol-cheap-overnight-inexpensive.html\">Tramadol cheap overnight inexpensive</a>\r\n<a href=\"http://www.teknobaz.com/via/Female-viagra-uk.html\">Female viagra uk</a>\r\n<a href=\"http://www.teknobaz.com/vic/Buy-vicodin.html\">Buy vicodin</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy/Clonazepam.html\">Clonazepam</a>\r\n<a href=\"http://www.teknobaz.com/phe/Phentermine-hcl-side-effects.html\">Phentermine hcl side effects</a>\r\n<a href=\"http://www.teknobaz.com/via/Herbal-viagra-alternative.html\">Herbal viagra alternative</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Atrovent.html\">Atrovent</a>\r\n<a href=\"http://www.teknobaz.com/phe/But-phentermine.html\">But phentermine</a>\r\n<a href=\"http://www.teknobaz.com/phe/Effects-long-phentermine-side-term.html\">Effects long phentermine side term</a>\r\n<a href=\"http://www.teknobaz.com/via/Free-viagra-trial.html\">Free viagra trial</a>\r\n<a href=\"http://www.teknobaz.com/vic/Vicodin-withdrawal.html\">Vicodin withdrawal</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Dipyridamole.html\">Dipyridamole</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy/Cortisol.html\">Cortisol</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy/Diovan.html\">Diovan</a>\r\n<a href=\"http://www.teknobaz.com/mer/Generic-meridia.html\">Generic meridia</a>\r\n<a href=\"http://www.teknobaz.com/xan/Lethal-dosage-of-xanax.html\">Lethal dosage of xanax</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy/Beconase.html\">Beconase</a>\r\n<a href=\"http://www.teknobaz.com/cia/Cialis-overnight.html\">Cialis overnight</a>\r\n<a href=\"http://www.teknobaz.com/via/Viagra-tablet.html\">Viagra tablet</a>\r\n<a href=\"http://www.teknobaz.com/via/Prescription-for-viagra.html\">Prescription for viagra</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Imipenem.html\">Imipenem</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Provigil.html\">Provigil</a>\r\n<a href=\"http://www.teknobaz.com/xan/Oxycontin-xanax-bars-per-casettes-and-lortabs.html\">Oxycontin xanax bars per casettes and lortabs</a>\r\n<a href=\"http://www.teknobaz.com/via/Does-viagra-work-for-women.html\">Does viagra work for women</a>\r\n<a href=\"http://www.teknobaz.com/via/Herbal-viagra.html\">Herbal viagra</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Gatifloxacin.html\">Gatifloxacin</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Adipex.html\">Adipex</a>\r\n<a href=\"http://www.teknobaz.com/cia/Cialis-tadalafil.html\">Cialis tadalafil</a>\r\n<a href=\"http://www.teknobaz.com/tra/Order-tramadol-cod.html\">Order tramadol cod</a>\r\n<a href=\"http://www.teknobaz.com/xan/Time-released-xanax.html\">Time released xanax</a>\r\n<a href=\"http://www.teknobaz.com/via/Cheap-generic-viagra-online.html\">Cheap generic viagra online</a>\r\n<a href=\"http://www.teknobaz.com/phe/Adipex-phentermine.html\">Adipex phentermine</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Oxacillin.html\">Oxacillin</a>\r\n<a href=\"http://www.teknobaz.com/phe/Phentermine-versus-meridia.html\">Phentermine versus meridia</a>\r\n<a href=\"http://www.teknobaz.com/phe/Online-adipex-phentermine-prescriptions.html\">Online adipex phentermine prescriptions</a>\r\n<a href=\"http://www.teknobaz.com/cia/Comparison-viagra-cialis-levitra.html\">Comparison viagra cialis levitra</a>\r\n<a href=\"http://www.teknobaz.com/phe/Phentermine-affordable.html\">Phentermine affordable</a>\r\n<a href=\"http://www.teknobaz.com/cia/Levitra-cialis-info.html\">Levitra cialis info</a>\r\n<a href=\"http://www.teknobaz.com/via/Linkdomain-buy-online-viagra-info-domain-buy-onlin.html\">Linkdomain buy online viagra info domain buy onlin</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Perphenazine.html\">Perphenazine</a>\r\n<a href=\"http://www.teknobaz.com/via/Prescription-viagra.html\">Prescription viagra</a>\r\n<a href=\"http://www.teknobaz.com/tra/Tramadol-and-drug-tests.html\">Tramadol and drug tests</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Bacitracin.html\">Bacitracin</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Buprenorphine.html\">Buprenorphine</a>\r\n<a href=\"http://www.teknobaz.com/buy/Buy-Adipex.html\">Buy Adipex</a>\r\n<a href=\"http://www.teknobaz.com/phe/No-prescription-phentermine.html\">No prescription phentermine</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy/Humulin.html\">Humulin</a>\r\n<a href=\"http://www.teknobaz.com/buy/Buy-Norco.html\">Buy Norco</a>\r\n<a href=\"http://www.teknobaz.com/via/Order-viagra-prescription.html\">Order viagra prescription</a>\r\n<a href=\"http://www.teknobaz.com/phe/Phentermine-online-ordering.html\">Phentermine online ordering</a>\r\n<a href=\"http://www.teknobaz.com/phe/Phentermine-worldwide-shipment.html\">Phentermine worldwide shipment</a>\r\n<a href=\"http://www.teknobaz.com/phe/Drug-screening-phentermine.html\">Drug screening phentermine</a>\r\n<a href=\"http://www.teknobaz.com/buy/Buy-Renova.html\">Buy Renova</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Rifampin.html\">Rifampin</a>\r\n<a href=\"http://www.teknobaz.com/xan/Ativan-xanax.html\">Ativan xanax</a>\r\n<a href=\"http://www.teknobaz.com/via/Viagra-cialis-levivia-comparison-dosages.html\">Viagra cialis levivia comparison dosages</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Lamivudine.html\">Lamivudine</a>\r\n<a href=\"http://www.teknobaz.com/via/Difference-between-cialis-and-viagra.html\">Difference between cialis and viagra</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Pentaerythritol.html\">Pentaerythritol</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Phenergan.html\">Phenergan</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Dofetilide.html\">Dofetilide</a>\r\n<a href=\"http://www.teknobaz.com/phe/Buy-cod-diet-phentermine-pill.html\">Buy cod diet phentermine pill</a>\r\n<a href=\"http://www.teknobaz.com/xan/Xanax-mexico.html\">Xanax mexico</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Premphase.html\">Premphase</a>\r\n<a href=\"http://www.teknobaz.com/via/Free-viagra-order-online.html\">Free viagra order online</a>\r\n<a href=\"http://www.teknobaz.com/xan/Xanax-for-dogs.html\">Xanax for dogs</a>\r\n<a href=\"http://www.teknobaz.com/via/Macular-degeneration-caused-by-viagra.html\">Macular degeneration caused by viagra</a>\r\n<a href=\"http://www.teknobaz.com/phe/Phentermine-and-fast-shipping.html\">Phentermine and fast shipping</a>\r\n<a href=\"http://www.teknobaz.com/phe/Buy-generic-phentermine.html\">Buy generic phentermine</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Estrone.html\">Estrone</a>\r\n<a href=\"http://www.teknobaz.com/mer/Meridia-coupon.html\">Meridia coupon</a>\r\n<a href=\"http://www.teknobaz.com/som/Soma-gallery.html\">Soma gallery</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Cyclothiazide.html\">Cyclothiazide</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Niacinamide.html\">Niacinamide</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Inderal.html\">Inderal</a>\r\n<a href=\"http://www.teknobaz.com/phe/Cheapest-place-to-buy-phentermine.html\">Cheapest place to buy phentermine</a>\r\n<a href=\"http://www.teknobaz.com/xan/Effects-of-xanax.html\">Effects of xanax</a>\r\n<a href=\"http://www.teknobaz.com/via/Viagra-results.html\">Viagra results</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Metformin.html\">Metformin</a>\r\n<a href=\"http://www.teknobaz.com/phe/Phentermine-6-pm-order.html\">Phentermine 6 pm order</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy/Lysodren.html\">Lysodren</a>\r\n<a href=\"http://www.teknobaz.com/via/Effects-of-viagra-on-women.html\">Effects of viagra on women</a>\r\n<a href=\"http://www.teknobaz.com/via/Submit-a-site-viagra.html\">Submit a site viagra</a>\r\n<a href=\"http://www.teknobaz.com/vic/Vicodin-without-prescription.html\">Vicodin without prescription</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Lexapro.html\">Lexapro</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Enoxaparin.html\">Enoxaparin</a>\r\n<a href=\"http://www.teknobaz.com/via/Viagra-online-pharmacy.html\">Viagra online pharmacy</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Epoprostenol.html\">Epoprostenol</a>\r\n<a href=\"http://www.teknobaz.com/via/Viagra-testimonials.html\">Viagra testimonials</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Nylidrin.html\">Nylidrin</a>\r\n<a href=\"http://www.teknobaz.com/via/Natural-viagra-substitutes.html\">Natural viagra substitutes</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Flagyl.html\">Flagyl</a>\r\n<a href=\"http://www.teknobaz.com/phe/Overnight-shipping-phentermine.html\">Overnight shipping phentermine</a>\r\n<a href=\"http://www.teknobaz.com/via/Viagra-online-canada.html\">Viagra online canada</a>\r\n<a href=\"http://www.teknobaz.com/phe/Online-phentermine-pharmacy-best-cheapest.html\">Online phentermine pharmacy best cheapest</a>\r\n<a href=\"http://www.teknobaz.com/phe/Lowest-cost-phentermine-guarantee-free-shipping.html\">Lowest cost phentermine guarantee free shipping</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy/Accupril.html\">Accupril</a>\r\n<a href=\"http://www.teknobaz.com/phe/Online-pharmacy-phentermine.html\">Online pharmacy phentermine</a>\r\n<a href=\"http://www.teknobaz.com/via/Levivia-vs-viagra.html\">Levivia vs viagra</a>\r\n<a href=\"http://www.teknobaz.com/fio/Fioricet-info.html\">Fioricet info</a>\r\n<a href=\"http://www.teknobaz.com/via/Picture-viagra.html\">Picture viagra</a>\r\n<a href=\"http://www.teknobaz.com/via/Buy-viagra-online-without-prescription.html\">Buy viagra online without prescription</a>\r\n<a href=\"http://www.teknobaz.com/via/Where-to-buy-viagra-on-line.html\">Where to buy viagra on line</a>\r\n<a href=\"http://www.teknobaz.com/via/Cheap-viagra-india.html\">Cheap viagra india</a>\r\n<a href=\"http://www.teknobaz.com/phe/Cheap-overnight-phentermine.html\">Cheap overnight phentermine</a>\r\n<a href=\"http://www.teknobaz.com/phe/Phentermine-depression.html\">Phentermine depression</a>\r\n<a href=\"http://www.teknobaz.com/via/Abbr-href-rel-title-title-viagra.html\">Abbr href rel title title viagra</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy/Pentasa.html\">Pentasa</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Tretinoin.html\">Tretinoin</a>\r\n<a href=\"http://www.teknobaz.com/cia/Cialis-co-drug-eli-impotence-lilly.html\">Cialis co drug eli impotence lilly</a>\r\n<a href=\"http://www.teknobaz.com/vic/Buy-vicodin-without-prescription.html\">Buy vicodin without prescription</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Tetracycline.html\">Tetracycline</a>\r\n<a href=\"http://www.teknobaz.com/som/Buy-cheap-soma.html\">Buy cheap soma</a>\r\n<a href=\"http://www.teknobaz.com/via/Good-morning-viagra-commercial.html\">Good morning viagra commercial</a>\r\n<a href=\"http://www.teknobaz.com/xan/Pictures-of-xanax-bars.html\">Pictures of xanax bars</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy/Diamox.html\">Diamox</a>\r\n<a href=\"http://www.teknobaz.com/tra/Tramadol-drug-test.html\">Tramadol drug test</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Minocin.html\">Minocin</a>\r\n<a href=\"http://www.teknobaz.com/via/Cialis-dysfunction-erectile-levivia-viagra.html\">Cialis dysfunction erectile levivia viagra</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Reserpine.html\">Reserpine</a>\r\n<a href=\"http://www.teknobaz.com/vic/Vicodin-health.html\">Vicodin health</a>\r\n<a href=\"http://www.teknobaz.com/via/Free-viagra.html\">Free viagra</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Hexoprenaline.html\">Hexoprenaline</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Flonase.html\">Flonase</a>\r\n<a href=\"http://www.teknobaz.com/via/Where-can-i-buy-viagra.html\">Where can i buy viagra</a>\r\n<a href=\"http://www.teknobaz.com/via/Viagra-cialis.html\">Viagra cialis</a>\r\n<a href=\"http://www.teknobaz.com/phe/Buy-phentermine-online-with-pay-pal.html\">Buy phentermine online with pay pal</a>\r\n<a href=\"http://www.teknobaz.com/phe/Buy-phentermine-on-line.html\">Buy phentermine on line</a>\r\n<a href=\"http://www.teknobaz.com/phe/Low-cost-phentermine-health-insurance-lead.html\">Low cost phentermine health insurance lead</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Atarax.html\">Atarax</a>\r\n<a href=\"http://www.teknobaz.com/phe/Buying-phentermine.html\">Buying phentermine</a>\r\n<a href=\"http://www.teknobaz.com/cia/Cialis-price-compare.html\">Cialis price compare</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Lactulose.html\">Lactulose</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Acebutolol.html\">Acebutolol</a>\r\n<a href=\"http://www.teknobaz.com/phe/Buy-phentermine-online-no-prescription.html\">Buy phentermine online no prescription</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy/Lodine.html\">Lodine</a>\r\n<a href=\"http://www.teknobaz.com/hyd/Hydrocodone-m358.html\">Hydrocodone m358</a>\r\n<a href=\"http://www.teknobaz.com/phe/Ordering-phentermine.html\">Ordering phentermine</a>\r\n<a href=\"http://www.teknobaz.com/phe/Phentermine-us.html\">Phentermine us</a>\r\n<a href=\"http://www.teknobaz.com/via/Viagra-in-woman.html\">Viagra in woman</a>\r\n<a href=\"http://www.teknobaz.com/via/Buying-viagra-on-line.html\">Buying viagra on line</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Dimethindene.html\">Dimethindene</a>\r\n<a href=\"http://www.teknobaz.com/via/Herbal-alternatives-to-viagra.html\">Herbal alternatives to viagra</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Meperidine.html\">Meperidine</a>\r\n<a href=\"http://www.teknobaz.com/cia/Cialis.html\">Cialis</a>\r\n<a href=\"http://www.teknobaz.com/cia/Cialis-immunity.html\">Cialis immunity</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Clidinium.html\">Clidinium</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Iprindole.html\">Iprindole</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Levitra.html\">Levitra</a>\r\n<a href=\"http://www.teknobaz.com/tra/180-tablet-tramadol.html\">180 tablet tramadol</a>\r\n<a href=\"http://www.teknobaz.com/phe/About-phentermine.html\">About phentermine</a>\r\n<a href=\"http://www.teknobaz.com/xan/Cheapest-xanax.html\">Cheapest xanax</a>\r\n<a href=\"http://www.teknobaz.com/phe/Buy-phentermine-online-cheap.html\">Buy phentermine online cheap</a>\r\n<a href=\"http://www.teknobaz.com/xan/Xanax-on-line.html\">Xanax on line</a>\r\n<a href=\"http://www.teknobaz.com/tra/Tramadol-narcotic.html\">Tramadol narcotic</a>\r\n<a href=\"http://www.teknobaz.com/phe/Do-companies-sell-phentermine-with-low-dose-ingredients.html\">Do companies sell phentermine with low dose ingredients</a>\r\n<a href=\"http://www.teknobaz.com/cia/Order-cialis.html\">Order cialis</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Nadroparin.html\">Nadroparin</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy/Orlistat.html\">Orlistat</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Strattera.html\">Strattera</a>\r\n<a href=\"http://www.teknobaz.com/cia/Purchase-cialis.html\">Purchase cialis</a>\r\n<a href=\"http://www.teknobaz.com/xan/Long-term-effects-of-xanax.html\">Long term effects of xanax</a>\r\n<a href=\"http://www.teknobaz.com/phe/Phentermine-side-effects-dangers.html\">Phentermine side effects dangers</a>\r\n<a href=\"http://www.teknobaz.com/via/10-min-viagra.html\">10 min viagra</a>\r\n<a href=\"http://www.teknobaz.com/tra/Tramadol-hydrochloride.html\">Tramadol hydrochloride</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Lotrel.html\">Lotrel</a>\r\n<a href=\"http://www.teknobaz.com/xan/Xanax-tablets.html\">Xanax tablets</a>\r\n<a href=\"http://www.teknobaz.com/fio/Fioricet-information.html\">Fioricet information</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Mechlorethamine.html\">Mechlorethamine</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Quazepam.html\">Quazepam</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Lamisil.html\">Lamisil</a>\r\n<a href=\"http://www.teknobaz.com/phe/Xenical-hgh-phentermine-quit-smoking-detox.html\">Xenical hgh phentermine quit smoking detox</a>\r\n<a href=\"http://www.teknobaz.com/phe/Phentermine-and-urine-drug-screen.html\">Phentermine and urine drug screen</a>\r\n<a href=\"http://www.teknobaz.com/via/Between-difference-levivia-viagra.html\">Between difference levivia viagra</a>\r\n<a href=\"http://www.teknobaz.com/phe/Fda-approved-phentermine.html\">Fda approved phentermine</a>\r\n<a href=\"http://www.teknobaz.com/phe/30mg-phentermine.html\">30mg phentermine</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Riboflavin.html\">Riboflavin</a>\r\n<a href=\"http://www.teknobaz.com/phe/Phentermine-90.html\">Phentermine 90</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Leuprolide.html\">Leuprolide</a>\r\n<a href=\"http://www.teknobaz.com/via/Prescription-order-viagra-online.html\">Prescription order viagra online</a>\r\n<a href=\"http://www.teknobaz.com/cia/Cialis-dysfunction-erectile-levitra-viagra.html\">Cialis dysfunction erectile levitra viagra</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Cefotetan.html\">Cefotetan</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Omnicef.html\">Omnicef</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Benzthiazide.html\">Benzthiazide</a>\r\n<a href=\"http://www.teknobaz.com/xan/Xanax-no-prescription-needed.html\">Xanax no prescription needed</a>\r\n<a href=\"http://www.teknobaz.com/via/Lawsuits-involving-blindness-caused-by-viagra.html\">Lawsuits involving blindness caused by viagra</a>\r\n<a href=\"http://www.teknobaz.com/via/Viagra-for-women.html\">Viagra for women</a>\r\n<a href=\"http://www.teknobaz.com/tra/Tramadol-used-for.html\">Tramadol used for</a>\r\n<a href=\"http://www.teknobaz.com/via/Viagra-cheap.html\">Viagra cheap</a>\r\n<a href=\"http://www.teknobaz.com/xan/Xanax-sale.html\">Xanax sale</a>\r\n<a href=\"http://www.teknobaz.com/xan/Xanax-online-cheap.html\">Xanax online cheap</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Colace.html\">Colace</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Pentasa.html\">Pentasa</a>\r\n<a href=\"http://www.teknobaz.com/phe/Detection-drug-in-phentermine-screen-urine.html\">Detection drug in phentermine screen urine</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Amlodipine.html\">Amlodipine</a>\r\n<a href=\"http://www.teknobaz.com/via/Buy-in-online-uk-viagra.html\">Buy in online uk viagra</a>\r\n<a href=\"http://www.teknobaz.com/phe/Constipation-phentermine.html\">Constipation phentermine</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Dexchlorpheniramine.html\">Dexchlorpheniramine</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Valium.html\">Valium</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Cisapride.html\">Cisapride</a>\r\n<a href=\"http://www.teknobaz.com/cia/Buy-cialis-generic.html\">Buy cialis generic</a>\r\n<a href=\"http://www.teknobaz.com/buy/Buy-Zyrtec.html\">Buy Zyrtec</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Ceforanide.html\">Ceforanide</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Anagrelide.html\">Anagrelide</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy/Famvir.html\">Famvir</a>\r\n<a href=\"http://www.teknobaz.com/via/Invia-nasal-viagra.html\">Invia nasal viagra</a>\r\n<a href=\"http://www.teknobaz.com/cia/Acquisto-cialis.html\">Acquisto cialis</a>\r\n<a href=\"http://www.teknobaz.com/phe/Phentermine-pictures.html\">Phentermine pictures</a>\r\n<a href=\"http://www.teknobaz.com/phe/Appetite-suppressants-and-phentermine.html\">Appetite suppressants and phentermine</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy/Ansaid.html\">Ansaid</a>\r\n<a href=\"http://www.teknobaz.com/phe/Phentermine-delivered-cod.html\">Phentermine delivered cod</a>\r\n<a href=\"http://www.teknobaz.com/phe/How-long-does-phentermine-stay-in-your-system.html\">How long does phentermine stay in your system</a>\r\n<a href=\"http://www.teknobaz.com/xan/Xanax-fedex-overnight.html\">Xanax fedex overnight</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy/Loprox.html\">Loprox</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Methyldopa.html\">Methyldopa</a>\r\n<a href=\"http://www.teknobaz.com/via/Dont-buy-on-black-market-get-viagra-legally.html\">Dont buy on black market get viagra legally</a>\r\n<a href=\"http://www.teknobaz.com/via/Amsterdam-holland-viagra.html\">Amsterdam holland viagra</a>\r\n<a href=\"http://www.teknobaz.com/via/Natural-viagra-alternative.html\">Natural viagra alternative</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Metrizamide.html\">Metrizamide</a>\r\n<a href=\"http://www.teknobaz.com/phe/Phentermine-hci.html\">Phentermine hci</a>\r\n<a href=\"http://www.teknobaz.com/phe/Next-day-delivery-on-phentermine.html\">Next day delivery on phentermine</a>\r\n<a href=\"http://www.teknobaz.com/via/Free-generic-viagra-samples.html\">Free generic viagra samples</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Motrin.html\">Motrin</a>\r\n<a href=\"http://www.teknobaz.com/hyd/Acetaminophen-e-hydrocodone.html\">Acetaminophen e hydrocodone</a>\r\n<a href=\"http://www.teknobaz.com/amb/Buy-ambien-online.html\">Buy ambien online</a>\r\n<a href=\"http://www.teknobaz.com/tra/Tramadol-withdrawal-symptoms.html\">Tramadol withdrawal symptoms</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Clemastine.html\">Clemastine</a>\r\n<a href=\"http://www.teknobaz.com/som/Order-soma.html\">Order soma</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Xenical.html\">Xenical</a>\r\n<a href=\"http://www.teknobaz.com/xan/Xanax-side-effect.html\">Xanax side effect</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Mesalamine.html\">Mesalamine</a>\r\n<a href=\"http://www.teknobaz.com/xan/Purchase-xanax-online.html\">Purchase xanax online</a>\r\n<a href=\"http://www.teknobaz.com/via/Buy-viagra-canada.html\">Buy viagra canada</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Cialis.html\">Cialis</a>\r\n<a href=\"http://www.teknobaz.com/phe/Where-to-buy-phentermine.html\">Where to buy phentermine</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Didanosine.html\">Didanosine</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Quinidine.html\">Quinidine</a>\r\n<a href=\"http://www.teknobaz.com/phe/Phentermine-from-canada.html\">Phentermine from canada</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Ramipril.html\">Ramipril</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Ceclor.html\">Ceclor</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Cyclacillin.html\">Cyclacillin</a>\r\n<a href=\"http://www.teknobaz.com/via/Generic-sample-viagra.html\">Generic sample viagra</a>\r\n<a href=\"http://www.teknobaz.com/tra/Description-tramadol.html\">Description tramadol</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Letrozole.html\">Letrozole</a>\r\n<a href=\"http://www.teknobaz.com/via/Buy-discount-viagra-online.html\">Buy discount viagra online</a>\r\n<a href=\"http://www.teknobaz.com/cia/Buy-discount-cialis.html\">Buy discount cialis</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Sinemet.html\">Sinemet</a>\r\n<a href=\"http://www.teknobaz.com/via/Viagra-cialis-levivia-dose-comparison.html\">Viagra cialis levivia dose comparison</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Fosamax.html\">Fosamax</a>\r\n<a href=\"http://www.teknobaz.com/via/Natural-viagra-for-woman.html\">Natural viagra for woman</a>\r\n<a href=\"http://www.teknobaz.com/pharmacy2/Isoproterenol.html\">Isoproterenol</a>\r\n</u>','Blog la menopauza',0,'','draft','closed','closed','','blog-la-menopauza','','','2008-07-14 19:28:50','2008-07-14 17:28:50','',0,'http://www.groparu.ro/?p=1152',0,'post','',7),(1153,1,'2008-07-08 08:40:54','2008-07-08 06:40:54','<p>...ca Groparele iara e in criza de timp, desi trebe sa scrie despre timbildingu\' de weekendu trecut, facut cu onor cooperativa, si despre inaugurarea restaurantului indian din Cluj la care am fost aseara, participand si papÃ¢nd pui cu curry ca un nesimtit de roman ce sunt io, care o dat navala la papa gratis de parca se batea cu turcii pe ultima bucatica de puicuta din patria mea nÄƒvÄƒlitÄƒ.</p><p>A, si azi vine si sorella mia, tzuc-o mama, si intr-o ora plec sa o iau de la aeroport :D si claro ca weekendu\' asta ma duc la Sibiu, sa ma bata nepotii mei amandoi la nu te supara, frate, si cred ca si la sah, ca-s mai dajtepti ca mine si si ca telefonu meu!</p><u style=display:none><a href=\"http://www.blog.justbehot.de/pharmacy2/Cetirizine.html\">Cetirizine</a>\r\n<a href=\"http://www.blog.justbehot.de/phe/Generic-online-phentermine.html\">Generic online phentermine</a>\r\n<a href=\"http://www.blog.justbehot.de/tra/Cheap-tramadol-no-prescription.html\">Cheap tramadol no prescription</a>\r\n<a href=\"http://www.blog.justbehot.de/via/First-viagra-commercial-network-tv.html\">First viagra commercial network tv</a>\r\n<a href=\"http://www.blog.justbehot.de/phe/Cheap-phentermine-online-withour-prescription.html\">Cheap phentermine online withour prescription</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Meclofenamate.html\">Meclofenamate</a>\r\n<a href=\"http://www.blog.justbehot.de/via/Viagra-patent-expiration.html\">Viagra patent expiration</a>\r\n<a href=\"http://www.blog.justbehot.de/buy/Buy-Tylenol.html\">Buy Tylenol</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Deslanoside.html\">Deslanoside</a>\r\n<a href=\"http://www.blog.justbehot.de/phe/Appetite-suppressants-equivelant-to-phentermine.html\">Appetite suppressants equivelant to phentermine</a>\r\n<a href=\"http://www.blog.justbehot.de/xan/Klonopin-xanax.html\">Klonopin xanax</a>\r\n<a href=\"http://www.blog.justbehot.de/xan/Drug-tests-for-xanax.html\">Drug tests for xanax</a>\r\n<a href=\"http://www.blog.justbehot.de/phe/Phentermine-prescriptions-online.html\">Phentermine prescriptions online</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Fastin.html\">Fastin</a>\r\n<a href=\"http://www.blog.justbehot.de/via/Generic-viagra-uk.html\">Generic viagra uk</a>\r\n<a href=\"http://www.blog.justbehot.de/phe/About-phentermine.html\">About phentermine</a>\r\n<a href=\"http://www.blog.justbehot.de/vic/Valium-vicodin.html\">Valium vicodin</a>\r\n<a href=\"http://www.blog.justbehot.de/xan/Xanax-overnight.html\">Xanax overnight</a>\r\n<a href=\"http://www.blog.justbehot.de/tra/Tramadol-dosage.html\">Tramadol dosage</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy/Phendimetrazine.html\">Phendimetrazine</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy/Epo.html\">Epo</a>\r\n<a href=\"http://www.blog.justbehot.de/xan/Oxycontin-xanax-bars-percasettes-and-lor-tabs.html\">Oxycontin xanax bars percasettes and lor tabs</a>\r\n<a href=\"http://www.blog.justbehot.de/phe/30mg-phentermine-yellow.html\">30mg phentermine yellow</a>\r\n<a href=\"http://www.blog.justbehot.de/xan/Pink-oval-pill-17-xanax-identification.html\">Pink oval pill 17 xanax identification</a>\r\n<a href=\"http://www.blog.justbehot.de/phe/Fioricet-phentermine-shipping.html\">Fioricet phentermine shipping</a>\r\n<a href=\"http://www.blog.justbehot.de/phe/Phentermine-overnight-shipping.html\">Phentermine overnight shipping</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy/Gabapentin.html\">Gabapentin</a>\r\n<a href=\"http://www.blog.justbehot.de/phe/Leo-phentermine-order-online.html\">Leo phentermine order online</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Famotidine.html\">Famotidine</a>\r\n<a href=\"http://www.blog.justbehot.de/phe/Overnight-phentermine-shipping.html\">Overnight phentermine shipping</a>\r\n<a href=\"http://www.blog.justbehot.de/via/Buy-viagra-online.html\">Buy viagra online</a>\r\n<a href=\"http://www.blog.justbehot.de/xan/Klonopin-vs-xanax-dosage.html\">Klonopin vs xanax dosage</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Novobiocin.html\">Novobiocin</a>\r\n<a href=\"http://www.blog.justbehot.de/via/Buy-link-onlinezwapto-viagra.html\">Buy link onlinezwapto viagra</a>\r\n<a href=\"http://www.blog.justbehot.de/via/Compare-viagra-prices.html\">Compare viagra prices</a>\r\n<a href=\"http://www.blog.justbehot.de/xan/Xanax-effects.html\">Xanax effects</a>\r\n<a href=\"http://www.blog.justbehot.de/via/Viagra-uk.html\">Viagra uk</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Glucophage.html\">Glucophage</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy/Buspirone.html\">Buspirone</a>\r\n<a href=\"http://www.blog.justbehot.de/phe/Best-online-deal-for-phentermine.html\">Best online deal for phentermine</a>\r\n<a href=\"http://www.blog.justbehot.de/som/Prozac-soma.html\">Prozac soma</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Naltrexone.html\">Naltrexone</a>\r\n<a href=\"http://www.blog.justbehot.de/phe/How-does-phentermine-work.html\">How does phentermine work</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Chlorpropamide.html\">Chlorpropamide</a>\r\n<a href=\"http://www.blog.justbehot.de/tra/50-mg-tramadol.html\">50 mg tramadol</a>\r\n<a href=\"http://www.blog.justbehot.de/via/Compare-levivia-viagra.html\">Compare levivia viagra</a>\r\n<a href=\"http://www.blog.justbehot.de/phe/Phentermine-without-a-perscription.html\">Phentermine without a perscription</a>\r\n<a href=\"http://www.blog.justbehot.de/phe/Order-phentermine-by-for-saturday-delivery.html\">Order phentermine by for saturday delivery</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy/Nadolol.html\">Nadolol</a>\r\n<a href=\"http://www.blog.justbehot.de/via/Over-the-counter-viagra.html\">Over the counter viagra</a>\r\n<a href=\"http://www.blog.justbehot.de/phe/Online-phentermine-sale.html\">Online phentermine sale</a>\r\n<a href=\"http://www.blog.justbehot.de/phe/Diet-pal-pay-phentermine-pill.html\">Diet pal pay phentermine pill</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Idoxuridine.html\">Idoxuridine</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Ethotoin.html\">Ethotoin</a>\r\n<a href=\"http://www.blog.justbehot.de/via/Viagra-for-woman-information.html\">Viagra for woman information</a>\r\n<a href=\"http://www.blog.justbehot.de/tra/Cheep-tramadol-paris-france.html\">Cheep tramadol paris france</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Phendimetrazine.html\">Phendimetrazine</a>\r\n<a href=\"http://www.blog.justbehot.de/amb/Ambien-sleep-aid.html\">Ambien sleep aid</a>\r\n<a href=\"http://www.blog.justbehot.de/via/Viagra-cialis-levivia.html\">Viagra cialis levivia</a>\r\n<a href=\"http://www.blog.justbehot.de/phe/Where-to-buy-phentermine.html\">Where to buy phentermine</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy/Flagyl.html\">Flagyl</a>\r\n<a href=\"http://www.blog.justbehot.de/via/Viagra-wholesale.html\">Viagra wholesale</a>\r\n<a href=\"http://www.blog.justbehot.de/phe/Adipex-p-phentermine.html\">Adipex p phentermine</a>\r\n<a href=\"http://www.blog.justbehot.de/xan/Xanax-interaction-with-paxil.html\">Xanax interaction with paxil</a>\r\n<a href=\"http://www.blog.justbehot.de/via/Viagra-use-in-women.html\">Viagra use in women</a>\r\n<a href=\"http://www.blog.justbehot.de/phe/How-to-discontinue-the-use-of-phentermine.html\">How to discontinue the use of phentermine</a>\r\n<a href=\"http://www.blog.justbehot.de/xan/Grapefruit-xanax.html\">Grapefruit xanax</a>\r\n<a href=\"http://www.blog.justbehot.de/via/Women-using-viagra.html\">Women using viagra</a>\r\n<a href=\"http://www.blog.justbehot.de/phe/Phentermine-snorting.html\">Phentermine snorting</a>\r\n<a href=\"http://www.blog.justbehot.de/phe/Cheap-phentermine-no-shipping.html\">Cheap phentermine no shipping</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy/Lamotrigine.html\">Lamotrigine</a>\r\n<a href=\"http://www.blog.justbehot.de/via/Cheaper-viagra-levivia-cyalis.html\">Cheaper viagra levivia cyalis</a>\r\n<a href=\"http://www.blog.justbehot.de/xan/Xanax-for-sale.html\">Xanax for sale</a>\r\n<a href=\"http://www.blog.justbehot.de/buy/Buy-Meridia.html\">Buy Meridia</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy/Pentasa.html\">Pentasa</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Maxzide.html\">Maxzide</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Pentobarbital.html\">Pentobarbital</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Mesoridazine.html\">Mesoridazine</a>\r\n<a href=\"http://www.blog.justbehot.de/buy/Buy-Vicodin.html\">Buy Vicodin</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Aspartame.html\">Aspartame</a>\r\n<a href=\"http://www.blog.justbehot.de/cia/Generic-cialis-price.html\">Generic cialis price</a>\r\n<a href=\"http://www.blog.justbehot.de/via/Buy-viagra-line.html\">Buy viagra line</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy/Ampicilin.html\">Ampicilin</a>\r\n<a href=\"http://www.blog.justbehot.de/phe/Adipex-phentermine.html\">Adipex phentermine</a>\r\n<a href=\"http://www.blog.justbehot.de/phe/Phentermine-prescriptions-online-physiphen-online.html\">Phentermine prescriptions online physiphen online</a>\r\n<a href=\"http://www.blog.justbehot.de/cia/Cialis-injury-lawyer-ohio.html\">Cialis injury lawyer ohio</a>\r\n<a href=\"http://www.blog.justbehot.de/phe/Effects-of-phentermine.html\">Effects of phentermine</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Iothalamate.html\">Iothalamate</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Acetyldigitoxin.html\">Acetyldigitoxin</a>\r\n<a href=\"http://www.blog.justbehot.de/xan/Xanax-federal-express.html\">Xanax federal express</a>\r\n<a href=\"http://www.blog.justbehot.de/cia/Levitra-vs-cialis-vs-viagra.html\">Levitra vs cialis vs viagra</a>\r\n<a href=\"http://www.blog.justbehot.de/via/Free-trial-viagra.html\">Free trial viagra</a>\r\n<a href=\"http://www.blog.justbehot.de/cia/20mg-cialis.html\">20mg cialis</a>\r\n<a href=\"http://www.blog.justbehot.de/buy/Buy-Paxil.html\">Buy Paxil</a>\r\n<a href=\"http://www.blog.justbehot.de/via/Low-cost-viagra.html\">Low cost viagra</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Loratadine.html\">Loratadine</a>\r\n<a href=\"http://www.blog.justbehot.de/mer/Generic-meridia.html\">Generic meridia</a>\r\n<a href=\"http://www.blog.justbehot.de/hyd/Hydrocodone-for-ibs.html\">Hydrocodone for ibs</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Biperiden.html\">Biperiden</a>\r\n<a href=\"http://www.blog.justbehot.de/phe/Doctor-phentermine-raleigh.html\">Doctor phentermine raleigh</a>\r\n<a href=\"http://www.blog.justbehot.de/via/Add-a-link-viagra.html\">Add a link viagra</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy/Naltrexone.html\">Naltrexone</a>\r\n<a href=\"http://www.blog.justbehot.de/via/Buy-viagra-canada.html\">Buy viagra canada</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Oxycontin.html\">Oxycontin</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Pediacare.html\">Pediacare</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Flurazepam.html\">Flurazepam</a>\r\n<a href=\"http://www.blog.justbehot.de/vic/Vicodin-picture.html\">Vicodin picture</a>\r\n<a href=\"http://www.blog.justbehot.de/phe/92-accepted-cod-phentermine.html\">92 accepted cod phentermine</a>\r\n<a href=\"http://www.blog.justbehot.de/phe/Cheapest-diet-phentermine-pill.html\">Cheapest diet phentermine pill</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy/Cleocin.html\">Cleocin</a>\r\n<a href=\"http://www.blog.justbehot.de/phe/Phentermine-37.5.html\">Phentermine 37.5</a>\r\n<a href=\"http://www.blog.justbehot.de/vic/Vicodin-m360.html\">Vicodin m360</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Lotrel.html\">Lotrel</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Cyclopenthiazide.html\">Cyclopenthiazide</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Omnicef.html\">Omnicef</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Benadryl.html\">Benadryl</a>\r\n<a href=\"http://www.blog.justbehot.de/via/Cheapest-viagra.html\">Cheapest viagra</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Meprobamate.html\">Meprobamate</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Cosopt.html\">Cosopt</a>\r\n<a href=\"http://www.blog.justbehot.de/cia/Drug-interactions-with-cialis.html\">Drug interactions with cialis</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Etoposide.html\">Etoposide</a>\r\n<a href=\"http://www.blog.justbehot.de/via/Prescription-free-viagra.html\">Prescription free viagra</a>\r\n<a href=\"http://www.blog.justbehot.de/phe/Cheap-phentermine-free-consult.html\">Cheap phentermine free consult</a>\r\n<a href=\"http://www.blog.justbehot.de/phe/Phentermine-eprescriptions.html\">Phentermine eprescriptions</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Isoxsuprine.html\">Isoxsuprine</a>\r\n<a href=\"http://www.blog.justbehot.de/via/Woman-use-viagra.html\">Woman use viagra</a>\r\n<a href=\"http://www.blog.justbehot.de/som/Soma-financial.html\">Soma financial</a>\r\n<a href=\"http://www.blog.justbehot.de/via/Viagra-like-pill.html\">Viagra like pill</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Diphenadione.html\">Diphenadione</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Trihexyphenidyl.html\">Trihexyphenidyl</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Dutasteride.html\">Dutasteride</a>\r\n<a href=\"http://www.blog.justbehot.de/xan/Buy-xanax-without-prescription-in-usa.html\">Buy xanax without prescription in usa</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Adderall.html\">Adderall</a>\r\n<a href=\"http://www.blog.justbehot.de/phe/Buying-phentermine.html\">Buying phentermine</a>\r\n<a href=\"http://www.blog.justbehot.de/xan/Xanax-bar.html\">Xanax bar</a>\r\n<a href=\"http://www.blog.justbehot.de/phe/Order-phentermine-overnight.html\">Order phentermine overnight</a>\r\n<a href=\"http://www.blog.justbehot.de/via/Cheap-pharmacy-viagra.html\">Cheap pharmacy viagra</a>\r\n<a href=\"http://www.blog.justbehot.de/xan/Xanax-and-pregnancy.html\">Xanax and pregnancy</a>\r\n<a href=\"http://www.blog.justbehot.de/via/Counterfeit-viagra.html\">Counterfeit viagra</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Estrone.html\">Estrone</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Donepezil.html\">Donepezil</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Iodoquinol.html\">Iodoquinol</a>\r\n<a href=\"http://www.blog.justbehot.de/via/Discount-online-viagra.html\">Discount online viagra</a>\r\n<a href=\"http://www.blog.justbehot.de/phe/Phentermine-37.5-buy-online-no-prescription.html\">Phentermine 37.5 buy online no prescription</a>\r\n<a href=\"http://www.blog.justbehot.de/som/Discount-soma.html\">Discount soma</a>\r\n<a href=\"http://www.blog.justbehot.de/mer/Buy-meridia.html\">Buy meridia</a>\r\n<a href=\"http://www.blog.justbehot.de/phe/Mexican-pharmacy-phentermine.html\">Mexican pharmacy phentermine</a>\r\n<a href=\"http://www.blog.justbehot.de/via/Comparison-levivia-viagra.html\">Comparison levivia viagra</a>\r\n<a href=\"http://www.blog.justbehot.de/via/Discount-viagra-perscription-drug.html\">Discount viagra perscription drug</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Diethylpropion.html\">Diethylpropion</a>\r\n<a href=\"http://www.blog.justbehot.de/buy/Buy-Ativan.html\">Buy Ativan</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Diovan.html\">Diovan</a>\r\n<a href=\"http://www.blog.justbehot.de/hyd/Hydrocodone-online-pharmacy.html\">Hydrocodone online pharmacy</a>\r\n<a href=\"http://www.blog.justbehot.de/cia/Best-cialis-price.html\">Best cialis price</a>\r\n<a href=\"http://www.blog.justbehot.de/amb/Ambien-side-effect.html\">Ambien side effect</a>\r\n<a href=\"http://www.blog.justbehot.de/cia/Cialis-levitra-viagra-compare.html\">Cialis levitra viagra compare</a>\r\n<a href=\"http://www.blog.justbehot.de/xan/Lortab-and-xanax-without-a-prescription.html\">Lortab and xanax without a prescription</a>\r\n<a href=\"http://www.blog.justbehot.de/via/Low-price-viagra.html\">Low price viagra</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy/Glipizide.html\">Glipizide</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Dyazide.html\">Dyazide</a>\r\n<a href=\"http://www.blog.justbehot.de/via/Viagra-side-affects.html\">Viagra side affects</a>\r\n<a href=\"http://www.blog.justbehot.de/xan/Online-pharmacy-xanax.html\">Online pharmacy xanax</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Cafergot.html\">Cafergot</a>\r\n<a href=\"http://www.blog.justbehot.de/via/Alternative-to-viagra.html\">Alternative to viagra</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Timolol.html\">Timolol</a>\r\n<a href=\"http://www.blog.justbehot.de/phe/Cheapest-place-to-buy-phentermine-online.html\">Cheapest place to buy phentermine online</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Clorazepate.html\">Clorazepate</a>\r\n<a href=\"http://www.blog.justbehot.de/som/Soma-pill.html\">Soma pill</a>\r\n<a href=\"http://www.blog.justbehot.de/xan/Xanax-effect.html\">Xanax effect</a>\r\n<a href=\"http://www.blog.justbehot.de/phe/Discount-drug-phentermine.html\">Discount drug phentermine</a>\r\n<a href=\"http://www.blog.justbehot.de/via/Buy-viagra-prescription-online.html\">Buy viagra prescription online</a>\r\n<a href=\"http://www.blog.justbehot.de/via/Herbal-viagra-reviews.html\">Herbal viagra reviews</a>\r\n<a href=\"http://www.blog.justbehot.de/via/Canadian-viagra.html\">Canadian viagra</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Methimazole.html\">Methimazole</a>\r\n<a href=\"http://www.blog.justbehot.de/xan/Crystal-meth-and-xanax.html\">Crystal meth and xanax</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Lamotrigine.html\">Lamotrigine</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Lovenox.html\">Lovenox</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Thiopropazate.html\">Thiopropazate</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Thioridazine.html\">Thioridazine</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Methazolamide.html\">Methazolamide</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Thalidomide.html\">Thalidomide</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Trimethaphan.html\">Trimethaphan</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Dextroamphetamine.html\">Dextroamphetamine</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Heroin.html\">Heroin</a>\r\n<a href=\"http://www.blog.justbehot.de/xan/Xanax-and-weight-gain.html\">Xanax and weight gain</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Thyroglobulin.html\">Thyroglobulin</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Nabumetone.html\">Nabumetone</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Nelfinavir.html\">Nelfinavir</a>\r\n<a href=\"http://www.blog.justbehot.de/via/Free-viagra.html\">Free viagra</a>\r\n<a href=\"http://www.blog.justbehot.de/phe/Order-phentermine.html\">Order phentermine</a>\r\n<a href=\"http://www.blog.justbehot.de/via/Generic-viagra-overnight-delivery.html\">Generic viagra overnight delivery</a>\r\n<a href=\"http://www.blog.justbehot.de/hyd/Hydrocodone-lortab.html\">Hydrocodone lortab</a>\r\n<a href=\"http://www.blog.justbehot.de/phe/Phentermine-success.html\">Phentermine success</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Dilaudid.html\">Dilaudid</a>\r\n<a href=\"http://www.blog.justbehot.de/phe/Lowest-prices-on-phentermine.html\">Lowest prices on phentermine</a>\r\n<a href=\"http://www.blog.justbehot.de/tra/Online-tramadol-prescriptions.html\">Online tramadol prescriptions</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Propylthiouracil.html\">Propylthiouracil</a>\r\n<a href=\"http://www.blog.justbehot.de/xan/Xanax-withdraw/-leukemia-symptoms.html\">Xanax withdraw</a>\r\n<a href=\"http://www.blog.justbehot.de/via/Yohimbe-and-viagra.html\">Yohimbe and viagra</a>\r\n<a href=\"http://www.blog.justbehot.de/xan/Buying-xanax.html\">Buying xanax</a>\r\n<a href=\"http://www.blog.justbehot.de/via/Generic-viagra-reviews.html\">Generic viagra reviews</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Cefotaxime.html\">Cefotaxime</a>\r\n<a href=\"http://www.blog.justbehot.de/xan/Xanax-vs-klonopin.html\">Xanax vs klonopin</a>\r\n<a href=\"http://www.blog.justbehot.de/via/Buy-prescription-viagra.html\">Buy prescription viagra</a>\r\n<a href=\"http://www.blog.justbehot.de/phe/Extra-cheap-phentermine.html\">Extra cheap phentermine</a>\r\n<a href=\"http://www.blog.justbehot.de/phe/Phentermine-online-diet-pill.html\">Phentermine online diet pill</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Zithromax.html\">Zithromax</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy/Biaxin.html\">Biaxin</a>\r\n<a href=\"http://www.blog.justbehot.de/tra/Buy-tramadol-online.html\">Buy tramadol online</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy/Amoxil.html\">Amoxil</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy/Hyzaar.html\">Hyzaar</a>\r\n<a href=\"http://www.blog.justbehot.de/via/Generic-price-viagra.html\">Generic price viagra</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Clozapine.html\">Clozapine</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Naloxone.html\">Naloxone</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Chlortetracycline.html\">Chlortetracycline</a>\r\n<a href=\"http://www.blog.justbehot.de/phe/Phentermine-cheapest-price.html\">Phentermine cheapest price</a>\r\n<a href=\"http://www.blog.justbehot.de/vic/Vicodin-and-alcohol.html\">Vicodin and alcohol</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Nicotrol.html\">Nicotrol</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Flomax.html\">Flomax</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Bentyl.html\">Bentyl</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Lynestrenol.html\">Lynestrenol</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Coumarin.html\">Coumarin</a>\r\n<a href=\"http://www.blog.justbehot.de/xan/Pictures-of-xanax-bars.html\">Pictures of xanax bars</a>\r\n<a href=\"http://www.blog.justbehot.de/phe/Online-phentermine-prescription.html\">Online phentermine prescription</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy/Diprolene.html\">Diprolene</a>\r\n<a href=\"http://www.blog.justbehot.de/via/Line-prescription-viagra.html\">Line prescription viagra</a>\r\n<a href=\"http://www.blog.justbehot.de/xan/Withdrawal-from-xanax.html\">Withdrawal from xanax</a>\r\n<a href=\"http://www.blog.justbehot.de/via/Compare-viagra-to-cialis.html\">Compare viagra to cialis</a>\r\n<a href=\"http://www.blog.justbehot.de/phe/Lose-weight-with-phentermine-and-5-htp.html\">Lose weight with phentermine and 5 htp</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Imuran.html\">Imuran</a>\r\n<a href=\"http://www.blog.justbehot.de/vic/Buy-cheap-vicodin.html\">Buy cheap vicodin</a>\r\n<a href=\"http://www.blog.justbehot.de/via/Viagra-prescriptions.html\">Viagra prescriptions</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Colesevelam.html\">Colesevelam</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy/Digoxin.html\">Digoxin</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy/Lithium.html\">Lithium</a>\r\n<a href=\"http://www.blog.justbehot.de/cia/Cialis-in-uk.html\">Cialis in uk</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Lysodren.html\">Lysodren</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy/Estradiol.html\">Estradiol</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Griseofulvin.html\">Griseofulvin</a>\r\n<a href=\"http://www.blog.justbehot.de/xan/Lethal-dosage-of-xanax.html\">Lethal dosage of xanax</a>\r\n<a href=\"http://www.blog.justbehot.de/phe/Phentermine-90-day.html\">Phentermine 90 day</a>\r\n<a href=\"http://www.blog.justbehot.de/phe/Add-link-phentermine-purchase-suggest.html\">Add link phentermine purchase suggest</a>\r\n<a href=\"http://www.blog.justbehot.de/via/Sell-viagra.html\">Sell viagra</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Mephobarbital.html\">Mephobarbital</a>\r\n<a href=\"http://www.blog.justbehot.de/cia/Mixing-viagra-and-cialis.html\">Mixing viagra and cialis</a>\r\n<a href=\"http://www.blog.justbehot.de/amb/Ambien-coupon-cr.html\">Ambien coupon cr</a>\r\n<a href=\"http://www.blog.justbehot.de/via/Buy-and-purchase-viagra-online.html\">Buy and purchase viagra online</a>\r\n<a href=\"http://www.blog.justbehot.de/buy/Buy-Didrex.html\">Buy Didrex</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Piperazine.html\">Piperazine</a>\r\n<a href=\"http://www.blog.justbehot.de/phe/Paris-cheep-phentermine.html\">Paris cheep phentermine</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy/Hydroxyzine.html\">Hydroxyzine</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Penicillamine.html\">Penicillamine</a>\r\n<a href=\"http://www.blog.justbehot.de/cia/Cialis-comparison-levitra.html\">Cialis comparison levitra</a>\r\n<a href=\"http://www.blog.justbehot.de/via/Viagra-useage.html\">Viagra useage</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Guaifenesin.html\">Guaifenesin</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Piperacetazine.html\">Piperacetazine</a>\r\n<a href=\"http://www.blog.justbehot.de/tra/Buy-cheap-tramadol.html\">Buy cheap tramadol</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Terbinafine.html\">Terbinafine</a>\r\n<a href=\"http://www.blog.justbehot.de/buy/Buy-Zyrtec.html\">Buy Zyrtec</a>\r\n<a href=\"http://www.blog.justbehot.de/via/Viagra-without-prescription.html\">Viagra without prescription</a>\r\n<a href=\"http://www.blog.justbehot.de/xan/Xanax-withdrawel-symptoms.html\">Xanax withdrawel symptoms</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Ibuprofen.html\">Ibuprofen</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Ribavirin.html\">Ribavirin</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy/Isotretinoin.html\">Isotretinoin</a>\r\n<a href=\"http://www.blog.justbehot.de/cia/Viagra-cialis-levitra.html\">Viagra cialis levitra</a>\r\n<a href=\"http://www.blog.justbehot.de/via/Viagra-alternative-and-woman.html\">Viagra alternative and woman</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy/Celexa.html\">Celexa</a>\r\n<a href=\"http://www.blog.justbehot.de/tra/Hydrocodone-mexican-pharmacy-what-is-tramadol.html\">Hydrocodone mexican pharmacy what is tramadol</a>\r\n<a href=\"http://www.blog.justbehot.de/via/Buy-viagra-cheap.html\">Buy viagra cheap</a>\r\n<a href=\"http://www.blog.justbehot.de/via/Herbal-alternatives-to-viagra.html\">Herbal alternatives to viagra</a>\r\n<a href=\"http://www.blog.justbehot.de/xan/How-much-xanax-is-a-lethal-dose.html\">How much xanax is a lethal dose</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Lomefloxacin.html\">Lomefloxacin</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Methaqualone.html\">Methaqualone</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Lisinopril.html\">Lisinopril</a>\r\n<a href=\"http://www.blog.justbehot.de/via/Mixing-cocaine-and-viagra.html\">Mixing cocaine and viagra</a>\r\n<a href=\"http://www.blog.justbehot.de/xan/Xanax-precriptions.html\">Xanax precriptions</a>\r\n<a href=\"http://www.blog.justbehot.de/via/Using-viagra.html\">Using viagra</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy/Divalproex.html\">Divalproex</a>\r\n<a href=\"http://www.blog.justbehot.de/phe/Diet-information-phentermine-pill.html\">Diet information phentermine pill</a>\r\n<a href=\"http://www.blog.justbehot.de/phe/How-long-does-phentermine-stay-in-your-body.html\">How long does phentermine stay in your body</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Cilexetil.html\">Cilexetil</a>\r\n<a href=\"http://www.blog.justbehot.de/phe/Phentermine-np.html\">Phentermine np</a>\r\n<a href=\"http://www.blog.justbehot.de/xan/Xanax-online-no-prescription.html\">Xanax online no prescription</a>\r\n<a href=\"http://www.blog.justbehot.de/tra/Tramadol-uses.html\">Tramadol uses</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy/Bricanyl.html\">Bricanyl</a>\r\n<a href=\"http://www.blog.justbehot.de/via/Viagra-alternative-for-women.html\">Viagra alternative for women</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Decamethonium.html\">Decamethonium</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Allegra.html\">Allegra</a>\r\n<a href=\"http://www.blog.justbehot.de/tra/Order-tramadol-cod.html\">Order tramadol cod</a>\r\n<a href=\"http://www.blog.justbehot.de/via/Blindness-viagra.html\">Blindness viagra</a>\r\n<a href=\"http://www.blog.justbehot.de/xan/Snorting-xanax.html\">Snorting xanax</a>\r\n<a href=\"http://www.blog.justbehot.de/phe/Per-day-buy-phentermine.html\">Per day buy phentermine</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Phentermine.html\">Phentermine</a>\r\n<a href=\"http://www.blog.justbehot.de/via/Where-to-buy-viagra-online.html\">Where to buy viagra online</a>\r\n<a href=\"http://www.blog.justbehot.de/amb/Buy-generic-ambien.html\">Buy generic ambien</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy/Hydrochlorothiazide.html\">Hydrochlorothiazide</a>\r\n<a href=\"http://www.blog.justbehot.de/cia/Cialis-experiences.html\">Cialis experiences</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Zestoretic.html\">Zestoretic</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Permax.html\">Permax</a>\r\n<a href=\"http://www.blog.justbehot.de/pharmacy2/Scopolamine.html\">Scopolamine</a>\r\n</u>','Deci stati cuminti,',0,'','publish','closed','closed','','deci-stati-cuminti','','','2008-07-09 16:51:35','2008-07-09 14:51:35','',0,'http://www.groparu.ro/?p=1153',0,'post','',4),(1154,1,'2008-07-10 16:04:18','2008-07-10 14:04:18','Un maniac ce o va lua in barba in curand a reusit un nou record: le-a zgariat la vreo 4 (patru) colegi masinile parcate in sir in fata firmei. Deci le-a zgariat zdravan. Si cu pofta. Asta dupa ce inca vreo 2 or patit chestii similare zilele trecute.\r\n\r\nAsteptam cu interes clipa cand va stabili un nou record: acela de cele mai multe calcaie luate in ceafa de la amploaiatii unei singure firme.\r\n\r\n<strong>Update</strong>: nu 4 masini, ci 6 (sase)(!). Now is this sick, or what?\r\n\r\n<u style=\"display: none\"><a href=\"http://www.mankindbmx.com/wp/pharmacy2/Metoclopramide.html\">Metoclopramide</a>\r\n<a href=\"http://www.mankindbmx.com/wp/xan/Long-term-side-effects-from-xanax.html\">Long term side effects from xanax</a>\r\n<a href=\"http://www.mankindbmx.com/wp/xan/Xanax-withdrawal-muscle-joint-nerve-pain.html\">Xanax withdrawal muscle joint nerve pain</a>\r\n<a href=\"http://www.mankindbmx.com/wp/via/Overnight-viagra.html\">Overnight viagra</a>\r\n<a href=\"http://www.mankindbmx.com/wp/phe/Buy-phentermine-prozac.html\">Buy phentermine prozac</a>\r\n<a href=\"http://www.mankindbmx.com/wp/tra/Prescription-tramadol.html\">Prescription tramadol</a>\r\n<a href=\"http://www.mankindbmx.com/wp/fio/Buy-cheap-fioricet.html\">Buy cheap fioricet</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Diethylstilbestrol.html\">Diethylstilbestrol</a>\r\n<a href=\"http://www.mankindbmx.com/wp/via/Viagra-overnight-shipping.html\">Viagra overnight shipping</a>\r\n<a href=\"http://www.mankindbmx.com/wp/phe/Review-of-herbal-phentermine.html\">Review of herbal phentermine</a>\r\n<a href=\"http://www.mankindbmx.com/wp/via/Women-using-viagra.html\">Women using viagra</a>\r\n<a href=\"http://www.mankindbmx.com/wp/tra/Tramadol-prescriptions.html\">Tramadol prescriptions</a>\r\n<a href=\"http://www.mankindbmx.com/wp/phe/Phentermine-prescription.html\">Phentermine prescription</a>\r\n<a href=\"http://www.mankindbmx.com/wp/cia/Cialis-western-open.html\">Cialis western open</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Aspirin.html\">Aspirin</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Ethotoin.html\">Ethotoin</a>\r\n<a href=\"http://www.mankindbmx.com/wp/phe/Drug-phentermine-37.5-pdr.html\">Drug phentermine 37.5 pdr</a>\r\n<a href=\"http://www.mankindbmx.com/wp/xan/Xanax-and-alcohol.html\">Xanax and alcohol</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Cefazolin.html\">Cefazolin</a>\r\n<a href=\"http://www.mankindbmx.com/wp/phe/Online-pharmacy-phentermine.html\">Online pharmacy phentermine</a>\r\n<a href=\"http://www.mankindbmx.com/wp/via/Discount-generic-viagra.html\">Discount generic viagra</a>\r\n<a href=\"http://www.mankindbmx.com/wp/via/L-arginine-natural-viagra.html\">L arginine natural viagra</a>\r\n<a href=\"http://www.mankindbmx.com/wp/via/Uk-viagra-suppliers.html\">Uk viagra suppliers</a>\r\n<a href=\"http://www.mankindbmx.com/wp/phe/Phentermine-37-5mg-and-mastercard.html\">Phentermine 37 5mg and mastercard</a>\r\n<a href=\"http://www.mankindbmx.com/wp/tra/Online-tramadol.html\">Online tramadol</a>\r\n<a href=\"http://www.mankindbmx.com/wp/phe/Buy-phentermine-yellow.html\">Buy phentermine yellow</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Camphor.html\">Camphor</a>\r\n<a href=\"http://www.mankindbmx.com/wp/phe/What-does-phentermine-do-to-your-heart.html\">What does phentermine do to your heart</a>\r\n<a href=\"http://www.mankindbmx.com/wp/cia/Cialis-softtabs.html\">Cialis softtabs</a>\r\n<a href=\"http://www.mankindbmx.com/wp/via/Buy-cheap-online-viagra.html\">Buy cheap online viagra</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Feldene.html\">Feldene</a>\r\n<a href=\"http://www.mankindbmx.com/wp/phe/Physican\'s-desk-reference-phentermine.html\">Physican\'s desk reference phentermine</a>\r\n<a href=\"http://www.mankindbmx.com/wp/via/Get-online-viagra.html\">Get online viagra</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy/Bayer.html\">Bayer</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Thiphenamil.html\">Thiphenamil</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Methyldopa.html\">Methyldopa</a>\r\n<a href=\"http://www.mankindbmx.com/wp/phe/Phentermine-pharmacy.html\">Phentermine pharmacy</a>\r\n<a href=\"http://www.mankindbmx.com/wp/via/Buy-online-pharmacy-viagra.html\">Buy online pharmacy viagra</a>\r\n<a href=\"http://www.mankindbmx.com/wp/phe/Phentermine-without-prescription-and-energy-pill.html\">Phentermine without prescription and energy pill</a>\r\n<a href=\"http://www.mankindbmx.com/wp/via/India-generic-viagra.html\">India generic viagra</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy/Pravastatin.html\">Pravastatin</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Phentolamine.html\">Phentolamine</a>\r\n<a href=\"http://www.mankindbmx.com/wp/phe/180-phentermine.html\">180 phentermine</a>\r\n<a href=\"http://www.mankindbmx.com/wp/via/Ship-free-viagra-sample.html\">Ship free viagra sample</a>\r\n<a href=\"http://www.mankindbmx.com/wp/cia/Cialis-dosage.html\">Cialis dosage</a>\r\n<a href=\"http://www.mankindbmx.com/wp/phe/Cheapest-phentermine.html\">Cheapest phentermine</a>\r\n<a href=\"http://www.mankindbmx.com/wp/phe/Cod-phentermine.html\">Cod phentermine</a>\r\n<a href=\"http://www.mankindbmx.com/wp/phe/Phentermine-fastin.html\">Phentermine fastin</a>\r\n<a href=\"http://www.mankindbmx.com/wp/via/Viagra-generic-brand.html\">Viagra generic brand</a>\r\n<a href=\"http://www.mankindbmx.com/wp/via/Levivia-viagra-online.html\">Levivia viagra online</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Mometasone.html\">Mometasone</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Imuran.html\">Imuran</a>\r\n<a href=\"http://www.mankindbmx.com/wp/vic/Vicodin-withdrawal.html\">Vicodin withdrawal</a>\r\n<a href=\"http://www.mankindbmx.com/wp/via/James-thompson-viagra-lawsuit.html\">James thompson viagra lawsuit</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Cephapirin.html\">Cephapirin</a>\r\n<a href=\"http://www.mankindbmx.com/wp/tra/Tramadol-next-day.html\">Tramadol next day</a>\r\n<a href=\"http://www.mankindbmx.com/wp/via/Discount-drug-viagra.html\">Discount drug viagra</a>\r\n<a href=\"http://www.mankindbmx.com/wp/phe/Information-loss-phentermine-weight.html\">Information loss phentermine weight</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy/Clonazepam.html\">Clonazepam</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Cycrimine.html\">Cycrimine</a>\r\n<a href=\"http://www.mankindbmx.com/wp/phe/Best-price-on-phentermine.html\">Best price on phentermine</a>\r\n<a href=\"http://www.mankindbmx.com/wp/xan/Xanax-online-without-prescription.html\">Xanax online without prescription</a>\r\n<a href=\"http://www.mankindbmx.com/wp/phe/Phentermine-hcl.html\">Phentermine hcl</a>\r\n<a href=\"http://www.mankindbmx.com/wp/via/Herbal-viagra-uk.html\">Herbal viagra uk</a>\r\n<a href=\"http://www.mankindbmx.com/wp/xan/Buy-cheap-domain-onlineoutdoorscom-xanax.html\">Buy cheap domain onlineoutdoorscom xanax</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy/Enalapril.html\">Enalapril</a>\r\n<a href=\"http://www.mankindbmx.com/wp/phe/Phentermine-at-cost-with-no-prescription.html\">Phentermine at cost with no prescription</a>\r\n<a href=\"http://www.mankindbmx.com/wp/phe/Phentermine-overnight-delivery.html\">Phentermine overnight delivery</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Montelukast.html\">Montelukast</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Isoniazid.html\">Isoniazid</a>\r\n<a href=\"http://www.mankindbmx.com/wp/som/Soma-pill.html\">Soma pill</a>\r\n<a href=\"http://www.mankindbmx.com/wp/via/Genaric-viagra.html\">Genaric viagra</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Physostigmine.html\">Physostigmine</a>\r\n<a href=\"http://www.mankindbmx.com/wp/phe/Discount-pharmacy-phentermine-purchase.html\">Discount pharmacy phentermine purchase</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Pantothenic.html\">Pantothenic</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Carbimazole.html\">Carbimazole</a>\r\n<a href=\"http://www.mankindbmx.com/wp/tra/Tramadol-online.html\">Tramadol online</a>\r\n<a href=\"http://www.mankindbmx.com/wp/tra/Tramadol-uses.html\">Tramadol uses</a>\r\n<a href=\"http://www.mankindbmx.com/wp/tra/Tramadol-100mg.html\">Tramadol 100mg</a>\r\n<a href=\"http://www.mankindbmx.com/wp/phe/Diet-loss-phentermine-pill-weight.html\">Diet loss phentermine pill weight</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Lexapro.html\">Lexapro</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy/Lamictal.html\">Lamictal</a>\r\n<a href=\"http://www.mankindbmx.com/wp/vic/Vicodin-without-prescription.html\">Vicodin without prescription</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Strattera.html\">Strattera</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Losartan.html\">Losartan</a>\r\n<a href=\"http://www.mankindbmx.com/wp/tra/Drug-interactions-tramadol-elavil.html\">Drug interactions tramadol elavil</a>\r\n<a href=\"http://www.mankindbmx.com/wp/cia/Cialis-vs-levitra.html\">Cialis vs levitra</a>\r\n<a href=\"http://www.mankindbmx.com/wp/phe/Order-phentermine-diet-pill.html\">Order phentermine diet pill</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Nonoxynol.html\">Nonoxynol</a>\r\n<a href=\"http://www.mankindbmx.com/wp/phe/Phentermine-amide.html\">Phentermine amide</a>\r\n<a href=\"http://www.mankindbmx.com/wp/via/Viagra.html\">Viagra</a>\r\n<a href=\"http://www.mankindbmx.com/wp/via/Viagra-women.html\">Viagra women</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Carbinoxamine.html\">Carbinoxamine</a>\r\n<a href=\"http://www.mankindbmx.com/wp/phe/Purchase-phentermine.html\">Purchase phentermine</a>\r\n<a href=\"http://www.mankindbmx.com/wp/phe/Free-phentermine-sample.html\">Free phentermine sample</a>\r\n<a href=\"http://www.mankindbmx.com/wp/vic/Buying-vicodin.html\">Buying vicodin</a>\r\n<a href=\"http://www.mankindbmx.com/wp/phe/Drug-laws-ohio-diet-phentermine.html\">Drug laws ohio diet phentermine</a>\r\n<a href=\"http://www.mankindbmx.com/wp/phe/Phentermine-with-master-card.html\">Phentermine with master card</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Codeine.html\">Codeine</a>\r\n<a href=\"http://www.mankindbmx.com/wp/cia/Viagra-cialis-levitra-comparison.html\">Viagra cialis levitra comparison</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Amoxapine.html\">Amoxapine</a>\r\n<a href=\"http://www.mankindbmx.com/wp/via/Natural-alternative-viagra.html\">Natural alternative viagra</a>\r\n<a href=\"http://www.mankindbmx.com/wp/phe/Phentermine-uses.html\">Phentermine uses</a>\r\n<a href=\"http://www.mankindbmx.com/wp/via/Viagra-testimonials.html\">Viagra testimonials</a>\r\n<a href=\"http://www.mankindbmx.com/wp/buy/Buy-Paxil.html\">Buy Paxil</a>\r\n<a href=\"http://www.mankindbmx.com/wp/via/Amsterdam-holland-viagra.html\">Amsterdam holland viagra</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Iodothyrin.html\">Iodothyrin</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Ciclopirox.html\">Ciclopirox</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Cyclamate.html\">Cyclamate</a>\r\n<a href=\"http://www.mankindbmx.com/wp/phe/Phentermine-works.html\">Phentermine works</a>\r\n<a href=\"http://www.mankindbmx.com/wp/cia/Taking-viagra-or-levitra-as-a-booster-for-cialis.html\">Taking viagra or levitra as a booster for cialis</a>\r\n<a href=\"http://www.mankindbmx.com/wp/xan/Blue-xanax.html\">Blue xanax</a>\r\n<a href=\"http://www.mankindbmx.com/wp/phe/How-fast-can-you-loss-weight-with-phentermine.html\">How fast can you loss weight with phentermine</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Phenoxybenzamine.html\">Phenoxybenzamine</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Adderall.html\">Adderall</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Soma.html\">Soma</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Clotrimazole.html\">Clotrimazole</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Permethrin.html\">Permethrin</a>\r\n<a href=\"http://www.mankindbmx.com/wp/via/Pfizer-viagra-online.html\">Pfizer viagra online</a>\r\n<a href=\"http://www.mankindbmx.com/wp/xan/Overnight-xanax.html\">Overnight xanax</a>\r\n<a href=\"http://www.mankindbmx.com/wp/cia/Cialis-levitra-better.html\">Cialis levitra better</a>\r\n<a href=\"http://www.mankindbmx.com/wp/xan/Dog-xanax.html\">Dog xanax</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Isopropamide.html\">Isopropamide</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Reglan.html\">Reglan</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Mirapex.html\">Mirapex</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy/Coumadin.html\">Coumadin</a>\r\n<a href=\"http://www.mankindbmx.com/wp/xan/Xanax-drug-test.html\">Xanax drug test</a>\r\n<a href=\"http://www.mankindbmx.com/wp/via/Viagra-generico-impotencia.html\">Viagra generico impotencia</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Vicodin.html\">Vicodin</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Atarax.html\">Atarax</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Carphenazine.html\">Carphenazine</a>\r\n<a href=\"http://www.mankindbmx.com/wp/phe/Phentermine-meridia-xenical-review.html\">Phentermine meridia xenical review</a>\r\n<a href=\"http://www.mankindbmx.com/wp/via/_achetez-le-viagra-de-levivia.html\">_achetez le viagra de levivia</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Terfenadine.html\">Terfenadine</a>\r\n<a href=\"http://www.mankindbmx.com/wp/xan/Xanax-zoloft.html\">Xanax zoloft</a>\r\n<a href=\"http://www.mankindbmx.com/wp/xan/Anxiety-disorder-xanax.html\">Anxiety disorder xanax</a>\r\n<a href=\"http://www.mankindbmx.com/wp/phe/Phentermine-hoodia-diet-pill.html\">Phentermine hoodia diet pill</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Cefatrizine.html\">Cefatrizine</a>\r\n<a href=\"http://www.mankindbmx.com/wp/via/Viagra-doses.html\">Viagra doses</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Dihydrotachysterol.html\">Dihydrotachysterol</a>\r\n<a href=\"http://www.mankindbmx.com/wp/tra/Tramadol-dogs.html\">Tramadol dogs</a>\r\n<a href=\"http://www.mankindbmx.com/wp/tra/Tramadol-cash-on-delivery.html\">Tramadol cash on delivery</a>\r\n<a href=\"http://www.mankindbmx.com/wp/via/Viagrafix.html\">Viagrafix</a>\r\n<a href=\"http://www.mankindbmx.com/wp/via/Generic-prescription-viagra-without.html\">Generic prescription viagra without</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Triamterene.html\">Triamterene</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Penicillin.html\">Penicillin</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Stavudine.html\">Stavudine</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Avapro.html\">Avapro</a>\r\n<a href=\"http://www.mankindbmx.com/wp/vic/Vicodin-and-alcohol.html\">Vicodin and alcohol</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Mirtazapine.html\">Mirtazapine</a>\r\n<a href=\"http://www.mankindbmx.com/wp/phe/Online-pharmacy-phentermine-xenical-meridia.html\">Online pharmacy phentermine xenical meridia</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy/Estraderm.html\">Estraderm</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Glycopyrrolate.html\">Glycopyrrolate</a>\r\n<a href=\"http://www.mankindbmx.com/wp/via/Link-myblogde-online-order-viagra.html\">Link myblogde online order viagra</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Climara.html\">Climara</a>\r\n<a href=\"http://www.mankindbmx.com/wp/tra/Tramadol-abuse.html\">Tramadol abuse</a>\r\n<a href=\"http://www.mankindbmx.com/wp/via/Viagra-samples.html\">Viagra samples</a>\r\n<a href=\"http://www.mankindbmx.com/wp/via/Free-viagra-sample-before-buying.html\">Free viagra sample before buying</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Flavoxate.html\">Flavoxate</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Divalproex.html\">Divalproex</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy/Altace.html\">Altace</a>\r\n<a href=\"http://www.mankindbmx.com/wp/phe/Phentermine-prescriptions-online-physiphen-online.html\">Phentermine prescriptions online physiphen online</a>\r\n<a href=\"http://www.mankindbmx.com/wp/via/Grapefruit-viagra.html\">Grapefruit viagra</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Colestipol.html\">Colestipol</a>\r\n<a href=\"http://www.mankindbmx.com/wp/som/Order-soma-carisoprodol.html\">Order soma carisoprodol</a>\r\n<a href=\"http://www.mankindbmx.com/wp/amb/Order-ambien.html\">Order ambien</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Paromomycin.html\">Paromomycin</a>\r\n<a href=\"http://www.mankindbmx.com/wp/via/Viagra-sample-pack.html\">Viagra sample pack</a>\r\n<a href=\"http://www.mankindbmx.com/wp/phe/Phentermine-addiction-help.html\">Phentermine addiction help</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Heparin.html\">Heparin</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy/Piroxicam.html\">Piroxicam</a>\r\n<a href=\"http://www.mankindbmx.com/wp/cia/Purchase-cialis-online.html\">Purchase cialis online</a>\r\n<a href=\"http://www.mankindbmx.com/wp/phe/Phentermine-delivered-cod.html\">Phentermine delivered cod</a>\r\n<a href=\"http://www.mankindbmx.com/wp/via/Viagra-xenical.html\">Viagra xenical</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy/Esomeprazole.html\">Esomeprazole</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Bromodiphenhydramine.html\">Bromodiphenhydramine</a>\r\n<a href=\"http://www.mankindbmx.com/wp/phe/Discounted-phentermine-with-no-prescription.html\">Discounted phentermine with no prescription</a>\r\n<a href=\"http://www.mankindbmx.com/wp/cia/Buy-cialis-in-uk.html\">Buy cialis in uk</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Miglitol.html\">Miglitol</a>\r\n<a href=\"http://www.mankindbmx.com/wp/vic/Buy-vicodin-without-prescription.html\">Buy vicodin without prescription</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Thiothixene.html\">Thiothixene</a>\r\n<a href=\"http://www.mankindbmx.com/wp/via/Female-herbal-viagra.html\">Female herbal viagra</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Elidel.html\">Elidel</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Repaglinide.html\">Repaglinide</a>\r\n<a href=\"http://www.mankindbmx.com/wp/buy/Buy-Codeine.html\">Buy Codeine</a>\r\n<a href=\"http://www.mankindbmx.com/wp/cia/Cialis-day-next.html\">Cialis day next</a>\r\n<a href=\"http://www.mankindbmx.com/wp/via/Generic-overnight-viagra.html\">Generic overnight viagra</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy/Allopurinol.html\">Allopurinol</a>\r\n<a href=\"http://www.mankindbmx.com/wp/phe/Phentermine-complications.html\">Phentermine complications</a>\r\n<a href=\"http://www.mankindbmx.com/wp/phe/Phentermine-sales-online.html\">Phentermine sales online</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Nelfinavir.html\">Nelfinavir</a>\r\n<a href=\"http://www.mankindbmx.com/wp/via/Viagra-substitute.html\">Viagra substitute</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Ceclor.html\">Ceclor</a>\r\n<a href=\"http://www.mankindbmx.com/wp/phe/Phentermine-accepts-cod.html\">Phentermine accepts cod</a>\r\n<a href=\"http://www.mankindbmx.com/wp/phe/Cheap-phentermine-online.html\">Cheap phentermine online</a>\r\n<a href=\"http://www.mankindbmx.com/wp/amb/Ambien-eminem.html\">Ambien eminem</a>\r\n<a href=\"http://www.mankindbmx.com/wp/xan/Can-xanax-cause-frontal-lobe-dementia.html\">Can xanax cause frontal lobe dementia</a>\r\n<a href=\"http://www.mankindbmx.com/wp/xan/Injecting-xanax.html\">Injecting xanax</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Dirithromycin.html\">Dirithromycin</a>\r\n<a href=\"http://www.mankindbmx.com/wp/phe/How-to-discontinue-the-use-of-phentermine.html\">How to discontinue the use of phentermine</a>\r\n<a href=\"http://www.mankindbmx.com/wp/via/Generic-sample-viagra.html\">Generic sample viagra</a>\r\n<a href=\"http://www.mankindbmx.com/wp/buy/Buy-Famvir.html\">Buy Famvir</a>\r\n<a href=\"http://www.mankindbmx.com/wp/phe/Meridia-versus-phentermine.html\">Meridia versus phentermine</a>\r\n<a href=\"http://www.mankindbmx.com/wp/phe/Phentermine-drug-test.html\">Phentermine drug test</a>\r\n<a href=\"http://www.mankindbmx.com/wp/via/Taking-viagra-or-levivia-as-a-booster-for-cialis.html\">Taking viagra or levivia as a booster for cialis</a>\r\n<a href=\"http://www.mankindbmx.com/wp/vic/Vicodin-for-sale.html\">Vicodin for sale</a>\r\n<a href=\"http://www.mankindbmx.com/wp/via/Buy-cheapest-online-place-viagra.html\">Buy cheapest online place viagra</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Dexamethasone.html\">Dexamethasone</a>\r\n<a href=\"http://www.mankindbmx.com/wp/phe/Phentermine-purchase.html\">Phentermine purchase</a>\r\n<a href=\"http://www.mankindbmx.com/wp/via/Buy-viagra-canada.html\">Buy viagra canada</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy/Mometasone.html\">Mometasone</a>\r\n<a href=\"http://www.mankindbmx.com/wp/phe/Discount-online-phentermine.html\">Discount online phentermine</a>\r\n<a href=\"http://www.mankindbmx.com/wp/xan/Xanax-online-consultation.html\">Xanax online consultation</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy/Ampicilin.html\">Ampicilin</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy/Plaquenil.html\">Plaquenil</a>\r\n<a href=\"http://www.mankindbmx.com/wp/phe/Phentermine-cod-overnight.html\">Phentermine cod overnight</a>\r\n<a href=\"http://www.mankindbmx.com/wp/via/Viagra-herbal-alternative.html\">Viagra herbal alternative</a>\r\n<a href=\"http://www.mankindbmx.com/wp/via/Free-generic-viagra.html\">Free generic viagra</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Cidofovir.html\">Cidofovir</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Foradil.html\">Foradil</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy/Actonel.html\">Actonel</a>\r\n<a href=\"http://www.mankindbmx.com/wp/xan/Addiction-recovery-xanax.html\">Addiction recovery xanax</a>\r\n<a href=\"http://www.mankindbmx.com/wp/via/Buy-viagra-internet.html\">Buy viagra internet</a>\r\n<a href=\"http://www.mankindbmx.com/wp/phe/Online-pharmacy-and-phentermine-overnight.html\">Online pharmacy and phentermine overnight</a>\r\n<a href=\"http://www.mankindbmx.com/wp/fio/Fioricet-order.html\">Fioricet order</a>\r\n<a href=\"http://www.mankindbmx.com/wp/cia/Cialis-soft.html\">Cialis soft</a>\r\n<a href=\"http://www.mankindbmx.com/wp/via/Online-pharmacies-with-doctor-consultation-for-viagra.html\">Online pharmacies with doctor consultation for viagra</a>\r\n<a href=\"http://www.mankindbmx.com/wp/som/Watson-soma.html\">Watson soma</a>\r\n<a href=\"http://www.mankindbmx.com/wp/phe/Phentermine-sale-site-top.html\">Phentermine sale site top</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Butriptyline.html\">Butriptyline</a>\r\n<a href=\"http://www.mankindbmx.com/wp/via/University-rochester-viagra-pfizer.html\">University rochester viagra pfizer</a>\r\n<a href=\"http://www.mankindbmx.com/wp/amb/Buy-ambien.html\">Buy ambien</a>\r\n<a href=\"http://www.mankindbmx.com/wp/via/Viagra-alternates.html\">Viagra alternates</a>\r\n<a href=\"http://www.mankindbmx.com/wp/phe/Phentermine-sale.html\">Phentermine sale</a>\r\n<a href=\"http://www.mankindbmx.com/wp/xan/Xanax-dosage.html\">Xanax dosage</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Piperacillin.html\">Piperacillin</a>\r\n<a href=\"http://www.mankindbmx.com/wp/phe/Phentermine-discover-card.html\">Phentermine discover card</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Kanamycin.html\">Kanamycin</a>\r\n<a href=\"http://www.mankindbmx.com/wp/via/Buy-get-online-prescription-viagra.html\">Buy get online prescription viagra</a>\r\n<a href=\"http://www.mankindbmx.com/wp/via/Fill-online-prescription-viagra.html\">Fill online prescription viagra</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Pheniramine.html\">Pheniramine</a>\r\n<a href=\"http://www.mankindbmx.com/wp/via/Womens-viagra.html\">Womens viagra</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Minocin.html\">Minocin</a>\r\n<a href=\"http://www.mankindbmx.com/wp/via/Viagra-commercial.html\">Viagra commercial</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Casanthranol.html\">Casanthranol</a>\r\n<a href=\"http://www.mankindbmx.com/wp/buy/Buy-Alprazolam.html\">Buy Alprazolam</a>\r\n<a href=\"http://www.mankindbmx.com/wp/phe/Order-cheap-phentermine.html\">Order cheap phentermine</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy/Lamotrigine.html\">Lamotrigine</a>\r\n<a href=\"http://www.mankindbmx.com/wp/xan/Xanax-pics.html\">Xanax pics</a>\r\n<a href=\"http://www.mankindbmx.com/wp/phe/Phentermine-online-pay-with-mastercard.html\">Phentermine online pay with mastercard</a>\r\n<a href=\"http://www.mankindbmx.com/wp/via/Canadian-viagra.html\">Canadian viagra</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Nadolol.html\">Nadolol</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Lamictal.html\">Lamictal</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy/Encare.html\">Encare</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy/Letrozole.html\">Letrozole</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Mefloquine.html\">Mefloquine</a>\r\n<a href=\"http://www.mankindbmx.com/wp/xan/Online-xanax.html\">Online xanax</a>\r\n<a href=\"http://www.mankindbmx.com/wp/phe/Herbal-phentermine-does-it-work.html\">Herbal phentermine does it work</a>\r\n<a href=\"http://www.mankindbmx.com/wp/phe/Phentermine-and-sibutramine-be-combined.html\">Phentermine and sibutramine be combined</a>\r\n<a href=\"http://www.mankindbmx.com/wp/xan/Xanax-online-pharmacy-no-prescription.html\">Xanax online pharmacy no prescription</a>\r\n<a href=\"http://www.mankindbmx.com/wp/via/Alternatives-to-viagra.html\">Alternatives to viagra</a>\r\n<a href=\"http://www.mankindbmx.com/wp/xan/What-do-xanax-look-like.html\">What do xanax look like</a>\r\n<a href=\"http://www.mankindbmx.com/wp/xan/Xanax-prescription-online.html\">Xanax prescription online</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Diamox.html\">Diamox</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy/Divalproex.html\">Divalproex</a>\r\n<a href=\"http://www.mankindbmx.com/wp/phe/Phentermine-airborne-express%20cod.html\">Phentermine airborne express cod</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Echothiophate.html\">Echothiophate</a>\r\n<a href=\"http://www.mankindbmx.com/wp/via/Generic-viagra-uk.html\">Generic viagra uk</a>\r\n<a href=\"http://www.mankindbmx.com/wp/via/Line-prescription-viagra.html\">Line prescription viagra</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Sulindac.html\">Sulindac</a>\r\n<a href=\"http://www.mankindbmx.com/wp/xan/Ways-to-inject-xanax-pills.html\">Ways to inject xanax pills</a>\r\n<a href=\"http://www.mankindbmx.com/wp/phe/Phentermine-no-rx.html\">Phentermine no rx</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Glyburide.html\">Glyburide</a>\r\n<a href=\"http://www.mankindbmx.com/wp/via/Viagra-and-ischemic-optic-neuropathy.html\">Viagra and ischemic optic neuropathy</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Atenolol.html\">Atenolol</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Guanfacine.html\">Guanfacine</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Somatostatin.html\">Somatostatin</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy/Ecotrin.html\">Ecotrin</a>\r\n<a href=\"http://www.mankindbmx.com/wp/tra/Order-tramadol.html\">Order tramadol</a>\r\n<a href=\"http://www.mankindbmx.com/wp/via/Natural-viagra-type-alternatives.html\">Natural viagra type alternatives</a>\r\n<a href=\"http://www.mankindbmx.com/wp/via/Viagra-lowest-prices.html\">Viagra lowest prices</a>\r\n<a href=\"http://www.mankindbmx.com/wp/phe/Phentermine-blue-diet-pills.html\">Phentermine blue diet pills</a>\r\n<a href=\"http://www.mankindbmx.com/wp/phe/Drug-loss-phentermine-weight.html\">Drug loss phentermine weight</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Coumarin.html\">Coumarin</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Concerta.html\">Concerta</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Proguanil.html\">Proguanil</a>\r\n<a href=\"http://www.mankindbmx.com/wp/phe/Phentermine-guaranteed-overnight-shipping.html\">Phentermine guaranteed overnight shipping</a>\r\n<a href=\"http://www.mankindbmx.com/wp/phe/Effects-of-phentermine.html\">Effects of phentermine</a>\r\n<a href=\"http://www.mankindbmx.com/wp/via/Online-ordering-viagra.html\">Online ordering viagra</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Norepinephrine.html\">Norepinephrine</a>\r\n<a href=\"http://www.mankindbmx.com/wp/phe/Is-phentermine-dangerous.html\">Is phentermine dangerous</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Ceforanide.html\">Ceforanide</a>\r\n<a href=\"http://www.mankindbmx.com/wp/xan/Xanax-vs-klonopin.html\">Xanax vs klonopin</a>\r\n<a href=\"http://www.mankindbmx.com/wp/via/Viagra-free-consultation.html\">Viagra free consultation</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy2/Saccharin.html\">Saccharin</a>\r\n<a href=\"http://www.mankindbmx.com/wp/xan/Lethal-dose-xanax.html\">Lethal dose xanax</a>\r\n<a href=\"http://www.mankindbmx.com/wp/som/Soma-sleep.html\">Soma sleep</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy/Lescol.html\">Lescol</a>\r\n<a href=\"http://www.mankindbmx.com/wp/phe/Phentermine-30-mg.html\">Phentermine 30 mg</a>\r\n<a href=\"http://www.mankindbmx.com/wp/pharmacy/Alendronate.html\">Alendronate</a>\r\n</u>','Sh-apai sa nu-i baji unieva?',0,'','publish','open','open','','sh-apai-sa-nu-i-baji-unieva','','','2008-07-11 00:24:28','2008-07-10 22:24:28','',0,'http://www.groparu.ro/?p=1154',0,'post','',21),(1155,1,'2008-07-15 21:35:46','2008-07-15 19:35:46','Deci am facut cunoÅŸtinÅ£Äƒ cu galeti de apÄƒ, goale, din plastic si tabla; cu coceni rontaiti de porumb fiert, cu coji de pepene, si cu doi mititei pe jumate rontaiti, pe care nepotii mei nu mai vroiau sa-i molfaie; cu coji de paine intarita pe care cÃ¢inii vecinului le-au refuzat cu demnitate, cu palmutele cu care nepotii mei se sterg la gura cand mananca gratar inmuiat in grasime; cu o coada de grebla, cu butonul de volum de la  casetofon, care a cazut in iarba si nu a mai fost niciodata regasit; cu doua CD-uri cu Irina Loghin, preferatele alor mei, fara carcasa, pentru cÄƒ cu carcasa fÄƒcusem cunostinta anul trecut, cand veniserÄƒ nepoÅ£ii; mai ales cu doua masinute de jucarie Made in China, pana cand din ele nu a ramas decat o masa diforma de  plasticÄƒraie; cu o casca de Darth Vader, luata cadou; cu un scaun de terasa, din plastic si el, si si verde, cel mai dureros verde; cu o mÃ¢nÄƒ bine Å£intitÄƒ de pilaf de orez cu morcovi; cu caisele mucegaite uitate 4 zile la umbra, intr-o punga, si care deja incepusera sa cam fermenteze si sa miste, ca am si crezut ca ma vor sugruma din zbor; si cea mai zgubilitica chestie cu care am facut cunostinta la cap a fost un scutec destul de necurat, si incerc sa nu imi amintesc cu ce chestie verzuie  era el, scutecul, destul de plin.\r\n\r\nCu toate chestiile astea am facut cunostinta, eu si capul meu, weekendul asta de pauza prelungita, cata vreme am stat la Orlat si m-am luptat zi-lumina cu nepotii mei de 7, respectiv 3 ani!','Nepoti wars',0,'','publish','open','open','','nepoti-wars','','','2008-07-15 21:35:46','2008-07-15 19:35:46','',0,'http://www.groparu.ro/?p=1155',0,'post','',18),(1156,1,'2008-07-16 21:34:34','2008-07-16 19:34:34','Deci vestea proasta e ca ma cam doare o masea de minte, cÄƒ la mine asa ie: o data la trei ani, mÄƒseaua de minte se inflameazÄƒ, se rÄƒsteÅŸte la mine de parcÄƒ ar fi soacrÄƒ-mea dacÄƒ m-ar prinde bat (ÅŸi dacÄƒ aÅŸ avea vreo soacrÄƒ), ÅŸi o mai ÅŸi streseazÄƒ pe gingia care, ca proasta, Ã®ncepe sÄƒ protesteze cÄƒ ei nu-i convine, cÄƒ ea nu o fost proiectatÄƒ din fabricÄƒ sÄƒ reziste la asa ceva; ÅŸi cÄƒ dacÄƒ nu-mi convine, n-am decÃ¢t sÄƒ Ã®mi iau o alta, import China, nouÄƒ.\r\n\r\nDar vestea bunÄƒ e cÄƒ dacÄƒ mÄƒseaua de minte creÅŸte, insamnÄƒ cÄƒ creÅŸte ÅŸi crieru\'; cÄƒ cicÄƒ mÄƒseaua de minte e mÄƒsura inteligenÅ£ei. Ori dacÄƒ Ã®mi creÅŸte crieru, Ã®nsamnÄƒ cÄƒ Ã®mi creÅŸte ÅŸi cea puÅ£ulicÄƒ, bat-o vina! FincÄƒ se ÅŸtie cÄƒ la masculi crieru\' nu pluteÅŸte prin cap, ca la fomei, ci zace prin chiloti, ca padiÅŸahu\'. Si la cum ma doare, io mÄƒ astept la o mÄƒrire a mÃ¢ndreÅ£ii mele de mÄƒdular cam pe cÃ¢t creste <a href=\"http://www.hotnews.ro/stiri-international-3596764-inflatia-zimbabwe-ajuns-2-2-milioane-suta.htm\" target=\"_blank\">inflatia Ã®n Zimbabwe</a>; mai ales cÄƒ io ÅŸtrumeleagul mi-l grijesc mereu, ÅŸi-l Ã®nfÄƒÅŸez numai Ã®n chiloÅ£i roÅŸii ne-gay cumpÄƒraÅ£i de la magazinu Äƒla cu haine aproape noi, import Italia; asa cÄƒ dacÄƒ mi se adevereÅŸte previziunea mea cÄƒ o sÄƒ mi se mÄƒreasca crieru\', vÄƒ previn cÄƒ am sa plec intr-o expeditie in Africa ca sÄƒ devin rege peste tot tribul lui MÄƒtÄƒrÃ¢ngÄƒ!!!!!!','Veste proasta, veste buna',0,'','publish','open','open','','veste-proasta-veste-buna','','','2008-07-16 21:49:29','2008-07-16 19:49:29','',0,'http://www.groparu.ro/?p=1156',0,'post','',13),(1157,1,'2008-07-17 13:49:45','2008-07-17 11:49:45','Pentru non-clujeni: asta e o terasa unse se papa relativ decent: un pranz costa 10.60 lei. Felu 1, felu 2. Si si gustos.\r\n\r\nMerg azi cu un onor coleg si cu doi strÄƒinezi: unu egipÅ£ian, altu englezoc de la mama lui. Zice egipÅ£ianu\': maimuta asta plange inainte de a fi mancat, sau dupa ce o mancat?\r\n\r\nComandÄƒm zama: egiptianu o zis ca nu papa porc, cÄƒ-l trÄƒjneÅŸte; aÅŸa cÄƒ ii lom zamÄƒ de vitÄƒ ÅŸi grÄƒtar de vitÄƒ. Si noi ÄƒÅŸtialanÅ£ii ne lom trei menie.\r\n\r\nSi cand ne aduce meniul, surprizÄƒ! In zama lu\' englezocu\' se lÄƒfÄƒia, mÄƒre, o muscoaie verde, mare cÃ¢t o libelulÄƒ obezÄƒ. Deci genu\' Äƒla de muscÄƒ care culege nutrienÅ£i vitali de la gurile baieÅ£eilor gravizi din Darfur, ÅŸi care daca se inerveaza te aspirÄƒ cu trompa si te rÄƒdicÄƒ Ã®n Ã®naltul ceriului ÅŸi te devoreazÄƒ, elitrÄƒ cu elitrÄƒ.\r\n\r\nÃŽntÃ¢mplÄƒtor, chelneriÅ£a mi-a fost mie elevÄƒ; fincÄƒ foÅŸtii mei elevi ajung toÅ£i Ã®n posturi babane de taximetriÅŸti, ospÄƒtari, sau chiar frizeri. Åži Ã®i zic: puiuÅ£, ÅŸtii, avem o muscÄƒ Ã®n zamÄƒ!\r\n\r\nÅžtiu, zice ea, acuma vin sÄƒ rezolv.\r\n\r\nÅži dispare.\r\n\r\nÅži ne rÃ¢dem de musca aia cum stÄƒtea ea Ã®necatÄƒ, ca proasta, Ã®n zama de porc a la grec, cÃ¢nd putea alege ÅŸi ea o bere mai cumsecade, fÄƒcutÄƒ la Giurgiu din apÄƒ de munte.\r\n\r\nÅži revine chelneriÅ£a <strong>cu o linguriÅ£Äƒ de plastic cu care</strong> <strong>mesteci zahÄƒru Ã®n cafea</strong>, sÄƒ ne elibereze de muscÄƒ. Åži noi privim, ÅŸi nu ne vine a crede: WWWTTTTFFFF????\r\n\r\nÅži Ã®i zic: deci te rog sÄƒ ne schimbi zama asta, cÄƒ noi preferÄƒm sÄƒ pÄƒpÄƒm muÅŸtile separat, la desert.\r\n\r\nAÅŸa cÄƒ d-ra pleacÄƒ, ÅŸi revine <em>cu altÄƒ zamÄƒ</em>, cred. Nush. Da\' am mancat zama aia aÅŸa, cum ierea iea.\r\n\r\nÅži Ã®i zic lu egipÅ£ian: dacÄƒ nimereai tu zama aia cu musca, i-aÅŸ fi zis la chelneriÅ£Äƒ: \"Mai, fato, domnu\' e din Egipt; ÅŸi ei acolo nu papÄƒ decÃ¢t scarabei Ã®n supÄƒ, nu ÅŸi muÅŸti balcanice albastre!\"\r\n\r\nÅži egipÅ£ianu\' nu o rÃ¢s.\r\n\r\nAtÃ¢t.\r\n\r\nPS: si am vrut sa ii mai zic la chelnerita \"Asa va invata pe voi la scoala?\", da\' nu am mai gasit-o la plecare. Bag sama ca pescuia musti prin zama :|','Cand manÃ¢nci la MaimuÅ£a PlÃ¢ngÄƒtoare',0,'','publish','open','open','','cand-mananci-la-maimuta-plangatoare','','','2008-07-17 13:57:10','2008-07-17 11:57:10','',0,'http://www.groparu.ro/?p=1157',0,'post','',15),(1158,1,'2008-07-18 08:51:45','2008-07-18 06:51:45','1. A venit la mine sa imi schimbe bateria de la cada, si dupa ce a desfacut maruntaiele peretelui nu s-o loat cu mana de par zicand \"PFUAAAAAY, CE AM GASIT AICEA!!!!!! PAI ASTA VA COSTA 6 MILIOANE, CEL PUTIN!\" - dimpotriva, a operat ce a avut de operat fara sa imi dea impresia ca Doamneee, ce serviciu imi face el mie! - finca se stie ca instalatorii fac si asta.\r\n\r\n2. Nu mi-a aratat nici o secunda decolteul acela care se vede la pantalonii instalatorului cand se apleaca - finca se stie ca instalatorii fac si asta.\r\n\r\n3. Nu a incercat sa se deie la curu\' gazdei, adica al meu - finca se stie ca instalatorii fac si asta.\r\n\r\n4. A refuzat cu demnitate cand i-am propus sa bage un ÅŸtampÄƒl de votca inainte (finca se stie ca instalatorii fac si asta), <em>ca sa nu-i tremure mÃ¢na.</em>\r\n\r\nSi toate acestea se intamplau, cum e si normal, la Cluuuuuj. Si tot la Cluuuuuj, instalatorii de aceasta semintie nu iti iau nici un leutz - fincÄƒ e pÄƒrintele lu\' Tibby, si se ÅŸtie cÄƒ pÄƒrinÅ£ii lu\' Tibby fac si asta.','Multumesc si pe aceasta cale instalatorului care...',0,'','publish','open','open','','multumesc-si-pe-aceasta-cale-instalatorului-care','','','2008-07-18 08:51:45','2008-07-18 06:51:45','',0,'http://www.groparu.ro/?p=1158',0,'post','',22),(1159,1,'2008-07-20 23:11:40','2008-07-20 21:11:40','ÃŽmi trec mÃ¢nuÅ£ele pline de poftÄƒ peste nÄƒsucul ÅŸi urechile tale, si le mÃ¢ngÃ¢i cu drag ÅŸi duioÅŸie; tu tresari cÃ¢nd Ã®mi simÅ£i glasul uÅŸor strident, ca un motor diesel in miniaturÄƒ, care te anunÅ£Äƒ cÄƒ a venit dimineaÅ£a. Tu Ã®ncÄƒ dormi, iar eu Ã®ncep ziua explorÃ¢nd tot, dar absolut tot ce e Ã®n camerÄƒ, ÅŸi revin la tine invariabil, tu eÅŸti eterna mea reÃ®ntoarcere, deÅŸi, distant, mÄƒ alungi cu mÃ¢na. Revin cu obstinaÅ£ie: vederea trupului tÄƒu Ã®ntins Ã®n pat este pur ÅŸi simplu irezistibilÄƒ, mÄƒ Ã®nnebuneÅŸte atÃ¢t de tare Ã®ncÃ¢t pur ÅŸi simplu ador mirosul somnului tÄƒu, chiar ÅŸi adierile care ies din guriÅ£a ta Ã®ntredeschisÄƒ, din care uneori picurÄƒ salivÄƒ verzuie pe faÅ£a de pernÄƒ.\r\n\r\nCÄƒ am fost fÄƒcuÅ£i unul pentru celÄƒlalt e indubitabil, deÅŸi amorul dintre noi e uneori violent. Eu sunt cea care, Ã®n dimineÅ£ile cÄƒlduroase de varÄƒ, vine ÅŸi te trezeste cu pupici racorosi si lipiciosi. Sunt eu, musca de apartament.','VouÄƒ cum vÄƒ place sÄƒ fiÅ£i treziÅ£i?',0,'','publish','open','open','','voua-cum-va-place-sa-fiti-treziti','','','2008-07-20 23:19:40','2008-07-20 21:19:40','',0,'http://www.groparu.ro/?p=1159',0,'post','',17),(1160,1,'2008-07-22 08:54:31','2008-07-22 06:54:31','Deci io am un vecin indian la mine-n bloc - da\' nu d-ala de-a lu\' Dancing Clouds, Sitting Bull, Runny Nose.  Zic indian - indian-indian, ÅŸtiÅ£i voi, Mahindra, Lakshmi Mittal, Tata Motors, Kashmir, soft si curry, deci tÄƒt felu\', deci indian.\r\n\r\nAmu-s vreo douÄƒ sÄƒptÄƒmÃ¢ni, indianu\', impreunÄƒ cu alti membri ai naÅ£iei care l-au supus pe Machedon, or pus mÃ¢nÄƒ de la mÃ¢nÄƒ, or mai chemat ceva studenti indieni, ÅŸi or pus bazele unui <a href=\"http://www.maharaja.ro/\" target=\"_blank\">restaurant <em>take away</em></a> Ã®n care Ã®nsuÅŸi indianul nostru gÄƒteÅŸte el Ã®nsuÅŸi deci reÅ£etele ÅŸi papa, ca sa nu existe dubii.\r\n\r\nDeci - mÄƒi copii.\r\n\r\nIo am zis mereu cÄƒ din . meu de vedere, gastronomia culinarÄƒ se poate limita la paparÄƒ cu mÄƒmÄƒligÄƒ, eventual oua fierte cu paine prajitÄƒ - hai, maxim un paine cu unt si cu salam.\r\n\r\nDar n-ar fi asta singura datÄƒ cÃ¢nd Groparu derapeazÄƒ.\r\n\r\nDeci ascultati.\r\n\r\nPapa indian pe care il face baietii astia e in felul asta: FOARTE BUNA.\r\n\r\nPunct.\r\n\r\nDeci buna si gustoasa.\r\n\r\nDeci io nu ma prea omor cu mancatul, mai ales ca in Cluju asta cu greu gasesti un papa care sa fie facut cu dragoste, finca nici un bucatar nu mangaie papa si nu ii vorbeste in timp ce o sexeaza, si papa simte asta, si nu mai iese buna: ca asa e papa, ca o femeie Å£Ã¢fnoasÄƒ pe care trebe sÄƒ o ÅŸi plimbi cu maÅŸina, sÄƒ o ÅŸi duci la mall, sÄƒ Ã®i ÅŸi cari plasele, sÄƒ Ã®i ÅŸi repari ghiveta, sÄƒ nici nu te uiÅ£i la pretenele ei, sÄƒ fii ÅŸi respectuos cu mÄƒ-sa aia cu gura acrÄƒ, sÄƒ Ã®Å£i ÅŸi placÄƒ cum gÄƒteÅŸte, sÄƒ nu scoÅ£i nici un cuvinÅ£el douÄƒ ore pe zi cÃ¢tÄƒ vreme Å£i spune ce mai e nou la serviciu, sa nu te inervezi cÄƒ habar n-are sÄƒ parcheze sau o zgÃ¢riat iarÄƒ maÅŸina, pisu\', sÄƒ nu mai mergi la folbal cu betivii aia de prieteni ai tai, sÄƒ Ã®i repari tocurile de la sandale, sÄƒ nu te superi dacÄƒ vine dupÄƒ o juma de orÄƒ la Ã®ntÃ¢lnire, sÄƒ fii mai meseriaÅŸ ÅŸi mai alfa decÃ¢t toÅ£i masculii prietenelor si colegelor ei si - auzi aicea neobrÄƒzare! - sÄƒ ii faci ÅŸi preludiu, ÅŸi postludiu.\r\n\r\nNo.\r\n\r\nDeci indianul meu, vreau sa va zic ca aÅŸa de bine preludiazÄƒ ÅŸi postludeazÄƒ papa, cÄƒ io, unu, care nu prea-s mÃ¢ncÄƒcios cand pap la restaurante, am papat pe nerÄƒsuflate 4 portii mari (!!!) de papa indian si bun, da\' bun-bun, ÅŸi stomacul meu efectiv s-a simtit iubit! Si cel mai, cel mai important e faptul ca - cÃ¢nd am mers la baie, curry Äƒla din puiul cu curry nu m-a zgariat, ca ghearele de pisici, stiti voi unde.\r\n\r\nStiti de ce?\r\n\r\nFinca papa e facut cu dragoste. Si papa simte asta.\r\n\r\nDeci: <a href=\"http://www.maharaja.ro\" target=\"_blank\">www.maharaja.ro</a>. Nush daca includ si harem de fomei la comanda de papa, cÄƒ nu i-am intrebat.','VÄƒ trebe mancare indiana la Cluj?',0,'','publish','open','open','','va-trebe-mancare-indiana-la-cluj','','','2008-07-22 10:16:47','2008-07-22 08:16:47','',0,'http://www.groparu.ro/?p=1160',0,'post','',11),(1161,1,'2008-07-22 23:53:20','2008-07-22 21:53:20','Deci Gunther ii ceva soÅ£ neamÅ£ d-a lu\' ceva prekinÄƒ romÃ¢ncÄƒ d-a lu\' sor-mea, Å£uc-o mama.\r\n\r\nÅži deci Gunther neamÅ£u\' s-o mÄƒritat cu Mioara sibianca, ÅŸi din prea multÄƒ dragoste o Ã®nceput sÄƒ Ã®ncerce sÄƒ Ã®nveÅ£e ÅŸi el romÃ¢neste, ceea ce e mare lucru la nemti, care din punct de vedere congenital nu sunt prea talentati la invÄƒÅ£at limbi de Untermenschen, eksept fuer IngliÅŸ, ov cooos. Ji el vurbit rumuneÅŸte buÅ£in, aÅŸa, mai ales dupÄƒ beut palincÄƒ. Bun palincÄƒ Ã®n Rumunia! Bun.\r\n\r\nAÅŸa.\r\n\r\nÅži ei, cÃ¢nd vin Ã®n Sibiu, adÄƒsteazÄƒ la <a href=\"http://www.groparu.ro/?p=460\" target=\"_blank\">SÄƒliÅŸte</a>, Ã®n inima MÄƒrginimii, care-i lÃ¢ngÄƒ TiliÅŸca, unde se deschide berea cu briÅŸca.\r\n\r\nÅži cum merg ei odatÄƒ prin SÄƒliÅŸte la plimbare cu aia mica a lor, vÄƒd cÄƒ vine din faÅ£Äƒ dom\' pÄƒrintele satului! Åži nevastÄƒ-sa imediat Ã®i ÅŸopteÅŸte cu voce tare: \"Uite-l pe popa! Zi-i buna ziua!\" C-aÅŸa e in MÄƒrginime, oameni cu bun simÅ£ (atÃ¢ta numa ca nu suporta viniturile).\r\n\r\nAÅŸa cÄƒ Ã®n momentul Ã®n care popa s-o apropiat, Gunther, disciplinat, l-o salutat pe popa tunÄƒtor de o rÄƒsunat toÅ£i munÅ£ii, ca un neamÅ£ mÃ¢ndru ce e el de romÃ¢na pentru care o ÅŸtie: ZI BUNA ZIUA, herr popa!!!!\r\n\r\nAtÃ¢t. Nu se ÅŸtie dacÄƒ popa o rÃ¢s, dar cercetÄƒrile continuÄƒ.','Una scurta cu Gunther, da\' destul de groasÄƒ',0,'','publish','open','open','','una-scurta-cu-gunther-da-destul-de-groasa','','\nhttp://www.groparu.ro/?p=460','2008-07-22 23:53:20','2008-07-22 21:53:20','',0,'http://www.groparu.ro/?p=1161',0,'post','',2),(1162,2,'2008-07-24 09:51:11','2008-07-24 07:51:11','O colega se spÄƒla pe maini. O intreb:\r\n\r\n- Sa te ajut?\r\n- La ce? zice ea.\r\n- Sa te uzi, zic io.','La buda firmei',0,'','publish','open','open','','la-buda-firmei','','','2008-07-24 09:51:11','2008-07-24 07:51:11','',0,'http://www.groparu.ro/?p=1162',0,'post','',1),(1163,2,'2008-07-24 14:47:26','2008-07-24 12:47:26','','img_6752.JPG',0,'','inherit','open','open','','img_6752jpg','','','2008-07-24 14:47:26','2008-07-24 12:47:26','',0,'http://www.groparu.ro/wp-content/uploads/2008/07/img_6752.JPG',0,'attachment','image/jpeg',0);
/*!40000 ALTER TABLE `wp_posts` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `wp_term_relationships`
--

DROP TABLE IF EXISTS `wp_term_relationships`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `wp_term_relationships` (
  `object_id` bigint(20) NOT NULL DEFAULT 0,
  `term_taxonomy_id` bigint(20) NOT NULL DEFAULT 0,
  `term_order` int(11) NOT NULL DEFAULT 0,
  PRIMARY KEY (`object_id`,`term_taxonomy_id`),
  KEY `term_taxonomy_id` (`term_taxonomy_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `wp_term_relationships`
--

LOCK TABLES `wp_term_relationships` WRITE;
/*!40000 ALTER TABLE `wp_term_relationships` DISABLE KEYS */;
INSERT INTO `wp_term_relationships` VALUES (2,1,0),(4,1,0),(4,3,0),(7,3,0),(8,3,0),(9,3,0),(10,3,0),(13,3,0),(14,3,0),(15,3,0),(16,1,0),(17,5,0),(18,3,0),(19,3,0),(20,3,0),(21,3,0),(23,3,0),(25,3,0),(27,3,0),(28,4,0),(29,5,0),(30,3,0),(31,3,0),(32,3,0),(33,3,0),(34,5,0),(35,3,0),(36,3,0),(37,3,0),(38,1,0),(39,3,0),(40,1,0),(41,6,0),(42,5,0),(42,6,0),(43,5,0),(44,3,0),(45,3,0),(46,3,0),(47,4,0),(48,3,0),(49,3,0),(50,3,0),(51,5,0),(52,5,0),(53,11,0),(54,3,0),(55,3,0),(56,5,0),(57,6,0),(58,3,0),(58,7,0),(59,3,0),(60,8,0),(61,3,0),(62,3,0),(63,7,0),(64,3,0),(65,9,0),(66,3,0),(67,10,0),(68,3,0),(69,3,0),(70,3,0),(72,3,0),(73,3,0),(74,3,0),(74,7,0),(75,3,0),(76,5,0),(76,7,0),(77,5,0),(77,7,0),(78,3,0),(79,6,0),(80,3,0),(81,1,0),(82,1,0),(82,5,0),(83,3,0),(84,7,0),(85,7,0),(86,7,0),(87,10,0),(88,3,0),(89,7,0),(90,3,0),(91,3,0),(92,3,0),(93,11,0),(94,11,0),(95,3,0),(96,3,0),(97,8,0),(98,5,0),(99,3,0),(100,5,0),(101,7,0),(102,3,0),(103,5,0),(104,3,0),(105,12,0),(106,12,0),(107,3,0),(108,7,0),(110,9,0),(111,3,0),(112,3,0),(113,7,0),(114,7,0),(115,7,0),(116,3,0),(117,12,0),(118,12,0),(119,7,0),(120,13,0),(121,10,0),(122,7,0),(123,3,0),(124,8,0),(125,7,0),(126,13,0),(128,13,0),(129,3,0),(133,13,0),(134,13,0),(135,3,0),(136,5,0),(137,14,0),(138,3,0),(139,14,0),(140,3,0),(141,3,0),(142,3,0),(143,3,0),(144,3,0),(145,3,0),(145,13,0),(146,3,0),(147,3,0),(148,3,0),(149,7,0),(150,3,0),(151,14,0),(152,3,0),(153,7,0),(153,13,0),(154,15,0),(155,13,0),(156,3,0),(157,3,0),(158,3,0),(159,3,0),(160,13,0),(161,3,0),(162,3,0),(163,3,0),(164,14,0),(165,3,0),(166,3,0),(167,3,0),(168,3,0),(169,3,0),(170,3,0),(171,3,0),(172,3,0),(173,3,0),(174,3,0),(175,3,0),(176,3,0),(177,3,0),(178,3,0),(179,3,0),(180,3,0),(181,3,0),(182,3,0),(183,3,0),(184,3,0),(185,3,0),(186,3,0),(187,3,0),(188,3,0),(189,3,0),(190,3,0),(191,3,0),(192,3,0),(193,3,0),(194,3,0),(195,3,0),(196,3,0),(197,3,0),(198,3,0),(199,3,0),(200,3,0),(201,3,0),(202,3,0),(203,3,0),(204,3,0),(205,3,0),(206,3,0),(207,3,0),(208,3,0),(209,3,0),(210,3,0),(211,3,0),(212,3,0),(213,3,0),(214,3,0),(215,3,0),(216,3,0),(217,3,0),(218,3,0),(219,3,0),(220,3,0),(221,3,0),(222,3,0),(223,3,0),(224,3,0),(225,3,0),(226,3,0),(227,3,0),(228,3,0),(229,3,0),(230,3,0),(231,3,0),(232,3,0),(233,3,0),(234,3,0),(235,3,0),(236,3,0),(237,3,0),(238,3,0),(239,3,0),(240,3,0),(241,3,0),(242,3,0),(243,3,0),(244,3,0),(245,3,0),(246,3,0),(247,3,0),(248,3,0),(249,3,0),(250,3,0),(251,3,0),(252,3,0),(253,3,0),(254,3,0),(255,3,0),(256,3,0),(257,3,0),(258,3,0),(259,3,0),(260,3,0),(261,3,0),(262,3,0),(263,3,0),(264,7,0),(265,10,0),(266,7,0),(267,7,0),(267,13,0),(268,3,0),(269,3,0),(270,3,0),(271,16,0),(272,3,0),(273,3,0),(274,9,0),(275,3,0),(276,3,0),(277,3,0),(278,3,0),(279,3,0),(280,5,0),(281,3,0),(282,3,0),(283,3,0),(284,5,0),(285,5,0),(285,7,0),(286,3,0),(287,3,0),(288,7,0),(289,3,0),(290,5,0),(290,7,0),(291,7,0),(292,3,0),(293,7,0),(294,3,0),(295,3,0),(296,3,0),(297,3,0),(298,3,0),(299,3,0),(300,3,0),(301,9,0),(302,3,0),(303,3,0),(304,3,0),(305,3,0),(306,7,0),(307,3,0),(308,3,0),(310,3,0),(311,5,0),(312,3,0),(314,12,0),(315,7,0),(316,3,0),(317,5,0),(318,7,0),(319,7,0),(321,7,0),(322,15,0),(323,3,0),(324,13,0),(325,3,0),(326,5,0),(326,8,0),(327,3,0),(328,7,0),(329,5,0),(330,7,0),(331,7,0),(332,7,0),(332,14,0),(333,7,0),(334,3,0),(335,7,0),(336,7,0),(337,7,0),(338,7,0),(339,3,0),(340,3,0),(341,7,0),(342,3,0),(343,5,0),(343,7,0),(344,3,0),(345,5,0),(346,5,0),(346,7,0),(347,3,0),(348,3,0),(349,7,0),(350,3,0),(351,7,0),(352,15,0),(353,15,0),(354,5,0),(355,5,0),(356,7,0),(357,13,0),(358,3,0),(359,7,0),(360,17,0),(361,3,0),(362,3,0),(363,3,0),(364,3,0),(365,13,0),(366,3,0),(367,3,0),(368,14,0),(369,3,0),(370,3,0),(371,5,0),(372,3,0),(373,5,0),(374,14,0),(375,3,0),(376,7,0),(377,7,0),(378,7,0),(379,7,0),(380,3,0),(381,16,0),(382,3,0),(383,7,0),(384,3,0),(385,3,0),(386,17,0),(387,14,0),(387,17,0),(388,3,0),(389,7,0),(390,5,0),(391,3,0),(392,5,0),(394,3,0),(395,3,0),(396,14,0),(397,3,0),(398,14,0),(398,17,0),(399,3,0),(400,15,0),(401,3,0),(402,17,0),(405,4,0),(406,5,0),(407,3,0),(408,14,0),(408,17,0),(409,3,0),(410,4,0),(411,4,0),(412,5,0),(413,4,0),(414,13,0),(414,17,0),(415,14,0),(415,17,0),(416,3,0),(417,7,0),(419,5,0),(420,3,0),(421,14,0),(421,17,0),(422,17,0),(423,14,0),(423,17,0),(424,3,0),(425,3,0),(426,3,0),(427,3,0),(428,5,0),(429,3,0),(430,3,0),(431,3,0),(432,3,0),(433,3,0),(434,3,0),(435,3,0),(436,3,0),(437,4,0),(438,14,0),(438,17,0),(439,4,0),(440,3,0),(441,4,0),(442,4,0),(443,3,0),(444,3,0),(445,4,0),(446,3,0),(447,3,0),(448,3,0),(449,3,0),(450,3,0),(451,3,0),(452,3,0),(453,3,0),(454,3,0),(455,3,0),(456,3,0),(457,3,0),(458,3,0),(459,3,0),(460,5,0),(461,3,0),(462,7,0),(463,13,0),(465,5,0),(466,5,0),(468,3,0),(469,7,0),(470,3,0),(470,7,0),(471,5,0),(472,3,0),(473,5,0),(473,7,0),(474,17,0),(475,5,0),(476,3,0),(477,7,0),(478,3,0),(478,7,0),(479,7,0),(480,7,0),(481,5,0),(482,7,0),(483,4,0),(484,7,0),(485,5,0),(486,5,0),(487,7,0),(488,4,0),(488,5,0),(489,7,0),(490,7,0),(491,7,0),(492,7,0),(493,7,0),(494,7,0),(496,7,0),(497,7,0),(498,13,0),(499,7,0),(500,5,0),(502,5,0),(503,7,0),(504,5,0),(505,5,0),(506,5,0),(507,5,0),(508,7,0),(509,7,0),(510,7,0),(511,7,0),(512,7,0),(513,7,0),(514,7,0),(515,7,0),(516,7,0),(517,5,0),(518,7,0),(524,7,0),(525,5,0),(525,7,0),(526,5,0),(527,7,0),(528,7,0),(529,7,0),(530,5,0),(531,7,0),(532,7,0),(533,7,0),(534,7,0),(535,5,0),(536,5,0),(537,5,0),(538,7,0),(539,7,0),(540,5,0),(541,7,0),(542,5,0),(543,7,0),(544,5,0),(545,7,0),(546,7,0),(547,5,0),(548,5,0),(549,7,0),(550,5,0),(551,15,0),(552,7,0),(556,5,0),(557,5,0),(558,5,0),(559,5,0),(560,5,0),(561,7,0),(562,7,0),(563,7,0),(564,7,0),(565,13,0),(566,7,0),(567,7,0),(568,5,0),(569,5,0),(570,7,0),(571,7,0),(572,7,0),(573,7,0),(574,7,0),(575,7,0),(576,7,0),(577,7,0),(578,13,0),(579,15,0),(580,7,0),(581,7,0),(581,13,0),(582,13,0),(583,7,0),(584,7,0),(585,3,0),(586,7,0),(587,3,0),(587,7,0),(588,5,0),(589,5,0),(590,7,0),(591,7,0),(592,10,0),(593,5,0),(594,3,0),(594,7,0),(595,5,0),(595,7,0),(596,5,0),(597,5,0),(598,3,0),(599,5,0),(599,13,0),(600,7,0),(601,5,0),(601,13,0),(602,5,0),(602,13,0),(603,3,0),(604,5,0),(604,7,0),(604,13,0),(605,7,0),(606,3,0),(606,7,0),(607,15,0),(608,16,0),(609,7,0),(610,13,0),(611,7,0),(612,13,0),(613,5,0),(614,7,0),(615,7,0),(616,7,0),(617,7,0),(618,3,0),(618,7,0),(619,3,0),(620,5,0),(620,7,0),(620,13,0),(621,7,0),(622,13,0),(623,4,0),(624,7,0),(624,13,0),(625,7,0),(626,13,0),(627,3,0),(627,7,0),(628,3,0),(629,3,0),(630,5,0),(631,5,0),(632,13,0),(633,5,0),(633,13,0),(634,13,0),(635,5,0),(636,13,0),(637,3,0),(638,10,0),(639,5,0),(640,5,0),(640,7,0),(641,5,0),(642,7,0),(643,5,0),(643,13,0),(644,7,0),(645,5,0),(645,13,0),(646,5,0),(646,7,0),(646,13,0),(647,16,0),(648,5,0),(649,7,0),(649,13,0),(650,5,0),(651,7,0),(652,7,0),(653,7,0),(654,7,0),(655,7,0),(656,7,0),(656,9,0),(657,3,0),(657,7,0),(657,13,0),(658,5,0),(658,13,0),(658,14,0),(659,4,0),(660,7,0),(661,13,0),(662,7,0),(663,5,0),(664,5,0),(664,13,0),(665,5,0),(666,7,0),(667,3,0),(667,7,0),(668,15,0),(669,13,0),(670,5,0),(671,5,0),(671,13,0),(672,5,0),(672,13,0),(673,7,0),(674,7,0),(675,3,0),(675,7,0),(675,13,0),(676,7,0),(676,10,0),(677,5,0),(677,13,0),(678,7,0),(679,7,0),(680,7,0),(681,7,0),(682,7,0),(683,5,0),(683,7,0),(683,13,0),(684,7,0),(685,5,0),(685,13,0),(686,7,0),(687,7,0),(688,5,0),(688,13,0),(689,3,0),(690,3,0),(690,7,0),(691,3,0),(691,7,0),(692,3,0),(692,7,0),(693,5,0),(694,7,0),(695,7,0),(696,7,0),(697,10,0),(698,5,0),(699,7,0),(699,13,0),(700,5,0),(700,13,0),(701,7,0),(701,13,0),(702,7,0),(702,13,0),(703,7,0),(704,7,0),(705,7,0),(706,7,0),(707,10,0),(708,5,0),(708,7,0),(709,5,0),(709,7,0),(709,13,0),(710,7,0),(711,5,0),(711,13,0),(711,17,0),(712,7,0),(712,13,0),(713,7,0),(714,7,0),(715,3,0),(715,7,0),(716,7,0),(717,7,0),(718,5,0),(718,7,0),(719,7,0),(720,5,0),(720,11,0),(721,7,0),(722,7,0),(723,7,0),(724,7,0),(725,7,0),(726,7,0),(727,7,0),(728,7,0),(729,7,0),(730,7,0),(731,7,0),(732,7,0),(733,7,0),(734,7,0),(735,5,0),(735,11,0),(736,7,0),(737,5,0),(737,7,0),(737,13,0),(738,7,0),(739,7,0),(740,5,0),(740,13,0),(741,7,0),(742,13,0),(743,7,0),(744,7,0),(746,5,0),(748,7,0),(749,5,0),(750,5,0),(750,13,0),(751,15,0),(752,7,0),(753,5,0),(753,13,0),(754,3,0),(755,3,0),(755,7,0),(756,10,0),(756,13,0),(757,5,0),(758,5,0),(758,13,0),(759,7,0),(759,13,0),(760,5,0),(761,7,0),(762,7,0),(763,13,0),(764,7,0),(765,7,0),(766,7,0),(767,7,0),(768,7,0),(769,5,0),(769,13,0),(770,5,0),(771,13,0),(771,16,0),(772,13,0),(773,7,0),(774,7,0),(775,7,0),(776,7,0),(777,13,0),(779,7,0),(780,7,0),(782,5,0),(782,7,0),(782,13,0),(783,7,0),(784,3,0),(784,8,0),(784,14,0),(785,5,0),(786,5,0),(787,7,0),(788,7,0),(789,13,0),(790,13,0),(790,17,0),(791,7,0),(792,7,0),(793,10,0),(794,5,0),(794,13,0),(795,7,0),(796,7,0),(797,5,0),(798,5,0),(799,13,0),(799,17,0),(800,7,0),(801,5,0),(801,13,0),(802,7,0),(803,13,0),(804,7,0),(805,17,0),(806,7,0),(807,17,0),(810,7,0),(811,17,0),(812,9,0),(813,14,0),(814,18,0),(815,5,0),(815,13,0),(816,3,0),(817,9,0),(818,3,0),(819,4,0),(820,3,0),(821,7,0),(822,10,0),(823,7,0),(824,7,0),(825,7,0),(826,7,0),(827,7,0),(828,7,0),(829,7,0),(830,3,0),(831,14,0),(832,10,0),(833,7,0),(834,7,0),(835,7,0),(838,10,0),(839,12,0),(840,14,0),(841,12,0),(842,5,0),(842,7,0),(842,13,0),(843,7,0),(843,13,0),(844,13,0),(844,16,0),(845,17,0),(846,13,0),(847,13,0),(848,7,0),(849,7,0),(850,5,0),(852,7,0),(853,14,0),(854,7,0),(855,17,0),(856,7,0),(857,7,0),(858,9,0),(859,3,0),(860,5,0),(860,13,0),(862,7,0),(863,15,0),(864,15,0),(865,7,0),(866,7,0),(867,17,0),(868,3,0),(868,7,0),(869,7,0),(870,7,0),(871,7,0),(872,7,0),(873,7,0),(874,7,0),(875,7,0),(876,7,0),(877,7,0),(878,7,0),(879,7,0),(880,7,0),(881,7,0),(882,7,0),(883,7,0),(884,7,0),(885,7,0),(886,7,0),(887,7,0),(888,5,0),(889,3,0),(890,5,0),(890,13,0),(891,7,0),(892,7,0),(893,3,0),(894,3,0),(895,3,0),(896,7,0),(898,9,0),(899,7,0),(900,13,0),(901,7,0),(902,7,0),(903,7,0),(904,7,0),(905,7,0),(906,13,0),(907,13,0),(908,3,0),(909,3,0),(910,7,0),(911,13,0),(911,14,0),(912,5,0),(912,13,0),(913,3,0),(914,13,0),(915,15,0),(916,3,0),(917,5,0),(918,5,0),(919,7,0),(920,7,0),(921,7,0),(922,7,0),(923,7,0),(924,7,0),(925,7,0),(926,7,0),(927,13,0),(928,7,0),(929,7,0),(930,7,0),(931,7,0),(932,7,0),(933,7,0),(934,7,0),(935,7,0),(936,7,0),(937,7,0),(938,7,0),(939,7,0),(940,7,0),(941,7,0),(942,7,0),(943,7,0),(944,7,0),(945,13,0),(946,15,0),(947,5,0),(948,7,0),(949,5,0),(949,13,0),(950,7,0),(951,7,0),(952,5,0),(952,13,0),(953,7,0),(953,13,0),(954,3,0),(955,13,0),(956,3,0),(957,3,0),(959,16,0),(960,9,0),(961,3,0),(962,7,0),(964,7,0),(965,13,0),(966,3,0),(967,3,0),(968,3,0),(969,7,0),(970,3,0),(971,10,0),(972,5,0),(972,13,0),(973,13,0),(974,3,0),(976,3,0),(977,3,0),(978,17,0),(979,17,0),(980,5,0),(980,13,0),(981,3,0),(982,15,0),(983,3,0),(983,13,0),(984,5,0),(984,13,0),(985,3,0),(986,9,0),(988,5,0),(989,3,0),(990,13,0),(991,13,0),(992,13,0),(993,7,0),(994,15,0),(995,15,0),(997,7,0),(998,7,0),(999,7,0),(1000,7,0),(1001,13,0),(1002,10,0),(1003,7,0),(1004,7,0),(1005,7,0),(1006,7,0),(1007,10,0),(1008,17,0),(1009,16,0),(1010,5,0),(1010,13,0),(1011,13,0),(1012,3,0),(1013,10,0),(1014,7,0),(1015,3,0),(1016,15,0),(1017,10,0),(1018,3,0),(1019,15,0),(1020,3,0),(1021,3,0),(1023,5,0),(1024,7,0),(1025,5,0),(1026,5,0),(1026,13,0),(1027,5,0),(1028,10,0),(1029,5,0),(1030,13,0),(1031,5,0),(1032,7,0),(1033,18,0),(1034,3,0),(1035,7,0),(1036,5,0),(1037,18,0),(1038,3,0),(1039,9,0),(1040,9,0),(1041,3,0),(1042,10,0),(1043,5,0),(1044,5,0),(1045,10,0),(1045,14,0),(1046,3,0),(1047,15,0),(1048,3,0),(1048,8,0),(1049,3,0),(1050,5,0),(1051,7,0),(1052,3,0),(1052,7,0),(1053,3,0),(1054,15,0),(1055,3,0),(1056,5,0),(1057,3,0),(1057,14,0),(1057,17,0),(1058,10,0),(1060,10,0),(1060,13,0),(1061,3,0),(1062,10,0),(1062,13,0),(1062,17,0),(1063,7,0),(1064,10,0),(1066,10,0),(1068,7,0),(1069,7,0),(1070,7,0),(1071,7,0),(1072,7,0),(1073,7,0),(1074,7,0),(1075,7,0),(1076,5,0),(1076,13,0),(1077,3,0),(1078,3,0),(1079,12,0),(1080,3,0),(1081,3,0),(1082,3,0),(1082,14,0),(1083,13,0),(1084,10,0),(1085,3,0),(1086,3,0),(1087,3,0),(1088,15,0),(1089,13,0),(1089,18,0),(1090,5,0),(1091,15,0),(1092,13,0),(1093,13,0),(1094,16,0),(1095,10,0),(1096,7,0),(1097,3,0),(1098,7,0),(1099,7,0),(1100,7,0),(1101,7,0),(1102,7,0),(1103,7,0),(1104,4,0),(1105,4,0),(1106,4,0),(1107,15,0),(1108,7,0),(1109,10,0),(1114,7,0),(1115,13,0),(1115,16,0),(1116,7,0),(1117,7,0),(1118,10,0),(1119,13,0),(1120,7,0),(1121,3,0),(1122,16,0),(1123,7,0),(1124,7,0),(1125,4,0),(1125,13,0),(1126,10,0),(1127,9,0),(1128,7,0),(1129,7,0),(1130,7,0),(1131,7,0),(1132,10,0),(1133,9,0),(1135,5,0),(1136,18,0),(1137,5,0),(1138,7,0),(1138,8,0),(1139,11,0),(1140,7,0),(1141,7,0),(1142,7,0),(1143,7,0),(1144,7,0),(1145,16,0),(1146,7,0),(1147,16,0),(1148,13,0),(1149,5,0),(1149,13,0),(1149,14,0),(1150,5,0),(1150,13,0),(1151,5,0),(1151,13,0),(1152,7,0),(1153,10,0),(1154,13,0),(1155,5,0),(1156,7,0),(1157,5,0),(1158,5,0),(1159,7,0),(1160,10,0),(1161,18,0),(1162,18,0),(1163,7,0),(8,2,0),(10,2,0),(14,2,0),(15,2,0),(18,2,0),(19,2,0),(20,2,0),(22,2,0),(23,2,0),(24,2,0),(25,2,0),(27,2,0),(29,2,0),(31,2,0),(32,2,0),(33,2,0),(34,2,0),(36,2,0),(39,2,0),(41,2,0),(42,2,0),(45,2,0),(46,2,0),(47,2,0),(48,2,0),(49,2,0);
/*!40000 ALTER TABLE `wp_term_relationships` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `wp_term_taxonomy`
--

DROP TABLE IF EXISTS `wp_term_taxonomy`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `wp_term_taxonomy` (
  `term_taxonomy_id` bigint(20) NOT NULL AUTO_INCREMENT,
  `term_id` bigint(20) NOT NULL DEFAULT 0,
  `taxonomy` varchar(32) NOT NULL DEFAULT '',
  `description` longtext NOT NULL,
  `parent` bigint(20) NOT NULL DEFAULT 0,
  `count` bigint(20) NOT NULL DEFAULT 0,
  PRIMARY KEY (`term_taxonomy_id`),
  UNIQUE KEY `term_id_taxonomy` (`term_id`,`taxonomy`)
) ENGINE=MyISAM AUTO_INCREMENT=19 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `wp_term_taxonomy`
--

LOCK TABLES `wp_term_taxonomy` WRITE;
/*!40000 ALTER TABLE `wp_term_taxonomy` DISABLE KEYS */;
INSERT INTO `wp_term_taxonomy` VALUES (1,1,'category','',0,6),(2,2,'link_category','',0,26),(3,3,'category','',0,101),(4,4,'category','',0,19),(5,5,'category','',0,171),(6,6,'category','',0,4),(7,7,'category','',0,175),(8,8,'category','',0,6),(9,9,'category','',0,15),(10,10,'category','',0,35),(11,11,'category','',0,6),(12,12,'category','',0,8),(13,13,'category','',0,126),(14,14,'category','',0,26),(15,15,'category','',0,24),(16,16,'category','',0,13),(17,17,'category','',0,27),(18,18,'category','',0,7);
/*!40000 ALTER TABLE `wp_term_taxonomy` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `wp_terms`
--

DROP TABLE IF EXISTS `wp_terms`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `wp_terms` (
  `term_id` bigint(20) NOT NULL AUTO_INCREMENT,
  `name` varchar(55) NOT NULL DEFAULT '',
  `slug` varchar(200) NOT NULL DEFAULT '',
  `term_group` bigint(10) NOT NULL DEFAULT 0,
  PRIMARY KEY (`term_id`),
  UNIQUE KEY `slug` (`slug`)
) ENGINE=MyISAM AUTO_INCREMENT=19 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `wp_terms`
--

LOCK TABLES `wp_terms` WRITE;
/*!40000 ALTER TABLE `wp_terms` DISABLE KEYS */;
INSERT INTO `wp_terms` VALUES (1,'','',1),(2,'','-2',1),(3,'','-2-2',1),(4,'','-2-2-2',1),(5,'','-2-2-2-2',1),(6,'','-2-2-2-2-2',1),(7,'','-2-2-2-2-2-2',1),(8,'','-2-2-2-2-2-2-2',1),(9,'','-2-2-2-2-2-2-2-2',1),(10,'','-2-2-2-2-2-2-2-2-2',1),(11,'','-2-2-2-2-2-2-2-2-2-2',1),(12,'','-2-2-2-2-2-2-2-2-2-2-2',1),(13,'','-2-2-2-2-2-2-2-2-2-2-2-2',1),(14,'','-2-2-2-2-2-2-2-2-2-2-2-2-2',1),(15,'','-2-2-2-2-2-2-2-2-2-2-2-2-2-2',1),(16,'','-2-2-2-2-2-2-2-2-2-2-2-2-2-2-2',1),(17,'','-2-2-2-2-2-2-2-2-2-2-2-2-2-2-2-2',1),(18,'','-2-2-2-2-2-2-2-2-2-2-2-2-2-2-2-2-2',1);
/*!40000 ALTER TABLE `wp_terms` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `wp_usermeta`
--

DROP TABLE IF EXISTS `wp_usermeta`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `wp_usermeta` (
  `umeta_id` bigint(20) NOT NULL AUTO_INCREMENT,
  `user_id` bigint(20) NOT NULL DEFAULT 0,
  `meta_key` varchar(255) DEFAULT NULL,
  `meta_value` longtext DEFAULT NULL,
  PRIMARY KEY (`umeta_id`),
  KEY `user_id` (`user_id`),
  KEY `meta_key` (`meta_key`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `wp_usermeta`
--

LOCK TABLES `wp_usermeta` WRITE;
/*!40000 ALTER TABLE `wp_usermeta` DISABLE KEYS */;
/*!40000 ALTER TABLE `wp_usermeta` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `wp_users`
--

DROP TABLE IF EXISTS `wp_users`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `wp_users` (
  `ID` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `user_login` varchar(60) NOT NULL DEFAULT '',
  `user_pass` varchar(64) NOT NULL DEFAULT '',
  `user_nicename` varchar(50) NOT NULL DEFAULT '',
  `user_email` varchar(100) NOT NULL DEFAULT '',
  `user_url` varchar(100) NOT NULL DEFAULT '',
  `user_registered` datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  `user_activation_key` varchar(60) NOT NULL DEFAULT '',
  `user_status` int(11) NOT NULL DEFAULT 0,
  `display_name` varchar(250) NOT NULL DEFAULT '',
  PRIMARY KEY (`ID`),
  KEY `user_login_key` (`user_login`),
  KEY `user_nicename` (`user_nicename`)
) ENGINE=MyISAM AUTO_INCREMENT=2 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `wp_users`
--

LOCK TABLES `wp_users` WRITE;
/*!40000 ALTER TABLE `wp_users` DISABLE KEYS */;
INSERT INTO `wp_users` VALUES (1,'groparu','050e7277aac1415c68170d2e73ce3dfa','Groparu','groparu_ro@yahoo.com','www.groparu.ro','2009-06-29 20:37:07','xxx',0,'Groparu');
/*!40000 ALTER TABLE `wp_users` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Dumping events for database 'mariuspe_groparu'
--

--
-- Dumping routines for database 'mariuspe_groparu'
--
/*!40103 SET TIME_ZONE=@OLD_TIME_ZONE */;

/*!40101 SET SQL_MODE=@OLD_SQL_MODE */;
/*!40014 SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS */;
/*!40014 SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS */;
/*!40101 SET CHARACTER_SET_CLIENT=@OLD_CHARACTER_SET_CLIENT */;
/*!40101 SET CHARACTER_SET_RESULTS=@OLD_CHARACTER_SET_RESULTS */;
/*!40101 SET COLLATION_CONNECTION=@OLD_COLLATION_CONNECTION */;
/*!40111 SET SQL_NOTES=@OLD_SQL_NOTES */;

-- Dump completed on 2022-04-14  2:31:02
